(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   4195894,      57968]*)
(*NotebookOutlinePosition[   4239707,      59404]*)
(*  CellTagsIndexPosition[   4239663,      59400]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["How Do I Perform CCD Image Reduction with ", 
    "\[CapitalOSlash]\"[",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`Mathematica\^\[RegisteredTrademark]\)],
    FontWeight->"Bold"],
  StyleBox[" 4.2",
    FontWeight->"Bold"]
}], "Subtitle",
  TextAlignment->Left],

Cell[TextData[{
  "   The purpose of this notebook is to demonstrate how ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.2 can benefit from the support for data stored in the FITS format. FITS \
data often contain astronomical images from which can be extracted \
quantitative data. The data used in this example were obtained on May 9, 2000 \
in Flagstaff, Arizona, using the Lowell Observatory 31-inch telescope. The \
optical system included a liquid nitrogen-cooled CCD camera with an image \
resolution of 512 x 512 pixels.  \n   All important system properties are \
stored in the header of each image.  One exception is that the Filter \
property incorrectly reads \"I\", for infrared.  In actuality, the data used \
here were taken using a V-band filter that has an effective wavelength of \
about 5500 angstroms and a full-width at half-max bandpass of about 890 \
angstroms. "
}], "Abstract"],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[BoxData[{
    \(\(Off[General::spell1];\)\), "\n", 
    \(\(Off[General::spell];\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Loading Reduction Frames", "Section"],

Cell[TextData[{
  "   First we need to load the images necessary for the reduction process. \
The frames consist of a bias or zero frame, a flat-field frame, and the \
raw-image frame. In this case, the image was taken through a V-band filter, \
so the only flat-field frame needed is the one taken through the V-band \
filter. In all cases, ",
  StyleBox["ConversionOptions",
    FontFamily->"Courier New"],
  " specifies that the header data should also be read in.\n   The bias and \
flat-field frames included in this section were created in another session \
from a series of frames. The average bias frame is the average of 10 separate \
bias frames. The average flat-field frame is an average of two separate \
flat-field frames taken in the V-band filter.",
  "\n",
  "   The bias frame is a measure of the \"zero\" point of the CCD chip, \
typically obtained by taking a zero-length exposure and simply reading out \
the pixel values from the chip. The bias frame is necessary so that when \
pixel counts are performed on the reduced image, they do not include the \
inherent electronic signal produced by the CCD itself. Since the variability \
of the bias signal is small across the chip using the averaged bias frame, a \
plot of the average bias would simply reveal a nearly uniform field that \
looks black. For this reason, the average bias frame will not be plotted \
here."
}], "Text"],

Cell[BoxData[
    \(\(avgbias = 
        Import["\<avgbias.fit\>", 
          ConversionOptions \[Rule] {"\<Verbose\>" \[Rule] 
                True}];\)\)], "Input"],

Cell["\<\
   Next we read in the average flat-field frame and display it. The \
normalized flat-field frame is used to compensate for irregularities in the \
CCD sensitivity across the chip. These irregularities may be inherent to the \
chip itself or due to dust on the surface of the chip or on the filter being \
used. By exposing the CCD to a uniformly illuminated surface, the resulting \
image reveals these irregularities. By normalizing this field and then \
dividing the bias-corrected image by the normalized flat-field frame, the \
image can be corrected. Pixels that are less sensitive are corrected so that \
they are consistent with pixel values from more sensitive areas of the chip. \
Similarly, the more sensitive areas are corrected to be consistent with areas \
that are less sensitive.   \
\>", "Text"],

Cell[BoxData[
    \(\(avgvflat = 
        Import["\<avgvflat.fit\>", 
          ConversionOptions \[Rule] {"\<Verbose\>" \[Rule] 
                True}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListDensityPlot[avgvflat[\([1, 2]\)], Mesh \[Rule] False, 
        ImageSize \[Rule] 350];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 350 350 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.001878 0.0192308 0.001878 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.20703 -0.0125 -9 -9 ]
[.20703 -0.0125 9 0 ]
[.39483 -0.0125 -9 -9 ]
[.39483 -0.0125 9 0 ]
[.58263 -0.0125 -9 -9 ]
[.58263 -0.0125 9 0 ]
[.77043 -0.0125 -9 -9 ]
[.77043 -0.0125 9 0 ]
[.95823 -0.0125 -9 -9 ]
[.95823 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .20703 -18 -4.5 ]
[-0.0125 .20703 0 4.5 ]
[-0.0125 .39483 -18 -4.5 ]
[-0.0125 .39483 0 4.5 ]
[-0.0125 .58263 -18 -4.5 ]
[-0.0125 .58263 0 4.5 ]
[-0.0125 .77043 -18 -4.5 ]
[-0.0125 .77043 0 4.5 ]
[-0.0125 .95823 -18 -4.5 ]
[-0.0125 .95823 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.20703 0 m
.20703 .00625 L
s
[(100)] .20703 -0.0125 0 1 Mshowa
.39483 0 m
.39483 .00625 L
s
[(200)] .39483 -0.0125 0 1 Mshowa
.58263 0 m
.58263 .00625 L
s
[(300)] .58263 -0.0125 0 1 Mshowa
.77043 0 m
.77043 .00625 L
s
[(400)] .77043 -0.0125 0 1 Mshowa
.95823 0 m
.95823 .00625 L
s
[(500)] .95823 -0.0125 0 1 Mshowa
.125 Mabswid
.05679 0 m
.05679 .00375 L
s
.09435 0 m
.09435 .00375 L
s
.13191 0 m
.13191 .00375 L
s
.16947 0 m
.16947 .00375 L
s
.24459 0 m
.24459 .00375 L
s
.28215 0 m
.28215 .00375 L
s
.31971 0 m
.31971 .00375 L
s
.35727 0 m
.35727 .00375 L
s
.43239 0 m
.43239 .00375 L
s
.46995 0 m
.46995 .00375 L
s
.50751 0 m
.50751 .00375 L
s
.54507 0 m
.54507 .00375 L
s
.62019 0 m
.62019 .00375 L
s
.65775 0 m
.65775 .00375 L
s
.69531 0 m
.69531 .00375 L
s
.73287 0 m
.73287 .00375 L
s
.80799 0 m
.80799 .00375 L
s
.84555 0 m
.84555 .00375 L
s
.88311 0 m
.88311 .00375 L
s
.92067 0 m
.92067 .00375 L
s
.99579 0 m
.99579 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .20703 m
.00625 .20703 L
s
[(100)] -0.0125 .20703 1 0 Mshowa
0 .39483 m
.00625 .39483 L
s
[(200)] -0.0125 .39483 1 0 Mshowa
0 .58263 m
.00625 .58263 L
s
[(300)] -0.0125 .58263 1 0 Mshowa
0 .77043 m
.00625 .77043 L
s
[(400)] -0.0125 .77043 1 0 Mshowa
0 .95823 m
.00625 .95823 L
s
[(500)] -0.0125 .95823 1 0 Mshowa
.125 Mabswid
0 .05679 m
.00375 .05679 L
s
0 .09435 m
.00375 .09435 L
s
0 .13191 m
.00375 .13191 L
s
0 .16947 m
.00375 .16947 L
s
0 .24459 m
.00375 .24459 L
s
0 .28215 m
.00375 .28215 L
s
0 .31971 m
.00375 .31971 L
s
0 .35727 m
.00375 .35727 L
s
0 .43239 m
.00375 .43239 L
s
0 .46995 m
.00375 .46995 L
s
0 .50751 m
.00375 .50751 L
s
0 .54507 m
.00375 .54507 L
s
0 .62019 m
.00375 .62019 L
s
0 .65775 m
.00375 .65775 L
s
0 .69531 m
.00375 .69531 L
s
0 .73287 m
.00375 .73287 L
s
0 .80799 m
.00375 .80799 L
s
0 .84555 m
.00375 .84555 L
s
0 .88311 m
.00375 .88311 L
s
0 .92067 m
.00375 .92067 L
s
0 .99579 m
.00375 .99579 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.20703 .99375 m
.20703 1 L
s
.39483 .99375 m
.39483 1 L
s
.58263 .99375 m
.58263 1 L
s
.77043 .99375 m
.77043 1 L
s
.95823 .99375 m
.95823 1 L
s
.125 Mabswid
.05679 .99625 m
.05679 1 L
s
.09435 .99625 m
.09435 1 L
s
.13191 .99625 m
.13191 1 L
s
.16947 .99625 m
.16947 1 L
s
.24459 .99625 m
.24459 1 L
s
.28215 .99625 m
.28215 1 L
s
.31971 .99625 m
.31971 1 L
s
.35727 .99625 m
.35727 1 L
s
.43239 .99625 m
.43239 1 L
s
.46995 .99625 m
.46995 1 L
s
.50751 .99625 m
.50751 1 L
s
.54507 .99625 m
.54507 1 L
s
.62019 .99625 m
.62019 1 L
s
.65775 .99625 m
.65775 1 L
s
.69531 .99625 m
.69531 1 L
s
.73287 .99625 m
.73287 1 L
s
.80799 .99625 m
.80799 1 L
s
.84555 .99625 m
.84555 1 L
s
.88311 .99625 m
.88311 1 L
s
.92067 .99625 m
.92067 1 L
s
.99579 .99625 m
.99579 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .20703 m
1 .20703 L
s
.99375 .39483 m
1 .39483 L
s
.99375 .58263 m
1 .58263 L
s
.99375 .77043 m
1 .77043 L
s
.99375 .95823 m
1 .95823 L
s
.125 Mabswid
.99625 .05679 m
1 .05679 L
s
.99625 .09435 m
1 .09435 L
s
.99625 .13191 m
1 .13191 L
s
.99625 .16947 m
1 .16947 L
s
.99625 .24459 m
1 .24459 L
s
.99625 .28215 m
1 .28215 L
s
.99625 .31971 m
1 .31971 L
s
.99625 .35727 m
1 .35727 L
s
.99625 .43239 m
1 .43239 L
s
.99625 .46995 m
1 .46995 L
s
.99625 .50751 m
1 .50751 L
s
.99625 .54507 m
1 .54507 L
s
.99625 .62019 m
1 .62019 L
s
.99625 .65775 m
1 .65775 L
s
.99625 .69531 m
1 .69531 L
s
.99625 .73287 m
1 .73287 L
s
.99625 .80799 m
1 .80799 L
s
.99625 .84555 m
1 .84555 L
s
.99625 .88311 m
1 .88311 L
s
.99625 .92067 m
1 .92067 L
s
.99625 .99579 m
1 .99579 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
512 string
512 512 8 [512 0 0 512 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAA9798A890A8A1AAACA18D88A4AB949D96A8B3B0B1A39E949A9B8DA2A3A4A1B3A7B0AB
B0ADA79BB0B69BAB8B8FAEB7A6B09BA89CA5B1C6C4B7A0A2AFBDBCA69A91A597A9BBAFA9
A5B0A9B18F8BACBBAD9E7D9BAC999CAB9887A4BB9CBEB0B2B5B1ACB0C2CAA8BAB2A4BFC0
A7B6D9E3E4BBB09BB6B5D0C6B6BEC8A8ABC2B1BFAEBFB8D0BFB4BD9ABDC8AEB2A9AA9CA1
A5B1ABA4AABFBDA6C0A68B8599B6C0A6C1BDA4B6BCC0B38DA0A0A3ADC0ADB1C1B9C5A1D5
C096B3BCB0B3BFAB95B5DBC3C8B5A2BABDC4C9D3C9B8BAACCDC9C5BBCFD0EFCAB8CBB8BB
DCC6ABC0C2C6DCA6B2BDBBA3BBC1C6C0B4C0B9A8AAABB4A5AFC3BEABB5B5AF9ECABDB8A1
AEA8CFB4B7C1A1BFB0AFA1B1AA9C9AA3AAB4C0BCAFA1A785A6B7B7D0BC9CB68F87A7B2B4
BFA4ABB1ADB9B1A48F99CF8F9D9B908B8F949E90C5A3ACB5A0AD9BA2BFAE939DB093868D
A1A3A69C9E9A8DA095AA829683A998A39AA086A199919294A7848F85938380979890A298
9D7F98928F8E9687929E979E92A1AB98A99F92979D9C9783999688A2A6949699A48FA3A3
907BA4897F9496A2868C83907C9683827D90A8938B9488847A8C7E928893A78DA2A19C8D
6C5851575552556356917A6CA17C8672567A6A78654F697096849DADA3958A7E7E83878D
7477848A848F727A6D7A837472869360828888769A817C9F818790819383957F8A60877F
8C70599288827CFF
FF91728772A98F9885A0898E926E928681987B8B93A07C8F948F818C8F9B9F999B979C8F
869D8BB4AE9A9793B4988F8CB0A58A9BA8BEB39E9BA6A698B089A9B3B29B9E868C958F96
9B84A0A98898AD9490AAA49E9CAFA49F8F99A09796A0AC939F91A09DA1979D9B9FAAABAA
B2C4A7AF989E9AAFB2AA9FA6ADB09DA2A18BA1B5A2BB9EA8B09F8FA9ACA286A39CA48A97
9C8A9EA27797A0B19988A19B8C948FBCADA1A0AF8B8E92A299AEA6928DBBA7AAC0A9A2B6
A4B197999790A6AAA69C98B1B0B198A8BB95AFABA6A6B1AEA6A3AAB19CD0ABA5C4B2B2B1
BA97A4ADA2C0B0B3A0B199BEAD9EB0B0B19CA58E9E95A8BF9EC0B2939399A2B1A198B1A6
A1A39A9EB5B4AC97B0AE8F9E9C9EC5C1B49CBFB6A09AA9A7819295A1C090A68BA2A4A98F
81A88D939389908F929FA686809D89948F748F7A9296A2A2AA95A69BB59B8F8E9587A09D
8C9C7886A099869592818C7D9981888E9CA394728A98888F927899819484A28280977A8D
88959B84937586929881798397726D72737F868D8A9C81928F8E898E846A809181867F7B
686B73886D717A80786D5D6E81717F7587928A9A887D7680817A8B7B8292877F829C7182
5D50514A505D566B6F66797E8D7C856A7E744D5157464B5274917D7D7893888668566C82
6B7257777F5A71826E89785E666C747E686471787A8A739276747174768A776D7291616C
6E6B717184807FFF
FF879BA0A2898C86849A8F7D999D9665898695A4A68E807EA09B9B829291988792A0959C
8999998EAE9B8FA18D94919295B6B392A7A5959CACAAA4A89AAB9195A3AE759884839389
8E8A949B9D9382907D97908D95927E98B09999A9A0A3859B8F8A8C83A0A19DB6B5A396B6
A7A7AEB0B5A0A1A8938F9BAFB09A949E979D9EA29E938CA4A0A3B6AF949FB18A90809F81
A4B3AAA0ACA0AFA19BA4808A899DA28DB5A69E91949BB78BA49F99809A99AC90ACAA90AB
ABB2CE9FBBAFA3AC97BFB7AAA0A1A9A0CBA58DC79B99ACA7AF97BAB2BDBBBEB091B8C4B1
9E98C2A6A5B6CC9EB290B299ADA29EBEACA18DB1ACAF91A0A3B5A5C1BEADAFAB708F9F91
8D9D87BC9F9699B2B3A5BBACA79EA99DB0B7ACA6B1A9AA956086ACA191A0AAA07696837C
907D7DA490AD8D867B877A87BE7D9D8E6B8B8E7D7D9297A28A8D79AC9488968689A17B8E
8C8A9F9F7F887F748496958A97868D8D87859185718794AAA48BA27B8E997491887E8C94
81838C88837D9C86646A7F9E8B687084908F838585768E9A82828D848386867E7272827A
696C938B7B8E819A81817B90817E807F63887E776A8C89787781597E958172909B85937D
863B35585250396D6B9075726B80787B765D556665704D7B847E858074718E75787C844F
4E60776C786469716B7A82746360707572708A868365696A8D85866D70666F7977686089
8A704E51747F7CFF
FF837C9671828091A58290A07E97947E7D7C9294A58A8F8A918985957B81949E94829392
A2809E777F98A3A5A0947F8B8B8595A6A7A0BA9598939AA7A699A1859588989BA28D7C90
968E90A6958D909B9F769D988D96867786948893869998BE9A7BB098AAA0A2BEB7A783A8
AF82799D94A6A299A1C5A1B29EB0ACAB998D8DADB0949EA7A0988B8490A4979D91889D9B
93B0A28491909C9BAC8E8B8DA08A97B7919D9991997A91A08B889DA19EA1A3B0A49798A4
ACAAA5ACA0AF9491A2AB87B9AFB1949BB2928FB4B4BDAD9EA6A6A5B5B3969897A8ABA9BD
B3A189A1B3CCB9ADB1A2A4A5A7B59B8FB69890AFAF93B4A0A9B2B5A99BB8B199B2AFB0A8
95A9C69BA78CA1B692ADABA79CB46CC6A893908A949D9D877CAA858A8DA79F888D889475
9D8CA9969B956E8883917086A89C9D818B9594898E8E89989F93B48F9CA3808179909C76
8C8681838C878D89877F92A48F838C8E866C8086858F9C8E90808F867F8F767B878A6A75
998A8B918C846C6B99919B9BA67E897E928F96848B867D768D8C7A7D6FA48E758A93987F
767E77718B7D7C7A737D7A8A71736F7B7E7C727B7B7C7A817B81947E9390877D8A94998F
63432C4C4940547F7B876B867B8A9E7C87715E54374352537B698391878B65807D775361
7070886F787F6C5D6E7677696F686A6F6F826072848C7C55526C7979786E7D877D666D7C
8068717668656FFF
FF90877E86838F8E747C86919C787A907F8D94A69797939882A1ABA6878B7F9E8C849C8D
7E8289919AACBFA192AC84A7A78EA69A9D988AA0938C8EA79FB89A9FA69998A097799B8B
80A69F9AA990778F7B888D979594859A95A5C39B92B079889F9D8FAA9693A58DA4A293A3
ADB2949E9892B197A28F9CA883A297A3B194B4BC9D95A4B68F9A93B58B779E918DAD8C9D
998CA0878696A39C87A78E9A9A9B8D8993A18A9D9FA7947C9D9D7A99A5B5C19BA8B2A398
AAA5B29EA4AF94B1B6AAA9ADB6A387A997AFB8B59B9EADA194AAA79DA99C8B929EA78691
8C90BC8BA29DC49CA487947EBDB19AB49AB1A698AFA1A7B3A0B69CA4A49EA1B79F7C9CAC
A4C29CB2B1B08886A18E819383968E86999C9C8FA8A8A09583808F968782AA8D8E948B91
8178858A8EA0A1928F969CB3A1A29FAE9E8E8A8B7D7F857A8E958788898088968C6C8990
8E8E8C8F7D938479757C868E85928B7B6A888B9D869489898481808A8C9D939CA6978388
8282827F737A8E8D877B836C6C5B79827B7F886C7587767683978A85808E998788728393
73777E887E6F83897279767B708279888B798B6C797B7A888E84757D9E98787C837C865B
66604B544E4B6E747F657A777F928D88806D5E4B3E45505455677161665D866F726B578D
8D8970638565636D76A25F5C6A727867566A666F86807D6F6A6378746E587065687F5763
8A8082747E5D79FF
FF879494909C6373787A97A8728B9B948494968D9892A290959199749096868671947F81
89A6A8A7A2907AA78D9EA6A0A4959EA1A2918B879FA999898F86908C98828F90848C9290
8F888B949D9F789AA489938795A5908E929293848C919293A0B19094818699929B9BA1A4
A6AF9796B3958DAEA490939683AFAAA69099939C88AAA79BC6888E918E948977A28B8483
A09F9CA37C9C809F9397A49793A49B9A8796A199A79972AD8A908388A0A9AAA1AAB1ACB1
92AEA9A59FB3A2A1A6A7BBC4A5C0C2A7A7A4B6B6ADA48FAFBBC1A5BEA19DB2ADAE8DA1A9
AFB4B5A69BC6949BA6AE9FB0ADAF9EA7AAAA95A8B39EA6AFACB28A92969CABA7A2B095B2
B1B8B1A09FA7AA9C86ABB4B9B0A09F8792A7B5A2948D9E7E9086899A9A9E91978BA68983
848B86887C917FACA1B0898B9D9A908D979C947CCA828F8B988AAA9178728B937F7A817D
929A8F8179757D748380878994928491948F8CA48D9796A48B958C6C9A879D9B9270AA9D
949E8A9A777589878295848A8777718290956E828A85A9628D90798D978A8A7A917C9784
7A887A60798890687470796984797A866C81787565728489647E8584767289878C948182
57493A4F45495C70666F8B887A777F754D56466A505B505E5D5E6A6A637872645C7C6A6F
7666717077755053595F6A6A657D4F4F77515B8871557D7C61856E5E5C6760697A76626D
D49264778B7279FF
FF90828991868D897989958A8A898993917891905E9F9A8A98AC898F878D8F8B739B9C88
859095887295A5A0A393A79F9B8DA0AE939B9A879B8980949689A4908398918BA2848585
90A68A847B90A67D89A79D998D91888B8AA89A83A09C9C9D837CA08D8A89AC9791928E8E
A18F9089AD968DAD9488AAA49CA784838BA199967A899B91919097A18B857F9773849693
998C9093958189A0A8947D869B9AA39593919D98A6A2A982969094A18DAFA299B39AACB1
B8B0A1AFB7AEAFBDC4AFA0AF9788C5A7A29385ACC8A8A5A9AD90A5A695A2ACB396B7988C
A4AEAFA9AFAFB2BB8FA1B59AB4ACA2A3A0B0A29FA2A7ACA5BBADA2A7B3A286ADB59BA4BA
BE94A59DAD959AAB83AD9D87ABA980929CA895839BA0798E8B7DA093877CAC9494878282
9C78748E7F7E8590A9909E8F8AA3AAA97D93708D97929897948583868D928D89828B8698
8E9D928F8C908188817C5F7493639B9587808088947EA2A96C94808F9BA9909BA88F897F
B496879298949298896C838477758889877D7F9076757975978B89877CA08A7C6D8C8C83
7C8384758F7773867B6F82877D767A788C8274795C7D7D7D8E82807B907A84829F907C78
4F5B466A594551605B827569707284814D6B4043624E3754558A7A817E7176696D866F68
617F736E8166766B5C746E8B6C6C4B7A64746C5169666A656A6A675E607C765E74626E7A
AD6F5D61617284FF
FF8A93749283848F83908EAA69719E907F937E70949B94887E86928C9F828A8392897E89
A88EA388A3989F848C9D958CAE9A9BA599A1908282917F918C95808985838C8C9280868C
889B9096858D7C957992949F8B949383879BA475789E9F9588947096919DA0AF95808C97
A39C929C9B9898B5B1A792A3AAA19499A79EA09FAB97ACA299938CBCA1899199A89C9E8A
9CA19BAA8D7F958D8D9D908AA7A6899DA2A49FAC95908B959A879CA197A286AEA1A4B6AB
AB9FB3A4B0A3BDBDB4A6A4A2B9B0BFA3A79CB59CACB1AEAAAAA2A7A8929AAAAEA89E9299
8F95AB8EB39E99AC9FACA6A8A696ACABACA59B8EA697A3ACA8B5A8A09A9CACBA9D82C0A4
99AF9A98B09392B9A79AA6B5B0A8A69084949D988DACA1BA9A929C8EA187B6BE8D85878C
8E7C9075869E9C9F9C829189948CA4A298976B80737DA085987B6F76868A94928FA19179
90949283827F79838969938F8D906A6B8C898493979589908C776E8A787C96948390869E
86887B85888C8B7C729C919D7D837F8775779D8B777B76818E7388767B847E80808C7375
61857A8D6E6D787F69738B63707878606D83636981735576836F8C7365828D8976899A72
66364D434A4E616E635C536771847274665D49585061695D74557C587371649378827571
7758788657786E7A5F73937977675F6F6F785E52527675747F5968577078675465677B66
69526D5C647E71FF
FF8480937C82A29188948A948687808A7B7D837A73878A937B907F96A17D7E6989878C7B
8E7A9A8988A1A7A09E9D93AAA79D90879A9F7C9998876C7F8D8184937B7289998F838589
84828E997F7B9C89996D7F7F94869C958A90808B8597828D7C848D878AA9966A8BA47686
9994A3A7908B98767F8AAAB0AC998F92A19D8A98839292A990ABA491828F8A8192829988
9C97A99C8D8F9B909B808B82A69087A0819DAB8B9CB19FACAA957A9788A2A4A5C59A9BA2
92A499AEB9AEADAAAAAFB0ADBC9A9FA8B3ACB2B6A6AFB9ADAE9283B5A9A8B9A9AEA0B29F
9F9C9FA685B0AD869E9DA2B3B6D0A19D9EA08A85AEB1B4A199A5A9BF86A198A8B0A89699
A1939EAA9DB194ACA48EA8B2A5A594B1A6969C9B9580969A9DAAAF887C9CA89088877485
955A728A8999926C64A48BA5927E6084877E998F86A6A29D95859588846B67937B989995
928A9E8E7FA5986E8A6F8D9485708F829795807D8F80707B86886D7B747D889397969E9A
9698948983808F809A82847EA6859D8989848B747A988680714A7296A0797F75827E8890
7982818D6A64657565796F6E74626678769867775E7D71697E937E68617E5F737E8E7472
7C6854424C534E607686645E5A506B6F6E64614A56525B544E737C885761778562657274
7C827580686389706C6C817763706B5A55716A8E7B6950756467856B6965254D7074727A
4E78516A87756FFF
FF988787849F95738B7E84827F7E789983938A9C89898A8194878474838697948C9789A0
888D95848CA082889C95A885789896A09CA69795899C6E6E7C7A709E8D98948E7D9D8B89
83827E7B9CA79C82958D8F919B996FA0968590768D958693809582909F8D9E8B6E838D95
A9A5A8A2A9929C949986889C9B8FA2B2919AA3889685A493AB909C9C958C789B9A8F887F
957C9D8B898280958B7DA08C9E9FB0A8AD9C8E958BA9999D9B887499999682A4AA9BA7A6
8F91A7A6BBB1ADA9AFB6B3A6B0B5B0A3B6B7A7A190AAA1ADAF9CABB49ABCB1928FA49EB8
B0AB8A98A1ADAAB2AF9C9FA1AB92BDADA199958F8ABAC2B1A4B9A28DA1A8A3AF9EAA9CB6
AB98A1A9978F9690A09E8DAA9E9A90A59E94B6998A89A68EA3758B887A9288829C837C7A
7E8B75718A7389827F9C8583988468668F80838C8C829496817BA46E8B907CA48BA98F77
87798879718B8384747B5A83847E727E82898E7A696196778A749A88869296989482918A
9D8D99777F78969E81886C817E8B867A7668677A797B6E6A8A6C64848D718699878A7F86
897C9A64897E7A8B866E8363569087846C667F6F85678867727A756E7B8B5D61757B8B6F
5F4F364F563E3D50575B624E5661546E7A585B4659594B5677726F6978788D75705A7685
676B7F75845D676C708B827670665174C5B857637D5E57575D7154546578667A5E73706F
634660605B7170FF
FF7C6C888E9190867983998C9078768B7983997B85917A6B7C5A4B73909A927C9B9897A2
A6A58A898A9B918D92868B89A79D7C7C81867B799383957F788E8171847685927B9A8E76
897A9499A5868D8B869F8C8291957D8C968EA38291858D917A9A938A849B9395868E8E8D
A6A69C9997998B7B969A829182927E9E8E8A938595A6AA939DA79393969AAD8F8C83817A
717F968E7E9DAC9B8DAE9BA7909D969FA2ABA0A0B2A884888BA69FA0AE9A8B84ABA5A58A
8DA4A0BDB0A3B5ACAAC3A7A9B6A0B2B8A3AAABA69EB3B4A189A6A0A4ACA4AC8AAA93AF9C
9BAA9AA2A4A7C0AE7C9D909DA7919A979BA6B48EA5B791A4A9A59791989EAFA3B2AC87A4
879F9FAE97A59999AE8797757F888B7F95909B9F96A19C9E8491A294A89CAD9882989F7D
78877E887D6E80867F8E89898C70808292858C8275946188A98082939995AB8F837D7584
948C99A7958A9A9C6D816B867E8C857CA195849281848280916E5A7294907777948897A1
7C8C847D927F6F9680888891828E9DA2657B7D74816A68797B7B686B8A8D59758A818E8D
807E5C8A7B6D6A70781E8786696672606362728A65727768727D7A7F7E72785C80766685
67755F46555B564F4362675555535D63536B62615E54626A6865788074858085656B7467
8A6D696B6F7862668161687A6C71658FA8644D757B6E52598073586051514668848B5F63
645E6A6B706366FF
FF8965706B877F857D7A928171787A95829076877E94849A7F7A84857A8678A7828DA299
809C9F72868A96986B8A76808B8F92968E8C87877D897C88758B8F82938277727778998E
6A7E959FA19F967D708E8E8E89888D90A39E8D8B8C9DAF929C9996BB91A385898A9A9082
9B8D8C9891919B94A18F96949F979D9E9E9F94919A9799979D96A2A591909595818D9C81
AC7884898588A591998F93989A91A59F86A6939D8FA08E8CA2B4977F9E9BADA8A5A39894
A89DB1A9A691AFBDC1ACA2A892BAA9B3BFA6A0BB9D82A7B5AE9796A09990B0B0A89DA794
8DA3B0AAA29F73A7957B91AA9896A3A2A9B590A99E9FA38EA08F8B9E97A18D87B39BA187
94AD8988AAA19AA69AA29BA1AB8F859DA0939A979C9BAD978CAD94937D9280A58E859198
747D84868376576F9E7282716F7F8D7F9D9A9191B095A79EA19180878D6D78817F7C8782
7872798A7E79767B767170728585938DA389947D867D8D95928F878B879675A8948A8183
8B7796907A878B7683888390778D78778A7A8B736468696B857D817D8E737C7A6D788083
7C8661776870767A6F7D8B6B737F62626568727881868271838275817989717378698A77
88636251483F574B5A5D546F64666652695061646F706F72847B697B867472707C75745E
72654B748C66615D6B5D9059724F534E5E4C4F386F6C7463616D676562555B5E755F6D62
5D7578644C7064FF
FF9D87868E879377717A81929D868C837A6D7D8192848D807F8C9980988C829A93808FA1
8C9C8786748EA08D8D909999A97F9B8082856F9A8578879F9C8B8B737F768A7F846F8F6D
7097998D898A788D8BA99F6F93A080A29A9B8B73859188989E8AA6978F858C799F9F8CB7
8798949E7F9F9696AA978C8F9A8192858485949787947C96B5B09D9E8F9DA592818B8194
8E8BA091B09280B28E71829F8EB6ADABA5929BA78C8DA99391DFB5B49D8F918CAC9A94BC
A5A1B4ABB6A98EA0B6CFB5A59E93A599B49D9CB2ABB3B79193ADAB928CA8B1B19AA0919E
A1A3858DA2A98E8B9A95AE8FB1B3ACADA0A998A7C99A92919A9EAE8D8FA3A790A0B4B0AA
968C9891B6A1B09A94839CB98C96A0967D928CA39E97A69FB38598A6B08D9B90889F8084
9D719D8D797579736E5C736F7686829B7B9176A67A9A88959FAE88716B8B7CB0827B8B75
708F8A7D8476817D807C99958F9282877C7C878A789388859897898B85868A7D81888087
93AD90878587A48C81968D7B899BA781765B6F6E75677C644E556880718E859183888682
807E806A5D75806D77653F567957876C6D6A786863706E828187746987986F756B786B74
6D74626E5E624B4D5A57736961586B5357563B55692F5D6769786C74737F99748B61706E
7A705F727168677F68746764716A7859445A4845624F6B4B5A7362696A74785E6A546F88
6E7F8970796846FF
FF79848D7283847AA27E7F907A8A889B926C6F8179628B6D7175899E7A97828A949DA384
7B8C8C8DA0887F8299849A80908882898C787F90A2945D827B788685768F7A7A79878A82
73698998887D67928F959C969FA4AD9BA57C879F9A949BAB93959AA48F889CB3A090A490
84809FAE8596A3929092A39896969291768E9D93948A96A08C9197A1A7AE9E9B8D7D8E8D
809B8C72738E8A99978A8B97A399A8B1A9A0B48AA4B8949B94B2898E868E90B694B2A09A
A5A596A3B4A9A3C3AFA2BAC2B0A4A3B0A0A4A4BAB2B29CA0B99BB29A9A8DABA690919988
B1A38C9F96A89E7D99A1858BAE977E95A4917FAB92A5939EA1949FADB294ABA0A2A298A5
9CB3A0A690AEADA37D97859FA0929A798894869987817F7573A2828694A69D94A296859E
837F7D89757B667D5C5A7B8B8A8F8A909D7B9A7A979C9894828F9793988A848E67738E8F
65657C87877F8E85736D69767891756B8D73647772818B8774848A818082829C9C869485
8C737C82938689897F9085897486807B6B6F7F5C4963666D615360726577798C72838878
756F73758579766C63777F746B73565284835A5B6B63867086798989835F60626971637C
7356705C575A5D623F60636D5762444A445B55517A63706A70767C6F7575727385698371
796A6E65756676727F53675E5A5D7267645D6674657574665B705E746C655A846765666C
747D7F7C696D53FF
FF85959381868D90828B8C7F7D90947F6F9D7986938475707A6F8E92778481748680889D
9C9384847D9C897F998886989F78798D6D62598D7C9B8CA6867A777B8A7D60677D715F81
7691989282918E9F8C8DAF9A987B90AC92979CA2826F9D717D8F8B9B809BAAA8998B7B89
A699909B8F849C89ABA898849DA39BABA76E9A9A94909DA5C4A29695929D98A295909B6F
958E8D928E9A86929E76929E9C9CAE91B0AA97A4AD7F9AA2A29AA7927CA9A1A69B8B8C84
B09BC0B8A8C6A0B3A9A5A6A99C9AAFB89BA68AB6BCB19F9E87939AA0A9A49BA7AFA6889A
968CA89780919A99A6988D99ABACA288909CA1B1A79F8AB1ABA2ABA9A198A4A8A2A6B48B
9BA3A3B39A889C958482A3A590A08C9390828D90999A7A7A9692828E8C959693A08E9098
9B5C7E7F838F967B716E8275838491B98A88A5929598927C9A8D8F83946E897F83708D8C
858E678C85846A938D9476886172768298897C7A7B886A898B8B81948C82A08F738E7C95
8F9E838C889269788B6C6C6F90707C6765624D535663625C70354150827A6D718A7C7076
7F808F66567C70757557647A826C61745D75778A7C63777F738F6C6C716C7260636F7968
6A706C777044364949645D4E6A6F5B5B655B5E5F5A5F76617C736163916D77885A84777B
5C52727D5E6A6F787570796B6583727E7873727B6A6B5C747C647260717375616C646268
745F7B5D684D35FF
FF8A847C9F8D837E88957E797D7D7F786E7B6C9397868C718A708081818197826D769672
8C8A94798E8A848386A49A8B8689768A857F7A898691977F6F6E5B77737C815760637777
837C7E8E797788958D6D6483728E86968287897E919AA1A49E9C8E8396998C9190A37E88
A1AAA7A2A37D849596898E9EA48B7385928098A3A6909D9191948B8F7A75838284818C74
989C9C76849A909B9E969CA7A28C9C9EA6A0A19AA9ACAD979C95899EA0B3B3ADA89EA598
A3928C95A6A5B3ADC5B1A6B49BA0A3A0B9ABA0B6A3A09B9FA093A2B6A6A49EB0A69BA2B0
8EA192999986899977898E9A8A939AA2A8A1A0BEA0A4A6A1A499A4949E8A8B9E7EA399AF
8585A397908578788586838A97A2719B96AA9395A0A3898D98AD959691968B818897779C
9E8F8B7D85A7736B768E7C948C9E837A8CAC87847CA5A88284987D9A9789817F8BA58F90
8B856F6F637B7F8D94887F7D8E7E8A737B717483727B888B8590887A9D8C9484A07C9286
878A9092876D838194848071746F805E765B66646C58695F516370665261505B595B698B
53725F6E6D687E75736F866D7E83796B676D738190847D7B71796E7A5C62756D75808B66
5873794E7558494C666B6471727544654E47595E7C845F6F447F6D796C5B5C696873776B
676D6D6D866F645B6B645B6A5A6B6A6D6D6B615B5D69556B76725A4F4D6E76605B716F5B
5F637E7D624534FF
FF8667917985768173746885798F8F7B817781938385807C837876717D7D85858F898279
8C878F9292A692889D979A87A0948F8C7D7A6464838556606D62675D7A66767867555F76
80938B84967E99A498A1929771AE9082898E91937BA39F86839BA48AC18E939B90909899
A19E77A1A89E8D98778395897C8C898E8F9B9CA8B199A17C9E8F87909C9B98869C7A7C70
9390869B8F87929E7991939F859897B7B3AC9AA6B492A3A8A593A396A699A8A6ACB09EAB
B0C2B292B29DBDA09688A6B8C1B99EBEB29FB2A6A5A39B9B999AAC97879E9B82A09BA99A
958A879C9F97938286A18FA07F989A9E9A9B9EAAA088B07D9E977FB09AA8A395AC929D95
929A9A9C98A48C9D9DA19A87949697A590AE8CA5948A938E9EA0A1829E87678F8B95A093
9CA77E92908698898F8D937B978FA183A083889B88A9A07F9A978B89968087629996A47E
81758A81999A89877E656497995D6E77686E73889694907994A56C6B8764938E697B7A93
7F73868A747A856E76728C7C757A62685276654F647B6768694862555A57545A627C7F99
6E6D654C6B927558787E796B937266677B727F6D815155767969737E7459809459576C67
7D716E8A72757B793F615761504E56606949616B72656E75687A7F6A4F5A686163555A6F
90726E62535B657569755F76573F5F575F6750696C50535A614A5361597650655A757275
6C867C423E311DFF
FF978A7991747A8C9B87787B8469757875678676667B8F969D89887979846A848E8A758B
867D737DA58988806E9472A0968D80867061747D63675D6C625759596F696D73726A7882
6A8475897C979A8F6993B39D6677638E95987B877892727B9E8B8998758C8F8292918C8F
898D8C918EAA9497989F9F93989CB0BF9885948C93A39E9686949391968F938C7E8F96AC
868698828595A0859A9A9DA7B09B95B08F7B9DA7A7B19A9D96A5B1ABAD9F95A9ABB8BAA3
A4B9B8A5B3A7B497ABAC9A909F98B8B8A9988B988F8AA58AA6A3A287A39FAB958798A1A5
9BAA9DA99C876B979D9386818492989EA8BE9790A2B092A591AEA3A7B7A7B5A59295A5A3
9B9C9BA3988E86A99EB093A2809295AE97AFAE849375A8BE968690A9989F937178989BA9
7D86917EB592898D9885908F757C8B9E7A95A28CA4939B928B969EA17F6D94907D968E8D
989377998D787478686473737C6669769B9E808687887F6D6B8675828C928197A58DA48F
927190668A938F81807E877086757B7462675D6D5F597472736D4B685B553C5E62746774
888378857E6C628868947B8A667781938B8A687888636C7C638682797862825A5D76647E
6166696973656E797E6B5C5F5A746A506868657D6E5D6E61627E877D77547E5B6F597153
677E6E616B4C6462685F6C6247565B715355586F6A50706375696C66483E655E63686676
7274736B5D3811FF
FF858B8495959A84798C778C828A926D816E7D5B596B968C74858180A9837584777A9387
7C81798181937D9697888E908083806E88606F68647767594746685A6175597176707669
654A6B81866A8895A58F71808FA48C908080918F748D878F8D8F9099998B9997899B9D91
849F9986919A9198977A8B9F9078A09FA0AF96978A9F8C7A717F8FA09F809290857E7D8F
95A191908595AEA1A390968577B6A6979EBCABA2B0A58FA0AAA6B7B9BC90ADADCBB2B3A3
AE997599B6B9A8A99E9C8BA8A3B4B5A79AC7B5A4998A8AA4BAA09AAD7C90C79F939FAB90
8E9393848A9A939F8EA3848A8888A1A1A28CA4A2A68DA598ACA89FA48899998FA0BC9FAA
B3A399AE9F9C8B9C87848E82B5939A90939D9CA592779482A5A97A7E779480828F90A48B
9A8562807293A4947493969B9EA0A5BE8D989BA3869B8C91807D90778E7C83819E757F7D
82758F91758D7D698E737F825F628381836D7D8F848178798A7969756E807B8183818E7C
7A6477597B7784886F87805C644E6259576669686C5268655E62693F48414E4D67626A7D
777874797A7F69757A8F7A666761758185769E6C798E9053616D57756173536B72637369
5C5F6A747C736E6F6F54676F694A61646E7B6682617170646867596C416A696D626A586C
515971686E8A796C6554646984586278625F66586D575B36557665525558536D586E636B
6D77655E333222FF
FF80886E8382708087877B7974767C726B827B8B69718371808A82867C8A7780728E8D7E
75848A887886769D947D9A7E7E988470675D604F5F65555B44544F5D5B72745E657C6976
55666C7975867D8195938D838A8A9A9178828B7C8E9D8BA6A0A96D7D858989A37D8D7B86
9392879C8E8F938C8884887485A49585968E86AC8F8D848C8A909F838CA6A59583A1A4A2
958598949185918F7EA6A4939081B49D8684A99FA89C9BAD9998A4AAA0A49CBDA1ACA2AC
9BA59DA6A28EB2B1968E979DA6A1A6A5BF9FB9AEA6AAA99599ACA58F959E97A8999EA089
75898F96A4B18986888A8F8B8D728D8290B2A9979B88ABA5A0A381A690A0A2CCA0A3A8AA
97AF847CA1B7A8A6A4909E898D9C99A98C9BA49D8F93989D918D8C99807B859981848E9F
A27C8E97999D9193927F917D8B7D9B97969CAAA3A58D9D95798976909A9982767E7C8496
87858A77747F6E716F757A7782746C78886D7574688B8D7384737E72A58C8590888E937F
899B8885969BA0958C755A756F5859643D777B7C66747779635C535A32575554396B7B81
7D6F825673817276706774667C62628575766A7A7E75637E71856280634D75678283727A
7572666F77797866677F6E5F5A6D7577495C7960536E945C5B5554775D634F607C726152
5F64768481616D6370527A6A524F63586958503A655062645F5F7A6161636347646D7188
725F57523C161CFF
FF87908B8F89876B7C90746C76908D767B67807771868F88879473646E7A838284807D70
6081818A87837F819CA68B8C8F866260556B4772613D3D4949534E4A644E60717E698266
675E4B765D818A948589768582938D867C918F778D9AA181899690A6978D96898C7B7594
9E929288A49C89969A8C81798B8D7F8D95B1B09FA99F8C8193A98C85A3A5A085929C8D7E
87899D9692949A927D899AA0B79298A1B59DA8A8AC9AAEA39DADACB09CA79DADC3ABACA1
94B0A6A2A5B89E8EA6AEA19D84A08992AB9F977398AE9E9A9099A597AB8BA6AA7C749B85
988C869C9490A0A7A5A79D97998B9E9A98A29BAC98B49E9A8D927F9C9D7588969BA59D88
9A98B8999E81A4ADA2899D9499968F8AA08B9093A59498B1AE8E8A978E719C907F85A391
8B88A7A998819D978F9B96909A9CA592ACA19A9F8B99958D91808A86A8798575937C9B75
84837B747D7A8E858A7D70627A825E887B7472687E6C6E7F828E83938E7B80846A678490
9A867A90868B9994786E7C79684748479365686C755B6A62796D66384E52474363557B74
909A947F74647174707E75697C938E8583897063637F596E5D7A6C60738B7E76755E6B61
867482516368747064716179566A745D68517364668A7E79546485686D54556D7A747E6A
66626B7A6E617A6D54584D6F777E4F6154686F645A5E595C4F63625071617961576D6760
66787E4323161BFF
FF6A74858A6D659380726E7C837C849280705F52556B70929880897E907063817B808174
667A6D666C929596939294938F5664483D57543F17304835414C4D5654644E567C716C87
775C6371788A847C8C8A6C827D798E8C958E948B87899A736B82A4947189A29D82947F93
7E8286AF9F8F8CA48E837B9A98959D939AAB9B9994A1A09A8B7C96B288A189A1B0939296
928A838E90938B7DB18F9AB5939DA09FA787ADA8B4A1A2B0BEA0A69898A5AC9EBBA4B2B0
97B3AE9CB9B0B3A8AD9CA2ACA8ADB9B398ACA582BFBBAAA9B29BA4A98AA6AA9A6F84A28F
9A9090788798899F999E878EAF9CA989989AA99B8E7EA3B8B0AD9D98A689B3A3968BAB93
A981A7AB98A59FB38FA4938488A09495AB8F969F9F898D9E7E9B968694A86A6A90A58E88
8995939A66665985A07098A18298958297999F89A0959A87999D7C88817CA39596917F85
7C909A9681747283736370607C675C6E7978907E8B9387818E6B7F92999881889698AA9A
87907F7D9C8A9A8A8A755B5D615B56675C8367827E7F757257746244403E42544337488A
848A897C7E1F007B6F6B7B6578847F6D7092727278627D6D637B837D71736B546B6C8379
6C7A6A72637C716B7D6E7A7B616C725A5A5E6871617058695E676369765E716858694D55
7D76685B6B715F65695E6A6160606D5F645A4349455D6E5D624E4358466B5A656261646B
7A76565634391DFF
FF797C785E718583827F7C7784846C8C858673759D997A83648D6D787C7473605B5B838D
7A95808F8477979CA19A9180625D35483337332D4947435A4B5259615B5B677574827782
7A6C7D746B7E7E8285638E7989847591798F7C8C9195918F838D949A7187AA9D7D8D9D6F
89968C9F829AA28A8191859893888EA39299A680B0A39F767BA26C9DA79D8E858F888AA1
918AA68C7B94A7868983ACABA49EB399A5C2B5A586A0A8B09BA59DAAA9A4B3C2B3C9ACA0
B5A59086A0A8AFA7A7A0B0BFA1999DC1BBB1BAA2A292B2B19C98AB6DAA99916F94A79F94
808E8B81917A887B859B93A098A0948280A3979490AD8E9CA7A2A3AFAAB39D92A2A8888C
989693A3A09C9F99B5878D88888D9581A586B0A69897969B937A857781838E8E91908F82
868C898D7D808E8771A57D96AAB39774817A758F7D75899C9C928E9198727690968C7D69
7D9781777979A1747F8A76877C89666B8769856D74787775808E9285988F788695929385
9B858D92627E6E78867A7A6360533F5B643B5F4D4B6D7689676B693940483741444D6850
7EA18368866151667F777888776E7D6477817E79867C7074716E7D8C967C69625E5D6670
6C4D73706D6E806C7B7563767A77675D645E806B6B5C7075725568655B6F766E79726A66
63635F81795A6A6844727560747554664C4E424563515B5D715E444A585665635D6B6082
71605B35361D17FF
FF85686288778379696181928B85846E807C8476785C6C6A8A83665E748B79825E75788A
938188788FA48EA793876A66502A3215272F3740293F3D50605C6F6B5966586C63736D73
7359676067708374898F846783786F858A81798893A08B9D8D6A9D869485B0AA8B6E907F
8D967D678E897D7A8F7B9B876D82947E959E92938C988A97AD9FAB9D9C999B909B8AAB81
768B96928FA9A79AA69D8D94A0B8B99E999AACA3A0A5B09DACA7AFA4C8B0AFA4B2AA9BAC
A9BFA4A4B286B19F95C593B3B09BA2A7AC9FB2A092B7A8979BA694AFA0B39F9A94929A87
866C86678AA29C9A948BA5889C7691A496A1B2A99FA39E8FA09C8D9DA7A6B39B94004A81
95829C8675909BA49287A78494A170949EB1B6A88DA27F91889C7B919A938B92997E7A98
8B8A83837E937D9C9C9C78978D69889CA892949E8D8A9B9D9A949A898881A28D82707786
8A70758081807969777A7F836D806E7471826378878B8B63737573807C799599766D7275
7A88677A7A8B78808D7D6F6F695E48494753485F6F6E5747757162494A42313532375171
6F98757396806C5F6E8C7B81726B687770677C73828078646374647E6D697F796F787260
69726D7973565A7E564B655F6F5B807553676B79746C6C5B5D657C744A7571625B636E74
726463654C6C6B706D72736165726A5E5A426362736C5E806767505D59745B663872635F
8D776245312528FF
FF818B7A747A7E7477887883817A8B8460607B868278857774786472616D86767381718F
808B7E716D7E848C8C5D62642B282B32291D1F334733445969685E6644586A6F4D676C7D
8477777965697C76926D737C837F96959089869EA88F88523C978861619E8A94A1998F8C
909395916B86999A88A494878E86778A98AA9EA0909B97A2989C888E758D8D8E96AAAC87
857D80A596A1A1918C9C87B0AC91929FA4A0A0A8B490A78B9BB39AB6A2ABA0A0AB9AA3B0
ADA5B2939BACC19EBAA5AFB292A2BA97B59AB395A9AAB393A296B6BB9BA98D9DB190859A
817EA5908486916C8E88899A8B929394A4939B8BA68E8D938E9D8A73B6A9949B98003C87
AAAC9391A28FA7A6A08AA69D8D938C8FA3988C9094919A98918B7F96928F817F7991817D
9188997A7A7F92A08D9E978B8F899CA67F96898D86838D837F7D8E879293637383898D82
6A78807F767679817B7F816A5E7D5E7C8D767D8E6F7F6D826993868792828198898A8D91
6E648383817888808B875C7B595244334F434D69606E6062707D4B716050424443375468
84837A9D86938745747F7B72717F84696374717E6A778C6C61758D6C70798A7862696875
58675F716B5F586F63576A70995B766768637F78545C816C6E59656B6D8B5F6F5464686F
6F56716C55586C5574705771515B586053516A7070664A6062696D496C436274686B607E
716F66423F1E27FF
FF907082846882869095947E7268767E617E7C786F7C6A81907F708A847975878A776799
88819888795662627E772A212606211832413A413935444653516E4F6556586760818281
63726D75557B6D7D7AA68086A07A6C71907C917B921A64030055967C91907E9680969399
9493989891A78B707A939396849695969C818C8F8E959E9D807F8B91A48B8FA68D9B8896
96929295A7929BA7B49D9C8FA16799B3A08D88B5B3A3A68299A0999C8FA7ADC6A4ADAEB3
A99EA5A4A2B1ADB6B29B899DB2B18FB89EA2A2C9A8A0949B80A5A09EB3AAA48A99AC86A2
83968394878CA088838981A49C8A80A08FA98B7C7D8EA97E8CA68D979F9096A17D8B9391
898A97A29A94938F849E8FA1A09FA46C91928B828FA48F729E8BA483A48AA78C94948965
84759A788B87817D8B92977E8C859E8498817696728E868D8675977E8E8E926A868B7A80
85848B7A70627A5D598A89928365806B84716C726B5A5F577D846C928067807A7E757C73
83828E7F8B8784988B766A5D534E49543A466E6A7E74677E5F72606D573236354C23485F
67726A78715E7D778186948D757C7E7C6663687077655F747B606483747A7F978B64775F
535B67657A5D5E5C6F7670745F6B727A626A675D74617B70805F69757054885C7B866567
617E7F6569546A7163605A7752706A5D47655C60586147595C5C495C5460405C6B5F7558
6D6F5937451025FF
FF927588816E88876C6F7E8A907F887A6481767684696F6A697B736E7C7D897C729A766E
8E8386747A88615B4F332B35291C1D1E3D2E3B3539525153636F62625968514F4F3C8067
7E7766677076886F917E939F7F89888B87808C5500000000608F9C8D909797798C86A09D
8C8E9B967E7DA38D8DA895A199819490718F978B988C8A9D8BA09D8CA5A58A909695AA7C
9D989AA6978D8F9E89A0998E76A48EA587B29C969DA996AE95A6A3B5B1AAB3B2928CAB96
8793A1B5BFAB9BAAB19894B0B99F99999194BD9A9A9A9FB99E8C948E9AAC8B95A3B6AD97
8A76849C858A838DA280A5A29AAAA593A79A9CA17991A39B919878B4AF8D7D8B97828885
97A28A71949D889A9081976A7A8881A99A8F7E978CB27F8E8B9A8E96838EA093ACA98190
A19B8593897E72859D84A6A3A7A188A4849B9277838E73878E8B979484958E6E767D7DA8
848277758E7E9A81947C77857D76798A82716E7B576D9D867F858DA177A08187888F8D87
7C8C7686868A8089907D7C7B54516A484F5860567E64767D946E6B705B3F4E3C44213F4D
5C71636C78807378717B7E6C587E707F5F797A6B6A8580837B79887680897C7279848275
69655D4B5857596F6B61777C678678665C654D494B5E59617B78585C7182677251875B75
836D6D725A70685C6661685E7158674E686563526A575F4F67545F4E6986596358817259
726A502E3D2037FF
FF67748F7280767B815E7A7C6A78866E5D6D7F757C808B81747F79816D64717083788187
8E8F8F80714A43574D3927000E1F13154340495E4F485A4A3C61605F554C4E4D50417B72
826672697F8B88898F809A8C849D877D6E816D000000006E939D7E807E8E9686748F858A
797997668E9894AAA4858899A1AB9E7C8E8297A09877849C937E95948D9B8BA5819A9199
988C7B94929BAC9F8DDA9D9893A6A693A9A9A0A8A5B1BE8EA2A49C9B9FA6988F99ACA589
62A399B4AE99AEB0A5AB9D7EA3AA97A9B29DA8AA999CA77995B1B7A499918887A392996C
70A49F89978B70AC7C8293908593A69B9EA29B9EA29C9D93928CA579669A999B999CA391
A19F8E9A8A9984AB8A98979294858171788B9482967EA9938C89978E846491A191888B96
A188947D839B99A18A8C98B1B0979EAA85A79F849D768C969C8AA59786998494937E8E7D
9687897C777475788481748F8670865A8169897885848A887F6B7F8B927C7C8A83767B79
75938C6E83888181716C7F8658544F37463E4843544E86656E757065495C314355305646
545D777D82828A7E829382879079808A8975907C817E7A6578777589738D7A7276736355
664F6353496471675F84726074745F5B6966746B675F5B6963555A624F5F66746F497165
6977684267776264535769667C6F4A5D747A6A707364665D6846325672626357695B5969
685A605E3F3533FF
FF90715A727793848D7966706E678571766F7D997B858878857C72726A687A5963957F8A
758680754B71506446422E3A1B21282C375B616D495752596C64554C4454594D4754607B
5E79755D6F83807789A29BA79A8890777287880000698F9B90868F97928D81878EA18E9B
988A92978684967D99A5999594A898988B8B90896598B2A6828EAEACAB7F9891B5AFADAE
9A97A6928C989DA88EA1B1978BA78ABE96BAAE9F8F8B9999A4A3B19DA4A3A8A3A9A0AC97
999F8C9CC7B6A6A3A88EA7A98276859393948695A497939594A29A7F979492A49A908AA4
9B8782768E898B6E7F998DA27B95AA9AA36EA8A18CA4868F9C9F93A077A6B8A3989695A1
8EA4A1B59A92B68087A69F9797838B919EA9978297938F8682898E8D9F9CAB8AABA29C89
A49D9978829D81A57B97868C919990939C8C81A68581A6968C94709A94736D8B828E948D
7479738187847B787A6B945C8C768A678082716C62817C8A999E7C787F89798A8A868570
726F888A6E8A878799AA9C74683B4657334A5739627961698C666257624452444146263E
656A496674746C7C6D64748083896E546877787088616F7D6F79877C717F716E6D62746B
5D527A66556A626A74766069795F6E557670634D68717E6F5F6E73667E6981837962677D
6174796B73815F7D5B696E7E8A6C5F72595B6A77645C68584D51615F684951676A6E6F62
67772F674E414BFF
FF94836E6A7B7C878C81886B8C99795A797D7374746E817C7C7B797A7A86667E766C6D63
8270685C5A576451462E36152E422C4B306C7E8B8066595D516D62584D6446473D4E7F67
7B8257696C82717C88A08E9A988A7B8A7B9F7F75818B7E7AA782888387AD949A8F839887
91A37B91879A908799A08FA49385948E937C9BA68B979B99889A9B99959E95A99CA68994
92AD919791958A88939296968DB8A892A59E9494A49A93AAB29795A4A398B091A8A2A6A3
8F93A1B1A6AAB7A7A7A48B85916EA7998CB2B6A9A8A0997F95939CAD9985AAA692A18C97
A3A68E78838B6D767E919AA49A98947C8F8F83999286A39E86AB9C908699849D948D8496
9387998C9799AC9C669D9494A1886F8E9A8B83A1A899908494B19FAA7F96809BA49882A3
818D7B928B81857A938490957188A080816F717E7691A08F89939F948779A08682858889
908A8E7F737E78768968898D778175837B76818C7F826B7F848E9696A183747892727770
79807D7D6E6389737A8B93755D53413F302F385353646D7482645B5E5A686E4C473C0024
5D605F7C5A898C636C645C677475707C696C8382706A5B6A8877837C6378786E5C4B516C
5C5E6A71665F62544C7A5C7A717D5B66615A546767715E6B6C62574F654D75576E705564
697C616452686E6E755E5C595C4B5F7775756466665F576B5C4E6C5A5A6E7A7A74726164
50525E49573F2AFF
FF7A5F6D7B616179667E7D8669697D8A6E655F74917E75717F716D6D707D6D666E776173
7D7955446E6B393D34513D3A2B48505D737B6770726C5D5A5E624E49552C644439505F58
6A655585767E938F9988938FA07A98828893818F8A97879D798B74959BA98CA08D908A96
8CA196967E777CA27B98988EA6888588889B937299869298968F8AA1A8A799ACA69C9FA5
998C98A5AF9FA18D88A296A8A5AE908EAB8CA09EA28F929B929CB09B9CA79992BEA799A2
B0A6CA9FAEAD9796A2AD84A291AF99997F9F7E87A8A39F8C99A398A193BA9A9C88A09094
8B809682759E75819B8F9D93A5998F69A3B099A687A9A28F927CB1A19DA89F7B958E988F
9B8D759280827AA1B184859D94779B94928D8EA994A09F697A7E8C72937395A4A8979299
9B7B80969E8C8481A18E977D7F8B7E8D788682769095909F978EA28BAA9A7C7B7E8D9B90
80877265897C8468608C78758386647D7586758B8171617385878F96798185807E897374
8C9C8888827B7A8B759D8C7E706B5A483A454E4B6D6F6A5F546C69815D745C5452453C45
536865817363948E59927A7E976D6586907D7E7A6F67736C807B6C7A5C5E606C5F615651
5770747E62697C6577665A60665E776555625D6B64646A707867686F6F506B5B7F5E5B62
37565E6E684E65626C4A765368617A706A3F71616D5C5D606E765D797A766D7D4B605857
6C665759605738FF
FF7C767179847F6C787C8E7C797C70716D636E787E747C7B6F8981798487807E676B8866
4B7D6571413C5A3D3849393F4E304A656479676F796F65625D4E52561F1A1F4D424D4B56
756E67777D808D8295848787939985867F936A878E8091737A8A927587918D8BA492979F
8F9E8C788798828B96868F857F8B958B92847E868D9892A8A58E8D968CA499978B9B918B
9B8C9C8F71858588978AA4849A7A82B28EA995937E79799AA98C9A8E83AAA18CA49793A2
979EAAA2B6B092A6959BA69BA8A3A3A27C939D839699969C99A389869DA99D92948E8A89
7EAD9F9C81838AAABC96829987948E91908E92958B958C81748F8D9E94979DA4849B7E93
8994679D7AAA998E72A48E8F837B8060919B8F969E8DA88C896F888482907D8E9F94A58D
A17D7EA3958585938995828198847F8D9B91629A817092938B72628B9B91807B6A818E89
9E7D99798B6C755A73656070966159848E7C6A6C85768B7D8B71827291907F8B818B7C97
6B8283767CBE86697B75757B6377554845402D4446384D625263615B6665505A55464A4E
6C466C5D8190748598867C75776F677B888F807451717F7178575C5A6B5954484E6B4A77
825D835A76586B6D6C536241656A60725768674C5E5761464660764A607567495B845358
7C5B7C604260716968506770547161537068454C5A53495B4C56616773675E57604A5A45
3F5E605D494E28FF
FF85777D7161626D73746982757F827274766D84826C898D886D81727B7C747F8169776E
8065635D465246545148423C51544D705C54618A63584662584C41372D282B3448505F65
7361567A63768E8BA79D8F9367848995907A8C6C96777D9DA6A68F779297999090838C81
716B809D95878194A6968F988F7F828AB297968A89949F9F939688807F8B908F9CA8B5A4
998D82909CA1878E9DA1898F8F98A2A792879A8C8997717D7FA1A591A69493C1A1A5AD99
86A8A298859E9DB090B29B9C9DA3978C9D8C94A4919772A2B29C92A19FA294A48A7DAEA5
8D939B8E826B8F7BA17D81AAA0A1B2898D938C9AA492A389A0A174B0A4B78A81A69CA59C
959A859B998B9A8A799191999B916D9788949887959D989D8A87A5936C89928F879B8294
868698A684969F9F929F8D9D7D7E839277889E8AA9917A79928B8B85859B8F85948F7A7B
7081807D7581748579756361647D8060605570816E6C85687580797A949991968E7E728F
877A8A7C9CCD728F7F84837B79605A5A344E4C4857556562584B5B656A8560596D675F5D
607078744A688E8E7A7B838676906586847C74877E5472715B666363565C68774950555E
57774673735E696A5E5F6D637072554C756F745E61706A6E54765B5A7C62676A77626D60
68675E69787A5275594C5B6E4F4969675778716B425258736276676D6C5A6E506C545565
6668466F43443FFF
FF837D907C698B7281738775866965846D617F8F7A7E7A82818E847C6E657C8787838881
7172575F6A4C68675766704F4F486C655570796A686C5F4B5139323A1E2F153A4B595969
7475718DA192AB93949C99948179A99B969C897E76A59985858889AAA78A8A90999C7F84
7C908F94877E91A490919570929296B39687A3B174979898A28C9BA09482A78B9D8F9F9A
9EA09EA0818BA79194BBAA8691AB98A996908CA5A8AE92A0AD958FC7948CB3AAA9BAA5B2
9DC2C28380A19DA095A09AC2A4ABA17E86989D98A59DA5A495AE9CA6AAAF9F8EA195A3A8
A7A1A0BF7E848197A1998F9899A794A87B9D908C9DAEACAC9198A47B97A99B88A79FA3AB
A38A7C888AA69BAA89847F899499AC9496A57DA88F998D8A92848D738C85758D95889C89
8293829B898F7E817E859B9C8DA3858689779A9F898C89927C7C788B83848D7C86805687
959A7684738E7F8182747C8C7085837F7A72998A838B717D89868988817F999892817D8C
8F7981907A98A08C8F7C9487838B7B5E503B3D2F474548545C5F6E76716C63685B695966
6E73857F907F82813F727579798287787864658184648975725F6864776D6B704F598759
6D6B74666B76706362607B605D6E5D62727660764F4E765B668371784A6F64705F5B5474
7D706C64676F6E6C6268795C7A7161675B5C536E596B575A79537659666F626E56606460
6E61555655412BFF
FF8B79766D7A827C697870887383806A807F7D857887738178848A98767E807484757072
685256496F715A83765E6544416947564F666B6766395B635664393021312E3756615881
7A84858D849E98959A969A8E848E7F9B7A8D8F868B9B929D8DA589A2848573898A6C9680
859975839E7EAD9D9D909D817473949887968C83A0A1A59A98928C9B9678908785B6989C
8B909991899994A6AA9BA2A090A09A9E9D94A69FAA95A0B79A9393859F97A8A59086A881
A1A8989597A291718EB7928EA1A09A9CA195919F9CB0839399A8AA979F979298A8C19D96
9F977ABD968E94939C8C9BA1877B9F9E9D9F9D98A09992959EA89093A1A2958B8395679E
8D8E7E898DA7868099968C9891A7A89C828BA69DA69A889D79ADB792859880818D878789
8F8A9C8FA995949B909F7AAA7E9797808F9C81698C8496777E7F6C90886E977D7F85728D
828582868781937B8277779587788D8F897F7B86839F968A81917480788C897484864678
7C7684589187938D8383849F86865F4A5C494D58472B4C4E6D59666A77736E6B586F5F76
78656578727D8485899C6C927980676F8D86727D857671767B6A6D6D80787569005E5D87
7C6F63736A6C7F5B5F545E5C595B756B7E4A64606F827166696775675F67727E777D4D59
5B606D5A626A77655A6B4F67615E5F6E6A6B75757E61566973606C7C43796760717D6A68
5C675C64534219FF
FF738176858179767E6D64889B7B68836C6A7482778B8F948A7A957889A48F705D7D6D66
6C6A725D5F77636775547B6F5E5E694E404C5F58493D5A50482E3A313A174343576B7761
70618D95698D8E8C9997897A799C7C918B748B9A81A87988968964959EA6919B9E9D908A
857D7C839F9083899292977D7C988997A4A48F98A38C93967F8F928D87A193A78785A19C
A2A19A939AA999938BA3A490918689A49C9DA2B39F99B1AAA8939C9397A0778898A1919F
B2AB949C95B0A2A3AB7BB0A0B28697B0A5AE9A909F9596799D91959A9DA9AF87919A9180
9A8190878B687D9685879676937F89A09AA6938AA99497917C999F988F8AA18C889B989A
88768F8A92A972879487899AA483899D967A81A2A394AB998290809B9A948C88859B969F
827D839B8C98929C8B919096909E918A7D9396839E888DA695836F8886816B897D777C85
89708E9B95806B91858467847398837A74817185978B958C7078906B79818C7B9C707273
7782906098905D858591998C81A15F74535067615F524253656180657F55765B6C696F6A
43527259897A8275727D897167816E756A668189807677706F8A8C85836882526E68646A
7668657873745D5749745456655A5D5E685B645C577E7867606D6E6472655D5D5C6C5D6C
6E62695956584C717C57635F606B5D4F6C707C714A6059505C807E746168585575646A6E
666D5944495651FF
FF7D7C86648B7B7B6F717B7A4B765D607B897186907D877F7F897C7B8A8374678B62696F
5657726B70777079758F64634D5D494A3B605A54564E45394834474A24454C4A677F7B7E
997F6F7A907C8F7D6F849C7E8B9AA68E8279978D8B8571949D75886699B6A79A95A0989B
868079957877848A8B9794A0978A8A828D969195A6A7A88B948C8C959888948F90928E99
9DA4B69FB899997D86A18F9DA2989C9B9AA5959D98AD98A6818E9386847C73897A88938C
71A387A4A394A19B93AD97A9A9B4B4ACBFB1ACAA7F9F8F8D8A78AA9F8F8595959AB89599
9EA28E83807C9C8593B0989D858CA0988F898BA895B07A8FA5729A8D836E8773A4919A7B
92979484A1918F8D83908F969D9A999D9B8CA8928F8F978D989F7C7E82A0958D98808093
A78B7B9A94838E7A82868A8EAB809996907A8D7085859A9BAE976C838F9986948A8C7F82
60698A8390796F5C73788D99889A9E898A8B7D7F9386887A87897C897B876E81758C8BA7
82747D817A7F7797908476779B938768775E54614F4957784E7B676C676E655C635F7250
606B67586D6588817A6D7282725D7A708C85798C97857A89916F84998863664166787B71
5E6E6B817B5F6A727F3F4E75694E5F6C5F755D6069756169554F7071716D6F5D765F7366
5A6F6D7A726D6A664E77686A5470714664686366766B58686B6260726A797767725D7273
6071674F4E4650FF
FF6D6E9884787B7A677C86787F7A907A928D916278927E9AA082919C8A8A866D70676D76
69686852567F84726754525D645042474E324A364429323B2F3229333E49524C6C628A84
88849173747D888B6B908AA790888B9296798E8C7E949AA28F959DAB8F9387849E8C9788
8D7D68688C82868F9C9496C08A969D8C888D8F8892B184A3A0868CA89796A1A08AA19471
95908B8A9699889593938E9CA1959BA5BFA5BA94B4B898808E85758570737672746F8093
8D8F92A0A29AAB999C95A99195A3B19D8B8DA48AB59D84A897A58D99A6B193A5ADA09D94
A18B9A866F8E858997768867A27684959D909A8FADA193A79684869C9A9B8BA4809B82AA
9A969D79867C8663807B9790A6A9A0959D8A918C8D80839990896C7EAC9BA6A4A083958F
9B9B9199887B96947B856F92929A758F837A908A988D8B88879B937A897E86829C94966F
8980878384A382818B96A68B9491938E7D8899757A7F8A78779389829AA38A958E7E7982
99737B7A6C8B8478548E79808D7E8E6B745E564D4F484D51706B7B666B576F5765876864
6B7A8876687C586A677A6E7063807C6F727B78707D7C8191739A897A7C7E706868676785
73875E826C866F5B687160795B635E5A5D4E5655706241726079766F5A57695C61746260
56596F7168736E725B6963775F615F5C5D687064656C5F686A737A7371596E54604C686C
615D785F4F6F45FF
FF8A726979637E828A9482776A7A6A63787E8685817C767D83777F897793778B737B6F71
777365635E6C8B8F737766564E483B4A373C2A31001A4B35313944444E53536C93899B88
829D8B7B747D798A849B96718D8889777E98A5AA9385968D8690AA9385937686968D8E88
9784766F7E966F6B9C89A4909F93858EA098949E94869094A88EA1A69C9FA4B2978E8993
9EA095839389816E808A99B2A493B4A4A4A2AF9A959DA78B70736A716163666878857776
809572949FACABACA1ADA9BA9C8FA7A697AAA79C8F8F978EB4B4A492A599A5779D978798
9C93A18279768475779C858F87857C8A6E897B7990AAAAAA706BA7AF85A3A3A2AB8B8EAA
9A8C7297948B947E98A2979D96A392BFA8A49C9A92AAAA959E97AF9C82967D9D919F829C
888C999896888596A78D869580898D787090A49694A5949379A8818670889A7E859B9198
92939991927C92918F767C85968D6B6C85A07F888C7D837D8694A0656E9590869A839476
8382828CA38C826F75976F74799B8D736C65525E60664F6F5F59786A6B5C64656C61526E
7E8F7B75787E72847B8A707179826979848A8B9C7669716C668684946A8468765985836E
6B5F776B655A684B66657C5B67707487625E8166776469706C72846F687265696978626C
64718961523C686A5F606C544E7362657E6A695D81787E6C558472695C616A6A3F665C61
3F6C45434E2D59FF
FF7B846F5F777F85884A736178827B7A7C818A686E7F787F8288817D9C8292837E5D7455
5C647B6A7D7786776D666D4A43514D4A493E290F183630193738385C6A748486979DAB98
88738E756F79A078829283768D8F958D8F999B8E9D9D9FA79E92719590907B939196978E
A17DA09082758C7B8A859095957C9DA093A2A293968AA799B4B0AC8A9A9790909E8A8D95
A48395A15D8078A0A29191A79674A19895A8AA898B805C626741594C453B504B6865696D
8776948A93A1969D98B5B3B0A69EA99EA4969E869A9EB6A09F96AB989CA1949491A5A48A
968DA8AD9B8FA69D8E9FA48A8490AB939477988C86AEA1AA9397928597809A9093A0A3A3
C28B85A48D848E936E96A5A09F86939C979B8799A9A9927F90829F9797AE9E868C9698A5
999088819AA99089A39881848AA4A18782AC9199947C918C8990908E876A86809B9B8180
88828997889A9275719993878B7F768E8A7F90837B7D94A28C7A7C787A8180878D7F858A
778F75907985737C86647C5D868080927466524A4C5D766966544B665B6C6E767A6C776B
776875778D8D5E757089937B6486896E66998585876174878E6882837C6F6870645B6364
66666262675B535B54796170595A6063635466577666636F5672524F7170726B6A51777A
656C606564695B717B5A6862796B4B624E747D744C70766A50716F646852647068765C61
70604B51473C49FF
FF8C89786D67777C75767898948C7F7E838D78916C7C778C818285857A9A6A8A8B925C53
7671516A687680706B655D595A302F552B2A2C2040362A3F4537595769718C818BA49792
81868D89795F7E9071958775988E93938095A69989A07F668E868B8E7B9B8A7E878A7194
8B757E6C7797998D9A90848DA58B8292858F8975759AA2AA8CAB9DA1A172909DA7837681
8880759F8394839A897E93929D979E9E92828060643B402D253C2A2C38443B3651486E78
5F6A81A0A28BB0ADA0829FA3A78E94A59E9494867F858C938E9C93AC848BA6928E9D97B5
B4B5A79AAC90958B8687898698A196918794A49D9A8E9EB0A49081858BA0AE9F90B99A88
A1AD8886A0968A80778A9B888B87958E9B6B8B9D7D8F8EA4A391A093A09786A38E8E9C97
8C8A83848F9E9AA49CAA98B3B98784A88797919089928A7B70938C979B82809C827B6A96
918B9C9A95989CA47F8E808285768477918C849B89928D7B77967B96858D8693729A8389
9F8A806F9D7D6F736D747984897D93704B6478516162587A664E57655B5867677266778A
7E7775818D6C706F7B8091798A8A698C6A70887F7986637D6D6B85805587767268555553
6D6E536371585E486F56765D7077595764684F65775B5D706760665C5C6478696B605369
7D61725B585E586552826C5D4D5A675F68646575648B78763A5E4F6D715D677070626A63
5D5A564944495CFF
FF7D6A7F7B6070847F7B7E8F7A75897065857B7684798E61887F91868E6BA79D81708974
6E7C77926B6B6B6C6E616E5D584D4236452E35333A303D483229455E7D8B93848282918E
869188757D8E86809F8E886F8B8A998D84A3A2828A909B9688979C928D6D9A8A868096A9
88A0967B75677E8C958A75A783918A90828E848F95A09F9B98998D80B2907F868CAE7F81
8DA48979A0808B8AB28D9E8D9A9B908C758C6656411D0112120605262D29242854605356
5E7992769C979EB69EA4A496939AA08873827685838EA384898D8E7E9793AAB39EA09C9F
A38D9B8056928568898F8B7C82A98DA494996F869B96A0B19890958D8C93A69496A98D7F
998DADB1B298A4A49D9091826C89938D81907D988688AF918C888C90A085A7927FA0A5A2
979C98889A938B998E8B93A6809E8B868C8A8F958D9A9F9F79959196A37F94918BA18C7B
9AA58A997B79A5808D787C81948F87928A766C838698958C92849882807D8E7B817D8786
7389978A7A887C719A70857B8579726451858C6169687C69646D7B5B5665526E5972738C
84737E75798486836B577D6B8679788382926A7A796965806B63806B6358727061636A7C
614E4B5E5F6D567169706571826C5B645A745F646B6370665D6668736C52565C69578875
7B5A5A7D73667A5D64697363776C74596A637F6E827D7371686C846569687D57546B606F
6A59304F41423FFF
FF7E916E6B83716A8B6D6E72817674977E8F8D8A717E77777E79768E7E8590816E726D77
725F70687C84857B665E5050503B373D5C4F4B433E305A47493F7687838C789899999C92
A0859584887A90838C85797A887F998E91A8A8979492A7A79E907C8399927E8A8B7CA281
8E8B7AA69091AF988EA18F85AE96798F839C92AA9593ABA8A18E829092A283A09C89838E
7585859E8D8678A48CB196898F948686644C5725000400000000000008234D2939584555
7150767090A57B97A39EA3A49E9A838577624F4B746B67706D5C676B8BA08F8C95938F9A
9E8B9787A48D8F93828C8B969198BAB69A9BA8AD92A0A3A4A6AC7E9F9C8E778279919D92
8498909E939C83909B9F857F99858BA0908BAD8F938798B29C887B9AA8A785A4937EA69F
A57B9099A0919881979AA183908E9193629A957EA39E9C8677808A7B6C9486968A72868F
8C8F9C98807C907E8D9E7D89958187899C7C907F9388858278715B8E8E7F86918A9763A5
8F81879276847780786C758B8071826A6A85736F7D8063476669675B5B716C4C78716268
7986867F8784707C7C8C8D8970826969928A9189858062768789827E7160706B7462646D
6A6F814F7871684D645D7A7E60637265465C535E6F77636D6E6989806C5A595B6867655E
544966674863526C584C62566F6A564E69504D696D37636360646C79607E697B6A535548
5362494C4C6357FF
FF917172727775806D888A896B796D71938C93857686967C608B82768D80587D75767E6E
7169797F7C7E755A6B533D424239485A63465D37436A5251555B6186949085938D879895
94937C779590888C92948793958C929B878497919E8AA2AAA0A999A195919167898D9F9E
7C889E899F9499A28A758991A1B3929A998A997A8D858F988FAE859AAB9D9C948C929391
A28088957982929D9194987B8C7E745D34371A000000000000000000000B0931394A5639
4F694E6F7F9498858CB7A082878779886180676F794A485D52546B7C7B7987A18392909E
9699AB969F96919B859693A39B88788190A39D9A8D949DA88B949EAB9B9F9B9FAB988C80
918A878A938988919A6F85938B909186987B869F759AB085A18C8896B483AA96848AA1A4
889DA29F959798888EA39EB392909E93B59D94A77D91967484838C8E868A98848D9A748B
8D817BA5A6937C87768C838293957288838F7D007584878A938A938F976A6F7F81818982
878188776C85866D6E7B8D9E817C836D75707F79764B776673756E687D846D74725C8578
68657B817D738C817E86466F86816F8D957F7D6D757B726F806E837B554F8186806D7159
4D6A5B7B7172596C5960685B745E677A7277737D705A61756379636465745977526E6B6F
5E5D5E826A675C675563535E507C4954614F5F64515E59586E5D745B5C7B4E5F84605C29
5B584A48563A58FF
FF8D8E75757A7D6D9985697F846E758F6A937A85867660888D8A8D7887817D7A86667F77
6F85717F797B7177684B503E494A43504548454E6C667B71768474979F7B908BA88CA297
909492A48EA8A19F9A9E9A968BA4A29194999A91A3A58A88A68481B4889B83948F979B8E
93A08A7C8BAA909989908C89A395A38198A2978C8B9A9B90998FA28AA09BA38D8C868792
7A79948A7E95829C9AB0A48F7A6F5B211F0A0000000000000000000000001824263F2443
3536547A53658A8D8BBE797E63685C6B7B5C68494D635F655938646A827379899CA9A6B0
AC808DA8A087B29999A17CA395837FA3907997A89C8BA9AA9796A6AB9793997895879E8E
7CA791A4A59B897F82AD868B968B8FB19B8A76848C9C8F8A94A0A08EA1B78D818DB79D8B
9E899893887C93959D837C91859791A8819C949E85909592807C6E8D8E83857A82988D99
8EB09087A0977C84988187877270999E868A7D67688B8CA0A38B86806478718E7CA48F71
7A827C6F8A7F857681748E868B78826D7A95778D6A7D8C76747C756F6F686669737A8A67
758C89908586696983786368827C7B727073917F8F8181836A7D8B78647871887F79717D
58617C7762676D6B6D4F58526E555F635D6D7E78845E85768173795753576649695F7B7A
52737E5D62757264653C636E714D4C5E6C79817D65616F606859725E686B608172657C70
5B44514A4C4A51FF
FF7E8690766D7469637B9485788C766C795780907270967482868A8386616C7373767375
87718382647A7971604C584059555874646D78594E88778280727D798AA3A1B98F8D8C91
9B8D878694B39493B0AA8D9D9F99869E8E916A8D9F7DB0919B74958F998A94B6988997AB
918DA5888B928B9297A694A7948E828D98878A8E9EA56B8EB4ACAF979691957587807E86
7E839C93828C88AE87878F6256582D2D1300000000000000000000000000182C1B23393A
3F4D434D6D6C9B998087776356666052625252747B62574F624F555F685F668A8E8A9EA1
9699A2998E9785B48F97B2A293998E8CA483918BA6A0A0A9ACB49092A79BB18E888A9991
97A58F9EA978819B958D8C8B9A929C918D997E999A99A094989A9784958697789A99A0A3
C1859F8083A48F958797838982A38E928C7C7E7C9191869C71A192878E839BA891989E82
5F8A7F889276908494857D759183AEA0768E8492A29297868C818B8983667D7A737A7F72
5467788D89728F716F7F77875C83758A636E6D6F8B88857E826E656A7160678A7C75847A
6372798771757083717161878283908783978C78838E838F82776B79747272707D866E57
728474615C826C7268615B4E56657F5D7D566A7E7E7567816C745E6C4B5C584C525F646D
6F5A6F72605A6660805A60736066666E777B7468516A5D4D757178606D775B746453583D
4C354B354A354FFF
FF9A8561817790926F7D8390688086908981708169716088858C795E6C876D798E65748E
7B767D7D77767366546075434C446C73887D6D899388888F71768594A6AC9C928D8FA2AC
87A5A4948B95AA957F9998899B9A8C6B918197A5988FAB9E969FA78A7F968F869B9A8889
93767780919B8C8EA4A69D938596A2A5A09597AC9E9B9992A8A8AC9290B1916486756F80
9F94A5A69EAEAA8494807F6252533A2400000000000000000000000000000022242D344C
1E2E2245648B777E7A8D68784946575D655D5D65716E6F6779785F59766A5F73869DA695
979693929A8C95B5917FA492967D9CA481A18FA689959E929094878FBCA8828E93868B5D
9D8F8B9FA7887E7595A495828A97A79B8F9680929BA49996988D8FAD99A8AE9096AE9CA6
87989FABA79CA78C8F86868E9AA6A880909B78877C8FB27B889E8A83918F8C7F9193919D
8F8E7C919088829389919B9580919982878577918083899080957C9C857E798B798D8398
7D999A878792877D816F8F86808679826F76836883847A6F716081817394857672776386
87908C706D7A6D746F8F89908190888A876B73757E597A746E847A6876716D6F7273718E
856B858989736F68855E6878756F6476676C5B7D607067717564604F5A6B57434262545B
59607C5C5D7464646B7153595972694F5C60636F5F74767D70746C6E525B6E695E647461
5A5A3B4C473868FF
FF837C7D797F546B718A8B868E828E7F836E809A5F6A686C898B877A907789807872848E
8CA3888F898A7B6C7866717054604E767A88A18698AE98937A7E72728BA596807A91B092
77958B8F8E908D8B78897B918C767E9F857D75797D94828C948CA1A6977BA08883A08A8D
9295909AB08598908BA8937E9E959B82A19B8CA78589879F979D8CA7A0878A839A76879C
7BA0A9968B94A5937F79815339371D020000000000000000000000000000211D121B3F21
2E07262E3A6F747B7B72504B3346403B3766657673677F616874695C615A6F8F88AE97AD
B097A6989D8F838B988CA59698A28697A2ACA2959BADB094A592938188B4AC8984977B98
887892847F887E947596977E776B91AC8AA191918E809E8B949A8B9FA2979DA49B9F8A8B
9B9281949F958F978EA399A0A19F947D79848B89908E768E808F817A6379918B7C7EA08B
928E9DA895A4889F9AA19F678DAB847C7A818B747D778C828B96898F938F8A80977E8E91
8E6B8585A490847E7C9B8889766662726D716B71627673847C868A757A7B787390869678
6491898873728C75827392769C7871797D7C707D7A836C686075946505647B6F746A7E7D
6271686668796374595A5D73696156637B77656B75606F7373806746545E5F38396D5E52
6567665C5F514B63596972665B685E77676877656D60787E676B68807D5D5D7578625977
6D58363B4D3836FF
FF857A6D8B7A75666E7B7B7F7C8068737957697F6D705B7678747D717174649191898080
836B7A74827779817E717060896B817E959B95A1977F6C82899D8E878989A06872848D8A
70878D808A6E838C85837E847596737992947F60788590909D8B938B9191858C8B909296
99988E89858799948C7C8BA19BA1B19488989DA59E83968D97A3A6A29B8287727A949470
9BA095A67D877F6A73665566372B0100000000000000000000000011120009192E2A2629
292E063B4B617366556F533E5B473648385E7A5D688A9095877E7F807B646A6F8A8F869F
95A39AA7847A9199AFA48AA0A39FA996908B81B98F969A8B8E8CA2A2778E9D7C8E9D9596
7A9C8BA78B8A99A187A99B8470828482ADA4A1939F88989CA7A7AB9092929C9999938D9B
8C92909A778C8784827A888D8A8F85837C8A95927F7E7292938B948990869E7A81978A84
7A81917A908599847AA088998D9C9B88A4859D857C75877F7A6977A5786C8F877E816F75
7A768690798A797D68847D728C7A7776897369656E8586776371786A6750467A7A817575
796F8E7B6A8791807C8B87858A7069765F71738E78897C817283867C79697C836B787264
83886C676C6F6D6A696A55686F5E787469696C5F646E707E6E6C745B6569505C4E574A5D
56756A6C69585F616F6260747080716C717672626E6D7E67726D70745B6069654F4E5E61
634655414C4957FF
FF8479658378828970816F67896F7E846389797B7B6E81817D847981856D527070858888
8A8E8E86967A7D698E76686373766F637B7889768B9D88726B907D9E9787B49D848C6B7F
798B6F6F869179866B7E716B838A8E6F7C777984798C8B929789938EA4A89998889B8F8A
857D8D896C87899881A8A0937B958BA3AA948C9CABC08C9691A7AB9CAD927A99888A93A9
9FB68F988F90A594627C594228210000000000000000000B170000240D0E0039221C290F
000C30464044764F5968595D1A424A6B6758676D77888D82786B887775646377738E937A
96A175918EB2C19D999A979E9F999291959A8998AF9196A99B97878EB0B2A7AC86A48F9C
A28D9D827787828EA099898E89819E9197788BA3909D919B8F8A949C8F889CA69CA18C99
9E9C7F8AA4839597A0827E8F9580868692AB9C938DAC9B9D838886838B949E928C809581
8496799C8D957C8C8C8E917E929D989B8F78827294997E888A696D958874879C898D7588
877C787C836C7254757F785F5E6B718B7774615E8D9081857470647A667E6A7F837C7573
7E7A7A87707F7E5C8386727C8E7B7384787576836D91888B7A6C666B738D80707B7D677B
8A7B757E774D5B7862765F6B676E7062795F606C6D6A6075886F736A63736A5269705E70
596F6A576881765843584E57525D524C63626560606F5F7F70515E677C657366606C5D60
566E573F58505BFF
FF7C5E7D59786F677C7174606C716F786561868E76A16B83767C829B8A768C7E77737187
799D92827EA48399908F93615D668164878A7D867C7A8D928C989D9C9B8A899371878D99
7F867A8978787D607373658161747C8B6090908080838CA772AC8C81909FA18760848996
959C9FA38F8E7195909EA99A9299A5A4AC98AA94A091A48A8BA1959C888D9387848F8882
A98EB7859DA1A082746B564B3A1B0200000000000000001F28343D3B2024112113191708
000C060F3C4262678B6A564860565946616F67856F81999277907A62705D8071677C7B87
86A3BFACAC8BA2A194A49DA696969E9A948FA7B19BAA928BA6949A80C0A89DA69F9E8D88
88829BAA9C7F9B9195A28F8F6B6495A27A829599A589969E90978A8FA194648394939CA9
92929B9A969783848099978C839E867DB69CA18D886B9592848D9482817F85A5A58E7B76
8575789C9E887B888285A18C7F8A7E8E7E856E8E7B87837D93878870858984938F9B7989
90857E918182776A807A787D656F657284818159768E9B758E8775787188869691756B75
73806C7F88949579837E856A85897C68697B717466757C85704C8E787F856F7A816D6E71
7D785B657F646B5F7157677061515346106172706162667866697A8A6858535E516C7163
6F55655B74586C6A5F715E6065565C6A756377608060616F57666D78656070596C5D5A77
4F6155433E5A56FF
FF7775726A7A7468788E8A837C815D78888189837F708A828B797E778073778A836E686E
7374899C90968F99939871627A6F8B7C7F6A82846973737B809A908D8FA783797C6F857F
658D93949F8F7D9874706E687678778589928979968C937C878885808B9B8D6DA07B8795
8E9A9D98A19FB0947D93989CAAA6A8A0998295A3979092AD9F92A6ACA77A978E8C66AB9F
96BD859DA4A091796A534D43100000000000000000141F45514F493B2B15171011150000
0000001138595F78696E566B4C4E606C7A655067747C8077978A767E7C785E56818B8E92
9C9D99968B9692906C95A2A497A077A3AE99A1B49DA5A4A099B280A191897CADC39C8A96
B59B969F9D98A99590AE97838B8B9690AFAC919891858A8586999FB48C899796978C7F83
91A1A793A48DA284988E8E81918D89978B898B9B98B3959F878C7779A67F8377A07E87A7
948092A0908B7EA1807E7781997C828B9C8B84818B8D8A79867D83667D8D868381938975
8D87897C7F817C5E7B827B6D587C756E6C68707B6B80816F9488748494848C767E8D8088
98777F655E8182807D8E848168717C8681686583777C6F84677B868182797F7186739878
6E76507562686B757F5C4C62766857655C7B65647080826D786B5B5F6C53715F6E6A6C76
5E516E724D71715F6A6F6C65716F605A4E726E6C51596C795A6859646A6A6F7764605372
47574D59415F48FF
FF7B6D6F6B7A74708081695F7E825F66647B7A748D797E8D73767D7A897E7E8579798090
7F7E8C967E7EAB8C9B9A769D7C92779375718677838C708A8D909A8F84729A90797E846B
71837D8974826E8D7B767F59747C665E7D745E8F877B8874878391877C9B8B9D9A787D83
947F75A693849E999EA5A393969C989DAAA58C94A382B291A5A497A496917F82979E9A9E
95A1B19D9C92A1976D6C41451615000000000000002144504A5B5140211F1E0003000000
00000B255955648E7D7071646075727D7A6D8B87608BAA859A9C7A8C7A77646075718F82
95899596719FA9829391A7A3947D9D9FA09290A08C928B9699AF9490A3819FBFB0919DA5
8F9BAB9A9D988A928B859EA190B99A8F74999889AF888E98978F8B8DAC74A399AE976B8D
95997D888DA3937F968891789C7B8A788D969B9C9993A8B4817883947F798B8897908892
9792829491779A92887D837E887AA88AA690727580978E99988C757D849B93918370877E
808B709C8C818D427B847787845A8385734F6D7765668583868D878B6D7474887F807376
727F80727285797383757D857B85766A8583737359786A797D817E5E7A7E6459827E7879
7C755D54717F776F797380627264746A747275736E7C6D60626570606360706E5A5A6460
59626D5653565F5C56666E6877706E796F6D496E5F5674747261866E65664A6C75655B4F
5A404E3F49403DFF
FF727A6E59736072816776796F615B68637B6B7B647E677C8366777C877B86777C85848E
8D789399A47A758A979FA18183898982707A8B869C87748F948D8F817880929487A16C7E
938E98A088B27C64778277827384858397936B8C8D7C7A72636D78977C918D937D7B8E97
A6AB75A0A3A0AD968F9BAB9AA3A09AB59EA6AB978DB98899A288818995A5938F7A6E988A
8FABA3AD7D8CBF897C505238171C01000003000A092A29334856525A3800000000000000
0000002F3B6B8686847F815978805B6469716E7E737A5E8E907964686C70705B697B6097
949EA5947F898E9A8492979999A5968A97979B86869CAB99A9B6AA8EB19E9790959A919F
90A0A09A897C8E7E8C8372A39B799A8BA09E90A194958B998D9B9298979690919099858E
9F968CA08D8F99BB9FA18B8C8DA68EAEA1AE9396B2998E988E7F8888A0987C997C94938A
767F819D9D9F8FA089958D96779C778D75567B7F7D8E977D838A837E938B8390938F786C
72887576697370787370928D698269746A7063616B66627F707E80697D7F847D72687F76
89779083796A727B7488775F95877A8E7A585C78443D757B6A60635F7182666D6F7A7D67
71694C658668617B5C6551745A756F646E5661636E716B6B6A5C627C5952556C5F708D74
4F687663536B666E42736269735F7C6E576F676F605A6676736B6171657253686F614D5B
6366544F6E5453FF
FF796B7C7E6A7761707B8673807F6B7473747B86828B7A567C7686818D85908064737D71
7C6C907785998D917668758A8B8A8DA8978C8E746DB8AF93888A7986868E8093788A7386
869195958C98947D7F776C7F8B9D7B8F97848A74978A60807169858B758B999D9793AA8A
A9989D8BA59D9EABB09C9AA5AD9493ABA3A38396BB99A8B9B5BEC1A0A1A8868F898B7B88
8993A3B995A2968167443B3C0D120007040D0F130D3934446958412A0307000000000000
0000071F47467C8E7D636F7574737B737E6678857A64617F8A767A69586A676500009D90
859D9EA48F8E959B8592A7AA9B70928EA1A68B7D948FA09A9F9A929FA2A4A882AFC39E9C
8F9E9397889C8780AA7998A4A296999196A8978999928799ACA99A92968981978B938297
979B8E85A4A8868C8C8A9C8792A4C4A88E8E98917F8CA3879875689E938E8D979E8E858F
7F8C9E8B84947E8D7A938D87928D7F8D9D9B8A8F727D999D96915E6E8A7B8F8D66916E87
7C8C837E6995886A7A9A7D77717176696F8155526283718C7C676A6F6A847D967D7E868C
807D8A8A646C61838F8C7A8773777D5F86837390717587816E7682836F6D797F63796476
66576B77758B7C826A4B846383615B5E4C696958646765854F61515467685C7379627578
6E686A6059606962517275726067587380827F555869565263758566666676646B4F5D5F
586359515B5657FF
FF797686677566496A65617A777576647377657B67738389857484755A6E758692867775
8571888483898A9B94909188918C8886728D947C9498A19992968C9AA8B28989978EA08D
8587A3A37E75856971655E64576194778F8F988E71867E7E7E85807F9CA48E9FA097918A
8F9E97AE8F91A890A08494978AA0A8979C9BA699B1B98A9CABAD90ACA79895A08C829C7E
8B9B8D8E96989F8D774B4B31010C000A00182408213D3747573828250C00000000000000
0000164843838283887A668E75718B787B7078768B5F7F657D8B87836769828400007B93
93A8929195998E809B877D81967EA04B7991A29B8AA6AB9A959DA3A7A9AEA6A79F91989D
9FA4B084949787938287A1909A7F94A39E8F9A80909D9B9C8B8F928A97A092B47B858896
A48B9482879585A29192A79E98827D9892817F8A958F798F849284878B8B9A8772A2908D
928A848E9E9993A69A788A8F92736C7F8D917C6A88929898716C7881747B7F927F788188
A1809B7A7175786F84847A9171708D576E829482756E857D84857D767D7A816D75768777
7E8A817B808B95767F5E787F718C6D7D71767A77708576545A8D806E72866A747E6B7084
6F5A6472816B537683805277647E5A6A695571715F58865E655E7F7D73605D60637C626D
73697A654B735A6773676A7B6056655E6E6576676A66657779805E6E67575E7B74605E48
507F6C54665F45FF
FF74747A7C637E717C866D5F8279615E7E6B7F8391786A7378806C7A88767C76787D7795
7973929782768A6E95918290867AA2988C89968E8AA0A99EA38C93889E9A937A9077708F
7293968E947A6C6C84726F6B678E9399919682818C845F907F897C7089AC95958898B1C5
BA9EA4898F92989C958C94B69A969CA7AA9C9A88A7A2A494A0968C9B9FA49B8593A0688E
7E998DA0977D705F746A4A372719000800141B29242B32382B2F24000000000000000000
00092E416A6D94A78D906D707D676F79806F6B6F8190746B72696C626368877784A59B98
849396A57A7F6A8092A1869D979E8B89AAA4A99B96A2929F8785A0909EB4B3759CB39E89
9A9EA18D9B8DA5A294A28E969388AA8B9B968369919D8393A9948C9B9890A29C958A8B89
8699A2A186969373869EA89C8CA49A7E76A3788395948C939D9684ABB8A47197988E778D
7997929D998F8F93997B948E76907E7D7572847D8A8E806F88817C7894817A788F81858C
7C87826D767F8D815F8A8062568478647F786F80907B836786768984938A548B825F8B59
A58B8A9C7C6577617C71806F89826F7C82797A7C83716B618481806F867E826B65836965
735C74806C716555796B6866676879635464726B786E69746A74544F786A7B7C5B56656B
60726657566F5D52607C7B4E66486D65786465696B54646A786E846E5669785D6849564D
696A604F647060FF
FF7C887F66726D765A7F8E7C84654D8B816D6F746B887B647C637A748981606471808067
758C6F85798463737C938A907D88958E82757F8EA1878B8DA099A69F9D93A0998B8A7A68
96A19C9B92836C878986765E6E7E7B7F858A8B8691918186706C74917369A2A58F7B9A8E
9C99B6959A8A9A919E9AA594948571A6AD8DA099A8998AB8ABADA7AFAD9DA18E9B9D8C86
6C80998F6E898C69886E4823121020001616172F0404131E000003000000000000000000
00002A3C768C827AA2697A7D806C6F74616A65577C647C6B645777486A737375808F707C
AA8C9C9B897F9AAD99A98A9C8DA098927B7E969DA2AB9995958DA3AD92899187B39BA3A0
A39FAB727A6E77879D9E9F80807F969386928C9EA5AAB59A839488A29F87928E93908999
A5B0837C75B5849C7D8AA692928C8F9E9F96808A8E94A0999092898E9F89A184A69B94A2
918D7C95829893957D92918E8E8A877B6D7B787B7E6F8992928B676D89817F959A7D8C60
7A92907B84717078766B74686570727E6D8788797D73818496927C8872767D8991777890
71837B66759677617E9283757F686E7D716B9087646F68776175706F6D8B4C87826A7E81
776F60845A6B7B7770596E74707A7F7B6154676261646E7174516C6E6A695D6A60727187
7F706B6A6C5C8979636F886A76696F6A5D505F4D586959475F555D6D73784C6360495A56
72665F5C5D4564FF
FF89817F7B627E7279657270697065765C7C796B70637B8C8981639A8E80867184968C82
73777080886E748B8EA09F8C7C85929284969E7F71927D81919295A4AE9B9E8D84837292
9D9B988A8F8B8871747B6A77777D7D8F8A8986AC93C2786D828B7C75789A9AA292A0AAA4
99987881989A8C8AA798A1B78A9A9F9795AEA896A9A09AB7858A96AF9C839A7D807687A6
968A8187999D9A9887685A3D181000060A0008001D000A130B0000000000000000000000
071F3248657E97A997826E705C543A576E6E6D5F676B5A6D526A4C616265637774698C9E
85AC79A89A93937E90968489AFA58E9E9787A6C5999E99A5A1B4B1908AA099A7B5AE978F
9B98928E99877FA59D849E9A7A9F8A8E9991939798B49A82A899989BA2B1B1909A9CA999
928B86888D869B89968E987A898597989E94A47E74A68A9C9681A3A692868C86A3A19A9D
94929C859292918675A08A78899395877C90875F95908C848E987E707E6B7A926E796D8A
86778A6A728873817F7D69848C8D897D9079826C747E778F8B76757795868D598E7A7E86
8491878D868991A06C7C89837E827C876C8291747A7662787C626A6D767074676F788B76
8E86607F817E8465878C6A7F7C60675D6D6C616958557C655D668D73816F8485667A6F75
7D6D496C64717E5F57644D7E61757E717B54755D5B8065878386865E5767685A565A5761
716C555E567878FF
FF7F6F776C76767B8E79787568667E596C7671827F7184666C6B947E836C8792819B6884
8D8A84A37A7D8C7F907F96819788857C7C818778848883808C9B77A38E7482738B869A74
828D9892837D7675534F5D7D6E938B888F87937E978498948D8F888D8D8B87A9A299B19E
B2A19696A79C927E88B2A6A0A897A4A2A0A380A68AB19CA5858E94A39A9194ABA0A8A394
8687807C7A6B8688836C5D631709090A0000000400000005000000000000000000000000
202858617D8C8B8A948D8471847A684C656A4B5D386C4B57546A686E5D6B6B917F789490
928C9A8E9C9596A994B9B88696B0968BA0A08B939B96A6A5ABA1969989A7B49BADA98AA3
A19BA49D90959A9B8C8D8998948F9193998999857B729B9EB3B17E92969F809AA48A9F9E
8F827E80888A9BA087818D977E6E7C927E7B91A789848B98889B9B8EAD8988ACA189799A
958D9F90989797838F8B878A8A826788906E949A828B858E8D8F9CA18A8D84996F6A6684
86878A807376827E767D7290687E87798581718E8C76886A738385857F8B7695627D716E
877E6A67917A7E76829D85866769837A6C7E8B71877381936E77785B5566576C76645977
6D7869625A709173617C71595C71695C757374617066607D66687A738C78708F82606F7F
6B6B716B7A7178755F6A837B54617287705A5A676A636F655252606662745B593D60585A
5B40375D725C65FF
FF7762826F74726C6A7971686A6C6A887273746684708A7F7C857B5A7F95755A876C716B
77897570977C9F9B9496829BA092949480848E87556A9A7A8B8A9490B09C9F7B8B968D92
90988B89978191745E6162586C6E7B85959AB28E6E8A94986D8E948E8394929AA69892A3
979DB1A2968DBB999F98B2AD96B0ACAF85929EB1B199A29AA691A8AC9DA89DACB99C999B
B0A39599988D8E969595554E32251300020000000000000000000000000000000000091A
494A4B767C928A8E887D7B8A75646B5B6B5964494D4A544C4D51535347517E7D9D8AA3A2
A98C85928C8C9B8EA085A0A1A2B1A0A6988B9A6EA587A68E7599A7AD9E9186988AA4B98C
93A3A38397997F95B0A69F9AAF8AAB8D9582A98B8E81A590A3B09D949B929CA5989693A0
8D95A0927572899299869088858E798A7C8A92649A878883A29A8D8F93B58F8D9B90788A
908E8197827A8A80957E96828B99868B86967598898779847F977E7D978E839B8F6F8973
6B77706F7F80756572738581718477907C917C79828C83738387859C808585818C847463
968D7A896F5F7662758387937698A1856E7379656B7D71606B73826F737E655F7A6A7054
64606779246A6365737C7682765D767978736A78817A4F6D6B858B666D626B686A866967
747E6B8172886372646C6759786E76545F635B5C69835E615D7E6A5B3E6E617252555E4C
4A453C3C57614EFF
FF94856F70525F747D6E78596F82687F78836E786F607B86987D838F737B8D7E82898385
827187886B9F798C8A827A7996867C917E8F8B7D748BA19D7698859A809B9790AC818E93
7F7D67747E7B7E72525F7B7D8CA8878581968C8B8D988F8C78837E8596957E958B9B9F91
B09690979C8F9A9CB1A5A47EADB4A7A797AAA195A4A5909EA2AB9994B19B99A99DC293AA
8E959DABAE8F97AEA084726B39272D100700000000000000000000000000000008133560
5D67648273817561897C80877D6A85665D3D3A4E47395D5F524D7362606674989FA28D96
949CA3A89C9B9C9CB69682A98AA36A9EA594ACB59EA3989A887FA3B1ABA187A2A99381A2
AAA69C9C8FA2958586949E9091A08BA4979799A2A8A58DA194786D8BA4A5689F9C97928D
97808F928B9C9492AB8C909989809F7E67768A828B98948F8691879B95808F9A808CB292
9FA7A58A967F90997E908D8B867D8B87998B7472737C8685857A78908076938190667B90
757C69708679746B6F505E775F8C7C57757076888F99857F919A857D7077777675948D87
8C8D886F6B82717A5C7A858495667D6A5D7C7E6D6F5A7877786E809B8D7B888C6B7B7069
577D717C6E7073638272855F5E7D6F7A667666817C7F7F6367947F6D6C847E756C7E7676
694A4F8082647D738766796C736C777A777E7A756E6D7551506E6769485D5C646178705C
59624C62616876FF
FF7775877D7D6F836C6A5C4B6F686572716D6C7382826F787192777196927C83907E577B
6975867D88727A9E8E73898A8182868B897A798988988EA2A390857D9D92A4999C948C6D
6D9A74798888787B6A726D8284739897A48EAE9C94779691837F8E818F8E9B9692998B9D
A2A195949A96918D78B0AC98899B8A7E918A90869993A18A8EA0879F95AB8FA6AFA89A96
AE8E8C848A978A9E9D9F8A6A5D493A2C1C0000000000000000000000000000021F3B4360
7D8470857F8F807173797080747B6C5A44494551384547354D5E5A646C85848092ACC387
94A285B2928298A0989A9A929B9AA895969A95989287A792A5BAB18B948BA18CA89B9590
A49B8C969D8C90AC90A6A4A18D9DA07973948B999199978B9C9AA08CAC9CA7A19FB48A97
958782876B949ABCA4A59D92858A99A59C9873967B85B08891A1968F94968D9CA1868C93
8DA78E999D7DA8837D7CA695878F6C757684888E76848C7B7784737C827063847A68826A
9D6E8779787F7D8F966178627E777A888A87617699838793839C7F6E7C89708271837291
728489907980897F7D837887597D828675786F7C766D7F78898471859A8F94646F756C6D
76706377737F8E6A73826C74768358798A7C847E7D8C80857D68796F5383867F7A6D7872
63797467645060505D64816D5357536C665D7F756565705D5F6F5E5D3E52634363574C50
4B6572676F615FFF
FF92786A75787B5B6F62657B676270687A8475707A8279937E6666607C887C7171798D69
7D787B818E90A080709A948AA07E736E6B75766F887E88828A95858191747E9780928C8D
7A8E9A726B606D72677376819088AB8EA0A593898BAC7E8A8B959171A8A0A78C8BA6988A
7F9982BEA0A2839CB09CA978A49171929B9A98C392A3A38B9C979192A6A8A67790A7A59B
909391A4A090B3979BA289944D5456411E0E0000000000000000000000000A1C3D507B7D
859B8092817D8C90A17A7D86625B605A6456485539404A5D617267698079998583A69FA5
BCA87C8A9F9C95968D9D99908090B2878980A6A7A6A4959691A677878C9C96ACA79BA69D
B29F929990A3988F976B9094AAA28D9296868B979681867C867E9BAA92969A8E9584A09A
999E8C92A1938D8EA69EA5907192737CAF9CA498AE878AA4AD91968D9498A78E73998A9A
9996A8A17B937C8D977F8C938F9085836F79888672728C9072628A888B7F706178806189
74837076806861557F7D68856572807781756B678771798981758A7081868172876E7D88
838B788179797E5E757A83706A748E7F8378809B7EA278636C787A6669A2738976717B7D
716D77888C7370757C656278856D8078877A6B7C8380685C706C7A687C775B726F8C6163
707F715A5D706878857148606B6D5F5E6B755B6A6D7770445F7765636259625C715A493F
495C495D553964FF
FF7F73837A7258757F6D7A655F785C6975816D6B7C576D716B7979816470735C7C8B8A74
868B8D8D8A8D8C779E7A9866648B7D89858B8F7C77968C92838D888075949C7F8795979E
7A82909072777B75746C6C757592949CA1918A7FA29790877F867F97AAB79BACAFB1B4AB
A89B9B9BA8A88697A1AEA0AC9B94A665768A9480A09FABA39B9E959DA4A2949F9DA58C9D
9092B8B9A6828C98BDA38D95A289574B4B321D10040E13000000000A0B1D2632557184A0
A2A88C8497787D7579887A837080746A664A70545D534F5667818B999E9D9781A79BAE9F
9D92A78F9E9D9F8DA3929994ADADB085AE8C95A2AFBB9695989D8E92A4A097A48D9B93A4
939D9AA0818E95958D855C739C937A90939E97909B819E706F68988297A39991A2A99A91
96818E989F9E838BA7919CA1AA95A0B2A7929B949F8798ABA7A78C8497A766A591947D7A
8A998D8B888F9A8C96AB7D96A296839B808870B48099867A5C736877807F916F6F917794
9277637C8A6A7C7970698D7C8A8B6C69716F79837B8D666495818C7D6B687D7A886F7D6D
7096848B8A7E908C8883799072826E6A6B737F796A827370618A73626C726574716F6569
776F777565666E7C846C906F846676747F865E6A5C6889837E636D6C6B62846E75816B75
7B8D7A776476718078657363687F715E3E475D656C5B6B7E5D5E83637267755F4D60555E
604D69615D6B6FFF
FF7D675C6A675F7355716975757A73887D825B746B717D5E815E896C72A19886788E7487
75789D8D7C80828F8C9399789C858198968D999B908798879F9C8096968EA298A1928EA0
A59994877B7A8A88717388838D8D94939E738383828C8D838AA49389A7A39988AAA38B8E
A0A0B492B7A2A4999C878E99AE9EB290A9A3AE969C9C9BA999AAB59C9F9F8A9DA09C9D8B
7C87A0B4A79690A8B1BAC0B1907D707159564D1912311D1624151D354B3E5D736F8AB09A
BEAAA07F896A78788C8A7261767482757E6F6E67577589968081868BAF9F78A7A79D7F96
80ACABAD8F9999968F90A9B1A8B2ACB59F9D89AFA49A908FA4AFAAAAAFA99B9BAEA9A49D
9D9E8F9897788795999F899BA597AFA09C879B9C968687919F98A19E83968C9AAD90989D
8E9298ADA17896AF8F907E9A958C9EA692A9979A97A7A0908E888EA2B0AE9595889498A8
8B8E8A869076AA777B697E8781748F807A899D82997F907F557A817589836E718A949F88
7D6F87847D737E86796C746F7872857D7D7E787A84777D778892787A666E717386736A76
8A778F878982756C6C79868A89627C677E7271666F667E7D6C5C7385735C757C74566656
7D6D656B6E837866606F7F7F7572567E797D656E6E71746564856D84787364776C8F787A
5B737E5E5562716E696D6D6D77865E5E538275806A537572597458665873645F57615269
55585065525655FF
FF7F636477827369836680746B6E626E6869786F6B64646F7982838D808C838796837A70
737D84876F927F858890707374868F88A18F7B99638A93A09C9D89A7988188928C8AA099
A498887D91907F978078798CA18D8979818883708799888289808F9DABBB8F95A2ABA6B1
B3BDBD918D9EADA19D999A90907E8FAAA1AEAF8A877F959E9991979A8EA7A095ABA7A09E
949F918FAC9CA3A19FA3B3B6AEA29E86806E695D4E32444A304D544C5F5D6D7B7DAAB5B7
A7AAA58C93917E71717E7373847D754E6F9275688A949379957789968893AE97927B9AA5
9F989695909C9D99948E8792A6B18D99A5997C999EA28A76AF93A985988C9BAE8EBC8A8C
8FA28E8B9788997A889A9A929C94805D8E968788958A9BC3E5A4858C998B9995A3BC9589
87859D948A99937A9EA48C8491A9A481A79A808D827F9EAB9AAC96AA8A947EA396988878
8F939597808A8AB2A19E9193887D8C959B8B838D6776909C80707F8D6D9C7C8E7D8F827B
7E67715B7773756770837D7C717F676C838993787F7B818D7683848A7A876E91706E6B7D
6C8E798692857387887D6D737D747B7970837C666C6783887A6879807164795D6C796E71
67805F6E7A627C6E76867E5C75706F7F6B6A7C6C6475727E8B607C8476586C7A8F8B8F8A
70777A6C4F717B6F66695F626474816A6D56725B7D6563726A4C6F7F6A815C475F5E5963
5268735C43576DFF
FF94777B717B826B7A756B5E696B5E7C76937B725E57568D70799C71627D827772706B88
81778E848E9A99A4879A8D828B90978A899DAAA4A37F9895A69D8F97A4939D847F8E8C9C
8D998F93A7A7A39DA49493889283858F897EA4A0759195849770A0A5B5A5BA9FA68E8A96
B4ACA9A1959396A98999919195A395989EB5B7BCA1A499ADA29687AC8D928193A39B8FB7
AEA99795B3ABABAE999EA5B7A19D98A2868670617B896D5F646068737E6B9478A8B0B69B
999B9993AC947C8A92778A7180708392869C9C9F82A39EAA948E7F919BACAD96AB968E88
8285899AAA9D9699AC95A0A89CA8A2B0ACA5ABAEAE94928B9CA3877CA3929E8E8CA79EAA
9D888A9D9B918B8D9392A5A28B9F882C839C9492948AB3E5AE9E967C9E8C8C959F789C97
A387A08992A78C967B97AAA3A69B869A78829E8D9AA39C8EA38E988E868B997D918A8C95
8E83AE8AA09F99899B9C9082998B9388747986766B82857A7B828A5C718C8F80708A6D0F
1B607974748A826A7659557E92756C7684705F7F8F828687839E956E67A18A8C8675797B
7F72648B8E8F64737C80708A71895A786D7C866B757669736A81868161836457646A705F
7264767E636160785B5D54857E7B6B636D817065647C696B6D6661587E82726D8381645A
707681717054555F6D6F6F80705D58725E686E7868645D5C8156646A6E707B7E624C7157
4049485B455761FF
FF7B7C6169756F677A876B58807673787A706F747B82806C8B74818891867E828A9C9177
8D86939165848B958A9170686D799D868498977679999B968CA9A4958C909E989D9CA6A5
8E8198B8A9848AB3A6877F7F8F6A9A80918F928787787A8E9AA3BD96969EA1B989B0A195
AAC08DA5B5A79E8A93999596908DB194A7AC9F9CBA9FA4A5AF9DAC94B69E93BF8DB095A0
A9A69CAC959B8CA69890959392A7B2B19EA39B968C6874717F8CB683969A9DA2A7A6878B
9BA79B8D9694858F9777859E856A788A9880928F9A9292A79CA699909B95A08875A3B396
998D92A4AC968DAC9994859FB19D8EB6B4ABB4959CB4A79AB59BAE9C939DA4728AA0938E
89AB928EA18F6F949F969A9E9F9585938E917AAA8DA2AEB58C96A5917F8A728BB1A5A08E
898FA08E7D969C97929C95A58572939A8DA0929A80A19286768D8772939D9B939F989991
9D95A19C9988A28981998D8C8D90737C77886A898F8A757F7C5785678093938A817C7700
007183655D8063775D757C747C608498A977895E6B73715E82817A718B8B7C737B947176
748A8287809D868E8980697490816D81797D7A847B616C7387654C6F5C3A505B6771667B
5C6E89886D6768657D6064857662827B6A6C6565545C737F687679708A826E6C74638475
677B7869616F5F6E745F607072637C5D4F7D7880798468696175767564576260654D5E55
655C7747664B64FF
FF7C7777725D7D65637470706A7B7866628C6672788A7E736E57706C6F87738391846783
898777979F9168678E7586708B938873A68A97B091A49E8C8A9D939D8388988B86919CA2
9791968284868C77918988907FA99F9E978B7F7B808598909B9EA395A39FA0A0A398AA9E
9EA8A09893919A8E9AA1AE93ABAA827BA5B899B39D93928A8994A6929CB1AF97957D93A8
9E9097909AAD9CAC90A492A5A0A89DA1A1AB7E859E9B757B86A3929F76A39683998A8791
8DB09C99AAA7938C949B99999F8784819992B59E8D96969BA1A19F9EA7B575A1B39C879A
84A3959A798BAA8A8C969B9C96A08B9D94B19EA1A0A7959A929599A4848DA89E8D8D8793
9B8E7792A09CA28F8F8B98949A9B9698887E96807E9A8A9597999F8F7A8A9A9A76667E8D
86A39F9BA1AB909D9D9B9C868188A99A926C849DA27994879A7D719F8091938592888793
949B7C858F928A918792845A867E758770808279966875808B7270727B8D817D6B755368
5B6A765B7C60637F956C6A8A7D6780796D6C5A6A66697E4F778E8C828A87857E8C87868C
808B77818989776C71737C8E7886866875788A7D64645D668B6C6276694562575E737D57
7F70988B71695568895A65657B5C5263647B65697E7468777357707A6F6275736273736E
5C716C7362717B6458496983596C6462496B546D6D61686D654C644B50426F746A5C6560
69694C5E5C735EFF
FF74747E617460646F676853766E6B6688726E696973767E717C8A7C6A8D7B7C63928B86
8F94808381848E8078856F5C6D8D8D99927B93908388A18D919284809C7A917D85A29F96
8899A7949695A19181A09DA9B4A09C9B908C998085977DAEB0B8BAA19898829B988DA8A4
A19D8FAAABABA690A69493A2898592779DA5A28DA2A69E97917CA0B68892A4957BA09395
AC8C74969B9FA49FAB978C94A19699ACB7B1C19D9991A19BA29899A1A3919698A8B7AA9F
948E9B8E9CB4AA7BA88A91AB9B998D9B9C8AA1A3A881969FA09EA08F94A398AAAD92A08E
8B837DA0A59BA7B5B3959A9E8FA5B29298ABAEA28EA9A0A5A397979BA79B819A9F93ADA0
8BAA989992A79B8C8EA1946F9A8FA072847193B79784989B8C9E969C9488A5948E8E8785
7F8B82879E8C838EB2A9828C969DAE9AAC9B987F88ABA5A4908F939196A29D98A6828A90
A8AFA792ACA69A7F8083A29987788781838D8B8E78757C7F7C8171818985937984688567
7775686B6762776A87727560636E757C8B8C88587A827E81867E8275887555837881647C
718B9A8779789E7B817C6E85837D807970776D687B4A456E6C63786E55607B6D54805364
437C7F6EA0506F7B5F7D54715B5D658277735F775A666173755B898879796777657A6883
72765A816C726E6E867D78747A73725A4952665F3F656574695641575C5166604E575556
5E4D6553574E6CFF
FF8F908285716A957E7560848477775F8A70847B7D988056838187769074868C95937F95
9592958898847C7A807B6488727E94867D948E9B8D888094ABA8927E8A869091989080A3
A3AD8A95959D8D8B899E99AEA3AAA4999A9D9589A096AFA5ADAA9E79ACB791AC998CA997
A1A3A49AA9AAA7C59BA992AEA4B6A3A09B9E8C9FB3A1A48BA6A597A8A79B9AA8B195A9AB
938D909A9DB59E9DA5B292A4818DA39295A6A9A395A29D8C90A79F7E9BC5A1A0A6A79F94
9389A5A5ABAEBC9DA3A6A69DA8A2AC97B4A4AFC394A29A86A3A3AA95A18E96B7B698A3A4
AB969B9BA1A0A4988EAEA7B197ACA6A2A5838EA2AA9999989B939BA8A781927E8B9D9290
ABAD94A39FAEA585A0918A8FA08B718EA094928396989E909B977C777F939D8AA380877E
8887A791989D9D859A949F93949E97B39EAA91909C7D9C859F7FA37B919AB38E8E86899C
9590AD9B9999958573A6847D99978782938D9093806B98797D71877D8188718C8479756B
677B706F815A787D887B84798A91898F87986886787676947579959E867E9571799A8A81
86838E9A8694868B778A7E987E788C7182706C7E79687E7C6C6D6B656B737A6770667563
6D557298C9726B877871705C596D765A816C735E6D5C6D767875777689757A82786B7069
7C7E8B6B765661685967635475735A857B6A536F626A5A6672576B734D48557059677855
43496062765769FF
FF6E63847584867985808D658B807595797172856B7E8F6C787E797A89947B8E8E8B8B81
808892927B7F838C886D797082806B877E97998892A9908D8B9B78839B8DA86E857D6889
849C8D89AE9D8E8A8C95A892B6A8B2B2A097B3979FA5A2A389A997A798AABF96A3B08AA3
B8AAA29DB0B28EA3989DADA8989EB5B2A6A9B287A2A5A39AA3AFA0A0AD9BA6A8A0968DAE
A9AAB9C6AFA3B58D7C949BA58DADABAEAD9CA39BB8A38392AB9F98B9BAA6A5A3B89AA783
A1A9A6B1ADADBEC6BDA5AA9DABA7A4B29096A19CA3A390BBB8C49790ABA2A78B868CABB1
A2A3A284948C9B7FA2ABB8B0A1ACB49BB2A48FA9A1ACA7AAA1A6B1A1B19A8EACBDA1979E
9069819EAA8AA79896A0919D817F8481807F839E9E988D9489998AA79589939A88B49F85
A0918E8FAA9F9AAC888FA08D9F929AA5AE9192848E8B92739D9A7A8EB0A3A2A9989889A9
9891989DAA9E8D7D8B91807E988C7E788698AA988C8779987A8E80739D7C958A848A7B69
7580787C734F768A7081667969957264727584848B956F8D988C6778827C859988868C7F
9371746F8A818E8B78767D856F70808F687B7D6D5E7769798680755D617E675F6677607D
6478666B63766E776D716F6F717464557D7E6A87635B6F755A7A584B756A677678876179
64667169695D7568767167626F646976497267685D5C546150575D6C7159535B7259623B
66566564696B87FF
FF8D71657182767077777C81777374777E7C74507C6277737B82898F677782677B7C8697
7F898272928A8BA4807C8C987B8969847E7A8690B08A966C96967F898A6B78907A8D9CA0
9E958EA69E989996A879A3B29CB6A7A9A195A4B6A8A2AC9E9AA3A28DC3B898A1A199B1A0
AA918CBB849DAC909D9BB0A193A490A09CBA9CA0B99CAF9EA58797A9ADAD98989DA0B279
9DB2A5ACA5A9918C8A88A39EAB918CA1A97D9BAE9F85A7A69B899FA1B093AC939B82749C
8AAD8D9DA19F9592AC9AA0B6A3A68BAFA89BA1AFAFA2AA9DB89DAB9AB39AACA29E999FB1
B7B9B8A8B5A198AB999EA6AA8DB3AEA2ABABA09296A2ABB5B2A4A089A4A2879DAE9C8EA4
9D929795A2A4C198A592978B938487878B9394A4738AAAA29D8B91A79BA98E8A938A9F89
8B9683B392888E92A9A29D8F9D8A9694B386918C9A7B8A8E8DA98F83869A928E938B8888
AB9A8A9870A69598858C9986808E9D9F8B85779595888582868185968B6D7985798C6E7A
7A877D7B7575856076777381877E7974867A848D7D79818E94618A7286828E6E76957E7A
8F92848782968B8A8485768770808C75825C687C8C87807D54837A606E6D7C876E7C4959
7A767B75527B5F787C7672756763677B7C85836071627C7072727277717F767B79797465
667D6163605D456A5C6963586D7C5E627D6664535B606E4C61736964766F565B544E564E
4B6A79585D6B68FF
FF877789726977706E6A7E88716F8359667381756B4F678A8681858A7E905D7987796895
9783928D8C7E8B9E81727B8E767B959785686F8996877E7C9586727D8583808871847771
79928B887F9F9F9898ABAFB0A48892AAA8AEAAC099A0C9B7BAA19C94A1AFB2ACB0B787BB
9DABB4B4ABB2B1A1A7BAA79EA0949F9AB197B8A9A7B79B97AFA896A79297948A9DAB988A
8C958DA085A69D928EA296A9A7A4869DA4AA8E89A47173A4969492979E99ACB29DA2B38C
A2A2B1BFA796B3A3A1A392A6A38AA19D96AAA89AAD9EA496AA9EABA4A1A197999C98ADB9
958B9793A99CA2978BA984A2AAAA9D93C09CA485989092A29FB5B0A08E9F96A3A090959A
9D929289859EA2B1A18A98A6838A988B98AA9B848B7F7F938A8197B09A8F708C98988487
A4939E7770999A8EAA9476827B9BA08D9896AB807D9B817C8A82AF778EA3778EA198A27C
8BA0AAA07D959394A09D7C809796887C77778E778993878079A183758864778FA18B7A7F
66797A8D6E6E7468787C727F81706B6F6B65516A8984778093796E64705F7A838E628280
848F797A8F9067788182908F76917690917D7573716A777A817C6B7F7D667B777D75836B
6A6A6B7E8074926B6C5D5B5B657B7561776E6981737577606C7A7981787980707C747175
726D685470817055565352847E685C706E6760685760555A7C5B6565575B625A433C6A55
596A6668445C51FF
FF897E5E6A77746F707E7F79787C708A697E787E7757696A6D888279826F7F8362839289
8892918B918E9B8A918A848D89838E78868A8E939A7A868081876761824E8D6F7C7E6D7D
78739D969499A290AB9F98BCB7C8A38793ABAC9EC5C0A79AA599A1ADB2B59F89919DAFA8
B6B197B2BAADA1B699AF969FA0A6B1B8ADB8B69696B3BBA286A08D7E86B299A196A3ABB5
ADB8A69694A7C0999CB29CA39DAFABA09B9B9B83A09E9B9A8F98A9B0ABBD909FB6989B92
849CA2A3B39DB79E999DAB8FAEA29D9DAA9B95779B999AABB19F8F9BA1AA9CAC9D79A9B1
A0A99D9FA98B998E9FA09BA2AAB290A6A9B3ADA198A4A7A58EA2B29ABB9B8FA3A8A18B94
9FA46E8A97A08CAAB291935D767E8E8F99A48A9792B28E8C8E83939AABA1848D8D8B818F
91A59C76A67C9179869D8E9F9574978F9E9585838B99869090968DB09B9290A17EA3929F
82989B8CA28B8CA29B86AD9693998E819384927F78817E9083797971867F777D73909B91
756F6C818371777C797A6467748D72697673748C737C998274698E816E7F7B7C858C6C85
8688747E8973886A7A728B8C887B88708078776669827C73786D7C8C7067546E72757272
8177876D6A7E756275796B635B5F6E89807A6E67507270717B6F756369706C6C6A7B6062
7F7459878A63676F82796B5D6F558C7972596761605B62645D734E64625C465A576D676A
626D68636B6F6FFF
FF8C807787A17D7E86695D7C947E877B79807485716C6F818E8888827E7A8D90837F8685
8A767E818794788E7C96747790865B764B79867D759095997C7C9A78615A60717C777C62
74717D918E989D929296A1A3B79EB0BFA5A9B296A3BCC1D7AEC7A3A2B79EAB9AA9AFB1BD
A0B59CAAAEA0C1BAA6889EAFA98FA3B6B5B2AB93B4B8B6919FA78CB99499A0B0A4929CA1
BA9AABAE9E81A385A199A399C0A375A1B0B1B1B29EB68896A89EA1A0B095B9A88E8BA5A4
988FB7A4A0A997A1A2B08AA6ABABA3C69EBFBD9F7CABA8A69F99929994A8AA9F9FB2A799
BCA1A2A68FC095A8B2BC91B3A9ADB198A1ADB8A2A3AB9C91A5BCA7A2869584AA7B87AC96
9CABAB90AE8E8F7F9D95A2929A90899199909B9898A2ACA5946F8D9F969A8BA69CA7A187
ABA8A8978B9AA1799C8B98A5A5B481858FADA383858F8A91A9979E97AC929F87898898A4
96A9999D85888E748D7E8A8F938C948E577D747976769F87877F998D7A8C7382736C8870
7B6B888C797868668B6E767D7C7B769483657A749C9A869386968E82956A947687838D79
8683828372709A8C778A878F8C906986927C815C7984838C835F765E6E654D766B6B877C
7E786C665A75817E686E8682755A866C6790846673727580746E7D78756F778B6E787C50
7F7E807E7B6C817C7A796E613270607C678E6353765D6C6A675B6156765C56626559605F
5E526E575F5142FF
FF86707C83726F616A827D7C77768086757966828F7A79857F885888927B9C77908F7F7C
7E9897788D9E9B8E9C918C927A788A7D7E8F737A648994886D7371616C50573B7C7E607D
666E6D74767EA2A0968B9090AABFB19A93A09DA7A6A894979CB0AAA08EA99AACB7ADA3AF
C1A0B3B09FADC1A8B69FABB28390B5AC9FA0A6B1B39EBE549E9298B5AA987C97BFB191B1
A596A99B9992A4928A88939AA6A49A9F98A195879DA59094ABB8AC949489B0A49AACA090
A1A1A19C9D9797AFA6AD8AB092AABAAD9995B5AFA79CAA9793A7A2A09792919B9DAA959A
9286A1A6AD998C939486ABA0BDAF94A7A2B9AD93B39691AE9E879C8AB69C9F83748A859A
A596A98E998CA69F9596A186ACA39489828F9994977D9B9C989A9797A1998B909C91A296
8F99A0A3B1BCA0AEAA9C99A2926E8F868A9EADB2988F8897938C978AA08C9EA49093A494
B08D97A3A7A4998A7F897D829594868678637E776F7B8A8B6B95897E808B788A918A8C75
846A8B7D8F7845616A83718681727B81967676767F71916F73808C9683867B9090796281
828F827F827D867A857B858E8B84656F7D76596D6D798D77775A5D7A70657374837B7D66
756D6287676F6960415F729081716E7583816A7B58688A817C786C6D86887D5C6B4B6D80
70667B55666073807862627A74685C6D5C6A7B6F8455696C6666715D5557454A5566655F
67666760554765FF
FF897F7C71858368906F6D886E7076937A7E6762705F718A8F91794F858C8F9383928598
998470858374958A937D7B9E998C75646E757E737973837E7383675E6B5474686E81676F
797E5285748793837AA2A0A49DACBAA4B3ADB3B8A09ABBAEC1A69E9BA4A3B4BAA4AFBAB1
ADB5ABA787A79A9B98ADB593C6B69781B5909BAA879BDC9A96A9AFAC8FA99EABA9AD9B98
9BA0AEA3A39A969E7C8789AB92A5B0A0A4A9A7BEA79FA39DA4A692A5AD9E9C979B82A0A9
919F93B09E91A6A59AA6B2A687ADA09BAC9EA4AFB3B2AA939AB599B9A6B6ADB099B5BD9E
B7A7A390C0BAB9ADBAAEBE97BABF94A0A0B193848DB89FAAACADA89E9EA5979899737DA0
B198B07F9BB18373A5838F867C9C879494A0849294AA9383768E7F888F9C93A3AA94838E
8C9AA5AD9A8C9B9B8E80AA7B92969D91A19887888F96A183899BA4AA85A7939EA28F7A8D
8183958F9DA29B949BA17B879A8581889C8A9E87868C82807A73936D8289A1787D8F8B8F
83838B977F849092917C8A856B7F82929E919B797973799682809F6F839A67976C5D7473
71888E96856F967E8884727A8088847C966D7D7D7C7B797D6E516A7C75575F6481837387
866D775D7576725A6E7960644D00818D758576837C796071827178628279798F6A6E6D5F
7A71638C6C8477726974615F5D5D7482676E7C63686C5458625D5F5D4B6A616E6561524C
596C55544D715DFF
FF8F7FA5838680A27E8972707395A16D7A8284798E78768D7D908D908D9B949594778482
8A7C9D83718B9E8E9F839F7A84976C81897E988C7860758579837866635B5D5A89667E75
6E787282698C6692977897B3AF94B4ABA0BB8BB9B6AF9AA6B39BA4B397CEACBCABAFA39D
B2C99798B2A8B8A2A4999CA5B59EA68EAB98A2B295A1AEADBC9DAFB9ACBB89A09DA6ACB7
BEA0A7ADA8A5A393AEA4949EABA1A0A9A9ACAB9C9FA08F92AC9D90A3C1B3B0A6A7A4A878
B99FB88B7DC1A893AD927F7491B197ACB8B48B8FABA29C9AAC9EB498A3A7A4C19B9B98A1
AAAAB5CEACB3B9ABB1BAA1B5B6B8B299B0A59A9FB8B3BDB5B293ABA686849BA187A78D92
86918D8D86958FA0879B8F6F7DA48BA2A8A1B3A59E9B8D988A8B8D909491A98C98869782
9795949F949089A57C6C91B0888EAF988AA1AA98A8AC948BA28C979A828594A0A8928699
9C9FA4927CA3A5A4A38DAA9186A3A1937F9479836D7C85717E94719B7677946E8D908C97
88797C93937F8F8389878586768882737A8A8B7E7D7E807E7D88897F7A8486708D63709B
838171867283869365538E837376656D6F7B6B7A8277796A6B67796B576D705C4B647C63
82897B6E76616676666C8E6B69EE79897377865F808D76836D7185839487897876648371
6E6471817C7B637F7A7573716D7C54587B64687374756D6E6A6E5A5B695B566E413B6852
5544594F45525CFF
FF9B7E81787E65627277938A757F838A88777D79786F7E8B826788949C8F9D9177887D7D
7D7F778D7C8078717B739787998E8174838A7D869495786E606F726869536C5B6C83826B
715853624E6E7F80939A8C91A4B6BDB2999EA899A6AEB9BBC7A6A1A698A2AFB0BEB2B19E
9F9C9CB2B8A0B1B1ACA4A19EA9A4B7B59E98948F9FB3AEA299938F98A994B2A1B9BBA695
93A49E8CB79AA99A94A3AFADC8B6A79AB4A7C4A5AFA49FB7A5949F9AA38EA09ABEB9AAC6
A4BBB5B38DC2A8B38A8DABAE98A3AAA0A7A8C9B8B89288A6B5B28D9EAA75AB8B918EBAAA
9EB19590B3A694A4A1B8ACB5B8B7ABB1B7A1B9BEAEA1B2B59086A191969AB28F978C889D
9A959F7B88959E8F8A8B95897A758B819EAA809280739A8D9F8F7B7393748E8E8F7C8D94
949AA19E879288818FA6A69098938E9788A78B89A1AB7DA1929AA9898A8AA6768AAB997D
ADA1849AA9958395838DA4928E85648B8A7D7A757C79958E9481745F8A86808E81728571
8B907F7F798A6E78809686917D827589888C747F8F88858B7D95846A6B6B7D727C6F7D8F
8E85706E787E977985848F71706A848A7A6F76626A7C778D75677D6367717860827D6B72
70847C7369777688877B616778A26C6B796355955C6C7893778B7F797B787675716D827D
7E777C70886C767B7C685D7A6B664E6B70725B5A646B7762665D4964596757515F666162
6C475467614A5CFF
FF7C986C667F867F85897E868D7D667983747C7A7882857E958B857281817D89A0847085
787E9987879E9D83817D8381A591777385837A8B9898736956684D3642637C647386957D
79657B6E695681737D9794ABA3B99FA3A4B4A1B79BA0B69EABB0A094C6A4B5A99CA4B2B2
BEA39CA8A6BCAAB9B6A69C97A1A5AC9EA7AB9FB19F949CA390B5A7AECAA883BBA2A2B5BE
C7AA9FFFAEA7A3ABBEA0A8B4A88A969995A090A09685B58F8986838999A5BCA88EB6B799
AE9EA49EB097B7888699BA9BBDB5A3B6A0AAADA1A4A09B9086AA8FAFB6A4BAA89EB7A5A0
9DAB9CA4BEB99088B2C0B8ABB3B3A392A1AA939C9AB69D9FACB09A99AC869C8188927F91
7AA880A58EADB67F6BA88A6D828F8B9B857A899C939B78A07B9E9C9277829380A08A958B
8F909592A67A9392A79196768B9B80A08F9C82727799B295748D707CA7948CA3969B8E8B
8C92ACAB9E928B90A57B8F8C90969A818DA5727C785B7E8783778A838391826D80766982
8980736C917D907A818F8B959B8F716D816685957671568C807B996A697887728D827A57
82988D81899D916E88796F7373878C80868691886F8589756C7C615D695C695D706F7675
71797D80646685786F616B83876D69747E837675677E7D7D6E608083847186936F676C74
837A6D80776F7D6B53636762655F6973797F555E4F5C655F536766645D676B6146524B61
405264720F0069FF
FF9D84847F8097957E887D7B8A84807D807B687A8B7C7F8264837672956E9987778E7D9B
7E847D7F9286947176797F6B77769494857893A0A08983846741635E5C59485B88797587
8879755C5C767F8E7A8B979F9EAE9EB1A4A1A6BDB4B5B7A7ACB2BCB9B4BC9FA7B4A9A0AE
A7A5ACAE9985AF92A5ADB29CA39FAEB0AAB6BA9FB6AAA9AAA9AD9CB5ACA8AC9EABA59CBC
A2968EB8AD91AD988EA39CA199898E9488A0AAB1A58B73AAA6949CAFA97574A9B99991A9
9EAEB7B6949BBFABB2A2ACAEACB7BAAA9CA3A39A7F88978DA6829692B1AEAAADB2AEAAB5
BF9F83B3ACAEB4AABC92A49B94AFA6888EB5A5AAAE92AABDA68D91A5979E9D95949F9E9E
9C9CA4A897B08E6F9B8D8B7D81948492958A99AF7F8379888E8EA08367909596828A898A
97B5AC91938095978C95859E9CA3A68C848294814B817D9A998F888087867D8A84A39F7F
93867BA39E7E9C847FA9A392988BA88F8F809D817C7F6B7A88797D74736A66726F747E7C
7A8A8C80827E86929C978A8D918D83916E80796484926C8B6F7D88848E7E828B838D8C85
908C867E938D92826B6771757B717C8870777972736F7182776C8D79686B68636D75827A
676F755C5778717468725B826B8D85726E7470676D5E5E61785A6C626E767869646C6661
737D8378667C87686F837B846764684C5177705D576C192953577669716B5B635E151362
8365754B304664FF
FF8993878E957F99829196936A847F85858A8994928D778597868A7A818E7387857E8A90
818F858D8082978A898C939B8F5F9C797A979D9C8BA3896E69263F5E5352676F6F77807B
808C657E76797B7F837296AFB6BAA7B7ABA5AAB4C3ABACAAC4ACA8A589A4AC83A9A9BCC6
A094A4A5B8A8BAAE9A8BABA2ABA9A8B8AAA7A1BB9BA0A5AD94B9949DB68D9AACB08CBC9F
878F9AA39CA390A17890A99D818FA89AABB49BA4A79B8995B49A9D9AB4B79EAA8DB8B5A4
93BCA68DA0A6B19FA6A4BCB2B1A7A0A488947B98968F707C757D87998F7D95B9ACB1BC9A
ADA4A28E9F93A9BEA0A9A8A3A09D9B9CA9CBB3B69EA7B7B1A39FB8A7A09B8AAAB08C9883
B3939A868384A39E8989ABA08A989F8A968A9394879A96ABAB807A959D7D8AA068A09E8E
A1A19EB49D91949C8A8472969387A0B58E85828C837891387E7C95947594978999AB93A8
8F8585A59A8A8E8F9993A99A7F927F938A8F947A8B7A8477848D7B57707D7A7C8876897E
857D87997A8F939C8A8B9189818767878D737F7C7176978284796D807E977F8C7D815E6A
6B82837D7E7D7968606070776C7C81888088898380817076766E88785A7267564F776E70
6476607968628B7B7966665F77787564728D8E85847D747D7A6F5C778A68777085727167
506C7C7070856A7158606A947967706343516974775534537C7769716C5059654B534E4D
4C5A77567D6662FF
FF82989891907F9D968D818378798A627996827B78668176887F868486A09E8D7A87A479
81879789808887A7899A759986968D948D7F9D86B57970603C48595574616E80757D9775
7E90967C72586A686F8389AABCB5ADB3B7ACC2ACAA9C98B7CFA4A89CB6B9B4B8BBADB39D
B1AAA9B59EA68B919AA2BE95A9C3A8C2C7A1C2AA9EA69EB3AE86CAC1A4ACA4A3959895CD
A595999DB597AAAA8697899E7C7DA095AD93A2BDB198A086A599A2A3A487999788AEA99D
A6A49FB4ABA2A1B6A2A4ACCD9DA4A48C8B80766A96897D757C8F79777F869DA992C9B2A2
B8AABBA1A39FA9A6AAA495B0B9AC95B09EB096B8A29FA898A7858EB99EA7A88C90A59090
91AD8D91B28AA2A0907D918E84918D89A29E85948E9B9E859C8F999C97968C8B928E899A
9C8A94928782867BB07EA59BA0B1A29C92A09EA08F75837590987C7D8D957EB3A38CAA9B
9499898C9592869F9995787F938B908A859086969280747D758A7283826E7D728F8A75A2
90778A73837C95848D877E8174929A8A858785AC779F84898E898D7D7C7A687392788B8E
996A7479846F7C73746965689A707F797F7979665684878465786B7D7169656B69756D6C
5D746D7A65667B5A6D547F62676C7B796C707876757E837B9E6C6781998E6F848278796D
655E807F664E717F7D7D7A5F656965413563716042614B5F566D716273725F454F4D4960
5774564D464A62FF
FF90848F7D7F8382849E6D7C796D808399957A997C7C8A81898295959687848B95A49093
9C878F899198868A898A81888687859599A3929F926F875B554B504B5B7A77717E718967
918D7D7843676E877882AAADB6BDC1A4A7AEA79BA5A6B2B4A3B59C88A9B6B3A9A1ACB4A8
B5A0ADA0A6A9B2B2B5989BBEB6A3B1B58BB9C1B8A1B6B5ABA8AFB3B6A8A6B19F80B29DA7
9CA598898AAD8AA29784AAA29BA192B3B49298999D99B2B6969BAEB595B3B0B0A996A4A7
AC98BCADB29A988A9FA0987EA68E8F8F688A83818B97797F7F7487978F828394A5A3BFB3
B899AF9ABBAB878FAA9CA4BA8AB59AA1B5AA9D9DA7AD98A89DBAA9AFC49298AC9195A09D
A8BB9B7874A57E8A83857391A8A78B6F857586987E9599A3A68E92A897A19987A796B197
A199878E9F94A19197A59C829C9C829785878C7EA18F7185768897A59F94899C9FB28196
9E9BA77E9FA1A4A38FA7928D8A9D7A909983797E7471808A6E677E8190737A5F5D7F896E
849360978C7282918A939A766D839A887A9D99858D647C717792857979786C7582817F9A
8B7B687A7D816684726B7273657D8284718A7D7E73728B70666B677768597C747D61675B
60857666584978687174626784877A827799918577835A819386827C7575698788848592
85806C70876278779172735A5E697E69435D5465578168414F7059565528665D50544A74
5B5B64584B6454FF
FF7E7B9C84959686697B6E87978D918A7B7F8292858B8A8B8484868689957E91A2768C7A
96998E8C899195918584848F90978D8C89957C9590907B68574D606062647D898693A092
9091968270725A66689084A1A9AFBDA79FAEBFB7B5BEB6B6A1A2ABA7ABAABDADB2A4AFA4
A9A298AEBCA2A1A0B3A0AEAAC3A1ADB1ABA18DB5B2B9ACB3A8AB8084ABBCB99B88B0A09B
B2B3A19FA09CA99D8E86979DA3ADAF9FAB918A8A89A6AC9B92B6BF9A90B4909096B1B5AF
AE8293929CA4A79ABB9E828F8555835F6A6A7D60696E596970837F6B7A7788A589BDABA4
ABAA9BADA8B8BDADC4ADA39E9D87AA9BAFAFB0BEA8B3A4ADA1A89F98A89D8B9986BB9F96
87A19FA4AA89947C8C828B79A98789918885876E8579A190859E83A5A99F898F8D9B8C98
7C89949A93B196A09A829873979B7C95989190818C878587778C958892AA809F8A8CADAA
A09698A8A1908DA2A4778A8D897A87768C8B8B8187838D85786F6D75747A5D7A748B838D
8985A6827F7783868A959C91808B777786A990998497798479808380686A7C7D8E796E77
717E8E8686919277797C7F777E757C6D7F6772606E838D73885C707D7079656A70566962
627778786E7A7D5667816F7A6F7C698F8C69907373716E63617280687A75698A8A886F7F
88706E736879797D8476607B8A6D7656494B25546B5D513D207A6A656C615560725F5968
535869685E5F77FF
FF9B727694877E8492867C839194877B8F96719187867C8469868B9E988289919C848B72
977584AE9DA0A07C7B746B9D829D9085929591929F7A715C35534351607D82A2A08F7E80
78798A7570755E666A649BA1B4ABA2B1B19EB6ACAE9DA6ABA0B3ACA4A59F8DB7A7A8B9AC
A0A494B196AB99B8AEBD94AA9EB1AFC7B3AAB5969B999AAFB0A89DB4CFB8ACA8A8A4A79A
AD9AB2999D8EA49D97A098A1A6978BA29C8EA9AA91A1A29CABA598998DA9A89D97A6A59C
90A19463A18FB4BBB295827C606670604F6B84726D848E717B777B7060876B87A2AEB2B0
B7ACB2C79BB0A79384A59BA7B5BF9CB7A5A998B7B0AF9AA9B08597A7A58E8F99A099A18D
A19F808291886A7A7E8A7EAC9472768E8178889A9C9B7F8694A991A29F9B9076958E9796
B1938C928B8D92989D98758384A69D8A9AAD988D7A85987889948D9791828EAAAE958F8A
8C868689759E7E7CA38F7C8165827973626B8485868D826D6F8B8797A286874D8378877E
70848A96908C90858585949481878D909C857F808F82976B81767D8689736B7D768A6990
887385736D6771716777887F7E8D80747B6271857E7A796873777F846B805D6A65508677
83757582796B7F66697C7E6D80958085858B84878B806D86857B7B7C7771688B66436068
6C836E52686A728873736E7275655F60525565557A5B584A5856786B6162585A44646761
69755A62587178FF
FF95B1919D948487757B8F89849A8790A19393667E74897E93848E786992769D889B79A4
8E7D92A48A929B988E7F728B9DA08796868B8C9C75727061584839536188957A9D9D9F99
907E8C7B876F5363727987ACA5C6B4A7A1C0BBAD9D9D87A7B6B5B69DAD81A8B7AEB8BFB6
A7B4B4B0A993ACB9B2989B949AB6BD9CB5A18EA7B393A4B2A8A28EB69DA3A69DACB28C85
AA919E79ADA4909E84BEA39E9CB0B2B3B29DABA6A49398B08A9DAAACB2B2ADADA3A5A989
98809899919D9B889579685961616C585B673C6C7F9089808A82839480717A78798CA398
B7B9B7A5B5AB9EBE9EADBABEB0BAB8A6A9A3A8AEB390D0A497BEB2AC988A9DBE99AEA79B
B19B7B8F888B99A3A990A09981A2A68F7F9E99A3949578A597959370769EA17AA3A78BA3
9C91798F8A987F7D8D9A88836A958C93997C79898F7D807A82958E8A9C8A8C9284A3B0A1
B77C8F928C8E88A39A939868885A6E8E877E879A8E98828A75847D797B9BA58D89868478
838D888070A09D97887A957791867C847F958C7F908480878A7F8381857C7E7C7D7F6B89
767E687A767D67896F746C8E888B8180666F705F578A75857477746C9172506B5D66636C
7993657A7088708559576C8B9066667E707A62746B687A786E7B847175818578757F6E7D
697063715969996E72785E7B81726A5A6866666A5F5E4F6E6B4D56606F61704C735F547B
774054695B4F6FFF
FF9C80818187786363807E868F838E90738173948C7082AB8E94859F7C9597A09B7C869B
886F808A828A848B837E8C8B9D8E93A79484A49B976964664A54536361589F98808D9A92
957C7F806C5D485C5062B2BBBA96A9B898ABA992A2AD87ACA9A2BAB19CBBA593ADC0C4AC
AFB99AB1BBAAA8A2A499AD9FA2A2B8ADA49CB7BCAAB4ABA7B2AFA092ABA49DA6968EB59A
819A8D9AAEA5B2A78E9498BD979B9AAB9DB298B29D939CA4B8C6A0AAA9A8A7B99FA896A8
9D988C948F9078756876605C473F42485B6E5A836F798C958B839294827E8A919181BF8F
96A1C8BFACA4A9A1A3A7A3A596A1B7C3AEBAB2C7B5AA879F93ADB59B9A9FB08FBB8993A3
95A29C8D819D8D7B999C9D899D88869A96847F809D9C92868B798273888692A5858696A0
8AAE848A8C85A99894958B8D7A8E778196B3968A928A8D8B7196A58993867D8599A299A3
95837975906CA8909495798485668D86837E989686898B848999948F9880758A7F89746F
878E85798D886F727C8A82879093938193B67D7A857C8493805F937A7976846B88818E68
53737661918776765D7F7E6A8D858E73806C84697C6C70696D8A6F9F7663635F8080727B
8A79926579698F797B6269766F526D756D647D5B716D8487816F6961747884869474827C
74646860607B6A6A6F6E717360755D884E4A676A685F6B64734F59744F484F6772655E55
62575062605471FF
FF968E76708176698378828D7F8979948887917B9580827788718B84808B867991997D92
8E7B7F85919E79708A76958085859E88A27F73979C996C5C5149615C69869B9A7A949B98
A08D6C70715E64566A8792B6B3B296B0AAB8B8969A94B297A59EA89EA5B0A6A99E96B2AD
A0C3BCAFB3A8B9A1BFBEA5A29E9F9C998DA6B19F9EAB9F9DA0B09EB3AEB3999B89A89CA3
A893A59E91968E8F98A6ADA1AABC9AA098828A9AA09C959CA6ADB5B68F8A93969A8F8A93
8D97819A8F9C896F865B526B382B292E3E68778091989BA49BA2928BAD8C677F8D8E7289
95C6BBB5C4B5B2A89DA9A2A6ABA0B8C2ABA4A19AADB6C2A6A298A195AFA8A19F9A96988F
988393928586A1A097A3839B91A8A59789998A9394998A96938C98A29795909097949BA1
96818C80909C897C8B7C8991868E9A848A92928C8B8D9A818F9299A4977588748075937C
9E988D7B8A879493918A939493A992B2939082A29C8B86838D8476988A918A718C79837E
8C766F7C748690868B8B9B80857C768D7B8391989FA086798B968D6471717665728B6877
6E707A7A6C817B6E7C6E6C726A897F8D727D5D80825F65806D6B7F676778736F64717B81
5D7D5E706F5F82806E75717B807297717D93726179817F8E757E7352887670786C745E70
7A7A8668527C637E68666A586F7682677460636760556764431D2147534C5F6A616C6A45
51778561767576FF
FF8E738257647681627A8C95A38D877881A79886747D7C85858F87739088928C8088AC79
7C829690989B93A77B8F7795809F8C90868B9381768269694F47405D704F74927081916F
7A8189756F5C746E5899929EA8B596A3B89DA8BF8CA6A7BCAAB3A393A8A59EAEBC9189A6
B0A6A8ABBAAFA89DA1B1B4A687A09DBAB1B5BCAC93A0A7B89294A29095A39D949D8B869F
9E9B9E9E939BA19398B0A98AAC8F9DA4A19BAEA198BDB19B868F9D93A69D99B1B59D93A0
A3929194908F726F7F7F7C4B433A4C364E566B74A197AD9E95967C96888B7BA1928F917C
A6B2C6ABB7B1B4AFBD9EA2A2A186B9A1A2A8B4A5A8BFADA0A091869FA9989FA890A796A4
A28C9197917893A292808FA67E9893818DA39D9C96989970919590979F846E79887F8AA6
A5997B877E84868B8C9589888D92A16D7A988A7B7F8C85A78A93899B9D9D83727C758A89
7A858812918F999D746F817981618C89797C83918A8290889E9187969C9F89878F929D9E
8897798A738B87807A9472977A6780969A8B8AA8907C96927F7F79837C827983767C7972
5D927A737B727E76706874846F7470737B5973787568857E6480816A75686E6E7F667158
6B6D6A7B817A8C70768260667A81877476877079637A857E6E66747667766C6360718680
5B6F7E7B80848084758F5F7C6A725B6B565B605F457E6B3B422D4D5F5B4F555B5E5F5E5F
53585771776670FF
FF5C5D6C766782757F82788C87928A95A18575868486826D748D869A8BA06376A0A08896
8C7C7B8F7C91A891AE8BAB839E9F8E7C8C86868F85806B65596D6360787A75677F7E737A
897968786E7071698089A1B9ABC0B5A0B1C5A19E97B7A890A5A1B6AFB2ACB9A9B3BCBEB3
9EAB9EA3B1A4A3B8A3C2C5A69F9FA5A6B697AC9F9BA7A49D8697A09499A2998BA1A3909C
9E8D879DA8888F97AB949D93868DB0B59AB19EAC9F9099A5A6ACA8B1A69BA9A496A8A18C
8B898986997A7F766C6060754C4D5558565D67749DA7ACA9A093A0938480897E72A274A4
96A9BDC3AAB3B4BDA190A9B19FB79CA8AA8DAEA2A69CA6AEADBA9F9A9EA89D9388A5B19F
AB748C868E9C997FA181948F8C817192A892948CA09B8D9A896F7B848CA4929D89888BA2
A489859288869F95908A78A29782959281839998877D8A898C9D939292A09D8F939A787F
849489A197777A8B91A2947B939C839395938D87768F9481997B818C848294939E847B8F
85A38885827B7C758278976C8B7C6F98877D8D88728E6D73798E8B86778E7D977E869376
756C707E757A837C73778572768E718181964B697C79687B91876B707171766F627F6975
6B6F68756B7877867E74647A6B74707E59798D6F647A6C7491716F587B7072686C6C7A80
5A596C78607263757571826F5651516570644D54685567884D48775E62715568716A7058
4B57647E6D8F72FF
FF73627B666771896A856E82738E838C909B9C8E76798E7E777D7C85987EA47A8E8E9187
91859C927E8976889D7E978A96968B9B9B81AFA3A7917C625D5556686C65586E7F636A71
6E74815C68676B74808789A8B5A2B5B2AAA18AC5AB98AEC2ADA5B7A8A8C3A0B6BCA4B5AF
BFA6B7AAAFAEB4BBA9A59D98A89A968C8E98ABA89BAAC3B7A6B3ADAC9BAE9DA5B3ACA5A3
8F7CA0A09AB3AA9598B1A7A98C9C9992AF9FA897AB9DA5899AB3B1C696A5C0A5B5AE8D99
AD82879096718F7A7D7E6C6662465C605977788E9FA69494A5938389928473788B7E9486
98B0CEC39E99AAB5B5AA99BCBEA197A2B3B9B2B3A1B9949CA2B6A597869B9C96968E7D77
828D867798977B797D8197A4A7868F8391938E9C8487AE8A97B17E998D838A8D698F9E98
9AA4AD907FA297759993768B908C7B8E8F8595878F889E8F9F9194878476938F97678191
8B948F9F7E93A67C828A918A858E6B809B8791787885A097729991A190989C6C62908175
847B889A8884667FA4918791789892858883868880828E878C807E5E93A6858C95788087
557985606B7A777873898A878874807B8275646064645E6C8A778D727E65717565627D79
8189757D756F85846A75867B75759673827773676A5C7C746D7D84846488837671717986
6D5F5B5173645C5B6071676467613F60525E4E4C724E4D5C6D6B5C68623E704E4C62576C
6E6C62607E727CFF
FF5E6F6E5A6444527368749F9F6E7F949EA07F869687A18286875F8891948D98A27E8281
7F829E8B949BA09E81A2A69F9F8BA5B2A5A6929291846D7258776769636C5D7B7B689091
7569655F59526C7E9999AAAB9F918FA5949699A49BA6AE7F9CA7BF96ABA6A099B4B2B3BD
C5A4AFAAB7A6ABB7B0A7A9948DA2B9A5A78EB7AEAFBBAAA495A8BB8F8DB1AFA399A39B9A
AA9C92929C92849BA499A891A0A3B89EA29FA6AEB0B3948F8F8A8691BBBA8E92879A8E8B
6D878A849096757A766E7771807B5D756F6F709292A0929DB388A08597958E8E8F95968B
ABA7C5AEB2B5BEB6BA90CAB0B69BACA09FA09B9C93A9AFA7B898A2C2989299A5A6929A96
7F9780A18B93789186AE89A98B8D828E87848A958B97B19C8F8B9387939E8183949A968F
959E978A8B88AD998DB198997E819177859B9382848F7478929E9079785269907F968187
9985A3A5949370947C7670807381A28F989F947E8EA79687837999AA987D8E9479758C73
8D948A8B8B818588848A859394A1808E768C81887F7F84795B8FA07977859D8C71929084
86897F9463817478828476746C6D927C8279756E60725A796B70654B66827F6D4C748665
707585675163597A858672718E848F877D747A707C99766D899C634D687F7379746E5E72
69747C7F7E6189626E666770705B5460585B5D72575559615253564E5C595D616A525654
67665F7862737DFF
FF6145536769605950527265778799908D8881887E75727F90908A8B70797B82837A7590
9C957E89908A8D83AB8D9098A084A8AB82638F998E747B62686E575E6B4E616B6E5F6E71
5951795B725E805E828E96B0A9CDAEA09293A9B1BFC3AFB7ABB5C0BCA497B1B1AEABAC97
8A9DB6AA9DB4A6B3A79DA5A4A29E96A0B4BBA9A4B29C839FB1BDABA497899D9C9C909AAC
9FA0AAAF9CACB3A0929AA0A298A1A79BA5AEA79C8B8F9EA5AAA1B992B0AEA6A9949A8978
A36A7E9B9E9595808F9D8E64686C88756C7F939E8CAB95A6A97C98978B807687788595A1
AFBDC3D69E8EAEA48EB4AA9095AEBAADADB4998BA9B7AFAA859197A08D7FA8A893A48A7D
A69DA59E86928392AC887FA68878968D82887F99959993AB7A888692937692828C97A797
B0899B949EACB1A09C828572899F8383968A82A3988B83869CAB938E887E678F958C8B94
858599869F9189898D9E9B76779880688279948F987F7D7F6A738D888C749C777E87848F
806C888C798082847978809098816C947C8D9C92A1918F858D758175798A7F8D867B7078
6B777B7372768284776F816F81806270898F79896B90806760767B7C8A8163576F80856D
6C69776F6C7D80788C8175768473897D5C775B75716D8E84726F666D666C6E7254614E70
53636E696F71686D6E5A7C7169765669745783756E5A6B64587770614D5E6F7171656F82
535B5C59616976FF
FF5E767076697162645D715C607D8E89818499819B888A8368947D74867B8D747E998369
888C83929B7B8C8F998CA49C969892AAA67BAB908AA29288806F6D6961637079717D7E93
7F727062707B7281A6AF9E9BACAF8BA3AE95A9A6A0B5989BAAA2AEA3A69DA9A7ABBCC0A3
8FA09C9798A5B2B4C7A5B9B6B0AC98A1C3A6BDAEA89BB0B4AC9CB3A7AC9BA5AD8F9CA18C
9B907F8DA095AFA8879FADA8B49FBA9A8599ABAC839BA5A38F7A8F92BDBDB6A8B490908D
8C7E7980998797859A949A8F91716B71767E85A39DB1A5AE96B5958B938B5F8288916886
97A6B3BF97A8C6A1B39EA5AFA29A9C9FA6A0AEACA1AEA3BDB99BAD9AA78F909A9FB39763
3D8D9FA896868F999491AC857082808F71969F988B8C9681A39C93789E8BA3849CA7A69F
9594A3AA9A8D929682A69480837C83978D9F85838C869088A07F8A888E78847989A59E99
A47D98A5978E95839789878060688999888D7F948D8D96837C8F77A0998B89768C7D8A6D
87787E74769D7E8F929079846981859996888780A296799279826A8D6E9784868B6C7E77
77726C7D71808C87836A84887C74807465726F5F74636F60636F7C71716F6458706D7169
8B6F6A83817D686E8188797E69728297795B62737A64786F886D527F777F7771826E7479
53666C6D7B6A7A715F657F6C5E5F4C4D4F575867795F6068527965534F6E625D69736040
50475156737675FF
FF7D667D6D7251745A545E75747A626B787A958187898C8B9366847D70796A7F728C876D
5A7B86897C8F96838BA0AB9599A896848EA08A728C988092887B76717B6F777E7B7F786B
7276655A65767F84859EBCAEA29E93B6AF91A5AFC59F93B1AC98A3A8A5BBB7A3B6B4A6AD
8E8A8CA9A8A0C8AD88B59BAA9CBDB9B2B3BCA39E95B2AEBBB8A7A8B7AFA1C1AB7AA4A0A3
A7BAA79D9F9CB19BA7A897B7BA92AF9B7386A3A395AA91A99CBAB6A9AD99A394A58E847D
858987887DAEA59382ACAD88938E6766788480989AAA97A09E928E7E8E827D898C8C8993
A6BDA89596B5B1A0A39CB0AA9A9EB29EA7969CA0A0A78BBA9886AB95807997ABA682877F
8F8AADB4888A99978D7E758882A0858A86728EA39D9D9FA68AA79188897E919EA0858F91
7F8D9E899F8D97A399A08C7BAD857E8CA68392977C998F828F8986A08D7E7D757F838B9C
929098967E9D9888969E80878586838F98A39E7FA88396788F907C6E84918C8C7A8A778F
74828F6E7F8A8A8D869076788A8B8C87A8958977948D8F91928E888A8687889381766F85
7278696397A47E8B736371887D6D6D6476737F6C836F688B717A737B83716E6A817E8272
747185917F6367776F766F70607B756E6B60687564717C6056536A808B736C5F8A7A7D67
6D5371695A5A425E6D717D7B55595A615F5B605B5A5C5A6046536656504B5362546C5F5B
6861507A536E7AFF
FF836C7973737B887F5548567D727883A78F8692879087808D7E6A837A80957379628870
887781939186A597A5757BA69AA08C9F9996959893A47D6D807D7D67826F738F8780817C
855A6F5D716C7C92A0B2A9969EACBEB2A8A8C3B8AE7CA58AB58ABDB5B1ADAF9FA4AABDC1
A7A7B9A0A6A18897919D8DABABB5B09DA6A4AAA0B1AFA7B0A2B2A7ADA4B0B5A3B19B96A8
8AA4B39D9C8E8C949DA2939E9D90A182ADB8A09C93A2B0ACA7A38C9798B4BE9B90929488
7A897A9F7B8C8E8D8B867FA18E7D5567665B7A7487989C95A280887F8B837C8F8783A897
AEBCC8C8A5AFA4BEB2A28C9CBB9FACA8B5BFA1BF83A29AACA29992B5ADAE97938CA89CA2
9298A5B09A8E927DA299A79E81948888919E8788947794AFA5738F88A49D8C8B7C988E8F
858D857F92A09091957F9C837F8B7184887B9B8A938588B19A8BA0A19686937C81B58CAC
977C897F938A877E746A888D83998D9C93A47C9B77808D8D76767A8783758E8B818A8992
9499737A8393817E897D6E8C8A6179A87C8F946D8A7C7C818774687D82987C87847A8381
7367798188727E5B7F55808C727D9C6B83818274616E7F6D6279836A5E70906B706D7C87
77897C717982676A62677C75736A6D84796A8B746D92788170786C79776569537D82705D
63712D536060687872585A5F64616C7B3D64575A616C544069605D5556366364565B5965
6A55564D6B637CFF
FF8960747996857C5F7166716678859097958478719F825E7071828F757C6C7F8693808F
8F888A899C938B8289968F9A9E93A2A6989AA2A099948F8A927F828291848F6F89808495
7A6F887E7E948F96AF8D98A2A093B1B090B784AA9D959EBA84A290969AB8A99EB5BBA87A
8A7FA697AEA39B9DA6A994A8B9A8B6AF9DA4AA99B5979CA5A3AB9A95AAA6A3AEA67F948A
AB9688B0B38B9F8DA4A689A8ACA198987B9F9EAB98AC9F849C92ABA29E8C86A095948272
85768BA6A699A7B4AF93A4A394866C5C76765D578E7B98917C8575757A778E8B8EA69FB1
9DA0A1A7B6A8ABBDBABBAFBAADCD9FBFB3B0BA9095A9BEB49597978DA7A1AD99AD9C9298
9F967C8A7A877EA89DA7907B9094A5987F949F8B9EA1ABA0908DA2A19E848A938F8FA49D
987D947C92889B958497998B8D7E99A696928E8C8C9276809BB2A595808C7D8E9A878A8A
8FA49A8D8A858D8F847084878987A09B92928780807E886B88839C9DA5A39BAD88897D7C
7B759B7B878F74715F74807F85A46995756D75896E8293857D8F6E808F719A80867E8D6C
78767F8F7C6A817A82718162727565707B70717E696871766D6084717573626D6C878290
9A928690736C747857525B49785A60684C6968907F7773886E7C53657C6A5863936E696A
60645B687E5853186965675B67666D515164645373736C6A5770687B7B4C506A67716975
5D5E7A6566416CFF
FF9A9F99A58F836560585A686782808B878D947D96887E76888088787D9B9A927991887D
859A8AAEA18A8D9E9892B09E8CA99D9B969A93A0A0B2A999949089848881989599968577
79736B70998A859AABAFAF9FA4A3AA919F9186A0A78F9E98A3B6A0B0B8B1979B9690A39B
A5A8A5B5908C8B959DA4B2AEA8B1BD9DA6ADAFA59EBFB19FAEB9B7B39EA8A3B78D97A2A0
A0A59F94A09BA2A39E9DAAA9A49E8E98949BA58F90B38E9C9492A0AA8A9F8291966C9084
7881818E86A0A78A9A8EB0A88D8666555C615E597976897288768C7E7E7E8D7A8EA2989D
A99BBBC0A477A7B2BEAFD0B6A7A4B2AEBCB3BA8DB28599B7919DA698A7A7AE9C958EAD9E
A6B1B695909AAA8A8790A97F808FA5AA88907F93B4888B91A489A6816E93B28B84A5A484
919F9F8A84898473988F8E89A6A6978F988C7B828F8188928F93879C8A9493848C838692
A39A92967B84888FA18392999797B487849789969684878B86858294879A938A74818867
848E976F719A8D929C82957B9A8F9E828B7C8B769C89AE7A71A08387848D8480888E7689
666F80877B85867B786C6F767C8D7A82777F71766C788D84977666507089765C6571876F
7B6C7E647A71697370546852617E696768757150698B837D706E65647C8C8E6B496E6D63
6E7B7F66485E5064605C5F716F5B7059527D6D5B594F60617667515B597C78796C6D5B5F
534F5B5D647571FF
FF9084A396938D6755695E58666E77858772838F8271757D8E6B7F9A8872867E85808C90
827FA08F8D7F979FA08FAAA2A5809BADA59DA9949F9195A297A9A39490859BA89E8A6885
91898397A3888DAFA19D8A9BB1A48BB2B2B2A9B19C9DB19B9FA9A9B0959AA1B49AA19DA5
8DB6A4A6B08A8F9CA08C9887A8A390AA9F9FA2A2A9C3AD9D9DACBEA5ADA4B8B0A788A09B
A5A09FACACA1A69AA6A696A98F99ABAB8198968A8FA6A4AEADA29793AFA1A69595AD8692
858F867391AF8EB1A2AF9B9F99865F7C515D564C62707E57626E666B746C786E8FA1A0A9
B3A1A7B9B9B7B4C3C8A39DB6BCA9A9C29F9282A1AC9EA7ABB28C8BA7A3B09C95958B93A8
9682B084828373997AB9A8A97B8C9392879796A391A5A87F8D9BA1A47F8A7283A190A8A4
AB878B859E8E8D8494947C777C83997D949491998E87988D7E82949482966A887E7F998D
9184977F66816D6C90766898AB91909A9191A29376957FA191698D7B7F939B819B87767F
8B8C8C858F9C818479736A606D8B7A7A63798778738E89786B837A778D96928C96827C7B
6376637D6683968F727C7F667D7A7D7E6F7982826C677A8E636F6C4F68756D9185686D8B
947484767F757C5D7C787C6E727BA075537A7A7A90707991816B4F6E746F68796A6B7A7F
7E728F8268584C6A645F6A6C6D676B6562585965546D676F60755F5D5F4E665458896B4F
706C6B42605970FF
FF889082879C7A65597572685E7A778192809196768BA97A757790919B96908D947E978C
778F9D87859CAA97A1777C9199B19C9D98A6A19A9492AAA4BC809DA88B9A8D8E85A98B8A
7E9E88809692A59C93AC93948EA7BF84A4B4B8B7BEAEBCC0AEBEACCAACBFAF9BB0A9A58E
9EA3A7B4A794B6A0B089A0BBAFA1A8ADB6B9A9B5A9A5B9A2A2B9D1A8ABC3AB88AD96939B
8D89AD99A1AAB68F87A2728EB6959B92A995A68E94A99D9191B99D9EA6B3BD95919F8A84
8684919B908E9DA09A7E90809A88745E594D516061436F766F697E6F928C878BB28FA1A2
ADA8B58B9AC0B8B1B6A3BDB1A6AB97B194AB9DADADAE929E9A99979CA1A2A09F999B968D
9E9793A89FAC98857E929DA4A082876C919B9C758E8D8581918F9A8C938A959A8A838B86
89AA8AAF8C929896937C85708993908D7C84989D798E9B7C9F8C7F778F7B95797F8A838F
7E8490896B85758A878A727390A3AE768EA49092A58A6FA29399AD8B9685976495888585
658C7A73928E90838A8C837E8B6B818F966A9792818784786E6E868284A56F70938E8487
7A756182816F947379777A98746F7377657F87745171697465825F535D7369668B748D79
776876547284677573666B738B8C69858B6A74676A746C7372696E776B895F6864707486
79645B56626C5F4900554D56797770786E656379616373793F58665563675850665E6667
5365647065588AFF
FFA78C8F9195958C7F6558527C705C80977D8663709B79786A8486777391859186919879
7C6C73978C8980838788849FA6A4AFA19CA495AA9F8A9AA89F8EA59599A192AE91A9938C
909D8E7F999494A393AE94BF9F9890B09C91B9B3B4AEBBB5C1A8B2B0959391A18C9396AD
AC98A69B80919E9AB5B4A390A5A0BF9CABA895B5A691BA9AAF9FA0A4B2A871A78192A0B1
A1AEA095A797B1A08A9D988FA3A1A3938D9799A3AB9BA397A2A98397A9BB9DA89296A395
907B947F827B7EB2B9849E959D8877685B455D6669584D706F685D609A8B84939D92A7AE
A4B5BEC5B7B4AF9C9294A9A7A6B4ADA2A999B0AEA790929A8DAA9D9AA5ACAE869DA49170
83968B9492A1899089809C818D8E878194997B82868CA4979C8B8184839B7E848E969097
A29E9CA0A2A5988699868C78A59B7B79888E87A7837D8E8C8B9E9E8E794E7065907D8590
A595847F82987E7079978E8E968E9A9C9385938A8093898195928F949098517B878D9581
9A7C8E89887E758E7A73819B849184A48F9479838383868362829A81787F828278867F84
8E6369928080748D8075776E6A79545B7069639A8F8F7B7F676D8B66776765786C887669
94947B787B7188788A647E7B6F786A75816D5A80736A876D6A6F83686E676E61886D6E70
7E8269597265576F5F79846070615B76696A6A585A5E5F68676652785170676C69725061
74506D685A5C52FF
FF817E9491867667715B76646E6E769092907E8D986E7288847C707289A7A0887F8B9287
66969D7D7E80A9988C9FB57C93A3AAAB9E9296A48E8C7E868194887A9475728D987D8FA1
93A3A495A699A6879D85A4849C9E98969B889CB3A4B6B3B18C9DACACAE8683A2947B8A8C
A49F99B8A48B989D879E9194B69CAB978B9995B5B7A29EC1AA9EB1A6AFAE9BAFB2AC8DAE
B6B8A3A3B692AD999AA290919F789589958990997A8DA2A0A3A9969A9D9BA4BFB3A19986
8E8D8F71857891799D877F8E867A71447D5B4E59597268687E9095818BAABAA8ACB8ABB3
AE99ABA4AAA4B6B09BB1A5B28EA9A5A4B5B0BAA88DAACC9E908E938A8693A1AFA1A49183
87B38384A1958FA09EB08D957C8F8FA19C8F959A8E899094867B8B8C8D918CA2877A7B67
9691748277959BA0A299908B81948F909593748C80939D949F9F7F8F7D8C897595849B72
86877F948C727D889B91857D997D89AF8F9F9993A4988A7F8B7C9A9CA2817F87787C7D89
94818893848D8C949497798E9B7B7F97956F6C999591999A946B9B71877F85897B8E7278
587590817F78777A6186807963826576888B89756879866C697A67806266548C81748381
7B8E8C937A747983846A7490776E8C86727168838B82776C6C4A6B79766F7B7275706677
74686668486C5C776C5D68787C655E6461576D805F6C73697263767326435A5565566976
6F555165806D80FF
FF9A829798968D807A6441676A6C8694947C81828784837E76708482877C838A9D6C8591
9C846E8EA8867A7787969C8D9E9CA1AAB5A5937A89877F798A758A71926293637A939D7D
9594A0A88F8C8B8D81A197938B8A7E9497B79CA2A1A8A29D98BC9CCAB58EA58A9A8A9899
8080A7A194A4A2A1A4AC9BA287989DA39EB1B7A795A7BCB4B8BAAEA9B2969B95A9BFBAA2
ADA2938DA89B8690AEA4828E868B7D9593A491A295A0B3B9B5A597ACA2A99CB0BC9387A3
868B888E878076998D64728981716B6E5B596B5C666E647761808E98A8C098A7C0B7B09C
A6ADB0A496C89F97B6B39FB19D9EA0A2B3B59BA9A89D9F888D91A7C1B4A9A2A5888A9396
8A9A969282989195829A91A3977C8BAB9798949F9D9B7B96BB9FA284878992909699B08E
928894A289767D9E9B9082748E947887809983A8969B8DBA87A29B96A48F8B9F779E869E
8A8759C98C7D7789718980A3A5A1B098999D9495939C938C9280AA886F8BA08C929F785C
83858DA4886D8D8F8F88849F7D8E867187938E767D90896E759C79898D728F82596F4D83
85968789907E7D8C96717B836E76728D787A6C837B6F797475698F6F78795E6478798973
8C79786D626C73768682748988867B607A6B687D76835E7166818571447265616A5D6E58
576E73645C81675F70667E74795A59645F576B556570714B5D6D656C4C6B636A72726184
6A736160666E52FF
FF93778A9B758B7867554A5D6D6583818387868390A68B856B6D767A768271615E829665
706A8F8982877789A8949191A0A3BEBBAB8E8B91737C6E607F697C71746C6E86677F7C9E
89AB9C9C8B94A5948385B17396938B9B9993889F93A097B4B3A5B2A9A2A59D8A81B7B2AB
8AACABBBA5A5A38FA492AD95869A979AA69A84B9B2AAA9B5A3A4AEAA9C9AB09E9ABCACBE
95918AAAA37E81818A80818B849563707B80A49B94A99EB1AFA9A49C9C84A9A3A2B59687
9B9989907B87857F84735B61706976607A8875766E89817C7996A1AB8A9F82C0A4C39E97
AF879FBFA7B8B0C6A588B6AFAD959C93A7A2B6BBA9A68C9EAAA18D99A88E98B3998C9FAB
9F8F899C8F9C8C789C8CB7A29A9B86958F909DA0A494808EA79887768A9A878F9B7F6D76
8684AB9D9E8A8A8097A0999A967E749C868E789092958D809879A49A9D7685877E8E8781
9D6D97A2AB7374969D93977E8A9DA18F899D9290888B8C9E8D839A868D9F99A5724D7293
7677769B9F938D8F887E6E5E9172908880958A978A8981998F9594838072957F8093867D
77769A766B766D777264666F75656670768385827775777788666164726F646D6B938D6B
6E73707179666A6E827F7C79927B84728489764E6F58565A7A81767987635D9D75505E63
7E63616B455F7A6A7579725B775C5C61614E574C384F56605654747D5C4D5B535C6D6E49
745E6553556F72FF
FFA383967F6B56637E6359547181857A827F8A8D8B78799076855D767D9564877384727A
748D78787B9A828C8E97979799AC8F97988D7667758155745F63797464837280807D877F
868E9C8FA3A47AA989AE818D7795928F818DA88D9BA3A2A4B69AA59BA5A2889C9C828EA3
AF94AD9D97A4918ABDB18D827CADA891846A9EB994A594A19BA7A4A0A3948CA49BA8BF9C
A1A5A069968C7A70868E897D767F8574958C779298A49C928A96ABB5B79791C6C08ABE90
94828AA5A58F6F73898D6767646E476E839672886B827395B8A885B5B8A3BFAEB0A1B493
A0A7B6A1B1AAA1A0AA9FACADABB9A9B9ACB28C90A0A18C7A9F9BB29D79A7B39094A292C5
8D9891808A959095878787917F7E8D9190B4B2977998A299848186858994A37B8369848B
9A7C808B787C757B927D84768B9A75838F837A8F8EA0919BA39AA182848A8F7A71917C74
988577797A868B78828699A19195918483907B768D929D979D9A888E85968D7872916683
887F83778A9899938C8A755A6B8686779FA1868C9976868C867C80919081897E70749773
84968675868F838884666A6C4D656E634F6D77777B6E7F81627173736657805C7B738468
72716A878285787669666B8982756B7773555973637E545F7B516F7E8E6D6F6D5675835D
746A78617A626C65655C6062637A4E725E46545062585F60746C6E6C5C56655768726A64
67625E6D82696EFF
FF977D7D8583796B59554D6D7861838195887C827E72787186787279756F7F76928AA681
807D718D7B9E8A9598959597A3A49C9FA18A727A647582726A7868796A688576717E948F
8C7080859083998D8F7B7A798D998B878B81A590899291A8AE909CA1A59492AE8F9395B4
ADAFAC9DA9968DBB92A999B9969E8490A7A08F99A0949AAEA297969A9F9EB2A295B7A5AA
ACAB8D948F6F6F7976806B758977616B7C7D9F98A5A2A494A6A2A18DBBB3BBA1949B89BE
A28B787E7B7E8B6B817C75858369737D79939E798F9CAEB2A7A6B2B4939DA986A3A7BCB4
A5ACB3A08FACA1BB8DADA2948F9CA9C29EA8AE9FA39C9F91969E98958D91979BB29394A2
9E6F9190A4819B928783A2AAAB8D9E8890918A8F7C96889C8B979595A09A838C9B827C94
9892857E917A888E9C8B838E86826C8195A08C7AA49F8187AD91709191816C82868D9F87
83958B84925A8A91849A8F9B998B8C919788948A9C968898968E9099838C808E8E837480
6860898099997D6F7B4A7D8F8486936A7F908E857F8C8A8D898C808A97947B81857A7485
746D9D8B767B797E788A647A7774785E6981735E857D65636F728179688F8A827E738484
7F8978636B7069657B716F7D796E797F6E6D706B586B697C4A677C70587F556C636C7157
617F826D6C6A74756E4F6F585B5B694F60645C626966516F5E71635B69525B55765D6A73
5F5C355E6C5E6AFF
FF8E76827C777565706A70748079787E929D8B856B8D9A9485737B8085955D9291A07C8A
807686859292A2A2759D959FB89CA0A97581778C837A7C746F715D7A7B6D6D888176747C
8E9A8B9DA095A99E81856D8371917E8680827A819A7F8DAC98A3A7CBB8ADAD9CA29E92AD
ACAAB5BAA097B2ADA1A6AD94A48E88A5BC889EA99EA9A0AAA1A1A197ADC295AB9CB0A6C0
9E9E9789606061708D859386788E7F9E7E9195A291AFA3ADBA9DA8B4A0AAA49A9BA0B09E
A0B08D868A82939A928F7E7398959C858987A8B4AAA99DA4AFB7BFA6B2BEB998BA8F899C
ACA98DADB6B3A7A3A7B592ABAFA39EA6C5AF8E9FA39B929CABADB9AA9E9EA7A7A0ABA7A3
A37D91A2BAA18F9A959AA48096ACB490A1AC96908B8C919AB0A490999CA5A8ABA19F9F97
98818B8E8C8A96A19686938B979B919580839D89A07C9B8A92748A94A4899177757E876F
968E828BAA889D9A898989979E977C996C959E96928A9E978D8D83966E899692978A8682
827A94878A86A58384758B7B8C8A8E937F86886F78928A79796D79A1928285708F837C8A
898A8573826A797C82818F7862777E708170767D7571717077826E7F7F6F67757F7C6D83
656B78827D82887D5F68647D867176886E7687846C555B5B7A72767A5859756666706785
706F655D697E62796A596676617A61645D5D70765950527275797F69664B566C71506E5D
6D5A61437F656DFF
FF7084706B67656B68634D6D6C9C877FA7A07E497A9C79816466647E8987877E85A0998C
8576988683888386A4AA92A19A8C8F856F7E705D6B806C697B7B7E82868E7168655E6E74
6F849799A29B9F828291787373928567708B808B7B7B88A7A7B1B79F978E92B0ACB2ABB1
ADB38AA18DB599A88BA59DA0829C8B878DB1AEBEB0AE93AFA1B79794B494AB9EB1A1B79F
A4A06B8B8D7A748D709588A78F829D7E7978938A889CA196B3BFB7AFA598ACAAB7ACABA4
BAA6988486A39F988A8D9081849692ABA1B49C9CB8B19BB4B8BA9E99B7C2B1CE959EB1BF
ACA9A4A0A9A2909DB0A5A1A2BBB3ACABAC9C9EA880ACA3B4B19E8E9596A6A0B9A3B7B879
92A390859089998895AE859897A6A3A8A5B29C8E988C9B9A9C8996A09A94A8A79D8B8F91
99A5887B8888AA91889D9395868095848A9C928D899894A38D8A8185868B879193888F8D
9A77929395838A95A887937F9694A2AC9D939B8A848E887F778F999387789284899B8E83
617E6874818E63638B6A8D857D855A8490797F927D748B7680868A8F9C8160866C867A84
867A8286897B8D76856E7C6B747566656667817C7673698484787781678263607D806E85
6B7769736C777B6B615B63946F78796F7A84925A734C6C5979707677778278625853706B
727D6B855D565E507C65675557677458473D555B71615D6A696C567352485D6666666762
78796E796B6B5FFF
FF685F6069736A6257578B869C7E7470828386997B8A93939F96817E8B75986F93A0A591
A28D89917D86A1A08593919576858C8A856B7375476C7B7E8893B2A47E7F95726C615A6E
666B7D6C9F9293899894A49E997F917D78688C8378796C90748D99AABBAA979B949CA89B
86A8B4B8AAA9AF95B2A4A29C9897A36E919B94ADB2B2718D9A88A79F8DAD98ABA0999DA4
92948285846D89797193857C8A855684778789758F928A88B6BBAB8F989AADA9A0A39499
ABB6B7AB8599A0938F9FB49691AEA5A4B0A8AEBAABB1B7ACAD95A79FB3AAA9ABA1B6C190
89AC7CB5B69A9CADB3A5AC9BA7B4A4AB8E99B9AAAFA1A69FAB9194959DAB918FA4938FA5
B287A2A88D9BA087939E8D8FA1999C94958F9893A39B928B99869FA7A8959F888EA68299
90A09382A2837F879C9A88849485879C6D92728E8F7C8D865E88828E7E6A7D91908A758C
8F568B7A80928796878C998C9F9D8C7C9A989E918E87989B979D9B868F8973868D818E86
897C5E777D767B6881726677858C998388928C89737B727684608D7F9F96858E85799191
7E797A838D9083886886716B7C717772736F6E6C9482856973727A6B816E7A886F718A7A
7E81836B7B61616D6A77725270876E7765775D697880816D87816C777E6D8C6E66516361
726779775C6C58655874635A56745A6C7B6C556560654D645E575C69567B596C68583B7B
5E66746C727175FF
FF7B675A5D605E707F6D7B8A88828B76968D908A847F7E93A47F887B5F75719091989A96
7994968590A69B90968C8784888C79787D7272606B776B7261AF939AA28C8B8175595A73
557489968AA48F849FA18F8E91828DA085736263887B8D8F9699BCAFACB9ABA5AA96909B
C6CFB8A49EA38CA9AAA6A9829C9B868D8F94B39595B4B192A4A0BCABA09EB6B0A29CA989
8EA49D7280837E547C9793888495A0899F836E8B848A989EA0B5969EA0A1A6AA9DADABB7
99ADB7A1B3ACB88D7E83AAA6A0AEB7BFB6BFBAC7BFA9ACAFA2A9BFB18D91B1B7BAA19F9F
879FA4AC9F9DAD9796A7AABDAAA89CA8ABAE959289A6A1A0A095B6999BAEAFA68CAFAAA1
80ABABA1A39F857D8B809A9AA2BC918FA09E92A086988A9C8FA2A29D8F8C798A859F8E83
9696839594917E8D6DA09B8886A578808280A2858F868D7A939190896F79998D8889808A
769693947A9E8D968C9288778092917BA3848FAF948691898F997E8D918E8E9D8EA29C95
8B9A878A8D797F8B7F859A7F728F816B85858E8B8DAE819085887F9C8C87807D82938E90
84855F8A86836E88836476728B7582856D74735D64806D7D79797D6981877C8874699262
6B74706E7F6C85836566857582728384897C795B6B7771697F7C827573686F777B6D6063
4B4D6E6B75536A5E7B6670696D5E5162557B6E576B554B575B384971766569725C69704C
55657678745A6BFF
FF8364606B867884766D719878969B889793929C758A907E577E6B92A3747E768385937D
A88F989A9C95879693919387807C775074705F785B7B6B8A9CAA98B0B1AE8C8F74758570
607F8E8576818A897B9E857E999B967A8A8D86608468736E7E688297AA90BBAEB3B7BA97
AAA0A8AF9EB5B6AAA0829AA6948A7D98ABA3ADAB92B2BAB197A3A9B7ACA9B7B2A6A0A6A8
A6907E79847F99687A9D9280A190909C828170618F91929B9BAA9C9FA9A69488AA93A4B1
B1B7AFBB9CA892A0A5AEB8B5B6B6ADAEA79AB5AFA8A0B4B0B1A9AEA9BAB7B0C8A893A4B0
A9BAAE94B8A5A3B1B4B1B49F939B96BF989596959E94B28D95A8A3959895948E9C998EA0
A5A89DA5A6A3968190A098ACB2A28E7D94A78F8876869178918C978979928A979A94A495
AB949796989292938B7B9D8C948E848C8A9C87818F7D8876958F848A699A9F818780877C
99A89F9AA691757582979C946D898A947D9E8E7F9E8382858795A598928EA4799A8C9497
74777B7C767A8988728A87887A7CAE9A89998B95998BA79391928A817F8C8EA395A6907D
8980858992757D8483818A7A787D726856707F626874567572856C6A6A6D738B958A6C59
5475747660716968687E8A8377616D877081667470606C745D6C7A7A7D8472626A516A75
7E63676573643A5375675A6C635F6A7C65576E5A5D484B65646E655F6E666368606D6553
666D7C6E756D7BFF
FF7075756E6C787684866A9B858D987E84717E8E8D71969580907B7788918E8C7C859B9E
9E8E979799978C969B9097937A7B8F5F69505F5D73679288A3A5AB8E92A8B2A084837A6D
7178928282948A878F85939B989C9E7D927C91736F8376757E6897AA8FA6ACB0B8ACAFB3
AF8DA7A2C0AEA49A8400A59C95877DA27E9FB5A5A3BAB29F929CA898B9AEA6B271A7AE97
9AAB84758D858985A09AB5B39C86A5A381827985847B7998A6ACA3C08C99A3A692ABB3B0
B3ADA9B3AABCB4A3BBA5ADB39783B0B3ACADB0B1C4BAA98AAA8EBCB0AF9CC4ACAFC4C0AC
A3999F8C7892A494ADBEC89EB1A29BA4AD8EABA6ACA9A0A9AAABA59F9C9BA58F9B927CA3
9D92A898AC9B9DA49E9CA2AFA39288869AA59B899E92A78F7A9380937C9AA6978599988F
938B8FA0A898989D7E8685868584868F9C899693879B86958E9B8086968867947F779487
957C81908DA5948A949D866D7B8D71A587848C87B4AA95886A7B908F888D8EA4A6949EA6
9D89998D798A8E738F92726784947F8A888A9F9080948498A484818B8583938077668A6D
77988369968D887C65826E72747B778178716570656F817A886A6D82837C7A608B836E6A
817C656049777A7074766A827F63826963786A7772815F5B787985776C798D4B60605D5D
647F6A5F6E7366656D7462585D63576F747B75696A6559605564586161544E536D506F62
686C86666E8067FF
FF9C85938B8B8C8E89918E838F7F93A38EA28E9A7F9F89728290838E7B7F868B90A88D88
9E9EAB9F9D99749874758D8E9589606C68525B77777DA296A2C6A499B6B8AD88778E5B68
6E7D9B9B8D828078957E999B888E8483869B79829E747B74647583827E90A797BCAFA587
96A0B5C1B69FABA2A6897C9A939DA99E94AFACA98B8094A39B919F9D9AA99A909AA8AA9F
8F6785807C87909692A89796B5A795888C7E708674778C91889DB2BD99B282A298A4BABB
AF9EA5AEA09A9798A599ACB2AF9A85B4A2ACA1BCC1A598AFA9A09EA9B299AEA5BDA6B3B4
A7878A9E9AB39E9FA3B0B2A3ACA9ADB8B6A8CFB4959C80A79F8E9DA899A191A1889B9FA2
A299A7A19CA9A98C8488948189869B998D8B96888A92656E8A90918BA39C919894809D9C
91A78A92A19E8B96B598A7879AA1908B958C808590708588897C7E92998C857E9884868D
8D909C7F8583A5958D9D8A898C90988F87978CA49779829A8B8F8F82988A8F999C9AA0A0
9D8E8D9A97966B897F92938C898E91859A8EA2956E888F5795839E969BA67D7D8D788E65
6F6C7C797F7F696B8D6F766E7365855E92776B5F797D6473907586887D706C7C7961697E
7E8162738571726D68847E716F7A5E7660707E7F7773737E647B8A6E6786615570727364
65726A6681636155616E6E5D4A6D705A435E70776C6465744F5F6C5B7A745B3E53466271
576E6F74735379FF
FF84898D888B7BA18B7E8A999C95799990A3A08EADA3A69A949B807C927E8EA48AA18990
8A99A3AF9693988C738D6C86766279836B896D6A767983989997A0B0B8B2AEA3A0858871
768A8C8689898BB1878D81978D988F71977C72998D81727E6F76766A81878A83A19BA19D
9DA3B491ABB6AF93AD989B6E9F9FA39F9FA7A89FAFA7879DA0A6A2919E989DA2B5B6B190
788A9E97898F97A5AA95A0A39F9892829C9E73707E856C87A8AC9F8BA29A99A3A899B09D
949092A8BCA6AEBEA7779FBFA78F9D9C99B0ABA49AB4B1B4AD8EA7ADBBCA91A2C0B1A8A4
B7AFA29AB9BF93C9AEA1B4ABAAA7A394A4B8AEA7ADADB08BA988B1A08C9496A79CAF8C96
87998DA29EA5AFA4A4959D839199829992788896879681838F88A09C8D94A08B7C8D817F
857D7D8190A09BA3A6848D9391A0A193707592689398877A889B939FA29093739B757389
8CA59C838A8B9E79998D916E828E8F88997E7F7A8F7E84A2A283998FA49085829EA48A97
00267E79888C7888968A96907D758985938E808B93949100567F988AA382A79A9D9A906A
719194836F7B6D718690747E836C557C62807680707671756175986A5970866B526F6B6A
8378446765736B866E806D648264825773867B7A8D7E716F56727C6A58696E637976855E
7066717F815C64807F80694A5F625F655256726A64595F606673667064686C4164586A61
747060594E4B5EFF
FF8B9C8D94A98F808993A0978D8F9D8F978798848F89717B7676809872826C6091939A8E
91A1AB997D98987E7F857E917A8B7D7B7D6A6B746D81777085BDA5BCA8A2B0AAAB8B826A
8278836B756B7B7D8B998AB597949DA2A8ADA089706D747369737A7B9778849C8F9DA590
9FAFA6B59680A4AB7E7D867A9C9A9DA0939DA3AD869C8DAFA98D879F9EA48D8FADAAABA8
9096939C76747A8599B79BA5B39894A78F89796972928A979DA7AB9E8F768DABA6978F8D
94AEA0B49DA6B6ACA59BA5B07F9AABB5AEACA3B0A39BB99790A5A3C4AF9CA2A5B0B79FAF
A2A9B9C4A3A9878A98B69D959B84AE9F879EA9B0A799B19EA69F90BB89918187A3819B97
87948996958C97A7928A907C8D9A9FAF90918699A581948981768B72849395789C87A0A3
8488A29C7F869EA392988791998B9B8C6E9C9070667776839B857B7C7099A28880709781
868B8A81817E908C8B9BA0A19D88859499898D969B868DA5929697A1917B7FA292A69994
5D649F938F7C828F77747A92938C859783857F8A7E87907A857C848A958D788491857C80
6E7B698C688B8B7D7681735E7B83627D8874616F6B78795D82737B8E7A6B767A6E6C7D6D
7553575A5E676F8282878072686B5E84828B6E797F7870517678747A725F66746C785E73
603F65706B795E4C776F605D66654650606360425A7851535C5B666E7B65624A71525A55
666A58686C5579FF
FFB58192959F97AE9788819782928E8E84918F949E729092898386A55B788E8F6FA68F98
A2AA969C919080749B7B7F8192948E73867F6775697775889184AA95ABA981988F916686
7985776E988A907B879AABA0A9868F999BA38D9B6B837B727D75777C6F86809085A5A184
8CBEA6979E9DAFA3898F8B9485969EA3A6A29496B0A19DAA7BA0969A93A2A7B799AAA784
9A8E9A8B898097A2A59F91999E98949A968C7387817C7F898FA6A193AFA9AD9F93A89F9B
98B8B0A8C295A3B2AFA6B9A398ADB6A3B9C39AA9BFB59BA59EBBB2A49EACBFB5C0ACAEA0
9B8C908AA0939B93A8B19EB79EB3AA9BB09B81B2AD90B2B0B1979595918B969F907B7E90
99879E847FA993897F9EA1979DAAAA8B92AC84AB926A837C89A49E9E8C74957E85999F9A
768A95A597918096AA91928880898A7B707A7D858C808A9888938E9067798F92AF877B80
878CA1927B90928F9A79819C8B958C9F8E937895867DA59685859092A5A68C758D699E8C
7889868572878B8394A07993759F887F939D9A7D9A9092A09E869296948D7E9882707D82
886982757D7C768F7A5B65767E956C7A637D76677A5E84656F7B7E7656885F875E746B85
5E6A736B7E87746A6E6B7D6E6B67536D8A6D646C7C7E635565897E717C68595B5E646F5E
685B416A7B66434B60484A4E39543749444D2E5A566D56635A4E575F6B7157796E5F5E6D
6451736A788379FF
FFAEA992959F7381A19382808B9A9480A08A93A38B957F7DA9878F76618E8FA49C89A9A7
7C88AF85856166788B8D9F8174A19A8A7B58757F7C7A888E899091A394A197A09A7C7F82
796F7D8F7E82948B9275AA6C9C8099A8979C96949D927D5B637B677A6A95799D848A9A90
9993A198A1A08F898499AAABA68FB1AF9AB0AAB093A6B9A5BAA380A5B19C9EAFAABAC0B0
819289797789A8AF8F999795939E98A1968A8B8A817D8488889498ACA7BA97989695AF96
90AAA0ADB88BADA9A6B299A7A0A9B6A9B098BABEA9A2BFA8B4C1B3B1A3A6A9AFC9ADA9A8
AFACAAA2B5B7BEB2A0A4A6A29A9E9FA1A8A8A09F999D899D8F89A6947BA396819EACA09F
A3938CA3A4819DA4919486A4A49A939EA585A9A8939392999F9C876D989D829686999795
7E7F919F85005DBA8C97928D7B9487787F85928A7E8F878E927D72808A6D8A968C868A8A
8683899096A68E91A482968C799787A28E8B7B7178848D8292918096998E8E968B888582
828A8478907C897C919CA58798988B92878D988C8D917D7E9C8D8782A394828BA07B8098
778F7F7C8370827B906A6B6F8F5D5680584D6A5B676E837B61866C7E727C767E8C776476
7070817E6B7E675C5F5A74788960636F7D717874796368796C686C6271586B6642526575
6E5D456B726D6E626B667059603A291C28362F4449565F597C6D5E62715B3D5C556C6A62
777B6B6B687863FF
FFA28DA79A8F7D66908887938E9F779090929F988994A48A8A8F94908594908491756F7E
93A688AC6A747D81826F8D7B9A8BA3908786737D71705D958F81A0948DA98AA58C887D91
8380677A7475837A85978F948CA7A59A97AEA48E8790747C604D5B676E66788B7AA095AC
B39C799290879D99938FA78DA9968B979A929DB3AF9EADA69498989A95A18485B9BDA0B4
915C828681758F7C96828F8998A09C928C6D8369727D7B8CA09EA2868C949F9CABB89CA2
9EB29FA6AF989EA0A0BA8BA3BCACAAA69484AC94B39596929B9CC1B3ADB6AE8AA4BF91A5
B491A4ABA9A6A7B1C6C6B0978FA2B792BB96A7A6AC9E98973D6494A38C8DA384A8979B99
A38C837B8C9C969A8E7A839983AC7E9FAA9E6B8A85909D828297B09189718F8085917EA2
7E888F9993877F8A8C86939F858FA58F90928289949F829B9097878D848E8C8F92818C97
78967E8A8AA88BACAB9FA09895A8AC86859193828FA297988A989B899B9390638C95989B
847A96857FA0918E7987A9A78B939187929A81A9A28B9D8993A08B9D889680866A809E7E
7A8A888F8385816E8B9475707F76837185855E4769768B766478667B76665D747952717C
698476786978907B7A7B806079725C4E6A65696266775D6E6A857C7D68577869714E6A68
663961837F6A6F5C4461676435341605000011203F485A5345554C5B5C5273656C5C6258
7B686F6C675F72FF
FFA88A849AA4988A92A5928B9F979B8A8C9B808195A0929FA9ADA57D8CA489899A91999E
998888A28D646C887F8D94A29799849A8583887F736D8375837D839A7B7FA298747D7E6A
8E877F8965907C7A808C8F999C988F95A587858EA57C6D787A7F7F71718673888A92A39C
A294B69C9EAA889299A89B9BADCC94AD96B2A9A5AF9EB08DA1B8A5AFBDB095A295A88FA0
A69C8B8494929B8CBC9CA78C999B868A72917F7D7B7B7F87928D96A77DA989AA7F83A38E
A1999EABA799A7A5A2B2ACA0A9AEA3B0AAAD9399ACABA9AC9AB4B8B8B8C3AFB3A6AC9BA0
A2A594959CAD9CA4B0ACAFC0B1949CA9A49FA5A5B5A79DAF967EA69F91A19C86A4799C96
A1977E9CA8A196979A96958E898B8590958EA0A8959498A4A3949587849680879F93A188
93978F9B97A18C8C819C9A829C9386926FA5959285758B837D8290968893A29199A0A3A9
928C9D78A5998A8F8881859D8D91979F9DA78E8CA98B98B7A99C96788496B594877F8688
8885818E858B907A9883788B929A90959BA3A17C98887FA087927E9885819C8F8096837F
77747B857F6D7A5D74676D746978726A9173686C617775746E7773618072766165767B6D
746F758B826A79686D7265785E7274596D63638B70706D5B8C7E7D857E6C6A6356555B66
7545525F7775555F695D424C4517000000000000304361705A62785F407778676667766F
5F775E5A696975FF
FFB2AB96948CA3859E989F9AADA19399957E867D9DA3B09A99899581948E8D7C84948C69
8795868F8888797678A1A8A2A9B8A0919881656F697871625C794D81A2837876916F8C9B
8E9076888A7E88786F8275766B8892A09D969890918D8A888E89737A7D9884848994AC88
948E999CAF949699A7A6BA949A96A19F969189A38F9D9A958A9996AFB2A6918B9EA7978E
9389977F8B869089A08A93828EAE8A74777B8E727B6B797581A5A4879A9FC096AFB9A686
8EAC90848A899290B7B2AA97B69AAFB1A5B59FACA1A999ADB0ADA8C498ACA99A8C939C99
9DAFBF9BB0A5A3BFB19A9FB2A0AEA1C8AB93B59FAD99B28E9C96A29D96A2AF9A8CA39E7F
A0929D7F9C9C9479939D96A7B0A0888996A282868678919CAD9E92A496A0A6A58B91788D
938EA48CAF8B88979C8C887D758398A1AB909C938A8F8290827285898F908783A19B8589
858D93AD9AB49091768DB28E959D8C8A968C9D8D9B7A7884919DA58E8AA0908B95866E7A
909F7D918E8F9C9A8B77819C8269728D96868E7896929B97AAA6A39292929B7C958E7281
75697671887D8C7D74679A7A5E72697E6F8679785D776E72796873656475756C70738D6C
76817B9B7C717D7A7F746769665B785D727D747A83746F746D7081657163786C81847365
536D6B60686E534F5A613943341900000000000A2C4F4E514E2E765C5E606D4D6E66574D
717D545B6A7C6FFF
FF90938D9A8D8998A397899D7D7A7DA9A0977B7C948D7E9092808F957C8196A07273777B
9C97B188726367698994A8AC8E9C9E9CA08F7F776A7057626D7C685E6C6C7B7F6A758E87
7676868784837B6080807F757AA58D98AC958A8A76968678827C82826F83827679A295A9
A8909DA7A49E96A78A979794A49B8E8A9AA59FA1A3B6A9A69882AC9F9C928890B08DA89B
8C9793858B7492908A9C97999794778F7E60719D8F8D867EA69CAC978EB69A9AA1A2B3AD
8B929BA4A2B59E9EA1AA9FABB1A8AF9CB0ACA9A59DA6A59D98ABACA9A9A3AFB4AD929392
ABAD9FA6A4A8A7B0A4979EAAA3B19A8D9EA086AAB7B4986E8D908D9BB6AC9A849D9C9EB0
A477868A90959BAB9F948A9FA28A898FB19E8B918B898A9888999B7C9A8D868E9896927C
8D9E8B848D7EB08799948E888C96769CA17D8A929E9F919D99898E89867A907E938E8787
96AF8786A3988581957A8C8184A084858273779E838385938C908D7F868898A4878F897A
8989957288978B918C808599738380948D8C838EA59EA08FA38A9F9FA28E738870998298
A480937E736D927E5B7B6481746B8E675F678C7871686A6C5C68555A806F6168707B678A
80849179506A8A7B886E697A7383626E6D6A68857F758367726E5C73618B78786B5E3C78
7A6B674462754F676B694F4F2609000000000000293F6369626250495353547455746A6B
505B7E62766284FF
FF888B928D9793989E958D928489878E918981948B92998989939565797A7E837594818F
918C9CA27276997283929590BDC1B5A393AD9A867E6267636B5D6E646472807A738E7E88
B1A4A3A1A18D82857D797B826978858B7E938B968F907C8261817482828A7E9A8B8C9A8A
99A1A3BEABAEADA5A0A6A5ADA195B8A5A2ACAFA29FA0949E87A6888CA2BDA99E95AA989C
97A991867277797A9387737A8A8A69735A81917F688566938889819EB3A0969DAB9AB0A4
A0A1A497A4AB94A39999A3AABD9EAEA3C699A9AFAF999CBDBDB1B3BFAAB09FB6B2ABAD8A
9F95A8A59390A1A199ACB0B2AAACB4A2BBB4B3A49FAFAB98A499A0AA919AA1A6B6A8A6A0
9698918AA39EA69B7D9779887FA182A5A6A4A08A7D7A7D99888B9CA1A87D86897A5B6D92
85918DA5908493748E967C95A188898F91A29EB49394909A858B8EA693817C8992827B9D
AFA19C829B8FA58E9D8A7D986E79808A8E9997A08681777894A1A49AA0959B948A899F7E
87988B7D8D858891A67589909687849188A2A8A17A9F7E838781A2917C7F88799F958A86
7B727E947880844F808C87916F787A81918F6472756A715F62747D5F5060685F638E7A8E
8F909484776C7E7C81706D807A6C76757664896C7C7B5F736E5B5E75806F5E8C555D7E6C
72695E5D51677F655F45682F1F0A000000000000263C5660605660504B596669725F6469
605E5876655675FF
FF94939298999A8A82929B979D7D99A1838F8B849B938BA9949493A2766E947689868391
7D748E858A777C8195A0939A97979A939F9D91807664687264635B636A7D7687767B9893
88A29AAFA6777E63896B7C8366718C918EA08B74805C61767D787E8A7D9C7D816483858C
6C7EA77F939DA6A3AE9FABC0A1A0AB9CADAAAA92A3B3A29AA1AEB1AE9D919E949DAAAA86
92887C7F707778648574848381949689776D7D83928191A17E9C96A3B4ADA6ADA9AB99B5
A0948A98A693AA91AAA09FAB91A7C3C1B59A9FB2ABA3999693999E95AC9B939BA1B499A6
9D98AAA28789929FA19BA5A4A0A1A5A29CB6A5AFBB9C9D796E97979AB386AAA8B6999586
92B39D909EABAC989192A3889C7D8B818E86888598897F8D9294A58B868076688187907A
A98BA9959581838F9A97A99485917F81807E939490898D897985828F81829D998991679B
928C867E74858C82908F8E68998087957CA390808E9DAF849B84906D8C8F90887F8E9774
66957B8A958298918F948A819196798D9378868964839C7E727B9075599683738776715E
79838072776A6C55676D83677E797F6B65645E4F6457647762846D747A715D6A4B646277
83918A778A7C6F76667068708179745E6872865F6A60787C6C73526E7767876E71765A6E
686D526964646256435E494C312E1B000000000F364D5C46786D5F5E6F6D7B6462726274
5C6C7F6B587C75FF
FF99929D98989F9F7C7F938B92A98B86B8837F8C9194708DA48B777A8D86819A80858B87
88A580978E8878A7979A879D9298B1B68B819780966663675564765776857271847A8ECA
A1A9B7AEA1A4989A8078806F837E797197819A778184858D7F8180848C739D7B8A967172
92A1909D9D96A0A09F91A089869A9C87AEA0B0BBA1989BA2AB9CA1AEA17D97A997A1A29E
A79C947E8E7E6A6E87856872757F7A86737B767B819F8C8D97848CAB8A9B9D9EB1A4AF9A
8D7996A79885A19AB594888EB2A3ABA2ABABAFAF95AB999592A0AA9A9FA8B0BFB9A5A866
007784AEB691AF99BAA0A7A4AAADAFAFB9B18CB0A8A0B88A9892ACA08BA1A5B69C9D929A
AE8DA998918B8795A6919EAD9BAA8B948C92989886889882879275799AA497819678868F
778A8384829D7F518A9CA190848E796E8594868E948F786E868DA0A09B9281AC8E89938D
87AA878E8E84748C8F8381989D978788988B85938C797C7A91898B949C9A9E8F937F858C
92758F848890779A8F81868B959275878E84AC9385A292946E7E84926E7E818466816E67
708B7B9A6F6E86847485615B7163796469616268754A5D4F595F5763565F7C6E87756E5B
9281898F546975626A735E64735D7275496C5E65726C7D526F6D7E686A66675E696A6878
616C6B7F5B6F6B6873465A454A362405000B152C25456260686B667768594B7158676F64
55454F5F556A80FF
FF99A59771919F958C9C9EA083938A7C8F877B9F72818F9596A47B9E8571809094769E9F
918F9A8078AB9E829D84919088979CAFBAAC89808B796C765F5F757D876E848992959F9F
AAB1B886979A9F99A380947F917C7A6A7171687C7461766D7771957B7E8A81946191696F
749F808E9B95A2ABAAB1909BA1A3C4998F90A58F999992969CA68692A2AFABB4A0A59599
9A8C968C89926E82747E897F86848B80718698868C9A9F94A69C86A2A3ABA6918F829890
9CAB8CAD939F98B0CDB19AA69FB5AA9AC8BBB6AAA5A5ADB09BA09D8ABB9F8C9CAA8C9C62
598DAAA89DB5A1AFB1AC849EAD9897B0A0ADA59DAB9A8F9DA58488A898A3ACA9B694A689
779597A69983999CA9AF90B7A0A4BAB0AFB4AD8C949A8B91878A89A2A0979AAE899E9B74
9B718791AD927EA095707981AA8C85859AAF9F91998A8E887A928594998B868C8A7A8F80
8F7A8E93A5A6808E9DA38287817A827670918B9E7A7E7093808F8F90A1B78E8A92877480
83837B768E8499A2877E8985969A737E9DA48B92A6A07B808D73819869437F6A90757691
9480A67C7680726C9876836965806C834B755B634B52656163504F4158746A6D6C797875
818C727B7F805A6B68585850795073717E747357819183877B73686B7F7A76696D6C6957
817072566F67727A41564A60494633213E25333C4D4946525F67767846546E6E666C4A5A
695A6B55315B70FF
FF8F788BA28B869CA08DA9979E8C91909B798BA1849CA1A9939E8D8C96AA868F9794939F
A884957E887E868C969C8C8E9A989A9C8FB28FA29B996B8C7C86756F8A9F93AD94BFA295
9EB2B09F71B69E8A72706786747D76778F5B5E6F625B717E7B7C778DA19269856A868683
6F8673AFAFA69C999898AAAFA4A488B99F9F9BA09A9195B2A5928E73939C95A69D9A8D9A
998C8C8992757D7C7D797C9263708B888082849B9CAE9A9D90A091788CA8A19894979BB9
AE83AE8EBBA8A2B099A0A7B3A792ADA0B0BEB19BAAA3A0B7BD8AAEC1A29D97A7AF929FAB
99A4A5B0A79891BDB19C949899A0A7BBA0989FBA9AB6A3819091B0969493B298A79FA0BE
99B2A9948A8286A4A7AABFA2AA9DA7A5A89F9E8986848986AB889D978D7D8B9F9396878C
938D9091857F8898A57B8A9A7B8B81A48D7E7E837E9CA5938B757E8475909E9D908A7E8E
A1868FA0747F8C779E979E83988A768F918E9F73A48BA3868F939F8C989A9686A19D8D88
84839D737990938290908A8F948881908581A3828E989B909289697C7B6F88878B6D8280
89898D8A756B6260757873886182757271674B57757E627E78768C6E425B4A62697A665C
64706C7F776A585D736B69645F767E535E5D6D83877771774D725F6F675F55596F677B63
7A644B41584E433A2F503F4B6C49343639393C3B623E52676A64604D625546645D564F5C
5268657E696E78FF
FF9E9A9D95A2808AA09AA985A18189948EA0948C978A97979EA2B49FA28CAEAD8B80918D
8EB8AC979E898C8898847C82977F839198718F8B9D738182908E8F91A8A1B79D928DA1B4
A8999E97BCBCB995857E729B7190878876665F614B476C7479947D8A969B8D897A826C88
8A768A959AACBDBCAD9D9998B08DA0A39A9D9DA0B49991A6929392A09E909D938C7F82A9
9CA0A2BC828388847C6982628D3287969285A799ADA79A93A29383B07EA793A0B4ABA98D
8E9193C1A6A8AEA1A1A99A96B5A5B8AB99A09292898C98A19DBD989BA8AC8C8496A08CA7
AF949F9FA195B593A4AFA5ABA399A58F8F9AA0A1ACAF938A839796A3929C979E96B69B8F
9A85A69E93608AA2AEA4959E9AAEA3C0A7A775A18798768A857E9CA08575939BA0929E8D
94A9998D8497848880909FA38C9D9893969A926A6A8F90A7968C789C9AA1A18A999698A9
9CA4849F938B9C9C9D968491957C85A9B79796A1A59FA1998E7B989B979AA89C8F788590
78A16A86778B8E937C9E848979849680877A76817C909AA3898A8F8588867D9099769D7E
6C8D8B7E62766A75647B5F6A686C767C7F5B55756F7E7D657E5E786D6C7971655D616F6D
7D7777816E51836676715C616C68707A806E737D607F75675F676982686D7E766A6F7054
568066675852494B624559614F614B304F3F524943425C696F6F676145756E6A6168585C
666A6F4B70684FFF
FFA599768898968FA07E83926E83938DAA97938A9A9199939689889A999390A28C9B7F9E
A7A395A1A286989B948C8F895D7A809493A262957C687D8B79839CBEB5B1ADB9A695B1A0
A7ABB3A6C8C1B1B9AC8687A27270796F535F4A33546960757F8B8B99857F9F956B8A916D
86837F9899A59D9F97A09F979A95B18D9C83AFA89BB0B59D9A9FA7817E8F938D9495A293
B98C898491999F78777B8D85814D89898A92B4988D9D95A396A69A92A2A2A9AD9AA58D9F
B4AA9FA2A4BD98AAAAABA6B2ACBEA2B3A999BC9E92B29BA395B7BBA5B89AAC99869FA5B7
ADBDB19B95A8A1A29BAE83A0C090BBACA39FADB89992978B97839FB088A38A95A79A9C91
A79F97957B837E9A929DAB9BB198A59F8CA8A58198967F939A9D91908F957C98A9926C8B
88949DA1918A86A5A479818D7C949D95978097A697A58D9E9D9A8B95AAA67C799394987F
90A09295AA9683779E839C7C8D94959A9FA98CBA9C8985936F85A2998EA1AF90829A859B
70887176978393957D90815D808FA69C8E9A87987C949D7399815F6491878F8DA08E8B76
7E7C8A8C7B74677E83735C6584696E6D5E6D7068616E806E4E647D69676E6961605C9176
695260637174757277716D5B6D776D7662708052746C7370718568784F6474757A736B7A
8171585C655A605B6B816A6A7C636859505E4250485F4C5A706A77675C6768443E595A5C
737D6C7270545FFF
FFA88C8794808E9793A69F89A68B828995807679869C9E9D9799A8A59790948F899E9F88
A189909D929EA1868F896F84A5898B907B8E868D6E7D7A709BA2BFA48CA7AA9F949BB399
96A4AE9C9EAAB3A6A6C7AEAD7F6C8D735B50484D424C587A777C7B81969B8F868B9A8D7E
7B72697DA0A1AFA691B8ABB0B8948795A49581A796959BA1A8A99197A09EA1809699A5B4
AC9095B99E928B8D85979F878E7EAAA195ABA58D7E9796988E9A6F887E9591A07E82B28B
9F9FAFB7A9B0A4A49D8DA2B1ADA0B7A99D95938C97A0A391A1B8AAB8BCB0A0A28BA2A6A0
A594AD8CB6A3AB9894899D85B5A8AEA993A29599A69379A38994B1948D9CAA91969D8D89
80728AB19685839EAF9899989FB7A198AAA7709292A595938E84909C95889D9F9F949F8D
869697898A9086A08798A3A38D907F8E9E9998829479859E9AA0A09788848179838F958E
9DA4999B867C9FA5828F87999CA18E968D95998F9C94B08497A797988D98817C969C8B82
87848D8A7E78929F99988A7F7692ADAC939669937F83899676808487888D719290898881
7B7760767E6D828C7A5172787F736576686B6F787D6C8F837B6776794F7F6B7579908361
626146777F857366667C5F646B6E7362727D81608B7C78714E66626C69607A876B64816C
726159563446565949516666725B6064655B464F69746857596F6C5D685D6D605B787471
7764555F616A65FF
FF93A18E7B8A7881867C819381918687918D8C7586718D9383957EA592998F9E977979A4
A6A8AAA087B79C8792A28F82939799859193797C6C8486918EA1A5B6A57D9FAC959C9E75
887CAFAEA6B4A8B0B9B29A8697A78C7C6C694F5246565A7C677F85858CA0958293917E69
70824F99A0A4A6A0929BA1B28789A895979D9491A094999D9491908A94967999BAA1A1A9
95BFB9B2B8B0A18E94978687839AA7B8A29DB09BA2A3999D7F809392896A87A795879389
969986A0A7A8919CA9A0ADA88FAA9C90AAA999BD9DAAA3B7B2A0AB929AA5ADA1B096A397
9095ACB6B8A0B08BA49F8FA194A2A1ADA48E94AE95A2A885A0A283A8A29B8EA3A488998D
99A07B6F808DA1A4A8A8AFA7A0A8AE948D949EAB939678998B6B8D90A67F9E8F9B909C95
93A29386A499B697937A969B908D8997658390899F79A095899E959890918798A58A8E8A
A8919C94A190827C9F9087709D82AF9687958CAE9EAA97AC9C7EA09291968F909A987D96
818C8D906E8B917FA5A595959DA1878688759681717F929183908F8E969E777E9584717F
8B79646A7982847B73808E6D675A765663906E7078897470696A61668162896C7F818078
835F767C74798B7B6F5C68816A836F777363686A526D80677B93795D736B635765586273
6461605D655956556650735F624A5F58666C6458454970607C72734A634F605E697E7968
6A63625B70655AFF
FF9492958E9D9C938C74838D968B869E8A8D99888192A58EA6A29693B69DA08896A69B91
95A1A695808D9499A27D7592879883818F999EB49FAD9F99ABB0A17E96B3A78B96AFB39D
9F9485AD8D978EA3B2B2B6AAAFA7999C6D3F5F4946465E61837C84828A7274798172827B
705B6590A49BB4AF9397B4969888A5A59AA0AFADAF9E8393A19184A6888E9C7B94A49097
A7AEB3A0938C8A999893957984938BA096958BA6B3A089758F8C89788698979B9F9795B5
89A799A1B2ADC1A8A29ABBA7A08EAB9E8EB895AC8983958CAAA98587A89FAA9BACA99FB6
AB99AEA7A3AFB5B8998397B4A2A1B6AEAFAEC896A3B59491A28D96A5979EA98C8F9D8CA5
6A827F95948E827E85A8A6BAAAA7AE9D9698A79C76838179727D73A0788670918694949A
718A9D6BA29483A59C8E9B798B86A2857F7C8C829B9784989B9596987E8773858E9E98A7
979F89A3A29C788A6D9D8E9A84888A90939D908C99998E86937B9088856F978B82808C96
A3A8A09195A29F9B706D9589A798A2ADA29B8C8C925C8496823B8D8F718988798695858E
8A7A837E706771767A7280657B5F67655A506F7A856A63897171737A737390957C828058
7075897470685C9475706E6B86554A716C7E7F59747B5A666D6169667664606A6C797B62
746A6D63545C5B714F4147635F756C684B6C6D5F5F58437555615D516E73596557626D60
31785A6E57657AFF
FF9E9B929099897D627AAB7A72738D8C9E969AA981A18F938F9484A2A08383958C7D9E8B
869A8E98968FB9A8C3A7A09B796E79889E8E919697A7AA9C97B1BF92A7B39FA8A696A8BA
ACCCB19ABDA3ADB0AEAFA2B2B0B4A08B77575358644E535EA279867D7F9B7F8986767C72
7C7F868598A5D5BEA8A99AA3AB9DA6A68D828999A4888D9B99B2838B938AA991ABBD8E90
A1A0AE9BC5A6A89AA27E94A2A9939FA591A2978FAB9B999977847CA58A808F8D9F8E9998
B0A69F93A59583A3B4AFB59B9EA69AA1A9A596A2A58F939289A794999AA7AD8B8D9BA398
88A5A1BFA7969B9FB69FAAA098A5989B97A1AFABA7B1ACA88895989C8D74958D7DA59696
A99A7980907D81949C8EA6979CA0B285A39EAD9F879D8791868E9E949375757A846C817E
8D8695A19B8F8E91838C90868B929B958D99757698A7808A8F778480A086A581809F9EA9
AA97A4ACA2808396969AA071989D967B97A79C8598A9A29F84A97F72948480929FADA49E
7D837796AD8B8C92818A90A798A094898796849384839483776272817E61947F6893825F
7C7D947271878293796B75747B83616475696C60758080787E737E6172776F5F8787806C
857F6E7575738A626377767D6E6763725A4969727E71635D567158596B6A5C716C7E6A70
756F57777245527A504D63685B565869735A585E52704B60557F5E665B615A695B5F4D55
64756567476566FF
FF929D878D6F8478888B859B947F888A8F799699948C8C928E96969B8D899C9E7F7F909B
9C8497AFA2A7A8B595B199A4A48E899E88866DAD9EA9A4B9959D7DA192ACA294999BB8AD
B69DA6BBAE918FAEAEB0B39BA2B2AF9873665B334034517C697588838687776282847F4C
686A8283B4ADC19484A8AEB39994948F9C9A8A9A9CA4928D8FAAA39295A8B1A29C91A894
89B39C98A9A493959093948C95ADA0AFA275A8929382A69BB3978D99919F9AA9BFA58E9A
94A592AAA7A1A99CB8A2ADC7A8909BA4BAAEA29494A0ABA79AA6A3A6B4AAADADACACAB99
B2AA927A9C9C9792969C9B9B989D9DA88A9891ACAA9ABBA89CA69C959B9C93A6A49B9E9F
858C6E88828479968B99A39590ADA58F7C908184978BAA8DA09F9388778A718D9494A090
90928B95B09D829C9A70A49C7C8491977E9D7A988390838A8A9797A191AF867DA094908D
968AA39E8F9D95869D957E8D80778D82798E8D928D9E989D9F8792918F97A298817E886A
A89EA3A07B7E948F8D8884A3A198929E938A938395988B8C8C93828F817C817D84897984
8984906B8C835C6B7D84738875827B7E736667845D726D8C6C7A7A735168625876867395
835F66617C8368896873576B7D79657170565F61646F72536F6267656F726F584E607175
7C695A5B54634872636D63446451626849344140886A63605D70816A63645D6156616740
6A7056726A7162FF
FFA37B927B9B7B9D828E947A8C989986908A9FA19E82B19894A08AA089897D8F9AA1AE98
97878C9493979696ABA29EA29DA49392998DB8A5AA9AB8B4BAAAA68BA6A3A8AEAE84A193
A4B4ACA29C90B4A5A0A8BBB0BAC0B08688826049445B59687A81697E9A95958A98765C83
828783A0B8C1A2BC9DB799A49999A6B0B1959B91A0969D9AA091798C88A992907CA29EA7
909E9597A2B2928B878C989274999A9699C3B6ABB57B83869C8C9F81A2B6BAB39EA2A0A7
A188987C9BA990B2B7AAB1B0B5B49899A4B0ADAEA0A0A7B0B1ADA18E87A6AE9C96A4ADAD
93AB8EAF938A978BA99C949AA3A0AAC1A9B9909183A79D9FB3A688978F9BAAB0979B9797
A0809C97A68B8F97889FB8828C9C898285889899919485A07A7D997D8880927F8E959494
99A79882927A8F859897948E8589877FA285858789747B76A79494909C8D8A95989EAAAA
B7AD9190919A9D9097928D85817792AE9E75787B7F928397A18996858579918AA09694A8
928B96A9ABAD8B8F8A7C83867C82829E7E898F8C968E987A738786937F939882867E7765
709B8494827589768479937B726881646773746F72737061845967675471708B838E7D6A
647A798276716B606D595C8D55677F735F73756C7D737A62635B5863796B755A6A637567
6B616B6A75567562625B45380042565966624F3F60697982626B66645F5D50315B69794C
71667657606F62FF
FF9B7F9D8C8C877F748C8D9794909986849B868B8E86A396A29390A0B0817991968A9BA1
A8849AB190A7B2AD97959EA49E8EA792868CA0B7B1A09D85948E829E889EA7B8AA9BAA91
86A88CA0AA96A7B7C3B2A5AABAAC9F9D8F7A7164716F59646D92758384787C8B8C756D7A
7C83808EB8B7B7A19AB8AE9BB9A798948699868AAD97AE9D8FA2847F8F91857B8C89B2A8
94BABAC5A6AC8794A0989FA2A3A69BA77B958AA9A18B958D9087748AB19EB0A4A7A48286
86A7A2B1A59A9A9C8EA097AFAD9A9DABA3B8BAA3BDA8A88D91AD9D9499A699A5A8BA9AA3
B29AC28F959096A194A7999E8D8BA99DAEABBEA685B2ACB2A7A6ACA7AA9C85ABA68B9DAB
838C8F92948197A8A0A08E9B7B728C7A9899B0A199899E9B9DB6968789936A7B8C93868A
8F9C88B0A5959287748C8DA38E8A8A948C7871A099868F8196A191949A9CA09B93A69794
889D9097827E8F7D9A9F877C878077748B888296A4A791A8857F8E897D917FAEAC85938B
9595987C968C8A98798696879991797C8077848F8A917C8B82976F80758F7E6F877D7A93
96807F7A6682788D72807E737E5E6D6C6E6B737F6A6B79936D707E8D6E6F6981717C8580
678174738F6D847273738377687E5F6B7D4D7C7A726E8164668578677581666F6B77486B
697E776D576A686A3569634E0031626F505F586F767E746A6D425C5A586B666272515E6A
79727173584D71FF
FFA4888F847D98A3788B877296A48E90938896A26F7696A7939B9A808F9EA6989E968E9E
B5B9A3A2A69E9BA07497A4A8969A9EA5B3A4A2A7ACB6A4B1997F7B9F959FB69796ADB3A4
8A9A979D9AA098898992AFB3979AA79399893F605383888163688C736F8A9497836D7864
897B7C96B5B9B2A49CA3B4B3ACAAA895A59A969DA1A99A9EA07D8587A18A8A98ADAF98AF
A09EA09697A5ACAB9CA7AD96A28DA6A38C99A998948A8C8D80847EA2B6AFABABB188B493
8C71B3A1A3A6A6B2ADBFA59BB0AF8DABA69DA3AB90A898A3A6A996BC9CA5A9AE9B93AB89
A2A78D9B7A91AE9CAEACA0AD879BA39DADA99CB3A7B4AFA2A095AAB68E97AB9778938E90
8F8E8BAB9F96A7989F9C999D8EB5ACA69B9C7B947E94878C88918E889779A57F83938B89
876C85977E847E87826789A19DA5A17E7A8E839690A39A908C728B8C9B9A909AA4A3ABB1
A6AB9A918588A4898D82928B838A87A28D9485988D9A8F9A939483858A899589877E9D92
88968392947E9F978D6E7E7D8C846F83978A94898A798E88A38A9482847C7F926E8D8673
85747A7485787C775F88907B696860636F8E6E6A585748587E7F826E6F696A8790827C7E
7C726D7677747C83757670705D6F606E6C64615138617A755B766F7D735B477286716782
565F787080715A71524A5C60654E5C585C67585A556859688273745D76635F6E5C76516C
637C6344644E64FF
FF979496A69FA481888694A1A19CA59D706D87959D9E9D948E87978B848D9397919E96A4
8D949896A4849DA0A4AA9E9B8694958C919C939CB2A1A69E9E9F9C9F989E999F8B988290
9FAB95948DB4A9A095A79FADAEACA273886C686066867082778F819992878D7E7970725B
86869CA78AB3A08A94AAA0A8A9A490BC95ACB3A1838DB5AF9A968D8B829AA0A29F93B29F
B8BDB8A3ABAF8C83848A6B8FAFABB2A1A6B8CEA383889F969EA2A297889FB0B4A79E8C95
8B8C7B9097AD9F9F969EACBAA983ACB9A8A99CA79090A19A9688959EAA97A6B3B2ABB2B9
97B0A0959C9D8FAE938CA086A3A2A59AA4AFBEABB196ADB8A6B0C3BE8EB4BAAD89A094B6
A9A59C869AAF9AAEA59EA687A2A4ADA389899B909DA295948C7E968E998AA6ABA3796D69
8B9BA68F9499907D86958E979E9B819199917E9696908D2683A4957B918B879597A2AE91
A09190878C948076836F95AD8E8189859FA095A1A59798969D9A947A888F9B97908F8F84
8C88A29B959F8E8EA785908079858B9C748483817B998192827D8D8985957C778A95817D
7E8A89837F777F778370708749645C886C627376918D746C8A756263706376747B7E7E84
7A8A8A8A6B6E6B52907A616A7E6C6D6963906A7F60757A707559646B4F605F6C67635639
5D77625E6C6671587350485C624E665B634D656D6B597677636B6E62835A61768583665F
7878515D755841FF
FF9B9F8E999AACA590A3A0A9968E7C9998989D8C98848F768D7883B2929C8C91949F8BA6
ACA498A993B3AA91A99A7A83BE9D9EAAAE9DA196837BA68F8F929CA1978F888A8C828485
87909CA2A0889D839CB3ACA3AAAEA38B6A7F8D6A8986817096958A8E97888581845E7F7F
7E7491A698A7B1A3A3ADA69999B2B68FA8A08FA2A1A0988C8D8A8A949184797BA8AEA588
8AB0A0B08F92AA89818DA1A08A8594A2A5B1A6B59CB4A08691A58BB78B998BA3A6B19890
7E8E9A947998A0A39B9CA08B9DAB9F8E7BA7AFABA8ACAEAE9F929EA28EA79DA19BA69E9B
AFA4B88F9DA2B3B296A078B8ABB2A092B4ACA4978FB3ABAFACB3B6A8B99BA4999C9F9DB2
9BA09E9EA094ABA0A79A8FA1A090939C9E8E94A1A19D8F92938375A47D8E9E8A73888997
847E8A9D9A888C908E929B8E9C888E96837886798279600074968A868589978182A1ABA3
A2A289987D919C938C97898998A872849592ABA2929FA69B85868C9A969E9A828B939C90
A0A685947E899B939F889D8A877E929D958A97909780757A898273857D899984848A816B
917C8772877E617F7584817E667A7A5F8A8259706F627375736E696F74718173777C828C
897C6F807D6687899F767368617F756466616A7A6B686B5E6E69745F695A615F8373746B
67617A61596563616A705F294A58556867615D69655B706872615D766A7A5F7457687871
73675762475E68FF
FF8B889381A39785A28E93B58CA5928D92848F889F6E92988289B0928E7F85A5939F9E90
928C93AD82907C9B828CB1ADAAA19C97839E8E97B98FA49AAA9B9A999788887E8C85839B
829EA46D719493939E9F9CAAB49C919C8E816E6E7D5D8B937D81808B7C95A3877C748776
809F7B8FABB3BDAAA1ABA4C1C1AC94A2AC888C9DB19692AFA984718A967E8F8DA8939BA4
A8A2A295847C7C797C7974787A7D83957596CCB894969094849FB598A7ACB4BAA59A9E84
938795A799B0BAAFA4A4A987A5A08F7C8F95A69294A89DB2AD9DA59893A8ACB7A29BACAF
A5A7A8A796AAAD9FAEABC39F959CC99D9FA7A3A79C8FAC8FB2AAAEBF9CA3AC8FA79DB3B0
9D98A89290A78FA6969BAA99757D8E7D8BACA48D8F9B8C8D8C9D9794918A9C80987A8C92
959D6986A99A938F7E96A096778C83AA8E92A38A98908D7CA7859C9C8A7A838E969FA77B
998A7F918B8D5A848C86868F7BA49A8CA8B1909F918B9D909C96A68D709B949EA590A4BD
A396B08AB3957786898286849D8D8A8B8BA17E957C86848B6E7CA3887B7E77819585726F
798670928C78798F857D756C7873687581724A656B727278586F74608277656B567D894D
6172747F8D66726A616E79696B657D676E7A776B5F325B6382786D52615E517A6E4E7670
6F756E5D536E5355655F5C4A565C606B725A805F6E5D6F6B6B8251526768745556676C6D
856646584E5A57FF
FF96918696A28D967885908A99818D7769A19570858F918E81847B859F848594A0909596
9E9BAD96A570979397A8B79D80839A7C99A68F7D9AA88DA0AA8A708CA78992906C83897C
9C89809D8067A0A99DAA94A2B5A4A6815C737A787B807487929698869D957A8274786A6D
6C8A9AADBCC7ACA8ADB7BBA6AB92A69F8093AD978B9F9D879E8E9983919A8E9C9B939997
A1B2AA96787D70757B7B7183718384877FB090ABA8969A70919199AC9CBEA3AE958D8E88
9AA29FABAEAFBAAFADA19CA19AA4A38C909E8CA5A7A89BAEB89F7B9DA09B9EAAAABCB0B5
A9ADA29FB3B9AEAFA894989E80AC9DC895B5B9A4AF9BABB8A8A4A6A79E97A69BA69AA3A3
A5AFA99DB3A3B0A08997979185A0817BA38A9492878C9E919C9A6E85979D8F91A0858F6A
7C7C829C879B608182709F8E8D879586869AA2A5BC998EA09085A782909BA0A282AA9A97
87818F8F89817F9F98AE9E9586A594938D949C89909D948793A0A07C856C818BA8ABA085
928A8393868F9C978F909A978D97948482928B8D7A907B78827193A08D718A8D79738D84
7F8283766D6D7478928288717694676A777264746D71607760717074697F7E715C6A6666
768D776D63768175867069718B757074696D546465636F8187615E626C7A77594F886462
7D707A6D394C6954706E6F608B6F6A5D595255667C5D6B6B5B4A734B546E7B795F68735C
6A6C4D475D647AFF
FFB4898A8287A7A794AA938D8A9592A195A58F9388AC96848D9D8A6D6F93A69A92879082
758B8B8C959999808D8C8FA0A2949694A39AAAA38AA3A1A5BEB9849493918E918693827D
9695A49180A38B788EA59B97A7B1A37E857D70647D9A988E8B8FA395AB836A7283647C79
76828BACC6BEBAB1A59B94AE9DA8A7A98EB59B9D9EAAB991A3998EA2A2B89192859E98A0
869481768276664B5E6278554B626B82778EADA8B8BAA08B9B958CA2A09D99928BA99781
7591AEB49DA7B5A7ABA0BE96A49E79948DA79FA89AA1AEACAEAEB1B6B59BAAACBCB4ACA5
ADB2A398AF9FB6A8A3B3AC999EB3B2AA99A0A8BA90A4AEB1BCAEB29E9AB1A2AF97979DAD
97A8959FA187919679948C989A87A39998969DAAA0A6A19685838A4EA1957D837C878D7A
706E9B8D7D85817C6B6D99A999928CA2898C7D9B9AA2B39BB4AA938680AE8A7E9A9C8D82
938FA0887D7D8D907596938D89868A967785A387829D8C8A7D86A4958FB49B8D80867C7D
879D708595988C8C928C897C99A0708B828292877D717B7A7B738987727F98978C827771
8877707F846D747683577A6F516873837F7076836D515B65876E717B767F7A78807B7869
8286848A627A7F806074727760756255716B757A586968686B806968614A7063786F6854
66745E416D53704F6E76AF595F6368665857646F595B6E83775C6B636E81664F5A6B5B76
697A556C626B62FF
FF969B8E9D8A90A28A94967E9C968A82AA90B0A0838782A186AA856779908B83859A8C88
839A908A848A828AA1AC9E99A182928F989F7AA89C968EA68BA8BA98918D7B8D848AA28E
7FA8B79B869EAC9D9B96C4A9A38B9E95787367777588919B8684AB97A3998A6C5F7F7F65
958FA1A4AFB9D2CB91A8ACA3A5AA927C99A1ACAEA4A6898F969290909D94A285958D9089
959A81734F5D6E655D4A3B4C5D63718879738C948A8881919DAFA29A94A49CA3A1779C7E
A48D819FBAA49D8299A8A7A79C99AA9183938CA0A9B6AFAC888AA990A9B09AABA4B1A7A6
9CA4AE989497B2BBB5C295ACACB899A79398B8AE92BC97A8A29B8AB3C2AFB9B4BE949EA1
A2A784BCA88A9097AC977F7A8794B5978BA795A1979D919B927A838B888691988F7E9B94
91879697A59F8C8E957C93969FA08B887A6CA5867E95A2908AA0987F747D8BA78EA99083
9A8DA087988F9593A08E948CAFA4A3919D75838EA27C869B86929E9991A387A47383958F
96859A7F83909497868E947B838F9B877D957F8791948885808E887D9B9780887590886D
84957880918674898A63848B576668424C887F7271836C8170747071856C6F857A8A6D85
716E7E8183837F775F73736E77726A7362767676765D747083695E597A66406283665766
8474796F6185848055725E777A64606F6F6576635569746160485769517B79717F6B737A
616863796B7952FF
FF8E8BA281979E7D9F8A818B959E87978F94728E8370988596839674807D97718596869B
8D8379848E939F9889A799948F94848C9E889A9FA294978CA2828C8D7A777B8E87769995
8B77968F7E927F93919A899395998D8672836E7A8A86999C9CAD969A939282647E7A7E90
7C8F9BC8AFA79ABEB8B59DB0A3BB97997A9693806E95A3ACB3A498AEAD9A7F849CA58885
7F6068685448506371544E6B5D43456075736B838CA398A890A78DACA29C8FA3979A8274
80AFB48D7E9F896B7CA7A0859D9DA294A1A2A19CB18D9C9BAFA38E939E93A9A9A7A3ACAF
AEACB9A1A39AA3B7AE98A2A8A68CAC9DAD9795A2B48D9CA49E92BDAF9CAFAD95ACA984AF
A098899E819D9A92AA9D979886887B8A939A98A1966F888E8D949B867083888E8B929492
735F99968D8A858B898E8C908A9D9992A9A6A77997AD8293A08D818A9697A0869D9D9CAF
86958B838E8F705A828CAE8E8C8E8A758C8B908C79A38AA295A991AE9E917B978C988687
85947792879690908B7F9D7F8180687A858B9693837D738A758A7B7A9B817D9592776470
7F68807895707A7772787E737E887A8879535D51746E6B7F777163668D6D797B8361877D
688F716277646C7279735D565E4F6C6B5C635B6B827C7D6F605E8A76644C585D6E626567
7267655F74775A517877567467746D686E5F6367516E545769765E5E5571767D5754606B
434C6865654E4CFF
FF9DA8AA8F8F7CA297978A7A91A07E9C9F7B8DA394859D929A9F86A18E7B898F8F938290
A0738F8A888D6A99A09284A08C977F8B6E907C81A28C9279909D947E8886978089A68FA2
A79C98B28E988E9F949B87A1848B867C836C868F8E7D849B88969990888F89738085777D
95A3A9B4A0A0A3ADC3AEB1A5C1A0B294B1969A8CA28E957C8FB0B2A4ABA8B3998B958581
7C69664A63655A325E65636E75546F5F6A705184A69096909897B5A09D8A9F888A87949A
9E999D9FA2A596919F98A79993999A9F8A939A92AFB49FB2B299BD9FB1A49F96A08CB39D
A1A3BEA4AEAABB9D88B2AB97A998AD8FA9CCA4B19CA4A0B1C2B9A9C1B37DB3A7A495BA9F
9F829E9AA6A08D9E96929196AB879285819F8C8D8296948782807F808D9677759B9BA789
B196A3A09F8D9D7B7A9DA9A5929588978E969793998DA5A29F979DAB9A97959A97AE8085
A5A09E9E80B393A5948775908A95948D90788D9C9C92968C8066A597A1868E8478779276
817E808A937C8D737889838B9987827E796684807E6F5A77948CA993817C808E85886E47
7986707281898F8F7A80826E6560867B764F577082817A78676D77737877517E616C6B86
8B648A88857B7172656F7A737F5C768C6C5B5972606B7A5B6D61625357695E7062707170
4E655E6862605C5C6B725F65796173606C62805662618660696D544A454D6E6C5A676A69
5A515A50685151FF
FFA195908DA1888298A49989919F88998B898D928E938CA38A9B8FA69E958F968C8F92A8
A4A4928B8D8E807692898C9B7E727399978C939393938F86978D8DA1876E886192A2A6B2
B09C9FB3C7A092A784A6AB98818C9A817B7485876E9B8EACA38E9D92A69B8D7D69795F7D
7B90B3B4BFAEBCCAAFBFB18F9DB7C0A9A6A9B0919BB3B3C6A98EA6A59FA2A5B3B1928889
75645F577A7762596A65776B676351664A6F5F86A0838FA4A2A48AB58FA2B1B18E8681A8
B1B8A0BCB3B2AFA0A3B3A5ADA2A998AABEB3A4AFB29C9D95BEA0B1A7B1ACB6C9BB9E9694
A2B48DA1B5A8B391ADADA4B7BBA5A2BFA8AAACACA1AFB5A3ADC0BDC6ABABAF9CACACA1B6
9598A598AE9899809BA29B9B797389B79481919DA27E84A28C9681A697939195879D84A4
7E9E488D8A9B918C9A908699A2ABA0929F9DBEA89EA9909098ABAEA8978B8B97939F94B9
AFAC8C99927D9597AFA2A99B939AA78A8B7F979B90919DAB949689988C918279849A918B
9D9971978A9987AA9CAA918D8B94848886A18C8D7B6B898A4F8692AC808978999A82A789
888585787D86898B8B9B667262746778667A71598C678269777E7D9A777B6D767B7C5575
6D726F7E625B786C8173837A6A5D767B9B9263737B766E86848C5E7073718176916D7576
7580576F6F577265694A7178427D68656C75707C6A5E7152666E5E706D6C6B7066685761
6B6C4B5D6E827DFF
FF8E7DA19BA89E8F959395869E99A77694AB868A8B968F8E9074A9998591929082778998
A896ADA8947786856F9A77669772758D958FA398AA9796AE99979B8C87767C8681789DA6
AFADB388A5A4AD927EA49D8F8C96A1858A829F938B8A958B8D9B968B9F807E847B718977
86AA99B7BEC0C6C3AFD3B8BEB39EBDB198A392AF959C9AA7B292998A9CAE9899B8ACA394
7C6B5B5C615D81806C9073787A7D6F78736D69647B98919895849FA8959387979896A8A1
B09EAF8AA6AEAEB1859C9CA8AD99A5A396A7BD998D9C9FADA399A1A5A7B4A4A59CABBDB0
BDB7A2BCBDA8B0A49BA0BBB1BDBCB8A9AD9FA9C1B8A0AF94A9B4BAAECEBEB3AF9B9FAD8A
A8A0ABA597978D9CA0AD9AA38AA29F90869C889BACB4A5949675967B9A9A79909BA8B09D
9E95859B9AB17588A282ACAE9597A5A1A9AA94909997AA8C9D979CAC8DA18D959D8F948D
98948F8F99868690A095969E91989EA1A3AF8C7EA08D888B9E6E879E91868880878B936F
958E95A09D8A979F9188898E9398817C8E879693778D61858A99808E948B949581887484
6080688A916C7972947B7B6A6F81648494887C67857F6574827A797893897C5980725B68
77717C726F75768A74788E6F7281795E5D7370546A6F826C5F586453707F7A6D6176856C
4F42585F838F576556787462745B6778626B60736B5F5A604B40616B7581685B6E705149
665B7055425873FF
FF9E909093989A82AA9895937B7F7B899B90849581819C80A3BE92B19595788E8A829497
A09592A278839180938C8E817A697D787F9E8FA6926B8B8DA6937F677E6D5A718B6D9F94
7E98A7A39A8F93A1A3948F8CA4A4ACA7959D95918E78719B878F939489A5A390898B8083
829298A4B3B9A5B4C0B89DBAC8B094A0AB94A6A7A7A497839EB7BF9A96A39C8CAE948581
7B6B637C5E6B6A7F978D9F8C9C8262787179635E6A7CA08F9E94A095969E9DA19C9E8DA4
B3A3B39EBA99B2939B99ADABA0C293848F9DA1B0B8B0AFC39DA7BBA4B2A6AC93B6BEB8B6
97BEA4B1B18AB0ABB0A8B7A2B4A0C1A3A39CAF9EA1D4BAA8A3ACA2C3B59DAB9BB0A1989C
A7A89D918E97998BA4ADA4A3A08A907E939E8C86A7AD8B9D9F82A393A2949998AB939BA2
8F91A29D919887A69C9DA5A0BA9E9F9C9DAEB98B93AB93C391AD988D8F97948F7FA09A96
9384899BA38990A2AA988199AAB2988DA298918A8AA08A99909C906D938A798A7F8285A5
947D949E73A6AB8D968F8D7E88A1919C8C8E827A7B8395A198797677807D8C83805F8070
5E6B8C828F6B848F6A778275676C7A88806D767768628084776E8A7C74787D7873637158
817E838C8A727D5A7E71698C65687160517259676C7A675E5A6C535F7B5F666A706A686A
7273747375756671535B6B6B748D746F6571646F5E3A5B54645868625C5D77495F5A6F6C
63655770896C6DFF
FF949D8E8D9080A085A39C9E9A9C8788909E92817F7E85A3AD8B9188A2AB938D628E899F
AC988F91867E5E76757E6E785149729695958D9C9FA09A9683929687777A606F8C98969F
939C9698A59C94AB8C93739874A08D8E8B858C8D9A99A1A081869FA28A89A47370888A9A
94ABABAC9AB0BC91C3BBB9ABB4B2C3B7A5B9AA9E9579A9A19DA7ACA2B2A8B68C908E7A8C
65526F6F7E7D959788A9B6A7908A8B798F5F6F71737689969AA5B5ABAD8EA4A18B9BA395
9DB1B3AB9BB19DA89CB380879DA0A0B5A0A0849BB1B7AEB3B7AA98B5A7C3A7ABADADBAA2
A9B59EA2A1BDB8A4B8B0A8BEB5CBA1BAB5C3B8ADC5BAB2A5A6C4AFABBAB8B8B0ACB4A4AB
8BA0999EAB9DACB89BAEA1A183818A9593908F9C877D889796918E938F988F96819493AC
A4A29AA6A5A098A9959E959F9A9B96A8A3A286A5858D8D92A2A9919C8F9A8B8AA398A497
8896A6A8A4A9A18B8B8F9690A6A284907B959C9FAB9C9CB17F969F8D6B839295899D9782
90A7A1928F8D8E9B9D8480869B91A092778982A1929D8EA075707C8786887579968F8F7A
768A85876F85718A8C8B6C7487677F8C705E6A8E88807D8F7A7C5F8965807B7A776D6882
85707B7077537B6F75625F7671765B7D70696B5C7171756F665C5978754F887964466669
666A6B7261596D737D6E585C66667E6D81656C6A9363886C6E82685E765F635A515D6E51
6365727B65525EFF
FFA09D8C948988888A9695909C89A78C8180927F84928E8D958F9993878D9C92988DA09B
8F886A8FA06B6981745F656D58868F918B8B6D70828A7DA28484878F937B8A708A8C9EAC
95A09EA5AF9CA69589A7959F9D8CA99E8E8E848FA69B8B87A89B8BA3A4876F836E898F7C
909CC4A7C5ADADA0A4B8CC8CB0C4AEB6A0A8A9A3C5A3A48BAFA49FAF99BE9CBAAE7E846E
745D4E8371739488BDB59A9495A99697778E6F737380868C86ACA19AABC09C9CA59FB4B1
BCBDB1A0B5B199A499A6A8A991B1B292A0A8B8C18C919CBA9FAA939C908FB0B3A7B0AAB6
AAADB49AA8B5A59BB2B4CABFB6A58CA7ABB2A99AA3D4B4C8C4AFB7C0A095ABA8A6A2A1A5
ACBE96ADAD95AFAAAFAEACAA89C1A0968D778D8FAC8797AB9D8D8F8E9F868A809A87909A
7F9F9392907D8C9D9886989DC19694ABAC92999DA29EA59F98A39DA3AEA0919C998997A2
9899A0AB9F9B96A4A99A969D899098808BB3A4989794909B8F8E8493938F92699E95949B
989A867B5D7F77859498838786948A8E968FA18598898C848C9483907A8F87886E637173
747483757B9086868C7282786C796570888D6B6E8276777864705E697E79698D65747B5F
626D7373665D68687C6280698E6871827369646E62536D61705D656954776C6173756961
71686F5F6C6C5A6C648175707A726F6F5963769AAE6D546876646F724945756D796E5D5B
6875584E527768FF
FFA28B868195A5A39A97A3A1919699A59379888B9188848181ADA4938C89A4A88D9D8189
6B918587727C6779755F587B6177787BA28E7D84848498A5A8938881838B8C7B8284A896
9CA5AFA7AAA1959787958E898FA291A593A1ADA1A08B77AD94828E8F939583906F908991
8F9E98B29DA4AEAEA6AA9DA1B7B2AFA6B1A1AEACB7AFA4B29E9AAC96A19CAD979B91996E
5D7174758185A7B4AAC7A2C6A89C93788059777C788092B0B3AAA0A693918991C1C2AAA5
A7ABAEBB9B93A08A8C9BAFB3B0A8B1C191A9A7A7C9A3A9B0C2C4BFADC7A0B1BC98A8BD99
A8AD90A4989AB5ADB6CAC9B2BFA7A5BABDB8A4ABBAB7BAB59C98B7BFB3BCC2B3A38CB1AD
979FA68D9D9699A08993A489AB82B292A596A6806E8E9883A8A58A9177969796A0AD948C
91A2896F7574748B90B399B5A1A0A0949092C6ACAFA39C97A398A99E96A1ACCBA59D89AC
AB90A09BADB17CA297A0B69B90AB9C69A0959C9293AD918E75697CA58E8097998F719388
9A8B8B8D7B9B9672AC73668B91838B899E858083A0898A7777708C959F7C8D8083858191
8C7D6671696E897E67837A7C757E736A6F70767F77767A797F9387876A67897B81737177
805C6B786B7B7D667363826B5E666B7E986F6D5D776674717053666E7772707A735E5A63
6F73676E685E7476807176717B754C74675782B8737C737267606C535C456A6D785C5064
596B5473495D7AFF
FF9CA299869A8C878A948C928F8E9EA69586888A8CA08496A4A093A1967C6F949A8B8D7D
80927C817B75856A67726B7780766772616081889D98ADA9A28E87827F9E8DAC8C7DA4B5
9EAEA1A1B7A0A191938D6F8D9A88B7A5A8979E939B869090988FA094818E89A0909E989A
96978C9DB09EA2BDA5A0AABCB5BFC8AA8EA8A5B8AEC5B2AFA794B793B3B2A299B88A8682
75656C687892A2A1B2B096B5C1A69A9D807550535A81849FB792ABA799A9739AA280B4A5
AB94A4B1A391AFA4B5AF9B95B0C3B6ACABABAEAB919F9BB0A293B4B0A6BA988E9FA4AEBE
B5C8C9AAAFB9AFABAFAAB5B1BA9DAFB8A87E93B2C1A798A9A6A7B9B9AAA9A9B2AAAC86B2
A4999E9FA195949EA7B190A89593908F9CA7A197969BA1B88FA5888C928383A4A59CA483
A5858F85988691AE9F9FA989969EB79CA7C48FA5A39EA1ABAAA2989AA8A6B295A6AA939C
A8A582888695B7879E9C9E9F919278828D8C75969F99AB9B8D92949E8CB48281678C8282
9397979F8A977A8A8190939096A8ABAC94868A8A8C9392AA888596958D7C7B927B869372
8A859296837C7872638C846D8383745C717B677A6E667066627B777F7C84856F836F6E66
807D696C7C80776A956E9079737C6F7B6C5E6A695B736280746E7878767E545D7379796A
616B77726C6A6D615E6154696174515F6B63506164677569615A616F6C65566D6A645658
66596E584A6172FF
FFA68E999E879993B18B9E9D8A94986D848F7A7F886900889B858F878C91878698979A7A
937274876A6B6165586385798271683C6B7B858379A5728F98A1927C6F8E727E9A87A7AF
A0979DA07E9CBEA385927C77939F9AAAB0A3AC7F879D9D7D8A8D8495A2AE878A9D8BA58F
928A90A3B3C5BCA587ABBBADB6ADC3AFADA5A5B1C19EA6AECBA8A8A8A2B08FA09A858B69
7684796F8B779B9F86B8A7A8A6B7A0848790655B737E9398A5B8ADAC92ADA5CAA7A1A894
A3A3ACA5C3BCA89B91AC9EB1909B92B8BFB0AD9EA3C4A5A0A3B4A0B2B0B28FBFB6ABA59F
B7A1BBB3A4A5C697AE9F91A8A9B5B18EC2B1A9BAA9C2ABBBA2BBA5ABAF9D86A0B991B6A5
B19D91B3888D8E888CA4AAA4B1AB89988E8C98A68F8591A69D849696948D83838FAA9786
8BA18F8793A4A58D87BBA4AA7EA198AB9D9AB697B2C4AFABA4AA999D8DAE9C9599A79789
8C9092A18A8A849096A58E8B937EA28B837E7D90838D9188A08F8AA8888F859E9B929786
9A9E97989AA1948479848782857D8297A08D79988D857F858B827C77776F71737F79A078
867688778B797A92776670787562704C767A7E636E82776D677A87848F65897A656E727D
8080857E67787B6E696F5E697466697A787A835C7266776A7869698855637B6C67718F75
736274746D796071787555677565658778826B706674796F54666A58645E686B7C716954
4B5C697247696AFF
FF8A9D9786A39D84958D95AA938C8E6878947A94956B60889D9D9F938C8F8797AD8C9189
757073517C6758765A687385676573707F5E7E677590916FAA9E978F9980936E6F88836D
9C9F95929BA493929588907294B5A5B0A7ADA1929AB0A3847A88A18E8EA498959D98A0A1
9A899BBCAB99A9B1B5CDADB3ADD0B5999DADB4A0A7B0BA94A1B3B0A894A58B8E87927078
67786678988EA280B2A6C1A6B398B0998362646D5789719890AFA295B5B7B09E9D9C87BC
AF989BA6A39191B2A4AFAE979B9C9AA68BCAB2B5ADAAAFA6AC9CADAFC0A0B4A4B0AAABA0
A4AD9FB398B3AEAB9FC6BFABA9ADBBA5A7AAA9BBB7B0BAA5BDA7C8C8C2A6A39D9499A586
AAA09C95B09E9987AEA3AEB2AAA899869FA69E9D7F9A8DA08F9CA38B936C95938AA98C9B
978FB191968C888C9888A2A989A1A69EB1B499979985BAAD7E95969581A29A8E7AA3B3A5
A4A69E91949EA29CA09CA6B49C9F926F5675999991A7949C8A9E827093888E9D9898999A
93A992A1A5A0A57E8B7F91808E8273A49F8683888E8B7883938D887D77918E8D978F8988
8A8085907C817B797C7B7E626F66846C76787A84716F6F715C7F5F6C626D6469766D8170
757F7B67815C686F6D86887C7D7673707B6D63617367756E7F7C72478883615F7A756D75
65746279826B73585E525C78847E7265736B75626E686E547368756D5D67737067576466
6A6B5A5F6B737BFF
FF999AAE9A768A8F8F8E8E909B937594927A9688748A8C7B8C8FA79D9B98A08B9A988C77
736488766F7C7C5563649B527C7F7C70554E5D776F6E96A2A1A99580917B7F8A9286788A
7D9B998B949FA884969B89AA9090B1A49D9F9A8683899C837EA7A1A0988B8CB68393998E
8EA7AC96BBBBC3959397B09388A0B2B98297ACA099A088AFA593A0ACA2AD8E47948E7D68
7D4B647D807A90939BAE97B2B4ABA0A077708B777B7173859FB6BFB5CB9DAD90ADBC94A7
C1B0ACB2AFA5ABA4A7979DA59BB1A09BA592C398AABCB3A6BAB2C5BAACCFA2A89CA1B5AB
969094A8A89FA187A6C2A9ADA5ABC4ABBDBFA9A99CBB9CB1BCACB4D0B6B9A2A8A79EB6B5
A6B0B4A4879A7D8199A0C4B2AB8897949E8787808E94A492AEA59C989BA7A5968A909A88
7E9698AA9F96A77F8FA1A6A68B819DA19E90B3959CA0A29A87A99C98A4A598828D829A88
9AA3B0998395A699ADB0979A7F958D7D858AA7A1939D9E968E819C96908A969E7D958897
9B8A94A28B93868287877783818FA17E8B939986847E909389847C7FAA6B7E737B7D7F94
7E888D7A7E64747280816E667C666A626870695E6A647D7360697C776486766C6F788785
5D886B75764F607D8E6E7C546A737B7A7B645460747771777E6361715E64587C4B835C45
6A87727875687182617C6B545470617F69625E606A716E588A693F4F537165776C7B526B
6B716E6D756779FF
FFA2A8929D95A09D988F8E918E9CA09399888193849774807D8D9C9685889EA38E806C6C
7A6A4C5F5A6C826D76706E7875806C645C585D576F6D7D989996928F8B8F777B6A857E75
7D9990868671897288798A8B9CAE6BA0A3A47D6593AD957585787D8C8D87977CB1BEA5AF
AFA7AAAE9BA9B1B28AA7C2C4B8AABCB2B29CB8AEB4B4B59DAFADB2AE9EAF95B5967E7D65
67745C7C729B9998AFA983ABA7887D778362666379727EA19DB6B6B9AEB3A8ACAAA4BC9B
AEA2C0A398A098A1B1A09C96908CA29BAF9BB1B5B0B59AB3AAACBE9EC3A491B692AA9BA7
C7CCA9A1A7AEA4ADA1AEA1A29BA2C8B2B9A4C99FB9A7BBB28FBBBDADAF9698A9ABA0A9A7
A2AB9BB4AAB29694829988A2949F95A6A29373889995AD84919C8B98829197849196A38C
9CB0A7989CA39995A58CA69DB8A49D9F9A9EA48E2B8292A69FA39AA17FA9A380A49E9EA5
A59C96978D8CA7A5B47C7D8F8A8A8095A6947B97967B81BCA48D867F9EA29A9C95979A8D
8D8A8B919A907F8872738D8C8198918AA39092957799A397966E54789295827B78898B86
998A7084676473897D876A7C726978885E7C54476E83867F96827B8483796B7B71756475
857B8088767A7E76696955666344646969725D636B6E82726156585B657268716C676A63
6379646E5D7B79686D66706275754B636C6D69737779735D6F655A555C69608379695468
6D59756A73617BFF
FF9B90A59BA7B09E8FA0AC9E86968A91A299938BA39B93859B846C9586847E9C9E8B777C
686F61635E618669868C77838E6D6B69615F5449505C82758F839F95978C81898E7D79A5
907A818775A19B9CA288899B97AAB096A1A1A194A789928B999B9EA3B78F96B4C0BAA9B8
B19DC4A6AC977DA5B38ECBB8B0B593B9A99CAAB9B0B2A5A2D1A9B7A4929EA5A1A8A9868A
5F7375687271908E80909DADA09C81856D576F6C7D7C9D9DA8B1C6AAADA0A8B0ABC5A0AF
AFA0A8AAA5A7A2A59FB0BE9FB0BBADA2B0ABA6ACB8D1B8ACB4C5A1C2BBB0B5AFB5B2AEAC
898A9ECCBBBAB1ADCAAAA9BEA5ACBBC9B6B1A8B3A8A8B3ABC9B8B7CFB6A8AFB7B5A0AEBE
A8B595AEB6A1A88E978EADA892868EA79894949F9AB086A187A79096AD8893898C849797
6B8D9A9E99A69CADB19287A4B2A697AB9191B2B2006B85A0779BA899A290A99E9995A789
A6B59A9AA291B7B5A9A4A89B98868C99889694A2B5A98E86A89B97928A7E8991A08DAB98
8DA795A0A08F917A828D848D80757596928AA37A8B7658806C87729080977D87829CA28B
7A82A2817D79A164817187717385868F726D606596947B6E7A76796A7B67706F7F796270
647B63805986847E777A57603C785C657550005761836A6A756765758B717D7D66737B6D
7768767A70737459736061896F6D80665C7363698846666468725A6E715C617D726B6D3A
5E5B6E6C7E5880FF
FF8E929AB1BC9B8A9F8B988F99B09E968E71948C85927FA092908C737F8B7F95A2866A69
60606A56425D69817885769A808B7C5A72555D4D69818D9C9DA1A0A8AD8F8E9BA88A9A8D
787D8D6C727C979494AC90A9B5A5BBAEAEAA91A0AF7D95898BA6849E8FA7CBC9AEC2AEAD
B5A4B8929BACA0BDB1BE9CB7AE9FC8A9ADA5ABA8ABA9989AA8B5B7C2AD97AAB69097A088
707564525E6F71838C8C907E937A81716B646369839A948DB3B8BCBEA7B0BEC4AD96A7B3
9AAFBA999FB09DA58EA7A7B1A9A5B7AD9BB5B6AFB3C2BCCCB6ABA6BFAD8FB1ABAAA3A299
490097ADBAB4A6989EBD9BB3A89AA7BBA5B596AD99A4C4C59CA8C2BAB0A5C0A09E9DBDB8
B4A7B5A2928B9D9F918BA091A5979A9399A390887896B2A199909F83687F7A8A959F9EB2
92A4B6A094B198A2AA9CA2A89CAFA5959C8E9F98A3A9A89C8D918A969A9F8D979EA99DA1
94A48C8B95A0918A8DA4788E868B82AEA0ABABA69E9993A09A996F9AAD7D9199877A89AD
9BABAB9F9597898F6D6D867D768F979D84838E888F846C8687648B6F72817C706E847E90
836C7B7D76766A9A99968A737D64937E807572896885687A637C6B6361687E6C9281968C
856F743B6E627F817274647449777D607A5C6C61667A886D69945C68687960826A624B74
6F7961695A5B745F5460688177836B5D6F6D7E5869525D5B55556B5F72476562735F5F72
5B62697F5B687CFF
FF9B8E93A39D90A1918CA0A1AF979E969C849E74838D83A59F9F867C7B968D8B94927268
715660606D6D787C8887938BA3897F5D5950485A5C586B979BA98C99AFAE9C816B8C98B5
81937985817A938E827EA9B1A6AB8EA5B67D9B8A9C848769A0AF8FAC97A8ABB4B3C3CFB0
A697B5B2AA96A5B8AD9ABEB2B7B0B1B3A0B0BF9BAA9CA3A9AFA4BAB1BFA8CAAC979F7B91
74817B6B615D635E758781776D6B6F606765897CA195B9B2AFADACB3A6A1A9AAA1A5A4AA
A5A9A694B2A0AAAAA8BBBBAEA99CB099ADC6A1BCBAACACB2A6A7AEB4B3B7B8B99C909EA9
8D0AABBBB6BCBF9CAF97ADB5B2B7B5A4CDA685B5A1B8B4B2B3AAADA99FBA91B7BEA9A1A9
94B0AFB38A9596AF9B8CA0A294939CB79191A3978990A6A87C9B93858A87829891908494
9A9093667E859DA1A4999CAEA191C1A9ACA4A0A9A79C96957F87678188A88B90A28AADB7
A5B09BAB9C96ABA1A491889491887F9495839FBE9FA0A1B18F8CA7AE81837D8B8E947787
9F91A7A1A68782758A947092957397978B598F83858188857396919A898197847D797189
6E85937F7E8286837E7B7C7C70827F7D6F747B8F707576668D71707C775E759187785380
726F687C7179747F697A744A577185707A7C6169817670577D5879597A6D7D6F6F5B7D76
83657C7B6B6A7A666475827A7D7B7973846B725E6B62806C845B75755A6360665E6B5F67
66695760626565FF
FF8BA995A9908880848B6E919382808D98A09C9C93837E8C9C957A7782957AA299936051
52485F626E82717A8378858171A789645C64565B4B608A94A6A3AB97A275A6968B958E86
99718180848F96A6809A94A39CB8B3A6AFC38AAA9A9C959D7EA0A49B94B5B5B8BBB5ACAF
A688AEA99AAFA3979BA6B1B9A5BDC7BEC8BFBDA4ADA2B2B0B7B5A6C49EA8BAA59C989E82
928A71666E6C635A73787A6754646E7769706C8181AFACA8BDC3BFC0BAA9BAB9A9BAA8BB
B2A0BDA4B69CA4B3AA98A3A0A48C9F97B6A2AD9DB0B1B58DA6A5A0B0C3BC94A7A9A2A5A0
9CAEA1A99DB2998AAD9098BEAABABCB5B79FA8B0ACB5A4A7A8C5A9A2ABA5B7AEA9AEAAAE
8FA2B39F9897A5A2B18A91949298A9A89A938A898E9C8DA0AC86889F958D9C9498958B97
8B948E639193929FA1C094B0A4AEA5BDB6A3A6A3B1A997ABA3A680989D8EA79B9CA8A0B6
AC9DA2A2AE94989C95ABA4988AAEA5959585AB9485959BAFA3918D988998948C86A07AA2
98879C92928B8B657C8E868792888C6E7A667B9A8B7C808C9D796D63938C7F8F82788285
948D7C907E7C8474809175896168638064645E66726E626E78618572688C686064626671
7577665D77656B67627C6573778268686658746E6679736B597D75837D5B73698059657E
6D58665B746C4B706F765767636C6C716F7F5B736A5F5E7B4E7E5F676C60546869626E65
583D647F575178FF
FF8F89A9939E8AA38B8F9383947D8D8491B794919D8EA19B8C81838E818E8F9AAC86856C
4A595A695C8485618C837E7D94907F696556685131677B8FA4A9A79F94A09B96938C8F8C
9A928D7A8D8D87AE9D8EBDC6AFAFB9A9B2AFAB94C0A99B9FAD84A89EA8BEB7A7ADA1BBB3
B4AF9A9CA0A499B6A6BAA69CB7A8C0B7B4B5B6AFA9B9A0C4A59EADACB7A7A8B3AFA2A696
8D858A5D71676C66594D5C625F627071967680A4B1A9C5B09EA09BB5B4B2AFA4B3B29E9D
A79CC1B3A09AB192A0AE90ACC49FA8A7B3ABA59EA1C698B0AEA76216AFAE9D878295B1BB
BCADABB9ACAAACB3B1ADA7ACC1B7B0B4A4ABA5BCB3ACB2BEADB4A9B5AE9B978C8EABB1AD
9BB3ABBDA6A6A48AB0AAA593AC9298989E8F84A09E889BA994919088848F8C9398AF9095
94889B8E8CA295A7B9818B7CA1AAA7949A9E9B99BA8CA0A59B98A792AB8D98939CA3A590
8D939293A593A189A0818A91988E8A9A8E939A9BA0A8ADACA1837C7B898E81938A787F88
8CA9938979928E8C969D9299848D909D95458C7485897384759C8C808A93887C94958D94
8B8E99858E80819884807F78816C787F827D546C826D6D85727D6E60885D89837C7D837B
60637D85677B7A6C71727C735E546C68775B5B4D77686B5E7375505A7D78685B7C727180
6B7D526C68714C58686A7363675C6F806F65714665534357534C5F536378896F59757668
6F66786A6C575DFF
FF8A9689948A9EA29084879891A3AA9FA1898E9F8785878C95856C7598A09899A598707A
5F624B507982737E91959394A898906D7F413B5E5B58817088ACAAB0A2949DA6869B778A
B5AF8790A0A6B39DA49AA876A1B9ACADA9A3A2A1AB8F919B85AFB8A2A3B38F9FBDA8ACAF
A09CB29E99A6A2AEAC9DA4B9A09979BAB8ADA5A499BAA7B995BBABAA93B2A0A2ABA2AA96
A583718E756C636C69675C6B6B596E85728B9192A4B3B4AD9AA9C0A4ABBF9EBBC4B8C39F
B3A6CFB0B1A3B1BAB09CA5ADB2AF9FB2B6AA9AB2BBB4B4A7A5B28F8BB99A94A095A7BCAF
81AF96A0B6BEB6B6A3A5BCA8A3C4B4B6BB9CBAAFC7BAADBCB7B7B1C6BB9FBD90AFB4A4C2
9FBC91A1B69BA89C8BB596A7B29BA59B8C7C7E98978CA39DA28D9597768F9180A98EA190
9C968D9EBDA4968499A49FA3849A9992B98C9FA0ABC3A2B1A7A99D9DA88F9497AB94A46F
A5A88D9A9E967E878EA6A5958C959E8F8D9C919DA39D9AA48F928C8E9183977B7A42747B
958286848E9088919898939398A28778A99581768396917C8A8B937E7C93878C7E74616C
B09776A28D8875748B79927E7461686A637C8681847B7D6D746A6C71705C6375596D7763
825C697465706F5F7265717D777457677088965265637879686183796C62514C756D6371
6A7E92726C736B6A567D6E636862786E6E847F6F687461485C575A787B416D6D4D6E636C
454E5C4C646986FF
FFA099967FA09C85A69C83977B6BA0A48C9CA5918E997B758C87958D925B8B989C849C76
5856565B6F646B7A6D95809B99B18B8F6E50514A46487783988A99A58A9E9BA29AB0ACA0
A3A092A3A39C9F9D8DBD9D9EB0A2AFBBADA9B396A488A0A1A5A2A59CA895B78CA5A097A9
A1C1AF849B8E9EB08DAE99CDC9C8A8B8CAD0B8A6A9C3B6AAC1BAAA9DADB099AC91B4AAB5
73B09F8F92835F4D7E635A757B8E60789C91A7AEAAAFB3ADA8A9AE9DABA1A9B8C5B9A5A8
94B29BAEADB58898ABAC958B9CA9ADB2AEBABFA6A79399B8B8ABC4B1B2A5A1A49EBFB6A7
AB9DACB59A9DB7A3B0C9AEABAFB6B1B89C97A69D8FA2A6A89EB19EA4B7AEB7A6A8A7B8A1
BAABBC9A92AC899F969E918EB5A4A3899E8E9BA38B9D968E889A8687818B7E8F98A497A2
ABABA0899AB1BFA29990B594B0AAA492A1B7AAB4AB9CAC9AA0A1B59296A1999D928E9B91
939D9EAA8D9F8E93AB9CAF9E7EA873669D798F96B69F98B2A6848E847E696B7976857F8A
87968D8F8D9F817577748C97908D8B8578958B887C878A957F87938686918D7E6B8B7997
71779495768691857D6C758D675D80657B747077607769647A886F6B85794D5D726D638D
587064515E8E6E797778726E7F746F66796475766C787683868665634862404A5B8A6D65
6A756568735286625A72656D816D616A70696F67615D56584D616A597E6D626971637968
67796C706E7D63FF
FF98999CAE8AA0947F8C8990848D8B988798759C9F80848B8B776E7B877EA5807F8B8E75
7258604E5A7668757C7C83778F7E6D6C5E5A6C4B68739295B893898B9D9BA097BCB2AEA0
A29CA29799B39CA69FA5A97E8AA0ABAA93AD9198A7BAA48D99AAA1B0AFA18DA2969DA5AA
BA9C9C8E9699C9A1A78EA2B8BAB4C8CAB8B0B89CBAB5B9B5BEADAAC38EA1C1AF9F9EAAB1
B2AB9D7C9E86978A7780758074689A9B92A7A3C4B8A88E9BA0AABE9D9290849C99989B9B
A6A5A5B4B99F90ACAAB19CA5C1AFB7BF98B1A8A2A589D19EBBB3ABA69B93A2ABC7BBB9AD
ADB9AAB5C0B4AA99A49DA8A9B8A0B7A9AEA68EBC9D99B2BFBEB2B6B1B8ADAE98AB97ABAC
C3B4A0949E9CAC92A8A39F95A1AE9E9AA283A0A1A1838C95A89E949CA38E9281909DABA6
9F9E8A927EB59DB1A6A296A69CA9BE9EB2AE97A9AB91989380A2999FA3B0A3859C7F9FAD
9D969AA185989EA9A486939F9492838D97A693AE9B9492827B807D8969757173756F6695
788C91938F938F719575849993978A97888D8C9396998A828D8D958C8687968C907E8974
957B8D7D6E86897A5E689784838A88896B706A577C7D7F598277847A7872737665546F75
7576210001747A7D83795B7F7B77756653706C475F607065744C87725860555373597973
717B7C756662837D718369746F6B7357737372644174676F5D5F56736E75695868705061
636D78586D747DFF
FFAA95878A869896A598939B99AEA0A7997C8A938077859175978A80629D91828EAC7261
5D66586261555798768879708C9185676C43474D727C6A8B84A397B4AAA48F92A1909097
A2BC91AD8197ADB29C968E87A9C5BDB6A8B0A68EB2AA8C9A9C857891B5BBB2AFA59DA2B1
AFA69783B6B19BA5BCA18DB3BEB1ADA0ACB7B6A7AF9E9DAB95A7BECCB3B2A8BAADBBA9B4
CCBBAC8E9CB198859F827D8B878E9DA594A6BFAEAFAFB7C1B4A3A696A6A9A1C29DABAAA5
BBACABB9A8BEB4AB8A8D9DA8A8B3C4B0ACA59CA78EA98FBFA0B4AB8FACB2A9B9A89F9FB1
A7A1B0B399B5A0B1A9C6B6B2BEC2C3BDB8AEB9ADC7B0B8A5ACB1B7BDB3CCA8B38EA5AC95
9EA5AFA29AB39A989F9FA5898E8EA8947CA1929EA29D979E90949D919BB59E7B8F92908E
B49C89AAA48895B09A819F95A89896A7AC9C8BB39AA186B292ACB79B98889BB39B949C95
818B9E8A83A39A96B09499798BAE9E9A8D8594AC97969A8A9780636D8F697E706B7C7676
7B868188A49285987E828E86858D8F98879BA8907A8E84928481907E828883928B948179
718359607C8074988A8E7780716E60695B706E7C7D737F7B7E6562515268797D76868682
6B602A004C6B71767E70556889896A65896667014E4C63836A6E644C6E74766C6B616278
818678406567726F646570665F604E42567275827F7080567D646C696E66846E5A657165
606D5A59677A6FFF
FFAAAC92A0A79CA3948E93899286858B90815B72947C8A808F8C87938B7F9B86A58C7952
4A565844565C6D6076777D809279807F6B5B5B4F5B6889838DA4A09D949291A39BA09E8B
B194A3A794AFA5ADAF98AC8B999DA19FA9A9AC948887B2A096AD7F958DA9ACC1A1A5AFA2
A7A3848997969E9B8AA2BB9CABB3BDC5B1C0ACC3A19DA1AAABBEC1C5B3AC9AA1A8ACA2BB
B2ACADAB94A8AFA89C99C19CA799BDB7BCA7BBB79D8F94A2AB8DA49BA79FB3AAA5A09D94
ADCDAEB59C9DB0B39BB8B7A0ABB0C1B4B794A8A2A392B5B6B5A199A1A174959DACCBB3B7
B3C4BCBCA0AC98D3B39B879BA5AFBAD3BFB8BEB7B693A4BCB4ABA7A7BEAF9EB5BC8DA59A
9F91A1A0A18985919FA69DB498A7949C918F979B86A18F839D82909C868A919E99929399
96D6AD8D90A79FAA8C93959993B1AEB8A59BA48EA18EAA98AFA5919CB19D86918D96A383
989C978B9B9290949586B18F8A9082A27D6F7F90A583848E8C826B606F816E788E6F957D
76757C8995A285848CA18E839391997A849290876D719E91A278868A888CA296A0648C7D
8B7B6432637C6378777D747D8A75918789657C6D7D6F757771738260846C807872748275
86816F5E71884E61775C5D737C935569617370726A7A68575E7C5E4A676C64616C7F706B
586E7F824B787E548284877B7F885A738A72696F4A55646C4F6E6C634E6D625F6A605C85
677E797F7C6769FF
FFA899A8B3A189BC9784968A908E82828E9191908A6C978A85898F91868289897D88796F
625B42455B4F59687679627979908C887273554E7B858099A7B19A93B1A56F9A82A095A2
9194A58EB3B1A1A28CAAAEABB39CABA0A1B3B5BB9391A0A1BF9E8E77949C9C978D8E9D95
929CA196A188A6B7C8C6BEC0B7C4B8B9A1AABBABA09B9DA6C4ABC6C0AA9CBEB9AF9BA5A8
B3D2BAAFC3C2BA9FADB694BBA89F9F9E9AB49DA59BA3A0CCBCABBB9D9DA6B0A0BCA6939E
A0B4A9868B87AEAFC7AC8DA5A0ACC3AFAEB58C9AA99F8BA0AFC99297B291B19DB6B5B2AC
AF98ABA4A2B2A4B0B8B0C19FBCABA48AB3C6B4ACA5A9B1C5BDAFBFC3A5B6C1C5BC9C95AC
A7B1A297919DB2A39FAF9A9DA9A0929BA0A191A09E8CA9836D869F9F8B8F8D948F968B95
8487897D7E9D929C85A398AB9B8DB1BB9C9A9B99AE9DA7899C809C979B8E778D89AAA581
839A989493A2A28D969D9C8398968298AA9A8D8F808A6F735D7388827D7B8D65657F697C
887E68779C989F9CA19A9D79A39C8080918776978D7E6E81968C8B9EA07E8679796E6F80
558E8A7A657B656576837F786F6969636577756561758A838273686679788068726E7383
76857A70745F82707469865A757C67755E6D6379766A6D725669736F75696D6E60647D70
797F647975605C5D776764647F74736571756B6C73568045506978697F6E72636C736968
846578665D8161FF
FF9CB197918A9589B4A27C887691A2898F92799B7C8882869178818C8990A393929C948B
7C5E5657635D3B657177675E6A626D666F61696A7E789BA08AA0968A9599996C80998F91
8BA9AF8C9B969EB4BC9CA0A79DA39A91AEB3AFAC98929C9BA59B988A837185768898737C
939295BA9DA39590A4BBB6B6ABB0A198C3AEAA9DA2B7A4B391C4B89EA1A4AFA4B5B0C8C0
A69EB592AAA8ABC5C1C0B3B1C3BAA7ACB6B4B6BABBB4C8C8B9AAA2ADB1BBA59AA4B6B2B2
B7C19F8093ACBCB5BDACB99EB6ACA2B5A8A3A0A897A2ABB2AD8FC1A18D93AF94A5A2B89D
9CA6A47B98B9AFB9BBC79DB8BCAAB1ACA8B3CAD0CB9FAEB4A8C6C2B2B8BE99B6BFB388B0
AEAFA3B1A7A8AAA297BB9EBEA799A7B49B9DAEA7928E9595918286AE96A6A8A4857D987A
89928C999F968AA2999C938FB69E9D9A99A89F8EA19F8B8E8C8C90A38E998A9A88917E87
9E8593998F9E97817697827E9592A084908BB0978D74757F827A7C88879694818F82898D
948586866894868592819AA98E8B8175A08981798894887E8385737B7E978D9573658589
837872846E797D7A78856E87897589888B726C6E8D5D686E70868470726E746663736579
866E7A7073768A807F7076735672857B6C5C675F808174696D606783857165675A43707E
75847060697A81647C725562668B806D5D7E62737D776D5221755F5550614C5D7F6E6B76
6A6F47746F586BFF
FF808C7A9C9A8D9490B497968E85727A8A91967687A092707493A68BAC9599889C98A191
78586665526B6149565B6759757C6F747961766E838794A29B9C9AA89F8D97A7AB9E9FA5
AF9D9D9DA38A92928FB69BADA5B9C2B3BAC5B4A1988F9C93A58D779D819D8A8AA197918E
A0B8B18F9A9FB1A78D82BE9A9FAEAABEB6C2AAA69795A9A7B1B8B59FB4BAA8BEA6AAAC9F
BAB7ADAD9EAEAB92A1AB947BAEB6C4ADB191AFAABDA3AB99B2A3AAA9A8B9AEB5BEB4A0AD
B0AEACAFAD959FA9B498ACA989AE99A9B39B9EA68AB1BCA7AEC0B8B1A4A19DB190A08AA9
9F9DA5AAAAA0ADB4A1A3A69BAFB2B8BCBEC1B7A0C6BAB0C6B7B0AAA9C2C1B5C0A6A5B38F
B5ABAEAF96A1A6A1B0A8AA9C88ABA5A5A699948693AC87A28890B8ACAC9FA998A4939FA5
A494A38EA6ACB8ACA48CA37B8B9AADADC78D888D9CAFA4AAAF9F9C989D9AA09CA1B2A1A0
7CB1868BA39C9BA8928C9F9AA4A8809FADA39F7F92707178777484757C95A5949B788F6E
A88A7D7C7F7084978685978884889A8C7A9BA6807E7B837E999F8E9F8C8E878286858F7C
7F79878A8A6774776F846D807459887C8D7D715562747D656F7E67738A6E706B726C706C
7A686070795D847A71736766586A5858765766675F5D5C6C69777B9266636F8262705065
686077746D796C52706A6D6A74757064745D627C65596D645A4468795D605F7F78595D70
6377825A686A76FF
FF84A2A59C829091A6AE8C958896737E95978D8FA694A88691A2909A91808195869C8B70
86756D725D463F58516C6872644F5E635A6E74767877889596AF8E9898977FB1A2A9AAA4
88A2906A87B1AF9D9F95A797B4BEA5B8A49A979CAEB5A1AB8D89AA98BA9DB4A597BC96AC
A6AEA4939FA8ABCCBAAFB8C3B6AAA5A4BD8EA8D8BAA9ABB7BEB9A7AF9EBBB9A7ACBB99A1
B5AFA69E8F98B1B4A59AB0AE9B9DA2B8B0A49ABEA7A9B1BDA998A8A29AA2B4AECABEC39E
A4C27EACAEA794B4ACBDABA6AFB5B5B29AA185AEA097A898A88FA9A7B6AFA28F90A7EAFF
BA98B2AFA2A3A39E9EB1BFBFB5BAB9AEC2B79EBDC0CBC4C2ACA7B5A5BDA0B9AFB5A1A1BD
8FC5B4AEA2C3C69DACAAAD97AEA9B2A89FAC9D97B895959F9198938D7C9396A4938E9995
9B988B92958B97888FB394B7A6A4A581919893A0A7A3B8AB9FB7AF9F9C94949F9CA0989D
988DB99A90A88A8988997E8C9288939A8D8995947F7573827A818D8795859B967C9D8893
93817E8783768E888FB88394A29E97996879998F88718579A084898A858DA48C9083788B
6A9CA190688193947C8D8D86796B738177797B846E887F8B7D766A70667E797C787D7A83
6C78757382856D69647A8370715C647F6B79757482826571646E6F7E6E66576A6365895C
6A6775695B7E525F67546E60647C6E79796A74677173797A7D6B524F77566D666A548965
6B6A7567775963FF
FF9E8F98868E7A761F8A9BA29B706A8E968E8FA9A09F9392949696A6937E8573908C947C
83707B77675A666E6A614A747C82607E6A7D799280908CA9B4A18B8D9DAC8F99ADB8A294
8C889F9D97A7A1A991978DB491A9A89AA1AB82A5A3AAB2A2B89AA3A8A5BAAF8FAC78889C
A2B18EA0A0ABC1BBB481A6A1ADBCBFBBC3C6C2A7C8B4BBACAEBCAAAFB7B3AAACABC2A4C6
A8A8ACA795A7BC96A8A5B097B88BBAA7B2A8B6B4AEA9A2ACAAB2B0ADB7AB85BABAB2BFA6
A69BA9A9B5A3AA9C8FB1B1A0919892A3B1A4A493B8B6A994A3B0BCADABB1A38DA6C2E7CB
B5C39B95C1B6A1B4B0BAA0CFCCAEC9A2A893B1A8BEC0B8B1B0BFC0B1CEA996B0B1C0B3B7
B1ABA7AD9A91B9BFB49AA2BAB6A1ABA9B99E9496A38988947A8EA07692907B88918A9889
84ADA39DA3A48CABA1B49191B2B58F9F9AAE97ABA68F9AAD979D97AEB0A0918DAC9FAF88
AB8380A5A2A08D8F909DA1AC87919E8A9994898172706E79819E80908B9A95918E979C96
60798A6E72757D8194A69C888594938E9B7F948A9E8CAC8A8B9F97818E90988A736D796C
7D78716C9F868E83968775757976886D6C7A6273756284686662725D677760487E6B7871
776F7871587170726B7D61596A6D67557A7C6F5C498D7B776D4571838573896A5E6C696B
727365497D7D79556E606457567278806C6E697D615E5D7F6F4D4E6A6170684A73627B79
64615F70546A6CFF
FF879B8A9B939440008381A791818978728B74A392A19F9782AC91828E798B9B7188A080
8499716E617266656D6D646B708788656D747C897F927EA989919D997E8C9E9B8C88A3AA
AFB6A6B0B09699A6AEA0989DA498ACA7B5B49B95A5C4B2B0ABA49C9F858F8CAFA29A9B95
B29A9595A9ABB696A1A4BAA6C89A9EB2B4A3A7C3ACB0CEB0AF9EAA92A2A0C1A2AAB1B6B6
BFBFAFB29ACABBA0AFC4ADAEABAFA6BBB89F9CB8AAA6ABB49CC2A980B1B3ABB9A6C1897D
8BBCB1AAA0B3A3A59DB1A7A0A7AFCFABA1BAAFB2928B9EC4BBA3A8A8A69EA0ABA685A6AC
9898B18DA5C5AB96A2B2AE97A1A4ABA9C8A8B3B7A59CA3C4C2A796A8B1C2A4B9D5B8B4BE
BABC9CB9BAA3ACB5ABAB9D9B8FAD9CAEA2A2A4B4A69B8E8EA58A9FA687938E9D8778A6A1
98909897A0918689978FB3959F8FA29AAF9499B1AE918D93A7A5A0A3929AAC8D95938F97
9196AA8794ADB57EA7929791A1B17D9997958D737D90815E7B848396909B98948B92A787
A991817976887F8D9195AC6C6D988C9AAF7E909C97938B93847A91866E968A7F8A7F8189
8F77858B937874847F9E6771817978617F877D777C8261847080688E647C7C66687D7D79
66706E6F7A5C656B758173637C685B6F6C758471674F7F75797F806B76755E82715E5963
8074656D6D995D6B7B5C6F577170596E79796567585D6871646265776B666A6D59625575
74677550754D7BFF
FF92968470978A7600877B8A8B8583829B97767EA496A98EAF95939FA69A9C8882898F94
7D8A7F7A6F7961586E7A766F6F696C957B6896A1999AA8B6939FA3A0A7A29DA791A69799
B29E96B3A9B9A971A19A9A93A7B0C0ADA3A5B5B3B1A4AD8ABBBA9DBA93908BAE9E9698AA
99B69192A6AFA4AF96ADA1B2C3BD8E9DA4AA9DAEC0C5A1B2BBBCCDBDC5C1A8CAA9AE9FA6
AFB5A0ABB5B391B0ACB2A4AAAD9894B095A0CF92B1A692A0B3A7B8BCA3A3ABB1B2AFBE8C
B9B6B6B8CCA1B1ADA796AAA093A1A08CAB9EAAA390A2A6ACB49FA0AA9AB792A28E9A84A1
B4A9B1B99FBBAFA3A3C4CD9A9CB9B4D9ACC08B77B0AEB6B8C2AFB8C2AAB29BBFA5B0B9A8
B3B4BBAFA9A49FAEB0ABB3998E9FBDA0A6A48A9F9093857C759A8A838B979F818FA099A2
9E7F9D9EA7A29287A09C8BA396AD989298A09399A69AB79B9E95A7A093AF97909796ACB2
A3A19C7EA5A3B1A39D928DA6858C8E76858B7C73765B6A7B839280969C7FA0979BA09798
9589946A70818F8DA78591876E8A8493869261919AC5A29399807C8A93869E7B84777381
6D8A9A857D818C919588778F91908D8B667D85657F8A706F7C7F78795E82716D70666861
7E6F5F41668E84554C425879636C7C6B7C6F757B52806E64696C725D7679886970718663
777B67475C6E6C4E6564656F657A7A756464736A606966637565745E5E6A67616D4E5A6A
6E787B544E715CFF
FF979196B78388A1ADBB8E819990869172697E9C929692AE907996A59A9D8E8B759F8589
948F9D7D6E5774696A66767F768D847D809B89A3759F9C93908DA08B88929F9AB0A09AB3
A5AEAAA28F95A4868CB2A6B19B9CA492939C9A9D968FB2B2A1B4ADA0A897A191A0AA9FA4
B1A3A7B1BC89A8BAB6A39FAAB4AAA1A9B7859BA0BAA4B7CDB6BCA59DB5B5A79A9CA093A8
9F90A8B5BCAAB799ACB79F9F96ABAD95A8A496C7A5A7AE989F98AA8CB4ADA7A5A5A19C98
ABA38CA3A4B7B0BFAB8FA399849DA0AB9B97A2ADC5799A9E98A59F9F9BABA784A7979CA5
ABC9A8AFA0B762A99EAEA3BAA6ADB6AFC198B4C0A0A5A1D5B7BDA1C5BE8EADB8D9AFB3C1
BBC09DB8A4A2B5A6A79B9496A5958F9DA7939B9B8FA6988C9F82A69AB2A4917890937394
879386829BA08D9E819A969898749B9BADABAAA0AFB597A0B1A8A49D91859488A3CDC18C
938D939AA2958C9FA598A19FA48A8A8893847E9781827C7880798FA69BA38B938F918B6A
84937F9588778B928291929DA99F888A8A9E7F678D8A9B81707876748084837F8C898078
7A727D67858074736675867D7E897A707B6670828D8178607486726A73636965757C615D
6B8F6960667B744B656C79757881767A61636B5D6A68837B6A7B734F5075706C60778071
6C6F695F61797A61657583758473715A6A6956556D5D685E6B735F67657358716C6F707D
427272665B576DFF
FF8F888A8C93A5A08E8E969D8E876B917F86988293A0AB8BA4ADB7988C8B848E7C838C85
7B908D987B7A6E847C788D8AA3848F7F78878D9E9C95A7B89AA9906C91A39899ADA6AEB1
9683999E9DAAB4A39EAD9C938BA992AAA6A9B0A2A89F9FA7A5A7BCB9B9B0C6BFA7A3ACAF
BC9CA7C6B0B4A5B298B1C6B7A8AA95B798A0A796AEAE90A6B792B392A6B1B3B8A7B9A8A6
A3B590B68D958B93A89E89C59B8589A67594AAB1A79F98AE969E99A1C5A9A4B2B4998698
AEA5A5B1C9928FB79C9DB3A0A5AEBCBCB79A90947DA29EA39396A29DAD9D989CA2A087AC
999BB1AB9E9EB4AAC1B6C7BB9094B2B491BBBCC0B9B2A28AC7ABC7ADA3ABC5BFA6B7A0A8
9FB2B3BDA4C5B1BE9DADA5B89CA39EAF8F96968F8AACAA85958E9B9D8B9DA785959EA096
919E9D8A9B987C7D948B8F9D828DAEA1A29F9375A99C949E95A5A38A8283A0AAA1A19898
A0A0958492A2A193838797B0AAA690A1A3898B9D8568647C7C959382908B92A89E9A9985
847F677F7F7A93877E868B837C86A0A781838C805A78A19C7B717D7E768879806F808E9A
85897C735562887E7E8387747675956E7877757B4F817E80768F7A896887656576666F76
8177797574615E71547267745B41906E746873647C707E60746463727548756A6E6F6A4C
6D826D5F82718F7B646571696A62796467536F726B777362687B566266646F6257577055
6E6A4561697670FF
FF9591777BB0A8968C9F8EAA8B9383807F76778C868299A28BA7979B9F9096686C5C767F
A391A5A0917A77979072929C82708C84667E968B7FA79E9AA9A59BB08E94ACA6A19C83C4
AD8CA9AC919BA2999EB1B5A7ADB99F979AA79394908FA6AFB5A4B4AAADB69DB29AA29EA3
B1B4AAB298A586B7BEAC9990A1A3AFA59C8CA9AFBCB69D9EB39BBA959FBDAB95B292B799
B4B2AAA7A39AA3B599ABAE918CA1A8A9B3C9ADBDADA7A5C6B1A0A8B29AABA1A89D9EBC96
B28FABAF9FA0A2B5A5BC929D9CADB2AEA693A0AAB5A18F9A87A4A1ADA8B097ABA5BDA0AE
CCBEC0B78AAAB4B5B2ACA9A2B1B3ABAF9DB0BFBEB7BCB2ADA6A2B3D5C3AFADADB2AAB59F
A88EB0B3AFA6B0B4B3A9AE9DADBA9FA5AD98988B8E8B8A967E8E9A8D949B7D8591887B9B
99AC9A858DA19B7B9994A7A07EAE9F95B3A8A39295A8A8A59EBAAB9E8282AEAF9C86A4AA
859E7F8B78739094A39F907E92997A797E7299827C7E747872937A8F76A09F879FA1908E
837F7F8C79877B7CA3A7808B7D8A888082848C8993778D8B8C748BA596977D7B8B7F896E
8C7F838F78737E848C6E657A7B82787A73827C727668758678667B737F65726F68786F63
5175698A814C9B817965797C6F32417268687170637A6C7A4B546A65707D74726973636E
6A7D8170626D7F6D6C6D7964735F747E50657971657163606963865E5E6D68797F6D7081
816E60455C5D52FF
FFB1B2A19E9C9A9E94958F889E968D867E845A75989792A0A1769B7A756D777D9B778191
7D8D908688807F7E7B9C818F9D9593A08595869F94A297B29C8FADB896AA92B1B189B885
AFA08F8EA49DB17694A2A8999490AAADB1AE9FA4C39EA4A89FA8A99DAA9DA5A0A4A2AC9F
A29F9E8C9593A8A2B2ABAE94BAACAF9FA88788B1A7AABCC1A8B0A9B2B8AFADAE8EB596A1
A495B0A69EBBBCAFAD8EA9A7B6A1BCAE9597B9C7AAC7919CA1A5A39DA8A293AFB8C2AAA5
A0878A91B2939EA1929CA9A3A3AE9DA8948B9797ACA8AF9BAB93999A928D9FB0BEA99D92
98B8AFADB3A6A1919C93978C899391A2A4A0C3BCC3B3C3BFC9AAAD9BB3B8A7A0B0B7B6BB
C0A5BCAA9BB5ABBBCCB7ACA4A4A5B48688A87C97A6A19C7CA39E9F96A78D959FA3A4A38D
95B09CA97E72969D9F938A9A988FA6ADA7B69FAFA79AAE9E9E8E97A5B1A6A297939C8B77
9BA18581926F7569869599A5799E9B9A9A9A9D7F7A698391908D978C83A7979693AD957D
81846B7A7F7E668A8A99937C8C888F7D9A95767096948A7784698A8B817C7A9088817368
64767F7D688A87797B8284757C9C7676A088857B7270757B777475767A64815E8D889081
7A7A7D6D77765A7B7A6B5C7491735866766B817C775C75795F71736E6579655C4B706370
5C73618E6868727163654B3309655E536A61566B7E73598B755B8B7652607A615066695E
705E5739405A62FF
FFB897959979918B94AD8F90A5949C7A768E7B8C9494A59595857F9C8A727B9D7C848580
938096A19FA0728C7DA59B938F74798B929E9795919B9EB6ADA8A99792948A8DA2A4A089
8B9E9EAA9B9699AB8897A0B2929CB0B492A1A2A29C9EB49EADAE7EAFC790A0A79DB2B7AA
B0B49EB6AEA0ACBFA59798ABB3A79CA9B598A3B3B098A394A5B8A6A47985B0B6B7B4B7B9
BEC3A0AEC6A1A4ADA4A3BAB390A28B8FB8A8D0B0B9A89DA8AC9798ADC1AF93AEBF9EACB2
B1A7979FAB8AAFB4A1A4B0A48EB0A5938FB0AAA6A8AC9FA7A5999D89868EAAC0A3AEADA9
B79DAF9CA7AB958B939B7E8A9A718D8E8B9399C8B1AF95B0C1B8B5A298BE9995A3B6C8B5
A89A98A1A1B6B4C6B1A5B5B3AAB9A4A89EAAAAA09C9CB1A89DA09CA99B97A5929D828AA5
A391A379859375A19D9C96A8A58887B59F988A82838F9DA4A189918EA08083838A8AA175
7F7D9990876C86918B918984998FA49996869B7A988978878087948AAB846E8A6B98768B
85837D7C808E819CA3948B8298A2A1867680988F8C7069907C767783787A7E8876937D84
97868A8153838983966C8A77817C897882727384746B757F6880717F857170858E8C5E73
776A7F8B696F6B6B6B75916360707069897690707E66706156626F6784776C7378688075
758A8F6E5378545E5A50604547685E69777A715B505972666852656782665A6D6B355B58
533D64516A6549FF
FFAEA1A79589977FA48B8F8B939280907592938F8D8465788679759A7E7B7E89836D9094
909FB59E989C9369847495938A9C978D9BA58D9F9A9AA099A28F98A899A49086A6B997AF
AEAD8F8F999E98A3A29A9495B5A48CA897A0999B99A589B8BE94A58492AFAB7793B19E8F
A0B6A3A6B2B6ACBA9DA7AAA3C2BC9CA5ACA7B5A5BDB8A7AE9C95C197A1BBAEA1BCA4BE9A
A383B3B09F90B3A4A5B3A09B9A979BA3ABA7B6C8A8A98499A5A4B3ABB4B2A2BAB7B79AA5
9FA4A6A3B2B199A49F927FA9ADA49DA0A695B0A5A69792ADBF96939897B7A7ADA5AAA29C
9EC4A7A8979294976B64797A727372796C79978C9DA5B1C79FADCEBABBB5C2C1BDBBC4B3
A0AFB6A4AA9FA7B7B8A4C0A0AA9A97B08D967198A3878FA19086819490868295A9949992
9D9D888397A79094849F9B95AC858EA7A098A6A6A2C59DA899A79CABA391AD9B8F88857E
9C9176747D6E8A98968D7B957F8698A4869083847B745C7474717195848E8468867C738F
7A648D807D9281899D9C8A7387837F8A8F747A7D708E7E7C685C858099986689816F7F65
7F7C726F7773817D8F87667D837C747B748576646C63748286625B6F6C696B7269626B44
76735F747775947979656B72657E657C6D81637D61785E746E467D7B76777D6C7474776B
5E69807060776C70886170684952656E53736F6859527C6B785E6787676D6D72554D4A60
6A725363647165FF
FF99838DA2969FB380878980A59FA48F838F737B7D6688807571888C928C9C828A8C8B90
9F9EA497897299977E9F819896929CA399819BABB18A9AA3A699ADB59992A5909B9DA9A3
9CA3928AA08F9D97A1939C897F8FB39FB99EB0AEADACADA091A8B1AEA4B48C909AA896B4
B19A99A3A999AC9CA895A9AAA6ABB5ABAD869CBD99949F9FB8ACB7AEC0AEBEB7B9B6AFC8
A9C3B5BAADAAAAAB86A9BABBA4AAABA2B09EB8ACA68FB481AFBC9D9B9EBEA4A3A1A0ABB1
A7A8B8B3B9B0A1A2839DBBA2A89A987A7BB2B2B1A9ABBBA397ADB3A8A6B0ADA9A5B0B1A0
A592AB876D8985647060605266535F81706F949B98A8A7ADBBADC09EB9A7B1B3AECBC1AB
ADAAC5A7B3B4869EABAA9DB2ABA7B69D9E9392A3A198A5C17B828D90918B9F9E8F7F8592
85A18670989EAB868E9E9197A391A7AD998F8E9C9096939BA38C9CB3A29F778F86887C8A
7D746E8F8374838A99876A989C8E8D909DA4947A9185887A896B86697C887A859B8C8468
6E85706A85827A9C9A9A929F808E969B8D728EA2916B7284897F89706D6B74958E928A7E
68707F708E6467897775666E8B99856B647E82648688688281727C68796B605863547F72
7C88535F5B6B846B6C7E6D696D666D646B6A645E676B5E665B58575F6A60546C65615976
515B688A795560696D61574E4D767062605F686D6F616B5060647456647887706468626B
6C786358874A7AFF
FFB1B1B99B9A96959B9597A0928382858C98848C7A6380585A86A1839B7B589491A29497
878A8AA4A09C7BA0AA8C79909CB5AAA7A4967AA0928A94A1A089AAA2A6A4979596A29695
8F738680A49E889E9CACB2A29D9D89928C9696A1B19792AC9E94918FA697A5B0C48BB48E
A39CA4A3918DA6ADA6BFA98CAE9BAF99ABA1D3C1A4ACB8ACC1C6A9AAAAA5B5A9B5A8A79C
A1BDAF979EA59DC0CAB09AA5A7A4BC9B98AFAC9C8DA89BBDB9ACBDB0B6C6A88F9E9BA9A3
98BE94ACAAA0958C78AD918E979A91919E9195A7A1A8B9BA9EB3AFB3A3A3A0B3A9B6A2B1
B6B7A7947A686864566167614053405D718093999490B6B5AEADB9ADC3BBBEADCCB38FA7
B9D2AEA4AEA3A9C4A296ABB49B9C919BB1A38C988A9DA0A696927D8EB88E8C9898969D84
9DA1908189A18FA39CA2937F8B8FAC96BB9DA48AAF93A7A290969C98A1B28B81969C7584
82759E909AA975737A888D7984919098A1AC928F81637A777D805F7678847B79727F8673
916C698F7C6F7D8599A59F85879295A6829C96806C7581A19297748B8C9396807868839B
6C6B55726C6183728B5F9360757A7C7C645B72836E858568738A8267656C83776E5D535E
685F6D65807E64726E61877165747157687D6E73656669756D7F7D5C835A756D69626361
7B866D5D5B867660455B756A607D5F5D6E577C6054756D70737566617152565175694B63
7067717D675B60FF
FF958D90A3A0AD8D7D8B798A8797848E7D947E7C7A7F6F918178868D92907B819B7C9685
848C9E8F93A994A2818B808F9F8DAEA390787086908B999C9A8B93959B788B8E94706E7A
857673818373829098A5A1A699A084A1989F957F8395A9A1A09C999C7B949B9E84A2A6B2
B5B5858AABAC969A98A981A6AD9BADB7B0A5A3AF99B19BA4BDA4BDABA8A798AAA6B597B2
AE9F9DA0A8A39AAFB4ADB4A39E9EA0AEAAB7B8CBB0B0AFB4B38F9A9D99A9B39F9EABA19A
AAA39E9ABF89A2A89CB0ABA0B79D9287B6A998A3BA9AABA3A9B794A08EA2A193AB9FACA0
A194997387563B3E3057462952614B51485B646D7F86969EBBBDC6B6BB9FB4CA98A4B7AE
A49796979FB39FA0A0B1A9AC9FB2A29C7DAF979887A4857D7B93A7A68B7A928D90A68198
7C888A94A9A99CA2988F947F98A49E95999B96A0A7A38D9C9E9488949FA19B9AAB858281
839695829A92AC9B8FB9886A90867383898F97988E8E97866A8182778B82716879787E7C
6C657A90968FA58C6F86978585826E888070808C8B707180777575837F9386797C77827E
67647C7D90807D836D6B744747598883906285668A6F7F827A6275617D6E686861746C6F
756985756C4D696D6479615C6457625856587B7A71706059617968607C69707172657E8B
5E626B637B5C585E4E55557C72726C605D5A717462475A5A595F6874696A635A5B687560
5C4D574F685E63FF
FFAD9DA38B9190B18A8A8186937E9D9F8C8E8A7D8B71857E7B7D88787C898B917A8B8FA7
959D9992AC927798A6938E828A9A9198B3969D91A98480919EAFAA9B96977F787F7E8567
616662787B8C96817C8A98A7AF9782949AA2A9A6A6B2A0A1A67D805B5384959CB2A1BBBC
A896A49F9C9EAEA387A698A0A3A9BDA0B797A4B7BFBAA1A79DA7C2A0B28E7BB0BB93B3AF
A8A1A18FAA9E9BA3A89AB2B59CABA6A0B7A2A4B6B1A899A9A1B0C5B2ACA1A8CC96959288
AF8A9AA19D94AEAD91A39BA0B49AB9A79FAAB6B2B8B597A99488BBA8B39CB2B4A99FAC99
978A000058493E555446393D61567148586D4B6E6298959FA2A3ABC7B3BEC3B5B2BBADA0
A994AD9AA19D9F8CB08EADA1A1AB9C99A6988B8C99A4949BA18F8498999F888B96A09382
8D6FADAA98909D969A7E9284A191A9C0B1A9A0A7A4B79C7BA7A7A49A98917B88907D7093
7EA090959CA27BA59B7974956D8B83968584908698A1858B856E75707489887F6A836A84
675F727A86809491957E87978869898A8196767F7B81797979767E6F77787180856E8676
77658175636260645A726B71817675676D7D807070596A5C629662627A6B56727778615B
5C795D727D5D79726F776D567068606252616378747571696E61596A54716970735C5B70
7A6461495C667575724C785C4E614A5462605A6B74786456686C63535F537064806F5E6B
5C6156596A7778FF
FF9D9793ACB0A78E8D9D947EB28F8D8086945F85868E7C72787D70899A7D8F8C8D888997
8CA4A2A09095959F8D8EA0A99DA29E9CA6B999B595ABAD8FA5A1977F956B817B7A7E7070
706364686C7C7C7A8B8C8F8A9EABA5ABAB8D9A8EA0A89A8AA49974000042809CB4A8AD9C
A69DABAAA4A2B281B3AEA3BF9EB8A3BFBDAFC9B0A599A4BCB3A3B6BDB0BAABB996ABA1B0
BB8AB39A9DBCBCABA4A6B8A59AAEB6CBA295B0A7B4B4A199BBAC90B6ABA2B39D8796A2B7
A5B695B0A6ACBBADAE9EA6949593AFB2C8B0A4CFBDA5BFA9949FADAB89AC8391B1BCB799
93810049484648503F585F5D6A686A495D6E6D6F7988959FADAEB2A2C2ACD2BAC9CAB28B
A49EABC0A7AFA4AABBB8A095998D91A385A6AA9DA2ABA0A19EA2AB9BA67B8D9795839884
7697907D8C9792978F878DA991A4A89D8F95AF80A187A2A39BAABC9C677E88939A9799A0
99A0A499A187868F998A827884678484869AA59A938A94A08A8E7C76995A6E888872719F
8F7E95A3917E7D778679866985A88BA28F868A2097847D898A7A7B617F708A70838A597C
88848E784F5A717A7E706495885C807C717B7080755B856E8882846B6267794C7369667B
707E767989915E6A797D6557727A5F574D646A65656359827B716A467463876A68725E79
5E7F54536D5A6E63525C5A656A835F6C67676C5A617D8C66585A666C705469615A65516D
666366645E676CFF
FF9D8A8E9AA1939EA086787791848F90968E898A9C91788D7C767D82879288A1919CA074
937D8787A4919A919E9BA29A8A8697A86D8F918880998A9A838D89969476667E83795F6C
706F7453805D7C787E8E8698ACA1A594A89192A6A9939E8EA281661700548F979D9EA994
AA9BA7B4A898A3BCA78E958BC5A6B293B3A7ACAAA4A1C18CB1B4BBAFB4AFB8A8889BACB2
A5ACA7ADC4B1A1A7A6A8AF98ADABB6AD9BACA0B7A3AE939AA3B8A8B2AA9C999392939CB3
B5AF8D96A5BEA0A0A7939F9D949AA1819EAAB29E74919DA3AEA0A096AE9CA4B4A4B6AA9F
945F4343374F345E495577766967715F75655B58625D86769ABCAAA5B5ABC1A58FB6AE95
A1A6B0A0B5AAAA959B8DCB8E9281838B8AA7A2AB889B8AA6AF919A9AA09B8694A07D8680
80997D7A8A9F9F949F9799879AA3937DAEA3A09D99AA99A0A0ABA7936C9B88849388888C
9A8E97A08BABAC8F89858B967F7E8A849BA99898A1A5928B7C5E818B746675807F738166
85868F9A9B9F988B92759886847F9B8E798571627B938E8B807F7B8E71717778746B8A8B
78808D727A6A78726F768D7E798E6476616F6D62576C6C79807554715472776B5E617459
7A6D89766C53716473626F6857465D6080666974575F6C498C63736D5B7C745A627F805B
828B7C5B726F5E586D6365536079626A6E7C6270675D4252666E64695D5E68654E587175
4C444E7356645BFF
FFA5A4AA8F938E8182A6B89E978082919B9A89848B9F8097968F838980969482908E9E7B
A48E8BB49683B2A87F958E948F9894787C78888F9E9B999B97838584726E545C6A65756D
78786F7070756C72939C9A9F9A9D88979F91B98E8B97A4ACB6A375756689BBADBBB1B69B
91A99CBAA19DA6AB86A8A99DADB2AB96B6AB96AEB3AD99A8A1A1ABA8A9BDB5A0B79FB2B1
988DB2A0B9A0B2AF9B849BB5A6A6AEADABACA6A6A8AE8CB8A4A6BEA2AFA68B8492A59FB3
A2AF9599A6A8AAAFB0ACB296A696AFC0ACC589AC001F97BDB2AAAB9E90B4A7A0C0B89D91
797B5A453741403B636052828C775C65697262615F3F5E7790A08CADA5A4A1A2BAC48F9E
98977FA19E7A8593898A8085A7838D849AA19BA39299AB95989BB29C8395967D8A969877
89868F78A580818DA0AA8F7A7A8B7F9795A9A5B897A5AE98B1AFA1B1A0969D8599957C94
9A8BAE999BAB8B9C959382857F74857D7E937E8789AD9C939BA3748D8B7D869195677C94
8C8F91839C988F877285886B8A7F89767F868A7E6B72756A848E75787B7B7D6A807A7583
7C85897A706E7B817D917C68797C666B9085857D5F6A706F6D737E4C708F7C7B3F698065
5D876D678465647D6A6C736F756955837B70634367805F4B70795E6F8570796F69776169
6C5F6C6F495E7E72736B648663556166485C6A625668645C5B4D6B6C6B6C68613F49583D
614B3D55586668FF
FFAF8C98A4B99F97929792849AA38F998DA698999093B7A29E967885816E9582948F866F
88798D9B869A97A2A3AF869C889D8393969C8D89989BB2A29C868080825E6675706D8377
6C726F905B677875838091819094B0B580979AA0A2869A97A0A39F9694A99EA0988C9CB1
BB9E9D9792B29789AA8CA0B7AA9CABA9B7B5969EACA8B1C7AABDA9B2AFB6A4BEA9AD87A9
A6A4C0A4AE9CA6B09FA19FABAFACB5B0AAAFAA9F9C9EA99F909BB3929FAA99A1A0A29FA5
83B38F9390A08F978CA6A5A89FA292AF9B91A2A94788A39FAE989DB0AB989CC0A9B58781
5E424E224948535572789C91718A7B8B80585B5D4E4571598B95A0ABB1A098B9A77FA186
908B668199859591877F8A8B7B7FA39B7F969F949FAB98A2A4A59D7EAA909E97949F9989
93977F998E9B97969A9099658AA19492A48B949C8F82A4A292948EA09D9D777276778B87
8189999BA0869D929B8D82827281656F8080857E849C96A6A17F8971848A7A977F7BA49D
977A8A7182999786926A6082888B5D85808A958A7680787185887B6E6D7C6D6D646A9371
7D7F78688B7670706C756D6B7D86606D69716068717F707B7A766A7A606D6F6E717C7A5D
7C786E655B5D6C728A6E8374635C756372646466705D635A7761837C6B66576456747776
5D6669546E5B5259736544496D5E6D5A655A50546B606E55596C67635D5B8757496C6A66
656151584C4F66FF
FF8EA37B93958D739E9A96AA8A9B8993917E8A85A58C918D7D828EA39389969782919397
839C908789A093949A929690A1A29591A09A92A77E84827E83817E7678767A69736F7A9B
958188617063666487788184819EAA919D8C939399A1ADAC9BA6ADA49A98958CA199949B
B091A3B09FA7B1A8B7B6B495A7969EA9A5AEBDB7AEB1B6ABB9AF9EA19E9DADA9C1B1A0A8
B1B1968D9EA7AF9BA69DBBA3BFB6B099949CB6B0A7919B9DB5AE99A6B5B6B1A3BFA89FB5
ADA8AB9EB0A1A39A9F998FA798A49C8CB4B3A8A8A08E93A18AA69D839E97A8A4B0AF9877
50513B3A2D4E69749A9D9391A27E928F67485352524666749BB2A2B7B2AEADA99F99A19B
94A08D8E927981928890766A907C8F889AADA4B083A9C09EA9A1A089909799879C9DA8A9
958D847E9E9F79AC9D879EAC9B9387A6AC9A959691917D7F8CA4ABAA95799CAE8D888787
9C9EA0959090868F9B8D87859099A06D6A849C747F8A778D8AA0819182838C7F89A07E89
818A936990929795909A859A91937C828C9A7D728C7B606A8C86898673727B73776B676D
9B77785B7E7C6A8885877A797F6D6F7D72475869797157586B726E646B64746E7F62767A
6E60716557657576807A436374645C71756872535766687C626F556073708A7A7E9B6961
66665A507C885E70737D3B514B5E63675766726A635160575B5E7A52666D595E56665163
6E4C5650594E66FF
FFA18A979E779491AE8C9D9999B49C888D9D81A49D728898939F9378AA889186AC928EA2
A0A3AB8E9A8C9E7E9FA1AC9398A0949CA28CA0A88E9A8A8A848B66717F74758C7E7B828C
9995A17D83777B8C6C88758C999B8BA38EA59D9DA4A4A991B39BA6B4A2B09AA0A6B1A2A9
9AB4B5B8A39F9D949B94ABB1989ABAA0A8B097B1A5B2ACB8B3A8B3B49FB29DB4B8B4B99E
96B1B19D9F9DBFA2ACB2BCA0B8BC9CAF9FA0A8A7A2AD90939D8AA5A38CA0A2B4B0989DB5
BAB49296ACA6A2A3A6A58996A9ABB3BB8DB0B9AAA6A8A4B0ABA9939497A7BCB3A0A8AA90
64413A3951406C8E9C9CA78EA0828F7A7B7059544857565585A7B7BDA89EABA1A698A2A7
A5A9949BA07B929A94697E71716E757E838B7EA697A195AC8495B8908D96B890A38D82A4
A8A29E99A49892938C877294859BA09A867F8F84A5A6A3B0A3999A9B959B8F89A1808E81
7F9FA08D8994AE9A738D948787738B8A7D8B88858C9E947D9D919A919A8A94A095868F90
9A8D82A07F919A836F8C8A74767978817D7C83797D70698A678372727472807565776E80
62768175688B748B84728B776F8D8070710000637583736F606264746C7D7470587F7F66
6F8A78644C6B676F5D4E615A7B717173685B68706A646D7E7479757A7666637185536E70
6D446F5E67587A6D6069686A446849376152626067746D6477715B60645150563B667053
756D5B5E5D6054FF
FFBC949691909D95A5BD9499A0987B7D9FA3928FA3948D6C8598979787B1907D91839B7E
93A5927AA18D927F869593888990828F88999C94839696847189847B7F6C818482928496
A08685887C505A96837E7B92898E959DB98B8EA8AC9792B7A8AD9296AE9591C09CA6B4B0
A9B5B0AAABB0A99A9DC48E8A8898B0C29DADA8ACA3A69CB3ACA1A1BDAAB0A296B0A0ACB8
AB96ADA3AEB7A6A49F97AFBDA4A3ADA49CA2A9909EADC2C7A3A8A0969BAC9B8CA6B99E94
999EADA5A89894926FABBCB6A2B2A8889B9F9F9CA6949BB0A9B6B0ACB3C2ABA2B297A577
4B353734455E7E9593A1AEABB5B48E9C9363443B3F3B557F717C88A7ABAFBAB6A4B09D8C
A37E8A7F84847A928F75887E746C526FA4A08AA0BB9B9F9E8A8592B9A090A2A58A92918A
7F787B9D85A1A3919D7E84969492A68DA29B969C8498A6B19E9B95AB9A89848F7A8C918F
9886A396969A87B3AF818E8F787D859497848E83A08F86898C8F8D7A7E89868E7A917893
8B9BAA91848C8D96979B8682978785818683857C6E707C647D6C855F7F71686C7A876474
62735F6E60757B6478967998767C5E5C515800487B665B50665C504D7C6B74787475595F
60807B798C526A785A6F636D676A6B627A6E6C835B745878776D5D7A755C6A82746D6D6B
58696C6D61513850588366504C683F515F6D655C72594C646369555C68634D3574586460
57655E5063674CFF
FF969DA6ABA48C9BA29F8BA297828B8F7C9E9E9D898D92A598A487959993936892719890
9F8C8DA59897A1968E90A2989CAE8A9C94959DAD9694978879557B6F736E757F9598A09F
B2A6B3918B8A6683708265567E8F8AA98C9A957C91909EB9AA9D8EABA2B4AD93958691A6
9FA294AFA59FB2BFACAFAE9FAEB8B09AAA969EB7A2A6A29AB1AC969DC3A6A4ACB1AA9995
A7A7BBBC93A1A1949A90A5A5B2B98DA6CA8FAFC6BEB1AD99A9A8A3A9998CA9BCB8BAAC94
BEA197A799B3B2B6B0B0AA9EA69E96A59478789EAFB8AA9BA797ADACB8999F98ABB07A60
5C42333A4E658692A7C4D1A5C09CA57F73495D48443A45557D95B8C8BCB7B2939F9C9BA3
94AE718B959B9BA4837E7C867E795D697A7E93A2A490A294B7A29596A39D9B9CA1779981
8794A98488998BA889AC9D9A908F91A59C9387A097869C94AAA59A9A8F839D905E858BA2
9C8E97B2909A9D997E8D9C76728491868E897A8F9E8B97A9867F8A828C96887CA29F9A91
9C828B846C909A9087959992729294877F5365786461796B8C7E7581698B807C89676073
715A626F7F718168866B8187766C54717253566B55575C6146505E66676A5F5E695E7A74
656665616C73676C7173756D705D70906559655777677784696061697D6D6459644D696C
696456618275623B5F60586369625E4860605F526B6B5A504F7053625963526241454964
5C4C5F666A5740FF
FFB3957E8A8FAD968989B0A48199A295929295A4A696A394AD97979E9A8D82A5A2998A99
99839F8C92B3847D7D8E727F6C9C969298809D7E95A78A948F6E7772747885748895A29F
8D80B98D86897C577060808C898CA2AD908A959685A3B2A7C0AC85A295A797949AA3959D
B3A0A9A7AA9A989BA69FA9A2B299B1BCCABEA3A7B2A1B892B1B5B39CA6C4B9AC9DA2B1BB
BE9FAB9AB996B2A6C2AE9EAAA6ABA59FB49EA5AABAA19A90A19D95A5908C97B99DA8ABB5
9FB3AEA1BC9E8D9DB087B2ABB38C928BA3A4B19185A3A3B4C6BB999D9E98A0A594A18260
4B4C2F384E5D738A9C988EB1A0AC968E6F5B45243F3A527B8892A3B8B4B1A28C8C93927F
9D937C97A89B85A09EAC917379818184738E819381A6ADA39C93A19E7F889095968C929D
998C7BA999817B80868287929F908993A69A869597928A9DAE91918DA29F9991847D8A81
8B8EA3829E9874AA7F85777A8085948D97968798758E9F887E869294A9849E9C7DA4B292
8782869C9A8D9FA1A494949093959C8F948A74758C7A736C607286816F796E62586F6D6C
7E7C7C6A66727F77697456636A786A685B6853554F514F4E43474F5C766E65685B636A72
7C5F62754F6485714F6A767A5D676D8163777072636960695C70768F667D656F60676776
7D6C567148604A765D5F63406D6F6E6E696768646E7061466248405A5E54565578727354
5A6769635A6878FF
FFA18995B38E969F82979595A8A59B929EA1949C8A939E9791938FA79B8F9C8BA29FAB95
8EA08AA5939CA17A87847895888393AA8B8C84978F9D95A292826D767384917F89AF8A9B
A99589A89A82A06B7D6870687792A39584A09D979F9195B2A49DA1B0A7A5A1AFA5ABB597
A4B0A79CA9BEB1ACB3A8A4A2A178AAB0ACA4AFA6A3B1B1BEAEA5A8B5B3A3AF8DB1AEAA9E
A1B287A0ABB17EB49B9DB3B396C1B0A59D9FACB5B2BBB4A49AB5B296AA9AA392988DA7B0
AEB6AFA0A9B3A18DA58E9BB37B9FA3A1ADA1AFB08F859AB9C1B4AEA6B6A9AB9B7F9F887C
56534C22415B78807C9BA39B958BA2A47948312D473F467084A3B5A9BDB7B2B59CA2906B
879A939CA2ABAD8D9BA497976C6D756C768C7E93B0ACA3A387AB8B7893A8B1A58DA98788
9E969E98A79294919B949688888A9CA8A2A19BA69891AA7D7F7BA7B2A788818DA69AA39C
83948AA0A085949CA0A28F73868099938C7C6E958886AD99A1A18D9DA3A599A097927FAB
9B95A693A2B2868E948CAB7B829F8C697E706D727B826E69716C777D8B8274738790716E
6E636D7A5F8179686B5E7261706752416C60484F5D646A6E78626D7060627A5361737C79
68676B60736958806D65676555707B707C555F54707D6A43434670516553735D6B697164
6E6D5C7A69707766725E5F6D6C67616B645B5E73675B6D5A646F6D6D536E5377576C7348
5A815945595757FF
FFAA98A07A8EA1929A8B98A39B8595839A8085707B8C9D9F8A849D917D8C889AA1A99B92
888E898B8993849E988A9B9893A2908AB1759EB2B0949681747D735D66707D6EA4969FB1
8FACA8AC839694887A82766F758E8A878A9DA5A5A8A7A4A08EB08F9A9CA7B1B5A5A1A28A
B7B1A8789F8BA0A2A59BA6A1B3A1B09D9FB59C9EA1C0AFB597B4A192B8B39DCEB7BFC2BC
AF99A2B3BD96ADA5BBA4A3A7C2A1A99FA7AAB9AFADA3B5B39FAC9AAB9F9C9C889D90A19A
A797ADB5A2A4ADA6A68BAA99B396989E99A8A3ABAEAFAFACA29DABB3AF9BA3AE9794959A
6745363B3F5C678EAD997C829A7D9276655A49432942738AB2A399C0C6C3989A92999093
8B949E9BA29EADA4C6A5987E7A687D728268677B70A49D8B94918296959392A49E8FA0A1
AFA1A3AD9D959896928C9178A9B29DAB9F9FA2949699968C8A649CA89495A266737F9684
74738A8369978A6A617E948D758F93848AA1A3927E969C9BADB6A79188967A9C9798998E
9F9CA0AEA9929298989A80557A8E828980657663676E7E5F6C887B676884696E5C676E74
84586D5F75636B707E895B736276794D7E6F5B525F694F5C517A79415452626A583A787D
7686767B576454826F71654E5B6C627B684B5A766E686D606E625D64617070746E6F7371
6F554A3F5A605A7B7774745C626560516853707A73693D5C5E59715F67677D4872625965
61674554486362FF
FFAA9D97A192A29C88828089A0877F95988D9B9390A892958F9895859F918E7C979093AA
A1AC97B796939A767A827D858A898E8E9681A2869A8A83996D816A6D7B887A8789A79FA3
8B94969EA5908D6B7D858382827B8A9CB7A3A297A3B5B29D95B196AAA3ACA8B68F99838D
A5B0A9A38A988AB2B19D95A6ABABA78686A7AB9D95A1A5A0BEB8B9B2AD9C9F9DA7B8B29E
AD9FB7BAB3A491C196CCB7B1A8B6A6AD8FAA9CAD9DA28B93B2948A809399A6838CB299A0
A5A9A9AEA2B59DA6A4859CA8A8B3AAA0B18B9B9CABBDB3ADC69EA9B2B9A0B0AE9399AA75
78552B473C48587D697592A0939A63715D55442D4441518F889FC0CEB9ADA2A18D75848A
8C999F959F94A7B9A19198907C87806C5D68777F8484A099998C84738C80997C95A38F81
88728D9FA292A3A07FA9918A7F7394A4AB9EA3929A8D9B99BD9AA99A938D908880768895
77997081877381848E7D8D897983A68182857E9498919D8E9199A593B88A83A2947D7590
7A83869289A29D88829CAF99848197868180817F7D7165646E7D7E727E828D846F83816E
6F6F676D616B7276736957776350657050757C606B636C5867735E606559646650555C68
836A78785F737969744E5A75636E7F6868436C635F685181716C50676A55696568777262
594B666A64754E53765E635F726665655967554B586968546775625C5D5A506C64685760
60514B3F696055FF
FFA7A4A28791957EA28E87889E9CA07FA08D9185988A979E9F8188A1A1A47D6E87929A98
98938B827C977F8A816F898C8B93AB817F93A6809CB786A38A6F7F60768F737C7C85AD86
93B1A6A88E6F61757B718E92908DA3A0A99BBC9597918382B4B3B0B4BE959F8DA99B9EBF
AB9DAF7F909291ACA4A5A9AAB6B4B0B3AEB5A395AAC0ABBAB3C0A09FA8A6A8AF9CA6B4A7
A8BB9CBDAEB7B986A897BB9EA5B5B3A5ABB5AFAAAD9FA7A19EA0A2A8A1AE9EA7AB9CB0A0
9596A29792A7B1AB9298B0B8B19CB29897929EB8B4B0A9A3A8B0B1AE94A08EA990A49B7B
536448505E5656637C5A6A838B817A5541493B3B43535E879FC6C4B8B5C0B6A29C897F7D
819B8AA8A5C8A4A5A9B4A8868F7F848A867D6E8DAC8E79999AA6939D8BAFAAA5AE8A90AE
9C79A092895A9DAFB99CB2BCB3A9A6B1917DAAA69D8994AF93B5919A9392909474869B79
788D8F8C8E7F858A8191788B858F95A2917A9A828F98849AAFA98DA57FA8A8A3AD879387
9E8D977A88969984888D98877C8673538C908C768A826C62608471567867655E71735271
6A815061727289776D7A696D6F6C5A4A726F7D81797476677465647A5B6E5C6C566B677A
6B76675C7A6A5264776F7B686B6C5A6D7E4B6F5A61586732565A5B656A4C597A613E5E63
7E57704B5160716562836D3F796E66417060285D6F675F6A646B595F6B4B7068704A5E65
5C5A3451655363FF
FFA7908E9F91999180918889878E87A897909C878FAD9C7C9176A4AC967B898093897F92
A392A38A947F83989087768F7B799D78848F9F9292AA927E92856C7C8470837F978A8498
9AA39D9388878E826D6C878A86AAC2A99A8C9D9AA09B9C99B4A7ADADA69A98ABBFA19CA0
B29EAA969AA98A90A0AAB1B5C3ADBCA7A5BCA6A8A69BB5B5ABB2B4A6A7B599BCC4AFADB7
A3B8A9B0A9AC95B596A5989EA69DAAAFA9A3AEA6B8B0A7ABAFB5A79AA0A796A998B07C90
AC9398B1C1B3B89FAEAFB2A8A2AD97B6A188BBA0A4B7A1C198988CAF8F887F9B9AA2A476
856163403A464A5E52616B716A64544F533B4141495D7AA3ABA5C2ADB5B3B0A4A383797E
87A6A6AEB7B5A68BA28FAAAA9092819089688F8F809590A78A92939B9EA8A098898B9783
AB898FB1A8969D9F9A98A7A5AC9D90A7A0A59E969BB3AEA0AA9D999493998FB29B969584
96878384808E77919970818391A1BEA9867992948796A196949F928A8F8C7D9481919F91
8C9A927B778D816275918588759386797A7E65857B7B75716D7C8C86737D60767C777E76
84656A6D6C536E95774F63665D4D5065594F5C6C7B82776E6D4F6F60595A4C4B664A7571
7E5E59757D66617573796F6E74787768655D67645D585C6C876C5776716E6D625A533B5E
6D7465556C6E65526B6F6760644C48465B696D52655B7959575471505C57525E5463564F
62494E6A4F4A50FF
FFA799938896848D90998BAB94A39B9DA7929C8DA17E8B8A90A17898967C7E858C8F888F
809B959F939170967B8A9688AB87939584A295A8A29A9695AB80746F6D4D6A76827F9691
A39D8781848D93797A658C78809EA19EAAA69F91A4A199A090AA8C9EAB959BA69B8F8D82
9D9597A7A48FA59E95A7B4ACA8B2B6A79CACB7ADBDA6B5BEC79FAB9DACAEB69BABBB9CB1
B098AFA2AEA39DADAE9CA0AFC995A4BFA58787AE8C9F8EA997939C9F999BA18593ABA389
A3A9A4A1B0A791B3B4BDACB4AFA7A99AA59A9A909FA1B9B4989FB099AD8FA294A090927B
7078636D59646A442B494F524F5C414125534A4E466C929BAFB1B9C3D7C7A98B7C897483
8598949597A19C9FA1B08391A1A7967E706A86918FBC9C9F9A8B898E9C86A79B7DA59299
9C9E85A88E8399A8B68A9A9198A6A8999EA6A7897D8EA5959D8F938F949F8D8D969F8085
8C7E81737C7B7C8D8C858981989894AB90A7B198A2848EA673907563888B948D9B7C7E7E
927C9B9E7D917C7676847C9280767391846B8C6B67617D8A7662626F7E6772757E6B797D
5168676E71748877775D6162616F585943566A706F6E8739666E627D76635F5D5E6A4664
686A695F6768616C777E5E64716558614864525D4E6E7B7572636D57696071626D6C6C51
573C6178625E69616440526969595F68665048717063675E5F4F5A516C7960626F477365
4D554A5B5A575EFF
FF9989A2868F888B8B908C93AF9C93968FA7908B99818C8C9E8F9F837897898FA7A5AC9C
89859A8A738A9A858593888E92779783927F9AA494879C946F8B89786D61656F7B8B747B
6683859189777785757178859AA5B88E8E8BAFADA69C81998A89ABAB938793ABAEA2A5AE
959C967FA09B87A2B4A49FB9B8AABC9ABDB48A9EA89CCCAFB7AFABB7ACA9B5ADC9BC9DA2
8EA3A5A5AFB5B1B9A795B2AF979A97A7BE83A798ABB197AFAEA9AD9A989E9D7C9AAC999F
AEA69F80A4988DA8AB9BC0AC9E9CACB5A99AA7ADAF919B99AAABB1988EB3A9B0AC9C8F8E
8F8A815F3F404A3B574C404351453943585B4C3B4F8E8196A5BDC5B89CC3C5808078737E
808A8F6F9DA59DA39FA0AF9C9187887779718A909A8A8D93959B91767A84979E9D819F8F
9997A3959B8A8E9C94A3A7AD9CB19FA5839A8BACA6A8ACB991979DA29C8696979396699B
8A91717F999794777A9D94B29D8C9FA7958291919D908A75697171897F7A878C927B8E75
99969896967C8890767A8C85808289788576646A7E77747B70725A6B78726F747D757C72
745F588374827C75647C625F5A63375E6267637081907376675B7A6B6B6662434B535669
71775C66756A5672846E6F767E78606F747250735266674A615C4B5C546C6C6B64516768
5E5B5D62536071625B646A6B655A55545D52605E7769846058685A624969575A5A6C4E42
5872574943674EFF
FF9293857F8986828A83828A98979C98AE9BA590868FA38F957F8F8385888F8F948B937B
7F88A1768DA683847A9681779B9B97A2968DA395A0A19681839B90716F7B6F8A868C7E81
878C84767C5F70739B887E7AA18C9DA8A8AE9A96A09F94A699B797918998A08199B8968D
8F9491918EA6A9B29B81B4B0B1B9C7AF9B9192B1B58F9FB3B3A8ABBDAD9D99959C9DC19C
959F8EB3B1AAAEB391A9B8BF9F9B998693A2A79AA5B08D8AB9A7A5AB938E969485A5AAA2
B69E9D9AAFACAB8EA38987A59797AC9996A2A8B2AA9CA9B28BB2828AA891A29EA6AEB090
7F8065637054665C574350493C4334544761616A769891ACB3A5B5B4B4A9B09776756E85
746D7C9FA6BBA895A19E8C8B9D8E7F817B857C9D927D93929F908D879C7F7B8086837A94
9DA4A09E8590AFAF9E8F9791B7979D8E91A3A0978AA08FAD9E96A69B7999B49786949F9F
9481807F958F8B8897828E818C8296969F979A8E8A877D93857D696A85899D837D7D7C84
7A888284918C837E7A727B8975787680886E797F7B5A806777676E766D60766E4F686869
6164917B7B65727D8377614959646F61616B616D71876D546B7D8486736C5F566D755E5E
5E71774D796A6E4F4A596B705D537D7151537B5D6B5B4D6963525159704C415E5A736F67
734D52665D607C5C4F3D5D44706C68604159686B5B768364616F585F52366763726B5D58
4C3E59563B596DFF
FF8D988699958B9E9190829295A09BA98A9A858E9B84AD8F808EA485888D928B94779290
8C8A8F9CA098A98C988F938594969B9574989B8786959C84B0B584808E8E6B6F8177877E
77887C7874646A548D919D8BA2979C9CA384A9A18C9B97909793B59C9788A48E8A9EAAA9
748691A197988A9C9B9D9A9DB0A38FACA8BCAAA4A9B071A8A6BBADA6B2899EA39BAABBBA
A594A5A3B5A9A298A6ABAB98B1B59697969AB299A39F92A5969DA297A7979985948FA0AD
A492989EB59AA2B09C99AEA79283B5B2B4C49FAA92AA9BA49BA0A3B0A29CA3C099959D91
ADA978737586514246543F3D4F525A53535E6E85A28CB695A6A48CC0C1ACC2BD9079657B
7D91A283879C96959F9CA18D8D8C928775818F9593989B87868B968A9C7E8DA8AA96A9A3
99957399A7AFA17DA0A492AD95A8969B9792A2939D9B9396B387A498958A9D9A9C8E8691
959B91ADB7988D8EA397899B988890A686959DA07C89927F825A60877F72696768617F91
787384939EAE988F888A839B689281846A6282867A60516272618C7C56735E7F677D7C7F
6D7C6D67648477635E6F796F586E4D684E6060697D676F56776A7F6D6361424F545A6060
60675648626564737C637048577563607A706F6D6F5F5B6172575D5A4C5E47395D6B644A
51514D5A5A56395365514968675F6783615E605A585861615E3F596066596E5C535E615A
5850554D4F514CFF
FF9BA59F969C998E837DA980869E9B8E8F8AA8A8A19D9D98A7A3967C6C838488A0958A90
968B96809996978E95758094AC8D9A979BA58DAAAD7D90A49B8C89729880756C5E6F5E80
7C899077807474829C9C8B96A7A9A8ACAD9E8D998DAD9799A5AD9A9A86878B9097909B9E
B69A9293907C96A7AD869CA0BEB6BAA9C39EC1B4A3BBB99F9DB6B3B4A6BD91BBC7ACB5A6
BC9BBBA6A3AE988EA49AB89AAEA2B0A996919AA08AA9AFAFA5ABA0A79DAA9DACA6A2ADAC
A5B1A69AAA89A89A99B8B3AFCBC2AFB3A3A89DAFB19EAB89A5A49C97A7A39EA49FB9B4A3
8E798C818D5E5B6F714B6053526D5F4E6764758F99A3A5A6A3A0B899B7CEAFB09E77877C
7F6783AB7F9A8F999BAB9891827C808B8585718F948D9E83929F779468A9978285AD919E
8A8D88949387857B76A09C7D908E98A09EA097959F9CA9A391898E919F9E869A929A9A9B
8599979091936E929EA18C989F8799A4AF809C8E9E8F92826478906F605F7E9D6B928E72
8599A5A8827D7C958B758D8482749586637E788E866A74595D8E6A926757755E6E668C74
84897A6D717C5E566E646F5C685857646262786D6275626070717362725E676B69617666
757B5F61646E5D5D6D696D584E4E654962786C666061775C604D58655C6056536F6D435F
5D414E626D5A4B4D7D7D5A7C6C5B6556645A6D6C5F63718B69635467715B656F61565C65
534B5646595E5DFF
FF848A9F9D9B7D899386627A9386A898A6AB909AA79B938C8D959E8F947D7A90858D8197
957E8989869EA98C968A888F9EB09BA3A1C090ABA09D9B828CA28D888B807E6F70736B78
7D77778A7C5D6A748188ABA994B296ABB9A49FA7B78CACA3B09CAC968E8C8385A0919AB8
8D8290A27D6D85969AA777B0A0AEC1BCBFB1A4AFACB3BC98BEB5B2AEBEA6959EA1A9C2AB
AC9397B094A0A5BBA99DA7A4A798A190A4A39392BAA5A4A8A299AFA79EAAA99A96A6B09F
9CA598918E95AEA1B1AF90BDBFAAB5A8ACA890808FA79E96A6A095B0A2ADACB4ABA1AA99
A7A4828B7D737D6E69696F58627F8864767B9F9D9EA5B69D9FB3A6ABB5A6AAB89F907480
727F628E6F6E838180A28C928682756E7E7CA79B8F91829E9E8692A096B89377ACB19B91
97AC7D9E8C958699939C958C87858C90938C7BAB967A74898F8899A793A0978AA482A189
977DA38881A8A380A594A4948A8B87969E8F929B8A817F848A8E8574928E90647A6D6D92
6D7186887583A0908F876A797E8C7B8A6D7F875F66776C6C7A7C81755268626D6E755B79
6B646B6C77757362685359545D4A39636D5C676F6450585B69776E695B5A62755F656850
6A6D3D74767B6E7F6388633E6159675E636E706660494D5B58664C526458765A72536069
696E57545F486A4C62615C445B61586D67435F5E5A5F644E4D6A585756526562655A4E39
64594753534748FF
FFAB9498A49F9AA1948E7F8A968D8EABB09CA39D798CA08A9689868D938075A28E979588
96AC94829E9FA59D9E9698907D9195A5919C9499A3987E949D9082B49B9191928C7B7787
6F6F6F8B7687808A858E939B949AB0A1988FB8A2A8A2AAB78A9AB89C9F8A7E7C9E8D8FAA
9A9BA091847376857B8C9EAAB4AEAD8F9EB99B999FB9AAB4A8A3A7AA969A9AA0B29EB5B1
BA9AACABD1ACABAFAD98A2A2B1A8A7B19899989FBC93A09CA29C99B58D9D999DACAC85A4
96AF958E9DA49AA18EB0A997B5A0B2C8B69E9AA1A3A1B1AA939DA993ACA5A2C5919FAC98
999C969599897988917D7B5572967276A4919C9C9EC1A8B5BEA8B4BFACB0B0A9AA8F8476
77657C80737C92818D8465798676817D6C61858D94B4A2B1879194908E8691AF86769782
8C9D7DA39D97A598A07F907884978CB0969B9B948184748E8AAC9A9E969F9D8E9A9BA19B
8F8282A3949AA9708E9B82928E999E8B9F978A8D82877385897C6C8A989876737E848F93
89817E8C8D80819594829581837D8760747B77727F6C736F6F63696B35687372656D8082
73626E71704C7562686261645A4E626557655A566C607A6976716E7163597853735A7471
68705A66687564615F645F5860676B57725F5A64617068644C6A586241604F6A4F606562
66627158574E5E61685D626F636E4E626C6A66805B6A5D725A7866686E4B515C60674C4C
404B734E405354FF
FFAEA797A08B8586838EA37E7F89A694A0A9949286AD7F9499A2968F887294908792949B
8CA3AD939B998A898CA0A1909092A1837FA89CB09EA17FA78C8A7E85908C9792A7878F76
83817C898A977F8C9A8576A2C19E9DA59F908FAD9197AF9FA98DA1997AA8768D828BA187
749E909B8E8E81837D767E86AAA89DA4BAADBA9EA6A9A497B6ABB3C596A4AEAFBDA6A0AB
9FA3A1ADA4B19C95A4A79F8D8AB8A48D92B0919B96ADA3B6ADA7999EA397AF898497AC84
A197A4A5A0ABA39FA899B7C49E9F939E9D9CBEABA1A691BFA9A3919C9289939B9DA2A078
AA98AEB37F979F8E858978818A86978598A1A1AEA2AAACABA090B5B49EBBA4B3AAB59E90
7A6C78766C6E738C758E826A76828C767C816B979CA09A8999817F879795ACA49DA3849C
A18098AB9F8E8EA190958A919AA8B49A9FA6938EA28BAB9F9C819D9D9692978E949DABA5
877B859F8E9A7595A888758B889F8B968B87A47987888E6A6C8E9285948F9699957F8B7A
7B7C8B70868190877F7F7F71815D898E7981685B61787572707172616F80736F736C5D66
757E8672626266517B7C6C6E845D61627951637C6C856D5B6E68676F556F63755C586060
516F81645A575363657671745B6C58655B665E526740384B5E5261566F6072756454644F
6E6B6A5D6C694B5B6E625A79525D644F5A5C5C68677A6A7D6561755960534C6057586961
4A5E4A5E4F5856FF
FFA6A9938C9096819A9A8F8B878596B19093A4A4949093969496A18B8D9B82829A859AA8
8A877E9CB5808E8CA19A888B9AA1A49B9C9AADAEAD9D8EA2A3A6B1AC9F9F9D91928A8E9C
9A84A8A79B8D95A495868E9AA1ACB3AB8C9B9CA2A29BB09F9EAF9B8F7762858B9D8D9A9E
618D76728D6E7585807B99948E9F99B1A4C6A3B0BEADCCB394A38D9FB6C0B7B6B2ABB9B7
ABACA5A7AB9B949F95AF90A7A6ACA2ACA3AD87A89D9E9CA4ABACAAB7A9AFA698B0ABB4A6
A29683A8A4AD86B8A8C19EB09ABB88B5A08DAF99A19F9DA4A08FA7A7B68C85818E9C83AF
B192B3ADAC9D9D9D8E9B93919A9FAAB6AEACB5A5A29EA7A5B19BA19799A593B9AFA99297
8D816D7F6578686968798D95797D647A958D73768B8F70809886929997938293A2969294
A09D95A39A9B82809B9381968597919D9BAB8992A68C9C829B8B86A895979186A198829C
9E979AAD9A8F838A909280918B9F8C789E907D85869981879190889180968585977F9291
89837D76728683967A7D8C84888A76666B827972706B6B826A7D7A6B5D7575607C5B6974
75896E807A7E638E5F69836C5D73665E64646E71734A58516461565C574F547165545354
594F5D4752665A646B515F60667973585D5876605857604470606850616A5D746263455D
69584D6E48544F5462555A5766526B635E6E5B676C706E53675D4B4F4C6F5A5858524858
4A487B5B403D5BFF
FFBCA39399AD929883A3838C72998F9B7E9CA797A1A186839EA2B198B07B829F948C968E
89747C9B96939FA38D919DA6869B7EA58C99A296B1A2A09B9A89A1A88E9DBC9D9E9EA892
99BCA06E9AAC9B9698AD97A999ABB3A382A19D9BBFA381A6AFA78492A79185827C898D8A
A09091778067818498677E9C97979EBFB3AEC2ACB4B8ACA7BFA6AABDADB1A991BFBEB3BC
B7A9A2AAC09AAFAFB098B7A3A490A7AE9EA6C0A5B3B89D9DB0AFA8B08DA09F9F9EAE9D88
A0AB8F9BB7A09B9D9AA8AFB49F87899889B4B0A79CA299A7BFA2918A81A28B94B58794B8
A7AC8EBDA4A1B294A4B0B78AB9B1C1AFA7B0AFA7A99C9D9098AC7990A29DA49DC0ABB692
8E9380738393838B6683917B9873938F717882889F88919172829A92918B9A9BA9967F94
8575869594A2A0BEA983949FA39A84949C8F7494A59D86A39E8D8E918A83B3A4A9B394A9
92A9A9A9B0979291AC8FAD8398927E7F8E859B986D7375877A99998F83948C8E95898398
81706F808A779078857B7A7E8D72776C847D867A906C687E61765D697494756957585E6C
72866D7069707A737E5A648575696242605D67565D5B685E756465764544595570634B60
465C41576C595C727568636B64756C71667854585751605842545F57644D484F4C4E6D59
5F41705E5B4C51555E726C5B7A67564F6F6C5C5F6E686D5254656E626B65585A5762465D
424F5C52596951FF
FFA6A98D968F9C989F9BB19A957C9A96A994A784A78D9C96B98F8C8C7D98899194809FA0
948EA393A1A05A8AAAA083AAAEA19BA79688878893989EA576AA9BA2A992A7B6AA9C9B9D
A68FC0AD9EBE9D9DA6A7B190A5A49A8F96849B96A59E95AFAD8184929B767F8FA07A9F94
9990808C826F80617A7E8C7B82788AA6C4ADB7B6BD8AC3BFA8A5B2AFB6B1B6B68998B7B1
B4C3AEA6A39DA9B3AE9EA1AFA386B6B0B2A38DB69E8DA99FABA88D929CA896ACA59C9FA4
BFB0BFACA88F9DA69C94A4B9A0A89C9EB0ABA6BD90A7A3A2A9A4AF99AEA29E919D8E96C6
AAA1A4A79CACB9ADA0999AB0B2ADAAB5AFADB3AA99A7887F85B7A6A6B6B5A3A5B0CEA8AC
97AF898597876E6D8E7670897157928D95748660888AA3857171A0869C7C74A0889C86B4
A1968A889CB39CA8A497698BA7A37B8DACB1A693AC8D8F8F9A8D8F8399A0769182928790
9F93A19DB185977D9F8A978D8B73847993A49A777367AF977B85879E8874917390878980
866E71667E728E8C83806A747F8461666B71887E736381767660706F67747480726A6F78
756F646C6D7B7470666C4054606058717868606E6F4B6C5B686C65525B574E5645426231
3047434E2F61495A6E75736C6F697363706F5D646354476D79645C4F646054426B4D675A
5D5D5A4C6575674A7A5256547A5F606C735A496274747963615E354E445C5E4561636342
0068545E45474FFF
FFAE96A793A3A59B8F7F8FA59181939583B5B19D8D9093928C8E599097889A908496878E
8C9F8E8BA67884A5897068868B8E968D928DA589B690A78288ABB1ACA8918F919BA7B09F
99B08C7C91B5A077A19394899B8E9BA3A7B49DA396ADAC9CA1A3827B8EAC705C7074A3A4
907C89837E988A94736B5B79718285A889AC9FADAEA6B6B09FB3AEA6C1B28BA4C1C4BBAA
B2A3B4BE9E93929898AA8BAAAFADB8AB9C9F9FA5A5AD8C89938EBABB9FA8ABA49EA7A4B0
8AA8909A939BA48DA3A1A39A9BA3899298B4A3A1AFA2C1BBAB9CA0AAA1857C9F95A49682
95A09B9F9599859C9EAEAB9AA8B6A0AEC0A8A3B3A5A19882AD86A9C3B2ACBD98829DC4A6
B59C9CAD808B726F56668A607A9378768D85696E7F89919184A395A08A9D8B919892A593
93939C9B978C9B8E946C70A7939689A19A9C92958F9296A1AF97999D9FA490A094AA8B83
A7A0998EA496938F9B7B7D7887887C957C7A8084848D65759D7C9B95A07887938A94778D
8B6C847F7070929878726C8871855E68757F778383795B766F7A745C5D666F866F8C4E4B
797C7B7D56687F54706C60907D766B5F57666874556B636865716942574C514A584E4250
3F3353494C31504550586060814F696273575967593821635C6378615A6245594C436A6A
48524D584D63646866545F6068735A6863687368636458626E425E5D0C766F5860616439
26586B58644F6EFF
FF909281A6A9907C7496887E829CA995976C9DB29E9E908B9F9F8B8A928B8C8683A38782
8BA1949C9FA18A7E888FA58F998FAEB2859E8F94B29B7597A19BA99C93A6868CB2A89BAC
97A09E92B099AFABA1B27EA4938EBC9498949396A89AAD818CA799917E636D667D8A96A0
9F929B788C6A9C7261715B7C68577E8B85B6BAA9BDA1A2A4B1D0C0B3C69ABDB48E94AEA1
92A7A2A69A9EA4A7A5B3AB9BA3AC94939AA69AA4ACAAA28E96A6A19EABB0B2A78AA5A7A7
A7B7B7979FB2B1B5A7C99DB59A979DB6B39F98A0B6A9B7A1AB929EA69C7E99909B8EACA9
A2A3AC97A2B2B2958CACACBAA296C3B1B485A8B4B494B0B2B4C2AF9F9BB2B495B39DB1B4
A5A0A6958A9391908B969D9C8C76788787A9989B9B8C9E859989AA958B98B08A8C91AFA2
8E8FA5A39B789196AD998FA798A5A497AC949CA269858D939F8D868F887F9BA08E87A390
97AC9C94887F837F978A7B86956B7E7F839492757985847182838F9967747B9492868373
7486726E7D7D9086825E8B6A9182646B6D7067545D8F725A6F7982666074767883746D73
816D7467656B74776A7469637675736C70375F74605D676F6B4B6D58355751534F575248
3F53564334374050656C52695C69717D62665A732F000057635E66634C595A5A59495956
5A62523F5C6D68626B5C70605A6273735B66665F5A5B5F555B555659555E6251615F5440
3C5661654D4E53FF
FF9589A69995A694828C94918A9DAD8B839BA2A1A88AADA48A8F9D928F918596807A998A
8E989B959E9F9695848999956A8A90AE90A0A6A7ACA6A5AB777B9ABAA79DAE8AB4A09E8E
ACB287A8779EB185AAA0937F999B9977A1A0A9A79D888B9F9D97888F81967B93737D998E
8F9A9B8A928D897B795A758079657CA09CAEAAA5B3ADAABEBD98C3BABBB3ACBAA7ABA7A9
A3A9B097B395A1A5B198A2AFAAAB9FA6A7A2A0ACA7A8A08FAFA4978B98BAA9929493BDB2
A6AC859B9CAAC6BC949DA4959C99A6B6ADA5C3C8BEA99E9A99A8BAB0A7B3AFA197A89DA6
ACABB2B695A1A48A80A2AABFAAABA08CAAA29696AEA991B0A9A2B19DA9C3B88EB2BCA19D
A1B9B49F96949B9384AB9A7E8A8C9686868C8D857D8C89919F9BA8969D9C97909E908F9D
96AEA4A0A69BA896A4A0A2839A97AC9C97A9A5989BA8999088A2909298788AA29AAA887C
9B84A9A894B7A2A58384879499817A96867C967A85747194AE8C9F9577758A9B87A37E83
937A8489747C93927797797881976D508492846484657B7863636F6B776F7B6A7B61875C
7A747465696C60815E5879796E586671654D6F585E6C6B575B646E5F6057604C42484D4F
6E443E405C6752342F585D6E6570665C6F667767625E545758576C6C70715B61675F4D63
5D495258635A6569735657605C745C4E62515A6B6C666369555A53535F57524C696D5463
535D4056676560FF
FFA796929173959781A1A99793A09294918D9EA995A09F9B9788AD85999E866692A3ADA6
92A37E5F8A988D938A91A0958C889E939DACA2A3989E9E91A5ACA19FB08D90AC7EA5AB98
AA8C9DA789909F878BAD9BA08895A49E9FADAEA8AF98AB9697978A9590747D7E878D8D69
A093A09B9495A3A3908D766D81757A82C4B4AFB6A4CBB6AB9FA8AAAAB8B1A6ACAFC499A8
ACA6A69FA69D9F96A29FC06C9D9D9DA596A59DA7ADA49FA789868B9A9CA396B595BAA99F
B38AA19FAAA9B0AD90A58B8E8BA3AD9AA8B0A5A08BA1B0BA8DAEAFB7A88D89A6A5A5A2AE
B2B0A39DB287AC94B295809AAAAEA1A4BDB995B0A1B49189A7A09DA4B3B1B6B2ACB9AC9F
9DAEA8A79A879BB1B2A99D93828E7F8189888AA2929288A676938E787F96A0B08E84AC92
A19798B991899C9FAE94A3AF92989BA9A49C8E93A49096ADB591748B8A92889290839182
919C72867292A07E828C8B83908176868B8F71906883717A7F83748C92939788838B876F
718171745B8F7C888E6583817480776D768E7E928171526B75747E676B7671777C79676B
5A75747D866D4D70796D89707A74675A7D79505F6E6D71716972533B5C5B685D54596A81
61625B5B45393F505955596B72725F647566586B6658654965505F6B4E5E69476E534B49
4A676D685651625453505C3E54646A405C6D6C5876685554805A4D3B57394C4A595A5163
5D473438444E44FF
FF938E8F8E929392919FA6AAA88FA2A19CA08C7E9BA09B9DA79F8FB69B7A986B908A7E98
9873948399949683949A9BAA9DACA489A2AE9E949C929189AC9F9596A3A5939EA7A8ACA2
958AAF9E87A4A9999A9BA1987B98AA9A84AC97B58F9BA891A295A09176827E8282769690
8A8E8A909C84907CAA908B7568859690979296AAD9A3BBAB9EC1BDB0B3ABB4B19BA29EA5
A68FADC09E9B9BA878BEA39FA7B1A9A8A5AFAEB89D80A5A5969D8DAAA1B0A09C95B59FB0
91A88B93B699B09D92A09AA39CAFA99FA9A5ABBBBB9F919087908B989AA69095BB98A4A2
A0AEA0AC8EB9B27C819899A68BB7A2AFA2B99D819DA099869DAA91B0A3A79395A295908E
A3AEAEAE77A08B999CAD949B7E8D9D7F95878BA2997C959589828777997E959688A69495
728AAB9175ABB39C97A6969594A699AEB0AF90A0A6A29B9A98AF9C8F9B9893917E85818B
85A5A09292A4949B75A09B9088888098828B908686867D7E797C98947F7E8A86887B7F76
6D64726F8D7B75747E7D7C7369856787817693697374818263765D836781857A767F8C72
74627A76776759405E858D6F797D85716F7F586C6B7292766B675163645D444D605B5C59
6F6F676C5A35421E3F575E595F69605E66605B505356517C646A785D726F53625D584851
7972674D76576D5B585254546C50505B626174693F5768745C5B52874452625862554631
4F5354425E5C52FF
FFA3A996999D94958BA38A8B9C9BA685856E967E83A09980938792979096706D949AAD86
88898DA78E8AAE867E93856AB5B59BAAA59D9CA698A680B09CA0A3B2A6AA9D8E9B9ABBA4
A2B6A5B0B8A3AE9B9D9CA2B9B3A9B7AA9CACA69C97A08F9F8FA6AA887E84857E689E9D9F
999B9598A09BA9A595969686827E8B989FA88F9497AB9BB6BA9C7DA0A6B5AEAA98A0AB94
8CA7A59EA6A49FB498A9AEB6A4A4B789ADA09DA1859ABDB5A9A39F94AFB6A4B0B48EADB1
A6AAB0AC9EB4A5C4BAA3B5A2A09B9B9C8F9FADB4ABA0A2A8A59A8CA0B195AA85A39EA991
ABAEB2A9A49EA1A29BB5A895A794ADA0A8B0A492B58C8A8B8EB5B9ACBDB3AEA8A9C2C8A7
ACB3B2B0A1979EAD7A77959F9A92938A7C7E7483908E8D7E89888294659FA2939B9E96A1
AD8F93978F9C9E97B99F968B91AE948FB3A0A89B8C838DA2A188A0A7948EA69B7D928897
8891A18C90A19085858EA4868B7B9D86777E7075806E82788B7A8383869083858995747E
638B858A7A809D806C916E6B5262756F6E7A8084979F857C886585727A65676659747374
6B7A6D7D717B7F637B6472677A79698478777B756A74585C5F6566565B503D5150677177
7B7A635D584A374C57485C43495E5E515C62626140526C6770625B586E696D6171625A5A
3A5E5962385D606A464E47585653516F81615864626A555B686B6E4F687366495854604E
576E5D564B4A5DFF
FF8F91A98E8AA39F8D9099858A837E8A95AAAD979CA4B4AEA3BDB391966C009881A39690
877F7B7F91958B9A9E9894AB92A7AB8B949DB1AA9F99B1A39487A29DA6909CA18FAA8177
86A4A3A4959F9D9E9FA0B09DA49FA39CA48B9DA3B8C8ACB1B8B59A93A0876B6265778580
969898A09992918F707B8690829787A2989B988BA4B799ADA8AAB08EAAA1A68DBD9D7164
759EB19F9EAC9E907F90B4B8ADBAA8A788989AAE9E9B98918FB3BC96A59DA2AAA0A69E98
A083A7A4A8B6B7A0A5B290B2B39D9AA5949D9CA9A2AEA88A8BB1A08E9F9F9799A0AD939C
B29FA1989A99A990A9AD99A984899C9D93B4BCA5A197BAB6AAAB9BA09BACB2B1B798A5C0
BFC09B928D91AE8B9B9984919386877E89839094917C9B93907D837D8B81899894949E86
8D96678D858897899AA6969BAA9888AB9C9D88AAA2929B988F9D81A89585A29F969D928A
A08F828896999A8B7091868B96738C8A8B87716E9167777168788A968A697A868E857779
67798363696D7B908468788856767F7C5F6869848B6C5B795D6143947F6C6F7F5B578083
7A797B8D736A88857580727A80685764727E8383656C747C6C5B585F605D505E64617263
725E638161434F4E4A4D5C605A4F5C4A5B6D6F525E70575B6A6066705D6B49505F67444B
5C4D59815D4A6A5B5D675E5C495E5E6A4361595466657459593F6C59565E5E676A5D5062
5761414A52645DFF
FF919B94A09A9E8F9B9FAAA0969D93A49D91A086AAAC99A18A8AB0AD916D548A9C9B95A7
9186A090A6A8AA899297A298A0A4A49F9A9F9781859B7C8EAC96909AA8979DAB99919B90
8B86A1A9C0B198A29AB280979DA0A9ACA796A79CA3ADB5AE8FA5B0AA8A808D7A84868298
A1A2A3888699959C887873878F92908F8F938AB4AEADA6B7AEAEABACBCB872A08E5F0000
53888AAC9FA4B987899C949D937D8CB3A0A4B9ADBAB3A383AE95A4A9A9A6A294B9979E97
A6A8AE9CA493B093A499AF94A5A7939CB1B8B3ABBCA99FAC8C9391B0AA9FA3A2A6C8BDB8
B0B0A8A4AEACA3AEA0949D95B0B77A95A8B49D929EAF99B2B3A5AAB0B29F97AEB2AF92AB
A6ACB6BC9D9E9EA390818A989478718B9B978C9689968A985C738F8F94789596909D7490
A7949E77998F7FB39D91938F9C948A969A8F91A6A79896A9A3938E90A0A79E7296819D90
86979683988D7E788B95A3938C8690988FA1A28F8B57867E8E796F65798B85864769756B
7763697372839086706D7F8574797574824A7D6D667991727964486995788E6A6D696C89
856D756386787D6C79747682694E568877617576726C796B684E4E43725C5B5B6866817E
7B62695D795844354C613E525572717655787B6C696F637A636959755C64714C7B4C5062
5B6563615B4A4C6F6163444253515958555054694D5156695B654E49446A4F00315B5D4F
3E4A3B53503350FF
FF978899A297A998A88EA495828483929FA1A5A99F98A78DA1AD859E848A9CA39E7F8897
9899998F94A78A8A9F8D81968B9D9F918E729986A69291939BA5A0B6A1A4ADAEABA19A98
85A4AB9A93A0A18FB1ABA893ABC2AEA3B5949DB68FA4B6C1AFB5A0968A8583806E79887D
99A5A58977828D7C9589966C82868B9BA38EC69CBEB9A7B19EA3BEC7A9A9A0B58C2E0000
17797F9B9D8D9AA0AAB9ADBEABAFB495B2A09BAF93A69AAEBE9F8AA899B1A4BEB9A49897
808BA9A1A2B48A94B0ABBCAFB87382A4B2BDC0B799A79B9F97A6B291969DADA1A49FACB1
A78793B7AFAA9C8BA7A69C9B83847CA27F9EA1A697A98F93A2A5BE8E9EA5A6A4B39299AD
A2889CA6A174909B887D7E7B898C718B8C826F89A58283889B7F848D8A9A99719191958A
8895917796A07895849A97948C949185A1A887A59F869A95A493A4929E8BADB7959C8F8E
8892A0938A8A7E8E787A939B899290857F7989856E88596D617550848C6971656A76786C
7F6B706F7D798C76928681767166646C6B787252636F68647A7573837285848B82547170
7A6C7981767173776D58706D646E6F6A6D836654799C80707570616463464D6576796D63
6976877763524263605F4D576A505B6757575E607064686170636A56616256684B4D7D5C
5E6658576954664E5752504C5D54424A66576853695755463C536B535E5B65503E644759
564F6E425D6469FF
FFB79993909BA4938890A18FB796A38F9C9B86989DA1AB9BA6A09BA19C8A94A29C97889A
828C92AAA3A08C8FB77B9FAF84AAACB29399A5A593A0ACAC9FA9ABB0AFBFA398AC9DAC98
88A494919BA4AFA7A5828D9A8DA9998E979CACA1ABAB94A2B29EA497AA8A7B6B64666E80
94869B9386AA8D958CA37D849D829C9EA28C8CB2B4B2BE8FB5A8B79D81A8A5B47B390000
206D8BABC8A9A49D997F8E999DBCC5A29496B193B8868DA392AF9F72A89FAFABB3A47E8F
9E92A2ADC2A5ADA69C9A959DB2A8A59EA39EB7A195C4969CB6A17EA5A7ABA1879CA8A499
B7A7A4A5A9B2A7B0A8ADBBB1A5A7889A8790A2A3909D97979D99A0A6A3A8ADA9A892A2B0
ADB99F8A98A18A9E9B948281878E8C7B8F8C9D8983757C80778C908A978C839B9191839C
969593819786849B7D83968A7B76909098839097A2A89A909D9B9C7A98928A8B8D90A091
989094AE8A8589718D96749D7B8A8A966F97886175787F8A756586606881795E6C78726B
504C70627A947477757180707C62827A62624870765E88676E6177676C7A7C7063676282
807E746F7F6F6A7A72917D6D746E8B677364735E785A896A7062556E615A57578574787C
7C57674F515D44685353646564724E625C655C66596174414B6B576A586B6D5F61516768
61575A76604B4B615727596144666F785F46647E4F4344437B62554E3857606056506056
47784E00003C78FF
FF7D8BBBA08C9BAC9CA1A28487A99C8C95979787AA8B959B92BD8283B89B9B7D94999480
8E9291968A819D8E8887B09C8CADAFB0AA8AACA88F949C9F9DA794B3A5A8B6A59391979E
9FAA96918DA794889BACA2A0A78F8FB4B29F97AC9CA28BB8ABA9AD89929287745660686C
7D9BA19CB6919984989D9E909E978D9CA3A39BBC9EC4B9BEABA3B2C0ACA8B6A19B814B3F
5D7BA6ABAFACACADABA491A3A39BAFA0A1AA92B8AFA7A99DC3B3B5B0989FACABBDAD94A5
92A89F9CA2ADB79CA7B3A3A3A1A3A4B1A3A6A59E9F809CB9A6AB99A6A5A5B9B6AAA194A0
9888C1A7A2BCB4ACA29E93A19387A9958A9E778D8C8E9AADAB8F97949BB6AAA79687A2B0
A2A099A28B908FA08B7F8684958F9A8FA6A5808D96A480919F8FAE967B9D93978C8F8776
8E7877937CACA996949582947F969792898199A48AA0A4B2949790A38CA7AD819A8D8C97
92978E9E8DA4AD988A9B8677A5948B92686697758F8C8C826F6D62817776907F6D83657F
5D886D727F6F777E75696A7375887E7B728C7374665E687B6873736C827D6F5963877B90
76777B7E60726E607C8081766F7C818574768E7A607077844C6085565D535766505B5B66
55514A5D582951505F656A5F5C6F4E5E65735561745E6D66676064594E5465406252546B
644C4057605D644D60474E494E4F686162576B4A694B4E4861414460795C525347644E5B
5E5D5000005E4FFF
FF93799278A77B93959178898B737D9CA9AA919A98A0A6988A9881897FAB999AA2A7B389
7E869D7B86A7A89B8B8F9892A7B5A89C86AB9FA292AF9FA285849486A38CACB7938985AA
9A8685B2A0A3A8A996919A869F92958E9CA5959797A59FAB8EB59BB3B289898391927E7C
7E5F7A9297759A8BADBF98878D97A097B99E9DA1ADA698A590A0ADA2AFA1B0B1AA97839D
9F9EB4A3B686969DA39093A09A9B95A199A6BEAC989E7FB7A6A29F9EA1A5B9C2A1A59EA3
949CACA0B7B5A993AA938F9BA08FA3AF99AC87A29BAA8FA9A7A2A4AC95ADA7B69CA3A48B
989EA490B49AA3C4C5A0A3889E99A89BA0988EA599A1A089928EA493B6A3B09C9A948B9E
949C9B8F7E7A7B927795836D90998EAD8A887F78857F9290898E8A807F837B8A897F8797
8895A06D928B948B8A756883A2988C88868B9192AB8477849D8AA683A06DA69790707294
8C8A80719092A49D83A5889B8D898C7A8C7F7081635E78646B78756B655664556B726965
6E75666D837780606272787A5C855C6F7C686A8545626368635F5C7D730C00797377776F
7D6F7B7E6F8189898A5F5D6A826B6359757F6E5A7262727D785B4A674D6E3F5058473E53
68673F595055463B4E7455794C636562665A5F845F6762637C6E52524E41595767563F4A
69706F5A4E425A4E665E4046645750514242455D31655B5A2B443F4D4A60475760364960
57635000005050FF
FFB99D7FA29E9A9E8792A49B9AA4A0A8A396B9BBB4A29DB2A097A0868F7B88849CA89E95
9199A5ADAB9F9A9F859C919A7897B2B5AFA2B8B2B8B4AB8E99B5998991B1939BA499B394
A2A7AE9F819FA99590B58DA4B1B29D8C94A08F939D8D749293A19E9F9C9E89889085727B
737A918A80A39BC09B80938FA592A29EA3B2B79D98B4B0AAB6A0A5B8BFC19BA5ADA1A1AD
A7A2A3A9A2B69FB69D978DAA8F97B49D8AB8A7BF9D9FBDA59AAA95ABABB9A2928FBAB49A
AEA59FA689659D8BB8C3A6B5BABBC7AABEB9AEAFA69581A4A3ACADADAAAAAF91C2B3A79A
9C97A5A6B0A2A7A9B2C48997959277ADB8A7A4A7B59FA39D9EA28ECD9CB2909EB6AE7D8D
AC9196ADA794A0819E8C8B9886988A848C9C98848C82928E808E909A8496977A9E808C92
929570667877929C6468939C80899E87A8A198868A9DA98897908CA37A8E8B9D9986A19B
7A76828C9D728994876F9D84727E8F8398938E7E9791818E8567656A7B827E8F837E8273
80727482686E5C647F8269715E5860726964787890677C62605F7A68796962727E7D8387
878783797A757769776A5B637478768274716C84756F6160776E7870704D63463C445A60
53474F534B2B3047605E4F5E56636963356E4E71646A6A79694E6559735A576960685859
5C515C60344F6C4F25655254485859565328415F55505A45555E5B61655C554B4E47654B
554F655A33544FFF
FFB9AA8AAA8E957D808D95A4899EAEA290A9A891959F9DA6968E84B7A7AA87919793A4A0
9BAD808BA3B29BAD8B99AEA399ADA3ADAA97A5A8BB9F8E8B7999959AA8886C979E9697AA
AFA9B79AA090A69A93869E8DA4AFA98791A0929EB0AA949E9DA6A5B1A388887E7B907B83
7A868AA19481969DA5AFA6AEA2989A8F828F97928DA0BEABB5ACB5BABCA5B1C0B1BCADA6
B0C1A5BFA8BEAB9FAEA69BA79E9F9CA7B1B49CAE909896C0A395A5A9AA8AB0A2A8A5B2B5
A1A09A990039A8A3A0A0BEB0A9AFABA09CB1C3A0ACA0A4C9C6A19CD1B3B8B4AC9BAB9A9B
A5B6A1ACAAB59B9C988D90ACAD8DA1A9A9A59D9CB09E91A39298A29A9EACA09A9593A2BB
9AA5BD7E8496847A776A9590A89386929EA1929E847D808D9E6E869380AC9C9EA08FA496
948794938D968590A78885958F9F879090918AA0938D968E7D8E93968887A3968B979696
8FA39E8298619E9B878F95978F9887979B97819398817E747B886E6A8377816F8485757E
7368727586665F4E7881827F6C70797B6B7184686B6E808EA37D887D5D7576767071918C
656D8090736B85826F687976748369668284667581726E7A8481856F646E5A4A3A4B4E4A
5D5336563E4A43525B5D50716B5A60497660656075706D62646E60476B5C5B69885F5E60
4F4547686276676E5652676068585062504748566366504452536B4E5D7165574B564C59
664447534A474CFF
FFA296A391889FAA9786A3A3A57D898A9E9B86B1B892A2A0A189909B9471A0A5AB9FB2AC
9E777D898C967984A8A78F9DACABB096AC9FA1A8AC9297A99FA6A8A89E9D9FA6B0959AA4
AE959B9BA79596AAB4A4ACA59D94A2A0B19CB7AFA2BFB2A0AE9BADBFA9B4B6AB9A64868F
9A9997817E82AAA5AB89978D889188919F97B0A5ACBDB2B49FA0B99E9BA2AAB1AFB8ABA9
C2ADA5B9A39BA5A3A5AC96A9A799ABA8B7B9B5A7C4B6869CB2A1A8A1A296A3B3A0B6ACA6
B3A3B39F8890AE9289A6A4ADB0ACACABA4A5A5C4B4C5A2A9ACB4ABB8A2ADB09DBBA18A9A
B2ACA6A7ABAEB0A5A490A4A4A28EA08F9DA9A99CA0A0A88F98A1B8A7B1928F9C739D9C96
B0A6AEAB8A8DA1A88C8094848CA799919597939086888A7B8F9D848B9692808892879C88
A7978C6D7297948393878B919493718A858F8F9A8887A19A818475929C7B8A9792989F6D
8198AD908C908F8870758C898F7A7E8996708E73698B8890887F9A7D938880697A887072
70577860706B65797C7C6E5E7A7E7673725363775E68616B77807F71938C5E867E887E82
865E8462665E76717379646F74856A727C746F82786062637A747E81776B585246404851
2C545B4A4D604E506767725F76816F5D63756E5D4D6261727A716A5962736055645A607B
5E526E5F4F50585D5C4F466D43414F435B47526A3659645B53455F575D63515B6362435E
484F3D65475844FF
FFA3B1948AA09F7EAE898D929A929C8AA492AEA08F96A8988FACA1987D6C899AA288A689
9FA99CAB92656498888E9FB693A3A783A0ABB193A4A0A4A0A8A2909A9193A2A5A8A9928D
A5A6B99EA69E909F9099B2A0AAA6A9A39F9AB897A792BDC29EA88FB2BCCBB095949D908E
88888D959A84A18D74AC93AFAE9BA3A9AEA9AEACADB7A49FAAB2B1BAB3A39F9B919CADC0
B9BCAB8A949E8B94B296A0AC9C87979C979CB5B295B3A7AAB3A89D98ABADB1C0B7B0B0B4
95A1A59297ADAA9DA7A29D9CBAAEA6A2BEBFB9A5B0BCA8BCC0B4ABA3B2B1ADA9A1B6AAAE
A3A39F9EB39FB4B3C7B5A89E9B909A9A939A9EA5A2A9A0AEB5A491A3B2B3A1B3929B919D
A99189A292829E94999C86A899958E868A8F78857E9A8B988C9C7B8C9D86908B8D938A98
7E8B918F859595A38A9194808292A09D8691A173878F8D9583888C7C81959A9C9690A694
8EA09079A3A88F8A869797867A778C7A6E7472946E8480877E7A71808A99849E7E848D90
828D6A7B6678766C656A487080876B5C475E4F7040627677886D758C867F8E6C57868887
7B7E7589678A8F5F6973897B76477C7B80738976886F886F81746685807B60694D57493F
4435455755615457667A555D5F565A6E67606D7F5F50574A5A605F4A6B5C7C6B47634650
5863525F665B575F44667364425C545A48545F5A59565B4B46493158523F543D50614A47
5E3B574A563B4EFF
FFAE92969D9397A38B81929789A3BA9EA2A9ACACB39E96867B9F98A3828B9D9EA3AD84B2
9493A9979676879593A9A9AA9C9E9CA6B8ADAD998998A0A2A0A3948F98A898969896AAB5
AFB2A1A299AFB7A9A09D9E9A9395A1969A9D9FA1849DAEB5B4A19BA1A58DABA9AD869980
7C8E9790929C8689A1728A8F9E99A6A0A49EA6BABEC6B5ACB3A195A3A0BDC19FAEB8AEA4
9B9FA9B598ABADB58D97A7ADB6A4ABA2A2BEA0AD95A4B6A497B1AF99A1ACA09FAAB0AAA4
B6AAADA5A6A7AAAD96A9ADA3AE9CAB98A6C7AC9B969FABA6B1B1CAB9AA99929BA2A6AE95
96A6AAA0A891929E9AA6B3919AAB98A0B0A7ABAAC3AB90829A9EA4B4BF99A0AF9DB5A3AC
A39B8CAAA47D9FA2917A93B3A37C86848C8496767C87877D9D82ACA47BA387959E86838B
8D7B80AC8AAA7C7EA88DA09B8395969D8A8B839690899087A3918C7C8B8C9092939F9A9C
B3849573778F97A08496907888A2809A89846C8E907A8D697A6881599083766B7B7E7573
816D61656874755E5E817C73716C787E73687A6648716380727A697977818C897D8C7C88
7E827C597C787B8A7B876D75636579777C7D6E8080876A67647093708369848867556770
615C5565655A6D746B6964646A66716A615C6A687659505869586163483B4B5E66536669
6E6D4832605F585D4F49504C594E57575C4E534F564B676452482A5B534F405460606157
525F3640654F5FFF
FF959290A19A95748D958A848F929C9BA9AA9CA79FB5AA9D98A69BA4A09996A891A298A8
AD98A0898E9FA1A59FABA0949CB695AA9BB19CBBA6B297A491909BAFB8B0ABA6A4ACBEA9
A88E8DA1BAA39DB994A98AACA292B3A0AEAE9790C1BABFB6AF9E9EA8AED6B2B2BDA3AC9E
96868F929B9BA19FA1AC978E8F8087A6AE9DB3CA9D9AABB4AAA9B1A39ABDB7AFB5B0C2BD
9FB3978CA2A9B69491B38390A7A58F9DA0A9A795A9929DB3A1A2A4A4A2A59F92A59DACA1
B0A5A2A59AA5A7A492ADB4ACC3BE92A1B1C69CABBCBDACA8AA93CEC1A7A497ABB3AFBA9B
8C968EA79BB0A298B1AE979A9A9FA3A696AA99B2BDB194AFB1A1ACB8A799AAB0AAA8A09F
B5ACAAB5948595998B838B888E8E9B6D7FA2906E8A8B9983808E949C9696938181898A8D
748F918B9C84A89A8D9578A47D9195A7979B938D6F909194A29683858C8B85968CA28E9A
9185627A8E979A7AA18A806496818386878EA88079797E797F81768371826D61878E767D
6C767D767D7B83656754656F6976696A726C706F71847078697B8270827B896571778375
79827980848B676C6D816871858B6C91868D5F83705E83758D66736B75747A787F72946A
595A675F756E6C696353655B625663636A717467515A48546A6C5B787D6C5A506F645050
58635C69604D6E57637056665C6461544F5B566852475C4E4B463B23735E4F4D52515561
5F54525852535EFF
FF999492A791A590A09E96AA8795AE9BADB897A799A0A19CA29999979793ABB29FAD8A8F
9DADA294A299BBA897AC9FB1BB9BAF9FB9A0AF8B96AAB2AEAEC9C2C1AC97A9B1A6A1A1B9
B9C589A797A68DA5A3A394A6ABA47BA398A7ACC0A79FBC97A6AEBCA5A5B6B5B9C3AF99A8
9697AE9C9AA6A5857B90A2949FA2B0B2AFB7BFA5B3AAA8B4BB9D909AAEAAAFA4CDB0ADB6
C9A9AEA6B796A5AA9DA4899197969A91B09C8B9AADA9BBB6A08CAB9CA78A9B9C899E99A0
BEACAE9AA8B894A8A8C1AFABB28A99A59AB7C5BFB19995A5ADCB9CA9BAC595A796ABBE9F
9B87AB9E9E9E9EAB93938C8E89B3B597959FB094969B8B909DB2C09DA58DA4A8AAB0D7AE
ACA69AB0A4939983909C9185977277888C8C88786E899295917E8D8F8AA096998190826A
7287B0858FB393A289849B94ADA7B0A28C8E6E9B8E839599788C89789B9E858A91917AA3
A2A37F9E88998481777C82847785848D727B777E928A84777E9276558471724F6A7C7A7C
6F7775837E96715F434F7A857C68747A658361746D5258758E7A94767993745969977B74
8374447281727E73776B796F7172767D74626E617A817F84778A5B7E5D686E7B8F8E7E73
746D6A818773628868667E716C5F575F5E4F67755F5161416764646E5C6A51395F50596C
425E5445414F64555E756659625261475C563F445A4D5F5258595B5B394B4C28534C4F60
5149494F5E604CFF
FFB18F9CA19D8BA7949B9EADAA9E899EACAF8B8B9C94869686A49E929DA49AABA19B9A93
81AAB1A19C95948FA7B0A69F9EB1AABCA4A6B1BF9ABCA3C2BAA9B0A7AB9478A99EA29697
9E959C9F91B29692989795A6A9899AA4BDC2A3AD97A3ACB5B49BA0A89AB3B1C0ACC4C0B2
998C9899A273A9A0A39C8B8E799D8FA598A2ABA59C97A993B2A7AF97B7B2ADA8B4B3A4A3
A2AAB4A9A1BCA5AD9A8CA99FB2937C9697B397849BABB1A59E7287A166A6A38F8CAAAFA1
B2BAA99DADBD9DAA89BAA3B19CBDA5AAA59FAFB8AF9ABDB98EB0ACA2A5918EC0949C9790
9CAAB5999CB5B4A896A8A28BA08F9995A9A4B0B4BFA89991ACA09F839DB9BBC195B0B0A8
AA95AF99947D998590957F9583857A8A828C84627D94968A9F8D9E99909594979394867B
7892A0AC7A8B9C938B9A8C829986A18B93978B8A8982938F8E919FA08C8E9A8D8B8A999B
958C9F869786978298987E8983849081788183788275704B6876768C78717C7566686E74
7E74847B746E725C66807D656094796A775D6F5E5061446E67786B6E745475946D686875
956679696379808B81837E6C69827D7799A79A81806D5E5A7A706A69767F6C608B8B707D
777B64816F7F85584C616462416D6C5B6270544E6777645C494E5065675F516073585A4E
5F5D65543644495640225259557E40534B2B45484F44563A4A5646563B4D445139545C5C
52575941546643FF
FF9EA4A09D90A19A819D8F9690949B888A969E9F929A99A1A9AE9595B495A484A7999296
96A5AF9FA49D9EBCA7A59DAEBAA0AFAEBBA9ACB8BDAFAAA497A094BA93B393A198B0B2A4
948A999CAD9CB5AAAAB29C989396AA979FA2A5ACA5B4A391A8B6B2B79DB3BAAE99B6B59E
A99E7D9EA2AA95A492979197A997A08DAAB6BDBDC6B09A888E95ABB09DAFA0A6B298ABA8
ACB9A3A28A9CA49D91818D807DA5B690ABA4A4A59C8A9A8EA894A89695AC8E9FABB2B59B
8EAFA1A5BAB4AB95A8ADB1A0A89398AEA9B5BBA0A7A7AEACB2BFB9B1A8938C9CB49BABA7
8798949B9FA3A4B3AA8FA3A0B0AC978CA798A1B3BCABA7BBA096A5A8A6ADA59FABB1A5B4
98BEA7A2897F85847F76857F9A8F768C818C6B87858886948D91A38C94868DA29F7F987C
6A979D8FA28A9C8F9C83B2898F989E9B9697818988859682797FA497886C7C889BB69A96
818B899E969B8890939C797A7C707A8B888980818D7D8091596B7471618E6E6A80646676
747F7A5A7359526E64674E74596B7A816869687270787B5D577F8D7D6466746A978A8584
84887A75698391877D7E787F7F73847F7CBFB47774695681956D6A7581767D64556E7C75
7B6C627E746A7873616C71736D536A75794C716C73635D58605E5C645A69655C62587554
69565D5759484F5566565855644A3B45515740444A4154525665604A52594E475153515A
47424E4F34463FFF
FF998DA2919BAFA092A39A988BA88DA792969B9E928BA4929490918A9B8BAF9C8E9F97AA
A491919AB09BAB97AE9FABA9B1B79BADB1AEBAA990A1A1A6BCABAF969F84C5C1B597A79C
AAA7ABA6AF9CB1AE978FB6A7B0A59DA0B8A3A7A5B1B6C4A6B5A0B893A7B9BABCA69BB099
B5AB9D9FA086909D9295B0B99E8DA2B1B1AA96B5C3A4B8B297A3A1B79CA4A89CA59A95AA
B6A5A7A895B29793A68F95A1A5A39D8F8CA8A98BB4A694A2A1978FACA6A3ABA6A09E98B2
A4A1B7B8B3BC9CAB8E9B8E9EABB9A6B9B4BAAEAB99A7BAAAB4A9A1AF9D938EA6B292A094
9E9AA8A5B1ADA69894B08A99AAB49CB09DAFB497A6AA99A19AAD987EA7AAABABAAA69A82
A5AFAD9D8A8F8C86A990828589848790927E76659C96859495928C908DA8AB9C80948892
9F96A593849C878D94856C8BA29B9E7B80988D6F8B8C918BA89C8267816D948790967289
98A4A2988B8F919D888A8A9282959291908B887774767F817676818C8659877677797B64
847F757353656D706C52626868807A6C785E715C5364747B7E83826C898F677A70618790
6C8B7D788A8772816F6E756770746D86777F76796462707B6E778570847F6D6A90756577
616B827F7C797C617857554961565E4F7165786C646F5A505A41535D68636B5B5C64605B
5D6D604E65583C3E3761535C445D5E6C5D52565B465A473E4B4C54454551425A49374955
453A544558374CFF
FFA6BCAD938B9099B2A29D919BA8A6A6AFA49190749F92929991A69095B19195889E9FA5
87A3A1ABA89DAE969DAE9CB6A9A5ABB4A79EB1B2BA97B7B78C8DAAA8A1A8A1B297B89299
98969BA1A6B7A8AA9FBD9DB9A794B6A89C9AB4B1AEADABB7B2BAAEA9AAC39DB1A593A892
B89C96A59E909CADAFBDB186B6AFACABB6A5B8BEA8AFB4ABB5AF96BAA19698A7A3B2AAAF
A18F8EA8C5A188928AA1AEAA978F909294A497A2A89D9297BF9991A6B7A2AC87B080AFA9
9FCBB0A8A5B199A6BBA385B7AFB097A4B4B3B5ADA7A7A8B07B9C85AEB0B6AF9AA8C2A39F
96A697999F9CA8AC8EA689A4A69485A0ADA596A9AB988D8F8D959E96A19CB9A6A99D9CA8
989A9A92A285897E7C8F7B82806E75906B867F7E8D83897E8F83808F9893877989939091
8A8596AC85A080948B947E7998A6818FB26B94917A8C8799958891A2848FAB6F7D658C95
9B899C898F7E7875998B9F9C8988697C90A1898373868B8C976475847D8F81757E747C67
70858182736A63575E725B783D61675F67565B635F646676647674757676877877756E80
84757F736577799285777179867E75757769826E6E7A858665576F7862716A7E6C7E7377
7054576572606D6B5C605E6D666E7B6B636568836966714B69564C4A626868744B79605D
6E5B6B694549736463515B696E565A4C426A3B57545848724E4159494C55565237435B47
534D4D48464B58FF
FF81A0A391ABA0BDAAA092978CB1AAAE988AA39D9D9597A69BA6AB9881A2A285849E9C98
AB9CA199A4AFBDA1B3A0A59AAAAAA38EBAB3B6B0A6B8A9B5AE9C9EB1A5AEB59B8C9B9FB3
8A9F95A9B5988896AAA6A0ACA2B4B0A6A0A5BBBCAFBAA695B5A4A2B5C1C2B5B2A8B4ACA4
B0B7ADB59FBC9D918EB8A9BCC3B2B7BBC0AFB8A8ACBCC4B3BBACAFA5B5B8A3A79F9E95AD
9EA197A2AB9EBCAD9B79948C9C98A0A487A39CB3AFA9959F9EB7C1899CB49FAAAEBF9EAB
B7AAAA8AADA291A89FADB18AA4C284BDBCA6BDB9C1ABB5BBAE9C9FBDB2A3B49B9E9CADA5
AE87A7C496A49A8EB5939993AE999998878F9DA9A5ABB49D87A9949FAA9094B9AFA4ABA5
93A4A6998D8B99B1868A798B7B718993758A877C8290A37E9286A18A99809A9096886E96
917F8991788F8B8A9E8C9B97AA94847D8B947F788E8B808AA3A3968A92868B9B8F827E8D
98A2A197A0907C8C937888939D857E6B987E707B8D959F9A7783678290848172857A8E92
887984796A646A545F4F4C57606B627B676562545E755F57656F90788374897788997A8E
5A5C5F706F7B73756F6D89888B856E7A896C5F5C6E7D755C7E606A777A5E766A896B5465
614E636D786E6F6F727C5F5678616A645D6671745769565A674D54756A505F48654C4A4B
6152604641414B5B5E565F575256445E5F593B5C6A6E6A5B57484F555F543B4761634754
4E564F465A545EFF
FF82899198BA9A96829B71B78786A09C8BAF998C9C9A9A9AA393A18F9F9B898D84839594
939FAA929FA1AFA2979FA5B0CAAAB4A49BBC95949EC2A2B99B94ADA59D929992A699B990
A1B1A1A1A2958EBA9495A8B6A9AD9892A9A98D88B4A89FB1BF9CB4B4BAA3B2B6A2AE97A0
B7A9A29AB1B1B68DACADB5BBBAAF989EC2B6B0B5A292AAC49FBEBD9EABBEA89EB5A2AFA5
9DAA86A19491899D91A68291829DA59FA69688A99C928981A79DAE88ABBFA4A2B2B287BD
9EAF98A7AC8A84ABADB2B3B7ABAAA598B0BEA8898D92B7B4A9A6A8A9A0AFA8AEABB2A9A2
A59AB3A4A6A0B7AD949E98A0A5AA968BA6B6A2B39FAABAA8A4A5A5C093A697929A969A7F
93A48185B5A17D88897B858C84869A7E9B87806B8D948897AC9389808778959E78879594
8291988E878A87808E988D757C859761738A887E81867FA283998BA3907D94998E94788B
848D8E8389919787A094A36E8A9774848F6F7F8F887594736F75768C707B8AA48B77708B
8B8F827550655A4F5E765865655763695464494152595C4E6F4562878262658A757C6974
737B8A8677698B7E827D70888387B67E78846F5C7574847260746B646C796B7E7A756C6A
786455737C74715D5A38556A5169695E564F6F725B444C005D61584B47595D465E57596C
66724F4D50545F655A60614E5947513960404B5B57566A70573F3E224F66515D43474B1C
2D4C4A39424F5EFF
FFA78D979D91A9B29A9B9593AAAF98A9A0ACA58E9FA2949C9D9D92938799A092A293A396
9F8BA2AA9DB2A89C9FBBA8B9A3A5819B889F9EB092A2B39FBAA79389A7899BB3ABA2A1A8
A89F9AA2A7B5AA8CA1ADA5A4AC969A95ADA3A2AC95AAC5BDA19FABB8A3C99C9FBFB4B5B2
BCAD9FB1BBC4C4A58CB2C3B9AC9B9FB7B3B8A6A7B0B5A5B9B3B8AFBFC2B1A0AC95AAA3AC
B995BBB169939AA2A19AA1B99F8993A6A886909EA69C8BA698BCACC1AAA99AA99FA7959F
AFC1AFB9A2CFBCA28ABA95B5B4C09CA6AEC0C2ABBBAE9EB99CAD9A92A69163B6A993A3A2
A8B793A799A0949795A29D7B8993A0ABA79FA08D95859CA792A19F9D97A592889696A796
A79B918C8C9697988E9AA777838B868779818185AF8F8E846F91949F9A81867F82A0A67D
8B8D8E7E6B8C768D9086987F9B86618E897B886B8D9B959BA08B93776A888E8C907B8A93
928B8F838F867F8C96A1837C8C767C8C949D9D8E7E7B6F79747468867F7A738976858971
847F767E60005B5B637A715D656D5F6E464C5B6B535A6B6D567B765881767D71796F777A
8E7C837D60816C7E6F82776D7592757D6F616176626F686D7A64537A8597625C7B71625F
6A646B6F4575667C7F614E5C744E6359605F55594D4E31003F4049286B5F3951455B6068
4C563D575E65676B6D5460505A52525128465155577A56494B4B5B484A54604F4D3A5152
5B5F5844463444FF
FF9CA5A6ADAAB2A5B6A0978BB095988E999B9CA46F9B9DB38F7F9C94ABAB96ADA09D9593
938D927FA294B5A1A0A0A8B7A2B18F89AEACA3899FB2B0A09C8E8B82A4A1AA9C9BADB39F
A0C6AEAEA1AEB69C9FA8BCBBA9A5A2A098C19595AC93A7ABB5A5A3B8A6BBB2B1B2B0CA97
96B4B4ABA2A1ACB3A5A7B2B9BCBEBAB599C5ADAAB5B47FA19AA1BEACA5B8ABC39F919CA8
9EB0B8D29DBBA6A9ADB08B8EA4ADA99A83A7799A81859A9C8798AA99B388A0A7AC9FAE99
9E9FAA9DA4B4A1B4AABEB2A99BA7AA9CAB9DBCB1B0C9B09DA594C6C989A9939FA7B4B3B3
96B09CA9B6BBA4A0ADA08C938F7C899DA9B6AEAD877993ACA198A39991A7AC9C85AFAF95
989093889AAEA3A19B94ABAC9399979B8BA19384978D8195827F82B192A48AA3828A7D8A
8A93A18F96959D919392958B8C968D928983888A8C8D7D9D849497998281958C989E9283
B59B93A8887F98818F9C8A95878A8C80886F7E7F7A7B8D8C8A848F8B6E7C667574546B76
68695D7A744A4651614B626B684B61466C5B5F60645E53616B6D6C78767A887E6C6C8565
6C866E6C776A7D6B7986707D816F72766E7C8A5D786586716E7980787E82886B695E8766
67665D58576F756162575B6263675A6A6B5F606A6A6B704C3A403E393339393752484A5C
46636745685E504C4E5D4F3A495E4A3F474C53695C4F4A57605D4755425951403F594B36
4A3D43444E5758FF
FFA5ACAE9D8A848EA6ADA0AD8E999A94A7A5B895A2B19E999490ADA89CABACA38E9B9797
9D7F898089A39AA19CA09C93B4AEA9978D9F9FABA499A0AB9CB4A599A5A697A2909CA0A2
A1AAA69D99ABA67F86B9B39BA7A39CAFABACA68FB4AEAAB0C4B098AEB2BDCEA4CAB1B599
A8B2B395B1A8A09BA5AB9EC5B3B0B0BFBBB6C5ADC8B1B4A1ACB2B2BABEAFA7A2B2B1A9A7
A7ACA68CA498A8B0B59896A6A9AFA5B9B19D9D7F9A89809AA8939AA2A7A19BB8B7AEC0CE
A196B09DA2A6B6A899B6BEA5A3839D91AEA2A096A290A986A89DA8B6B9B69BAFA3A29CA7
ADAA97A298AAB5A79E9F948FA0969691A998AD9492A0B9B0BDA69AAAA099A2A096A0977D
7496A97274949EA9A29894929D81879BA18C9D988A787E80A58A938F8D82946D88879793
909888818C938D997C80777F79A38C8E938D89758190849281A28F899C858B8079929087
838198858F8A8D81947E728D9D8784867E88837D5D888797947B908A7566766A556B7887
70836B768B59666E746262714F5177736F7758564A506579746C766D4D58555188787172
6A6F7A6C7A658E7D83777C866E6B536B75896A6D717B6D707068636A7965696C51565D6D
696F6B738172585E58536A72748060606948556D526254332B2A39512E3A3C46443D4930
4E4C6458525C4851694D53452D3C4654494D43525D615C5E484B5848596859544D3E3F59
4F003A494E4749FF
FFAA9DABAAB4A3B4A5A0948CA49694AF8B939D9FB2A08AA8AF9F869D9087A0AB9FA488AB
9F8B80898C7E8AA6A4B0A5A79AA4B6AD91A0B79E94889FA2A194BAB2A89EAA90ABB6919E
A09CA89CA2A3976F9DA9B3B9A298ACA5A4BC9E9CA8A4AEB5B4AB99A8A4A8C1CAAFAFB5AD
B092B7ADB2ACB5BCA9C3ADB996B5BB9EA7A1B6B6AEB0B48EA1C9A7A99CA893A4A1A6ABAF
A3A9A6A098A4B19BA0A3A49FA58C82819F969B9688949C9F99A19C959AA7979C9FAB9DB0
AE98B5B0AEA6B4BA90A3A4A3AAB6B6BCA1A0A2A5A7A69E95AD9EA8A4AFBAB5A3A283A89E
B3A4A7B49A9A8D979293A4979A97B293A1A9A5AAA4B28EB4A99CAAA39AA9AD928F9AA3A2
929B989C89848FA0947A9C85A19585848B80A69D929885877788868F7C8A9EA09293988B
648C7C73878692A28F90937E6F798293949BA78B858BA187919E6E7279878A83888B7A6D
748596857F7E8C73A38E888C749081789A8E8795698882737880778884888E7572728B8D
7B816E737C674D5B42645D5C60677E676B5E686262747275756E5A766962926A6257786F
6F6F8174677283877D7F7D81785A5F7E767179796E7771656B847A7B6C846F72716B6371
77666675686671775E695F4C53575D6A5A554940595F4936424E3E273E39353A2F333D4B
484B58634A583D585D3B475C4E3D2F4B423E55685F55414B535855524B41373A47533E4E
4C00284943433CFF
FFAFAE91A18A9CA0A296A0958BB5A0A1A6909F9D75919A97949B99A59F93A9A58EAEA485
8EA09591BAA4ACA7B4A8B0AAB2A993B2A8A5AEAF97A6B1AE9DB6A7B1A096A4B3ACB2B18B
98A6A993898B9E9AA29B9AA596BB8EB8C2B0BA9EA0A9ADA1ADBA9BBE9FA5B9B9AFB19BB2
9FABA9B7A3B6AB9E979EB7929EB9C3A5B2C7B6BBA0A09F9CBEACBBB9A6B4899C99A3A6A6
B4A5C3AC909DA28BA8ACA3AFA2AB98AA6D92A3969E979D8A98AFA0A097ACB198AF9A89AC
AB879AB19DA096A8CBB194A09BA1BDAEA8B0BDBCA3B0C8BBA4B1B8B09F82A3A1AB9DA589
96B0AEB98D8DA69BAC9C9DB79CB8ABA0AE9CABA79FC1ACA2A9A9ACA0A48E8CABA79AB38A
AAA37D9E9CAC9AB0A18C95897893899589878E8F97919B978B78748078A88D6886837C7F
7F9B908A91989D866E988E868B987F868F898C8A748E8A8A9F9C82919C85898E5D809C85
6F778176888E9A958C878474727E83908A827A8193827B8494735D7B80807F8E9079717B
77636F86716E604B5D546B6E63526773674E6B6B81545E6A6A566468816A717364765575
71776F796C716A647C7E74655E898B6D746580867B716D9D82816B716D6177826C5B6A6C
71686D5F61507374664A646B415F7376734668594955414F363F2F344D60593B34392E52
3E48525B565748483A41534C425442424A3D5763445F3F42494C404603572A4E48451E4A
60474355564547FF
FFB0999D8C84A3A8927A8F85A69B989AA0A1A19D968F8E8C8C7C94938EA594AD9B9EAFAE
A48E939390A79F918EAAA2B0A59F9B9FA39A97A5A68E879694A7B9A5ADC4BB80A1AD9684
9BA7A195999F9796AFACA1B0B1A3A0B194A1A3A7B7ABABA2C7A7B5A0B7A3B5B892B2A9B6
BBAFBAB4B2A9AEA7B8AE8CA6C9C594C5BAA5BCB4A9B1BA9BAFB0BBB5B9A4B59EA6A99EB8
BAB19BA09EA19EAC8C99AD908C94969DAAA081949B96A48F958EAFB7C1B09B8F9487ADAE
B89990A0C7B1BA9C9EB5B6B6B8B6A8ABB9A8B6BEB7C6A081B5B2BA9C93A5B2C09CB8A69B
8FACBA8CA9A495B199A1A4969CA48EC19EAEB09EAC96A28B9896A09AA1AEABAD9494A693
8B9A9E7CAAAF9291B29B9D889B8EA3879F7485919C767E848F8B74728F82809A768A788C
A696807D808B7A8C917F7D918A98858870808E7E919A9C919BA08A8C7FB0946D7E90827F
6C678D8A878880947385877E817D87907481888373778961827969708B8887867B649666
7B77897170617051104C565D5B5C6B536262665D616E6D7066516A52646A6A86766E6B76
6A74667C7D717D80796D746D7950859571667780726878657A6C83717D6865735455697C
745F6C61755F5B6677815B6A6A6D7279675F544C4F3C34473F35234256583F4E572B3820
2C5C54664F453D30343B5D4E36523A3A4F51564E5D425957534E6045535F445447575144
37564B2C423D48FF
FF528891858C948F96A09EA2A8929B989EA1B0B78F97A08CA383A5869A9D9EA9A1BE9A95
A59ABFBF9A7E9B99A6A0A2ADAB9FA2B2A89EA2ABA29BAFAFAAB0A79FC2A7968FA78A999D
B4AA979DB1AF8095A0A3AEA49DACA0BF540096B6B5A9B0C2CCBAB397C0B3B4D1A9A0A4B8
C3CFB8AEB7B6B7A3A8A9A99CA9A8C3C29AA7AAC4D5C3B6B9ADB08CA2C7A4A89FACB9A79C
9A9C9FA9B0A89C9CACAA989DA296A69C999B9A96979DA090A5A89F9FAB8CA59F8EB6B19F
A7ACA8B4A99FAC999CA19A9D9FB8AFBC9FB3B9B8A1A198BBB0A6A3AD97AC9E92ADA2A8B8
9D9AA8ADB09D939A9A8EADB39197989D9CA97FA6ABAD8196A1A8999BAC9FA68E988DA39B
9E87968C8FA097978D8FAB837F908F8166858A8F8B8E9D879D8C7F82969C99897F3F218E
79716E8F9D87A08A94798C99869199808D859B7EA383918F7A8E8D838D767C885D5B7E91
9891A097847C787A76967F9788848D75708B837E7D867F8B7183717275889F75756E6B5A
94705F57786C55595A58574F6E5D636D724D4C6950556463516E6A8086929583847D657C
6E6087766B727163687C6A89716E646965676E5D906D74666C73685F595A577960606B6B
5F4F525B667E73716859647B6D546E6C73774E495030274F51396E39535339432E561F35
3334264B5540463C4A42507341365D57534A584E413828434C36514E632E594F59536A52
554F4F4E504A39FF
FF8A90A07C97ACA09EA0A495978792B6A4958C9AA8978C9880968690A2A09EAB9797B29B
A5B19FA2B088ADA3B6A3A3B8B4A6A99899A4979797AAA3B2A7A9AC90929DA1A5C19F9EA8
A5A7998AA4A4B3B3AE98A1A3B1A1B5A59594B2B59FB2A8B2B1C49CB1A8D1D5A2ADB490C5
ADD3B5BF9DBCAC9D96AFAEA7ADB8B5AC9DB49EB1B8B6BDB0B79DB1A1B2989DB19DA19B9F
A4AFADA1A79EA2A59E8FAFA0908B8C9498B08A8888948D98887C9AB1B893AF87ACA6A6A6
9BB8969DA8BBA9BBCE9591A7A2A6A5A4B7C0ABACBC80AA9D95AAABA4AA76A09E8894B793
94AF88B99A9D939F9EA0958596ABA0ABA79BA7958F89A0988383A7B18699A794869FA3A7
A5A3888E8F97B79897A08C898F7C828C6D86988E888C6D8A978E8786998F92897958488A
87837C84917B9B7188ADA9929FB17A928F8584927E95887C9C8788978A939891827B9476
856C84986E7E8D928694885A7698897B6C797A7D7A7F6C69727582768B7168746C868877
8D7E74636B6D51636357665F4C5A498963676D6363655C5A68645D76506B6C72606C705E
7A78657686936D738164735E68957974796C755F7399746670697173795F75778F6E7961
5F5365716B70685C6162655F6875686268704A4B3649343C2F4662714E574D52573E2E29
2B473F43305550403C4B545858635F713F39535B66645262565D68534B3E50403B374150
4A42353C4F2833FF
FF9DAD8F9FA688949A9F91A89FB0B3A5AE969D8AA0B07B8B9A958E9E8E938CA3B0A7ABAB
9E999FA89D989AA6A4A9AAACB698AA9BA991A2A1898B9B95C5B2B4A4A5A7AAB5AAA9A595
8FA6A1B9A1A4A09FA9A5B4A4A393AEA991A9B59CAC97A5A4A3ACA9A6BAAF9E9398ADB2A8
BABDBBAFA1A890B5BAAAB5B0B4A0B2BBB39ECAABBBC5A394B5AFB0AE99A9A2A1A6959EA9
A39F9E8FA2979092A29589909A909698AD90888B979CA686A18893B0A394AD979B999194
AE9C99A4A7BAADB09DB6A8AEB8A694C3C294A3ABAD2780A28BB8ABA09F8BA79AB3BC8EB1
959FB0A79BAC8F92939290798794AFA690909CB38C7F9CA7A7889D9992A29FAAA1A09CA9
9AA08D96A5948F9634868F91886B7B74A191A09E8A99968C828B90928F98A19676A68D7F
7282858389927987799993997496999D8093A2898A8A7E8B798196828B878E847C6E7E61
8A618F847C777590878D8076858881737A7573847B6F859A8285525A788273756E56807D
697571817C6854674D5C6073774E754D70716A7B6C7359705C5D795C7785748576727A97
8373665E70726E615D706366615A847791696378625D7067605E5D5C755D59787160596E
647077795F552453694F4E6A686C6D5C6166584D5B433C284C424A705E4D5C4542353F31
2A182A5A444E4943403968594A57464F495D505A4C354E3D4E564400424F534D5158544E
594F4246324B39FF
FFA294A1A18696818CA4A1A19B848F9B9E91859AA3A08EA29F8B9B96968A96A09EA0A9A3
98857D9A919499AAA89F96A995B5B1BB9BB5A6A6B59EA6BA9B97A9AEB1A091AE9792B999
ACB5A0A990A3A7A3BAB6B2929BA89BABA8CBA7A8BCB6C7C0C8C7A4C1A9A19E9DB1ACD1A5
B5CEABB48B9294CDB1A5A9AA9C8D999D91A7BCB19BA1B9C0BCC4A9B3A5ACAA99A8978597
B0BEA1AD90978FA096A1A58491909076B195909180A5A8AC8F949BB5A3B1B8B1A5A4B6AC
9877A1A5AAAAA0ABA79CC0A59A90A7A99DC9C3B6A98D9AACA9A0B49E9F7D87AEAE7EAC92
8C8E9B9BAAA09E8599A394BBA3A893919BAF9B899DA09997A89FA3ADA587A5B392AB968A
989E8E788A9BAC9366908C82877D7A8271828EAB8B8A978E888C8A90977790A791967C87
8275837D8283A896A0758E93929AB1A09B99636E71837E8B90897C7585878C9492837C9C
8B7D7A897C897C89928A8D856F8A82647675817D72737A7E93656D7C7B7679808B8B908E
8C8D7B79804363556854548969675F7071586B6256666168685C6967615E657A7B697474
7575666D66597E5C6A6D687273707C7A5F716A527E766553567B858679846B6C6077683C
6C6450544D6B5D7E595C544A525D52646D556F4D3C442F373C4A524B4F61434D4341272E
3932343A43585A58435A4A40535273866F5E544841543F5A545D542F464A395C5737553D
45504C3B233C40FF
FFAAB0A1A4999998AAA998ACA39E8F9E8BA5AA94A6AC88B6A3848D888B8E988D8F999586
989A8E90949CB2A4B9A0A1AB9AA3AC99A1A3BFA1AAA088B7A7A0A5BCAAAEBCBFAD8D7594
93A2A0A7B1BEAEB5C1BEB4A8B5AABBB19CAEAFBEAEBFB7B59DA9AFB3ABA2B399B0AAAAB4
C394A498B2A2DDB7AEA79E98A69CBBC8CDB5ABB5C9AFBBB4B79AA3A78AA58CA8A78A93B1
AAA09BA8A18F9C9191A589919C997F99AF8E8E98A3ABACADB2ABA3A99FA2AFA599AA9DAE
84A29B95AFC5BFB8BAB0ADA39BBD9DAA9DB8ACB9A09998A3A4A5B8B6A8AA9BA39CB5B775
93A0A5968590BA9D918FAC9DA4A4A6B08E798E98A1A39B92A4A89A8F908B9095CA9C9DA6
95A18D98A499999289937F82836F8E8A6E8A9081AF908F7695807188828A8C8B908C7E75
808E96797A8D7BA28C879A8C8D9290AD928380967C84897D72969C81859A7CA0928F8E91
7E807D7D879288888F8C809B8D927F86726E738A878684806D896C606F838E7D7F897879
7B72867D7158627F776A607357657A57797178605B816566437560696163716A76647F78
738473736259727A7E7E6C736967668158726B745E4B5E6A6F5D68666A607B5F4E5C515F
4F5952514A4D51716B6C746E6D62666B6C62515B3D244539333A3E455748573D5F445A1F
2434232E44475744616D556153584A525B5049374633464E57634961493C514E3F4F5137
404A433B393B33FF
FFA494BB9BA4AD9C988F9A8EAAA9BC8DA4ABAFB59B95A9A29C8D8E997A978BA4A0ACA296
97949891B09C85AB999EA194A2A5AEA692C29FA591B4B4A2ADB9BBA19DA9AA9F8D9A9CA7
CEA3A6A8A3AAADAFB8A0AAB7BCB8B58EA59F98B79EA9ABAEC5B0BAB4B59EADAEB8ACBC9A
BEA3A89CA6C89EC2A8A0C2B2ADBDAC94BDB6B39AADB4A8AE96ABA8AAAD8DBCACACB2B4AF
A39AAEAAAC96939A968BBBA39D9F959B95B2A897948BA69397A6ACB9A0ADA3A9AFA99BA1
A899A2BBBCC7B1A99EAAA2B0B3AE9FA8AEA7B59E9EA9CCB5A7999FAEBFB1A7A19CA3B28F
7A7CA0B8A0A6A8ACB0A8A2B4A38094A0A58DB4A9B2908B8A897B89A3867D98978FACB6A0
6A94A4A991929A8D77747D73687362707A718A9C71939784808C9A7E9084786E7B909C85
8D897FA69CA39D888688A7958891A2838EA2948998788D8C837D8F6A8D89907C82877F87
93998D89818791959757797B837A8A7674877A827C6D948E887E76506380788086767F86
9279777068696939534E6454787F566C6262655F645B634C5E4B496264796C7E6D8A8283
78657F7660715F6C7068667C75606C63705D5A796868686E6C616482666350585E68544A
4D4942564531726569737E60486A5A6A7248685437312A4622395D393959505A48503A45
312A3639464135373C616C5C46505E415C503B40583A535B59454E433B403C5558453E4C
5E523F3D383D47FF
FFCAB48E83A1A5978681A5808BA095A3ACB1B9A9A7A9ACA3A99AB9A092989DA09D8C7993
8793A5958CA698ACAD99AEAC9DA38695ACA1AC9AB0A48BA0A2A8B2A3B586A2929AA9A8A6
8890B3B6A18991B094C3AFAAAE9A9A9EADAAA9A4A69EB3AAD1C1B0BBAAAB9DA7A593C0BE
9ACBBEBDA1B9E0A7A094A1C0A982BAA699A5B9B4B8AABAB7B3B7BB9C9FA39CA2A79DBCB0
84AF86B2959FA59C8BA87C989B8AA0A29B9BA8A39D86B3B1A3B5A29BA0A4AE909BA2B283
A0A1A9B79EAAA49CB2A1899AA49DB4BEBAB9ABB097AF9B9BAAAEBAB99AB6C29FA29082AB
A5A9978FA7AB9CBAA3A3A09E9BA1A8939A9B9A98A39AA29F9598999B9E90958A9D95A08D
968D908C799993617579726F6B7E797859786C7E8B887A8B7D8F7E8F9A8594918783827E
8C709F967F889B8384AC8E8C9D978B838A94789A8E8C8B6E86A08A897986778E9D948D7B
918B8E91896D8875857F6F69887C69739B6C7B7A87918E92887F7A6B857D7B6C6E7E6470
6B6C7E6D5A6B6177634C454B5C81654B5E6671425F4C78604B70444E6461797A7B71718E
637C5B39764B725D79696F5B526D66636B745C705F3F626351516667566760565B52403E
1B2E424A58553E3E747783797C5D77675C616552461C3A4E403C3E455B4158352F2C262B
181725494B3D40573E3F4D52475A5B4D3E46544D3B3B3E455A5655464448403638353B33
4A494A403F3F4DFF
FFA2A197A493A18E9D968684A898AFB2AAB4A9AB949D8EA2BC9297A4BAA288919C7A8FA8
A6A0B3B1AAB89C97A2A3838A9FBE879FA7A593B5AE99A0B98FAAAF7DA6B5A4ADAEA9B5BB
8BAAB29B99AEBD8D9FB7B1A7A0642F9FB6A0A3A99BB3B19DA8B6A9B4AAB5AEA682C6C4A9
A7C0B8A2B5A9ADBE99ABBBB0ADC1A4C2BE99BCB5A9BEB5B8A99F9DA998A1B9A5B0C19494
ABA8B4AD9F9DA1AE9E97A1A9979CA6A0869C9A8EA2B3B2BCBB96A6A3B5ABA79CA89F9CA6
AD9D9DB5B0B4ACB5BEB9B6B287B5B6A4A6A0BDB7A58DBEA693B6B2A8A9B7B6A18FABA69D
A9A1AAB69EA99CA29DA0AAA1ABAE93AB9D8E8DA37E9D8FA29FAE909CACA08B989D8C857E
A49E96929477878D77946B676A948B7786707F837A839C8C808A6D9292857691818D997D
8A7E8A7C7AABA8978B78887F8F9EA79C7E759D989998919B848F82738D8981838C899C7A
80988699888C8D888175727C61887A746C8D777D75796C7A7F918685887C638688867F7E
796D7A6F716B60696C6F705459606670496559725E5D5D6E565A5567664A78607F698464
4655707C6660676E65807B747E735D6665586C6F63455784547E696F5B534F3F494B4858
3E5737494E233D354C69525F6D6C51676C5D593C3F3F23333C3F3949505A564B3C3A181F
3B4035473D2B454A24284C545165514F445E424345565C4D593D3A423243562A64513F29
41483723404047FF
FFAD9F9F96A09D8F969B8AA2859BA486A79B96AB9CA48F78ADA0AE9288AD9798B2A4959E
958A9C9EA1B491AEBAB9B9A29FA29DA99B99A8A29589AB9196B0A2B4AFADB49F95B5B3AC
B2AC9F938AA9A9A1A29CA89E9F8C97A0BCA5A3C6A9AF9D9C91B1AAB2C6B2ACB2B1A0B5BC
AAB5C5ADB28CA8A8ABA4C0B1B6C3B8B6BAB8A5B0C0B3A5A0C4A9AF96AA989D969D85A9B2
9CA6A2A398A59C987E949A99A0979F8A9FA0AB95A7AFA0A9A69EA585A98D958E96B39F96
A39EC4979DBACDAAA19DA3A3C4A8AB947BAB949BA98E9190A6ACA0B497B5A19DA296A097
8B9EAEA0B0C3AFA7A398ACA9BAB093AE98A4ABA69596A3AA9CA38DAEA49FACA08A979E9F
9B989794769F80788C72829B707F7E7A80838C7E958695927795A07884878F8A71728CA0
7F86A7978F8B8D849C90779E947F918B8898968474868786838A6E9096857D918F8C9D80
8B6D8C97888093798D83A67B8293847080707C848675727F7E82807A85616A5B7D7B706C
525A487B648268494C5C575E4B53606B5D525D665E5561485C505E5F715D6D7365857672
666A7F6E6B73756F6E737255796778696B70606C496277716D5A6749555F4B482D394E37
513A3A3136442C32626C627256535A5B5245634E585B4D3413203939533A3A334C231127
212D4B4D4A314B66476145394F3846356B46455B433D4857564E4A304A51374A5543524D
383534412F393DFF
FF9F8399B6A4A2978199B0A7AAB4B1B3A79E7A91B1A383A995B1C0969180ADB2A1B3938A
7D9A99B88B959FBDA7AEAB9EADB7A7A4B8ADB48BB4B5A99B9C9BA49BAB9F8C8686979BB7
ADAFC3C9BD8E9AAAA6A6A2A1B0AF93A6AD96CBADAE9CAE9384979FAA92BEBB9CB59FB9C6
A5AEB1B1BEC891C6A4AABA9E9CB3A6AAA9B1AAB0B09AB6A0B8A0B4A4A5AEBEAAAC9D9791
A1A5A6929F7E989198A49C9BA2AFA58693A3A6A8BA9EA8ADAAA8B49C7AA1B4AAB69BB0B2
BBA4B0A7AAB8B8BCBEA4BCB7AE95A9A8B6B0ACA7A6AB999C9DA08CADA9AEB1A78B919A9C
9498B1BB81A7A79895A597A08E95888AA1A693A4ACB19F97979F9E8F958482A7997E959C
9988A2909A7E808177957779A78D9E8F83767B7E6D7D6C938E9B7095948F8E7B8A7F8E8A
7B7E7393838A90847E849D7891837491909EA176918679558F7A7C96908F77A28A8F9795
7588737A9085837F869B8A868F7E807F7E9D8C777E8579527583745F6C7F7E7886565A61
717E6A6F6A767455636A666B676B564D6450525C55615C6E544D705361567D6969767178
676E73715C6D59446464694F678057626D8C5D4D505455696B6849563537384B484F3A53
3C4E464C5224483053496A4F7E555B7A6A785D656B4D47363A3E353930362A423D480E39
2D445566564A4C3940402537454559504B3C4938474C4C4F635A49392E49423E42495552
30343D403B3B48FF
FF9999919294899E96A89C9582AC8A9DB1ACA2958DA2A49B9DB39AAA9FAA95B5B2958F99
9F9CACB8B6B5AB9D81BA98A3AC9C9F999AB6ABB0A3AFB992A794A2A097A0BCB1BCA2B7B1
AB9E94B69CAFAEADBFA7A1ADB3AF979AACB7ACB8B0AEAFA09490AA98AAB0BCB1ABA5A5C3
9DA2A3B1A8B2ABADABA2B5B0BCBDBC97B9BFA0A2919AB39F9BA39C9884959D948E9CACB6
A0ABA99C8EACB09CA590A18FA19B6B899DA6AE91A88F9170B4AEA4AEA196998EB6B9A09C
A7A0B49EBFA5A0B0A0A7ADB4AEA9ACADA7A699A9A99AB096989E94AEA6BE9F8B9F95A189
A1AD95ADA1A4A89C92A194B09B989892A988A39BA09F7D8F99AA86818E9098A2867F9C8B
7BA49D818580888F7E8A7F948C9E636F95858A6C7D798C7C8D788B9184829D8C93929E80
827593898884949B897C98987D748B75867D8387877C8391847B898980909C9B91936889
828B9D88858B97907A979A7D8569687A8E7780868F81896B6C848A8292726F6B625C6478
7B6E6678696A616E5B6E61587B43545523475E3E67635F536575596A706C76636E855771
53757D6E5D78677477617E78646163506576765E576E61584E57664E3D3F38414E45494F
4B4F4835363C3733342F326E4E586F546F6E7362655357544F173138451D2D3A3F1F362C
3053454E435635304C49364230493E463145522D5146656063403627532A3B1443485C3B
29443333264C39FF
FFAC8B9B8F89B096A1818EA6958F999C9BA094A8ADACAE9C9BA8A9A693AD98B3B09A9DA0
A6BA96A9AEA1958AA7A0B1B0A99FAEADAEB6A9B2ABA39D91AEB09B96988AA9A8949981AC
C7C6B99DAAA4A7B8AAA5AC8CAF9BABA8ADAAA0A2ACAEB2A6A9A5B2ADC4BDACC5A2AAAB9C
A9AFB6A5ABB3B1B4AEB6BEB7BBBEB3AA8EAAA5AF9B9095A989BCA7AE9AA7938E9D87A2A1
9EA1B3A8919897A6ADA59E8D7FABBDA1AE94AD9BABA3B0B4A3A7A68EA3A6A297A891A9AD
B5AEA5ACBBABB5ADC0BACBAE92B5A8C3B5ABC59A9FAF98A3AAA8B6ADA19CB0949CB2AF7A
8B9E9C9CA4B491A4989EB5A09799A19CABA49AAAB29EB5C39D9E9AB0A3AE8D88898D8A99
A19383978C9889809F778298989895918C85798A828D668F8878808C909982A2997F89A3
8E948C8B7D7C9080768894858A8892938F9D86958584937D917A887E9987818D89728D95
86725E7C999399847CD6F17E6E8791827E8D828D738C7E7A8A836F60798A60885D57616F
796667526A76726D817152594C434D544B415D59505F5A645B655366654154617A6C546A
75766B6B5D787650716761676C7D737C756788605C567B5E5E5C4E48463C2C5C4D3C4955
5B46484B373B454F453148534E6769666769475A55464F3D2D3E314F341D4D1F2630373A
303938494B525551585953362D4B414734514539485359425C4E53533B42384231484837
4E314B3F3F3C41FF
FF919C94959DA1A5A39D9D9392A5AF979A8EA29AA9ACBBB696A5AA9BB3B2A3988FA98997
9CA6AE97ADA7A9A1B8BD9AA29E9AA6B1AB8D9CA4A3939DA7A39C96BBA4B2AB939EAEA8C5
AAA78FB5B0B7A29FB2988BA88F91B5D08DA5C6BEAAA8B3A4A3A09BA2A89CB5ADAF97A9A6
9CA0A4AEC29AACABB6B0A8B69694AFB1AAADABBBAEA8B0939784A6A9A89EA3A18F8C7FA2
AB97A4A6AC9F84587AA9A0A7AA989EC99594A6AA9299A9AEBAACB3A28BB3C5BB9C99B399
A5A7AFB7B59E9AA29CBA9DB19B9A9F95B2B0A0AA92A1B0AAB79C90BCB9AFA7A7AE7490A0
A89D9FADA48195A6988A9CAC938E96AB9D97A1AAA5B8B8A8AEB4B2807F7D90B09AA2AE9E
8A929C83938C909B8D9898879BA4878EA198848F7889918B838F908C847F948A877A8691
9C83A49377949C7D777B83887E868A777F7F8C9DA297829E869E7F82719C9191897B7777
767A70898EA3746A9299BA8E776F748C747D7E7A8F8594717E5E726E6D627E686A81626B
5170757D63676A6B537F5D5B6E6865443B5E6058624B5B84775861755E64676E6E697474
665D70667F8279677C6A6A5D71716C5B76766374746F6C546057665C543F36284E555D66
6E5D56583F354920121D33405A5F7263634B5C5A434174656135323E42583F5461454226
452C51515158535256314F42292C41405558454F305255434F5A3536553547473D514C34
3D3E363656503AFF
FF9590A99FA5A98AAD93948BAD9EA27A8E9A8C9C7F98A6AF989895A7AA8AABB59F8C98A2
AD849FB994A69D9998A3AFA2BA8A9F9EB0B5B0B8A69DABAFA9BA9EA8BF9FAFA4B6AFB9A9
A0B09DA0A19CA79CA18D89A3A3A09DA28F76B0B9A6A9BDC2CF979FB68FB4ACB597BDB794
C0C8BDA68FA99FB4ABB888BBB8BE94A4A095A1A9BB9BA59CA2A69184B09FA6A29A9495A3
A8A9A09F99A08DB0BEA1A7B4A6B5AF9898AA9AAAACA4BC8CB5AF90A7ADABADAAA8B2C4AA
B0B8BAA8A0ABB9ABA9BCA2A7AF97AFA4B7A5A8AAAEC39EA9ADA4A2ACA0AEA3A2B89AA7B3
9AA4878797A2A69699A791B29CB09B9D9E77A69FA4A8B4A19F919BA8A19F7989997E918F
7F8FA1AB818C969F8B8E87827A8DA09681776E6F907B9298AEA498A1868EA094938D7B9F
8B8D6E8F78896C929AA49D7987919C85848095808381806D7A899082818467669C987C80
87827588657B9189878A84656E856E6C7673777F7D6278668372745E597C667D8B607C68
7777738570636A78806C6A77755E5A4D434C5D494E4766626078705F5A5A69727586785E
736A685F5579668271705C6D5B5C7E7F706A596A6971816268395059324E4457464F6967
5E5A6B614D403F370035443236635A5455554F604C69403F3A503E444A345B54463C4C5E
5565464759505E5860514C5B45583849295F4A50354B3C4457564258452E3D3F3B284245
523F4A3C273A2EFF
FFA7A8A18F978E949E9882A89C948A9E8A9E939399ACA1A297979EAF7F98AB9BA2C2AEAE
9193B39A95AAB6A5A6ABA2A58E9398A59CBDB5A799AAABA2A6B6A5A19D95AA9FB8A3B295
A3B6A7BAA7ACB5B2BB9CA78A959BAE9FC0ADA8A08DC0A29EA0AAA9A09DBDC9A19BB3B3A5
A2C9ADB4BCA286A9C2AF9692A5AF9FA69BB0B3A3A9AB80A9A3B2A2918E918594A4A38AAA
8DA6A89598B4A393A1A9A69A959690B99E928DA4AAABA9A7AAA0ABB489B7AAB0B0ADAF9A
A6B496938BA2B2BAABAC9E9DA5C695AA9AA9B996C9A4A4A79FAFB49DA49D8C95BEB096AE
A3B39798A2A5B49B98A7928DA49EA79D859C9CB7B6B0A196B99FA2B2AC87959F9380AAA0
999B9B9789918AA28E94A2958B89A09689A5827D79779191908792969F7E93747B848193
9189A19081828A7C8D9372848989718C8D817E7686807D8C8E86918970867F9690819377
92848F92AD8679848C8DA0918283886B9185858B82939C797C7C7D66726C7A7F77725D66
79635D695C545F73646963745557546451514E54594C7450666169735C71587155785C7E
4A6B6B5D717C70535D69845252784E6C646E6E76585B765E3343583A294F612A4957616F
7759585C4F4E3436322A263C485853775F6A5868626C5454534D3F5B3D59534B404A702F
4F4D4F5A49504D465E57574A5142403B57433F556B5A564A3A31374C4F333B3C4238363A
2D5C3B44453E43FF
FFC49FA1A29090909C9E9787869BA095A1A0A5A694959CA3A9AEA8A7A2B4A5B8ACA6958D
9A959DAC9BA8AE9AAB9E9EA1A68F9695B7A6B5A5B59FBBA6BB978DA18DA38C9798A3979F
A8B09BA2A6AC9F9B9EA3AFADA1B2AE898DA49B8DBCB9BBA7A0B0A7B9A57D9DA5AFAEB5BD
BEA5B2A7968C9CACB3BCA892817FAF90B78AACBBA5B19FA4A28B9C96AE958CA7A1A09A99
ACB29AA2B3A3B8AAA9A2BB828D90B0A6A7A09FB4ADB3B3A1B5A7A3A3ADAEA9A4B7AD8FBC
A98EB4AFA8A5A893A3B090999BA0B0A7B0B4A896959EB6B5B1B5898991B8B79FAC90A5A0
A08FA88EAFAD958EA28BA2A29C96B79C98B594999EA59D9C9DA8989AB0A2919A8F858A96
8A96AE818A7C858C888D97887C9599889385839593919387A99A90818E939A868E9D9A87
829280798A888B8F757F998164689672825F6B7A8395917F9889777C8B6E766971687273
827B71706E91878680709174797E91716580778D6795727F738F7C7A6C6D6D8254756F64
6C696B7275696F76787354656355576267674975617E6C6F747254706A575E8276696561
4C535F7864517362727C79836F6D78735B625F5F756562606D574E5E46433A5055484F5F
67625F5D55301D48353E3249381F4B62684C684A4E6F55375834555D5F654C4F42594D5E
553454566239434C39443D4A4A4754342C433D3B3E404643494A473D4332573B37413B4C
58384F3C434F4FFF
FFB19B92AFACA899B399A4BEACB2AE978698A1A59C99A8A3AFAD9199AA8F8B9D70819F97
A27FA6ABA2989795A3A79F9DB1B38EA1A7B499ADAC99AEBBA58CA2B5A0C1AEA9A8AB84AD
BCBE9499A79297979D9E9EBFAFAB99C9AFAFA7AFB9C3A4B0A6A1B5A9ADB999AEA5BBBEB1
A6BBB1C0BE9EAC8EB8AFB6A5A6AB92A9B7B79CA79091ACA0A1A3A6A8A1A5AAB3888AA6AD
B9B59CA38F9FA0AC899DB0B492AEAEB0B1959EA5AA91A7A4A4ADA6A0BBB98DBFAD9C9398
A39FA7B8A88E90A48D93989B9DAEA8BCA9CBBBBCAFA9A2A1A693A7A89AB6A79FB6BB9DB2
AA9D91AE95BDA9A0A3A69899B8A38693939EA4A7A296A58E9FA8AE9CB0ABB2A39A8AA19F
88989E827A7680798A877B90B18891768A83837F8F7885888875738184898D929D908A98
9780958A998E7478778E887781988F8C917983628495978390959787869C9780737B797A
7E777C977F7A90776E8D9F8685896E69847682848A79757276897F82865B6870766D8778
81816C755E50644351516A665674774F605D65594F5C675D616B73715C497061686F606C
77725E71745F7C66705B70535256677371617A646F6C6E6D4C52673B323957436464625C
4E3A4E696059465B4031232F4240425F785A5F756A40294A4F5C2A513F45583C604C4E48
5D51384F453D2E50443546465448385F61544B685B695A3A52484A473C54374F50375854
4B4D4131583C46FF
FF918CAC92AAA495969F8A7D9B8B949CA69DB599B3998FB0A3B7A1A7A997979F8FABA4B6
95BFA39898B4B0A2959292B8A29BAE8BADAA9397919899AD89A9B89DAC9BB59E91A0AD9D
9DB4BAA0B79FBEA893A09295B39D9995A9A0B798A89DC8AAB0B7A0A9A59DACC1C0A9AE90
C9ADA5BEABA99AA2B68EA0A49CB280A6A3A6AE98A5B3A5899AA0A7A68C96B2B28E8D9CA4
B2B4A68EB39FA8A59AACA6ACACAFC1B39CB7B19DA3ADB08C90B8A7C1A09DBEAF9BBAADA5
A1A3ACAEB3B2C6A8B0AEAFA1A0A9AA9099A6B3B6A8A6BAA1B0A9B2A4B097AAAEBDB095A9
A79AA4AEA29BAC9E9A9AA991A49CADB6A2ABAC959BA3A1B3A7C08DACB8896D82AEAAA799
AAAA958C879A8D835B647A947D7B8287737C83758B60787C8E9C8A839F84786781A28787
7F8F76918484857A9B91848E9C697B8E79998276948174837F7E7A727F706F5D628A887A
6F7797789189959196837E978B8E7A7487836A678174676D7380966C676F887C817D7D6F
736F657C6563677A74526B657157656254545A4C5A6F6561465D4D5850646D726D657D72
76696C5E616683717A71788177514A536B6555515574646B4E4A37333436376152615F5E
886152516B4E583238333A483D525B66665C69394A49535F39494E445B4431483D4D444B
454B4C622F51434946343E2F614B5D493F52494B6A574C5C564D534F58383E3D244A2B43
55484B45474D45FF
FF7DA1999E928795878DA0A389A1AAA594A486948CA5A17D979C839C95A79D94AA8CACAB
82948DBFA9A2BC9B92A1A5A2A38EAEB6A7B3ACBE809BACAEAB97858F91A2A68C9CA295A0
9CAC9DA3A292A5A8A07694A9ADBAAFA7B7A39E9D9FB599AAACB4ACA48EABA3B2A99994AD
B4A79B9E8D9CA0A5A8A99D9AAA9E8B8D9C99A9ABA09C829897969FA8ADA29694BA9FAA95
A9A3B69A9793AFA2A29F97A6AFA29E989D94A3ABAEA0A79EBEA29AB0B4A1A2B7A8B5B6BB
B1A9A88A96B3A3B5AFACACA4AFAFB2A09AB5C896AB9B9D9D91ABA4B6B096A076AF8E9E98
7FAA9BA392A5878F7BADA09BA3A282AC99AF9A818D9580A3BD9DA99E868683A199928B98
9FA093928D908C857B7A84829882846B6E4D68756D8F7B8C7C8C87897E5D817A887E8067
857D8D80877E7F7782788C91796A8E7A6D767F7C7B7C8084777A838C74717185787F7564
666879979F7C75747A95778C7F8B8A7187816D7F84737B7968727059516F5F756774877E
638777776E655C66616666547143717969595061654659404C5A6750697767435774604B
4950605C5166706D634F59655A717271587861686B79737E44355D2947293B2742367261
48575F6C5D5A4A4546353244394135507E50556356546C405D553F505E495E45624D414D
5E3B4A4248334662425043394054564B4C444D3D42465B373947593F346335302B303735
1F482B274D483CFF
FFA1AA999FAB9794A198A58291A5A79CB09FA7B0A8B6AE9D89999D887C858F8E9C88938F
6E819C94A1C1A091788E96A896A88BA89A9DB9A7B1BDC0B3A5AA9EB5A9A59C8A93AAA6C3
C0A0A3A8A797BC989D999798AD92A8AAA092A698B3A196B79EA1BD988DA0B58DABB0AAAA
A7A0B19C91A6A4B3B7ACAD959BA0A2B99D928C989FA4B68F91ABA0A392B2A6A395AE9AA7
959C977CADA69CB1A0A69A9D989FB0B0A9B387A2AFBAA29AA2A1AB8FACB0C5ADB7A9A5A4
AD9989988AA29FA0939DA9AEBDBCAFBABAB5B9C1BCB6B1BCABB9A47C97AA9A9F928C98A3
A490A6948EAD988CAEA29C9694918B9AA5A88DA7A296A8849BA7A0A17A8488938E9C9E84
8C98898C968B7881857B885D7F8C827A6A63837A82719C968A908BA68D73917880818C84
8D726987616A798B7C7B82888E706579698B828884677B8079746F60647F64867C7D7D8A
6D73727B7482635C776E85758474597B65687773666470757A6F87846670897565657786
7778726A6169626268637E6D706B5E5D67825D5D6A8868686C615E607F5C675066515277
605F755E6165867467656661585D505B575C5B5550635A5E6C604A3D4A3F3D5F4D676261
5C535974435533303F313740384D556053394D50546053575E5D645D44445E614F5B4A56
49414425303F464B554E376545505B55465138585C2E4C48453D4C4538432E1A45434342
4F3C393A32414BFF
FFACA5B3AA9CA9967998A3B29DA19B8D91ACA29FAE9E8E9E9CA59994B08A9C9CA3A1A858
004496A29DABA67E918F9FA2AFA9AE949A9E80899AAEB68CB1B2C0B18C8D979FAFAFAC97
B2918D9DA3B4ADAA9AC6A4ACA6B292A6B2A49A9BB1B5A69FBBA8A99BB2A9A69195ABA2B7
AFA2ADAEA7A3AEB3ACA9A5AAAC9D89B1B9A1B19EA5B1A87FA699B4A4A0B5BEA08C90A7B0
9B98A399B19381A8ACB5B4AE9AAE9C979EA699B2BBA5A4BBBCA9A390ABB6A69FC299B4AA
B29DA8ADBBBBB8B7674E93AEAFB4A3AB9EB6BCABCDB3B5ADC69BAA92A4AEACABABBDB2A8
9690917E8D93B3B295A7B19CACB5899392A79899AF8B9DAD9A959E80868A8F8495948794
8AA0A277997370837B8A7E7663738079736C5C7364826B9493967F73898996967E7F9774
80908A9B7B998A8A896F879476777480756D727163997A73826F6A829784807875657F76
6D81817B6D767D8E658A7481648C6E56817B7A7A6F797B7C74796D7F65717F7D7672807B
6E7D536E4B5D6A5A4A765D42676266846F582C5D5D786A76656368765F8066694E6A6557
4C5A6B725E656D5447645450758370605E5D5B53785C6C5E514A4C3F3A2B3F443F5F656D
605467674F635348474D494238324B4B664F4D56656643514F4E443D705E4C464C575856
5457405A5451635066566358585B6046467452524C5C46485D4B55465F54563C43394137
5E395F343A3737FF
FFBBA693A2A6AFA2B68A819391A885B8A19AA4B392AA959E989E829A96949682B5B78F66
005B83A39EA0A796999D989593B49C9A8E92AF91AB9CA4948684A09697AF91A5B4A3A7A7
A0A4A5B99FA1978CB7A7B4AA94A2A2AE9797B3B09E87B0A9A1A3A4C6A4BAA4ADBC7FA17E
9AB784A6A189B1A4A9A39CAEA6A79B938B9E9781AA9EA19BB5A2AEA8B29DA5A0B2AB91A1
9DA8A1938F8C95879E9C9197AB99A6A29D9CB6BDB198B4BDAA93A3C9AEA3BDA6ADBE8D9B
BDBBA2A5B696A8B63906B0AEA6ADA797B8A1A9C1B3AD87A4ACA69A9ABC8EBC9DB291AD92
AEA1A5A6A39AB7A1A2A09B93969D8F97A18CB2A39C9D8C929D948F9BA3889391A2918FC4
A7968D848A9A9A7D8A7D71837E7D7E8485819071958F7786909398868D8E948D8F9A857B
979A9D8A8799868E927A7A6A748186895979717D8D88858D7779808B6B786B5F89998299
89829B8275917A6A6A707E8C7E76687A798D908D8C718B886B737961846362675F777C7E
634C8267645F6D6A7A6F705F66606B7D71595B62736757656D625663675D706A526A6D63
666669796B5B6069444F4B5D4C56615960677569735A4F6A7062422F1C3A32384A485368
56605D3A5D49402A4B3D443A45674C5760484E4B4A496A5D56554E5E594F49526B5C5442
4B516048525D544647416067524D4D52534D4A28384D476E4740515C462B48434E42323C
3E43453245512EFF
FFC38F96A19D9891837B87909E9880A2A39CAD9EA3909E9F9A8979928E93879988A09E94
90859A969194A18E8D678F90908DA1A7A38FA38B939BAEAA9CA68F9B9792AA9E94A6A0A4
9DB9A594BBA0AAB392949FAE9DA7B4A5A38E8EA2A2B3B2A0A47F958DBAA6978E7F989FA0
9BB59AA1A172889F9AA8ACA2A5A1A8B4AAA4A29FA395B6B2AC998CAB949A99988C9BB0A7
A3A2949296A09F9D90B0B3B196A6B6A2989D999AA4A8A8A1AA9EA2BAB3B6AAB5AE98A39E
9B9F949DA9BFC29EBEAEB1ADA49E9BB0B0B9B5A7A99BB29FB9A6B7A18AB1A1A5C5A6AB9B
9DBBAA859F8E8B8FB0A9A899A397A77C9D9A9F928F91A4A08B7F9CAAB0A87B809B97A890
7F96BD908BB580AB8094918F7D858D857C777C887A8D987E9E818899936D77919F98707B
929D82906E9990A1767586967D6D6F7D847A7466728869667C73756F697F707B7D7F7E6D
96708090877B7380678A868B885E5A767A8B7D886B796C747D776860738A4F77577D6D82
7C806C796F677F7C68536B6B7F4A6E64725564605E567176605D5A70606E715C585F5C6F
607D5D766C7665666C7755535E5461756C60796063746B9A6A6848393E39441835504F55
563C596E584A3A4B2B2A41384A575B4F6247463863426F605A5F536D46614D3F535B5C33
3F51355949554E4530645B6643594B4D48525A404421493B3E2E3D4D3C573C544D492F29
3536362D373937FF
FFAE8B8DA88F9A969798B9A38B9CAD85A48993A3A8A08F8686939DA29A9791A7B19A8F97
A399849B8AB7A3B0A99CC3B8879C9691B395ADAE929A97B0BAA0A575A5B6A29C9593B299
B2AA8E89AFAB859C97A1A0A1AB8CA0B29D81998BA1A5AAA497A5909A84A4ABA0B5A09FAC
AAA6A1A18B94A7AA928B919C85A8A4A6A9A9A9AAAA8E97888EADA3A39696A3AA96AEB5A7
999AB09FA0ADA1ADB4A3B6AAB2B1B6A893A598A28AA292A398AAC2ADC1B9ACAC8FADA09B
BDBF8AA8A1C2A99FB4C4AC94ADA2B498A2BFB8ABA7BFA89499B79DB1A69C93A98EB2A6A4
9699A194A38F94ACB09F9D9C9F9490AB94B57E9EA5859EA48991998F878E908A86889287
93AE908D8C8A8D8DA2A28C8E73748C9B91B880788D998B8F8186988A8D8F7D999B9E9886
989B7E779963758579788075846E666F76726E627A7668746D7091747874706D767A7B7D
7990777281926F8F8770687A69798685716D6B637C79837D827675745A826B615C7A766C
55697762756E7B5E5E6875745D645A6A6F6E6D6F69695164626B586568685B6875736065
597E7862656577815E6B75604E5B5F556B6B6B857F6A436462475443304832362B444450
46523F444D253B473C42373544555367594B4C57565B56574C385D46444A6C615F513F39
4E5551473846673B404C504552494A5355505749554F444D4B3B3C424F4E403B2D4D4D34
3B623F35283C2DFF
FF8DA08C9A8B87928F75A7A8949F98888098A29995AD9F9BA18F87B2A8A49097A8B199A6
779C9A97979EA4A3A09E9C87A9A69399ABA399A2AE9690A2A5A4B1A6A6A9B8A793A4B6AE
A2BA9D8B8F94B6B8A59AAFA6A8A7B08FA89DC08A9D98859BA992B1B48A9599BAAA8FB2B5
A29BA1838D918491A19694A2ACA2B7A6A5A4B2BF9EA59895AFB098A4A2999AB1A8B895B4
9DA291A094A993A1A2A79F98919686A5B7AFA1999CB3B2AA9DAFB59EA5B68AB7AC9E9EA8
A7ABAD9EBBA285A183AAA7B7929BA6A8B1ABAFAD95BCA29BA29CA0BCADAFB6B1AB9DA5A7
A49F9BA6BAA4A9A5A198A899B89E979C8B9981A9A4BD97968B85A79F97A3AAA473A6A893
A69694A5A28A87767D8283828E8AAB8AA77B9A94A690769385919794A87E6C758B957A87
87837A7881AE957B867A74814F4D7663767B796A52577C7A7B7A69748A7797747B7D8A74
77928D6A7181767881888E8982856B727B8D716D73887F756A7A6B5D80698880627A6C61
675D6B6C75745F535A696B5666675D6A656F645C6B7E846168607472686A596E50666964
5F5F6054455656726C6667764C655A84605E70652C3B0063767047533A29343F473B4E45
3E4B4F33424C42202A4D4258555A5C4450546E61624F6B6654596D60576B685D4D5D4439
3D4E394A553E452A33535A484558554A484E56564149454D475B4C3D5B3E54434C48474C
55392E0D32415DFF
FFB59092978D819F969A94B396939C9C7C9CA6A27B8B94ACA1ABAAA2B39894899A97B1A3
9FA47A99A99E87A7A18F8C8E969F92A0A0948D9992929D9CAB999B9F97BCB1B8919190A4
A29BA7B5B6AFA29CAC99B69BA09BAC96AA9C7EAD9E9C89A596959C9794879F9EAD9E9994
999D86A5A39D9B93B4B19DA091AFB3B6A78AA18799A4778C98978AB3889AA498A6AAB29A
B7C0A49C9990A4A38DB6A9B79FB3B0A8BEA09895A092A8A9A79BABA4B4BAC8AFB0C6B29B
8CC0B2AC99A7A6B59CBCAD91B2A3A2B39D867E8FBFA9ADA2AAAAB9A4B1C3B8979EA9968E
969DA7AFA4969494A6A4A4ABA971B0A17C969CB38A8D9199A890AF9CAA9B8B8E919B8B7B
8A999E95916C8F94858C7A92AA957B9B80897CA2878C918E957F6D7D8C766E7D9C668971
998B878073827B9678697C7D737F7E907F797B6D7C80745E7282825D7C716371848C8B87
6B386978709A8485958D86918880876E8D6983877C7C88758873857B59828077646A657A
7D73728572596E6E654D685A635B6D67666B796E7B66636776777B68687087666065706E
6C6E42515A726D64655D54775C68577C74776F603B330040676954475C4623363D553538
2C3C4331423B313748413C413B4564664E434B5854635943545246384965604D68623D3B
38613457515563545C51563D604A413A494B3C476F5D4A5D4D383F293245376239353735
552A222A2F4044FF
FF868A969EA980B3929AA695AF97989D8F979C968E8FA79CA19395A2977F96929D938C81
9495828C77A1A08C948499A4B09C9693A48BA6A5A9B2B995AFA7A17EB3A7AD8489A88A9F
ACADA09E9FB3A0A09DA9A7B28A95BA9EA19C9C968499809E99A38EA3ABA29D91AAA5879D
889B96AAA99BA19D999DC09BA8B5A3A8A28DA4A39485AE7DAB96A6A7B599A1ADA2A3B2AE
AFAC90ACAC97A6B5A9A4ADA4A8A8A6A19BB9AE95B3AA9298AFB097A9ACAB9DB19AB5B291
A9ADAAB3B9B9ACB3B8A1B598A197A9A3949093828FA1AD8DAD8E9DAFBAAFAFAAA3BAAE9F
A7968AA784889890939396B7B18698818E8E8997A993858B9F8D9A92958F89908E8C889F
A78689A57D8C8A8E888F8C8F8A8D988A8993857995949E91A2A489709F938C7986897892
7C7C85777F93997D678A8E62626F816A74807B8E7C6F807A79847C745A54867374747B7B
9C7C687E9C787C8E728195628E806D747B89817B7F826966808272737F7E83726A7A7D5B
5F736B6A766C6F827A5E616C6E7A4C5E5A607769578264516D736674716A626D8D786B5A
674471845C5168666D6451615F64665B494759477957615D6D6766696B49362B2D2F3026
313B2341353F54433B5F523F53694211694E3C624154434A5B485B55685752605341524B
54534A4E33584D49553B43554855515A413F534642523F524F4D413F514057385B2C2B46
354E4441292718FF
FFA77D8D7E838A9B9291B18F9C879DB2A89B8CA294A3B2A68A9694999DAB8DA8A4B49899
926F9D92A0A2A38E919A829AA8A891A6A28F8DBC999A94A8A0ABB3A19A91887CA2A8B2AF
A4A697A7AE9B9BADAAAAA99A96B8A0A6B093989BA29CA1A1A99B8B97A39885979D9F0000
A2A4C6A79FC68AAA99959098989D98A2909CB1AB9091B3ABB4C3A19FA1909BA4ACAA8AA6
9C9BABA2A1A5BFA2B8A69D9DBEC19F9CA898A4AF8E9CA6B9C09B9DA1A699AFA1B2ABA9B5
B7AFA8B4B4A4A0B890A6A0BD9DA1ADA0A587779DAAAB8E988AA1A6BBB9ACB8A397AF9F86
96998C9B9A8998C2AF80A08DAAAF8EA19197918E99AC849398A0927E8FB19B8C8A908690
AF9696A08479977A88989490809F86868B95919AAF7E69928D7D908E7B7D7F70829B768C
6F7674829468796F6C7D728368756F826669717B666A6F8366788A796F74718C81777762
6784808365837C7981688283517A738271765D8173858178625E878A78897679775F5950
7B48574A635F637061625E594C5A705F6984684E6C625C62507D73727B67667A7E626A69
6E6465526553737B60696C6D7D514E5D716D77486754536C5F556566626338423B3F2B4B
5656382C35363F3949435643596368614B4062576A39474D4753525A573F5F4D532D555E
5460544360455F545546435C473F4B354C495B5E464A45403A3C54365D523240453B4A3C
2E452707230000FF
FFB67994939A91A5B2A798989293A4979FA39DA2997997A5AC82AB947B978D9CBB989692
939BB3B0B19F949F95A698989EAA9F9E969F9E9C9C9EB7A1A4A3A6A1B3AFA3A594A0BFA4
B7AF90B2A29CA4AFA9A2A29FA891B2A6A5A8A7ACA4868CAB938696A6A99488A4B29F005A
B39791899BA8A09F97A9AAA394A7A3A7AB9CB2B4A9B0ABB5A7A9AFAC9FADD0939498A4AD
99A99AAB90C5B4A2B9C6AD97BFB7DBB6B3A07C8E89A3A39FA4899CAD859390B7AC769C7E
9DABAAA99FA4A7BAAE89A4AB97B8ADA1A4A37A978C77A996A1ABAFA2A1ABB7B5AC9BBFA4
A990AEB4927A7A927B8287A399A3A294ADA19793948FA9A48D91986CB79B949E8C91868E
8B93A582987C999D748C8A75907B616F7998969B9DB56F757F857F859790888287617789
86816D9D868769787C9185767A766979827A516C75938B79717C7A7F7394968E7C637497
746A94667B87857498839E817F8076778D876B887D73827E8BA679746A766F617C707873
775F5B4C525A5C736E615C6771706A6866556262656C706877586A656D53687072644B57
516B615858686866674D556A6F60664D666F67705B6B6851515342656A6E6E4E54433D3E
3743373836494C50405C3A666C635964555966544E38544C5550575B4C444A5D68526A43
5260494F4B5A574E3A455563473F4452493F486427323D3E4C66413243413530593F3F43
35313A2E290000FF
FF8898969D919089947F90AEA5AAA68BA59C979A9E7AA382A3A69C9D9FA284A596A39B8A
929A9D9A97A28B95B58A93938195B0A0979C9C7297AFADABA08084B0A77B9298A19E9B99
A8A4B3B1ACAFA9929EB19E8985A89A8E92A3ACA5979E7B959998A4A2B2A79E98989EB1A7
ABA9A3B0C0A699989D8DB4A083A2B59A8CA9998A99B0A5C3A6A3A5C395A28FB8B59B8BB5
9D9FACA6B6ABA7C8A49D9990ADD2AEB078A2A69EADA39CBAB6CAB6A599B1A4A6966894BA
A0BB9695A0A8B6A3A49E989C8F779F91967D9597878D8A918BA9899486CBC4A09BA4B3A3
A79D979DA0A8987CAB9B9A8E9F8C88AC8D8A82858AA0938C838095A3947F9897AE818790
8BA58B8E849F9D9B879894665B7E838B9E918E79A2938D907E8D7C7F848A7B8579869490
897F9A819285657B727A7079787B786865676B6367788A7E926F707A7E627E77977C6170
82818B7C7A76867395997A8C6C7F89776D677D846B66767B8F63696B6D68808C887D7151
6C5E6E69594B6D5658585A576B676B666F665558607975637058584A656B64646E546A7E
5E6C83606563836C5F5B6C5975876D67575B655F5B685E6F496E5467636758525C534B69
305D494D3C4651354C4E744D4D663F4846523E4458595A4960534A35555F4D575934324E
55607059344260584D443F4F34473E483C5E57333631405E504A5E484B4F435545523740
5351362C361226FF
FF8B8A9DB09B95999D98988DA0A89194939CA19B8594909B8C94A09B909A9A9B9C909495
AF7CA48C9CA6A1BA9E98B098929F9C9FAB928793B0AAA192928BA8A298AA92A78CA0A3A7
B2AE96A3A6A6B2A698937C89907A79809A7B919CA673948BAFACA298A9B292A8A3ABA39D
9AB1B59C929F9C9BA3B3A09FA09BA298A9A69597A7A9A5B7939EB69E918EA0AAB8B2A18A
9E9F93A79DBABBB8B4B3A3B8A9ADC1A5A29AA8AA8C99ABAAA197AAA7AD8DA3B9A2BDB6B8
C0ACA0A9A6A9B6A67F9F9A9D928A908B87859C866D838286898EAB948CABA9B3A9B7B79F
B5A487A69D90A8A2978188ADA895A4A1A5948A95998E807C77778F9F8F9A8A847488989D
94A28861956D868C967E610960989A8E708E866D6F819D8D8D7B9D6C8291938396938368
7A8C7D7089927279796F72606D7A796E6F736278847283636A7C78655B82886C69787073
836D83747B837C786D818C6484827E8B7D7C8A7D7E7A727F7D716A6D695F676E5F8D696E
603E6064776762685B584F6E6F5C5B72585D5462796B7372736C61737267756950656264
534370706355627D6E4F6B69557676625869526D625C5B486C6361595853756560613C4A
524E514F372868756864555F414556571D4B6243374552535A4B584C474C3C604651704B
4F4B455455544C5853574B3F544555404046494F3536365251383D67445D3F4B4C573B3E
4D2B2B3D3D422AFF
FFAA9CAAA291A1A2969AA18C8CAAA09CA09DA99EA59D889D96B08C9EA6A58C9DAEADA9A1
769095978EA395A3ABA281A6A08C9B9D909897A48F8FA2A4B9B8A2A5A0ACA1AA92A6A997
9BAEA8869E93A0AA83989CA3908F8B8F79929596878CA584968591B1989298AFACA3AF7C
918C8D8F928AA5AB989281BE8A96B4BE919EAD92ACAAA4B096989CAEA0B0A397ACBAAEBF
9FA2A795D0B4C6BEB3ACA9A5A39E8FAEAEA3A8A0799C969C91ABA4B3C5C3C092AAAAA199
9DB1A3B0ACAAA0AC97986D99A2A6AA8CAD9690A268484A7681908995BA9EB4BAA7ACA79D
A295798F9F9C999E9DA6AF98A297A09E82A88782837C888C866A638E8B8F7A829399967D
81A187848F929BA385A0A78B7F87749295737B7C88A887878A63856D9291919B7187707B
949D817E6E8380856C7A68657A86A3756784737E8A72749858676A78758670896E847C6D
7668657F528768747C6E6C8B71898378838691849C757D80755D89857F797B817257574C
625C6E5F5F654967645D635D69575A665D6C60386A556A4F69745C6E8A655B5D7E7B5D63
546B56566B595B79754D575F65686D525B4E796252784A4E745A557259515D6B644C5C61
5A5E4F474B474A42594A51555752576A5F59304543343156454A524F475731595C4C5659
60525A535A4D5143516459675B493F4131472F4D4E5A504A3A5E3C434361573E55544D36
344A4656203630FF
FFA99FA4A08E7D9BAB9EAAA39786AC9DA89B988D95928592889EACAFA48D9AA4B8C1A79A
92869CA7B390948C9690A889737E839E94A1A2A4889396909EAD9BAEAFB19AAB9893AEBA
96AEAF97967F98959685A2807686858589896E75828C9295A596A493A0A38CA79F9284A1
9895929A8C899B9CA79796959E9C9DB49D96A5A2AF98B59EABABA0ADB8A3B8B9B5AB9B97
B0B094B6B4C3B4A2B5C1BFBDB5B4A7AEACA187A0989CB78DAEC3A6A6A39B95B6A4A1B3A5
A5ABA08BAD8AB39F907575849E9C8FA3888876918A797C8274887F8F8A9BADCAB3A4A2AC
98A891A19FAAA095AD8D8E92AC998EA27F6E84958A805D87957365759179979DADAC9EAB
9B65899881A3A087968E898E7E7B8C9B7B9681887E8B7E7892A27B879189947481817680
92A68B788C6A7871627E6F7F8E8B817470638784877279849B7A7E7C817A878F87766762
6E7D5E8D907163827E758E909579746B5B768E6B85917359857B6D8B7B88866B7372635E
8A5C706D695D685254515D60686E755A6166735457785A75855669586F4F6C947D5B6951
6E857E7772825A6A7261284D4F6059405C654E547E6A48716E546E8151585A5E734E5B58
5E59604A435C5D555468555E56504B5748436855514F615B4B515658484A47525F484E3E
576F66594A65654C533C41534753522750444759523F492A506D3D3B3D44244044444347
3050403F443636FF
FFA5A0A08F87909C9BA482ABAD8389A49588939CA279969FBCA5997689A08C8A92A190A8
8E6E9485762B8AA6A29E9194997E897D978D89A1ACA0809DB1899A959ABCA898A4BC989F
A2B1B99F8B81A08980878E9D84658C7E91868D716893877E7AA29AA38B899190A68C9492
8F8B9DA0A48EA7A0977D929C93989DA3B1AAB78CB1C1B8A89FA1A797A7B2B1B2B7ADAEB1
B99DB9BDA794A9B5A3B9A899B4A6BBA39D88AE8AB6A9A6C4B490ABAFADA7B098AFB9AE9B
BBB2BAA8889F8F9192988A8D8EA5A59F8CA09683817E83747789617D7F9474A9A5B0A1A0
ACA1919A85949BA4979E978E8790AA9A7D778280708A89716D6D847A877B9B7C88838788
9CA2A1818089A38A8A847A8E837E887EA081878CA18A8485898983A28B93578384899971
77878F9483817B7F856F80878383827D797A67726C7E7D6F71648889788B737A705C727E
7075695E77707B8969767A7C58857287877C7F866D7774657681908A776F737769417066
566F5A5A5E584C666B64665459576B6F6B67555944445473546B686580777F60537C6661
7D7C5C395F516A638150525D59646E7E60717C574B4B5E4949627463434F5B5F5B666B60
525559384F5365514F1D395565525654484C4D404044565C4E454A365F463A494E6B4154
5B46405D6C624A4A5530414554424936444E3F415248454A4C3C543D3047465333363435
35373940444233FF
FFA4A284A49C8EA09B8A9A9F98B7899CA6AA99A8A08E939C8294939C8F839DBAAA899C89
938F9F977665A596AF8B8A82839F958B9498A798AC95849190A895A3B592A9B7A499AEAA
99B3A19992989D7A86877162959B8E8D7D99897374847E8F919195A0979B93A896977175
9F8C968C999C9F8CBA8E949582A1989F8E9D84A5B5B59BAEAEA9B5B3989EA8A6AFB5A6B9
C4BEA6A4AEAEB4AD9FB99AA8929A93AA7BAFA4879BA18895B8B09F949A85A0A2B3B1A886
88A798B1A4B4A9A2939282967E9190988CA0899BA2727C7E8E6D74725A6C8E949AA8929F
A49F8C988E9E92A48B95A2AB81898F90909F997D7F8F7C898A7D9486846A86929A938589
9A95B3A38E8B8C8B9C7C816F8579808E958C988E727D7D6D7F8D9A96798B93777A929480
815887867C817D6A6477796C744D7569968E7C896B8B7E83767A79857671767B707E658C
88677574818B70636B89966C6E817A79736D6C7A667E64917D87877D75798C5A51765C78
565C556C67727575604E5160556D59454C56605F6D676A536268447A7E584E69696F7F68
51596152625F4A5E6B607A6E7973666F49445662655F5D716F524F66575356534C524E61
524F47654051516D485246505E423D4C54534E58403D4F3D5F4B50393D345D4F4D4D6475
61485A585E6057455444404A3E55484E52383D513946483A303F383845413F3735513633
34424138432B47FF
FF9E969C8590A59C84A99D969084B5B1A8A0B1A8A1ACA4A2B0B1A09F96B39C8D7DA8939A
9D9D788189ACA0A0A8AA7C989695A3A2A7A2A2A1A68FA1948DA7B3AEB2A3B2AB99B2A992
B8B1A0999E898A937E8F9E846393A8A29683968881757A9698AA8AA18C93878B9A990000
949D9A97B4AEA0B0A2A292A2A994B59DB79E667BB1ADA3A0A0AEAAB3BC8E9AB1BDAFAC8F
B6A1B2C1A1A5B3B9B2B3B0968AA09F90A3899E89AAA59EADA592B09E94B79D93B1A7A194
9E91B0A4A0A4A29D8E92658091A7A796A490978DA39E74856F746863597D769186ACC290
8E9BA0A48A98939F918E9AA1AE9585828E7D998586869184999081759086839D7A68897F
AA96877E87968D9A878394869576A5938988786196888F8F6C8E859C86978A857E63787E
658588668B78766780806B796A6F71687274727E7D867B797084887384706B7381747A75
7F6F8384726D7692948E7C7762643A7074897A747B7A7D87747A8273757B69596574535F
5E4E6B83716B7B748C8562515E3E5A72686864646C725E67616B55626F38504E606D6E66
68727562566D6871755F605F5E6254404B50715B5F6B6A60574748736B5A5D4D0D485B82
5A705E56625B554C5A5D504C48534C444F384E5744385C56635A4453595C3B55593C505C
425C495D65545848463C5652454245583E4C4F3C4548424C644A51533028473F3830264C
43413E4A373144FF
FFA48C847A86937B9494AC8AA7A081949FA5A69E8095A4898888909291979E9F918D8399
979D99A7B0B29093A1A2A38489A19D859AA2AF9B98939AAC9A85A4B79F9E7CA2AB94A7C5
AF9FAB9C8EA6A09B756A9D879485A2B68D878D93899C919987898A989996B1A3877F3F00
7992A1979C98B8A9AEA0A1A3A5B4A79E919AA297B296AA9AC9B39DB2B3B3B0A8B3ABBEAF
B7B6B3A5B7B3BEA9A1ADA8A0979D8BA49B8F7B9FA3ABA89CA69F94ACA6B1A0B6AAABA9A9
A7A7A39F9EB6898F82808994849179967A8B9C898277817974786E5D725F56758AB4A9B3
AD8C8A7C95AA877293AA939B63758887816C899BA48BB08E90828B7A696E7B838D928A98
989A90A7829F8C8DA39D81898E8E8997A59986918A78899481867D7D7E67558C76869C69
975B8B8D8585698B73798B928189958E826D726E71707E8B8966758770826C845D7C6F7A
78877570846E77738A6C8973648A708489728C8D827B7F787F5A6C547F6A6A757357765F
61607F6270605E6970785E4B3D3B4F56475866655B4E5A635D2A76426B595B68615F5860
7B76576A5955667972687366536C60526E6443677553525F485A715953515640616E5441
4B5D67527A6A4C614D4B585A6365424131585F50436D4958554F504C454654615A595C4B
5A494E585D524A3C5357473E6B52474D4B6455543A40323C494A464D463F444548383848
4B4A302F281A28FF
FFA0B3AD91968199739EA0AB82A8AC9295AD8F999AB0979DB6B4948D8E938993A89498A1
A3878DA1A8C4A19E99A18DAD8D978E8C97A592AF95A79AAC879D98A485A3A8BB9B9FA493
A79C957B9388756A58676FAB99989CB1A699988483808385989C93A0AAABA59A9797AD9E
A0A17B7DA69BAE909FB1A097739E9590A3A08494A3A899AC8DA3AAB5B3A494A7A0A1B7CE
90AB9197A7B6A4AB9EB3AC9DB5A09F9290A1A5AA9DB0B0A09183C796B0949198A8A79AA2
87AAA9A9B09A9B949F9D8F8195A590917C9A95958A9E9F7B7E6C425C5A75658270A083A2
AE8E9F8E968F909FA3968592A4A8757B7F7C9DA89D9680A1AFA08F957580819F99909EA2
8A8E8E9791869A9C936E8B928F9A98897FA48878A2A19F879B7D9D8A7A520086867E8576
7A918B906B6B676C8679626574818D8964786D6C7A7C85847D8B75667B7F8E72827D7671
6C38888B8C8A8B886589896A7377707E677C826B7F76897F7D7A78888274686F4E826865
5E716C61758180507C67696652622B695C6B75765E7D5D5F7B546D5F633E75675C6A756B
7F7972614D63677C6472655D51677B66426B4542586E63615553615C4C596C5345554C4D
66665E765F59645C614E5A59474E44384431584E5059694E52443D4C4448563628486763
59615057464F63433E4062524455402B27595A4D3B27503D464D4D52422F484D3F4C382A
31494640362823FF
FFA589A3988E939D9FA9A8A7918F8F96958CA4A89998A1879399978A9A7DA192969CA692
9C8E899B9DB4A295A0A9A8A49A91959D9A9AA1977F74A4948093B5AAAFB2AB9A968CB5A3
938E829684779289888FA09C9EAEC4BD9BA0AC9A7F78948C728292A2A48894989B938491
8A968E8B9F81AD9E96908F99A5827E9CAE999C9CA7A9A5A88AB795A3B1BE98B2A8C39D8C
A0BB939DA4A4B3A3A79C8D8FA68FA3ACA9AA98A19CACABA88D90819BACA3AE918CA19BA2
96A29F8FABA4808179879D9A8794867D929093A29A999885795E4C5F554E4C597B9596A0
A4A988A8A49C9EA1A7807A8F8D887F866370989DA0A5987991918F6C88807B9791677D8C
9B889B96AB877978959C7F8B8D7C91A47C8D9F8C8D988E9579849691998A7F9D8D908774
70918E717E8C606A8F856A6484766F79807B86817C5D6A7E90756F718D69707178767773
7A567D7660633077848688766B8664917C556A6370897482855C4F5C6F83726B5A72776C
8E656B6D6E6D72665A575B674D4C58496E4986676B5A775D787263695A61686E6766628B
5A6C5A51665F704A74746A6A6A6B756548715053613F5B62555A474960444B665F0D4E63
5464474B57444D5B5C41504E5A45474830424F44485B5B4C4B454F5D4D4D5A475857524A
5F51525C272D63553A3C394F5051473F455D304C5843465D4340414251482F3440373A4A
583A554A2F3449FF
FFABA58B888E9779A092889B809485A3939683A0AF8DB9AC9B9D819B8AB579A9B5A19B89
9A829DB5ADA895909A8D98959099B395A0BC8F8D887E98999DA3949298B1AE98BAA6ADCB
A38984868882737D959284AC9F9AAC9DB0A1A6916C847E7B8385A1AFB4948FAEB19BA0A2
A298AFA1A1AF95A6C19FA69697B09FA08ABBC1A096A9979FACAEA09E9F9AADA9BBA4AEA1
C0A5AFADABABB8B1D09391B19D91A88B99AAA0A0AB99ADA39DB0A59D9F90AB8DA49897A2
A78CA094987C9C956D836A948F9486767F7A91928B99A1885D6667565B44564761758F8D
9AC58596A098A6BB9B85AA979A926FA28A86909C8F9C9E9078837B7C6D7C78918E95AE96
939FA884B6A4998E5DA89496939077969F99807D8F869C89878C89A09776917F8E6E7579
6E5F5E7F936A7D5C8D826D8275717072706C787E7365888D82687B85797D858A73697584
708380878F787E7D7E8E877B7B7A846F79505074616B788660967369747B746C53584242
616170736F6F63635368554E493C43675263567B775C637460716E5B55615048796F5D60
706E6072716863636E72464C50485B4C455F5645535E645D5A5555554F6059594B305558
3E42496B59454F3E4C514C4F5A56434F4A58424734405D544C5640504A54534A39445550
45574C534C24324A63574A305559415E4D362B354A4A452D304A4358514D452C1E47373D
272F352C322520FF
FFBEA5928E9991AE9A869195A09996A9A8988C9AB57F7C9185A4969B9FAD989F9E979197
8E9099A397997C83AC9E9187829D969275A794899FA49D8AA29B96A09D9E9AB9ADADCCBF
A49D8C868E838A73918EA7A39FAE98A4AEA99C9299A8888B7185759698998A829DAB9D95
9D9A8E9F9E9099AA91A0AB92A3A7AEB8ADA0ABA1BCA6A8A8A2B48B9DA0ACAAA6B3B1ABA8
98A7A7A4A8B4A3AB94828B8AA395A9A8AEADA9AABFC2B4A87FA5A3938E7390A490A39EB0
A7AA8B998FB3AD96848C907B7687959289908B999D807A827A705A3652474E4646635D67
8F96A0B498B0A4A291989596A9898B699D919291A08DAF98B99996677D6C608276A79D91
908C91A399A0968C92879C7B849FBA979B9097A484839576809365857A9C9981817F7E89
859096A68178869C85828C86637D7E72858261747A807D8A60738B86889097866F878584
6E63897A9A867C7B75758A66768867759B4F676599957B7780628362747E635E68646272
58755E6B5B697764826C6241535B6A6048746B795875795E7672575A614C4950665E7686
5D5B716875745A56365B4B525A5D6E57633A5A634C604C4A6C515B5E685D7B5F653E5055
4E4A5354595057604F495A55735051343B5027604150434732455A4C3E31455B4548474B
465D54544244452E5A5649512F573A41494E61413D373D3539384C44372E3A3F4F333030
29472F3A2A3735FF
FFABAA9D9B9AA58E89AAA09892A4A18F969D8F979E7A9DA399A091A49E9FA6B28E999FAA
9A95A295A698889091ADA4A08680A2718EADA59FBB849A9D9C8E8FA795A399939DABB6B9
A17E9E8F7F84967A8D917EAB908A8C82B597A9A5A1A3958A8D9785939BA3A99CADA8A185
BCB3BBA3827B6F869E9BADA0B19DA091A1B0A7BCB4BBA09DA3A9ACBA969599B0B3AAA2A9
A7AA9EBFAFACBFAAA6ADA7929CA9A2ABA691A5B8A89CA398A5878A929FAEAC8EBF9A959D
9AB2ACA9B092989D9E89828490727E88837576788D7D779684826A554F4F44604353715E
889599A7A488B9A1AE78A57B939076767A909F917CA79C8C788C80776381756E8A828B9B
A4AAA98FA080879F908383A78E8AAB9794939692729C7C91858C6F7D7D818C7B84736D88
7F8F8784838D7F88746E79828F958A8298908866646E74716F80737E72606D7A89767393
7875547B74797F8968818982705F686F898579918A856C90596C72746E7C80764F5F6A64
704A726565605E6D6D5F533D565E5C4F58686863796B756E8481516B6C436166605D6A63
7C695D6C5B556068565952504E57595164815E5A7A4C4C6A5A4E4F6648546373585E695D
504762494C4F57574F414E574C6E543D3D3346473D505038424E2F363842484B443D343C
57415144593A3F5C504B3C4B2B4B4B505155404E552F3A3F53444E58493427532D503C29
33302C2937414AFF
FFA79B818D989D9D9795A1A7A57A8FA5A79D93A098A4929992917D9BA8A39F918E85AE8E
9E9A83A38AA39E98A39E97A191839EA889A1A09B8B979591A397AEB1B8A59D749C9396A0
AC9EA67B8B8C7D91839D6D95A78E9986859FA1A37F9A86837F808E978AB8AEBB95A2A99D
97AF83A9A889AA9D9A889097A3A095A4B1A2A38BAFB293A69DAAABB7ADD7A9919EA8B699
949CB296A7A69F9BA9B1AC9DAAA9ABAC9FAFB5B9A0B2BA979FAA949DA0AB969C95C3BAAE
A7B7A99D9D9F9E9A7A6C91836C807482887C768B7D9D7A6D75856B3B564B4B434F5E6663
7D7195A6889C9D979094A29798968B88867A87849692999C886B78535E7382869296A989
87908585879C95967C9AA79993849E9F9E87979A8D868A71769184868B806B8E7486705A
71897F797E7D8A7E99875F59587A958378887B5C757E82717F7169677B927464648A737F
7C8D7E6F84809D70847677797081857C717A6A8863669D6F6F7B717B62787568816A5A5A
4A4B586B5056585859454F6263573C5D5D596D5A71705A7E785D60636A66656579776063
756A706663736A4D6334676768546861514C5E6B6159615C5256546E6750584A6167664F
575B4A5044563F576447554F4C3D573C463A50545338374542444E322E54314D52705250
52405556392A604A4B56464D554E435B384D49222C4A303F4C5222424E3A4E3821123B33
58434840304518FF
FF8FA080A39BA5A9A5A6A69092978BA49B998C9F9B978C9B8D89A9818F83969692B19B9B
A0A491A4A8A070819C8973AEAD8F7EA8A69E95979AA1969978A89EAAA98B9E97A7A3AAAA
8FAB8078817F888F7D8C9DAF7689A39A8496879EA48E88957080748AAB8DC9E4A6AA9FAF
9992A298AC9C9990879D969E8FA4AD88AAA38F9BA8A08FA8BEB1A19BA695979F9CB1A6AF
AEB4B1A695CFA4BFA49B999AAAB6A7A8A3A7AC92AC8E90A2A88F90A3B1B2AC9FA19490B0
979A9F90A99BA19F87697F827A764F717472657081777B727F6D5F6758524B3C4F69444C
687F89A2978D98949A9F84A085918D7F7D888A75A0947CAA7A8E8459757382A7ABA08A9C
8B7F7AA99F96889D8B9088998BA396A19A80818A9BA9979A6C8B8A788B97858B768E927B
7F85808E838F7F9983927878857D6C81796E75786468767A789B898B868B797A78757D94
88836887665D646B848B7B7E857B7B878A8A738684836A8283715C7B757883696A745A69
5C456F66554E4C5C68607A6A66736D5F6963566375687D565B73615D54526362596B6E84
6D6B6A71636762605E5F5A61795E4C5E52714B275A7367664A5A566462595B7267645868
67505168515A4B595062465C5059534032675640433D496244333C353C29374838584940
56584F523A4543595554515C4E6C513F4A55464A53423F5E39304A411B4349242247323E
4B45233C3E3825FF
FF927E818B93B6ADB5999699A796ABADA2AAA29C9B9F8A9C948AA79C96918A8484A693A1
A28AA88FA0A600009A97A19885848C98A4A4A09578858F9F9A8FB0AAB2A3A79781A78992
9397979C7B7189949A949D91A593A08C7B919AA1908A7F8A8D809094A3A6E1F1ADABA8AD
AB9B8F949099AD99A2A29798809687BD8B9CAEB7AAB5B7A8AAA8B5ACB8A7AA93AFBCC2A7
9EA39EA1B6AA9592B2859EA1A09A9D8F9294A5A9A7A9A7A095A5A9998AA9A0AE9797929B
8EB08EABC2A69F8A917D8D8371755D6961615F6E646573677876626A5F50564B4D4B5959
677A7595A39D96809590909B9687919F938A998B7A7E967B94778A968986717AA4918F9C
91959EA1AAA9A9938F9E96779F8C92A09F9A9E968DA47F879E8F8890A6888F8780919194
76949384808C997D7378817F927F7F77707D8790867478608F737576797A886F75887D64
5B6F726A8A869C728D7B878E7F5D6C7D716A81639B6E717E7A678472786F946B54524D4A
7061465A4E2E46455E4F59636762606A615D7D6A5A6E6D4C7B676069595A425854556F6C
7980706655605364705A2B525D775E665B43496762554E4B5E68665F5D43535B5C55595D
676249383A4D3B5D5454664362535C3B4830424528453D3D4A4858603F455C4468464B47
435E3B31473A6C41514B4F5744424650544C435429393728374150374742345648473E42
352C3C4A2D274CFF
FFBB87A6989A9C9A9EB1918ABFB5A8A79D798FA1A2AB988B9C9EA2A59A95959EA7989AAA
A886A6B38B8C5A599F969E967074969CB19C8B8F9498A2A0979CAD94AAC8A2B3979D838A
9A97929E9393929C97808197958FA29392A6A48E9795937D807B808795A3A7A698A0A5A8
ACA8ADA08D95A89E92AB9CB2AB99ACB2A4B1B09A96BAAFB0ADB2A79AAFC99771C1AFACA8
AE93C2A8B1ACA49F9CB5A4B2A0A2AEA8A08C9D7CA3AAAAA5ABB288A09FA0869BA0ACA8A5
A0A29390B8B2A5B58A7E6275757165495B6E5553527A627A737D6F7A6F70655B4C5C5C63
6D79847F9B9898A58C9B8390909582917D837F888C94857F68677982869178A28AA4969F
93AC909D8684ADA18FA28790857E85949E929781728C8B917D6C868974769C8394898D7C
808C85887991A189948A8D94747C5A62878F8A866D825F5D7A667E80827C736672767384
74787D7E75807B9A8EA685877F7B7B7489837F94516A606C7F887A798668636E62706171
4D345258784B4F54555E5B555C5F646164645C6A6D5F645D50486A5462596575755D6A6C
5D58656E7A7D676354511C244345656C4C55494D6743595A6B564256766E663E67605B5F
5646594C4B485558514A434F353F585C444C59413C4F463F354C4C514E3B53594B4D5850
505B4B5629463C465D58465445462C3D5D41522E5F3E4F2E322C2F583E2F3438323E404B
33372A373F3E2FFF
FF979EA286B1A39E989FAB9C909A96AA9F8E9D91918E99BAA5917DAA97968A98978F9D84
97889D8EA1A0ADA194B0A19395929EA28FA79F8EA8A6A8AC939DAAA67F97A78D90908BB2
A9AA8D968D8A8195899B96958C9CA496979C8D87817D8A7D7F8D8B86979C8A9FAB9DA27F
95A4A19E9E9EA49A9FA3AFA79C92AB9A978DA2A9B0A9A59BB8B4B19BABBCC3B1B2BDA9A1
B3C6B29AAAB698AE9D938A9A86A78D9DAC9A8EA99BC1A6A38FA99EA7929792A2B9AFBAA9
ABB1B8B8A897BEB497AA81685A556D694F52565F5E6C6D837D7676849780616854565A68
4D6E6793A47B969BA48B7F8D797E8C8A758B858974787C90879D8E6E9E908B8A8588849A
9A808CA39FA998A4A292858CA3947D7D91838A9F78A199A18D786E77828A91978F778083
927F8F8789867D787B9F7D767A7564877D5F7A895F898278747D85867374728176887E83
74828D8E838279888B8D77938D967E8D747E73668F648B7194797E7F738474666F745D77
63525876475752686F6D56755652594C6966637777666C6F595F61527B5A6A7063636679
5D726154836C786C5F5B21264D636A6452625965594F494E4C6F725C5267497B64575443
5B584844524D5A6D4D574A3E3F4846483C4A323C57503A59524D4E473D3553474B4C3D4E
49405E4A334F57314E4B45573C22353859302E374537443E434C374C48284E3B40353509
4C383138372832FF
FF80A6859D8E9F96A192A9A2A69FB2AEA39D7AAD9B93827E8A8593AAB09B94989DAC9A8B
A39C98A9A8A2B4A5A196A79E9B9F928E96A18E689DA09397979B868897A8A49C9B8E8194
87A2AF99AB8F747D8C8A848093AA969A849F9696A59A86A58C8C90AA9C8F887A95828A83
7E91A6A1936C97BAB2A7989FABA19AD3A1AE8CA490B3B7BFB180B0A3918492B590999EB0
A3989E9CA7B8A8A0A1A1A4A9A58499A68F9A93949D94909E9B8BA48FAB7EA0A99BA99DAA
A0B198A4979FADB0BA9F9A877B694E684F4F4B576E79807076778D76807F855C6B5B525A
6572726C7C8393A37C90AA8F89918798AD8E958C83888B807D6A8FAD857875879B9993A1
898D91A39F988B819E9BA7AB9092978C848D7E6E81848E7D8286927597818C9786908F88
849E7C7078817D9894807A747B7169817B90626A77788F82848B928D88736D7B83818076
877E66738292887E899392828F79818D7C736FA17E757A74696D808B85636F7447757B53
65675B52715F5B6A576C6C605D683B564E576E505B5D7159757763705D624E67625B8160
6E725C78485750796B654D3F5E536050694A51575657524851535045645164455E515F4A
5548514160443A4A6B6240565161532E474353393D584F603F3C395654694A5C4B365A53
45544C4D4357523B3B4B6731584D544B37442C3E5544393B2B51422F3E40253A47552B2C
344A3C3C49263DFF
FF929C93999791A8A9B29BAAB4AFB8AEB8A6A2A2B3A4A4A07C959776998398969CA4A3A5
848F94A599AF9F9699989AA5939C95B5AEA7A96F7CA18D8B9C96A49FA8A08A96AA84B6C1
9C9CA1A07783946A838C868696919E91A38878828A937F767D97978691AD9A908D8BA48D
947498B59D8E8E91AAA7A7AE8EA6B5FFA38EADC09AA098AEC4BEAAB6A7A1B2A0ABA1A5AB
78A38F918997BAB6B1B09690ABB294B5A89AA7B1A9939B99A0938DA98E9A98A4BBBCABB2
AAB3ADB5B7A5B3ACA9A9B57B6D585B5A5F363F4661566B797D93886C6995926C7E756754
4463546E79B092A08F9586989099899A957D8E8B7D889B8072A09C92A0859C8A9B9EB187
A4AF9A97ABA59E8392917F919A938E84969697A28693888E7E747E769A907C87968B8B8A
738F948A8267838F847E8A8D848469686A64767C738593708071718B755C676F8B758780
908D919E8A7D79717B7F8274669C757971846188727E8C74636180767A6009647A5D687A
42707063686D6C69646F604C66587153665966747A6B60626E694F546E57725F696D6673
66392744555D44584F645A78675C4F50674C53624A6266575A573863684C5F605A543D50
5D454E4F43535A31554236364648424849644A4D3C4F6F5C54305A594B4A492F65512A35
394E626567585D38404A4F5C455B58504350535C3F493D3450414039472F3C3243303548
2F3B3548445945FF
FF9A8F9EA6B493A4B0BEB9C6A7AC98ADAB9A95A294AF7B9AA4A3A3AF9599988AA492AC8B
A0AF9AA0AA9198AF7CADA4A3AE97A495C3A89BB0AEA7A7ACA1A8A595A4BCAD9275A79BD4
A89FA79F99AD8A8473888A986A81928C9D8D8B879E8E8EA887A58D7EA29D979886968F88
A595A1959AA7AAB0A5B0899EA690A9C0B49FA293B1B1CABFA6ADA0A6AC9BA1AC8BA3BF96
94AA999B9AA3B8A7A4BBAFA7B69AABA8849D8AAAAB928DA088AB939D908FA4B9ACA8B7A1
A3A7AAB7B99EA6ADC1A8AF838B757459535545545952637C83848D8E96838F9177725E57
39495D6A908D96877F9F949EA0A07B92A09C9C9795A0989BB8828FA0928D91A1919DA48C
9FA4959492A1918A7B9D777691998771828F8A7F919C8D6E7E838B8E7A6A807D85837B8C
948680787D83798888838C8B7861816475627973798B766B5D676F6E8D836F7E9082756D
6C6B75696E6E7A796E89A2728574707E81678C8D7E6A7C6C666A6C6E536B5B6E6A63525C
4F67694F767A69565C7175757464705C686466645865606B496E60584D63617B666E5D74
5D616659696569656259645D504E5F5D5A3A4752523F5668572C635A645C566152495152
6D4D625E4F60405C4F353A424A4B426A533948556A605A534843465C5F434F4540413B54
844140354B46454746654645484E494A5A4D545E4C33303E4A1553391D201C40302B333E
30234F3D33374EFF
FF93947C80828A959AA0939CBC9E8890A6A499C79099A98D9899749BA7948FA8B5988F8C
96A2A9B8B8ADA5A69FA3969FA0A4BAB3A2AAA1A6A59B96A2A583879697AAAAA3B1BBA5AE
B19DA1A9A883909D84888090AD849CA78A928AA2A59E927A99A0909F8298A396A1B292AB
A8AFAA8DB2AEB8B0B794ACA89EAEB9B0B2AB9AAEA5B7ABB1AA9F98AC94A89CB0B6ADB6A8
8FADB2B195A0B5B1B2ADA29D8BB09BA397A7A3A694A1A7AC8C9FA4A58C91919CABB7ADBA
9B989C9AACA99E999F97C5B0968A5A5C5231393C444E73747F9086957B737B8478716F76
74676F63818E8FA2A398798FAA968F848D999D8182A39AA58EA09B9E978F8B8497A48F9F
A093888D969A8487748E888E928B8F9090938A9D9C8C979183848E847E96917D7A69849C
8F8694868D977E72777678878B7B6C788B8B75766C736C84857E60766291738770716086
84777F7A7C8A655E677D747C7E74798086946D82908F66778A7665767C686F5A62676D6D
68746F515F5C6966686668566D7259635456435F4A6A6764595A4448515B705B665C6363
75706C6D6C4F5374735F6B685C5B504E546946605657495D58574A535D4A604F3C464F4C
41423344515254564B423A50533E4C384A604F605E54605358534E4E3236355648494B4D
32564C3F52510000343B53504B595B494041474A4A3438403F332E334345254428222F48
3F442C00244337FF
FFA5A2AABD9B8CA9B6A99BA3819395A099A0A695A79B9AA58EA9908B9DABB1AC9F9CA4A0
A1999FADAAA28F8D8A93A89B8C9E9EA39B90AAAEA4AD9EA58EA4A7B3ADA19AB5A895A895
9D9B9DA6B57B99A47C8D9183827C8E8086859F959A8AA59C9EB8A598AAB3A3AE9D81AC9F
A7B1B7B1A7BCA484A6A5A0AAAEAEA0A0B49D9BA396B39AA1AB90B8B9ADA19C9AC0BC989A
9C99B3A68CAAB4AFB5988BA28C9E9F8BA9AAAAA49FABA398A1A3AEA49C97ADAEB0B9A9A6
A6ADAB9FA4B29B8BAAB7B5ACAD998D5D6949484B4E656976936386879B8A996E616A864F
497D697987A19B9D94948893908EB186878B927A988FA695A19BAC9C838FA38A99958673
907FA7857A9B8C90A6887C93989A86A09A84968E78989088788268848373727A778A7A85
8D8B818689848592757C817B788C867D6D69737D7C776C8A8E7C8A607586817972908470
706F7C738C7F7C76767C8789858F8477868378748665648A7E7B6F7F75836A756A676869
52706E6F86625C6A7779706F596A8E5F5A67436E615F6E615762655D546C47684C5D6457
58744D5A605A576F746A4646615470675067625857594466645353646C57435B69665F3A
5C494164405C4333424E553E46494F365C403F3C5B365D73535E40434A57483D514F4246
355132265358000041525E633E575650403F474A3A4A4630452E354B2E1C413E22193435
2E25291710243AFF
FF9FB4A88BABA093B78C929E8A919B7F95899AA1B9B3C19EABAC8E999CA08590A07CAEA3
9C95A2A2A19AA497A2989D9791A09EB2BFA8A2B3A2AEABAEB0A4B1AB9A9C96B8A6B6A79C
9EA29BB4A0948B8DA4969B7C7A6D7A9698768C82A5A6B49D8E8399A4BCACB0B9A2A09A90
A8A0949D92968BAB88AEA3A5BBBBB2A59A6FB3B6A2A3AFA4A1B6AAA1A8B1B498A7ADA1A9
ADAEA59E9AB6B09CA8A3B59093A29EAFAD8896958F9CA29AAD9DADA19E919D96A3A2ACA7
A8AAB6A3AFACAE909BA191BCB0A3846A5C5B60523F5A645E7988839C7A9B836572665C6B
6F617A776E7D907F83979B8E73959C9B968EA3A89B7EA2B28B9DA8B39D7DB2A193908A71
8B999D7A9892949E8E80878B8F729A8C9DAC8C847F85799C90758F7F787C7D6B887A9A92
767E8061547A8A8695916F7F81927681696F787063708B7D897871887A7B7F6F6B708473
74797272719D83646D7C7A61778393877075778986777E79897577736D66776C69566969
767F708262577E625960566374706F6E6762695E6163424E606D4B675156568282676368
627F675F5B5D7B53593C72553D4A794253526A7151675E44626E644C516B615657535849
415446362F42452D503D685758545E483B653843494A49504B4F4C504C535451331C464B
54495159635C34524C4F674E574B434E534F494458474A5A454F5135384226313A4D3D1B
2E262C55313B41FF
FFA1A7997C9C9D9DAC9CAE8992AAA69F98AF8F9C9D9EA2A2ADA0B2A59799A6AEA299AFAB
91A8A7ABC38FB7ADB3A6A891A0989BA28DA597A4948FADB0ACAE8B89A2A08E9F9199A996
A5A4B19DAA99A59A848E878A9E9DA0A696B588ACB09597889B918EBBACADA8B4A3B3AFAA
989B905AA89CA398B79D908BADA7708C8984B69C90A299A88F88C19CA7A6B5B49CA2A3A5
A2AB99959AAA9389AF9FADA09997828095A29799A793AA90A0949F98AAA3AFB0AAA590B5
AD9AABB6C5A9B1A18A999DBBACA891746F61524B3A5D546D548C8C799988927773786C5F
4F7971768687A69F99A8A3BB8D787A82969E87A59B8BA090A080AD9D95898A8B948F95A1
948A8685718EAA9986A184889495749F8B868778958583A08877827394747B61847C787D
918D818E968B6F6982848B86958F73758C828055737C717A759376737A6F7D75727C737D
84707580756F6D669081885B8B895D767C79757780946273778275715579856672785B62
5D5E617063615164707764656F6A705C735C565157426460676D7D606C6961514C5C5D5B
6A636D6D63564F666E73715C59645E67545D68596253657668655E3267697A5C53645964
5C6548565C4F60483B4A4845464D426251254B53605236674D3E3B663B3D4F4459514560
4442364A4E3A4E494F58324142484F502F4C3B45303B61483F3A3B363A313F241F303D35
382F1D252C1E41FF
FF9F8F949C97A4AD9A9BA5B481A19CA79C92B0A8A9A579A9A181B8869F9C898285847C85
959199989EA9AEB6A7978494A28FA8A69FA2B39CA7A7A2ADA1A092A1A19B97B2BB9B9585
99889089928FB1B7A79B969CA8919797B0909CAEADA2B4AAA899A4A1B5A59D9C959FBEAE
9EACAB9BAAA8BAA2989A9B8CA99B9891A498949695939FAC979A9E9497928A99B79CAC8C
7CA5ADB9869AA2899E8C9596A7A1A0908C998C92A3B0ADC39587A6AB91B0A6A2AEABA5A8
9FB7B4ACB28C8D877CA08E8AB4A0978B73865F544548596A6F6F7A7678776E7A726D6E53
6F737E7E818CA385908D829090B18A8E9098918D9E958C988895998D8C9998B18A9D95A9
89939679A29396899F8878927D759A8A7C8E91887E8B8374877E69968574779591788477
6F72556E728E89978C7F7D7A799170746969656E71766D98678791695D888F976C83757D
404B91896E73696E7E86776C6370917D72807D6C56557C835A7E71606C6F635D69646D62
65696D786E668355736954555F4B566C4B693F4B514E564F6A5D5959617167676C6A685F
655D5D6563746B7166795D3F5B5475654E5F6B57444D61575456605F6265554C49527154
5754495A3B53426E514F4D443F5C525D532F4E434F49554B5A5565504454445D2D344E2B
5148394F414F564B5A273B60572F3C3C5545403A54294F3922413B43404C26352A3C2A2C
44362F34383734FF
FF9F9584968FA397A68FAA92AB9BA593B68CAAA1A09D98A29FA49C99938E878D888E7F7D
726F9C82A5AC929AB2A991A0B49CAB98A49AA38CA19294A8A99F9D8EBBB5939D98B5B0B7
A9A57E909388B690AAB1ABA2A99DB1A0999EA4B3A3A0A6AF9C9C98A6A092ACC2AEA286AA
BAAAB99EB7ADA3B4A9A698A0A0A9C0A59F91B0A28C9FAD8BAE8C9AB7BA7EBCA09CB89DAC
ABA4A39993A39B9D99A9A8A1ACAD9EA08FA19A92A0ADAE8F97ABBB99B09E848EA6B3C1B9
ADB1A0ABBBB6979A94A6AA9A8BABA59B90715E50635A58527A737181745F77815D6A7F80
5E698182919692818B8DA69B9E8DA0829D958B8891A09F83988A949BA97C8A8F95878BA6
929699AB898291A77C878C839D867A7F91A27D7D978087999E86937D7A818D848A948681
81887B7578888C848088746F7E828A8A7E6A6E6072606F7B9A717D6A6D75746E8087896F
647B83778D71797E89767051796F7D70785F7678897F79818A746A515F5E4859535F626B
68796D7567807C7A535B787181766B6E706064584E3E49594D626E51565B5E6755616A6B
7B4E575047635D62674F666160716E585A553D6F545C5F71805D5B5B57565156254E6266
2B5E4E5A4D445A4C4749375448583745444A494A57414D4C4143395938315D4B3F61515A
5C555650525143434C5646443143404F31493321473C261D32363241563435282D2E383A
3B1F224921323AFF
FF949D848991808E96AC8A81A391ACA488CAA496978F97B2A19B90928E87998A74869298
96878299949394A7948F8CA19D82A29A7DAC98A4A598A59F8C8AA19882A68997938D8AA7
9E97939CA190A8B79DA6948286A894B5ABA69990879D959C909EA4B8AB94AAB1A79EABB4
ADA28AA0A2829799818DA69A9DAF9AB1A99EA1B5B09FA79191999CA683A69E9CA48491A2
958E95AEB190749B9FA5AD9E9F9CA89688929B8A8F9CA3A1B28FA7BFAD9A929AA9AC9ABD
8FA8B6A1A2918099ACA8AE8696B0AEA7A597724F6255615C626F72788283705C587E6D65
8168797D737FA09D8D778F908B997E8E869B6D8BA18A8E8D8E727D8D969195928B978FAC
9E929E8D8AA39D9486858F7B779580808682797F7E83756985728C788A8A9A8676667C69
6F7886808486977D816F837F95585A8081976E565A6678706D6E805E5C617A8467626F7A
7C6F88877593888072797B6966797E7A6F6C7772807A7C7D63798570695363676F6D6C50
4B6E7B686A7C656271775A616970674D6D675C4F5C686F706F46676658525B5B58505D63
586B5F625264685D6961565E5D5E5E5C4E44775C5F6D77543D535F784B5B6171654B6150
4D003D4E4A5456544F375D4E5A575A445656565145374A5C30543E274B473A574B483A49
44605D544F523C424E453C42475B3E5F4B4034481D2823362D3F2938343035333B293C29
1B323A3C474840FF
FF9F87968880A49B959E9C9E8CA1A89D929DB5B19BA6869D968AA2A899A8908A9A7A879E
A3A67B8D928CA19F9E9C8A9AA2A9999E9A928EAFABB09D93A095A9ACA78B8D7F82A59E91
947C978897ABAD97A1B9B8B1AA95B48F94ABB4939CA4B7ADAF969C86A59C9FA99BBB9E93
C0A89AA5AEA4A3AE9EA2AAA0819FA0B1959DA17FB2A39B9CA6ACA1A498959E97A79CA992
949C98A9A891AEAAA09FA195A4B1997D9083B6A7AD9A9DA5ACA7B499A6959DBABDB8A1AE
A4B1B2C2C2A0B1A094A29A817CADAFBEA2A39278545C65627165756D70665A7A7C707C80
81847D7D7A7E918AA785829098AD9E96938490958A65878792717BA49B987A91928C9D84
88A77FA9AC9A93829097879B978B967D858A7C8F7C8C816E8879809C9A7D968A7A8F926F
7777617F7D796A83755250806F867A768A5971736F73767173746E877C7D986C6B6F808F
6E716E867C636F87787983957D7A8A8A6B737F677A75616B707477725E736C6B5D535B5B
7C7361567A756D786C697161605C6D624F584D5665666D67544F6F6D7852744B5F5B6D67
5D5A6755776A516761676B3F5F646A3B5125625646575F66524A5F5D5C6C66544D5D5E52
0000544C4E462F4C6D5C553953544C544B49555658443E4A503D48343C3130495B515352
414F76564C56474C574B4F3C42404B4D4C443E261C2A282D30553F3F2C32142A2D3F4047
3F38334044534DFF
FF91888DAB9C929571689BADA19A8CA7B8A2A3AEA79D99A3A49D9691A4ACAD969E91B4AB
A2A19D8F9685A4AA9CA99799948EA0A4AA89B9B3B4ACB0B1B09D99A17E9D91AE9792B0A9
8692968E908291A3ABA28DADAB959D8B93A6B1B39987AABF9EC3B0B89FBCB1A89FB6B0BB
84A7AEB2BBAB9EB2ADAAA4ABA0AFA8AABAB2A3B59DA4C9B094A6ACA7AB9DAFB39AA79C9E
A7A798B39A988DABA38E97A7BBA09FA0AC9590989B7EB6ABA99891A3ACCFA7B5ACCAB2B3
939D9EB2A7A4A6A99AA4AA78879595B0B2B09D8160567673647165777571736C737D7F85
97938A75788E83858F85866D999A98829D97858AA17D8D8085A29EA39E88978F8182899B
A3928B9D8E88939E817A8B9A7E996F938A7B8E9187857F697CA0958096947882997D8D7A
7B7E7C6A809389967B8C73818E73827A556269726F5D5F657D816F7E6D7574837D716C75
876E96807778866F7B7D8D6F917D7E77697D7693686F68808F7A786C7C845A60555A6667
68627666797879626E636C6F6A4A6D765C64755D605A707D6A5571625B3E3F6867686357
62555F754D53673C75746D836A696C6F535E6469584A536D3F46586B677550524E5F564F
004A5C53625F4F1A452C32384A5C515A594A3D5C4A50605048634B5A56393C432E485442
6166534D5A4A444D384B5356493A513D2742262F15404F243C412646483A42342B32481D
392F2B1C4E5027FF
FF906E938B9EA79B9D938988B996C2918AA4A07B9C8E94988C9F98918C8E9B92A5A78FA9
8DA19193A7B49797AB98A2B5B8ABA790A0A29D7DAAB4A48FA8AA8AAC98A59A8EAD889798
A8929E929F97A9A49F9A929E95918BA7B0AEB4B9B195929596A78E8EA4A1A19CA2A2A19B
A09E92A797ABBABAAE98A8A7A299ADA7B29FAF9DB2929AB3A0A0AE9690B4A09EAC98A1A2
84898F939B999DABA6ABA0B390AA9AB79BA2A2998CA89BA9A19D9B98A9B0ABB1A09E9EA4
9BB1B594A29E9199969AB3B2A19687A1969D9D8770806B625E55686E675F71766967667C
8B75798B8697968B7B79A36B8AA1A39B8A999C8C879BA59078968A8D84928F67858C9D98
9EA2958C919D8683818E7F8D9682786F61818C9D8A8C8A787089729182907E8088857583
62657B8179737784877D676C8395936F59525F796C7B6683797C818C8271607481838474
708F9A808A7D8A8370855E79626F8670617B6A8A7C767987817A83765F6C76576C6A5763
6985876D73757E6C737A4C5E4B6C4C654A65526E5F4A505E5977696970606262625C535B
5068526A605A565476773F474D6F655C686C4E416B6F66525B54605A59596D677058495D
6B614E65694B2C354B43263D5A566366483E53485E725B4F3D474835414C4765644D4840
4B553F4D503B573F3C5549553F382B40374A29385B3F30383B18305E563843413D2F2027
162329353B3D39FF
FF8386A99EA59BAB8FA7A59BA09CADAEA5AAB9AF907FA1BAAB97AC84A0A9A88FA8AE9299
B4A4A490A68CAD9AB4B9A0A192A2B1A9929C99A6AF9D88A291A09CA69997A2A484AE8AA9
99A1A3999B9DA6AFB4A29F90B093879AA8A69CA3A0ACADA0A990B093A7AEA19B959CBC94
AA98A2A2B4A8B4A3BBA78EA1B492AC9E9A8EADB1A494A7A7B3A69CA2ABACA7B37EAAA09F
A19D9FA0AB9AA8A7AEA0ACA3AFA3ABA89D8C9F908D97B2A1B2A0A7ADA3AFADB5A6AAA0AA
AEAFA4BCB8B3A6A2A9AC8C819D8D9FB2B29E939386908A6B684D80727874758D7D8E8073
677A6E9F80888D8B808E8489A0869DA0947AAD879D9F8C9F9CAA9890A59098A1938D81A6
949796998F897F817E95958C837F8A7B7C7B8C8A97747F749C75828296B6876172809071
766D8F6C7883737B96967C7290848C7460556B6A72776B7584878C6D68877F88776C7D90
7F8878967664717E7576796D85746E5B576C6F8A8E676984735E75798068575F78695263
74766A815F514B5B795A4E746561603E71464D5A4668434F56515C5A5B5763724B676349
514E5E50616C66695B65604C67656835615B6A2F57603D5253464B6974744A4D5D476364
614A52425851585D6C4E565E645E3F4F6550525B64655541443F35593A514D3A44486330
414A494459584555594F5842423C2F402448421B50225A46413E394848172B292B273C30
1B382B43424340FF
FF9A9BA391AB9C9495A99E909D9FA595A5A896A191B2BC98AB8591A294AB97A0888CAABA
AF9FA6A69E98AD91A396BAB187A278A2929BA2A0B3A3A087A2A6A7AA909BA5908D97A5B0
A28E959D9E90BAA49F8DB2A5AB90AF8F9FB08EB89A90A6B1A89DADA1A7B2B29CA0B39B98
B2AFAE9AAD9C9B90989E90988F98B695979B89A1A8ABAEACAFB9A6AEA99FB3AF9EAA9FB2
938F929EAD9E8795977FB2AEA3AA989F85A992ABAEA48EA0AAACAAAAAC969F83BBA3A1B4
97B284909E989C76A4AEB18194789593AA95A6988E947B7E7B775680867F60818E727682
8F7E6383A09E988D9C948797A48E8D99898068888093ADA7907BA093A38B7F9FA19992A0
9391997B8A787F797E829C867A7F96908689876E68707876747A888A74E79F908B767C8D
8188848059868A88808D778866586C778D5160785F7281876B856B8D6E767E7C7D808975
7674887D8B878F6E7B838061606E687D85727D72694A7E6C7F7B786774727A6C5F717684
6B5E6E7F676E736F507B696C6B617D49585F5140626A705F486B603C5C575F516C65664F
8B598466645D7761567174445B666A73684D44635E506B6F4F5D504D8066553A5B526159
2D295E485264524B49665839375A60605E4B544D4F576263454C4D5E5B394F4339414748
534E353F2F4543555F5945393239363E483C234C3B3C4438333D4F4F4C404C2D1F43262B
4F2626492A3F34FF
FFA3859C8696A9A89D9295A58DAEABA6A5A0A29488A1B99C9C909D8D88A3B4ABA9A69E9E
A79FA794A0957BA99D95A1A69B9D9EA193ACA9B2848E9E9EA5AB8EA89A908FA893AAAE74
96989D92958F93A19C9E93A4A798B7A3A098A597BEA9A4B895A9ADC4A2A69D8BB2B5A49E
9EA9A8A29C9DBEAFB9B992B2AE9F8297888A969CA493B39B9D88A78E9D94BAAFA1AC97A8
B19F9AA08FA0A0A289A38A9597A1AFB6B5B1A49586AC9F96A88892B2B9ABACA1ABC0AFB6
B8ABA1A6A4AFA5AC7FA4ACAA9DA19DBB8B9890A093988A8C7D857E697E6A797C8A71856F
8B868EAB9DA37E81919476838194918881908FB3968A969588938A959A918C95A09770A0
AC898E778592827F7D859B7779897E8673956D7C848B7C827B798D8A839F7F797E8E8098
82708077935E728E747A6377896A7879858779856C5E738072747B6E6D66726B8A8F726C
71657F908689706F6D89858B6C7D606F7E746462705D88827B8170917C704F637F787961
7B5C6861814F4C7077435957685952645A66656C6C60645A605E56785B67535B61634463
5B73607C656C725F6448637A58604E5D675C4E5469637257605350625D6153633753606D
625761485D5C4A4B61415862624F52484A644B41585B50473C4A5B5A573945344C484C2A
4F55475C5041455836364750475D53375857573B42453E51464A31262F372C432934373B
2F363A4C512F36FF
FFA3969AA29D9A929F9185B69B8A90B5AEA1919D9AAB9EA4B1908E807FA4A3B79AC8A0A7
AAA49A8E9E9799ACAC8C969C9CA0B09485A098A0A7B3A78A98A5A4AFA39E9092A98BA299
A2A38BA7ADA4A5AEA69BB1ACA6B59A9AA5A3B694AF9195AEA29FA5C2A2A6B1A7A89EA1AD
B29CA0A3B0B9A897A69EAA9DAE99959990998ABBACA195C4B59A92A59AA3BAA6AE97A5A1
A1A7A19DAEB0A7B4B7A5A699AFC9B29F9699A4A7A5ADB89A98B3A3B3B2A09AA6A6A5CBA7
B6B3B1B4A3A6AC9EA79BAAA3989CAD9B87959E8E9A917A7F7B8A8C818770A290847A7C79
92907A9D8F929A9D7594A3B3937D7D8B92968A99A99BA18982939287969AA69991859599
6F8D7B777982B179939F979E8F7E8380866F7A7E807778968B8F8A71859D866E79988579
7D81727F8379696C65877978766782776F6B71717577857F806F78836F6E6B7D736D7771
6F73687C6F7E717A8C8B90737D635E7B5D8A898E737165807868786D6768727469746565
716763815A73737274775B4555556464593E595E6362746156676361455A55426855836D
66655B595D6866453458704F7B7269715A5A73565958677562556D5B6E624A73674C6575
794E665D584F4A46504F4A6552614D5158517154494E494E4953535457594B5246573101
4B4E4236563B44613F5C3C47633E4942363A3334383E3A2F4B44394A482A2F2F37333349
292B513631334BFF
FFA1A08F889AB4ADAD91A582A19EB09196ACB5B59FA298ACA496858F7EA4AEA9C39FACB7
91A48A997F7A98A6ABAF9C9E99A0B69F938DADA18B9AA299A08FB091979E9999988AA79F
9C94B7A7A1A2959D9B8FA3A49B9FA099A67C9DB4ACA0A3B7A8AB9AA5B8BAB0AEB6A7ACB7
A9A6A1BCBC9EA7ADA094ABA9998C9E97A5A082AC90928E91A9AEB8AAACAEA29F99A8A1A6
A4A4B4B5C0A5AC9D92A7AC9DB6989EA3BCB1AEA09FAD96A4A7A1A2A5988BABB2B6B391B1
ACBCAC9EB099A6A1B7C4BEA3999D85AC8D96A9ACA0967B90A396989A77957A859F8D8283
7E95A28D9C887E8193977C9185958A9888928E9D869D8CA5A197889E8D9495949EB9928F
858FA39F8E95768084A394958B797A9D9C9E8F888D82A37F6A678A817F87958E9895858B
736B5D4C75807686776E7D627A6E808B8470917E7D696D715E7A796E8E6173847E78777C
7A6F6D7C7C6A83A7788968836178707E768573777B7F83776E866E6778615D715B6B6178
69537B596B6A74526569715B75756062586374677B555B626F644F56585E556352505560
5B5156646C6A6C55516C6840565C3E466B68564C4657574D49686A68535B55464153454C
58496B5D59494D625F5250473D53605E5C5D4E4B4E4E5A66585555376455665B535F322B
334142494752503544412E515531393B2C444F553A32504A484032443352442346373A41
442E3E2D253E40FF
FFA195AF8B9A9795919A83A097A59CB1AC799DA09B9FAEA0A59C8BA38A9790989EAB89B8
BE9F8E99A89DA5B3B0B0868EA0ACAD86918DAB9CA3A9959FB3AF8E9EBB9398A5A19C88A0
99979F9DA194AAB19DA5BC92A2B8A1B89FAAC1BFAFA6A89F9AA5A9ADA9B8AAB19AB48DA6
AAC5B4A09C8EA7AFAD96A69E9096A7998B90998B989DB4AD9299AEB59BAE979E8E9A91B2
C19C8F9EB1B4A591A3A0A1AAA2A18EB3A79DAEADA0A7AA92A1BAB7C09CAAADBFA5A5B9B5
B0B1A7A39AB2A197989B9A9DA68EA3A29C839E99B59493989C94979BA88CA294818E998E
9E8F89939699978F78768785827C905F9B93768284899A899A979D9A8B828D8B909997A4
8B826D5AA18B928D8F929A847695768989858B81687E717B848B80858D848E8B9D809B86
727A7C938B6C7A73716A7764648A5A65857D75807C8D7B8B716C707D7C7D7D7A7A6DA076
6E7376797B776D7C6C5E7B887B79816C7A808666777A7B716C8773767063775F617A7B73
6B656E4E6B6E5D65665A645461775E71566E623E4C5E5056754C576E645F5859585F615A
5F5168716963665A5E676D4F505C556F544A5B586D543F5D526F6E56625D50536A4C5261
50534F58465C556A6B6C5A404640493F4A3B393F32444E4C453C4B524D5D594E35393449
3D4D5B43493D414B4A3C52463C483E3E3438464F3F373A4C3D25525939393E28404A3937
343E2837405F2BFF
FF939E899284B0A6958A8BBB9FA3A6AF7F1AA19AADA199AEB3969C97998C8BAFA0A79AAF
87A48D978B6E9FAFA4ACA194A0AA8494A4A19D9BA6ABADA5AC909D7C8F919D9C92ACB78D
9A889BAB8C91A09FB3A99BADA2B9C4AA99B5A7B09F9DA0A9B0A88DB4BCC1BAACAA8BAEA0
B5A3B1B7B9ABAD9CADA4B6AFA1AD9A97B98AA999919EA8A8B3B5A0B8969C96AC959ABCB0
A1A5A4AB9D9EB8AD8FA39E90AEA994A5A4BDAEB9A3ABB2A2AFACA0A79DA0A2A7C8A293A8
A8A3CAAB98B3CEB2B1A5AA989FA49B96AA95A7A482929795A696938CA4858BA58B969698
84869288819BAE9C86887A75908691957E899782858BAD948F7C8D9A97A1947275808F82
9DA0908A96847791947D81869298A08E9485747D957F8082947A8C776A6F6F887D767377
687991897F74676A74737E6A7363756E737B94877C89807983607368717072797A747B72
807C8A70747751645A65757668726776816F7090856B54746C727164767A6173697B7868
7E82686C7F716B5D4F587457624C6A695752596865524F565B626658574E545363786C65
675F61756B4B5E466F486561545268404D755E7D625B622648345360695C69634C4E424D
5C3D4E4E665966676C4F40725F6854545C52534044475A4E3E52475D3C5B573B42414F42
553B4B484D353B33384A4545313D365C334128354F4F3C2A40383A3B402A334053414440
303B4E302D2942FF
FF9A829F8EA192A891A18C8E8C84A5AD91A9B8929EB796B0A999929A898A82A0ACB5C79E
8E8C969991899698B1969797AC9BA5989CA4A9A0ACA898989BABA6ACB0949A9FA291809C
8897A1A79DBB90AB9396B2ACB29EA8AEA6A2AAB6C6A8B2819D88A099B4B2ACA2AAA8B2AD
A2A5B0AAB0A796A2A6A49DB1ACB0A1AC88AE9A92B1C2BB9AABA191A4A3A3A2AAA0A59BA2
97A49DA0A8998FA4A1ADB89DA5B17FC5A9B193A1949CB1BC9F9C98A09EA49BBCC3A6B09A
A0B399ABB3BABFA29E9CABB1AA9FAAA28A94A487A0A28D92959C9C9A8798969CA48C928C
7D9F898992A0A3A096949C8E879D98927D89767870839196938E8296959A837C80946B8D
8B82768A897EA6817F81877F928B8D9F85809689829B7D9790717161788A9A808D77877E
83676C7F7E717A8460727871717470778F8F847C8072798A758082756A79856E7A6C726F
6B877F74848169847C815B5F64806D666A6B746D758486886A71777074686F5F5F556470
6E697363635F615E505359604B5650557767346250495B5D6064385F6468655F5C5B6153
6B5B6E77604A52474D6F65675F505260695E5D5C64605C645F534F4965525D5C5B483E44
414B3C45585B544537454B4E463F3B39396D43454441462E54564C475C64474E454E3848
2849604E3632292D424055503B40592E1F4261414D3A364C2A32402F463A18152843362B
3921192C3A433DFF
FF968A778DA09A958888968D9298927E9E9A9AB29FA09CA0A98BAAAF9692867A8CA18D79
968A7C8F86909AA2B0A8BBAAA1AE9C8895B5AA989E98AFAAA7ADB7A094B2B58EABB2A9B8
9D9F9CA1AA9AA38F88B6C69D79ABAAACB6C0A18DA9ACAF97B59EA1A7B39FBC9780B7A9AE
9BB1A6ABA49B95AF90B0BB91B3A1979A9CAA9CA3B1A0A29F9E8A81999DA8AC89A1A09E9F
A6B49A9AA19B998E9DB09BA9AF9890A5889AB4B5BDA7968DA99695A0AFA2A0AFB1C5A7B7
B3A3B2A890A39DA6A49CA3ABA3A697A8AC9CA3A4A28397849892AA9E8A988B99979B788F
838A8EA0898F918F8E9192877B8586868F867B927290897B99777D79858E85677B84838B
A4988D7E82916F7D798F8990A7898B8089907F85838490947596907F84687D7F7F827A6E
8C7D737A776B89638680706F796260677681737F836D91806278808B73727F748D6E727B
83797D5F768F7F8485898C6582827175767C7A74665D6A68687C83647365787158547C79
68637B68607C65566D73694C664C61504F6C5F3B2F56415866495A67575C524B426B658E
797259696F6264656756604974564F484957675D51554E5B5A4C596A516A633C4252554D
4C3E4D50564C4E634E674E3E393446624B68645759423E4B564C5A63535C5545584F4E5A
262B453642314043373C4B4C29543D5F48334A52314C4831382D35231B434643432D2C29
334F321A0D1A3EFF
FF789BA47DAC9FA6B8AB8F9EA57BACADB4A591ACAC95A6A1BF8DA5A0B59A7E9B7F7FA18C
9591968A9EA3A1B9BE9494A6A9A39EA198A09893AEB2ADAF988F96A9B2A27B9BAB9EB599
919695929EA7AF8990A9A9B0AAA1A1AAB0ABB1ABAAA392A0B5AEA684A77B9CACA3A2AC99
A7898EA4A395A08E87909BAF999EB5B8C39FA6A195B1A8A0A3A8B2A0AEB088A19DA8A3A9
7D9EA3B6AB9AA2A3BAA4AEBBB297999CB6ADA49B87A1A9A3B1A894BCA0B4A4AAABB3BCB1
B3B2B4BDB6A4A5B0B2AD9EA9ACAB96A0A097ABBB8A9D8F1C93AA929D828AB98E94A89080
9496A5989D868A96AA927F8BA0838C768C858184877D8F90867785958B925C7E767F9972
93877F918C8A78A681829694A1897F7D85847B86939D878A6F8C797376938B83837E8688
84827F826A96815F6B68647D7C6494847877847E75797C8E628985897F7B877B707D7975
64757B9275836C75857B73756C7B6D6A7485857E787F74756482576B65587678806C7C79
6469787C5E6F4D656C704973586F516D605E6A496354435D505E444C4C64566E4C73676F
4A60596D56684A424A4E423652606881625E547659575449514B333E596645463F475747
3C524553585F6556574A5B3B6066454E4F40634E35555C575C52402F5B46423E4C4D3E55
483C2662564D41424F2D4F3A5F4A5A454D3D2D2D563045412137393B32405036333A3814
2A2E3F3D281C3DFF
FF928A98A58F96A39184959C8E9B95BCB8AAA39A9BA1ACADA9AAA29198658F7D828E76A0
899E8F979EAC9F98A5979EA2A090959FA2A4A091A1A5A1AB9FA09EA1867692ABA796A09A
9AA5A9BFA5B396A1B8AE9EACB3A39AB3B7AAA3B09BAFBAB6ADB28992AFA7AAAEB9A491AE
A1959C9A929EB0ABA0A8A4AA9EA6B69D97A199A4A6A6B8A7ABB7A1999F90969D84AA9CB0
84809396A1A38E9BAB9C90BB9EB1859E90AB9DA1B29E9AAFA5A38E98ABAC9DA3A9B193B9
AEBFA5A4AE94959298A8919882A1BB94AA9EA6A29E85784DAB86988BA48F809899969198
9182A09F8E889C91A096868A8B88998A848F77839883928591978F888A85767A8F8C8B7F
95958476A07A86858081879B9D78847294938A99778583858690878EA37588706D6C7A86
787D7DA38B747B79827373837C5B7C658E847B827D70767D78937A757983675D616F9172
70747A857F848F7E796F69837175626E706471767C6D8193715181717F8F756981567666
4A747F72606E73756771784D6C7A7863625A644F5C675C60643D6D5569705B686C5F7153
695D525D79695E64664C5A6F605E4A4D485754544961504E354D4A5643585F4A54424B4C
5B3746543D5469575D44284B46453A5236372D465F48444C4E384045453B474C473E3936
463239513145484658433D24323A33404425473F3149413033152926292E31333F383845
2939263B34221EFF
FF87A5908B909B958A958D869F9F96AA99BC9C949FAA9B9AB0AA9A9B99917492938CB090
9FA3A2A6B4AFA89D89A5B2A58CACAFA2888999759C9C958898B3A4A497A093A0A892A89F
A3A89099B19FA3AA9CB6A99BAD9B9799ABB79F9AB194AA9EA29C99A7A998A1A4B5ADA2A2
939395AF9BA1A681969FAA89AC9AAF9D879CB8C0B8B1A8B8AE9DA2AA9A8B949699889F8D
B9AEA19CA1A5829093B3ACAAA69A8F919F909CAF95949FB4A0898D87919DA2A7A09994A2
A3AAAEACA6918A9E8EAAA37DADB38CB292B1AC96A996A79697919E9C9AA8909B9AA5A091
8F2E4E8F919C8AACB296959E9F92868F9D7787868D9E7D81A88E9685718692746F7F918E
928C7E8B8C918D8E8D807B8A9A8F8975736A7D7D9A879F907C669086855D68858B7E8582
8C8B8E7F807776577988756F818184706B85628079617A836D7C616F5D94936C69888993
7D77827C807C726C6B837B77768782758A747B856E69846670728A6E676E6C687E756968
6C5F75636A586244626B554F78765F5B376A64666A4D686B4C5B6E5653496C6E736C6061
5D70725E4E526E5E6360656C67585C4D25384651543F414E6C495546665C5B5C3458564A
5C5048484E574A46435B4A495B505F584D45444D3D4E60606F704A4B3B553C4A4E314B54
53584C483A2149413B47482C3529473C41463340465032373E29453B2B1E3A3351343745
382E1F2624302BFF
FFADA0A69F9397A784ABA98DA696B196B0858AA7B8A29FAB97A2899BC091A2A09391969D
A0A2AABDAF8FB0A598A8929FA1A2A4BD9397AE9596909D9B8F91A4939F978D93A6A896B7
9FB4A0A3ABABA2A69FB4A08FB49BA9A0A39FBC9D90A99DACA2A5A4B1A190A3C3AB9EA9B0
B8BAB8A5948E9689A1ADA1A8B2A493A3B4A5B690A8A0B5AAA8B0B78B9E9B8D809FA091A9
98899992888EA19A8C9EA09D9597649DADB8A9969DA28890AD999088A49DA59EB7B098A7
A3A4B29FAEA39990B5B0A09493B18D8FA4A795929FB79F9FAEA5948783829A9E959C9E8F
9A676997796E697D7D898592A79188917CA396939786888098958F89A9787F8271698083
927E9694A58C90967483928757689E8489758C81927076718F7D926E7A8D7E7B806D838A
777485728A787D756B6477756E758A67808581615E7B777F7B62837C789455768772757B
7764827971759970766D796C77827C89597A847D6D797C6A7777586A78626168827D5D7C
5D6367747370797A68646569596E735C5859655E576D6D594D5A665C535C644B6860706A
625D505668646E5F495755516657591F00003A5956536330516054514F57675A4E3E4351
3B3C565930475343603B4C38525E55574F3E54485D5D494D496445473937504D3E303D44
4E2E523F4B454840295A5249493A1F373D42524F474647263C3C48382800293115341F23
3B2D4515281D1CFF
FFBD8DA3A196A1A49B9B907C8F9493B9A19AA79C8A92B6AEB9C0B29B8CA28D9E979EA798
9BA6A3A1999C9396A4959DBEA199979B959BA7859CA88A9DA59FA191A481A896958799A5
9AA0B5A09F92A9B198AEB6CAB3B59DB4B0A6ACB0CBB09D9DA7A29BA19FA7B7B3AFB6B393
AD99A678899093A19FA6949C96B690BCBDB4BBC39696B4AC9FB3B6B688B29DA390998C8D
957D7694898B929E93949BB69496A099718B9FB6B79F98948497997D8F8F9EA08F8DA68E
9F8EAC969E94A592C6A4A19AA2837993888AB3B1AA8F9FA0848E9FB29179A09F84968FB5
6E878390809794938B819F89789296847D6BAD7A8D88789590A372816FA58E7F81876191
797E7C8D9B8C9796858B8884867C92947B958280837F9A85738A74727185976F897C6A62
8284947A66667C80748E7C84745A7F807E7B847285848374858192788C8C7D777B75678C
7E7D7C7689658F75749079717D76738A6C948C84817A7A869A7678707F908C7D8665775D
6E7E756F716B566E70506C695D535C4F615B5D43595867626C586666575359635A605D72
566C56506242604F61764B663B384A490015534B644B305355574953574755283B5C4A41
505A2E434B3B66445434504131574D5D56505F6146443D474F4A453A572B324322565642
3E3C424D2E58434143363F4037303D433F3B393E3D2B3742515A13584424403D3936333B
2C503536091238FF
FF7DB387838F9B7995968F9A9FA89C999A9587817E98929AA0B486A1ACADA1A9ABAC9CB3
A4AA9F9DB2AFA08186A3A093A6C6B09E9CA4A3A5917B90AFA498A9A0A094A9A5A7999D94
A09393A7AA8A9AA7A9B0B39BAFA5AEBAB0B2A5B5B4B28CA4C0A895B3B6C1A897B999B0B7
97A2989996878FA799A5A38F9BB5C0B0BFA88C9299B6AA99AD9AA492948D829A86798D94
8A6C95998D819F9CA4A5A9AC9CAC8C819D9F99A6B9B59E95B2B09A8E92A199917B99A1A3
8DAE99A1A7A399AF96AF9EAA9A9599A09E9A9F9EB499A49899918C8C97A98F93A298918B
9CA0A9919C8693848880A48A858184998F708A8992889B8F7D78907F8581758D88748782
8A96A2878D83829892896F778F839073868C7D926D77767F86888A7C727776867F7F747B
7D8C757D8D76717C80748971727A806B8364949E807C7C847174798E8B7C8D7267819080
747D7978705E80877F758170776780777C6181736E636380776F807C71857A8268717976
896D667288554B6C6B67626F62615254586763565D60686863665B7364615D51465C584A
5E4D4D4B5E57534B5C5C605A756E47494E5759623E3D564047564E5D5543555663555156
584438422A4A35583C36345B3354414660403860513F4A4B4B484F375F33384251434F3F
494B25272B50464C5C424D432B523F404D3D54482029342C460F17352D37363D30314038
2F2A2525103C44FF
FFA28EA6A89892979F88A89F928F85AD92828C817FA7A0B0A99EAAACB494B6A3A3919DB5
A3A3A6A48B80AC9596A38C95ACA19EB1AE9C9999A58C9AA6A48C8CBF8AA29D9795A1978F
B2A89D938AB59CA0AAB38EA9B6C0A3ABBCB2A58D9BB99BA0AF98A2AEB0ACB4A89BBA8DB2
B1A9AAB2A79EA8A7A6B7A7A9B0AFABB9AEA9C2AFB2B3A9B1A5AF9F848F8F8E867A838B95
8C7F9395899F9390939B9EA69E93A0AA97BC9DB2A49BA39394A3A0A4B79BAF999AAA8A8E
A4A3A1AEA4A8B2B0A39FADAE9FA589AA8497969C9BB08F9DA28CA9859698819F8095AEA8
A4819E8D7D78768194929795918789798390918F849C979B9E9E81838F74777F85778396
9380807B7F86958C93877866817D857C7C878D877D86907E78778B83708178839072836B
7A7179768A7C607E887A848D8D717A808C8686636E756D848E85857E8B85797B765E8076
7582818690786E696C7B848068776E977A957A937974726984A6798B7A76677F77898773
54766E675E5771726F4D5B695C476459625D4A754C605264776972656B63726952535F45
4A5B4C4E655F5E664D5E4B4E5656666A4A61615F5A4B554B4654633F41394A49624B6255
594B533B4D5122394E402E3C5049485D394B4C4B473B4653463B38514E4B43432A5C2D44
3842504A414E303B29523E38313F495842363B362A463649354317342938311E292D2325
32273B22313319FF
FFA8A6A0ACA37F8C937F7D8A9C8E90A0AA9FA59D939B839F95AA9E988EB496959B8E8E92
978A8B8CA99C7A84A6B2A59D998DA39882A272808AAAB69CAA9999A0ACA0A59E968999AA
A9AAA1B1A39B99A094B1C0A5A4B7C798889DBAA4B393B1B2A6A2AF9FA38EB6A4AA88A5C3
BAA3ABA1A49AA2A5A49F89A79EB5B6A3C9A4B0B0B6AEA9B0A989989C7F8E8C808F8B7F95
848A8E85908A7B8766939791A9A6AE98B09EA58E959090A2ABB9969F9A8E75A6999C999B
8C9CA5A9AA9C969DB3A9AD9883A8AC8E7E9B999F9992A39394B39EA0A6A1B995909689A8
8C9582837C8B8F9498948C998F8D797A877F689C908D8A918E75827C7D9089767F829185
838C8C8C929290798B868E97738C878789866E7E717E857D7F817C7A74729B7295746E76
70897D7881836F748A817779858D7A878B8C717C7F878A8D7577797F8F907C7B6E656E87
626F705B837473757D576C788F7166768A867E7F716D6B797D6F70849186695A8277656B
857174617F6F6C7458666E50674A6678445A524D5C67656063665D6A4B74484F56525A56
464B5F6A6F5D4C59584F4E5A47683C42672F3E383F3A464147494641564C5E5B3341585D
644833425E4B5A4E4E55514A3A592A465640484C403E4E5050493442344F48354540493F
374A4946374F4B3454343B37494F4E4E39514A464E313D403C2E2E303E3B2A373B423629
413E2C40211B2CFF
FFA6A0839E90929996B37C6894AA859EA3999A8B7D9DAA96999A8A99A880A7899E8C9197
A18DA8A288988C8E93807B9884AAA09794A2897E8B999586B0878AA29B80939DB099A997
9EA09E82A2B4A7A8B2A58E99ACAAB1B3B5B798B49CA0B194ACADB5A2B5B59CB7969DA294
AC99AFB6949199A091A79DAB95A2A1B6B7AAC7A78BB391AD96A08D93938A86828B9E7672
6E7C8C99697E927E7E679598A78FAEA698B1B4B3B09FB1A4AA9EAE93A0B2B0A5A2A67D96
A89EAF9F9AA8B5A0AA969CA0A3A08A8BA88B9F96A3A49BA38E8B8C95AC939199A5A4947D
9CAA879683919B8C8B8E878C91899285848477648179A07483758B797B7A81826B7B758A
8A8E9E8D8AA38B958E8590888179887470787368857278847F7E757E856C76866D7E7988
9077676A7C697768837488717D7C7A6278857B857C7F696F7678618A8D677A818B7B7D72
7375846E6D6C717E6C876F6471725C715B7F8B8E7D788C85837E7864647A7B62687D5D6A
70687D7D65497067567A637053594A4A6F666F5C636060626C55615C6F434F6F63584D50
656A5E4E4159606255565F5E4239535F38305961615360615C54424B39425B5F4A524427
402F3B5C3F3E4D564B424629404E563C3D3F424A544F4B462F4544335146507035513042
2F4E373C61393945455A5A553D365339464733345B37445D4E51412C3B222E3C49423537
203833261A3537FF
FF9E8E949F947980987996A19CA4818E939A969D96949B9AA28B8B85A0A1AF838F9E9091
9A7E9AA49A9F90989BACA0A7AFA99C9BAFA4AD9994ACC8A295A89C9BA3B294B2ABA79B9C
A87FA4B0A2A2A7AAB69FA399AD969AAEAF9DAE93A8AEB899A6A8B8AAB6B3A79A9DA0BAA0
8D9E8B848F979D9A9D9BA18BA899969CA9B5A5B58CACBAAFA787849B827C797E8B839C7B
8591857E737286766C68838A9B87989BA5BBB7AEA49C9CC2ABA4A492AB9FA0879694779D
8B988C8FA1859E8C99A6989A9E7D7F90ACA6A69E919C86938A91899F9CA5817E8E8FA29E
9690958C827E989380AA888585837C888182829B7C8982737C807985898A8D88939B9097
947C858E738189768073937E8887828C7D898780866B9665757E8A75847683A5747B7E90
8F8185606A758579748E8A74808679876D725E816B7775666689807488818A6E787E6F64
6A7B6F817568737B73757F6574818076869481817B6D63706D68766D657F6E7A77675D59
645A74636458678975646D4A665543573E5659506E5C67706084685C6F45404953544B55
4E675C69666762696A5E5F606F65704C4D5E4C4C4C5E3E44563B4B3C462E50434F60415A
504653443236483F55592E484636555154452D3B3A2A49494036492D3B353C434E49433A
42343A4A3124424263494D40214C552833464A494B3A3732444B3E37223E18231C312B31
351941381E2C1AFF
FFAC9999A2AE9F9AA29D809293838E9BAE9090A590AC929E9C96849C948E88948CA0859D
93908A7593A69EB08C7F9BA987A1998B878B8089ABAA94A3AC9999A2B59591A7A399AFBD
759A9DB3AFAFB7A7B0B4ABA1ACC4ABA3A2A8B1A8B6C2A9A7B59FADA9B6ABA0949FA39A90
A7A491A49C7AA498ACB0B19FAAA49AA98C8DACA0B1A4AB9BA1929F74858E7585928F9376
859A7C86767E6C867A6C7D958094A5A5BAB3A69AA590928FB89AA5B8A3859794AE9BAEB2
9D82A6C08AA6978FBEAEABB5939FA893979189A09E9F7F7A838C80878C9E819292917F93
91728B928D8A7383B3808F80859594939C89897F897C80879284766D777985888A947F8A
AB818C749A8A83757D998F88837C7B7286928472828D91816C677B777984897A82848182
7F7D83708F886E7E738E6E7E847D5E5193605984768D8272756B6E885C76748D857E6662
6E596D6A7D7577718350737A8E7F8E75698B88977C7F82687E7E777778717975756A785C
656F3F82744D556B686F676D68545E5A675A4C585F645C6A67472F3E517C51505D426C60
663C5A525C535956575960524A665964594E554C3E5A4B40545A4C4A514B43527A47504C
514453504354514E5A515D5B585E4D2F3E334A4D3F3E4051483D38463E34472F37413354
444241494141464C444948314C35233A56653B4D4141424339424430401E25273D3A3C3D
3D29311B373831FF
FF960082A07C918B8AA0998BA89594A89AA1959494908A97979D9A8E7B88AB9191AFAA9D
918E91919DA0A190939C98949EA1A1A4A8998C98A0A59FB19C8BBF8C9D789EADBB96A292
81979BB89CA9A9BEB59DC2ABB9B89C9F8E97AE7F90AD9B9B9C9FA0A88B9C809F9AB5A191
8797A0898FA0909E9391B9B3AC9DC4A4B1B4AAAB9EA4BA86968F7B9B7276709A979E9194
879AA1888E7C846E805488999E8F8D9C91B08D9FBA9586B6A1AA8E819FA19D9E9893918D
738696A58E999A9C7D9AA0A38DAA8CB0A9B0A09D8895AEB09AA6A49395948E868C9D898D
768183949E8A8A9B918D86879180848089757F90916C78988E7666718E91838B8E8B9E98
8F958A9A7C918776908A7F907D917F646E688E645E87947E827C6B7E8080636E84767F77
7E8E98898E7C7673828489768F8F72708A7B788984896C8B6D657E715F746A7C6E6A656C
80756B797D59675C837D899369797974807B727790766C7D7A86787D8282857388866167
5E6F60726C7277696458546563684B555D6567695E4C5E585064525266544A654E594A5C
3D4B43685051466B464F594C535061646F5E574564455B4F3E3A41555E3337485A4D5D5E
453B474F5D4B3A57354A323B57404A4C444245494A635228493A49423D3E2E4E3A402549
373C423A4C383E3B493F3A3347424244433D3B4A46333603363C2B2D31492F35152B202E
253B2E212B3832FF
FFA087A0A08D9B999D91A688757EAA859D9CA49D96828A9981A99E7870908EA0A9ADA3AF
84908D949A9EAB9FA0A9A9919DAA8C778993B08AA2869AA2B4A0989F929E98ADB2A4A89A
8F8FAF9F99B2A0A098C0BDA8ADB4A6A0A996A39D9DA7A5B5A4A1918EB1919EAEA599A38E
A8B39D9886A0B39B9E9EADB392A29AABA292ABB19FA5B1A1A6918B8388848B9098A0AB7B
9A8B8A947A72916C6E667C837CA4B88FA991A599969A868B879098939D9EA7A6A49FAC82
8D968D80977E999297AFA99BA7A5909F95C09EA589A98D8B939B8799839A95979E97A9AD
8C9D878A858B6E79886E7B898599817F668A7D998F9C866F6E86898E75838D8D7D8F8372
6A72796284787A89938B8F8E859B838D847C9182837564728D918574746F886D827F807A
7C7D77747E7E96817C958B91786D78706889857E78726D7685727F766D7A756162637A6C
5F5872634F6C69766B7E727A818299806C878F81768386836A786A7A7A757F6C6A7C6D62
5C637A42674B7D646673676B6A596053516067606F577162575C59495373514C4E56433B
625666565C61615E4F5756575B524B415A46585065424D5749574D434A47583B4C473F38
41393939455150465A242C445441575A503848563E383B4543534E283A362E3E4D2D4E45
4842454537392D5B4845332A1D2E59414A3B35434D34422B26413D2E2434443941362A2E
152B1B2B171E11FF
FFA3A19B9B8F988F919099A28C9176859797A3948F9BB0918688969E8B988F8392B5A2A5
84ADB5A69CB3A28FA293A69BA79D92A59D8995A1ACB6A1A6AABCAEA6999CAFA69AA88FA0
BBB099A8B7A0BFACA3A8AE9C9EA593A4B9AAA9A7A7A29CA49CA09FA69989A198948B91A1
959BA36F988A9F9B9589989C9E98A0B7B89AA2B1A1B1B39F8D6968787E8171828893A6AB
A28F85857B786E657B827B77B0A698ADA29AA3A2908F9997A2A893A37D9A809C9B82A397
A2938A8F979E959FAEA0A3BF8E8875A5BD9EB38CA7909F958F99B4959788929CB3A2979D
957389939395748891898D92827D6A7F899181648998877C7D828073738777789D9B7A6F
93849287888EA581968365858D878390829E7B7E69748B73808874757A80848891678580
7F7E7A6A8068687F82858C858370837E7D6D636C837E5073815072797288726B7162577B
6E7877697A78727C6C749B778A8B7A8E6A896D878088917872526E83747A6D6E7E82506E
66484B6865778068675E5E594966694B4C4F6056655248625359435F4E5F5B5D60494636
474E5D406F564449443C454244555B4B4A605F66605E44553E695A48554A4D4E6439473D
5348582F474E533F3B5254423D47465A473C56434D43674F322C34513E1E4631193D3A4D
543C3E4A4B4B3F3B3E494F4F4C3E263B48263640293944464443334C3543353C313C302C
172F1F38302239FF
FFA16E859B978D9FA08684909699878DA5AA9594A4A88CADA39E94999791987DA59097A8
79A68FA0AA9EB1A3A4A4AA9894A29D9698AD858798A6A6A7A28A99A3A8ACABC087B2ACA8
A7BEA8ADC3B69BBCCCB0A2AEAAA7ADABA0AEA7AFAD829B9EA7B5C0A6A4A28EABB9928D9E
A7A8AA9890927B83808DB7B7B59BA4A1B69E9D9FA8ABA29090786D746D697C84939CA28B
93AE7D9F7780725B736E8BA3ABB3A29BAEA09D9088A49CA18D97A8948987A1A09C959B92
8C728588A0948E9397959B9BA6B09798AF94AAA1A39D95917C8BA497829187967F7FA098
93936687959B9C8F958FA482949882737E93968D83867A83907678846D6E877F8895739E
8E8A9791848F827A698D74907470897B7A87847571878783767D85867A8569867E817887
7361818A6E867D948B9E9194707F7C7D71708973836D7F888971686E716D74787A6D775E
7F6F6F6D746563936569858B7D738B6C798D55805F8A73817C7488766E776779775E625C
6E506B524C6D5E6347686269686A46433B535D625A7160634D5B6665585A58686A4F543E
6935544E2B42382D3F4A27394D3E4060385255495057453A444A39465B4F463E2A4E3D49
422F423B40433C2A353962413C48564545354F5F555642374E3D323D4750464E504E413C
44564152363732353438492318363962674E2F4F4A204A373F3F54332D24321B313D201F
2815281F2A1A35FF
FFA17790A99B9D8BA1A59EB49CA496A29F9E9C95909D929EB093A6A4A1A09A98A6ACA1A4
8E9E7EAF9A958EA29883A2A7938D998C9D99A8ACB9989EA098908BAAB2A68C9B85A68E97
9CB19C9DA7A2A8BEAEAFA8AE9EACB3ACB7C6AAB5A8AFC2A399A7B7AE8A8C89A4A9ADC3B7
B5B4A5B8A18391948C9E8D9DA4A79FA29EB8B8A0AFB99F9E90837082698380928376929E
A49E9C8A8A68755C737D7F71858A909380A69D9A8B939293A1A9858E91967F94897C8785
8B7A8E7E8A8CAC95979EA5AAA1A1959F8C9AB09FA38A8CA4A382967C9CB1A38C85A39995
8FAB83858D80978299978186927A807B7E928185747F917B6F838473848996B69C99877F
8787737A75858D69706E847B86649482858B8B9E86866B848882867E9E8B786E65768F83
827B70657C5D8C796D6E8576796D7D90938E979276808F776460647376848162676B7D6F
6576617A7C6A6A627D6A757C6A65897C7986807D836B6B8F78678881837867877F6B4E50
6E807568525558706A4E5553605444657A5E5F625B604849533B5057515C58415F523F60
44664C63513B493B301B0F2A3043334F5342534F5453434748203A464B3F4A374C506056
345B393636433147454F3D4F49423C5D59382A395B3D554E373B2842382C424F30315426
3D2A3C2F3C463725283139474348244B24574426373546343A46373B432E1D43282D4448
243235250A0A20FF
FFA6A28E91999E9AA0829B84A97E91829E76968BA7969394A0A0AC83A998978AACA3B3AE
9F90A28BA5AFA294998EA6B196ABAC9BB2979982AAABA0997E9594A999A7B6BDA694A89F
B49B9DB4B3B3ACC2B5A6BAAFAC91B395A0BCADBBAD90ABA4B3A89B92B2A493AAA6B0ADB0
A3A9A5A490908F909AAAACB4A0ACA48AB39F96B6ACACACB38C7464764F52608C93919296
B3A5747C9A727C6971675F909DB1B6A7B3A091A18980957381858994949B8B9A9A85907E
807C4741476470939293AEBFB0A7A4A0A8C3B6A58E95AA958B7F908AAE9F99A89AABA494
A5848C97869F897E8D86A594947D7C7579757A7F75948A81A58D89687A887EAA98778A89
81917E878C8E80927C827DA1849577978A848F6F7B85806269727C787C8D9086887D8881
80707D7868488E8D8D88896B947D7F70756781817E9A7F7474787673827B5E625B78626A
7767906C716182646D7D628A867185727F847771788C64727A6E776D6E746E798772596A
4F716F687B775D676B6857485C5961597E7A5F644347526A5266626057534F694E565151
634C40392B47475B4F1C2A312E33314144445E5D43526F67444F467144454743553B3D38
5147492950615B4556585446404C423F304D4538393E374F465C5138353E2F44452C3431
424639462A33432C263F354A324B2A2A3240410A234249312E36573B1D383A3F2C432635
39142934251922FF
FF96A1998FA39A90869A93B88F8A94A1ABB17E9593919DAA949C9E9C939E988D99AA8C95
AC939A9B9B9098A3A39D989EA3ADA29F9C8976979AB6C0B7A0B8A493A7B19D9BA292AFC6
A7B7A89E908FACAE9B949BB4A7ABB6969B9AA08BADAC8BAEA8A99BA7A8B48F93A5BDBB9B
A4B68D98B5918E8CA79E8697A192AA9FAB9A7DBAA8B5A07C8A8D6A465F6C728581859080
9E9A9D8E7B8B6465597A5E6F9EA5A3A992A3828B82917E9688A69F8F9A87888A7F84848E
7256242822415A6B988A949586ABAB8E9D909FAE9FADA4A796919E9E89A09B90A08A9E97
A6A595889E959894789096918A548C776973758B7C767E726B547D8A8E72959683869A98
838D8C896D7B7C7C85917D898E9A7B81A6996F908A8B7873747E6A5D79A57B875E8B7F7A
6B80706E5F89777C86887B897B7C72886787856E92827B7C6E6B75838D6A546967606671
7785866B698A744B487294846C937D81827B7D7A837E776C756F6E6376627C56756C6A5E
6D756C7654826C6B5363625C7A605D61604F68524D5668595B4A5C586E525E5162436552
4F334645553A42324447440F36353A38475635525D646661643D34364D4B495E5335423D
2D4131314D4E505452492F545147414A404750484A3A313C3E3F413F4A3E422638313B32
43512F14252D3A402A4239364F4B473D41413D313F4D203A3D3C4E32463532452F3A4454
1C302B25313C26FF
FF9A9A9F9A9B81B2AA9E719487938E869DA2A0A48C8B9479A2967F87939DAD9BA8A49899
A6A7A1A9A995808F8F9BA8AE9E91AF8F928EA59E9BB08D99A6B2A4A8B599858FADBEB5BB
B29398B0ACA7A1B0ACA696CDE4B0B78C989DA7B9A58C9D9D99AF96709B9E9FA69685AC97
8CAD97AD81A18A9F8787ACADB5AF99A2B194BCA2A8BB8F968D64705D685C6C7A78928A9D
8DA37D9E73855F566E737F8B8595B8A6BCB2829192948A9B9A8E948A8E8D647A858D8384
58410000003C698D8EA6A1A7988D8D94A2A6AAA3ABB08B958AA3A1AD989DA799A374958C
938D836887898197A1837D895E7973828D6170787A78768187887F9C8F7C5E829A9E8F82
8D8E878A85686A8186739C958F74637982A2879C89818A8177898D888C636E6A83848D71
8885795C8476736F7E808A99667D7B7E75738C8D78667C8B93716281875B636B6664907D
75877B787D7B7B879282717767908A5F8483837E6C667B6F6878796B52667D7263717874
5963766F64576969564B3F36444D54473B484764685A6C4C4A5B5973634847645564565C
593B3927383C151E26252C2D3830373A3C1E4643536550555A6E49694549552E504C3158
5639613521474237494B415743463C494A3E39492038432F3A3244534B3136442B27333A
322A313A3342415646343532425158392820543441452A37584E393E352E1D3D422E3D25
16251B2F333832FF
FFA193978C8C8F83929C9B7F938B7C968A959C9D8BA7A499967D809A8899929AA8B6A9A0
9A98979A8898BAA49F869CA38BA5A29D92848BB18FA0A8839D8FAD999FA38B84A8B8BD9F
A6AEBAA0A9AEB2AFA4A5AAA29EA1A4AEB99B96AAC2A88C9DAE9CA8A48AA28B8BADA39A78
B1B8AE9BB0A3B3A19D94A4A9AFBCB6A68B9794B6AD8EA29F98745D6D5674818981888A9D
A49190706D77666A546972878CA2B7BD92819D7FAC9893ABACB9949C8DA3858E93A99789
7945000000246A878A9B9D829DA08DA69FA7A5A193A3A4B58C9BA49FAEAF8F869AA28D8E
859181828D93A17FA28989937F9294846F898C8C72857E887C767F73868D867E88837871
728672707A937881967D7F8D77827E8A888A8D7E828D7F697C7B7F7E696082779880677F
796F8A7F787A7A8E8085859983677178766F6A888B7F866E61687683626C5E67736D6F71
678A9067756F847282837C85898F7A7B8A816D7A7A867E866C7268575A7B756A7A735E6C
706D716A6E6E5E69574A554C62785C6D6A5C646655655D3A6169443C4B5E534F4E595547
3A3C2A3F3B2F473C31212447332111372D2542433B463B684A474447323E3940495B453C
2136404F40384953200046304F3043525C45382B5B512C433544435F483F291C3445272F
29404B41393E2D424D353E1E31383740412A332A3F5B46573C35412E262D3F2924323E40
331D2A202F292FFF
FFBDA193A3A076A7878C969C9F86948496849B857CA5998AAC96A594948CA0A99FA583A7
93988A8D8BB2AA9E899FA3ADAB8AACA59FA18CACAB9A919BA09FBA9E95B1A7AFAB9FB6AA
9CA29E9BA792ABC194C5D2A4A7A5BAA5A2A1A39BA8ADA8AFA7A2A7A68B859BA698A2A993
ABA39EB89D887E969A9F9F9FA49A9FB5A3A493A4A9BCAEA3A37E6B41546C7D66788A9499
8A898F78967B6B735D60628D9EABA9ACB2B3AA9A868B8C9C9CA99D7D8684879092B0B985
5A4F21113067708892A8A5A9AB94A59A9DA1A3AA8C999891958EA596A9A1979E909EA4A2
7D91AB968A8492AD8CB8988793998991929BA086907F85678783797E7684867185888F84
8C8D807570947D7D819787987E80858F8A808F996F887D6C8187866076A1938090718F7A
9079748C8272766B748A79868D787A7F6C736A73676F76835D6E71728E866F697C71736B
726B7C636C756773857B7083866F668A7F6B756B606B7561756F7A79667681555C74616A
697E6F67617F5557506C665F776660606A675059446758795351504F6C48275957514B23
4F4E3329374D494954534C27322D28413D453633383D454B4C4A5B254C3136364946312E
545152524E3A455A4300223A443B3F353A4D334A414142464D284B42375E3B282A332638
3C3F414246434340583F323F31435039223D4A424031384D3F37323246433334263C3D45
341A1B1B142531FF
FF987D8E95898D828E96A39E7D888E7F9F819A9E9B8E989291989B97A09F999E8C93AC96
A39C879884877F8A829BA78D9C89949EAE9E91A9B6A2B0AFBFB698B07F9F87A0919EA2A5
94B7A1B5A6ACBAA7A9BCA0B2778CA6A6C2BC9395AF9990ADB3B6ADA6AA9B84A9A59EAAC3
8EAAB49990AC909C8F999BA7AD8C9BA29EA0ACAEA095944F66705151667865668188857D
A48D876B7A686759767F337979B3AAA796B499808F8F8291A89392938F95A0A4A0919279
875E60594D6978908DA5A2A388A4919C92A0A89CBBA89DA2B2979CA395A1A889A2AF9288
9E6A7483998C7B929B7C7D9E858E998E867E80869190858B8A677A778B73896882858B73
8F85788D8F969889808793868D81878C819A9685908B6E888887747E918E797B7D757E75
7C88807071727E688D8377937C8E8A7F6E7282796C64547876897C595A68866C5D686E7C
7684767768696F7272807B6C7F7D756C737A74859A67717A6D6F687B777B595C738A626D
81726F7E73726A6D59594E6064675C68706C6264544757605A515B4D3753614D5F543755
4E3C4B363F484E495253504C4D49463D3E382B453F3B403B545C5468432E62494D594D25
224D523E3F4249443549004246292E494B473C3B342F4B303F422743543C4D2D2E334039
3C3548544631341835321A3F42443632252E47423B3520555B4D2E262B311E4D1F254122
1E2001223A2A1FFF
FF92A48B8C94879378939875A5918A8E7C8F91A085A38C9A92928E9CAE9D7EB09EBDA0A7
858E97A6B5A1AA99909F869C869596ACA49AB4A0A194A47C9CAB9B9DAF95AB97A396ADAA
A0AB9D9BAAB08F90AAA6AAA8AEB9C4BEA8A5A8A5A09FAA8AA8A9B091AB84A3818CA1A9A4
A0AAA48B9895A19983A49CA796A69D9A8D8A95A496A29D908B917F676E4E7067637F868A
8A78929C6E7662745D717286A9A0B1B4BE99988CAEAD9C9B9798949F989E949C97A9AC9B
8D6C8189908F84ABABA5A29B83AC9DA6AAB1A6918E91A49F97AE778DA098A09191918693
9B988D88898E8C8B7A9798747DA297677C8EA694919989926B89729C83887A7C7D6C8387
898891747892827F7B7E7A7178749D90708883877B8C868C786C7E839185846F8B7B8674
78868A81768388808783788C6076726D79857A90817E748E77858968765D576B7380857C
64727B796D5E7390767577707D80847888848285737C7D787D848957645A85606C6D6562
6D736A655768625D5B65726763615B587C646B3D5C5065676252527751656B625C5B4C2E
422D3544524C384049564B604F4D495A31413D31353C42404F4C5043585353452C2B4950
4B43423C50464F475E503B4D50604B413C432E4443444A502E3B43364C4250454130444A
432D4F34352D2C483B2D3E3243462C3324463837453A32464B4C414F3C2935352F4A292D
13410B14112132FF
FFA8819EA5A18E85708293838794878A9DA59D95A88E9C978786A1B7A498A2738B91A08E
8087949996B9BDA6958C85A596A4B8B293A9AA9B9E89A187ACABA9AB94A49A95A3939EC1
8AAB90A89DA9B0B79BA2A4A4BAB08AA7AAC0AD9B97ACA39DA8A59A9B9A979AA08F9D8798
A6959599B1B086909A9EB197938AACB1B793B7A5AC99B7B49C757A4B56706C6F8086839A
8A808B667A79755D7A7A6C7B95A4A3A7A39597A17D81899295C7A9A59FA6AEA08391899C
8AA1AD99809996B99F93AAA8B1AEA49B8D9D9BA38BAA8C7391AC948C999B98858492A39F
81999376869D9B928E8A8389767E8A888C616A8E95788A6B8C818A8B7686828E6E758A81
788E8C8B898A817E868F8A96898D9779827F83759695907E70837B81898A7B907D896C69
787F9583808574627F7A857E66646E76827380707C69707A796478836F6E737379757176
6E66795F5D79705F6B6A678576837E67797E797A5B6576675863627E7B7C7B665571576C
7671584C5469676161605B666A5757495455534A412E5D384E6B7553706D72464826343D
433F3D5D5A4247574D5B504A435043231B282A263741373E4947495829353639402C474F
3A312C3D3F454A5F4938503C46402D40454A583B383F383D39454A4E3B1F1645232C2B38
454941483A3A4938363E4F391C303836282037383A3A36272331282E3137383D37333A44
3618001431222DFF
FF9D7F8C78958C808A8AA8A38B9E969D93A98300788294A0969FA58A8AA29BA29DB0909B
85A0A97495819EA98B9B9D96A89596B5A9AE838D93A59799AA9F9F8BBC97ACAC93A09B94
97A299C0AAA59F8BA898A4A9ACB5ACA19E93A0A6A49D88ADBABAADB4A5A29FBAAB919CA1
9BA1A3A296779496B3A5AF9073849DA79A93989D8883ADA6B0976F6F71736A74808C7D79
7D6E7B808968646862567C8A9EABA7A7929EADA1ABAC99B297868899958394A2939A9893
8D938CA08AA195A5B1ABA6AA9D9B9799AEB595989AA08C8B989597AFA19199898F9B979F
8A978C7EA089946D7F8079808D948F817C9B829094828B898866808196737C88869A8482
7D83596E697E9D857971647E5D7F827E639082848F928C828087928F575C888685869680
7E7A71848B8B78667E957C7D736259686D78606A67684B666A78636A89648E8D87575D52
65786E5D6F5262745C797B75708393786369515F6D8D744F6D5F727B6E62676874533A4C
565A554F6760646053766853696F64524E486067536A64655C7159585952655D4A423643
3943485A3F575F504355575E574E404A31342D39442A55455C424B4957584A55335E4D38
2D3E483640535C5F4936383738495B346739374D4D3937283A2F39343039312C4B444122
3C443D4245301E37583F2320353F4B50554449465944232E1A2446411B3D3E352D331F29
24331521283A2DFF
FFA6A28893958E8294857B80988F939391968390A39B8D8EA19798A1988A7A9194A28A9F
83A58F9D90898CB19F958B848A999B90B4809F97939D918DA7A18D9EA29A958B9E9F839A
9C99A49196AEADA7A79C8DBCA888ABB99E9BA19BA79AB8A0A3A0A0B9B7A5AA93A3866D88
88829782848A8A9287828F7F788C98939DAA818A979EA9A67F8B73736F73697B7A6F646D
576E747E7D816878897C8C977A829B947E8EA1A5A3A09D989AA793A5908BA08F89A38EA1
8783A49293A68FA497A28FABAB9BA6AB8D9496ACB39C9B9B9181AEACA085A08696828C8F
9CA4977A977F8F9184847F93AB917E6E747C7085808C906875647B828F766F8183687E9A
8C76747C887C8E7E6F68617B737886818C7F7A858772747575956E678575687C7F827F74
8B7D7D68596E856B6664836C737E676E7B6C71697A5F62667A696A786374586D66665C73
71536B62626F666F80607361656C6E6F5F6E6B625D60595E5F526E5F645E636655625B40
6A5E5D58606A7546735D6C5E6765805B557765746D66635F64735F5247755D4B4544292D
3140494267546754657C5F3B5544353F2E2A0E27272A3C5F4A4E42372B37390F43254731
37381D3F48401D41423E463F463B27502E444825324D363E3B34464736364A3B2E442023
2E2F3B3E3A351D23102F3817252C293C2537422D3B3C2D2A3C240F4F322D412F3C2C333F
34312D18200B37FF
FF9D91A3829188857386A39C8E8E7E87858D8C75A5949C5E76ABB095959F98AF84B4A89B
AE98A19E8F8B9F8A9FB291939EACAEA8A3A98BA69188A69EAA9BC1AAA69EB1AE9B9499B0
89ABA198A09B9CC7C596A2A2B9B0A8AA9B9A9CA2A993A4A59CA8B5A1B1A3989AA5A1A798
AF95A6A5818D9E9FA791A4838AA0AC93A19A9582848A9A8C9590766C7F85968B78718A98
9F907C8D7F7E767D7FA0849EAB9A9B947EA1A3AFABBAA18CAFA6BDAB939EAAA682819391
A9C290AA9789B1ABA3B49FAA93B39B9BA599B6A2A3AEA9AB97A19690807E968497A87D93
8D6E898E9B8A8894758C7C867E778177778082898C8A7E6C3E739578847F7A76898D9897
8C778A8E808A7D987783769086867B7F7C838E8F9165897B6D7A7E4F71844C91967D7E89
6B686E8E848D7D81866C697D747A7A6F9267756F5D65776E7C7D7A70787F758379677B5D
7C8474636C697F736662587C737E79769662896C704F79626755437C566D5A666E614F64
696F746D64504A674E5F69645F516E5E586A72685D655F68565B655646624D4F4531463F
443C4E424E665A4E5E635C695F4638371C2E3F433D2A566251525D514549456249485458
1A383B423C4642453A363A444565402E35304739454C26413C2B44433F3A414E461E213B
3C393B342F30243738221425284538213D4A414031302E0530253B2D38252B4030403439
29371E2A512F17FF
FF9D8C848E9280889D9B80617F8685889A9F8E8D8794990039A795A28E8B989199999898
93A19C9F959D99A29B98AE9DB1A7979C8CB0A17C989EB2A0BAB8B4AFB2AEAAA8B98DA8A7
C2B6ABB4BDAAA7AAB0B5A8B0ABB5AFB19B88A58CB6ACB9AEA0A5A295A0BDADB99FA09785
97949C98A7A3A0A4A5AE919CA7908E9FA09091A0A1A59599857B888C838A7C8595909A8D
6A77958A8389758A8D888B8086919D859E9A9F95A8ABA2948CA5A19694ABABA5B09EACA0
AA8F969D9298A59BA0B695A4BFADA7ABABA996A2849C9B9B9294949B8481869199A47D9D
8DA0A39C6C867A9B85848D87818898898A948E67948B787F918E8978817C797B8A80768D
6B82889493828372A27D8F959A6B86998E9A9F90797E77627B88776D7978797C737F7F84
8B81756D857F8D818C7C766E71677A8B778E7A6F76756E65715D73696E9B6E737A766D7C
6C65527782737965686B717A807967696F6B7E6F575D617A62576C71796F526962577163
656C6260495B6A69705E4463675C48626A6E7E675E4760545C615540655E7A60555E3F3D
3D394C40475A4C5F536F74404A5746453329362C35444948453149523E404D3F484C444E
4F4448493E352B3A35483D4B4755424729364E444F3544442C4E433E393F473E47474F4B
3E3C3A301B302A182620341F162B253C3235322A5046303633293C352A263E3338392D2B
45322B3429192BFF
FF768D8A81908C948A807487868D92838B8F8F808A959E92A7A28EA297969D9F8EA093B1
AB878F919E97A17FAAD29E98AE999D8D97A8A896B5B7A0BAACA6AD99AEB8B6B1A78CAFA3
A9A79EB297B4B1C5B0A9A299A7AEB78DAD9E8EA8A4A89DA49398929FB0A19EAA9CA3A99F
938D9F7CA5A4A9A2AEAE95A9A3AEAFAE9AA0A59E9DA3AE97A3A88D8E8B7B92878A9B8F83
867E82838A877E957E9497979488A99D8DAFA5A3999BAC9E9E9DA1A3928A78A8AD9A9E8E
ADA69F88A1B2A9A0929FB3BCAEAB91B4A6A59E9C9288B09B9BA2AA9D97A899868C918D96
9997939C9E8A9793687F8A7790807D8768799290708E97787A798B8E686C7581837D8873
8D767C7F8A8976977F87717B8E8784827E7B758A746D835F8A8A818281727A738A667187
7159708A58998E857B677D71777C68738E7D6B787A796E6F82696C736D72756774747C6B
5359726D73607C706C627E73827C70645462806A737B816B6C735F746D696E515A6D5F72
5E60574A5B565B626C7D6A79505D616C706654716E553971564D615648655A4E433C1E3A
4B483F43486B5B455F5A524D4C413F002D39462C31524E503C3756424424374547325D33
483F3F36373C504042324C3F3260544137453D325431404445422D4A393C514C312D3B34
391400101A1213191F1021372036272F342B343E3B3231293B3B31312B1B282526282D3A
25141C0D2A1926FF
FFB69B86797C8775658691706B6B7E8D907D8A738E9A8F979998A0AB8C879296AD95939A
A18AA574A0949FAEAFA297A28498A5959A94ADA8A3B1A2B3A49FA09196A5BFA6A0AF8CA6
93B1AEB3BCAA8491A6AF94BAB2A191A0A3ADA3A6A9B8B791A6979BC49DC0A3B5BA939DAE
AAA2BFB5B5A9AB949AAAB5AF93A69D98C2A79499A69F9BAC92ADAE93838D8C8680A59692
8794B092958A9A9B91979EADAECA9E95B4989C92A2A0A2BA9FA5A6B0A19D9797AC9EAC8C
ACA79AA09B8DA0B2C2B39CA6B297969592A6A59497918F988E9C9A908F838E959C86809B
7F9370959391837D8A988872928F92967A7364857A827E8C8A7B64798D8C8D6594839C88
8F668C93988D95817C8E858F777A777A91768D7E89926F7D7C656E62698E6284637C8573
8270847F5488897F797373817B756D4C8178837F7E657C7F7675835859805F6671867367
707C75777884777A7482657D6E9A7A49685F636E7774785C656560846F5359635B6C6457
594D54644A5959626969696D7B615472587075725A686E675C4C63715F63634A57444B3C
374A3532363455543D4748565032312F22171635534A4047374549335C4C56543F4A3C2C
412F43283754374B4A534B5C394440433D414E36362C374048455737513D644834393838
23031A1D1F08101B0913152B2C2D262D341F35353738354D3536384B26283722422F4332
394021381A323EFF
FF9E9194957F937B767E72446A687E7C7A7C64899A7196928E95A79C8C9AAEA38B888C9D
9CAE9EAA9989A4A18C989B9AA69BA69DA9A387889C8EA5ACAB94A6607D9C87A4AAA0C093
C3B59BA4A49CB29DADA7979C999E9DAF86839AA7CBA3A1A7BEA7AAA49484A38B9EA1BBA0
9DC09FBAA3B9A9A89CA7B2A7ACA28A9B9D889FA094AAADA19F829F7B7C897D9E9C89887F
929E9C9B859C819B9893A9A5AC9D9BA1B3C19799A9AAA4A7AA9DBA929F908BBA88A0A7A8
939880A19F9FA29FA7A7A4C9938F9EB0B7A1A9BBA6AEA5A587A89C8A8A9F69939D7B8977
86959780708089A6909085837F85869D7F7F7B86927B69768A758579808074898D7A8E8F
859FA5928F94988BA093868D7D947C868B8A778F697979786F7074946F686C92947A6D7E
7795858780787C717F797682768D786A775D777C84667E7C76816D7A5B55886A57625F85
766F7566686C75846A6F826F67797F716D66698A757B7A71796E516D7664786D6061615F
6C757164756B72684D696C5852634D5A634E705F7460625D5E606D5E5956555F594E3B36
3A3E33412F512F574D613944604A353F362621543A5040434A4C3D3E4D434B3439365346
24374650362A343943583551384C424C423D443D4D462E2C4327324B4C403C3A45364068
24201F140F12142523381F2825062B49433B3410431D30473E28281C3B1F26312C2B2D1A
1D403C31191B1CFF
FFA693A2918D8B7968907E88737D8C76817F7177848B917D8D9E9C987E8C7B8FA480929F
B78C8586B0A1A19FA89CA4AB8A91A1A9A19799949AAEA5A1A5AC87A1B4B49588A9B7A19A
92ADA5A1AB9390B295829BC0ABABB9969BAB91B3B099BAA1AFB29F99B6B5AFABA89F8FB0
93B1BBA2C39EADA297A09E8B988C9DA98F978B9FA0AAAE929CA6A289829892A08D99A299
9E7E8F7C9F948D9D9A879DAE96A7A0A49291A59D9196B9AFAD9093A29B828A92ABC49580
A0A1A4BAAAA79AAEB7B3ACA3A19BB39A9CAC929AA9AA968F94A98E8D9CA086A38F9A8F85
9890858E9E84778D8B868F8D82866B6B797F82957284957E7D9C82736A917F80858A8C87
8A8C787692888C837F706B82889286807788826E868B78857983768375807A5B766DA291
866D808A747F8A877286755D785E748B766B81655D796B65636E5F6A7171667366516868
6872716B79606B6F8B727B7C7058756F7686887D796F5D60654656655E74607570776F56
6D70756C5B6D44536A5D655673637C696F66676E7861694D6567646C71625C6A5B5B5340
31393E3F3E343B443B3D3960324630392B362C384145473E5C313A564C4561503C303E45
4F4546274C5136384947362D44512C3C474748513122364A4037294B3232424E42364536
232D32102B1E282327303D35323D29211D2837292B2E383E482A251B2E3A3F141C2B2C22
1924321112222DFF
FF939682988C7977747557797F7089978D817671947C839E928E7892969A9D90959C8B91
8284779A95918495A09D8896A2BB8579A2959CAAB6A6ABB5A7ABA194A99483A795A19FA4
99AAAE9C9FBC819AB7979BA3B396AFA794A9B5ABA1AEBAB0B8A198A69FB6A6BA8D96A0A2
A7A5AFA495C0AEA1AD94A3BA959A88AD989EA68EA69B9DACA2AFB19C969BA287A9A2978E
879DA39490AA9790989E978D9DB5BD998A8F8DAEB0A19BB299B1BC9D93BDB3849D979BA7
96AF8BAE9198949FAF9DAD96BAA999B486AAB0A9A1B4A892A095A38C988FA692939C8F88
9F907D8E8E7C7E9A8C74798E6B8E9D846E61806FA89396749088837D85859570757E726A
A28E819185947E8C81798C9E857290809090828D7E918779898489857E788886857D8372
7E7F90997E82655D72676D7D7A846B817D818770736F8B83796866596F7345597C5F6082
59686C697A7F6A6F84785F707A75607878497262756A6D79765B5F5D794F6A405A6B5879
656A687062615A5C596D7E6D7158615569646E6C71605C566752525C6B5655765B615048
4645363433262A2C3C462F2838282A241E334033446057623C46394C14314743204E3344
3B524C544D5E4A563F4A3D39403C313840482B4D415547413C2A4C3B162F413633372A33
463C341C13161B1C2A301D1F16363F001910372C1628273736433A2D373C544C392A4A30
212A352C232722FF
FF868F9490828F90777B7D7C6D7B7D7E819888988B7A6A94898A9F939598B59B9A95A4B2
8DA28F7A96A49B91B297ACA29E9EA69CA19CA8A391ADA4C8B19F95A4B0A89F90A7B0C6AB
AFA9A1ADACB0BC96A7A6939EAFA5AEAFB59BA7A9ACA999A0B591BBBF9BA1A59EB89C9AAD
A78D8C9AB19D9CAAAFB596979C998FA68DAAAD9F9EA9A6AF9E909DAB9C939895A8A57271
8C909E809096959A91959C9999A4ACAFB4AD96A1A5AEA6A0A8988AA495A69B98A29D959C
979A9FAD9EA0A497A7A7AAA4B7B0AEBFB0A8B1A0939EAAB1969F8792958C8C80859D928A
A2977A7399898D7C89828C8295868C86737F8F93918A6B739996938E7489819294818A8F
7B9B8FA08E93868B818D88859088828371747D86979680907B8A6A7D86827B6E736F7975
828086787B71814E7B8D826F786B816375736A806F8F8A8975767C77666F66706A6A7845
747E70625464767168707766797B687C8F81815D76848063527675625F6A6A536B5D5E75
6F5D52755F5E546877566E7868426D7E746C5C6E5A75697D845E5E776C65495461584B2D
2C41534039262F2312221D282E422D1E313C2C3D3233484E40354F323F384A4A44334337
4E45435B51384635243345403A51394342492D3C30334541383226564D373749331A2440
34283E2C1F293822362B4138183523121034292826372C182B3322042E3B35403E1F2B4A
30342135281936FF
FF9A9E95937C6E8F7C72898A949589717C8F979B8D8BA59891848EA298A4A07E9299A6AA
A69E888DAFA2A49F799E9DB08AA6AB9B9FA09191809C93A0A7A38682AD95979DBFA5B6A2
AFAD96A5ACAFA29C93AD96AFA0A0A8ACB6B58A97A3AFA68D93A7A9AEA1A4B094A5A5959C
9188ACB8A1A3A4B89393B1A6AAA09B919A91A9A3AAA6A9B1BBAD9B9E9E9B9AB184838E74
869A849EA29DA88892A6A5B6BAA8A8B3A2A89595A0B6ABA3BBA3A4A1A89C8088B8A29D8A
97A695A6A4A0B7BCA4B7BDC5AEA5B899BC9EA599A27A8BA299AD8388949997788094947E
8D92A692808A8B918E7E6D7A94808363708674777367897286847CA17B94778E8B73918A
88AB9798867DA5878B737A77807F567C978A83928D817D69748B846B7286828171756E83
5E6C7980787269645F7C64636C6F76808A7A948071826E6D6C806A6C8369826F74737379
42586F535C717075625D69716D65717365636B647277806D6B6D72795D5E676E697D7B53
76606C5B6870815D786F677B6B7D61796664805B6D5F7B73656A66666C5E5E715856634A
3A2E283C4E34403C351C323D2A00263F3B394041424E4037414C3D3E5345364C38352933
55443A2E2F4C36271C464B36351E3B3B2945474F3055514A4A47374A5D4C39423530272D
3E432A2822383C5A2926302326372E20371C1F0D2E3A46244244332346463428392B2625
3A1A2225061539FF
FFA88876848A8E8C867C80808B8E8B8D879EA0946F8D90A095788D84878D889E878F969C
AA9B89A39C958DAFB3967B7B8E979BA1ABA89E92988AADA9A2C5AC919BA094A8A3969693
B8A6AEAFA8A79096AAA7B7AB999F9C9BA7A89880A3A692A6C2BE9A94ACA68BA298867C9F
AE82AB97B7B2B8B5AABAABB4829D9586A4989BA0A58DAEA4B1A5ACA68C9C9B86919D8E9E
A6909B9EB3AA7A8FA19EA68BB6B0A0859FA5B69EA6A4B1B4B28E97B1AEB9A9A2A69E959A
AEAD9EA6AE9F9EA49C92B7A6AEBCA998ACAF99A58C9BAC9EA28D8C9FAE979398977B6194
9E9A8D8CA988977A8A84807D8C7C717D6C6965675571836B666B4B6B83949F8B75717D84
76857F8492777D7A9F897C95878189856D917D7F748687797A7A85806F7A72877185807D
70587D80727482757D83667E74867883527177798676765A73767457677569837B6F6C4E
656F77615E8C8877667B8B787F62685E5968756A75736A75618D755A6F70535F58725A71
66596E5760635463624A665F746747636F6D5C645E6468766C6F596F596A6F6C585E4B59
4F3F42422727333D273A232C273E25203747403740493E3F38354B3D4240434D57473B43
433F2C363C41352E2948423A1B41485325432C3A2D4311352B404C503438443A2B29181B
0A3239291E101B352029244241203737210E27100E4E30343A394F3626281F29182F3925
282A4A24283819FF
FF9374948F86858E88898A92878B786E8C7D7F83878991767F8C748AA3ADA591868E8996
8697A1A27F9895618B9D85A7AC9E7A8C898FA8B4C4A48AA0AD98A79A7C9EAB9BA09DAAA1
9C9EAEA58F97A5A593B9B3A6A08CA5CDAAABB0A0A2AE938B9FA9B9AE9AA7B0A5AE8087A8
87A69ABEA7A1ACB19D96A1A68DA2A49C9698B395AB93B9A09CA3AEB2AEA5AA9AB6918D7D
9CAEA19B92A5B7ADADA5ACA097A398ACAD9DB3B9BAABA3A0A7A3AC9D9DB59BA1AF9E9881
93959C9492A4A69590AEBAA7AB958EA39B92A0A9C093A9B39EA69BA18D96938E9D849286
9B9C8B928E8B958995857C58636D603644482F303F2F41492A454D4E5471736E7F6B8188
7F778292849B958794B2776B90807C79887A8881838564949B897776816C69708C806D82
82756E798875898D8678778687777888787C8A85676D76617971637E7F75726178687571
72677175836564636C6867766B785D7457525F83647B735E6A618077746E5F6F6D6E6972
615E5B73676A6E666B516261627065558752625C7958675E70726B4C646552626F574B5F
4F5746434A342529382C3138343D274B2945453E52463E51593540393738314146473436
4E44402C4F223E2A3C305E4A4C524A40454541333C45533B313D49313737332232452A30
2F240D252A2C232F44472D3C273D2A2700033013203835353248323B3B353623272D352F
33132A293D2331FF
FF838E9185758C8082797E67878C7C768D92678285827287878D7C8496888A9295A199A3
969A8FA68CA2A8A9A38B8E9F97849DA6979D8BA59D8897A39A86A4B6B4A698A4BDB3A4B4
988C9EAAA4989E80ADA5A198A3BDAF9EAFA6AD9BA1A59A8AA4A7B1AEB9ADA4ACA7AC9187
99B4BFB190B5B3AA8DA0A792A2A296A8B69E9D9C949C91A79EB59D7F9C8D9AB582A4A5A3
9A8A8C9D9DAD8C90A5B6959E9DAF959F999CAB9B91C59EBAB7BAA19F95AF9F8D8A9E9EB6
A2A895AD95A6A29BB7A1ACABAAA19DA1A8B1ACAAA6B0A999A693889095AE788B968B9C7F
91927D4D7C81918B8F804C6B453F38122015220E12000C260B0637263B525556746F8370
797781888C8B9C87887C78888A898B7E7270879B9075747C9279837A91829688837F936B
8973758C7E717984758685876F7D697660785E7A6D834D5F687D848D937E8A877C7A796D
6562607176776953727F6E6368666C6C4F756C5E70496B6E6063716C745E615E5E68706A
67555955665263716B616F71643F566C6C7F6956645C657053806B6982615C65655C5857
534B54573F564026313141554824442C473767534C3F3B2E42634D443545394946363F32
31585842363D2A40363833463B3D35482A444A2730412F3D39303C47254A32322E33442E
312B401315160E10444134412C183F352F2918231D2E4C2B1F2C2F0B36232B2C3934261F
3D2D1B0D032D1FFF
FF999E998C80677F788B988D84977D8B8B8292878388868D888A918895A192969D909C9A
A9A593A4A6A691AE94B8A6969EA4AFB2B79299A5A5939EA7A49D9C97BB7E9F9AAFA798A5
A899ACC5A5AAAFAC9599A1AC9F94B3969E9F9399A0A29B988A9EA8C3B7909199809AB4A3
9D7EA095A6A99CB09AA7A8BC977F87B2A3ABA997B4A4A5A4809DA091989DAB9EB4A3B39A
9F9C99B198B1C1C9C4C5B1949BA0B2BCB0B897BDB7B5AAB4AFA4B59BA9A1B8A78A9593A9
9599A89E9297A5BF97A0AEAD9C9C997C87869A9BAB8F829F9F827B6F998A849C948C7A89
946E89938B8976866B562F393832280D000200000000000000000B30233B35566C746C60
8D87A5918F928AA280886787868978918470787E86857174967B9083887C7D777B8E7983
7E7F6D78856F826F878A8B9991869A8A8B777A797575627D7275686E6E858060726A7B6E
6173666C6676786377757879685C71705F5E5C54446470575A686F734E7363756161706B
55756469515C6F7563716D836F615D6D57515F7467526D6F60595E614F5F59515762556C
7460444C515241495F39405A283B46421E39404B415B423D3240424B344D413731453D41
4F3B5547413C3047462830412C32484040363E3D3E39353A433D23403A32383B2F332237
35312B0D222B46213A3E37071D27372F1E2C2B163431484033361418230A272620341720
33161402161E24FF
FF949D8EA07A847688798384898F66948E8696847C6A8074807576708B978A91A087A596
97A4A0A2A8918897909E8E90ADA58F94A99EAF9E7F909EA0A8A29EAB9FB1AAB8B2C5A89E
A1ABC7A0B49AB4B4AA8EB6A487929C8EB294B4C1AEABA79B99879DB4AD8D9AA49CB4727E
8B889F96728EACAE8F8F82A99699AD9396928CA9A9AFBA98A58EA9929B96B0A39DA69890
96958E98AC9999A3B5D0AE9CA192B5A5AEABADA3A6B3B59ABBACA9AAB2AA93A9BEA5A8A7
B4A08A8FA59B8F9FBBACA2A7AAA2A1A7AB8EAB889AAFC4A2988DA6A882759C8970998781
8C97A98E8B6D7C8173593F3A251900000000000000000000000000000B17273143555377
738389918B7E93899B828771728B867C8E68739474937D8D818A808B827D7A728F85383B
7D8A7791827671888D727F707D8477727B73858B7365687B768A735E8875807476887667
7A506D55737E7375726B674E5466516466624A545655617067706759706254605D6E5F6A
636D4763686D6E6D65555166726A5653566B644B6F7364476A68625B524A5D4C615D4B4D
4D31437A554A48433F4940494F472E3F4A4D443842493B4252422C554E4E493B4A22313F
48363E543F3E473D51404B5F4B4B4B343D5B5A3B42363D4D404A403E363121403F29284C
31151A16290B00213D30313426261C271A18002C301F42413929222E26203B372A28311B
1A44281E34221DFF
FFAB8873739489938CA173779B827670857093758F907E8084709A8493928881A09FB58A
9EA4A8B6879F999D8E9AAC86AC95A98AAEC290A4A7A3879FB7C2B2C49A9CB6A0A4ADC5C2
969EA4A4A2AE80ACA6B7ADB0A7A0928D909C9E959694A49EA0A0B1F0AC9DA68CB3AEB989
87878AA5A197889BAC869195B69CA5BEAE9892A4A6A6A6A393AFAB8C9797A8B8A4A6AEA6
997FA79EA194A9C797A6B1A19B82A9B4A3A391818D98B0A8A0A8A099989FA28E8C93AB9D
8997997F9C99ADAAA79C9191AA969E86968F88ADA4A58898A284B4A592858CA39A909EA1
8C858E8B7B6263686A35222E0100000000000000000000000000000000000A2841395C67
74626F7D8F8B7F8D7C7C81727B7D6F59587E857F8F6E8385887B7B83836E7A6A8F83686B
8075837175646B747579858A7689806D5E787C796D847B77776F666578787A718961726D
567A7159536E787B6F7C5853687B5C6E53576F5D5659564F69695E6679665968785B6B60
7E736C74826D6B71605E71735E52716970696A626F545F6175606F4E6B5A646765565C6F
4F56504C3E4D51575E4E5D4005424D344D414856474C5A564C424246533D40414456212F
3D3D5751585A3D44272F3E433D2C50525146103953363037222C4F34443732423D342B26
30191F1800223135212F132429160D0F2C433D2A1C382516352C3E321C162E420D301312
35062624231D24FF
FF8A79897C8A87738F6B81686984906F6E7980A5787F8B88A5939D9288877C929D8B8CA6
A39180B1AC968A8B8C94A68B9DA49E8BB09EA6AD9489A4A998A2BC939FADAD99B2A2A08A
AB9E86A5A48F988CAFA9A5B7A2A89FA39F9796A7AABA81AD9C7BBBAB95AC87B19EB8A492
9699A09EA098A0A49DA29F9CA6A1B29BA1A7A6A28993B0BFA4A2A6A7A6BBAB899CB493A3
9EACAEA5A8A19AB7A3AAA09F9AADAFB6B399BEA8A1A69399A5A1A28BAABEAEC1A7A4A286
A1A78E998C8E98A9999E9B81839C9D9CA29A8C92A892A49BA88D9E9A9A889A8292909F92
9E709081786F745C4E2936160000000000000000000000000000000000000A08102E5159
5577668072859692857B676D868079454F6C81877E8F786C8464748F6989879071767E8C
737473727B828F8E84877B7D7C88777383847D746D8168806E7563847B77856956716660
7F5A6D494E8D798171765F6757556955646264665863534D45675B7566647C8779666366
705A63636C5F625D63706C5F686B68734F43546E625E545B6251647B5D51626D59585552
4956355452435F4E5F4D6659284651434C39525952604962494F3A433831434A27441D45
403A463F322122234B423C4851333C42534C4649383A4B4038413A2D2F3E403F283C3241
333D161C2717251219201B240B030D1E102C321B3739272F14232241490E2B1427433928
252A2D32232517FF
FF878B8478727C967B8D7B6E8D747C77817A8289A08C88797B89818672837C907E95849E
9A8F9E9DA8958A8DA199A0AEA597A0A0AB84A3A6ABBEA7C39B9096A98B8D91AD9BA09F92
B0A7A2A39988A691A494A08B9C8CA5B2A69FA89F99A2A2AFB7A4A0A3AF94A9B7AA9CA599
7D738C9C86B0AA97A2AA7E9F99A7ABACB3A4B89E7BBA92A38F8D9C869B98A6B09F9BA797
ABA1ADB29AA9B5C8AEBAA3A4A0B2A780A2909FA6BF92A59EB79EBB8A9289AC9E9DADB2AA
AA8AA39E988AA1B7A998A2A09CA2A2A1989D8D9CA19CA2AF8086979D7F9F97AC7C7D748F
938D8C777F6B534E3D301A0000000000000000000000000000000000000000000E003C46
5A523E75917C8E7F7B796E6E5D60552D5573799B8E8D7F9A7066787D83716A747B73776B
6B928A7B7D6F877B7974879C7E6D7C6B7661777F6071757656657F7D5E7F7167758B886E
66685C5F6E6176664C77565E5C565E5F5A71625F7170656D6B455C77747271606A627877
695F655E67606C59785C6D6E677667757C5F695E6679705C59724E564A5A4F6465515059
5E553653615D675E4865584442415A583D4C51363550433D435A4D3C38555E39364D2829
362E2D3B4842224D4F5A4946313734562B383632482C42242C395B46443E42331C3C341E
2C1F3937242B241822141F2A302A2815220E2229333535353A25151E2D1E264138202621
2E002620222A0FFF
FF86738D937C947F738A6D6F797A8E747C799190858A998489636E868E9996899C8E9D89
969B8FA38587AE9A90889FA08C9EA3A6B291AAA193A2A78F6CA5AFA1A9A887B2B898ADB5
B4A2B4ABA1A38FB2AC96AE9FB7A98EB89D919FAA9BA7A8AA91AB9E93A3A2ABAF98AE92A8
9D84A79A9CAD9B9F948796A7959DA5A69D9CA58AA8B0A39099A9A5A9AFA29A9A95A19AA2
B6A0A4B0BDB09A97ADA6A798A798A5A3A5A8A3C995C4A1948FADA69689989CA391AA989F
878E9AA1B89B94A7ABA6AD94A78EAEA0A0989192A59E97939C99AE949091A1828479AC78
89818F837A6B4555370D1A000000000000000000000000000000000000000000000D4232
58676D657B7D8485806F6D66767673695C8F7E837587896C7E7F7E80827170858488627D
856F577B766E77857F7A7975777A68978B8A7665628D6564866C6A5F697685816B715E76
7C235A65685A5361636A6E68746E63617C61737678695F6859585A67716761525E7B716A
6654646354585E66654943586B585C664D675E5A5B6B80746556585C493C615F6244535D
50514256645060003C41534845573941372E484B48523D4E4C48494E514A1D1A3B34473D
4F49302D3F3E3B543A342B373A37252A45382E4542403539343B3D323E453E2A2019252A
1B2A4F501621161F1512292A282F2E2A291238441E3B2D002D2C3235111D2E221213120A
3B1B271F241424FF
FF9876727A8A9C896E778B897B967D727091838183817B7E87A08F9E7C888A959392A2A5
909F9B78A0B07DA69D9F948F989D8D9E9FA190A2A5A19BB091C0B1B0B690A1A09F93A090
96AD9680929CAAA3A9799AA098A9968B9E9C9A9E9C9EA5A4A28E99A399B4BE99978DA497
8B979DA4868B9F9D9998A3979D9096A38892A6ADA3A86B81A78D9AA18F92A371B1989697
9F9C9E9AB8949BA1AA96A48EA48C95A897A3B89793AAB29C869792A69695B29F92939C7E
95A19089A0A29C9E9CA29EB5A4A8988F8590A1A086889AABA6A89F98A0888B7897888E7B
9C8A786566645A341E0D0000000000000000000000000000000000000000000000011F48
33577D627484948883675D65667773778D8671826D72627672755E817F81898F4C5F7764
60738E7B7E6C7486688383786B6D6E6C888F7D737F78898B80696E7752686C6D65756D7C
56686854546563546688674C566C7080767B79866C616A4A5063653D56565E6468676853
5C535A5B6F63665769545A50615F5A6282685F4C55603F6559564B5168546C67466B595A
5856465D576053504F43434B4358333E4A4E574A4429514F4E4053470E2D472E16414432
1936402B123934563C3756343236404A3443322A29372B1C4B3D423B2D2531433D30323D
2320391C32441D2820281B38352D2A13300A311B26372009222014222948382925163A26
262329421F4023FF
FF9281839A888987887B8A668084868B7B86796B7F7E857E8A84808488A09995848B8B95
8A89929E9F969585867CA0B4A0AD99977D939E9DA0949798A7A5AA918998989B929495A5
A1AA979384A3618BA59695A6A3959FA197A4ADA2A5A0A4AABBA9A499B5A097A79488B6A2
9A91958895AE9F958F8A9AA09292819792A2A58B8AA187A29392B4B1ACA797B0BBB7B2A2
B29D799DA99389AE9DA0A1ADB0A4B8A5B4B793998D89B1B39093988CA79990A1A3A6958C
AE95949AB3AC9295A7BEA8C4B9ABB1A19DAC9993A0918A8997888D8F94A295A9919AA3A8
96887670626854242F16020000000000000000000000000000000000000000000003191E
2B3F64708B85808885848177845E5C79776E996B6A8F7968786E6D6D89817B778E4E8986
6E7F758483708A7E827C787885657A92767C878F80986E6E7365647E8772755E70737559
65646B716B676F7364616B5E5564585B5F7E6D7D6E855C626656636A62616F5468687865
615E6962635C636A63786E5F5B52664C5C60644B5752626E6C45615C4572686961525559
515E564A5A654E494B37593F47465B445456543D4F3A2D334A4A3F46001343413F3C5242
3744253F4248434D38441B4A303241433E2D3B3A3A3D3811203A20332E13353D2E373732
3B37241A271C16213B33351D0D2431212D351C473C1836453A47292C2F1A3A262224180A
32192911080732FF
FF908F8F8B7B73878B808B73687D887B8C8A776986839CA2857682B9B2918AA4899B9497
AB90A4999FAB95A3A9B19FA6ACA28C8B98A09EB1AC8F7AA2A2A77EB6999FA99D9AA09899
8A8A959B7A939B9F978F969EA88984A3AB92877A99A1AFA4AFB1A99A92A19BAA9D7C789E
A5A2A19E92929594757B6F8DA8A7A9BAA08BA1A59AA5BB94A09D99A8B4949D969CAC9DAC
9BAEB7A489ABA8A8A99F97A3A1B0A4939FB3949BA296B2A6A19BAC97A1997F9C9DA4917B
AAA1A7A7AA8D939B9AA6AEAA8E8795AA9C91AD9379969390849E9682A19D9F88A0A5728F
838375634D5732150F000000000000000000000000000100000000000000000000040F26
3A46545D718C77988B7E8572716D648A83747F87837C736F7276967F808172647B725974
90659562827C7095728A8A857C6A758283867E886B668980737B837A6463776F66656B74
6A7263778560654F724E587358535372685A78657777797C67666E555A62697E65534C67
60605D4F8576657C5F6F5461585B53654E77674B5F6C5874505D4556694F61604B545E59
68594955473C4A423454513E4C4449565C4F565057444837423B47352F47462B3E3B3A56
3F453D3B3F2C3B4443303F333D2B46424732283D4838343A3F42253D2422183D36332D28
0E271838322A1D1B282B2E2C3854323C26354A463430302B361C3037212A181D16001F37
0D202421371D16FF
FF7E7E95A89A84887B9184877B8D929F8E90777F9A849E9B7D9E94959E9E827B92948092
A09A9185979D91A8ACABA09CA49BA0A09DA4B289AE9BB5A696A4CF7B99AE9291A58B9EA5
9288ACB579A1968F799A94979D9C888B9BA5A49898A39A9EAB96B4A093B6A18C9C9AB1A7
9CB59EACAD8F9EA2A0A28D94ADB4A797A59FA699A899A59E939E96999F8C96AFA0B1A4AB
98A6889096B5ABA499A391A8A89AA19FA7AD999A9EAB9EA1949FA48DA7A2979494AA978B
88A9A49DA98492939D8FABA9A3B29C85A59B91A8968D97A09E9AA79A9F9B819690889094
A1877C7E744B4027110000000000000000000005060D120E020C00000000000000000013
2A46424E83739D7C7B766F877A7872767689728385857A72747E717079645E8F748F5D85
6D897F7D75697E71766C6D7A797680737F716774648B667866606D666359706F5A67785E
5E66576F74506572656659506856534D5C6877696B62787772675E69606C7B886B6A756F
6A50626C76626C63624E555D6D606266706F5E393367604E6964726258605449454C555A
5F453B4648564E474F553C465E515D484751464451454B40544F3735554547453C43263F
3D6D45343C3C35423D2D4B38294C4C3B3241423239342633432D3A283D4038133A242934
3F282B282D2B44202B233D49313827412A21221F1E163A3D042E191B4E3A3C392C1C392C
2A2E2E1D1D0D2FFF
FF978A7A92997D848E83889C8E9691787E8680888E967D8D8B9286859C888CA28E9A8BB9
9EA0A291A5AA93939290B0A7B6AD87859CB2939C86A69C8AA19E79A8B1ABA4A69C8EA6AF
837987889DA2988E85939E979CA68A9A908B9B99B9B0A7ADBAA39FA5948B88A8B09F9EAF
AA999BAA8DA3B6AB9791948E8196A2ACA69EA989A58BB0A990A38F9E93A0909983A19E8E
90C6A69EA985957BB2ACA0A8A693A8C4AAB4A8979A988F8FA099B1A1ABA996ADB3A0A883
99859BA1A189909E9DA798AFC08EA6B0B3998D999D869FA597A1A89F8DA5858C928E7B92
937B746B635D2D32110000000000000000000F0E373433241A0400000000000000000001
00295C5A69778583807575746257767062666C60738184847F937B918787764D75717F7C
6F807C8886887D7C857C646F8D8A8365727483728064856B675660877A6659675A7A6B68
67776E6B54616F6E41596A555F726679896D73744C746789676258767274565E67665860
61766C715B7267514D515D7C575A614C435F656B5877665F616C7065576B55605458496D
513D4F5C80635B53594A503C5C51386E334C49502E4241365739444B3F564B454A4E502E
4B3A403A433C204426435A51482A3E37373C3020443834443D3534324B342C332A1F1320
263048082533133E3F383529242E223113372133364E2E281F4034392B27002518062924
1D3D222B2D2524FF
FF9C7B91858B8B8B8D878B8F9D868C8E857973668A9D9E9F8F889681868A828D9D9EA38F
9D9995C677999FA1A99F946F9D90A79D9599AFA2A78F949DACA99D92A7A1A497AD9C958A
78A88BA994979BA3A57B9394989EC0AD8286B2B7A09A99B29EACACA88A9FB9A1A1B69C8D
9E928A786C8D919BA4A79BAB7FAA8D8BB38F77A0A0AE939896A0A2ADB08882AFA991A891
8F81979BA89C85A579A48D988E9EA99E9A94918F99A49EA7AEB5999EA18B9CA6A187869B
C58C8B7D8A9F9CA0A7B9A0A1A0A8B5A09D98A0A69D9DA7AA8E9CAF84937B8F8090928A78
8A94787C4E3D2F0704000000000000000000121B24483D330D080000000000000000101A
314A3C455B5D76908882848175717189747F8C964D71716B727B7B6A7C6B7967967C706B
6F7E927A826F71766B878483778A7F70857C6E858386717575504F49537078576F60836A
73735D5566786D5C5365516A693C5C59766C867A54776456776966614F6B9B845E6E5F63
7F5A516656654D4A6C5F5C5B5C6C48673259526F654D6F6B664C58545E6A645E6655614A
56675B5F5D4D5E4245434352445640302F5B4E522B2F464552244F55543F294D4B4E3448
43374846263E4728493C39281F2F5343253C404A2147402B31363B221D25402B3E352A19
2A332F2A2D3A3C3E293B2C32413C4A4033463824252111314D392B32140000002C3F263F
13252F052B2814FF
FF8190A3B28B85859B8A8A8E8A90967E8D8D88948B8D8081877F8FB08F936D8C97A28E8B
937A85909E9FADAD9E83A17C7C84A198A29798939C8BA3B5958D98B29D9DA3A2A68AAAA4
7998A599A1989990A3B48E909891A87B8B7DA09A99AE8C89BA8F988193908E9DBAA1A097
A7A5A7AEA38E9A9CA89EA2959F749DB49CAEA9928BA19FA48399988C95B2A3949A988C99
94A590A5C0A4B7A2939BAA8E8F9F86A49AA4A0A3ACBCB499979B9297A390A5A6A8B697A1
BEA09EA6ABB3D0ABA1A29B77A69894BD97B0C097A39CA3AC939F9C908F988A897B80867C
8C876E605C35321306000000000000000000141B201F151A12000000000000000000040F
26423E44686D8783817C738F77706D566860596A7173778582646A7685775876757E896D
8B7A877277877E7B758586789593726D766A7F74796A62746D6368538963566562735666
506F7C506C6582876078625A385C8770675F5F726C6360626F68545D716E71585D606352
5255604A666062756D8F665B5C805D63726576654B70767450515A60564752525A635759
5F444C4C5A46555D474E483E53544352463D4D48533D67464E3D37392E1F4D434A443949
1F44502434404A3D38462B384C5139433D3D3D3B3D43392E22471A182B2F271A35062D3B
3A383321264121383C23362D1C553D282B20302D294C3D4F30302F38140000003E21320A
0B2B3306311207FF
FFB383789092878D9A7F83918F92808569878B908180909C897CA396939DA28F70979AA2
969CB5AAB5A8B3B9939F7EA3A5A4A2A7A987A6AC969997919CA7AAB48B929195908F9F93
9C979C998CA79EAAC094A7999B9E8DA0A49B9875AC8AA08E8EA08990B2A99593A79DAE9A
97A2909166A4A594868C969E953B83A47DA2A1AAADA0A4B6AB9EA6A28D8C988D87899D9A
9DAAA897A19B86A095A99A929C998F999297A6A0949596A6ABA89193A3B6A3A3A4A78E91
94A49A9CAC9A94A5B1AEA7B199919BA6A6A8B39AB190939DA4A17F9D7F978A8C7D71928B
8864826E64554D15000000000000000000000009100B1706210000000000000000000000
16264D4F688A75877F717E74627472635670585B5D5C768367687175707B73546F928763
7C82818D6F8985908782693E6D70626F6E6F7C7D40707D645B676D725B7264695C576E75
686D5D5B6C6D5F7360587066504559595C6360646764666C5E7059646076595E5A716D5A
7B7771816A5B534F6A4C4F585D5A65584E6365645A5B6367654552564F5D58545E5B4D69
57576B5D6A3B5369594E5846525C623F4B535E34564E5A4E415D3B4E3D41423F55363E51
5841493B5C46573B3E32413541372E2A3236463D373C19214C2629273B3B2F301B26163F
2B232D261F242E14333122363F3135322E373526310E22323B232C3028000015231B2B23
22181C1025041FFF
FF9599967764798E778B83817E9A8B8B9D8F938D8F8B82A07F9A969A8C8F9795A79B96A0
9CA5A0A698A5B9A59E94A9AD79AE9080ACC5B98BA4A7B3A698989EA5A8A2849BA26E8B83
9C8C9D93A2ACBD989885A18C83A7A79F88B49996A4B192A79A89AEB4B79099A6839AA1B5
9C7FA78390A0AA84949F7DA791A2A5878B898A979D9389A480A39BA7A899A588939BAAAB
93AF8797A890A79C86A696969A9FA4A58CAF98A69C918D9AAA9FB0929FA1A28D9F989397
B98C9BA5898BA9A2A192ADA19DA7A6A07CA799B497A3A4869B91A890828D9A8F84A58281
958771765A4B2C2500000000000000000000000000000502000000000000000000000012
18374D68817E7A857A82737B626973926C6E6A7878897C709182907B786362758A6B8A7C
827E77567A6B6F705E737D8F846671706375646C6976636B6B7D70888A5F6D7074536B76
7475696E625E82586964466266847871675D5F574E534E67584D725B737675847D625060
56435844575558655E64565E5F523E5F5D4C5F75746766547164765B5D6D6E7145435156
5E5C5A705C59512B4D51633F47434F583B4B44564C515D43353D45514F3947534F324238
38414431433C2A362962483B252B3C40353730444430271804223918383428202A4E3116
1F1C24292727301B340F153533291B262C2D28322D2C3C2D31293F2F27132C1B1B322015
242E331C2E401DFF
FF93908C7E74877FA9837B818C8A796F937A8984899793709D9D91898892849797A5947E
9AA0B692989CAE9EA68D9AA19EA29EB0AAB4999D9EAB93B29C8BB0B7B2ABA89C88999899
93BCB3A3A0A09E9B909285A89DA7A4929B829DA6A69AB191BA8B9D9C7D7BAE9191B99BA4
A9A3869C99A38873B09E92A38F888D83749D8E9D7EAF9E8C9798B2A0A7AE9FB99C9D98BE
A28A948EB09D7A8DAE90A3999A86919C90969FA69C8DBDA6A9C18FA2ACABA5A291A99697
A09FB19B91BB9CA9ABAEA48998A098A0A1A49D7E92A396A7819C9388A18C9B7B948C9297
868E847155403C230B000000000000000000000000000000000000000000000000000005
12214E59796D5B78659563676E625E6377727F77736E627C827F7369665B756D6D7B7C71
6D767E50687D847561757971797D53686C6E5D666C69656D83776C6B6459706856715A6E
646C6C525B66676B695E5E776A565C7F666B706D5A62516D686068675E5E696C735C5877
5A64665555555962686F475F685A4B584C636A4E534744545A70664A5C5A686A6271695B
4D4243565A5C4A605757503E43633745695B413D514F5D564D50545754414A3D49403E2F
5955363A393342492F373D2C4636444E423A2624364C12223C302C31201C2F2D301C3429
303C292B32271C2D213725301E29281642241C1C0E254010382E39501E2539221B112719
2113002D2A342EFF
FFAF8087798E8B7D7F889691A08A9B8F8B7B6184978B97A2A4988495939F907D949D9898
ABA891B29594919F7B8FABA9998F8EBD99A27F90A09F889A9E96ACAA95988793737F9277
8A8A86AD95B6A193868373909C9A8A9DA2AE99A4A7939F9A989E9F8E91AE78918B90A598
A49CAC9B879A949D858280888A89817EA595A4A39C9C8E968EB798B69A8EA99DABA19C9A
B196888CAD98B5A891AFA094A5A49D9EBB8D8EA0899A98A09B9B858D8D9B94A5BAA1929C
9E9DB6C0AD9DA199A2ABA48E8DA1AE86968E929BBAB7959D9DA5978590809285969B8F73
93918A7A6660401B00000000000000000000000000000000000000000000000000000005
1F3650835C8373717B6C847F7853656D72716E737A827273726A7F8395694A7C71737F6D
6E8D7C6C776A6F8287817371715763565471756B805E5E7B5F85636A516D67665C5C5880
877B7B7463446F5C4C774E6264716662624F437255685F607C7457536B5C6D72725D6F53
5D68635C50676F62534C595467505D58645B596C5155516F5F556075586362635661565E
372C5738485A5A484B554B5A494D49524E4D5440364738654F203B3E4D473F37403C3C56
39265646391825383C333759392C3534414E5C3D3D452E252837352124432D1633102D1C
332E2830251A382B1F374229442A36443A293F400B2E3434153A153B2E0B283122172A2E
211314232B1D2FFF
FF7A8F7B8D756881937F958C6F879A817F8879A3828C8D848E75909D7D938A9B99BA8B9D
82A2A0A3A3B19B9A808C9996A3909B85A9AEA6A49D93A9AAA9AA989999808544006F978B
977F909CA58A8FB8938884989C9484A59B85ABA3A8968A9D8595A2A1878899A69E899487
919C9CADACA5A7A29DAAA6AA7DAC9296998CA4A89D96A2A1A271A49CA89DA1A79E9CA78A
91A1929F98AE9691A1A2B6779F89AEA3919A9897818396888CABABA6968A999A9FA18E9A
867FB698A2A5AD9EB1A999A694868A8B8A998BAC6DA1A78D8D89918399A08FA19D708E7E
8C9591917361564C1700000000000000000000000000000000000000000000000000042A
32565C655C55778565767B6775756B6C576F818174696E818A8F587D78805E6770857570
74777553607A7E7E829B7E6E837F796E7D737172696D827C8F7A856D7B7170647366675A
5E5E726557746661655E606A6E626B685D6F65584B696865585076695E6B71695E686366
575C6B5B6D5B5839605C3C3F4F43525371594E5B65596C745D5C723F695268544E4D5965
56683F6F665559584B5144496947523D5C4B3647394E323E4C4D3B50513E3A475A4E5067
48303945453952433E554D47424426302C40542D283C43312E29353242353A3527291633
262D431F321A2A2B2F1C214536392B262B3124211A212B37282A3A1D2113290F2316222B
251E32252E3F36FF
FF84878A8A8E9B87889D9987899A809A8381838F7C7AAAA388A7A2A4879EA6729D979DAD
97B1A499AE8695A19BA2AEB190AC96A49C979EB2A0A8ACA193949BA59D898D612C729F98
8EA78B9F8DB39A969489947F87838594938BA9BDA293A1A4B08CA0988F9F829499967C81
9090808C9FB5A39FA08582A88E7B888DAF9C9C9D9F989F98898194AEAB98A5A9A3C09786
BAA298B1A7AE9C9E9AB0A798AD8C8FB788A7A99F8A94B49F959F8BA19697A5B4979D9B9F
A8918698A6A18AA3A6A6A7B1A1968E9AA09D99907C998492989E95728AA09E9A94ADA89A
9489A68E59695A281800000000000000000000000000000000000000000000000000161C
363B61677675847A75707079777879867563775D6B887770748586718D787D758165816E
7582604C5F6A727C636D67627D7D7E72756052795E7F816F646A6273656E585959605754
81667584686C5E647A6360676B7A7073495E565E4F5961676C7250516A756B5E556C6E6E
716F595A6A7E7363534A6C5D634E5D60686145515C5855534A777E6048585D5A6A5A4860
4D623F4B4D607F486639554A4A544C53464D4D4D404133473E5F3D375951523B4245464A
492C2A353651343447252E43404E5F2D2F40304435272730363C3E37241B112A1E1B1939
3E2F1A273636292B363420460D194D30333D46200D24162A1F212234151A302D101C3B29
23322C211C151DFF
FF7885717C9674738992788087868A89788F8F8898978EA09C8996B09CA791B4A08E878D
BE969EAF9CA5B6A59D909A908FA3AF91A4AA9FA9B98C8FA4849786888C9FA197A1A3A48D
A38A97B2AA988FA58D8E8B7571878A90918F8F859697A6B49EB7A0A3949CA2A090839B87
8799A7B4949B869C9A7B9A868F8283A5A9B0AF9195A3A28F898AA9A593AAA98DA48C9FB7
8794ABA4A3A09FA094A0848289A49C95A8928C8198979F9C9A98A3A49EA59FA28AAAADA9
9394B8A0B1B69E9B8F9CAC96A3C9A77E6D869BA3958D818C8B989D7599AF969296938592
848F817F6C7760522A000000000000000000000000000000000000000000000000000F29
48727C6C6B7D7C676C8179737770637979766E71606B6C6F71777987899082866E75747D
786B6A5D7A6F647A76778085837463837766696771715D657B744B73613E445E7F717442
62664D57667D78594C6751625E6F6F596A5F675D68567667805E464A6C766F6179685F76
7F5E69685F587363625D5151465B475F796978595A614F4A563D4349576B527152516A60
685A6149564F584C44554E453C4A405C66385947453F544068385842535B3D5732413243
30463E3D514B463B535A4E3B1E36403E39393E443D463B312E2F203E4829332D38274426
1D21341E161B3A3B122F3A2C302E2F3E3229252F1A0E2B373622262A1937262D231B3320
152827291A3F2AFF
FF7D7B818B9D726C727C94798D75879C9D8A939097889E9DA7969A93C2999FA193B4A38E
888E9C96929BA3B2AF86858FAB8A9395939AA89CA49DA5978482A7AF9EAB8EA38AAF9DA6
9590A0B28F899F92859477868185767A839399968BA98E9E999299989E89979B72728B8E
72A3A2A4B0A5A09593A1927F8895A199889A90A6929483AB94968D87A095B6BD839B8C99
8EA498928888968586908682A4A29E8D8E7D6A9083708E7A9BA8A8949EA4A2A8B0A8998E
AA538A8DA59AA09F969DA798A784A2AF8395968B9BABA39DA68E7D88888DA39681949886
A091998AA785614E5A3C10000000000000000000000000000000000000000000030F1915
47664E647D8A8E71736C627366716A6961817777756A85746A7D5B6B7770788660735F6C
6A734F4F64786D758965787568747D7977597F5969786A55505F53535370685F766B6253
3C4E7F725E706E4762745D5C72647C695B837A847E7675715060777469465F615568645E
6379796A5B56655E5B4D5F57406E55594D644B766C5656514D52564E6E71625F5956644E
50643959776B5D5F485F3B5E5B576747635B54515C524C4F49585E60554C684041442347
49545450444949524A4B3C2C4C2E4E362A331B41563B3333371E3F3F2032293E37320A20
252B051C1D2A382C2A441A27382A28353C1A34180F2531392742291011263039251D2211
2C123536423732FF
FF7C76908C5C978D8D94A2A98F7C967F827F8DA38F998F87919D81897D94809990A29B92
9C9AA5B78EABA887A1A591B2A4A47EA1908D988B908B929884978E99918C9FA4877F8386
A489A5A48D81758784747394806D79B197897EA8969A9DB289A693939785A3987F8A858C
79899A9AA999A098B3A07F8D8C8BA57B97948BA4B6A09C96937B8289779E81939394A5AB
A2929B9D96A68289897F8967898E98AB968E8790A39F8D9C798A8199A8858CA898729297
8E9C70A09CAAACA792A6B4A3A59FA78E979883817B9F8B93A592B0AE9B8E82878681A895
8EA56B8C837E63593F40200A00000000000000000000000000000000000000000C163B5E
6B5B6A5C7F7C7C7F708B86816C80818B808E866569857474566E787C757B6671715A867B
86677C606072787275806862867D6B716A7C7F92666466785E5459735D4B736155765E66
696358557A655366606A87666B6D66766671707E74595F686B70737A74776474546B6962
616070676F74666451586A4C5051554855566D6D594B54563A3D5A5B6D5D69615B5D5B56
3F485A52485B4F5C3565704646555C544964663C3E422F48616141465D3748534E322845
3E5152573A382D3B3D504A543C414A263E443A3D3541372F331F1F0B3D34242628383B3B
2A1B0D1C2E28232D4E4735322927404024311439130F241D232C34493B2D36301E1A331C
1D433735213429FF
FF8B928D81869192978A7E8CAD956D8E858986887F8D848B91869194A98C89B2A17AA1B1
96AA9C9D9F9FB6B8B0AAB089957B9B8D8A9D9D938E897A826E7D88A8A5989B9A94979D8A
869495917F7884845E64726F8E968F898D9A9385A58D7693B1AEA39D9C9E9BAC9682928B
8B9593A7888AADA8999D85917D9B8DA8B49B97989DA9A99CA18AA88F9679ABAA98898AA0
949C9792A69D937A90A490A07C979A9DA99694A18C9D918B7882848A9F9EA87AB498A3AD
93A297859E9CA09AA5AAAEB3AFA2A09990A4A2A4A19896A79094899FBA8895938A918B81
899F83928A77775F64544C2D071000000000000000000000000000000000020022315955
6972618084817C70756F69778C7F7677756160776D87747380667B737262726D85606C77
7A837389576F786675666A7D6F6D6E857475634E69685A4F5863684F5D5C47645D796778
6272657B6C5D6971615B6C7272676F6A757089717C7A7E7F6274685560626A617867685A
545C5D5F4B6B7A4C64594C504A56585A3C6158604C4E456B5370756A5B4B5D6464534844
4F5D40586D5F594D515957464D4A4C654A42495951482D38525B3B3C4E3A50344E3F3B4B
525C555642483B513C4D524F382D1A443A5539193E14442C31471E1C473A4B2D2F2A2C39
30001318293D3B1C2C17252D2A25331E42092614201A23282823220F2517301F22372838
4A3B4239341B30FF
FF7B6B8C8C83817F66749A809687949D8F888F8C759B82818C998F8BA1A79F8BB3959D91
A49FA592A2A3A9ABAAB0AC9699A4A38A9A879EA0AC96979286808E93A888A69898878E8A
968D808B857E8572898A798B9596A182838E9A97987286AD8DA4ACACB09A9F9B93928C93
A188A49D94A29B8D9D84988A8390A6A8A49E9AA39A8E93918E9FAA8AAA8E93A0B89684BB
9A96A7A0979F9F8D92888B8F959C9392A297A0ABA68F9B908E96A2AA9A8F9BB6A6928DA3
A390959D929DA4AFB2A2A697A6B0A3A3A8947B79959E899183A89C9F769B9D8EA1908C97
8E74828E7985817D586B505D3E222F0000000000000000000000000006242143354E5171
7B806F78717D6E61626871716C5970626B786E7A83756E789379637C8E776D8078797681
745C77687C797771705A667455626771577D78625B7A766053504F44654F4F4E636A605B
6A5F576D705E606B6A516A61875142896A8269745E7B6C666B7F8C71856E815444577A4D
573E69706B4E69645A605C5A674D745C63524E4C627C675E57576A5C3A69595262645760
5C3F55444F40516956677044484B5F60675A4C574A3B4D5E3E4C313555354A514249494D
474D5346353F42525246323156422F413A3B3A2A20342534334A3D282C452126292B3E2B
1A372A2330222E000728103E364023112C2B26342F1A28352E363F32493D153B12152B31
242C2328271C1BFF
FF93869496847C8C9B958E8574977C8682839A8B8C897F989D94818D99999FA491A2AB9F
939DC89F97A092AEAA9795C5AB998B7F96B0A59296A09798879FAB827993949693938D94
99947D85727E846E7F7B8AA8918F80978A83706C8F7D9995B0AD94A38EB889A78C888A85
9A9A8A8A96AA9A8DAB9384999B99A0A0A0899B9FA99C9AA09BAE8D9994A19CA2A9949E91
AF9AA0868C6F7BA28C9B9C989E929B898F9D97948A92869D909CA59A9D89A097A5A7A4A0
A388A8ABB981B4B9A6A29A97A0A791958E9DAAA3929B96B291A39E8C96879276A19A998E
818C7E8185726C6F6B6780633F48382121031F0B0A000305170B17100F394342483F5F8F
78686660747A785E7A66722F638266737467747A77877F767A8471754749866368727C7D
735F7A5B74696D85725A746B4E687C73797F68766B78607378777087606A5D5F6E716958
615F5D5C7558727179706B6A727A7F6B556B6B626D67797F6BA99468536A526C6D766C61
6367595C6C624F676365684F4F674356694E605C705B5D676D645A4D574F4D495A5E4A5B
586536674D55474C4E5867655354465A6659555A3C494E535B4D414743443C4F2E3C485A
604E4950454C3F34492F474434433D572A21244222333A264924332631333A2532282616
0D362620351C27432627182D2F2F3D32302D241B3526292C2635231C25381E000A281C18
232E2429202F1EFF
FF828A928D9F838C668B8777897588848E8D908A9C90888D9592908779A5A39E9C928BA3
969F86A09EAC9D929F839E9FA09F9E7F9F91889F9896898A92848299AF939796A381948C
9A8C9E8E8586747F726479959A978E8A979B78638888929C8F99A19A96759D99878D8094
907A777A818A9498797891767B83A49AB2A1A48B8792A78F878FA700839992929A8EA2AE
8A8A897F0E28958A9585898E878887A5869B74928D979A94A8ADA6928DB1A2949E898C85
879085A4999A8BA8939199AF9086949C97878DA298909F9A9C8896918A88957A838E8B7D
8B83736E637E7C6969557F716362483F1F353B3D0C292B1A0D1A46353E345366734B6978
705F50765E6973826F7675617564566A687C74737A615970607069656B6861816C7A7656
607270526A617B6937536A7C5A598176664C645253566A6E645B4E58606361526D7D634F
605D2B5E716F6F6F724C3F7F647355617B5F50645B51616844545D5F796266756861633F
505F79567676465B45545D585B584754594557585854424C4B454F60475F5E4D30515B66
3B435961622D4B4C3C313F624D4E475A5A534E51404E4D5C354F3D473F41583D5E3E4246
244D5043382E2644305938303A36421D364A2F2B372E1F2623232C36332F273717232215
421B2B3536353B16374A1A06191C281E26362E0217101B1311332B202E06270C172D2018
0D1B150C172834FF
FF9784968D89988B7D9C9C7C948D6887788E7E90768376889A90979E939D9D98A2A9A2A6
AA98A49CA1A7AF8CABA795A18E8EAB99A9AFACA295A29A97A498A5A8A596968A918F908C
8EB08AA778668584839596AAB89FA9959C928F868B8A8BA0A79A9FA9A1B485968B8C96A0
84918891878692759292909997A7A7B28E9E8CAF8E9BA4A2866DA47EA393ADAFBAA69D8F
ACA7815C00188CA183A48C82839CA0989F929194909491B296A7A4B2A6849D959DAC998B
87ABA6A4A39FA8ACA99FAB96A69687869A928B9C8F9CA9979A9999A67D92A690999E9B91
8A918B848178807B70746761666C5A74544F44334A5151513E4F554C476054606D69716F
76725B7780818D687670837764667D626A6D606E6E7D597684765C6E71567A3B64798686
764F746B7265747D634E6A58786860656070636D6F756B61464C64536D60636474726C66
65486C68707E60676E7969754474787E7171716A78685D7462685E70706A66576A586785
3D44647C54566560595A434D5D45565B565E646B63545B6655644956575754455A485366
364A566549484B6F5056424F4C544F504F5F47424B4B5C2544544F5F3B5552473F3A4063
4F4A3A3D493D48373E25544C49463E5C303930242C363F3C1A362A1D2534221F2E412827
1B0E331D202E23371F1218021C1E253C38312B33290736200821212C382C1D3741432B22
2B144028162926FF
FF84947B7D797C879379909D8E8F8D7B909887989A837FA3A2AEA0929E96859E929CA48C
A1A8B5719BB489A8A6A0879FA0A1B89693A6A2ACA497A2A68C969EA08C818DA79593A4A6
A693AA9C887D849285929F8E929AA8A48383857C7791A0B59DAF8C9586B09699ADA19080
8C647688778F7C798A977E9396A0AB98987CA99F98ABB5B7ABA89F999087A5AC9BB8A3A0
9990907E5E7384A09894B2989A878796CB78848DABA0A59E9D9BA2928EAE8B8DA4928C99
9D95AB909AADB4A8A591A4AA99A9969F979D99A8979E92A6A999978E99988E908F957B91
955F878253776F7882727187716B65576650716B624D53406F66555259654D6C77697F68
7767746F79706C7B6357787D604D6E6E6978687160857570626D707E696E69003F7E5782
6F69597D857281747C5D735D756C72746C736B616C6360676F72545D776C6061666E686C
7875654A80616C6A6A7D757E44526B8074674E51527A7E7372796D6D64526A5574786166
5E5762656F5558575C5F67614D626B5F5E6068614D25173F5A5E59525A525A5652494F58
495D5C49595C6859424B5441304356533F42554847494F48585740425669554026512D57
474A4A3B3F404A44572F3932172A39412F4E34452A292B38292B472B2D2F2F31132E3311
1A2B141E1D2B242A340B1A2A3C2E16173147432B353428010528302822352E1827332E1B
26282C34352132FF
FF8387807D707E97917B86829E8B7C8D8E7D9789738291987F87A6889696AE91A0799799
9AB4A29BA59B92A791B5A37B8397779996A6B4B4AF8B8AA1A0AA8C789F9B927F918AA195
9496AA908F7B7F878884A69AA8A6ACA3A08D93869C929CB99599A4ABA09E8592939C98A7
967D928F8D8D779289899494999C9B89A7AC958B9AA89BA4C19698AA9B8AB9A39D97939A
948785978A8C958294AB9B8E998C86A889A6A6908F9E8E9C95959E94A9A8A6B4A9989290
A997B1AF8195968A929AA48C8794959285A0839582A6A995A39F9E969A8B918A8C728985
90828A86947A7057887A585D785744634B5F7966646C5D623E5F545673595B6F4D6F7A6F
7A74776F6759637B7970717F6E004770757481726C687567666F7175577660798C6C707C
78627D7B74797E7484876C7D5F72715F615E4A585A737065694653586D696E72784D7160
7B6B5678776E6A6E737E6C646A83746F726A7A5C7D7579716C765A7F7250877B70697360
5C605B614E4369634E4C424D525F4A4A40565E3C5256237358552E4E4C4D5749393C364A
2F39373B3D5748594A515C3D40414D3D567862464041523E515346584A54505A4B474B48
48494C40415F2D3036494E49351D25374449305238231F354A162D2C20372A1D11060D18
293F3B293D191825161E1D241B30291339142E292D31290C0B25201F182E371D232C1C31
0A2A1E3037313AFF
FF9F7F9A8A668A877F7E778689809D8E879A9A87949383A8A681879B8DA9AAA39BB28F9B
9D99B39F869AADAC869AA7B79B97A79AA68E84A1BE9CA07D8B93A47A9F8B9B959599A8A9
A8A69CA4958978888A918F8D8E9DACAE9D9C7F95879B8F93959792829C999BAA98939AA3
93988381947B919380AF8F6E939F7F97AE979999A6BAAEADA5A27BA0A0A9B3A4AA8E8F9A
A79FB5A19599968A8E95869980A2AAA6B09DA397A4A6AD9B93AC8D96A9A3AAAE9CA3A69B
8FBC917CA1ABA296A3ACB89094A3A3ABA2A9A7A7A9908E8B8A8B8B87807386969C879397
828781979A868775646E837073677B74715756786D716559474558536B6463656A76645C
60666F715D89837C7A68798276687A526C69665E00665C70736F5C6971628F697F8B857F
6A8C5C6977847C746B7B56504570696B5339645A775A3E6C5F54555C5B6651615C626173
716B76737387724F6A5F6A7071696E6D5E6B685E6A675B6A7A776D5D715F66796B7F5555
6F6757865C54566770424B60626F6E5E55374E505B684C565E5A5E454941404A4F515D49
4E373D46595A5553494250554463655644474150645B5951493D454150314246415C5253
404E463C4A30373A372E273B484C442E46434B252C303B23203630273A2B53392E34373D
3322191D2B28262B352918003D3B37262B3A381F2723212723243332170D22261B282A20
33301C1D323229FF
FF9D6E7D90858A8D8E9B6C6A8294767098828BB0867FAFA6A79C99A999909883919BA99D
959093A691728C869A928E92AA96A3A5A88987C39AA88DA2A49989979E96979B939A9A9D
9D96B3A0937E65609486A0938F949DAB87897F6E959D869DA58AAA8D878FA69F99A1939D
A6A39B958671998B7C9B829D9C9294A28BA4B19A9CB7A6A08D999DA7B5B6A1BEA18F9E98
9BA492B1A69D93AB9A90A4A8A6A5B99F939389A098A08D8A9898AB97A3B5AFA4AF99AB9F
91A0B885A490B290A1AD9781959BAAA3A17D99A892ADA5C0948A86849891958787858770
7D8995757D99817678826E6456757369564F475A656668494E5657564A4760656C7D7376
6B706D6E7275817D765F885F767B726C666E6D675B7F707D7C7667616E62715D856B6E7E
715B75777C696B717C7080765D6D5C49524F436D586F666553594B527A5A62423C3E676A
6C816661684D5774688E726D6F715C73625E5C797F58816B72766E69747E6A716E5D5655
5D5C4D5B71736553564B47494C5E4D5259566A705E3F5D55474254694754425A4245565C
494F47574D53453D454A5D5451575241464C4E63554F5048474F4A664E4A413C6037393A
4A58360C4A403B462F464D4D3D45323836223B2D164231253B2F382F1F2D2C3A1A311516
1E2D313B333E2635203344381E271C25423634372F2E2B380937160C183D0E311B1C2221
3238132C262A24FF
FF8E7D818E93988886877491868C90788FA3A997AE8D9A99A2B3A98DA29AAF9AACAB8193
A48F9D95B2AE828F93A2A4A785A381999F9F9A82AD9F9A9EB2A39F9897919C97978B917C
84B69689947375A07C829990978F9A8A8F8D8CA2928D8CAD8E9995A0919B90B4B59E9891
A7A3A1AEAA949F93A5B5CBB29CA29E91A8A6A0AAAD8292ACB9A9858B90A3A599A790AC93
A07F848C8584AD909D849DA2A58B8098878D898A97959A8B99A27F9095A9ABA09890A69A
998D9B9198978F8D96B5AB90949B7F8D9F979D7E9A9AA2998C005087997B92A7839E909F
867375A3877F6A82717F715C65516A5862624C4C606A5B5860704C51685B5873835E5C5D
64658071856C63775B6D8D88846B76517D647F5F6E72896450737063526260747F7A7756
567C87716D7B87756F775C7E6367703B5D665A5D7C5C554A495A4C5C67577D674D6B7B5E
636A717F645B5D71545E7F65698265746564786576686F8166705C6C6F6A776B6F957C55
5F6C6063656063686450635E524F59605F4C5B467F6A5644606866405F4B504B6A575D56
454A62424B40385E404C554D543F4D5256585B5669475C5B4B3462653E3950754F3A496A
3D66405449374A3C553F2735392A453933503F3934333436353E343D33243A3235313617
30431224132130183038221C1D1438374D3547323E34293A41432E1A102436131C120B14
3A482C25291524FF
FF8B8A998A81889F9A8480849A868A808D9C9A9597828F91859F96889E97A3AA8A879097
95A09EA1ADA1A5AA8B88A49A999EA1948AA0A0B1BBADB29D948D90A2A39A9FA0A5999CA3
A282A180777B888C7D737891909D94928F7A8976A6778284A6A58E81B39497978B9EACAC
939E968B99A4AFA499A2AEA6B1A6999AAFAEABA99DA295A08E8B8A819096D3948EA0A697
A1887294A8947B9A959783949A70A2A7A99E97958F98869C9EB5A69088AFABA892B294A1
99AE95ABBAADA49FA1A7B88B97A998A1A7B2979095909996A75E9398969795B1A09F999F
8BA789708D85847F847A7F74765663737771575262424956505E67656B6D62708A856C82
756F7E6F5F65777F647675787A6E654A5B695D8C5871668075616D82655260677D866876
636A7170827A7B73837057707B6E6A5F4E4D724C5A6C686B7D75614D5B6B686E725E736F
8F6A6F56565178586D678B656971685B616463756B6F70666E6B776C6E6B7A617768825B
677C62525C49615F6166734E5251595B4C5C5F65435C3F5B5F6A5D3E3B3F545F5F706B46
3B454B585859545048575F4D424C62503F324C41444C5853583E4D455E666E3D47414244
5C4A424F3547443E3C2E463B304148243A3C523042271D2A39212A330A0B16374131231B
21272F201A251E32302436141C32441D20383C4A3737352C30213737351C27332F292126
34311E2F2C1F18FF
FF91848A999386927F9C84756F837C81829BA19BA591927FA79B85AE9098957888A29F9D
A195968DA99AA893B3989FA89AA9818C9CA08AAE9A9991689675A897949A7FA48B998C96
A2979283809B86928B7A769391A4958A788C89A084A99CACA09B95B0A9A4919D899E9898
8A96878D899A97A1A19DA2A99DAEB0A19FA28E9F87A9B3A8AD8B9992A58B9FA396B4939A
96938483A6808F94928AA29B7F96AFA1998E949A8A958597A38E92899395B09AA29AA09A
85968FA3A38FA198A09CB197A292A4A483A1A4A28E9BA3A48D9BA7778A818393938B94A3
8DA180868D6C7D8A8C89787C7D63725D73696D674F5F6E74605F5C67687C7A757564746C
5D717560736D7A765258657F5D6D735F816A786E6C777969677468786C666C7F82717F71
76647F7F6B76756A7F76686A59575A473F5461754E69706D7D662E655D6965566B5A6E79
76565A786271776E6B6E79527D617D6E72566A6B737677716B7F656E6B604F6E69525650
46668552576F6564457070574E81645E4A685D645F4B5F5A4F424C35625F6152605E464B
485A562A3E605753524A575E3F516A58405B665342615564634A4E684F424D3F404D5B5D
444F4A3B56453B3C312C3F3A3C513E5733303341242F304A392E3C36202B2F413837301C
3739373E3333322D0D47311C39342033453E522C352B323C4333271E2636402B23172735
1E3536432A3632FF
FFA09893959388818D85928A7F8698907E7E957AA89981A49CA2AF979EA8A28A968A8C9A
A9A58DA294978BB78AA69B9BA1B0A59DA08E9D8790B18F937FA17F8C7A929297A79F8490
98A38D90A9948DA57F8F93878B878A7781998C8795A099A0A3B8A19AB0A2A6A099978275
9294A4908B959CA8A0A0A0A1BEA78D98A69A98A0ABA6958790867BAD9AB599AE9EA6A79D
9EB08C8E8086A08F879D9B6C93857A7B80A19C9E97839B888392B5A8A48C9B979CA7A298
AD70947C8F9793A6A6A5A6B1A99E7D99AF9682A796A79194A39E9A987E9A96AA8C8F908F
958F98AF88778C6D74817B757E9A757079706263746B7A49677A7773756D6A7278728B82
5772795360826E55585A5A6F846F576767746D625A5F61696A557D785B6B6965695D6B59
7880616A70547C766B6E72687D4856604C5B6F5D62766E7277736045705F6A6B5E607A7B
6F6F657D716956575B676C627682726E77636E80795F5E58846E6F656D67696F74736157
735E507B6664655B5E616061425B644E5B70584353564C5A4F5B4C514A616C385E5E3E5A
67634C3B485A465A52543F46454B3B5D4F4054566155514E5A5859435B5E4B634E3E4146
544B3952323F324C2F273E49452F2B2B1A2C33343B32404B2D36292E2F38482B1D2B211E
46322F4434242C2903302F202E353C33426034303546152C381423163C3F3D3532163721
152B363A223228FF
FF998B87959AA383A4A581889180868D8BA8B0B48F8C89AAB09898B8A09A95A7A390A0A2
A5998F9AA67FBB8BA3929FB4989D939F88A08EA88384B4A88C938799979D9C9BA3A9878A
9992979096848C799A9685708F7F978E6B72799C9B9092A09895A2AB9CADA399A8B48297
9D9099B6AAA7A8BB9B999F969290A1A8B8A6B0B3ABA0A7A19FA9B0A7A494A39EBBA3A0AA
85C2A097A490A0958193A07F8194A7AA9C9D829781A0A697A98590B0AD9C9FA8A7979192
90A486AEB1A19D9B769195A1A9ADB2BBA08DA2A99CA78B9097868B9B848790847D739F8E
A28F908E928E77867E8E8C816D736E7A80726B748559577691645C556B68787C73796F72
7372696F5874696E7E73855D6E64826D667D76637473715F67846D6862445C5F736B5D7C
7C6C6F73626A736A6478575C665F766D6950724F53747069656F7167574866516C777579
65566F6469786569606673688066736D5E787B7B65886157765867675A6E7D8866757F66
78706957555E5F465856656261575E315C415B4C5254454A6743625E576463695A435A37
5D425C4A4F5A55445C6A374F572D4B534B4455455E4B45666352564F55454C683F525059
543E453C4155373F4648302837353444292E342D41191818323C353B3F35312C30404420
263E41281D342E1E2D31412D363137514437322C371E241E392624401A122B2035293132
2C272B20362413FF
FF798C9B95A297938B968A918899838C988397859CA0938A878EA3968EA1A18F94A3A5B4
9B9E8B85A799A096B7907C978994A69B9E958E998D998D909F9985879A9692969783A08B
8799A0919B94788D9B91878D8A94998D8683A2A0AE93939B9FA28D9BA09795B0A2A599A8
9DBD9CA19490909189978DB7929D849CB1B6A692A4B0A09498A6979F9B93B7B39D8AAFB7
9283A99E8A927393989D938D92898492997D95898C9A9394A0A0A5DAD2B7929FAF9D8793
9793A39DAEA49E9FB4A79B9CB98B898A8A9698AC999699909B938C8C8D91A98295957A8C
A383907AA083968583698B807A809178828563656179637F6065656C877C636C79747865
695C7881837C67704E53618180727D74706A6D727B83685E6264777B776C6A8769886E6B
7B6D7F76666B7E79706E6D636C646266727385726973582B62676A5A54674B6B526E7570
61687176616F5C7C5F666E4E666242636D8461897A6D7B65476F5E7873786E5E68596671
777055536B4D595A756546616365615E586F5A455B595146565B4D446359416E4C695254
4949454640435A26404D50574B4F644950514750685A45585D645E46565D4A4D624A3F3D
4A4349433D37495A422D282D32353C382F31302A2C2A22452B40334D4642463C283D3B1F
3E2847333B301B3646333D2F322150472E341E363C4C341D353E2A38362F293020110827
243237262A3C1EFF
FFB490927D7583829F878BA0A198A189999A9EA29B87947794948A9E93A287A4A19BAEA2
8C9287B39C9C9F998A9499959F7EA08C8F8A98889684A39E8B96AFA2B19F918D9A929D97
869C9488929F998480818681898C8FA6A39F94B3BB9DA6A1907F85A097A08FB9A9939B88
9C9EB2848CA8A58F8190ACA2988E9B8AABAF92ABAB97A09D9EA0A9A9A9A0A3AFA5A0A19A
86B0A391978F82918E939383A1928996918D9491A09F8493AFA294A0A78E95B18D8C94A6
8D9F8DAC91A997B8A4A7AFB999939AA692929FA8B79EA3B0958E8E958A9EAF97959C9BA4
9183908A7C798F8B7978877D9885785471727668767A7E817B8772826F728D767E67697B
6B6B707E797B6D6D73518672695C667C766E70726D8C706C815E6D7890696552687F626E
6C6769817086757F7A61717C6B6F877D77606D6E657716625857686E6D6A616F75696556
64698C6B7568605D6E826C5E5C6B61797C76757E70886A816D694E68896A725B71626656
666D7B6858665C485B634F523C4A4B54384F4F3C616781574A43626068525A516B606446
4D635D3A30465962645A4F5B4C485B666658524D6054505D484A3D5F5639354952474D44
4C494448373825384539504848372C3033283521242E413B45293B3B2A3D141D36513538
2F37313E3E43333B50423D35343E1C2F473A34422423351D1A352C273D401D23171D2A12
1B133D162E2E2EFF
FF99959187A289949A938E737F9E8293908F8C999298A480B395A3848B7F99958FA78576
A28D9597AE84A8A79093A2AC978FB09C9F98A9958F9B9382A39690AC9E908A8081977E98
9193A297998E87A39D9DA9989FA59394B39E92859AA39E989A96989CBB9CA68FB1979AAC
AA94909A989F9481938290A8A38F99928CA2BAAEB19DADA090AAAEA4A6A48FA28D8799A3
988C84918C8D9E8A9B93898D7F82A8A58184966F94A1A69B9DA5A098929F9194ABAE99A6
A17D8CA981A09E8298A2AA999FA29AB7968C91A49F90A69382878DA49F978AA29F8F998C
ABA8909771588F8B8B8E8B8787A08178717B77728B907A7D6F765B7E8571657983938277
845F7F687268876D6F7C648A747E84687F666C6E74735E867E6F756C436E5D667B678076
747682756B737C7861765C59635C784B7473637C5F6B5C717A5F745E6F69837479627769
4C61676D67738375897F5C67767672756D8B78898D676D6D797A70787588796264795C6E
6C466A5D2047705E4F5445595C4A444659606838613E3E3D5F4661383047563E39585E65
565060325A5A4D5C565D482E537645684D615D5F465E3B453F3A3E3C544A39304046434A
41442D4E4F533F3833352F26243540343C372F32374D413F3F404F472A1933292528464A
2D183E655647342A3A33432833282C1E375A412A12302D263B2933221B00241D1A082B33
25111C1C182622FF
FF91968F7A7F6E917B8678878D8C9A9797A39A949F8B999A998BA698A0798DA097848695
B4A8848A939C9B7A938EA5998C9A8AA2A0729F9E9E9491A69B8E8E8F9B9390C0B6877E98
7890999FA392B1AE86A093A1818C9B95A19B8E94B297B89A94A098A994A3999496978A82
9393978E897E939E8BAD82969B9F917CA0A5AD8F908A879A92999E9BA097AD929E96938E
A0B28E9E998F849A6E9A9E90A69F8798A69886947F98A993A4A094A6AF8D95828393A19D
8D9196919DA2AFA1A3968DA8B89992839C75908C9CA492A2A9A4A09B8C83918C9BAB9E98
818DA47C967A99888580848E8B9177939B946D7F866A676C7A756A6977757C777774828D
7273778C64767D6D6A6E7A6C725E62706D766779758D7C6D6A887775626B88757162846C
81696C636B6C797F73747065646A677C686B6E755367628174777663377A5E51647D6473
638487847068647F817368737F6D8F7B79798B6B73856F686C72507971465464776A706B
88795F707D606155666069567370765C615C45574F593E5852655A6460605A50475C4669
4C4415473A3C5D51664E5B5758607F56414F595D675B6A57455F4A596447336256504C52
4854463F453B374650464B3A43434A3338414143404E333E173A2E3A1124413F22181D47
46234A3B364E4946374D373120464A3D22293D3E2A3039181D3C1F212C320C421336171C
0C16121A212B39FF
FFA9A3A198927E817D7E78758D889A8987808A9E9DA49A9488A0858AA09A7B939EAD817C
A79F9FAFA29C869672878B8F87B6AE9087B4AC89AFA8A79F9AA896AF9192B292819C959D
8D8C8CA6899C9F9D84A39172A0A0A8AC94A0A9999C8F8BA09884BA8E9AA4958C9BA68A8E
8A999F99878E8590A0B494A5A57E979CA3A0A0AD909D99A1B5A7A399ADB0A09FA28FA38E
8EAD9784A08E8D908FA3949A938F999F9BA0909CB49295879C8F9F8DA99CA2989F9D9E9B
8A9094A19C9B9C93878F9399A7988DAD8D8C99AC8D9FB38D90989A9F8F7A8199958F928D
9D7B7E94938F7883867D9575808788958370778F828D5F637A97777B717579675A7C7767
6C7D6C6C8669797E695B74726F6880876F68776E7E837476906F64746E887A6F6C7B7A83
697D7F767E727A73786753676E6380676B726E6D55604E6E777B726C5552685A75766F6B
8875886F6F6A5B57897C827B8C7A7B6E738579677B6E60506B7F6F5F747558648470647D
67636265553B65605467414B6253484E6C4D485543554B4A5E4E634856525A5A5F5B5660
51443F43434B53685C414B425BA1875F45564B58746E6953593957414736393E4F534242
383A3C50493E3F3B3A333D443C3542254133364639504B435335313F252C48332A2A383D
14264F33463E1A2A2D3B3B47353D4A39383C3435243837203537202F1C3725382E173235
1B19281A17221EFF
FF9C9082887B79957CAFA2948B96968698A081A39890969C858891A49A8F58929698A8B4
B497A6829CA1996E948DA1A484A0838CA784999AADB39D9B918A858D928F8D9F9E969D8E
88958C938575A195B19E90A698AAA6909EA698919798889DA88B8A9290B2A4959D98908B
8C8F849B7F829FA6AF9EB5B096968E8C8E8B959BA39A8C8992A7AAA59D93909EB0A0988C
8DA0AC9AA5939590A69898859697A7A09A8294AE8B9CA496899298938B9C9496AD9292AA
A193949FA38E8A9E97A2B5A9AD9197879DA2A4A6A18D9EAA8A71A59A9CA3A1939E9B8E83
998F8F9E9197868B90757F84A17C718484677A7C8D87787A9372836B63796D6A686B7571
8380648579716F667C51868A856B7968946A686D6186717A676C756C66706B80886A7273
8B7F786260897B64768E817F76758170796581516D5E686A796964595B50688272635F7C
747B59885D786B666C7A85787878806E80567A7C7075737A84687145635262847675716D
717871695960603F6C50455F48566060597147365652405D5E5F67704156666957434C4B
5B6759583038494B4D5B4D4B5A64875457504D584B6B5736585C3C4932484956305F4248
3E314E343D3E543C534B4C472D3B37401E33402B2E3D3B3A3A40273F4D393A45444B3D30
3F394A4E4E35343B38333B4851362646444C32422E3D48393D353548472C0A2E2A0D2A25
20252B2A291A15FF
FF9D96828E7D9D9F8D81937B80A1868F8896928C939F85798585969491A498AD8D93B0AE
89A3938F9FA1A6A2808E9B88A58EA69DA79D908C869CB076849192948D99988EA797A99C
9B9899AC80ACB28686A68787959DA4A096A58A769393A09D9B95A1A4AE95929B83898976
869196979F9FA9A1A8AE91A3AF9198819EA18CAC9C9E8D87957A97A8949A8E9C8FA3929A
919E98ABA19CB39A80908D9F9E92949B916181739493A791A4A5848A9B98B4A2979289A1
98A98E929D8385A3A487B2A2A7AD9F999DA09A9B9F97B69894B5989186A9979CA4A2A29A
9A858E879F898675919567826C867E87988E7D7379877D84827D72825A8B736F84717571
6A717D7B74878C6D7F7F778A7D75787D81826F51814F7575696B6A7D7A61637499856E6C
7F6B7B6B64667761867876737A727E6C5B6E5F6C5E787156536468728D6A655F777B6B60
84687C5E756279876961746B757079788367657E8B786876838D7A6F6D786D657B656571
63666A5D4F6D6B60675A53555B5B4B4B615D44604D45505065495155715E5B4A3B44434A
6453614458504C624A4E455AA3555D5E5464505A4855686152426457544C4B4552414D37
44411C36474B4C343A452A3D48553E332F444A3E484A234A432D2E2736362F2E402B5246
484D33292D4731332B2C442D3131223E56482F365446444845354835464D3F20153C2E2A
3036132306261CFF
FF9472779E476D8C889D809071919E9FBA97999297A19878799C8F8C9496B78D91B19EA3
81B7868192A18A9B9389A09A85A7897CA7A291948DA49CAA8FA896AE95B2998EA29E9593
98A39C9E9FA49485AD9D809EA2977F95AAAF9899A4A79FB6979DAC9FB2A092A6A39D858F
928F98A29697A6938B7E8F9A7B90848D8394989D9FA0A2A38881918BA0A1A997948FB3AF
ABB2A087878DA9A3B2A0A8AAA2839387889B8A99B8A5AD879B98909EA9969EA5AD989CA6
948EA19CA9A18F918D97A3B8A67BB8877CA4A6A1AEB59C98A892959F9B89878F9E93A6A5
928F7E7A7C7C648F8C809891917E7C849F807F8A777685806B81757A708187716C787682
7F907E7172767B6D816F6A6E737A7B7065746B525C7C76836F6C797881697B736A887B76
5B4E7F8E6961616A52818A746E755672616F7C656B6B666D736F716F6E60645C59604C5A
7A7C5D6F8767808977766F8976597465727A6A7E788980767A7C8C626D60606B587B786D
567372635B4465436B60604F565F70505F5D4E475E63575E525C7565536C572E3751534E
3F5047553A554B3E493A4F6A974C6351603D594E5F62534F4256593E373E3E3D2D34514C
5A3F453D4139443B3E2A3C482E31412E234A404241313438453C3F2F342F383C4448474D
31453D312B3E54404739372732485D594D3441443F462C22474C17162E2B1B323B362B3A
1D30282E371320FF
FF9A939083A0948D85939AA191999B938C909A94A59F93838E9EA6AB9BADAC9298909F99
A98E7D8D8496968098B6A7A8898AAAA5A09C9D9A8C9C9F9992A6988D86818A91838498A3
A89BA0888F91956497A69FA2A1A19E9CA2A8907795A7999D9F9690A799A9A99BAC8C848D
8EA98BA8AAA191969F8E9AA8A889A4B0798E9A83A18E9DA3A19390A697A1AD9F9CA9958C
93A9A09887AAA0AB9A9FAD96908C9DA491AAA2A69597A08297A8A19F9B7687A89E98B9A9
82A6A99C939F9AA99C9BA8B2A4AC9EBBA29399A08A959791A591818E8D90AC9B9CA18098
7F8F92907AA6948488938E8A858A8493898E898E7D8C7A7F7E75757D747271666F69925F
7083727E81797E7885817F80887F68717D8568728C7870558C8677738A6F778083737B69
6C7263557064554F57648A84597A6F766775695D6C716C666B6E6A6166686D6E6E49745F
65647066796E637A867561737B77705379817268787C706E9077847F6979717E59677E86
8283666362605A656C6868696959525E55555E5A645A5B5D58584D61634A507A4552514F
603C4B46535F595B595E5C5C5A475A5942504E4935465D4165593C535F4D355650364042
35504C573D383B513C3D4B4F5047465A5639372E3627452D45504646492F2E354A4E4046
3F4238412E2A2F0030443738323D473224222B253C43464F323F103A2B18121D141D2A20
2F26242B070A17FF
FFAA839EA09A8F8892968C8F8791A79F8BA098A08E8B799E8F80969A9EA68496A8AC9996
9B7B9795987E7AA4AF8CAD93AF8A7FA5AD98A8A0ABA78288A084A6A39F93939A9D9C9AAA
9998A99EA0A097B08287BCA4889A9E9BA0A3B28E998791969EB1B9A7AEADAEB29C8376A0
A59FA98E9DACA092AA9AA3ADA99C8E8DA1688C868D87A0758B948AB89BA69AA58F999F93
958381909C88968C94A8A493959E809B8788A69D748BA89A929D8D8FA98499A297AAA396
9B82A2A2ADA291838F9CAEC1868C97A59CB2999CA497B79B809CB2929A967E9B8C98A291
AA9CB0928A90838094908C89827D7D8A7C7D9582738F92837A87728373878E7F747E6569
8A8B7A6B71799181817E797767816D767F7E756968716B7C9055757163737B7287788F7C
8484738D876F59795D7A7F728B63826967767079706975857186736F507E6D70556D5B67
577D4E6F727576687269726D8055686F6E646C7771526F808D6F6E60596B5B6056706B5C
6F6B60695E7C71616779515F5B5A6057555F4E565C48465C453E37555F575351624C3B54
594D4858475A585B58504858554A6E6A695D5B514B5C4B54424D4533344A3D374A645A54
40282147484A474A3F443E3C3F5A444746464A4A42354E4A2227293940463D414D284C4E
5A4C362F36483D3D1335263A1933104753344D34444A4E2A362B413D24263A424D40221F
25213F3A202E2FFF
FFA5A7AFAA98928491938A939E849888A19BA473A0A29987889204798D918E8BA9AAA199
ABAB877FA9AF95A3919BA39688B98885A6ABA9A78A93AAA195A5A1A097A6A98D90A6A98C
7F9092A0958B9C998F9798809FA38A979D888CA0AC858FBAA1B286A79FA2949F8E69979B
8B859C8D8B86AD9E9383918B9F8487A18E909AA78F9D99A09DA592BF9DA09FA39691838C
8E817092948791A49E928E93808CA3938189A3A1879598AC939BA7A17E96A29DA39EA879
8BAFAFA6929B95A5899E9FACA79E999B8AA4AD7BA7AC979DAAA97B97A3A29EA29B8C9783
8D7E977A758D808F908393908D7D8B9F7F8D7A8D5D87817B5F7D7A887F70747E6A6F877A
7E6A6C76786D7F846A677D7B77607C91756D7D7F6E6E5263668B677E7A878D737F707C86
8F8791747C727A5C636C61855C887D8159766F6B70736F7A727F867888706C7A65685852
7065775E76716C807081766E6B484663726A6959696F856B61766E71767F836E6F6C6F72
796E6671695A5F82755F634E4960665D55645A4C3F3954334C445368785459676A6C5443
5A5251327058435A5D504754514269574A5657815A344E59594A3148615A35592E5B4D62
56594C4C3B524F3D3D313C3C2B2250433A4F454B3E3F34424D3A4D504B4A4151394F324C
3B44483B272A4E322C3D423D3C35393E415B4059483F343F46352B3B36322E302E39372B
423506102C263AFF
FFB19BA2909B8E8B948781929199AA978D95A6A18C8E8E8DA69B98A7A09793979898B48D
95A78D8392949E9499A090AEB097AB94AA9092909D808E77AB9FA4A2998D89A3929B9B83
AE7690ABA996848CA0A49C7484A59EA98490898C9790BA7EA2A1A48898959AA49689A094
A1AA918F97A1A6A3828F8D838AA0A08895879C8597A59089A79696938AA5A9A88FA19180
9086867A92899F8F70839D8D94849E876B96949D998DAFA191869C91859291687D8D9B88
91A79FAC888C9AA69BB4B99F8D9798A4879193948986AD8D9293878B8EA28595969A9993
978D89A1867BA38F85AD93999AA4797B797D7A73857E7A84645C6F80647C796779646475
7879857B7C817869767D85837B8B62575B6C75776A7156777B6D657F67827B5E72776F7D
7E80736C7A68786D6E927B5C738583798081826C77796B556B67758374727A6B755B4943
75766F655E7766867A7777605B00007E7E8E6D867E756284706F6F656B72868A6C646C55
7B6F766B63746A6659415D5160634A5D61685443674E40574B51646E5855525B5953655B
5F675E3C574E605B724659565759455B3E3A583C565B565A47624B2B3A475349645D4442
4F4846385D4242543D1F474E3E4F24385243444E4841525055293B404E3A484044482D47
462926333E30242E4F3A414139374D2A2D482C475823384E4C293624341539271E292235
313C2A3C182A22FF
FF9D9E7D92989BA5978D91AA97A198938D979FB2A1999495A693988EAAA79C8C989F82A5
978A9EAB8AB585A691A094989C9CA590979A999D99AD9DABA39C8B9E92ADB28A959B9A99
8D8C8DA1A69D9D94978AACA4809F959CA4B693B193ABA699959897A79DAA8EA9A2A28886
9D9F8986A1AB918188969B9889866D8586868678839C8A9E8C989196B18B928AA6807193
8EA190726D878C7C909F90929896999B81838F919B9285939299A19DA68E9E978C908C94
8F879EACA1808EAD9BB0A8A2AFB0918D98C5AE979F969192AAAE9494A28CB0879FA999A9
9B9D8B869D8885818A8C907B857A958E9989929E92918D6C7573805186856F686F7F8194
876F6B6A637C837E85966A70837A7C8B6B84867A866D72846B727F7D8A747C7F847C8565
6667676C59706D737F89797570808C9072788071797580816B83818A655F7E6F657C7661
74757E78808A807774858977686C75756D5F767C6B7377796D827383686F675B6E667174
687E6E6A79746474653A606F515B4A61505B6A4F3A4F4662625C5F555A3F75504E495E62
3C6257544B4B594C4A604F605742584F71535855724B5556505A61625D3D3955514D4F44
4E514B33444D4D594A4D25494B394448614F4D424B3C3C4D5E563B46396044453E452E34
4C45223A3E4028453B314339384838413A34483C433E3B48323136472E3538292E2F2E1F
141733093A332FFF
FF96989894A09990928C9C90A48B8F99A1808E92799E93A5B2B18CA699879199A5A1ACA0
96AC9398ABB09DB099A8869F9B969DB2A38AA1AC98A499998CAE9999A3748A9A8F8991A4
B4A69BA894A6A28D9D9384A4ADA18C849685A1999C9474889397AE85B1909E9A9A96958D
96949B96908EA08798989F78908A9F86807B82908B918A698592827E646F6A8390779690
938390A891876199AA9295AE987A8CA28B8183969C96977C929783A6A993A196A0799199
8FA39094A990969AAF9A8C9EAE90AE999B99B1A6A2A08590889E92A6A3A0A5B77580939D
92919F957A89987F8B88898E8185769085A48C8A8D718669818A707B817176727B776C6E
6F6F8A69797E877B6E6D768D77809471887C817D66608064695B78758074697F8B7F758A
788162928263617B8A6A89898D8E8B74718298846E6479867975767577686B696A7B6B5F
6C7D5F6F8E775A73778270727C6C6B80807A977081807A6D7450756F68735C695F837050
7570644B596A5E6D675966516451655C695A5A505B65363D565C4C645F5745666A58482C
5A3D5E55535F5169673E5342556254614E4A4D5C5B5968593348553E436043434C484F3D
475C575636475D5A46523F45394D2A353148504C5A62573146483250364046464F382F41
404948503F51384E3C3B2837422E274C314C2D274130413B35253C3B514E30354326350C
1E1E1F2E452911FF
FFA58599B1B4A17695939BA0A0A48D96AAA89CA294809B8FAFA6ACA28F86A18E9AA7A79D
9B919997A0919C999AA29E9AB7A496979F898D7E98989A919495B1B97DA2917A74AF9C8A
AAB690A2A0AB9BA99187939996B8AC86A69BA7B18994B59797908B8E85A05865A8899E8D
A09A82879C969AA3979296957D628381837783808B926C7677806D646B767C7C819A9095
869793807F6D906885817E68879594848A8D9B9865919C98A8A3A59BA1A59BA3959DA89B
948C9B96A3B19E9FA2AD8495A6BA98A7A8999795A0A6B2979291ADA19E8F998C8E7AA799
817E6F739EA28E9083738A709A8B8D7D84879481727476726F777B6C63605D737E6F7C7C
68777B6D7D68826D837C72787B716977647D727E7E8C7863777C665E73746C6F777B7B72
766C7E79766B906F7A758478757F6F7C7B707169878C8562797E7F6E53735F6C6A607664
6F5E7F8C5D7F6E897760766E556F7871797F826566716E6B6B756766757E677E7D6B7575
5F6C867977715D6F5E56576F7578616E5C4D545B55513A3B64575F614C3D554B5A6A4544
4B536263465B4F7166645874664E634E5543593F3F42554F56525A66444C41565A3B493B
5C54364C4F5D5864524D3D484143505045473B5C4C5421364C6655304B3B345357354E4B
313F354B4441403D3A3B292D362F2B1D4E31361E22393F463F433A412139453626131823
22240F1A212E33FF
FF969B999EA39290778F8897958FB0A68F93989E938C978AA49EA3A8A0979990A29CAFB0
9CA4B0A08CA67B9A97AA939289AAA7A1979062667891A0A9889C9BA8A1A08F907EA29D8E
A49F81AEA297A07F9BAD83B49C97A48E8E9593959AA09E9896948D9E9FA4928A8A9A709B
877583958E9F8C949E9B979E8C958A8CA89B927C8E697B848178946A5F645F5B87729486
8FAB8E9E85928F877E7E8F8F8B84908981848090A29D8F71818E91948E9CA197AAA39A9F
96AD8F9F9E9492998E948B999A8A9CA5908DAC8A869D9399A6AA9888AAA19D9E9AA48E84
6E93968F9C838F9587808071748A578F9A7385817E856275776B6752717296745E635B8A
9D726882626D78737C5D877F6B84706465747A71846D6A5D786E79726F746E6F7179746F
75745C8179787F856E777E8B6E645B69796E8171676A7279667F7D616C7257606562846A
6382846E637F54737C6F59606D606F7386747183838A829265697675696C616C70616C79
755F64686A6A5948737B6E4E685D6E4B6169593C68495B62436456655A4E4E4A3B5B6C48
605152564A5A57624F58616959684D555F535E4562613C4A5D44504F404A3A3B334A5559
4A4743393F564D41543D642E482A4560513A624E453E324E443A543C3E516358474B353E
284235313E3939523E5B5137524738292F372E32342E432C3B282C313E150C1A21232218
1F1C0B1725272FFF
FFA7999AA59193AA8293939C91A5839B959390B5A6A5959195AAA599A78D9D9CBAB0B0A3
9FBA90A0957FA4979B92979C9AA0959D9B6F0003A993A28F95869595A89A9D88A190AB95
7D9E7777A08B9E9B9FA1919C93929FAF9D9F98AAA99BA8A69B928994A0989D87898D6B89
726D978E71928C799294708F8E879374667F797C6F7C70766E445A7A725F84765A777C89
7F86798C7C9484858F828DA8879590888A8887A5A69F88917B9E98798797A4BAA596929E
A6A698929C8F87AFB19C94979699929CA5B0A29994938BA09B8C96A4AFA58A97BC9A898B
778E7E8F9796A6998E92957F9C87939683828E7998744A68566458717D757E8A6674516C
6E6677786B7471777F718B778F818C726A5D718A885E7571735A627B7E7F746E7F7A778F
847773637F786F767C8483896B6571677872816F6A6B8275797F746B6D59595E5E756368
7A74616D757B77637F69746E807F8C7B756E65637269757073707B61886A787A737C8463
6775686A5F8254675153587662595B57543F56434866535A44635F4F505A585364435246
5F4C5D605651513D58635A6A605D4D4E514C606155513D5568604F4754544E523D4E4554
305346374C624156444352414446343B3E5233464735354746484D503F443D4A444E4357
41413D594B314A434E61174A342A3C403E322425223C32262021301C2937201211002C23
18171316153935FF
FFA99E9A8E81A28D9A969E969A8682969E8AA7A19DA2A99A8A94ADA99AB193AAACAC92AC
B196B3B39A8D8198B08CADA28DB0A3848D9B7680A4AA93A6B598A089A3AAA09CA990969A
9D9195987F8093BD919C91A3A19386A78E958D9BA2C0B9A99B84A2A1AD9A9CA2907A8D78
966D5E7689849491797A9274978E989C8180958481858060675D636A696F667498806682
7F8875796B797F8D818E8A938893939B9E7F958591909D81707E95979D9D9498AD8DA0AD
A48B8B949CA3A9958C8BA197949BAD6C609EA68D8B9D828DB29BAD8A85798B9A9AA49D8B
947FAA827D8D92909C8278907AA7979281827A8D72827B50776D5668778279656376706D
6D957D786F69786F897C5B8965847A8D868346647495847776839074697D7998858E698E
766C80696965778B7D7C6D7E6B7A6C79836B81855E71666164647F7C7F692A5B5C866C73
6E848A6F66736A5B66706270767B7D7F6978716A818871617C8C6B717A78706675614D72
614C5B6C685A4A675E4E54685D66656E5A5C5351455F4A445C5A4261664F4A515A503859
484D4B6752505650535553344C5A5A556651455C58574C40544C42443B445843373F414A
3136435D43394B4B3A5546474E4E5C39493B4048444A48483E352E3D44404E4B4A5F543C
3B514C50614941374A4A3E34304C33494A2A1A332631231E2C36324231282E403F2B263F
23271E1C201C0EFF
FFA4AD98A09A75757A8FA5A09E95918AA78787A295A095829B7C9A9DA2939B9AA2A69BAE
A49294947E89989C99A581A7AE96AB9AAE8C858D9EA0999F9F8C9983928A91A9B097867A
A6A292A69D8AA09EABA0A293978991917B8B92939F8895949B95878E87A195A28E7C6882
7F7D7C82948088837A7F8D788E9A7D8786828069837F5E69828D70756B776454787E9478
6473668D93928F96908F9B8B9AA09C8E7D6C898F7B9198A39B8E918077948599AABB9195
A0967F47ABA6A393A59BA19999A7AA48469796BF9DABA2919A7E94A5A49DACA1A2928197
999C9D979C8A8C998A719C7D929E9E82937E8B83677D77757F8171907268736F6B5D6167
7E7E70756F6D4E5182846F71847990756975857D9F716D70797B6E6F8F575E677379816D
79796E7F878A757C786C71668D795A645C80737A847381856F7E76716F756F6C52656354
725A5D695F79716179757C77728277727A907E5C576682866D7C766C7987686E4F666B63
5A6465654D6E744D62796B6F6D6378655A61625A6B403F5636565E2A425E625E46444F4D
602F415B5D4C4B4B4A644F434A5E583E4857495C6D5C48454D3E645E6847504D22353133
60363B47594B5031195050292B645D6746524E4E4848303A3A5843444C4A6447554F6047
493E4A463F4E5750433F3C484C464014423B3B393D363D3B0A36353C3F392D2C313A241D
2D412B1F230E1FFF
FFA6958F86937D8C7387868EA49D7E93A492A39BA37F9F9D96A7A2AD929D75889398B396
9EA2AF8A88848E9CA091938F9F89909F9BADA99DAD8D8A929A7D8592A1949D989A9E9F9E
9F9C939AA39CA6AC9B96988D96A39F99B289A796A7ADB699937C9A7E8782A18187A28B8C
879C909398959D978998838A90968C747F857267716E7974737971817A8075777E767276
7A83827B7983806F92807F6E9190838E868A8D9D9B8D929599A9B39FA297918B9D998896
9CA48775B18EA39DA89489A89A97A2A29D9A9D8FAA949591A8949CA99793A08C96898696
988A8B697E88A77C8693887C8588797772737B888C887E857D646280866B6E836D727583
7572755F796D666A7B6379696A94755F86787C79537877786F786B5F6C7F667A88967170
7C726A8C77658D8F79617F87817C82889D7F967B57807950726E6F756A5F7076716E6F86
5770565C62585E5F3A455A6F5655595876787A765E6E717E7B6B7D6978716B795D70867A
7A7D676B6F665E596457705B5F68587677654775505350425E664A492A5143586C616F57
535B474657635C4E5259695F47484F494C4C64575652594A675F453C534E465049563E4B
364C405E405156625263313B544A4E5F4A3C53345458333549544855415452484E3D4352
463D5748283C2E4F4F3B371D5254282F3337411F342534272A3E2C3C2A3B2A2A19222F2C
322D30241D0815FF
FF988D9685958990838B8F9FA1909CA28D7A70A197A684A39F959F98827F9D92B6A0A09E
91AEAAA2A7B79F9680A2A4868FB4ACA190978DABAB998B93A9998E91958F869798ABA19A
82997681A3B3A0859E9C958D8F9D887C75927D9C889797A09D809B9BAA8E9C86A1A09A83
878E86939190848E84A067638196928A7A7A87766E6D746C77808A88787468866C856D6C
797B767E978F787B8785718B8294957B9B7B87818B9A8E8F9788708B869393879EAD9CA6
93A8A0AE92A59BB08D949BADA2AC9FA0B295A19F969D83879AAB9C9B9A9C9F7C9091908F
8B9A89898D829B97A7AB7380978D858C787383936E79755D64798070856A7E685E767172
7678757679667587806F6C5A786E6788756B59746B82866B5C66787A5C73716A72767B7F
5F736E5A7A748B919B8D737F8D937B8E87888E74847A6F7D726A62555E6B6C7E73725E5E
5E4C58505F4946363A56434D68000D87868C7D7B7B64606180656A87784A706479557272
6D5D877F707B676B745260526161806852615C46606452524343504866525E516A6A566E
4B40543C46405B4B434F3F583C5E41564B4C3E39374F405D414B515B5440352541275653
504E423255434E3A473A4A3C534A45505F57444640494D4F504F3E39453C56615147534D
47452C3E3F5B4D474E3C4832322D3931504D3A3437252C3A322F2420264230433221282C
2F351A28392027FF
FFA5ACA9A9939990836574AF999C999DA3817E90B398918BA199B19E9C958B96A0A5AEA2
8C8A93B6BA9999889090A6A5A2A29CAA89A7A898A5A5A19A9F8887918F96A0938B75948B
84948B89A99F99A392A4AD988B8B7B8B9C969F8AA79395AA969F898C8C9C819A8896A179
88757A8C899B8194A58F4A819A9F85868F67667E7774657C888A8F8C9188956C7C817374
807A6E7978848C8F979C9180997278A47D988C6D9F9F98908EA28F7B96759588AF97A69A
AAA8A09EA9A3A9A58F7A9BA2B998A4A8A79EA0A68C91B3A089919C9BAC798DA1A488977F
898C9281848F89B57F98888B69708B8C74847E516B818A89786978727C918D745A6B5C7E
636F727A6A6C7368657C746D7A807D6F68695B79657D868868637A608C8C826A7A72756E
665A758E677A756C8E817B8D747C927E765C4B5E857A6373766E5F564F576B6151544E63
554B56405E4854425D4640365A4E7F896B605B7977816C6E6E756D79715B646A6F695A57
69896C62785B60606A68735C5A4C6C5C835854595B493A4C45374E564E505D424F456046
4A3740555C53546A627058585B5F445B4D4D564650415D4A63374B533F5D40473B453B4D
5E37653B2F3B4C47484638323D3B434E30464E482C2F4D35344B4253424B663853563A46
3B45361E514C4E453F40372C46474330282B38393C3113393237253530434044352A3531
2D270A26240601FF
FFAB78937B9A83888591769F989EA58F9D989BA98CA1A396929E92AEAAA0BD9081879BA0
B9A3A0A3A79C9FA1A87FAAA8A3A09E8EA5A3A0A6946DAFA3927BABA39784A6A29F8592B0
A8818F9E9495A99D9F90A690818CA3A3A898859BABAC95A59F74AC8D8E8888A49899848B
808E9890876E9C7D9191A0848E83767663697468627C81847682847E7B7968878A647488
82817F83807F8F92A0888D8E8F9C91908A7784B5A0A2A384A2A48D8F97AD9889A0979692
7D81AAAEAEAAA0988D9CA5AA93A39F8D959FA09B878F9A84BAA9998B97938DA69C888185
8193808B95959682A1969984A39584739170718464977F878A7C7C89777D747C5B62676D
5B6E7E545072675B5F6775937A8B6E6C687C83878388787E7E737D857D6757717C806E63
557F6C776B6E6B767C7263667E816D6B74787F756C6F6A70677080636F53686D6059555F
64583D634D464155473558474A486670866F7A8F62565B5E78877B6B7674686367707662
6B628A726B66757464696E45624661584A6D59505354584E4859645E59494C465A305948
4A4B434D5046604D4C494A544C534E47555E384A3C484B514C4D5C454149464B513F3E3F
44423D464E483823384533273A3D2F573D3F593D4E444F3D51472E485D5D46595B524658
4A39355A3B33264434323D2C102B492235363823374720282A32303D351A4034232B2E35
242D252C24222AFF
FF9794919A877F8D9AA4A58A879690AD8DAA9A8D8494979CA0708D979C959CB3AA94A09D
A29DA9A2A4A295A999AAB2A29E8CA6ACA6ADB3A59BAD9688ACA9938A98969D9491809D8E
759D8E8B9C859A9FB58E8A989D9F8C858F899294979D9E899293917C979C9A849A8F8E8F
818B8CA295748B8E8D9387A38686798877636B8581636F8272929496798583749C847E88
756F849A82748E9F8D898C898A85A78B977C849A8C75817E86997C9F8B85B290979987AB
9FA19692869DA69F9DA3938F9E82A0928FA09991B4A5A88BA9AEB3998B9E9486A2888983
9A878D8F7E859B89779B7B957D8A757D8A8985867D6F8168817B7A81727660626677757E
6861836E757A7A706F68817C8478786A817E6971746D7B82826F80687D77716B7A688674
71858E9368558C8A867A757C73866170807563796D80847474646F6F656055585E71575C
6671433B54464E354C434B666354605B4763756A7171816779737B7172726C6D69656670
597872856D72714F686E62794C582550475860626A524F3C453E4C554F4B445542333F22
363D64695B5E475F3C48514E56474954574F584B4F4F3B44563E6151444C4A3E2E164939
505A4B482D4241383331402B454C3A493C4847474749253C5A5344585633456041444C60
57604B364C555D352F47342B3E3B26492C3C30553F162B3041271B3324323A29311E3F23
27322A30152118FF
FF88AD9D856FA9A0A8959CA199A8A078A3A69EA0A0A1A6B0A6AB82878787A586939299B0
94A0B08D949FAAA19E9B97A58DA4C0AE9E9EA9B5A09FA08CA9B6B17D9482B0947BA09498
898F8E8A815C918C8FA0A094849B978C84738791949B97A68B8A90A3908D809AA3A4A592
8D7E8E75919078837A8A91988A8B7C7372738075887A728385897F7E8F807C6F747C705A
646B8488798E7483918B858F93758592959E8E91837D89939494978C989A9395BDA79B87
8C9F96A9849B82969D9674907C9C9DA598857D9B908B79927EA19497959C947AB3958381
88A28F7DA07C709677878F996F8C9E9C8376887B928771778C93827F86717079896D796D
6D635A6077729092777E576F775F716989747F77667670837D796D7578687F7F7E7F997A
74765C7684758A8D907D6064817B728D8E8C8E947270627A746A6F67747B5D65744F6058
6550515951564B515D543B3C4650646E64856B6B5F7B7B8A7B87858F71797177786B836E
4F4F7254776860615C7A5572554662695C6A59584D5454643C5A6E44503B36493A43464B
4A5443495457613E62424540415139403A455952674E5E4C2F473550492F455163464C65
4C3D50472D454F391C47364A424443374C54415F4E41515E574753684B5D583F2E65543C
4B4631363029465524402B34394B353F49454E3C2348463A352E11133D1F3949331F3014
18202C141F253EFF
FFB29AAC9A9396957D92B09F9AA2978294AF826798A591949C8E8790988C9DA49FA2A097
9B94A5A6AC9795889C949EB6A9B2A098ABC79DAFA8A789A393988794A38F8983987D8DA0
8B8A769195A17A89867B9A799190ABA8A1849D927A6E7D6169948B8592998990868A7996
85929193979799699B7F7BA4A0966B6478635E67707A6F8B968B6D787B7B82896E816774
617E6E656A98929889897E89888C908D918D8097928888968E7E9C9F90A8899F8AA09C9C
ACA8959A98948C8E918096918FA08C969990AE9894949B8D9A949C919D977E8D849B8E87
8A8476A3A3928E8992848A71867E867065616885867C796879856F6B7C8C827E6F5F7170
6F84784B6F7D6A64635E6E597081776E6B716B7E8A9E75617A8E7D89737F716F78958379
8577577B7E6B7F7B766E7E84757B717A766B777E86797E706E657379695574614F595756
6D4A6862705467625753515B5D587A455F565D7A768C6E766B5E91736E79735C7D717666
5E675F7B5F636D6C748374586C5D7A71595D5E444C6C534B5A5250555A5652513F272E46
334959474628494A4D535B5D565460432A35515D5D3B494B464C31403446375260584856
5C44542F3D31503D3D253D3F4136494B4B3C483C5354343D4945384652484F3E30474543
5450433C39504332392F3E4E2F37463E4137462F3C374134321D39391A29431424262626
35252E21232A2AFF
FF9C928692B0AA7F8083789D9C8E9D68789980819A9AAA9381A1A0989294939DBC9A8A9F
B5A2A1BCB59CB3B3A4B2B2B0A0A9A3AFA2A0AA8B7D909789A3A5A5A0758C838F83927E98
808D939B9C979C949C84908A8F89908FA370738A857987957D868CA68697A4A0B0A1A180
74927E868E948994929290768F8994777E6755777E7A887D756985827478767B6F77748A
577175588F92A587899B999D8CA89F818B709098AA7F83998B7F888F8C8493A192AD9EAE
ABA7B39497A88F80868F97A996A187988E818A998A808796928E8E959B8A7A9D999C989B
8F7B928782996F859497946F7A819180758262778669838C8E7097907C7B6F6F605A4B7E
816A776F7B6B73696562605D7F8A806D717C70835D7D7171827968708975716A5D6D8583
796A7865587E757D6E655767788181776D747A62676D7B87707C5C624D54645C5A55736C
536E6E7A6D7967775D556B7263655754617460586D6C7A776A4F5E7D71727E8A73656762
736A757D667B6A575962646B54705965544B4F70645F5049414B51553D464F463100134D
533E4847465D526A5949544152485447524D3B4450554B4B433A42305E33464041526347
463A4437443C3D4E46533D3C39523C3E2F4B644D45493B4C3D2A4E4F3837515F514C5069
39475B534B3E3359564346575543423C53484833354D3928302132343D2C2D352F201335
3634462F1F2300FF
FFAD8D9B8B90A8988D879F9B91799A947E9C928C8F8180860073A09390928F9F8D899F8D
8DA8A397A7AE8CA9B08DAEA5B79C889C8C849B878D9A999387979A8F90A17E7FA69A9E8E
807B7894958B938C819989888C998E91838C9B818B70908A7B68948D948C9884889FAF84
8480999493948CA189888FA7916D80767B6F637A98757A8764949E8E84877E807A5D6E4B
6B6A7890837C83938896A5908DA08B9A789B8287857B768E909585889388B9AFA1899290
A691779DA86F979996B4898E9C92A58790A18AAA8A9F958D85858A98978A8E8593809B90
949C8E7977949199978A819A757A809579766A82787F857E7F7D8476747F6955626C5C5A
6774666D725F647B706D685E7D827B696B826673657B6D80746E676A6A87676B6B6E8276
7987715A5673727E6985877D79755A75878576817D755C727F6C68685B69546B5B53574E
495E5D616C7B646B6D735E58605C524B504E554F5A686C726669776B7766687787757168
71573D5F65584969664F53596561704F5B625D5F64766B484F3F3832575547484344383C
473A3D4B4D44583A454B4E4A51594A4D4640363C3D2C343852443F4935333C5C3246484C
3942224B45363F37333C464236383D3C2B4A57353A3F493F3B4A53464E4641344547593C
523C385B45362C3F45544940383B4536384D264D4A302B40292D262B34412D212B293D0A
190E153D23212CFF
FF9590A0A59997A5A4978EA6A49187979792A696A879939990A797907BA1AEA2A8A3A4BD
B49C9CAC909DA2A19DBBC5969EB29295977E99959F839D96AFA8AB95AC9C8F969B9D9187
8D81AA90917A95A5915F93979E879791AD93849B96968AA996879E87ACA4989DAC818296
788F799DA18E777C9A8B87A3A37D9A797F705E6A695974718E82997791817273716F7183
758590878A92988CA99C8C848C918773A48995788D93A3879196748588629BA68B8D7FAA
929CA7A9A4A6A59A8E8A8A809898868EA08790979F89989393A1976692A49D927FAE8E92
868288967C8B91708A8AA479A5A187877F7A9E8B8E876EA0967F78756C61585F80777C7B
807E8A7C887A6F6F70787C7D746B758F6B867D8F866A73897A70757058746A69795B806A
88826F6B70697B75797880916E7785807A83847B7E668C6C7C65757B546C575465626773
647866646F84866F8E7771797270716C656565647F77676C68786056708150757575896B
637367785C5B5C6263686A5F6E6C6A6E676B65675A4D4D535549543C4D3356444E354855
50323950463C5262614643656B55524559593F3D53455E37454F3A493D4A615043504C27
412D5F4D363E3D42293F3C3D2636444D4E53404E5055574A555A3A3F42455C465A554647
60583C3C4A4E395352453B5B44534437464D40373A2C3A332A3125332F371C372D392B20
1A48342C3C1F10FF
FFA89596BB9499938A99928E8688A4A393AF9DAA8DA29A98A28883A68BAD869C779E979C
ACA2AD8FABB8ADA5BBAEA89D9CB8AFB2889F979E7A859694A88E8FBBAB8B978E7D84908B
909E899D9FA29C9AA0A984858C8D7EA6968F83919BA091AB9A9093998A8B8C967D9A8894
9E89899F9F847C859389868282847B736E74706B597572857F895D8C786E8570697A6D75
776D8D797F929785888595918B9D796E858D9787768D9784958DA2919A7D8D8DA88F8F8D
A28A9DA68B9D7CA5C5A1989CA08E87949291A7928190928C8D907986758A89A39186878F
8385978E83788E7D8C9A8D857B837E9D86415C80836A8B6487857E868F738876637F7A7F
646B605D6D7F7D585F6678708F75696376766E60866D7E746868697C626F726560787462
867E76806D675B73746D7C89707C8E867B6C7F7870696A7B836D8A5F7A58695F747C6D67
637A6B6A6B5A75707582754A59645E5D6351646760747B5F79608077747B8077666C6E51
6E78726F5870776A6651536F67675B5A6A614E7A4C4B4B595F454B644F55325F56454B50
4B51533C5965614F564D5D5358643A514C3A424B47565B50413F4042464F53454A303E45
57474C3C383547364548423456444E4D594C3B5D60504F5E4747534A4A4D524D335B3C53
5242465A513F4C445C3D394759464E3E4B4C472927382B2E2511372F2F281B212C2B2A3C
40332A32102523FF
FF94AC807DA7909A9386959E999B838EA09F92886A7FA799A29ABA8A8E999F83A1809496
8A9AA191939E889B9C9EBC87B89D91A9969896A9909E9A9C9196878082A9A09A6A79A1A7
A8A397888DA69E8F9F8F8E94A092898B619C6480758D8F969491929898A68F9E899F9D8D
9990A19B86A68D758A7F858379987A696A6E70726F7E716D6F779A78787477828D797A73
717F8683A4A996728A9180807D8A87867E817B958E9990977C9980A49388909D9B94958D
A06E817F8A889AA19492929D9CA9809C84A39E91979EA48E958678919A868693877C90A4
A08E91868C8BA19B777B847B93A48B75817F9789737E808A5B6B78726B7A5C726B6B798E
75748C7D7773566F52646B746F787877786275765B636C6F69826B7C7F757183695E7776
728572797D705B776F7879767677695E5062806E627B797852756B6A62554F5E676D676B
676F726A86767C7B82785F57664D5D5F5D736B6A677369758277706373735E71647B6E6D
626E76596F7955604A63664B746C64695D636164393F60614649414F583857484F4A3249
5C4D545E585D694A4A636462685D4357504F565539443B415345406022403E483C315042
3B43344E5251374D4B4C3E363A412F462E2D3F4F44405F3A4B3D4A474F6D49562349543D
4B474B2D414740493B4952413C4B3E4F3520393945334B412F3B320A282F3A3D352C0F1C
2C401C1E211838FF
FFA29B999C92A5A7AD9C97A288A39B829A9AAE8D00008A92969D919395AC9E9BA4A09781
ACA2988996A18189A596A49AA5A47F9F9383A596A19BA29FA0999C9273849995A3A57E87
A498828C8F8290928A9D75806E849C8E83928A8A948E7B8F968A9A988287AD8089947681
8A8199898D91828D8A8F8D8E7083797E69737F6476616854786462816E62537E727C718E
8E85889F9BA08CA48B9AA48B8580889984779085918A788F8887A88A8A9AA1948B8F9094
837F8491918B95868E998BA08A9E8A8A928A8B9D948693A179929B8D839F91999DA58A79
9298848C97B087A57E9973808C8D9D8D907D797A824083596D6564826F637B7777617463
7F787E827E806F566068656D8A8E8B7E8D6F686D83806D4C6D696C716F5D5D6274817E8F
82875B607F5E7B725E74808C856D7D93816F7670826B85756659727366605B6470485676
7368635C70777B7B7F767F6C61556C5A5865614E654776685D715A5B62757A7E5E5C6A6A
61687677666A816E6C566E7A7C605C5C7E61655E832E67575147564C564A4D4B3149553D
5F4A4F56676A5B62645142554F5A4D4B3539492B325C3F5B4942473B3E2A4745583F4E51
3A44445045524D3A48342D3E244D3E494C4B3036394B36613B4B5353525659513F49484E
4F574F43653E3C4840544C4D334D34442E3D163A4039464E352A2C3930462019322C431E
1F210A201F1E35FF
FF94A6927E80AEACA18B97938F8F92A09EABA27753748495A1948FA4A3A39CACA08B9A9E
878A9E8F8B9D83A1A1A4A3B19FA6B18C97948A938A8593A08FA29F8790929C8A92998687
8594897D928A8C7F878A7F7785A58A93969793948B86B28E8E888C7E829D8D7D81929684
9C7C8AA09A8680858A8E808C8F908B887F7D756D7350586D5666767B676F77766F697E7E
A489848F857F848C769D9E9E9A97A08DA6928E9B84856B8188A97A9F8C7D9888AC938780
8F98998C97909B7D96AEA2948C8697AF8C83928F87968B8C88959E9A8E7DA38C777D9783
9298949C918986757AAB606C7D8E998C7A907B75617B6D868257887D7575736C76826E66
6C766C7D857A70686F707C7B8D757A746285797878767C7A6D7374576D7D605B787C7380
87847F7C797778898A5E67756E7A7F776D618F80758C7F6A74606750756057665F4E7160
6C7C8071846A758369807A885754425A656E465769565F6A6A6687758872626679817A78
6E638274695255546C5F6067715F535E696265515D5D52556D5D4F445B4C4D5A3B534D59
3E4F4957654E4E604E5B433F6C58365F51594749363047483A3E48393F3F36512C4A3D4C
5631313C405A482D513F3C3D383C42385946355749464F5C504E4E626540585358485547
413E533C443E453547394D37383B274A47342D2E363918302D2428351F2825343A190D18
23360318302A18FF
FFB781938D92A9A48582948B7E909A8D99B6949890A39DA09E8DA090968D9FA39D989495
8FA4A198938F88909CB4AA9396A89C8DA195A4AF9DA0979D99918884948788A5937B8690
7F859599958292A0928B8E94A7969E7A898B81969F8B95A684818F807C758C988D958085
7E8C877781989C7492857D7B7F7C857D7473748266615A8D71867372717061836A6B857C
789F899D8875A784897770939B9D928D7FA6A6868E84859897839A91948A6F6B8A88928D
9CA37CA09C8F968AA7928488999A9D9E8289A6A4988B9577959E9F7E7C8E848279988EA3
ADB77E938393969289806A898E8EA788A47791798B9A6E857E8683747158575C795F7665
885F70788A8A84726571727A758271837E7A686F777C686E707A767367786D6D7D728877
7069727C666C77766177846B8A83646F7E7B88787067947B68826A766A6F606C41444764
70625061678B577F558D715F5953546B5F6C6C83426865695E726E5E6B6161687262516E
6B787673746B7852513B5A5E62567351566C52415E5D5F554D62565D57605B5B515B6757
6F606751664C60525754525D46424A4E5E4E5C3D3C5156674A4C4E272E52484A42464447
3F4C444259461D4A533B424043523C493C56514D5D53504B5E51544863526149455C4D49
674839214E48493E4C4D4F5D26425238442D3B51493935234F2F3224230E3A35362B2526
3A2E2D20201E25FF
FF14AB99999F8C8995A099A996A3A2ADA79DACA67E9B909B9394898D7E90938E91919994
BEAD8B9DA89AA19F9F977CA0AD9A9D95958AA1AB91A7A67F7C899E7B7F81938D80A4748F
AB89948A84AAA799988891829B8A9C89849287879288958C92868795738D808270708C7E
B2878A9C8485A570807D89788A9E8D988C9579748B697471566D729071606C67747998AA
8B8F928688947C7B85978FA190909B928A7C889A7281917C938B949B8790908F868AA08E
8C7D8C98A186979D94A99DA99F91929A9E818B9D9EA09F8B9398A37C929896999D8CA58C
8589788D9381806C7578819B82938A928499917D8167827C6B786278726B667D768F616F
726E857474626762747A865C78848D7B718C7F7B6F695A706C7F7F7A707A77636966706B
68767C85775A65828F816D7975717A86727C6C7D6664626A6176776F5F6773725D635A5B
6C5C65648571617E55666E64635A58737873636865665C71747874836E736C5E6E706A76
777B637867606B6C666B6469656D486B78686A4F5C617A5500184B5A554C57564C4B4047
656E575C4C5F685C45534D47424245364F352452575444455B4D58513A3E4044412F2327
474736404632354B4A2A414A47555B574D4036534654585354644B3D44555C5C2F3E5E5A
4564484D4A49453B4F3D345D433840394D483B3D434232333E344A20341F2F3B0C0E251A
201D251B181E26FF
FF0093979A989E95A2B0A08593896BB09D8B9FA28EA09F81A09AA8A67CA0A582989E9494
A4A19496ACA4989497808E84A7969387968AA09C918A9C9A9B8683948F81899C8570859A
77827B89778691979CA68691828B81829390809D8B7A8892797D827C9493AB9A8D988FAA
8985797F8A836C7E897E727A839C8279867B9C817388776A6658716E6B62816B6B787692
9F8F89998C8D7A6587789F927B809F8983A994818A8E8FB48787919B96838E72799989A1
999F978F8C9784907C8F8C93948FA09B989E918F83A0809B84949B99799B94AB9F888182
8D8F9286847D827B806E8B9986928289836C939A80777477867C6C77846B816793877A75
7B8E798371777684766E8188678485837F896C5C768B6F6E6F687D7C796E6E63536B7B8F
83776670576B6783735F747F8F80927E837B7977727B7B8487686B8271685D5A554D5468
7054564E536F69665F59495B636D6040617269716B728075817180616E6C7B826B846D7C
6C6967767C646D737669785560665669676563676B5472652F3859555D48474B55354A3D
56455E5A66615C526259404D6130353B424D57455E5147536342342B4C593C414457333D
4B452D35356039404F325A434D3F3E4D634F4D405751614A513E3B494E504E3C616E4F36
4A4F445A36424E4C47545A4A2C4C464E4B5B1C4431333D3A2E3B43202F2E22210B201D04
0D230D2517002AFF
FF9EB49D8C6F9AA9A2959A8C898DA095A1AEAB9DB4A499939FA1A3AF858D93978B909784
839094A2948C9F9AA29E9799958B8EA09E8F96929795A4A1838A8B8F7D8695A382948292
968176A28291987E828B969CAD86659E88808E978B899A7B8C987F83868790819584857C
7C9A809A6C6B86797D85878B778E727983788E647E878A75766B818E90876E6F7F828EA1
A797999F80A6999A888E828B8791958F8A9A929382939C7680798C96748A799CA49D9A82
798C818C9E8192848C93B1937F8FB082979E88A09892988E9E909596988875789BAA968E
9B8C8A7D7C768C978D7A7C7DA189818B869994827A808D788176847A768F7E6981758686
8970817B7F727073786D807D86727876717277746E7087727F7A85757F836D4E77728581
778C7D6E736A8C73878F7E6D857D6F867286947A6F748C796C77706570697B6B6C535660
553F6740536846616F64406640426078625E6B6959686C405E867C7A7B857467716E6E5E
7D6760647B715D604E485C637766665C4F64875157625A68436045553F635E5359686C64
4E2F56586F4655604D5450544E5F55544B665D4F4C5354353D3B2C3A413C4F4746354947
2F453F474D454E3E4E224F5443615346433F2F56485A5C7466605E7151573E3A483A595D
394A464A564D463C485248323C4B37332A22442C384947403A2331382E4000210F000912
32332401171609FF
FFAD949F8BAD9A9793A5AA998F97909684989F8D90AD9E96A8A0988EAD86A5A2ABA98DA5
A0A89D9B82A99C9C958496B39B9B829DA4979EA692888D767D81AB94947F918199928685
8A6D8D9984A37E848A868B8C807896AFC8908F8D877C8594808C8093709374868894958B
99918877858F72658E726F887C7090828F7D83758389898578788A7F8F9A9B7D858F9795
7C838D93A3828F9CA492948C9A969293877A9A929287878C838776897896988C868AB5A9
AE99968E82859D9D8B9392A58294A0A5849C949F849BB0AC988F93878B8A9A828D71A097
838678756F7F87839484839D7FA49F807E8B868F90836E816873968A786B747B64646E6C
86777B88716E7A64668860758D7874598B6F6B576C72777F666F637277627F6D736C6578
8577576B7A867F74947C6281808B92718B9D706775857E7A7D96708D7C76576964635339
5F5C3C37474F5E4D3E1F4E42423B596E79784A5E596A756C5F756583877E63654D616956
66726E7E645A5A4C6A5C585D5E65656B67725A70675E543F4C4F525D696C5C505C595A74
6F2B3554526F3E5239445166592C3752786944475B43464A57504347363D3A29432A3A51
4D2C4A515251465F4C463F33414C4C57384245616A4F583E5B58524C624F3F445A4F3B47
4D4F50544D44464E434F4054513A45404146454E4757382E1A473A1E1813242C1D000F1C
161A25323C3616FF
FFA5A49E80939FA0A29B91899EA686A19CA0B2A28CA096A3A092AB9D999D8D95A68FB4A1
A1B0918E929B9B86988C809C9C969284889889918697875D879B7D858E8598A0848A878B
90807C6B66748AA08D7D91766878B3A6AB7A8090708597928D798A857A8384897C7B938D
9A85899288828988738C907B7F7E778880697D9A898AA19C8B79839898806F9B8D898A90
8583868E7D71767F93929D98A07D819A827F8E93A184978E788D8B98928B7998888C86A5
A9A491ADA79D7F839995979AA0A8A6789AAB8EA6879B9A7C9EA08B9695818C7F9E9893A2
858794889C8F7F888E837AA5929F86779B868195978E7C8E8B9F63868878858590848684
8C84615B7193716C82807875857D7E787F6B71726E6B6E87876B7E80687973724F6C6C72
757F897B94776A7C86A9858A9E818E6D7463787F7A7F7F91828080608B7E726F6F666B68
6143624A345C495E4D484F585A645F686882786A846A49697D868777737C767E7168765C
757173787C60635D5D52495B5E61757860735E6F447056475660595F5A57695B5443555A
635B6C4C45524E594C3E5068435D5558664A65545A3F3F4D365E534C5D504F44313A453C
5132404534426331383D4550423956623E484552655053604C4E484939414A47446B5647
515F5139453B4956473D4A49373946291A2E32403145453133362827193C15261E251C20
0400181B191C10FF
FFB19C9F97948E9CB0AE9AA5A39BA690A8A09BAC869197879D89999C9E81A27D8D8FA790
9595A9A29E93A59C83A69BA5939E95A1B3797E95856E7D8F89879672807F847E72697997
84818B9088807B7B8B7AA9A0798657748B8D857E987D6C6A80847A86997D8D838B7D8F7F
8478786A6C767B62427A7880848C64868682737E7F919A7F789688898D819B856B7F7672
6C857352706E8B705B737F7A878690858A8490907D9B9D916885999193909B8E9F88999F
95AA9E9B9D919D87808699B8AF8D9D9FA3938C7AA090969984918592798B929195858A89
748E6D788F8E9A957D82387584A29B928281898B69939994886E6D887F8A648E765B626B
8C976F7396586A626C81648D5C6C6186898B8B6773747C5365717B707F8F7B6A4F646781
8874737677867D7C8E878A657C9B847F77807F728B77868B8581887A6B78756C72605C63
614A644E56466B525D3334434D515953766D6A70635C63618874856B7F727F7277616B6A
73845C74687F6A52696D6A536156646455687567613E5E5258665A564F5D675E5A6C3E5D
465C555E424F4A4F505B4D344A524C64453841495560593B414C622F4033415B43523953
34434D565D5E3B52394C56495A4F6048525C584856494F5564425B4B504A545675404F5D
5C3B5F483B4453384A55404144363B52423B2E463E313F423C33411E3D13201F1D24280E
0C1F213C2D2934FF
FF9CAA929D9494A094A592B7A89AA483A3AEA986A48F96B28C7B9C828B938D9F918AA097
9EA58C7D8E94A791A594A8A0A69AB9928392A491859A8A768B877F9E958E9D8C787BAB87
A37F97908975788F7C8B94809B858691697B8B898292848F7F7A9B93938F8773657E818A
7A836C90788F727F7E757B70699197727A7F7582834F704E77686F717B63767A6C705F54
636C626560676082718269778AAA8D8F7C8A899A807F837D99988686838A9F938E92A6A8
BE92899BAEA2A29AA58EAB978AA1AA8786769A9BA79981A679829BA29D8B9B9099928C8F
988281996F95AAA19A630072837C928B7C907F74888476907A858F7C818D807F84737584
787E65836B7A87648467778C7A7D666D7A76777C747A76756E7F80747E7C887A79596E87
687873817F8799887D808D818C7879817F636F786D6F837A768A888D87898970836E7C61
744F59625A5757543B5D3760544F5965635C6E6556697A655F767674726A837C6B7B6A75
53706D6D6F6444625F625F716048715F6F53564E57585B5167584E5E5E4D5B4F5E6C6950
41353C455454566C534C5464346136534E574B586858545E5D433D4651495948464E593F
4B423B382E573F42483E56525F3E555D4A555147605D59674D5D5861565E4B5657565E53
51554A4A4E60465C5F54513C3E51373E2D3E37232B2C483D2A371E1F1C19361B230E1107
243C1B31372037FF
FFA598A6B2A5AA9DA4A19E9790B2A999A5AFB6A0A09B989C98A5ACA79B7C948D8D8A87B4
9980958C9899769B929C9EA08B848AA79FA6858E90939E9C858E848C878A859D9394929A
9284747D998A7897898B8A7C9CA4929786639A709787866C8584776B8E7C999D7A79757D
867580877A817871765B5278756E7E6B967B70817063737E77827C77605D77715A48423A
54425B53484C614455606685818A968B7F8287847C9A8599859A867A93919DAA9D87A19D
909888869B8D9EB1939C6E859D9D8895958F937D7A7E938E8289848B8B9E80889A738572
7AA0BA969D967D82856F62939A976C8A95889B876D978C798A878E88788777728E8C7579
88798784755E75818C807A6D6D6F6A6E787D736368787C77876681817177766076826172
6C82868087898A7378887E9D768D77788588857D788C81798D8F9385916E70797F896A7E
7064636142565A3B4C5B3D5E63546069686C7265567D6F7B776E646B70656678856B6282
6C515D5A74795A646B61675041536A685D445E4B5D57554D5A645A626958615E685B4B4E
4A4A623B5B4849435E454647674A3B4C51525D53553E4F554D2E555A3C443A3F3D564B4A
424D5646544D5841495E533D5E5A51596253684D556E7D506061524A64494C655E5B6257
3A504F5448313D514C403F4432423E3D4C2D34393828474F3B2E2D211F371F13131D271E
36263B3B072C42FF
FF999AA68A948D92AA96A992939B959D8A908A9A988CB4A890967F83A19F85A390888E83
9C8BA99D85768D9784948AA98B8DA78CA5848F7B80847C908A99A18373808A8B909A8273
7DA19D75888C7E87818F888A999E8C6F8C84968B9A9C8A7D7972786B78838A8294778481
7E68707F83608B77737B7D7F6D5F9081726F6171948A7E6C75846E64584C684C44232D33
181C2140393839475157626A74728E74998F888380897B6D948F9D9AA28C809889A39B95
9A869593A1919185A29D9A867AAAB29F9889A18E978B84B088848A8994819A86788D8491
9F8B9A9B838189A079758784997D8D6E797F9474868C8EA4978D8D92AE8B898D8A83836E
7583759181627772778D736D4F707696787479698F859380787B6E776F787F6F6F5F4E7F
7D555A696574567A7A7C8E857E8E867D756C7C848E867F8B88908899827B7E8B7E7F767F
656F6053646E666B6470535B596377626D61646A63495D6365777091846F607D6B696073
7C615D6D607F74654570576E736B637162625E654E584F4E3E426E5E57546465575C444E
6F5C553944355E6847696154474F4B585E534955654A3F5A3941414A533A3F453F425133
5C2C464B57423B64663F5F563D624659624E43444A4E54594A605646516A435A4E4A3A4A
50445358563A2E33382F354251363D3E433E1A3C244E3A403A31262A28281C1818322126
151D282929182AFF
FFB49FA6AFADA58E8AB5979090B1A9A0ADA4A388799D8A9391878A8C8C9A958B817C8793
87A086999586747D7EA7A1A09B9DA69B7F7F6C8C99958382939D838B9B88768FA1808C83
7A868875938695857E7AA1766C87887C7A927C7C8283808A8072897F80889E7F877C8065
8C5164877D7C6289867B8784778D7D7D74896B826F766F75626483694A5A423A1D030307
04000408170B162E2F364B516B727C8E949A918F81808D86AA838A8D94A09EA28FA394A0
A68C879CA1A38D9697969CA3A08493878E9E728BA07E7A7077857E7B859979987973AA9A
9D7A858F797C51727A76777E9A90878887889B91717E89928A9B9F8E9599979F75758D72
7A5C7C7175837A858472788176837A7B88736F82878E6A717C816F696F744975576E9B7F
8E5C7D6B5C7077716D5E7B6F6F6E5F6B93937F898E848EA0708D8872737A827C706F7F75
7B677863774F666B6D6B44715F6C755F656B5272667367745C6A6C5D525C8E7265726F7B
70837770746870706E5C8067777571655E70616243545D585859515256575A546862674C
3D634E5A4741544C5C47453A57494F3E3F48412D41504A4B4D653F493D394C4A72594357
484148584D414E4555465A465A52395D414A5B69563F465F5D504A3F5253766A60584749
5A4C4845423F46372B5059583E472A2C243A2E4A341C3E344C1322261F260A1E28362734
372D123233322EFF
FFA08D90A0A59294918A8A95A69F8A9F96978A938B9990898A8CB4A283ACA9A79F8B8A91
84AF9E8A9B8B9891AA9D7FA1899298917F716D7F8F95A2897D89858D7485997F7F918668
7E9B96826A94837C8D8D7E668D99847B7E766F9D8A8083758A868A837D8490606E738A7A
71799A7F6F847E798081777A88878C8977606F8570638063617C685E58344D1713240000
00000001000000101625254C4751787B928D626C9E9F9AAB868183949291AC9B99A6AC9B
977AA1968692AEA5989D9F99858AA89B8683978E99976B8C8DA38D93909A8D8A82847A7B
85807A80657B3C586D696F8186A3978DA79E878AA28A868E9D8985A18372988FAB907A85
897E756C6A7C887C7B7D7E4B6B7C727372796D7E8187827D756E7E6D8680906676828C7F
6F6F6E7D627D7C69616B5A547E7F706D86707981727073798D6E856B67616A77796B7F6D
72776A7B576377755B79777F626B77746A69877D60757771617678598762646184757E61
6C7C746D7D656C5B64685A4E565A6C59545C62656656705D376A5C5B68625B6F4B624F43
2F574D5E5F2D516B575D4E5C47445E4E51444845484E4645525A5A3F5F5C4F4A3A54593F
54544A55524D4A564846414328424B45404A645F62584F55615737515F4B3B604A49616C
63623F425D4B37414757504B393233351B323C1C3F2C1930260927260D26251A352B0531
251D342C25222FFF
FF9198A7A590A9AA95B39D93929792AD99A0B8839D9D8692848391807F9BAD819688826F
816C82917F87AD9E987F977EA6A9A099A3A08B8A9A8D6892A691919E927E87987C9C8698
9D8E7C8D94819F78708A829175788995837B748098968F8875799E86828071726972737C
8C798482777C7A758B8A717E76706B847E6171706F64745B74674968503C301509000000
0000000000000000040410183B446674708C85868297897D929B829F928A739B927A8988
829F94A7928F8095A2A59ABA82A4A38791A396859B88968D8381907D889993889F988C5B
8F72817E7F7C87836D6E667590738086858A88897C949B8E8A84A69D959D648D8A7A6A5A
787D69926C83A37F88807F7D80858086879A816C7987756F7A8D86934F7E73636F586F8A
75614C867E818773838C6E6861697B72865E7B7875826C7B72707E919B846D655681937D
7165646B6C7379795C5F4F806E665C4D5A5B62514E5C706F7073618967656D6D707A6978
5D5E696B666D756E725468646F68668166604C5061524E67585E566E5F5C6A57384B695C
5D4D625A605E4C5E615C4A5E5C393B463D6660564E5057535F5E464A34383B523C3F5443
374B414136604C4C4E593F404F4841474F56416C543E5F5E394D3C6C4E535B4F3C625F44
3E305A536651504453513440463B3C33332426251F37212D32050B200D1026281E1A352B
33203E3D11311CFF
FFAF9EB89FB0AC8C8C76969E95A1AC98B4A6A0AFA5879787859A8185789E99A19F859287
7A8285829392947585778089859C888B9284837576797995819387908893958C9C7E8F91
638894837679698787767183807B838A92969F856E8C9091736F8B8A7F85847D7B788A85
61817374747D88828A7D82739B8A72786C758569576469717A706F5F5134220800000000
0000000000000000060D10002B6466746E9091A38679AA817C90858A9A878F8A8796A583
898290AF99A0919F929089938C8E929EA979A2909497869184898DB6A67F938B9898605C
768A857D7873707A6F717B6E8073809A838B887A8089807D85929F958F879C77917D6F68
8586737A82885B7F75998E7A79847E70778475778A847C8E74857238818190857575896C
6875737D816C986E70737F727390739B7B9872957F6565778885756F725E627E8774716D
7F8277655C696E74856A817E705F5B6D6C5E687C61686B8176686A7A696B6E7673716379
7979826257687A6472556063757169635F6757505C635B5545867369715A5E63785C5563
505F665A664E4F655E57364E44485A494E535A685D56504241395549302B54523E565048
4B47606135415541554F4D4641564C3A41634D4A534F50545D5658564F544C5156424F3C
245D3F54374839484A4D54424B3E3B1E323020423C172A29243D1C2D212C191414352D2E
332D432F153335FF
FF9C9C88A6AEA99C9F9A8B8A8D90909CA1BAA9A0B0B0968A99869F918480829185946F96
88959E916B6A8A8A958595989E977E8B6C76729D909F99837992898D7E7E96767E877C7B
968192708B948D988B676B8380607F7F8F8172847E8272809283856D7A7268707B667287
756C79868A7C7F766F666C7971857E80827E757472737B7578686E4A6433160000000000
00000000000000000000000000143263607C8A9093899479689B93899FAF9F9990879EA5
8A7BA2ADA4848DAB9F9F9BB18E927F98978B86937488848599898C9A9E9F9890918B8260
83796D6F8C87827D70557175627F7C968987838E9297A2759F9A957E917F8C7F877D658E
7278606C737279835F8A787A7E76808A7372421B7887847485607D637A72878274746783
62738983747A63737375737F7196777E7F78698A88707679828B7A666E6B6B7063666D6C
7F6D72697164677A5E6E728185767B6255716C71685B5C617D7E657F75836E617566664A
5C63696B5765777861767065655E5F69734F6D6877597261705265546E615F6B6566647C
606E515B515160695E525B3843454842432B57453D445F4A44575338544C525740424E40
33364138504B453E3C3F40434E605F7254445A4F4C5C535740374B6459535A4B4C364E36
48434753353442334F51394330433A471F1F3A31362D2D1D24382E271F192B0B1026331A
002D341E2F1D35FF
FFA898929D9C89928B958B948D8C7778A18892959F9E978E939889A593988B926F8B7B7E
8E82A1769A717984876F69858A757E937B887F97838F808B8791979590779C96867A7874
777C88908A928B8B87785F83827C8090958975A26390A08977887F6F878D838C8084797B
75787B5E728A6E5E74957A727F86757F6164717460517A807A7E4A253F1A110700000000
0000000000000000000000020905255B6C7795998F898B7A848E838C868083818A99A1A4
829C9692AB8E82959DA590AA948E969299928B94957A858D92A48E9796A28A77807E6E78
846E4E89859A80737F907C8A808A8985898C8473628D8A85848B8C947D847F8A93868985
898974758F85868A86758B727C75787B838B0D00407872737F857E7F707A93856A865472
7B8B6E8B95686C64797B88826E727A847B8A7E837674678788797E7A7568797768838768
63876A78545B615E7B91767A567360657269615C665D6C645A5C7D7A8471756C736C7D57
775F5972727240575D675B77607558635F615F554E5A684F505D5563595E53564C53413C
6A5757655B43555768503243525159574A3A395F4440465A585253514A4E41454C3D4744
59503A37564C5B56483C00005E5E514F4D4C4D7153485357454A324E3D4451584751344A
3C53394A655E5C3E3A325D1E2D302C2F50231E1A3639352423182E1D1F06222315292412
2A383941292420FF
FF978D97918A9C79747773667488758379A093A0888E9AAE8D9F7A897FA3AF978092888C
8CA0889291868093827980878D806D89A3857D86937F8F8B748479938A898C8972908F9B
8E918B9393937C7C8C7E7F88757F858879778494817661838284828975769A84777C8C82
756971696D7F7E707077857A707D6D60757776668068637A7B6A52463F1A000000000000
000002020708000000000000001819416286989699868F7A93A28E969FACA4A3A9828279
8B91919981727C899F808F938A95A09A8BA57C8A969B95A28B83A2979191867C8F908370
726786787F7279898067646C968E7478928C94817C7A798A759B98768B83908B8A867B7D
70748582628086858288736C8B8A81758E75605A6D756F866F768B8891997B937779765C
7F6285838574758082745E658D81918D7D75967B907562756C717C71867B76736F72715D
61897982777967776B707763687D7C726F76757E5E84716B7D68665F62776C755D557062
647A69757B85756E5D505B61696268725F7C55666675526A5D6269675C605B5C61624867
78575E5657295C6145433C574A5A596C3E4E433F35634E425432424D4853704746424B46
424F463D46475557575413185C4C475F4A4F5231555565504B75574464563C3E3D4C2E3F
393D43425042364248473D352B3F3B483D4138413D2A2E3119221D26181D1E1017250F34
40222328283718FF
FFA39E706E73786B6F56777B7C6768808F9289879FA89F9C738A8C84A38E8998878D8E8D
88847D919A7D7C89818F887C89936B9C889A688E8D8393907D949793A9928A9791AF9D81
79858A7A8E8A84819B817B728A89829A7C8A6A888D6B668D7F7A7E7E6C865F718B717A6B
71807D767A6D606E75818A77678E76647F71848B70758C6D716964212200000000000000
110000151D090000000000000000222E4262799E9390889E9B969DB29186827E8F88918F
6D9E8A8AA5937E7E927A878498A57F8F91918B8682838896977D8A91A2877B87767A7B6C
75808F8F81647D8C9A84936D798D87517D878294948F8F7377878F918A968689788B7169
6B76797B787A788E887368827159807766947B7E7D846979656C7086746E816F767A7E73
9A7C7E867E7B7677778C747388997A8575866D7B8B7B7860737361687869976D64636D78
814C6A6882796E767459546D83746A72605A796F727055857A674C60546E57747C73726C
5858627361545E506C655E55685D57646A5C724E627E785371606264625E5E6E6A54695D
4E5C4F565F45564F4F4B435F3C3C4A522E323E4E4850425B3F69554554403E4D472F3C42
6256485D395038594253595F64564E534C4F4E5E4D49515B5F50505258545757434D353D
3B384E4E433153452E375951183142353F382B21294234353E1B2825040D1D26232D260D
1F1735222A2230FF
FFB1917C7A67797787756B75908B6E7271797F9288929C9A848A9D857F9C848C9C93879C
79768C9290908B797A868A957C9C7E8B898E9D8589A194929B8E7D5A758A8D8B76819087
819A84766F8A8293927F6E8E83808F756F737B81896886787B838685857A727E817A8181
85736E66596E7E81857C77757D7679837C6D64615A705360626659281D04000000000000
0B2A2F29323B1D00000000000000012A455B7F8892909A7F7073A8899C90919D8D989186
A9818D8892A1AD959294907F797F9DA48C96AEAF7990748F9D988F9B9F929E7A6A827869
755F7D958B8A8F858C7F918681707382756E7A8B8E868C79908D9B788F84707786847D76
786F67847B856F74767C7E8A7C906871658D51777A95757B627472667460868E6A776982
7667757C78826D8178676C70828B6473756A7578785C75876573696B7F75648F82816273
757B7A6F6970708467577F777E6C706D6868686D79646C6F6C705E64595B7E796D634F5A
6871697D5F546D4C4A73646D5867727C7B5761656261626F5A6E5A736274616153685C58
52605A635B454E495D4155654F59454437474E575454434F415D4D333D48322D48303344
534E47505C5066494E4B43584E4A5F5B4D585C5962584C733655485E605E4B5654464D3D
424251315136174F3F4A445A3541334C2F35342541133835352728310E181702101D0330
3F2B1F2F2F291FFF
FF9199875C87827F8387747E8899788F8E73738784957D8C8D96A59B7F82808971896187
98829AA77B989A809B8375777E6F7B8791829EA1809D80909793A5958C92A0B282838593
7E908F96A16F98798A91808B898283888E9271728E77838A9687A08070778E8B7381877F
7D9689877E897F8765929681889E81817C8560637572475E835F44311A00000000000009
24253B3D33303313070000000000002C54636C7E789F828B7A888E9693A994858FA49682
8F9A868B8B7E7B988B92796E6D928891998BA48AA9A49C7F94A48FA1899A9A9C855D7A74
577C8A866F808E8A7EAA9B817E8269657D6A9CA07A857673799882747AA77E836E7C687A
795575788A92756A7B88797E6D7F86706F858A8EA0926C66788B8B7E6E738784817B8180
768F797A795C836A8D7A6D79766E789771638178757C6B6F947B78907976808A7B7E617E
91707C876D696876706C56784942605D75766876645D6F6B6A78685C536B676B6C715A59
6770866B615F7B70626172625A6A5263677C697159605766746152326A4B7D56645C8179
55516D68796364594748524F4E3F45535D314F4147474B492C3A524644454E564F413648
464B5346496C4931565E43624F393D4E464D53565A5160465D2648434F554A4642443539
36433C5D2B492734373440273F352C36454D32312E2936291B4145461838232409142610
132124390D1E26FF
FF7D8F7389698F82819A929A8D907985817D656A828495A08D8C96A293978A9A82719477
717F697585878A8A8989858B80807B92907577877F9CB9939B8F8B8F97838A8B8C81857B
A1637F81739476838F78897B819786798974716F6477888F87817885938B807E93884E73
87808D827382878C81637D788B928B6B6F5075737750616B6F6F4D3A0900000000000000
2A2C50475339412D25000000000000194060717390877C8E8384847F806D8288938D7477
8FA291879B9280668793948A749C9E9CA0927D809494A096A091A28294899F878E756574
6E76718489907E888F957683706E7B6C7B6698887C827F8795887B7F7F75757F847B7484
8A5C999862787A7F7D9076777B8D7D767F7D897683818084787C937F75917C7E867F7D6F
73778579808479766C6874556B898D7374746C7C8284818078827480727A7C6E79705E5F
64627A79855F66737C7C7266776E656266546F61674C6C5F7B59717069716F76666F636D
616F5F5E617559606B53776264677C696D74787E6C7778796979756E546E51546E5B666A
616041616253585749525C64675E564956544E384E5A444A46533D4A4D53475340214245
424B4259474D3453563B51575A5249456D4D5343665F475A5A4D425746474C584647523E
3C463A395442424A414130214A3E474046293A1B35373A2817323F3C1F2C3A260F15312B
2B25161C23271FFF
FF7F7C75636E907D869583A188A8898D68676D7B7C6D979FA27D8C82728D9781937A6A7A
706F6D5C6886857C7B77829BA08E8983968F8B8FA88787A0939398929C9CA4957F88A18A
897E838A7F876D7488896C8379807B8986837E6F788B7195848877887282827A7A719291
8A87756E656A73747D8268766C8086727C62805669837E8A665B35240900000000000013
2A3E595360584F2718000000000000223466828A94808694839381878E89A08399998B7D
9EA06F849990999BA0837F7D807E8F918FAD9499A5979997888DA89A9DA0889C8A8C6265
78648D789D95877E817D8A7B887C788C788C8579908B6F7376598472777F6E8D7D867767
7C8E7F6A7F726D88A06D707A918C828870808476767C6F937259888577797D827C858A8F
68826E797C8184766E74646C69747E77707980758C85877784797A6D6D6A908783827B6A
60655961728C7275839267667781637A845F556E69666D79726E656F5F5A75598D6F7254
73514365536747585B50547B6972656E595A6664646E5F6276643C595B65506C625C634D
4941563B526D6A605C4153695D4F5559695352583B423B3442463A3D5B4B364438463433
3E3F394D65584548566350444F444C564E6D4D65604E445B4A3B63564C56444842483C46
39252B36314A3B2F2E3D3730482932133E304C481F341F3B322B2834464531171C2A2727
2213121117271CFF
FF8C7683887C81A39AA49986A59B91969675857B7B7F6F837DA69592909972808B846C5D
767B6A7D5F466D838091A08CA38A8D898799947E92958C96977B8B8C7C87877D87908A90
77849D7D8B9D7C8A79808593808178797474737E8B928A85838B937A537F7244747C8783
82678D827174708C80897C7A777B737A7772797D6A5D7C6377532E0E0000000000000008
3F5D664E4D5742200B0000000000001339535D858898978FA08C866D9B8B8D819996A19F
8481795788909C8B798A7C848083928BA49A7E9395A3858BA69E8A7E7C8EAF8889836881
7B607C7E6C989E8875839A897B8A99758E7E7A9A91748D77766C6978626E808B7F6B8C95
99797E7D696976877A6C917975798C818B72928A948C8D804159686575707F7054787987
77777673707C737A7A8075727B87718374807F7A687E636275837B6E7287758D6D677179
85776669736C6B71817E5F796F6F5F6E7486716F646A536D7263615C78696E73776D6D6C
8368875E5A675164835A5875676B6F797267516567655F6B555666566A7A4C5E4F3D5853
62474C595D50544D4D4B5C464C3B544255605054453E4C5A5938565261414E3250484E58
3E4137554E5A555B41535F4C5F62503F64685E464B6E4C423D4B5C464F52605B5753472F
2A534D3C2C3F334D4134474B3F311F3532533324351A30363D30232E2E362D1A23191F2F
24320B0E0B073EFF
FF7F957D787B7282A19494A397AAB78A797C7C90877D6789967D8B8B88918D80937A6C63
5B696F6D51706A7B6E8A6D927E878F7E84878C939C86707A9C9891A2938C87848D8D8F6B
869583957F857B7F908499609B817C738573808486878286857C8B7E81777164787F7B73
73707F688B71797086A06181758C728B72735C57757162765B5022080000000000000000
343A4A4E5E533C2C2C000000000000264B59588E989671948F8C9293838C7880648B8395
9394938DA3A3919194A28675877F8B938C92A178758C959C8699928D8986738C7A8E6C63
6379896F8A88868E8D898277527A83AA888FA07F938D7C8E7F8D87798D8F8866898C9285
626969727571727B87936B84797F7E8168846C657B6C846A6C865B6F8C83897C80686C7E
85816B7A87786F577A6B7A8B88758A8781776E9B796F8B87696472658D75876F75637E79
6A69787160845F71775965757B8576636E606F8D574B684E74707557567B60535C5D6174
675D4D696A645962705C5A6260656E587C86715967636470735579707B5D7061685D5159
5C4C55523C605C544E443F5651433C525C514A5D5644503C474C37564D61425F455E402C
42443E4446474A554538455D474E4E5854595E4B655F615D655F4B462F63494946393D33
463D37324C355D403E2431383248283D363A45402034212131373D342C2D201A251E1B24
1C1E1D1828222BFF
FF84667A797565969494A991B09893A486795C797599778E75918B9C9B829A81626A6A5D
6066666C7680717D716A7D9A6C7B8890817C73698998A28D776D6D999782888C8386939C
868471967F7B927380847F85729693776D87607C697682857773815A7E8270535E898573
7D73676271777E76856A73787D686E897B626866695B607F565A2B050000000000000011
0D404F38563846350C000000000000282B6F6E6E829789858B799D8E9D818F8C787D7D8E
A798888B809594759289A98D869088777E927695959E938082859C8A8C8699808DA07C6E
8A6B697076896D7580717E717E7B716B8B8686A182858D8271926F65837E7E678A8A8D93
8479716A5B8E7E80827C8E8A8496747B766B77606F83907D756E80798C746C6F5F6E8B73
718D7F8E877B6B88827C6C6C746E756E8A698C858B85958271695484706A7E8A6C66776A
8A84706F6B798365768B735F5A5989564B69686058595F61647D7E705058585B56626089
61555C66776361655D706B51687A595D5E574E5172636B634F594866637D636D5D41675B
595B6659404A473C4A4D6744512E444F405A515B465C574F5F463E4E5F555F5A574C3F47
4B263A565E4F5A4D5569505B60425F385A6D48445E605B524751514447472F4240545632
414D2D3E424B5045394C3F302D445633314B3F2246232C4840303541391F38353F362E24
32281C220A121DFF
FF826650805F8684928C97B19C97A390927C605F75788393A99C7F8C98947F7C6B75675F
7E6E766368808360685E7465718692878A9F78888783828C7FA67994747A7F8B8D8A848A
8C807A81848B91868990917C6E7B82797B70627E76906F7C7E7D8C7C8191467E81857B85
6F7B82867C7A638A8290837E8E8A7B72847986916E646E66665628060000000000000000
272E2356453339100000000000000D1C4D6B859A969D90989089739598A78F7C7D868188
8A7E6B8D968F989F9B9E9687AC8A94766880897C807D9080887E81816D978AA1A4867D8A
777C7B756E817A7F6C6F7E7D85806D949C958EA37673748D958375737C8A6C979B988A93
5F7E695E75757A7E798E7A73826F898689856E76887A787298828A7F82836A7484917379
6B857C666A656F70765B6F6D7A79877A9579756D856A7A5B74617A6A6B698B777052636D
796A787A8574757C8D7E646175586D666B7A5F5947604F7980786E676E6A5A605C6F7381
61726E646D68775B63595C68585C6453656361785F735F6641665F716F607165485E645A
614543584B525F5A4D5749425F365856685E436D54324E454F5E58746057596169525D5D
4A533A4C57473763524852554B51435B635D505C544D47745E575349403C4C474D5D2C38
483C504B413A28302945453C37352737374B2F3425422A2A3641271B33312B1D3E2D291D
2E40283611272EFF
FF886C6F406776808FA6A2A79C8D89727F685270817F8498A88D967D82867D857F58766B
80694F6D888374756370847D8469688E8C8997887686919E99818A83888C8B6A69838381
9D7F94827D8A8A968691818D6F747673804F6C938B6C6E797F758E877E646E8783707393
716670777F887A6775776E63768B6A64695F727A7A717C94784B29110000000000000000
000A151F162F270105000000000000264D5F86899685909694897C81857887616B908482
969F969193807D779981989B888089758DA48B8274807F7A867E77937E63857E757D7E85
78718F6F76627F7979737F7E8586967F92979C7A88748985829B79859090737B80767381
67647D63777B765B8576765F7B647489806B6A9367628E829971727B85897C728675746D
8E8B848A735F74895D795D617A89646A75856C79806A69606A63737376737C6C76816B75
6F7F72606D6D65665D6E68767572677C79545C7355717B606258806C5D506B636368835D
63696D745D5F6461717555665A4F74787C5E59566F67605B6874697D4E6074687976583D
436F705E5E6256464B50554A5A535A5A5D5376534E2F506A374F6358524D473854665151
4C53644A435C663E424043524B3A456B4A5958645C3F4C5E674D4735504C495641292840
3F38432C453D43623F49483B393E3236274835343F4B2F3222362B0F26322F232231341E
2E213A2B2E112EFF
FF8F875B6D706E758C877C837C9D77666E8477776E92A99A9384819E8A756F836784737C
6F8172749A8186646B6B746E66766F87847F89947E96857C7D8FA49E768B5B698F8B8895
9A8A9696636E8778838593838E9486747A85756B6E727F70778D79638160655E6E616B6D
89967C7D78928D876D855F877DA8918F848A6763826B5720534E3C080000000000000000
00070020040000000000000000000B3C60728B758991877C878A8C969C8E9D8380887A9C
97888A7F7B7A75878A87688089998F95767A938184738A88A287908B8277818578839691
8F7D706D6C806C74716D8282988A818D85858A90908A9E80868D9F85799A9172688A7784
7890868E877B87838A906F7D8D8F716F64647D8B83817C8A7480737F7A547C86758F9781
747464708A73656C717F698C6E7A7577858B65717B8374877B75807F77616A6F61687973
6A4C7375707379727F6078917A6B6C546A69736C7661745C5566608360756C6E726D6D6E
79425E6F6E68744D675D734B65624C777B72716A8A63696D7C61545F64595A6756747500
32695D5C6B384A415B3844656B6B47646153605761505747615F6152514348584F524C43
3B3B5A474A464C664A585B5E5651555C6B5E554E605E4D4E554D46594A644544513C264B
4934413E5963531D3D41382F34483B344E3B45422037282C2922401B2721402F2A271636
422D3A24362826FF
FF8D83827571757A937A6B717351717C665F7D898B8293909089819E85856C7F646F7777
768488706F76737A936F59727A748880898086868D849DA38D9C845D92B17C82889B6D6F
7489727A7A827F986F727D6A78876A658E9D8E7085777A7683716C7566766F607B867374
8B9991757B7E81688B7E746C667B8283797D837D70904F0064612D0F0000000000000000
0000000000080600000000000000263A4B719187869B657F8C8B878A86746088825E707C
7C8079877E7A72897C878D9E939195907F8B717F8A80758A7B948AA28D908C8D9C8C6A7D
7F817988727C687E766D7B948AA8988694887C8D928D6C8C8F99878E8594839290907C8B
7996827F87736B6E9090A3877F7F65677B767B427F8A826D7E7989758071655D72725D6D
7392898A767E71858E776882776870677F717A876B617C767377756463706573636E6F65
6870676867898265716479738777677D6271597B77676E7574737F685B538046645D575B
635A59535E5C74625D5052896C6877576D6C626F635C62717D656C6C5D61476067535160
5A4D516B4B6A655F5D4A3F733F3D6A70574E705F60453039453F42486760455A69573641
11445444404F4948585644414D65456E606B5D525852564D3B525A4E50534C46444F3E5A
4C333B393540334C51542C2B3940433E463529454A423031422D4026222E1D322B351F24
2826110F37303BFF
FF967E726A6C566A607C6A73727A676D796A717F91A08F977DA2927E7F7B685E7D637874
6D888291758E8A7F8085675F7760716D7D848989807D85A592848C957A70809A84938874
7E7F887D9B9D80708E7B737E93909288716472657A7A93987471778A81637C697C6C6E74
85828187826B859F6A5F767E739B7195898E948A7679807D755237300000000000000000
00000000000000000000000000163459768171617A848693878B927E848D9F83847989A6
9A8D829BA5777C787F7C7D9CA1938B8A8F8A8E82877B81789E8E80A090975D6E8F80858D
9096A79A818E9E9277958C968A8674839599919C96957C867D7F947B708284767C767F84
6C78837972737F85799F81847D837C8086846B616C6B7A99885873777C95947870785F57
776B7F7E759376726C71618074807C7C8F7C687D596776747D75686A76614C4C6E80796C
7E676B7473677580666D638D79774D666D787661565B576A867A757074666F705B5E5C67
7B676D695B605474565E724C5D6A68688D687362636F586D565A5B6D767871665D574B4E
555E43555A6D6071736C4F645B5B686C7E747F77597056483B626539374A31574A515C3D
322A4355545C415D4F62593B41525D3961492852576461605C60554F483A2F2E4A3E4F3D
484B4A4F53463E454946312C0B1A343F431A462F2335294742492B422E2F262C39302339
2B32391E0E0F27FF
FF88806E5D6E8172697383665E6A62706F6B84747A6D9B989FA184848B6379545D689788
778A81978784938A7372826469696E8C88668F83899B758FA18B889681638982757A7081
867D889386898A817076807664888B877E698E7C6E4B6F7288766E698261578B64826572
726C736E82647F4F7691817D77778A6E78859287588B7E8582775F3C1D01000000000000
000000000C0000000000000410214D5D67958F8F847E97826180788A777D8C98769A9080
71897E918E9394838874968C8C859A9492748F86818E8A749495818A737F9B927E738C7F
838292988D817B819B7586949BA49B96888085829A76799E929D876E776F7C837B8F8B9B
806D7692858978767A6D6E808A67678D8F7F6F8580887077868A82796C866E69756E6B6C
616070798376736B68857583837275727F7488736B6C75607B6A66746960766F616E8558
65856B6F80786C6F8780776879757D6F5E676F74795B74794A6D6B696B65556967555776
7175537578597D7A745D646F6468696A63515A5460556871665D6B5D616D556652715A68
5D4D5D4954584F4D655F6C3F5C555B6A5D687C855C4A5135434142613F33455251383A40
58574B667153574E5B56515F60636F553F5B5A5D5562585D4C57383A424D465C5C2D394A
3639434443464442273F3024344B30333D402B2742464031393D3844352F312336323F24
293B3A393C3228FF
FF8995937579716F6760707050616E6671897E908489A0847D878C8975757A6F866B658D
768D8F747C8D826C655F656E61736A5A7084828B8D7D9B8C8F9E95908C8C8C788C7F8D6E
938B88766E87875E867182697A786388938C63787E8A828F817488827574837E857A6788
756E899479807D726D8F7E695C8987789E8A8298877D7F778E82694F3A30100801000000
000000000000000500001A061D2F625B859A8C7A9688877882897C967F8A898097909594
8F948E82778E878E7470729B8D678885846989859A8E9D887E7E95749275727582898C94
927E83898C899B7D7780A1948C88897E78888991938C7F86817F6E7A9377978A875E8387
64857F7D80629993626273859891797666916C928F7795686E7E6570717E7472757D747B
62757D72726059607F7267757B606C6D848A766A5B7E7A7A717D6D7772686E65747A7C66
697D867F74787F7C696955657A77787674645E5F7875776F5E56615659635E5F667B696B
5D706561667979516F6F447168636750495557686C817369656C545F7B655963534A5258
49665854535A4D585A485561586070759118638A667F56636A3A2A5454514E2A5C6E4546
52566B556664595E4A494E6150354C506E5B5A5A65595B63575F4A49535153314D4F212B
3E2B404E5F43312443362B3F392935221D2B002D4C48353635182732282A332A312D3941
372525402E343FFF
FF8A7D8C757688767362655C597774785E838373797F7181778B6F6D5F6E7F7B64788781
887666837F7E99896B625B59584E6A707771269693749A79987F8A8971868D86878B8C95
8F828F6677706B777D75826276977C7A7D6B7D827E8C7F85777E7A7288857C8582757764
5F767C758A786B9376767087806E7D876B81767286738E776B70906E6C49261D010B0002
0000000000000D0410030D1F3245668C6672867880867C857B7B777D8983847385938E92
9A8081716E6B7580747D90A1908D888981927C7E5D91768297878589817C7E899C7C8A6C
71928B958385888A80907E977E85888281897E7A7B7794878A8C6F7B838B80757E857C7E
667D7B7A83734A8887717C7C6D74707D8B7F7D676E77727D735B6C687D7183746E758466
72647F7A7370624F5C746A676961676A7D727B70676B627379727D8C73767F8050647174
827F7B72656C7D746773636244646373636C576F65797C8D627F6B7571566265606A6665
5D587072726C6F66744F6C66757D466272835E5F6C7C4772776F65617383425654666F65
5557524E584B5530664B495177567C5E747A887F65445C4A474B55613C38494A3D3E3B3B
4B45465242555060634557625760474D4A524C614C51624B5039584B5130514E42413527
2A323C2B2D323A3F26482D3D2D2B2C213A32233536362F39343A28323F17473F3B354331
132D2D1D262B28FF
FF827694857C8892887E785F7C8B6A699D827F8D898F7C828385757E65747C686F888888
8A97836F717480647268616E666C6A785F7676678E9F938A909C749B8C9A93837E758085
7F909E957B8D847989777A89728E715B9D89896C6E8A968D8357809A94886A7C71809777
7E717E838F9085827973727F75888C8584768591718E8A56869689838869574A301F2811
00161622111A04080C211D3C5159777A998186928476888E7F9195808E907187847D898C
9E978688869282608A8D91938B8CA4A0A58F9C99A0759B929E9A9198889095898E86847F
8E7D938B85938B9F928681798C9F857F9193938F847C7B8C7B868F7685888B84839D877C
9B81899095778D6A8E8C888A9478897B9F957C6D82676F7D7D81707C73686F7289776564
7D97847D6378717182756B4D797E726E79947A74857086859C8F85927780907C746F7181
717B75716A6785526C6A66556B6F7C63717D8884697C6D7677696C6A56815F7075585357
6D725D6864516C68717F746C5F5B6564586379664A695A6164715E616E4E62686F596946
4C4D66594C62414B536741426A67585F818378876A63675D405449384D4F503048694949
5B57594F534D4D3B274654585D564B5452493C45544F555E4F6C594E4F46403341283638
383A372A3E4A3B33494B2F2D473D37423D43324F2C2F2D1F4E354656363F393E25304A3A
2F32251F2E3433FF
FF7B85889D90868C898C807289857094758587828B847F649D929A8469747C718973747D
7581758277746B647E807958627A7A808B8A767C889E8D808CA4949A8D9B868775868469
73887573718776807779918090946B8380817C776E7B858598908880888285917A807075
82897777817A8D82767E867C63717A696F6F6B80808087858A9C947C867F724F4639362A
31220E242F002E253B1829514D7D7C949A9486927E938F747685719679888B987783848F
9B7E8A8680778B9B66717A92AC8585A19591888F7D817B90889992868381858C7882937C
7E69AF929092A18B7B837D7D8E867C877D8D7778958A7A868F7F849F799589797F6F737E
9087687D808E7F8D6F73708B78828E7E7F74756E7791725D84768C73838481896A68737A
736C79848487738196796B7D777A6A5E897577827D737068866E76857774737D7577966B
677F77777B75636F7D695E7D7366768D8A766D7679798880886E67685E73777274704F70
5C4A757969777550668A7B7970757374704F5B6B5664695D6F6D65635D68645366735D71
4D43475E53514D495D5763495E72636063694A4C73685855354E41444038553944524E48
505F6D604C58605F514E554562515E5950695D546D635D4E6356452E3A3740433D46433D
2C25222C263E3E27364244283D343A412F3141304442283E2E2A2E283E2C313446333D3D
33445D373C3239FF
FF786A8A8C7C82939B8C848B7A8599766B77749D8A916D7795897A857573797D6A768378
81968D8184797D6F6E67686A715D6C828281847990A289877983908D7B967D7B98988B88
84838A797C7B89758980727080808A7E7D6D7D836F80807C6F8089878B777D7289807D77
608397797B877A877C947C6D6F798E6D8A86778485847B888D947F716E675F6E654C5A45
3F4D444E39283D433E354347748363908C8B7D6A8798769384829BA09A939292859B9481
857D7E86767A8F7F978784969789949B7E9290698A7E898C7B7192907B8E848582827B94
617A7D967A939C90818A8E7E7487788A997D7C8087848B897E828A7C8E6C60828D7DA292
8A8582706E7B897A849186767E9576798B7C88888D7E86657D818874747C7E6C74676B61
7B876A647E796E8679765D6C6C8E678A6F6984706C7373706A646B716E72676C627F7D87
8E7981767977837C6F767E8D77875B65757178746E8C6B747A6C694E73636C747B6C5B55
7671695A566466755678747779526871664F4E5D7C605E58596361706B49654866475150
6B5B414D533D4D634B4C46645E57534B655C645B444256564856614B5855342C2D534C70
6D61564C5C67735F4F596067666060505F3F4B52645A535C585F4A484D4F415247585B3D
3831253530283F35172D4A50404A362B3B52333E41274F3F3028483C39243D42372E2230
322C2D24483B43FF
FF838E837E917D8376867F8A7D9D71868B81878F84909285887C9083777E667476737A73
6E7A848093817F6E817059526D6C696871AA856E917E8684747A9A7F7C85878A83768A8B
89845871678A7C7A81868B708279907D7677897771837287857A796E6D78668E778E6F69
7E7A8A8C786D8F807C627E8B7387897E7D9B7A86788F82688681828A7070717F566C5756
6B54464B4B54515851594E5C868C816C8A83969B7F7A848F83768E878B9A8985889099B3
889887837F898B8A948A85826E81938C988E8C7E8B8E977F84957B8987797D7F91778F7A
97A28B828B917E897D81999487829775798283869176927E8C788D9E8C9A7C6384917DB1
837580637F728F89967E7E8493736F6C76678B886E71807A7B80757C7C80778D7E857489
707B79687C77686C6E9489877F78838F7274998D796C697980877E5677788064806B7464
7877807A70806B7979715F646A7C5F7A645A62717C6B776D6178767D6672816E8D846D8C
8472656B6B615D627876616C726D695A5B617E614F614F70625357735E604E454964645E
414C6356524E4E4D2B5854466F53625D47545F515D69605A56495A5E505B524A53565559
5652716157775B56565C4E57506B566B536D504F646C5E5A683E68584D52474B49583B40
483B30414341324854484C3A2236562D3443544037342943283D32354133393531384A37
3E314C3A403D30FF
FF808B80888C847298857B6C747B6696967A98908D867E856E828886836970725B5F656C
828666616B7667586A805F64776F79667890817E8596877A75849D9F9D80818B8886897B
8C73818A797D7C7D908F7A82727B7B977F747F93758B7765738862606A796A6E7B79756C
846F8F7C848172898A646B6380929279896C5E668B8E72889380718A9C93716B6D706966
3F5549554748585E6E5E7561857C898C76868389718D86958C89838A7D978575958B9683
94948D8892809CA08B9AA0A9878090848476838E7083737E8D98968AA0A08598678B9090
A499A1907E86727F87848F7F5880847E6E849191808D827B889D7B66809397927E9F887D
9F867B8384928D8574897C707C91877C7B927E745C6A79886B707A886F8187987B75937B
7C696680697191819376707C808371707778677276756D737774757175767678707E776D
5A7C7B7F86786E7F626769726E6862587E5E758475697B656B7B6F60726456676D540067
6E7150707D676A666366625D6E4A677762755A523F586968676267636B55525F5039574C
5E576A5E404B57592A444E5E66604A6C5E6A6F6F4E4C554B574760532A5D615D69625D57
6572575A556E6B5667505E50686059454F6C4C5A5D6D56484D425C4E3449483647403C26
4F29431D1F213D49403E4B3A4A512E51434E333543453F3C4933304B48353E44473F2625
37344A37482942FF
FF8F76788E92957E778E88716B777B908481979B7F7978879F96997A706D574B78856E7C
7276816F73767775725E776B495981859288727D7A7A808C9CAB9B79857A9C7F7B808783
8A82A3737684788A7C7D6D8385526D747C8581658088384A62738B8E69677069777F796E
6881697A8A846F84918A6C847E8689827F76967F828A78A78686868C7C79828584617D58
6E72644B586763786A828E93768F7D8180947F977E9581738C8B938E968A94808B94899A
927A909A877B82A390878B83A57694838B8B7C8476868A7F848F84868294827D7E848B8A
A0998294806E756E7E82938597889397928B888C6B8281737E7D7686A28F877C857E698E
799A6A798B787A9E8885898A9887747E947C7178608076718189857D7F747A8483836267
777C7D6A6767788584948B8172627C777D708E7A7C7C8A796480737E7F644C767A675B71
7A7066606E74737F7D93736A69677A7D5E6B7A6575877A65656E697B71828660795C0068
666D628266737357645E6B5C546A6D594E51725B565B58574D546862715D586161455656
4F54515C5D484C364C623E513F5754435B5B4C525E5E5F73493F56375646415F4656584B
6046515A545B6B6253507863635B56444C43626048526240594B4154284D3844473D5757
2F3C2A001B364843243C465D3734473F2A4330443E414149364A423837441C3D463C1D2F
44332D342F2427FF
FF8B758C7A6C7175778C90737A88817D858B79947864568F8D9B8480817E60614F406B75
697381817F7A685E7062586D64706D808194987B847D989685878A89799A8C96887D6873
938B97908D7B9C867C6E81897E7C7A6D806C71808D93544B72757A5B74796E797E7B7863
6E676B7B8A8B8A7E6D637C7F8499818A838F725C7B8D8D7D978B808C73837182846F7278
7E6B78776C5D5D8E83897583858A908E758E85787EA49392717B8894938385777C777C91
7E8A97A0868EA07D89928E9B7C9385848F877F826D7D7F8E6E8B75A27E7E886C787A9196
7E838AA790937C777D83859B6384809871647D73849276887477767F658C8D8E7971807D
8285868E777C6E898C83828B7384857D708180828B88766D8386865A7890738872727462
7B74846D6D6E698E7F74636E895F747991836582797D635A84696880676B6F5B526D827D
69666F7E7E8281887E7C878A795A6F70699658627970587885766374717F7784736C5E7E
686E5C76746B6B615463727660775B63546C6C5472555538406458434C525949414C6866
595858514E6161684E486754414C5C5B575564555A607255634F70665550626B59504957
4867686D565A735B6558495E546F636664706B77605345464062553D46594A4C3C354727
402424273F4D2C253F305F34334A384C383F363D3D4B49403A1B1C403734403B34343930
245B3A25343638FF
FF767688777C75808F747B7481906E717B6575978E85827A8D899577717D6A746986756A
7F736159626A775F74747B5D80788F8694926E6F7A95927D9B86897C85858D979789887E
7D8D7D8D849381738C697481977B776F7075597363737F72597D6A78826078805F80957C
776F7282848979875F726F868483747C828579757C787B8399A194917F718174847F8682
7C90797B716B72796A8F778391778080877B9F75A07D7E938DA98E9691A48C93B0878E85
928F96889785828495888B7F90767B8093928E83997D88718B9587897787929E76949993
97868B8E9C848D748582A3709A7791868B7974A97E81997991837183868580827D877387
8BA28584887E817E817C6B8C6E7687808C7D7E6B797A867E81847670726F7B6B6E5A7E7D
69729273724F696581867874618C8B71817E4B6A57677171506D77758773716269595B66
7C7D796096757382977E5E727A7D887C8B85785D6669776F798280808175766158689470
745860727158597E75666D645E56636C59534A576646635E4B6F695941585A685759675C
554B6B56496A5C3D3D53423A6449544B586153705C4A686B4C69725F4E5B635D625A4462
556C674F5E6F4165555C5B5D5F596555595F63563A565171586376484D504B3B30303534
2837424B372A2E423D352459524B3C3A463C3A3741364C44453D30354249403A47443333
3C45462D3E204CFF
FF7D8891697E9E837583788C847E8372927A747D96908A92955E7F8771707E5B507A7176
62626F6063767A6F7679727379797581898D77806A7A9493826F7D6A6C88858192969286
828C776489786F77807366566D7E7F8D7787947F42777E756D7477656E696C656D737F7F
6484787B7C626C6E79888A71827D7F8A506075757C5C848890928C7E7E81A07378778572
69719C7B767484907961707E9784869B7383869CA384828F8F8C84959D898B817E938195
8D928B9B9497809796A09174888390898E84748A86768289739087867B818E90778D6E5A
84918A878D828E8880917E8D8587768F717F8F818B7880638376705B8380777777878382
9290867B8185918C848F9A769175757B78847D6E90817263868A7680977C6B6F756B7171
777260827C748E777A83786E6B80687172857869766D546B85696C8178576C7B74897287
746B6A8B727A9F907B7C887476838374657A647589857354717D677E6B6F70755356696E
737C76787564796D778570685B7A636A68614D665B5F62617D5C70405052605040636966
665961676D47666760594458463B554754564D3E425E4D4465515267595E53625C645756
516C676D66666355726064656D6665697179495B4A555D634D5D45476644503841352543
2F37363E2B37352D2E3349413B3C3A3B3B5429412B343952433D3544412E2E3552472E48
5031393E472F29FF
FF8981637B797B939076706C7A958380737C877F7494816D707E81A7947D8C806C775455
617CA6BA6E666877736659708A7D7E898392877D797D8F6F73907DA67991856C957B8E7D
8492776E718085756C917C836A8E89797C7068658769887F867F7B7B7F796F837C6D8083
9381847662666982777B837B87917F88778A97787E83708E7E7F8B8E88657CB1879A9171
82866982829190986F7C68848C7E847D838E969E918C957E8298AA909198906F848B84A1
8C8C9A9B8B879A9A8A908C888880A18E92877E7A698D89B1878C6980737C74958A83936A
8190928271927B82947E8C8A93898E84928B8A6F838A78837D7674937A869670A98A608B
80957A8B7D8D7A767E827A8C8E8D74658681886D8E9A886C7A7F7D5D5B75807169697C82
858381758873656B858A946D716584827D8970836970757B606F5E737C6E6656636D7A81
6D767B6F606B7B5F667774796E707D758573707D7D837D749076775D7577545F7D6E7C75
6E6955666A7277486B7C74766B6E3F666D5F7D65575D6E6B586256514E624D6A534F5261
58505F604E4B4E614057515A543E56464A4F5762545D4C72605B70445262473955645260
7358655157586375575968695D5F6B554F6D6E31655557404B2C503C505C5F5054373140
19473C39374145484B40472C3E33403C3F25433B3B455638575E3A39461E2B4F37373525
4C343724333C2FFF
FF7476796E7D8281887583917F8E9C7F747065797B8C948A73858E78747E82948977705D
82688A8D7D616A73796B708484838D8997877E898F8F8B8A8A937F818D877594948D8997
7B847C808C7A89806D80887A8F767C8C8D9080726F72786E726D6C6F81788061676B5B7A
7A6B78707371747F736073908893886B817A8F8C8788A299857E789A8B91736878858278
8DA69D85819A827F9C966E9774868E80818C946F718683838198A49E988A799694908B6B
8D8E5B82867B84878068808B81858B8F74A98582A189828F90916F88867CA9928B89908A
817576799A8D90889087788F7998988274928A6E83828D8466847A6969948A8A72878575
8A8E7F7A7478837D887A7D97778C86967F766F5D708B826C72808F87846A647176757178
6D7A957E927C5C858C6E7C948888787B777C7171827B64668E8173867E7F707359677666
6573615B6D7C757C7068827F7E786C7686736F70747B7B77757A826E657B80738870747A
707372565E675F717B79845957553E6A705B576973556D6658645A544C335C5B6C5C485D
4D4E4C5B70525F5A605A5E5E58403E3F504A514F5D626859424F554A62524850564B5165
645E5B6E6374675C5E6A626947475B687F62576861624D624C4F3D2C4A484A4440445840
58374341404242514A3A473948453F2F45563C334F4B294849434E464D43404A2F1C4F26
1D493D4F43382BFF
FF7B74848C80808B7A7C937F7379818F7B8C7B72786C728A8E8B738E877D998F82586178
6A7E75607362768872746A7F86888D8E9E7B7D8E92738A837F7C7998988B889268877782
85729E9F927B627C8385827681936B7A7478848C876B7F817D6373697A7A747582708A73
756D6F87747E7F6F817681A387959D987882887E8D8D877694989A7A7F7E989E71657E5F
7C8A8775848A7E83787F988C9486707A9E9288809A8B859B949A9680797F809E90857C88
939098888089829D8C7C70988686779699979692908EA27F8387AD82848379808D717E7C
7D898491787A898983A58E868C858AA072867B7A88827C6D8A7A998583697482907B918B
719C7F879D7B7C72816A82928A997E98787E79748594788C8E7B607675738C7F7A6E7D6A
737975808781938A75505D7B748985838D686D6B6E7B6D67706882716E77707C78687668
6F74656B6881796F6D71757F7B81837B786F82726972655F5B707B727469606B67937D77
836E63617B606B5F6D7B7193705844595F725E75616D6C565A564A484D625C3C61455E6E
5E486868506D625B6C515C54534848553A434A565A6256596152595139454B4A54577467
6152536962615F6B6D5C6B68615A60605C517B645E5D4E4A63385A433D494C653B46534B
363E404B586850433B32413E365F554B465248464A4F534B322C3B313746444852553349
3E2D4536391837FF
FF8E82867B71808094637073827F6A6072738D768A6E757B737775697781869786817161
667C7887878D6C6C758D94828B997C907F9795878D7392838788A3968F8B90878D72838B
7E9096986C7C94727F908295888D9682907783726C757C768971677E636B878B8380798D
64718982908C8A786C7C8F967F7F758B997C8D60929A9089769F7F78896D7D6F838A9C8A
9A7EA594949C79958691917C99827E8A74808E94757D6B93A07A8D758F726F94778E7A7C
749D85938581998885927F77867F8295A18D8A6C828E8A75908B9A9E8C8576749185878E
8590937785A07E84788B8B7C7CA19688787D88928081948A909C7B85858C6C767C817979
86877F96928E8D7A75897687798B92AB98757A7488737D757F886C6F8A7E8A6E86647B69
8986686E7B705D88877D8385726E6F7387718C908976818B7D7D706D7573867569716A68
686172647B808F6A8C778079747C757F93656B7071816B5F5D78847583596B736A645776
60885D514E6B5E68857788736B59625E7964756E716D775A6E5A603D5B3A6073475A6D62
5B5E605461466D4345625C455D583F584572646D62395B646F55576F5950656368684B57
546461676945555A6B64714F6565805F5E593E496648675956413F4C453C47324E4B3C48
4B404850494F4B3C4735482B43383A4E41533B3A4B444E6352383C32383B432F22284048
5639493A33343AFF
FF817B705775818A8B8A6B53676B7B8277687398825C8C868469876F7483768483789D7F
7975807C7B6F7C8DA67A838C998D86759585929D9392667C8480856E927A9360787C9798
6B72806572836C747B68787D7773849B767188777D67786E7C7480796A777F887B6D7D74
7E8A7B7C6C7592838A8C7F7F8E898786837C70867B787B777781A18C8B9A88818279807B
7B908E9983818D887164808D828D8B738D87947892A17D9B6C9DA1848D9EA08E838A87A1
7D6E9B91946A76759A89919583967D9C8A8D8B99968A907E7E8C788A8B8B927E93757887
7F7C86928B727F8A9E936A87949B84859683877A897C877F6C7B88867D78A16D917F927E
75767F8D85708C818779838B8A6F746E7B916D8F8C96697681848C747B85837C7A806273
6E858F5F86888D858171707080858F6E7673736E7C786D81727871626C81797B7A7E7175
74705B5F80697570817791857872706C746F6A776E6C888585756A83697263847A5F707F
655E836487685C77688177886B6C604E6D786F476A67657C81625774643C5C5773545C57
685A5B62636255605A5A614C4B6D564D6A5951606C475857615E586063434F555C495C63
573C5A6C44576B77594C5A55665851546E68534F586952474950605051553C3B284A2635
48394A585255494E454F452D4F4A6A463C4A3C544145623C4E433B3B473333393E435034
26453227282529FF
FF8378708B8970757E908B727677728C735C8A777983727B897E9C936C858B8875868086
7D8284978C9E8A82768A6A89707286648E8F78807E8C95928181A38E8A9F93879282847B
707697A0708784815E538284897D7284757873797E938A7E707A787B5873697B6D6B9292
77798C797C8D8B837D8176949C91727D868B97788D908F7C939981858576719B81817E74
8870716985855D759C628A827293857C8B6A7F857C7A8E818A9A8392878794888A7C9091
7D888786897D837C73938E839291AB44507AA9968075848F8D8985859A878982938C786F
77818A737D999A948291A087828E83808187888690918C989B66739189898A7D7F6B6E72
6D737193708B8A8C888E8181817C807D7D91955A94767D7B8283708D9E867F82808B8376
74927A868C8A7B7A80808E707D82877581737D81637A97727F758F73807A7C7583717F81
6868786058507782626C75737E5A5F6660657B8368736B717F76626858736864667C716E
7C7B7658747B7A69777980786B635D67646E7E786860765F635F4E6F5A504C55526E6C70
63725256635C665C5C3D5F4D524D465260655C446957545D3E624C394B636468525F6A41
60697E70564B68656662556C4E5F5B66633F5F6A56383E5E625B4C545758515E4A444560
323040373840373848414143503B4B333A3C47553D373C2D4B40263B453A404445281F26
444B333A24332FFF
FF8F7E838781736F7B73686F6F73837E705A6567796F626B74727385917E897A7D80A184
877D8C95826C827E6D728F818B8D6A688783819D918E94828D828B89998E98908D838D81
A5A1767A8684838D817B9B6659747B95836E79867A976F7065808489747880877F757981
7A858F7F837D7E78847D956A749A8E828886A0757695797D877898947B8180815A8E898A
7F807B8A8F938D7F7A88606B7D7D878B9F63889B9E7172788B899B83908D8A8A7866807A
8581688D9A6C80A08F828B7C87A38C92878A7B8A9385857275817F889B8F84907E8F837B
8BA2739E7E657F77938A999397809E9693888E7A769F8284828372AC967F5F61655D7A8F
8E828F87828C747E8D988A687589856A777B79AB839174658B80756F6878759E9882736C
877E88A0847F9C6C727A7E7E84888279626A51717571746F7E718B916B7A766F71676E79
69535667727079727468747D6A747A75786E6C687474766D6270767E6C64626C7E495561
867F7978756D6E7971585C72704B4F626D6C4D7D68616D7170776B586457504F71495654
6A4C6E524D654C594E5156463D375C637A59515060645C73625A5353505A57605F745667
6A5B56624A5B56514D5E62455E556775664E6A585C496A5662424E4D5C58575A61504C46
452D475A4F484A49584C48335C55463F4358423E534A434E403C49363B46404E3541412B
25232F51462F4DFF
FF9567777D958F7D818388859879575074756E7F6E636A768760728875836F947B938C9D
75857F756C7E7C709D8A8E8F7A766C8B71947E949196849D968A87A0948E7B87847D8F89
8A838A8C94888E808B879091797782787A8A6E757B856E6D6B7C85806A6D8483757C6983
6891977D7189878570816A86877C7994A396868BA297867D97928D9585628C85758E8B7F
7B7F907F9466947F88857592917A747E5F8D9071967C97889086807F87788595758A8289
9F838B7B859E678189968B7F8A8D9283929981838A79746E9375A1766977958682929275
807E878A8273818A8A75867C828067916D8C7D7B69709990838F8D968F877D8A7D836B78
8295727C93768D808C7F63758A8580728683806A756B827778626E767876827C81937560
609488635568577684787E7D867A706F688E5F656B687B71656A6E597C77757F7D91004A
7C54525C68616A7971777B7F7A7379727572846672625C7274867B6F63726E847F72797F
6F8E6E6876606D6A7F8C8A746B765D6363716F51755969757A666167535673585447666A
58583C5859584C515B355355404550566556625C68656B526852664E696F66604E625856
4C53535B6362624B6C605854544A52545E695159454C3C51474B4D3556564B653C433357
483929436733524C3544441A5B38364A3F44514550523B30345649324A4C403A493D3739
423E353B163435FF
FF8187798C71816E87778C7E7A68816B73817A7C6F808166807D7F78838C68868C66786B
7D808968797F65857B90766E86938094818D8285877470797C8E9B7A749A8E8991898F90
A07C8686889685817A858A81808F8776727A7467778377856D7886827E778D817C7C6A6A
7F7B828A8A8C8B9A7D89778587718B7E937E6D9088858892926378847C747D789894928C
89897D8B798085957D7C87897F8885818586909E8B7C8C98958D8E938788868D9291918B
8C8F9E807F78808D8A787A878C84A59993728581848178937A88729288868792988B8090
7B75988D998782B192918F90857C96887C858678787A8B9D808386738C8D8D8970658077
7779797685797F917B717E8F6A77847A948B83797982895967627D848C7C74707D76605C
6E836A7C8D88847E8B80716C7F8067767966707075897F867D736C866C868768795E6762
68676F777C7551766B5E776B796D657E72778E8B716567686C5C797363656B745D66765C
767B765A5E7468627C665F686E71626666605771607A61626886747B69806270787E7A61
655A61395D50464C5C56425459606862697A6C755960576A4F6863575259545752465B60
6B565A4754614B5E63695760664E655F6146524F555C544E584F43514A6D52443E52575F
5738485035473F645865413E4D463E383843545169384D494E4432503B254D473844423C
3D3C2D373B4049FF
FF877E72718265786B596E84696B7C728A7C81786F8773747C795E9A84676076746A706A
96918772898A7C94929A8A9C8D92877C7C8D7C7D85888A89A6AA959AA185838E879A6E89
919D899986938E929374867480797F867468907E7E7773637C81848D7D997E78767A838B
927E866F758B7C657D7D847A85897C929082849C726277728B6F809B886E87888C848478
83857A8A9C756D88918A8C838A80857C7F8D848B887FA077969B7679967B6D9B6F8C9F7F
7F8A8D7A76798D93917C987E73727A9CA099908B877A8169848177776E8B828882617F8A
87939A87848D8993988375918E7E937F7881856F808D8478897A898A97989E7F807D9283
776B8B8787A28E9482889D847C7B6A857F8B9C6C78806A7E7B5C8590808471857F7E8371
7B77757D819A8979887F918C6E997B7492897E68634E6875715C8E6977757A818187736C
805B6B695064708D8173727A7E8E5F6D84858275917666776965717759786B657B72647F
6B697B60794A686C6183617682737979767866675C7565775D72795E5E606D66686B4B60
53576141585B5D563A3A564B3C545C604956754F5A5C56605B5E4759696061515C4B5460
4E61726658576052676E6260584B345C4C5971586F655D51594F6159474857454C474B46
493F38524A37553B4D4751522B7158463645473F3D4755473A55563B3752423D513A3E3D
383A2F20153049FF
FF7A6E60757671706C74757C8088706C7778815C79687C6471787B7D6B8A60749098868E
7A858B926C7C967E987886978E797F9D86A1A59B8F7E6A97838F95A18F83949D85839F7A
89918181848D8C86968482778294867E697578756E6B7566708B7C7D757E92786984858D
8B717570858F6F826F7E8D90909D9571808499919289A0818289898C99928E89907F9783
705D847070746E778A92A6787974766C8299977D808F848A787F93848B9398796C8B8F92
868D84876490907F757D8D8996AA92726F858286847F9599948D80707C7D928C8C829272
7A7F8D938F8F8BA3877A8288887B7871768A788584848C828C768F8A8D878C7E89826E78
757B838A807B889885826A9078849A92977B75827F73797686868780787B867F7E646A65
7E8375778274869083827272776D8081857260607B67736D64887A76888C8A81727D7470
657B5F7A6B6E78856F6F8A787F658E8E8776595C7A567C877B757570707076628269627D
6E7F64685261727E915F867A7480757D6D7C7876696167694D6864687F6B70758D755966
614D52534B3C56474858486167664D685E57595D74676457565D585C6B5E5D44484E617F
5C5654605972644E70605F5A65725E6455654B69505D6C51463E2A41465444445262343A
49513D4B52424845443344354359485E3A5B3B3F5657543E474246434E563B393C273C49
4D53333F40303DFF
FF836E66727375707C6B75657673737C798B8E7589897B676C73836D6A806D7E7D829569
7E838881786877877F9069798C88778E867F8B828C97919F6D68838C918C929295958F95
889C6E958175897675858E9177837874758D99936395717A5F7F867475878379848F8277
837F877E8979778F9A7C717E7D93A88A8C7B898B897E79857F77847B7C878B8F947D8C6F
4E60727A897D9885898277707A8770927E727B8B6C8590908186725A9672708F8F946E84
8796928596987E918888828E989D7A968675706A81797D8A8DA58A7D89797985929B8183
8C7B85868A7A7D857D8586928391768F6A667A8486637D8E8293858A88788268728A7E87
6C6A8D816F78686E75795A79808C85888C958B7573817182848485859C84616F81769170
6E7883978A7A7A86857E7B7783987F74749362737F7E7C797F84807C685D625587826969
66787C6259587469755B72777286878D7776605A697F877B5B73916F6D6653746B836D5E
6381828685677B6F68868E5D726B6C7E716B7A6E686A736D6D836D746184766C796C7B5E
69636251615253554A60435E4768674B6D694352596966656C66695B655A5C6E5C576463
767179637650565D5A5554595F60675159615E4376576E654467524E495354665C565453
5337443A516B566A504444303B4051415C495C5C434A4649443D3B3A38473C5E3539425A
4A3D322D383D4BFF
FF756F7471685E678972687A84895070686F5F63656C5764606671808C817A777B868A91
8E866B847E8E7380788B89907F978E808C9C918281898B77838F7A8E7AA0949D968D778A
9C957D58708C76708D8E807499828A6D87858E7B6A80956D6C766C848A827E6C777E7475
6381787473829372977982799A947B89657B918D7A7D70808479728A4A6E795A6C877986
505B8E907E76797C8C7D728781796E6482767E71957C838586786987797C87796E8CA181
8D707E7C6F738B978D917F96928B6C77819197848A7B7C7E818B7B9C8D787E7275769589
73959996848B8A82728E988190709069876C785C76797E82838A8F82877C87A37C8D7C8C
7B88748589977990938C897483806B79A09A7C727F868882798F8C78899193798267786F
73836886846D72737C7C8D7E6F839499866D67796E696E6B6E678C9E546E666F725C786C
786C636C6A767782736E6E6B805872675F6A5A7A857977686F6F776B6982737479726E7A
667B6D7E71737E637482717F53705D6570657E7572777D5F786C867161635774747A6863
68635A6E3E62474E745B5D567C5B383E5C665A86736250475753573D65645D6C4F535564
645B546B4C5A7370613E5F624359574C58665C5C617244615F555C47624C61564852434E
523F4A2E41545850534D543B58534E4D415751385350424E5040384151403032313E3E38
5235493E2F2847FF
FF8272795B7375785D69756F7D78624E6C6D7E53766688626C567890707E897694765E77
7076708477818B808E828974897F839A958A927879878D99A59A859D839F889DA2A37F84
8E76735E70807F827369716F8780797D928F8B727E678CA285796C7074728F6D7A849180
7E6C8068858C7090788290948E85948A777D8279858A889F788A7D8084707E9A71729282
757A85766B5E697D88869C8D747F82918E75758A7A6C6770958D858A928C8C7B8C807493
7A98898496968F89848B948A78747B7E8581829D9697A0918C9096898A8AA17F84758290
8D7B7F84978A8E9F8E8D86A171678C76818C79868A688975928A9381677B6F6A8E7F7E7B
847E7376797A8998936C8B838B7B7A97778D99897973707C86987C86838CBA9D7B798676
758B757583827A8A6A7E7E717A7678847B6563848378776B78736960876C6C7861797565
5D5558675C79687580828E75787C707D747159486C7F685B6865656B745F826F48827560
61765F7571627D7068838B5E6C706E755E676B7366665F72787D6C7669696A8E83658274
696F6C5E66606F6E5F715743584B666A6F5B7B666C5B596D5B6358676751474C6B616371
506F5859724D5E4A60555666556848493C50576560585A4B5B5A5A5B4C4662654632443D
4A45554F4A3E393F55394A583F475059433F3C5036375441404A59343B382B362E38393C
373D2B4554462FFF
FF96776A82857A707F7078617C687C8C6C827D676C79717A967573647C7A8E7B829A8281
77757E9A877586908A7885838B8F8B8D7E9E818794948167947D8B7C8D9486919386837A
706168706A5961666A62606D75737B8E8D7B7C79889A968F80747B7C7E99738882827886
6B7E7C798C8B9579747175907E8B7885A5A19A7A7D748B7B7B838B958B92967E89837D94
8A85888B7D8585888D898C9B827A6886987A7D887B636D8A9C858585827774698A8F977D
90929C6D7A949488798B9190AD8990847987827F889F90939FA17F919F857C978F9C8891
868D827D95958994847C9581937F79756B7A80688682808F6E888E6F8E707C807B7E7C98
A98A7E8487848C8E848A927A9585888987897F83918B867F7C7B867E7A797B8C8D8C8086
88957B84858E8A787F8283778276816C7F7A67616C5B4E505F61605B5E5B55545E586558
77625D78776C82658E5B6A746A6775487D7B71686D656D78697A64617459805E7D606970
6D686177616E6E736870665F7A6C848F81566C7279797A8A807D7B79666B5F665F506C70
6250707B5366395977786F5A5C7753615B4A416D706866707B655D454A4E546668634F69
817B5C4F605B455669666C4F425660496A6674675A636765545E5E663E5E6E59425B3F51
534F5451565153343A484846414B40395A604444504A2E3A5E4F42443C414E503D354630
4F4B3245483A48FF
FF79685E717C7C536473787A73647176706C6B716F6E78767F676E856F8283876E8C8E89
92906F7184727E7E7E5A717588947B8A7D81867991988F7F9681828C968A97A98C7F6E79
6D656C5E4E756E64705E75727E7E767F8B807B6C8790737B8E7A7A747D786B7D7763617E
848F8885686E829D91978E8C8F6F8B7F9D819A6B9B79677D96708D89878F8C8B928D888D
9A8A82857B6C8989787A898D8D8C828680866D7E8D776E7A746B767D5D8C7D927B80767E
6673948F89687C9E888396A58A82947F85847D6D8B83808A8C85737B7786918883739792
8E87A09D7F8A9280908786797C796B8482748E8D967B826A6A8D8B83819092988C938A77
7C909789898E94A0829384826579859B798A8C78757A794F6D888D828E6C7C94847E8793
80677B7C82848089737B80667D9463888080867E81717773866C5E6972696C676658686C
724C816C6E84758772726E6A917D5F5E7773805D7B80865D705F655E6F6770906D6A6E64
5F677263757B686D7F7A6482627773827974837B6B748174656C6F7173776C5688706366
6E778455676569647262687552615E5B5A7B5F5E5B6A6D6B67666F66464B4E5766586056
5A60615061625C56655B6B4F5254567056535B66437962613B51615B4D605C635F262661
60354A4D4B4D2B4F53514436333B295B38422F2F4E554E4A4E4F60364539444E38413A47
4D3C403D34464DFF
FF74787F83767666896A6F686D7B7A7B90807F6189878676757D777B71806D7A84607776
85737D807D707A878399867D686F818397847B7D81789987937484959E999990988F8877
67796672693951726160655856786D88837A7B70667E7D897A71818169808C7E74767A7C
88778188928E9469809EA8968F92688880A185A18E7D8993858F7D817DAE8D8E8F91907D
71718888676A7F8788788582877B7379987D64757787757A6F88A68390977F7A67777E7F
8A7084947D76838C85988E797D8283726F7C8F9194998C968E907C8B908B83717E8F9397
9193918D976B6678778D76827D7F817F89809588907E797E737D7587937E63867F7E8E7E
7C9B897F95747C7D74748D90978A7D857689767F7277706C8C8F907D709B7A816F79776C
809186919F7F6F798384738C899367798A887C70677D6A7B756E7B7E6E7F685D6C70775A
776D6372715B4A767771766E7D7271648B94718379715A586963506B636D8562878A5777
5E67717E6A8A726078757C7C756079727068809470747D6F7E7A7F7A90697A6C7A7D6F91
778461727268676A6F6B7155685B5F5A7065496F706A675B4E5E766D64555F5E5F536051
516F4A644C55635E6D5B4D505A5F694B53595654625B4B515D4F4D6453433351746A495A
574B4C424763533B47464E516551483D654D46573F48534F503D2A4A294657464B3C3731
483139422F3931FF
FF8B7A67686E7366556C8385847B7D73787361658567778577828A8984798E827F7C8796
9A8A707A8C8A7B7390989A8D7C80A0888C78888C7C7F9791888A8D8D8383817A956E7354
606651605973617071615C6E7E5B75757F85848A8F8A807891946D886F746F936B6F8369
79878594779C828A889C807594858E8F977B9192908D8A8089816F78947A8779866F9389
856473737D76807B776D7D7B7381758F81888B78818791918B7E72886889827872849B85
8C6E807F7E769783818584937C827B8A867E818C86938899988B759B9F829AA98D8B728F
968384856C8C989B98728A9D8B868F9592816F95828E7E7B8774879D826973697E7E7FA1
8F8E8C8D8E8E957D78777C8080868F8A79867A898A748C8575838863827F8A818B806889
8B5F7D827C9774808B967A7375919B8291848880816A876E6B65557E6B65755B70797177
755F6889806976818575818F7775687D79757C7A757E78705565747974706B745F6B786C
806F5859736978706D6D6B655F777B8B87826A857D74717779827C8E717A7171605B5D58
766D568475787065755B596A5771646A734E6A686064607E6B53644C51646E77594F695A
796F736866616A4C54685D5A5F605E615E6272625C5A5E6659595B3B485856495D484E64
6153445847444B3A3E4F554E335557465B4E4A424245505C4F53504F5254453B48475346
363D474E514B54FF
FF816B6E7972876D6D837F5B666E6270766D6A626B815F75727E887082916C7A7C888977
9083847B7687798F92818990A295858374978D8A94728381869090988694836C696B5D52
53555C62725C80676C76657075757B8A727271637E7B8872898488866584998B7B96658F
85878376878B898B7A8B8F83917B919D8C8AA187958085727E819397968B8D8C86828B6A
887C7F698C6F79807B7A778766746A6E845C798C8A80856C8E7A7C7C87808063837C827B
7A8D8199869BA07E7E7E809C766B6D8A888295987C889C7B91839B966F8A868D917F968E
918E88978B91948980758986907A6DA397767E8D8369818F7E8289748A7E9692798F7C73
609E928A96828B838A6D7C82828893938E738D8C717C797D7585878482728E9063817F81
84815C8F775983817368766C70707D728187678772748082716474666E7A7A775D696C6D
8E6D667570746E6B6A6C8379746A8288798F956E786F6C4C84607F5F737F7657836A7168
7B748370807978777A82626F7F7379886F807476797A7A6F6A74895E6E757A7184756960
69687C5D797F82606459694F6A6B565685825B7E60576F696941525259655A4F55605F67
626563666269365561585E6763596159483A4E66564F5748565B49573B4D486F52504B41
5B545C3D4E455058475B4F3D2C432A43424C3659404F4E592461543D423D13404E354343
4F394C47372F64FF
FF856E7B5658747A6A857E87787767676C75886C7674767361879559887D7774758A9888
86848C84845D777A98857C8A756777847F8A7A81929387807B887C84A6876A71746B6465
5E4D6566695A617C776A703F63807464757788899B7F7C8B80818D837D72738B968B8C73
8383A08F869A769E958B8D8789A6837F9E8580867E787C9A9DA392697A808978887F7687
86766170666F7E8B7F7B8B7A878E8E758C89818888928D846C8D8B83827A81847E937C9C
7C818679847F778A76888CA7948064948F98799D7D768A827983888380678B868B788795
719A958E8D899B7C8D6E8C878288868E98829C6F727C92746A7685947E7977869A869C87
8B7F958A6F7E7F9091AD8C89898D92918B83819298827D7C7794739580638E9590899994
7E70717B87897568688B937B816B7D756C8174768594727D8A777063626C7A7C375A696F
6B827C7580736F6E79668D807A71775C6D7D83766E6487777363756A5F657683667D5772
6673647A8469617C6F7B7565756F6776747A878E88806F73777F6B807080736C6871776B
8574615C795877717C7268697666717D7C58676F725F516068614A5D656D44595F6B624E
74735F676F4C675E656163606762704C43525C62604752525C544F5B6243594D554D5D6A
4B4733514A49394450504846524B2A204B50455C4650514E4C585A5D5C4D403B2B4B2C49
3B44424F263E30FF
FF876A75736266677B606B70816F83837D73806F66796D61706287797D7F7B757A8E7B72
937B8E9D7DA07F978B8D7E907C6EA18F8C889F90868B8F82908A8E8C8290656D564D6F6D
526B687464675B787A815B655E657A4C73807F818B849A8D7B73A081A87E8293849686A1
8E8679896A79A17B98808A908F80928A888574718DA08E82817F8F8D746B75826D847F7F
67806A8B73866C7D6595726A926B657B608A70156979796A7B897576777587987359968A
7681537F93896971887E837290829087809A7586817D849585779C8574867A9E827F7C82
8B8C7F8A87A08F886C987A88869A8F8994876F7C698591718B83877594809C8B918A9D7F
7C828D778C8E7D888B968886909F967E7B9A7D8B84988E898F828D8A6B8673757290768C
886683796D798766888E768065A07A7A8C87718F7080877B8D7E7E718788757E71647584
6D777C5F627974796F79678C6D678581717771588B7D747754656963716B816F897A676C
6B83796D867C717477737970858B6074777B7E828D997E7874797780797866765A74607B
6B76648567606E86796A64625C5A685E7662666451627A6D63616650516D74675E676270
65769081685D506262715D72685C6A7A845E505D545B664F4D543B5D4C5C635656544749
56334B2B4A3348253B525F4D4F4C603638414F644D534D4852505939423C634742456052
4555541F3D3E47FF
FF776B637A6E756C7C9177608E7B7C6C6E7763797A616A737B797D676E7F80877580758D
6887888E72818C808993898377746D98748B89777A8FA9859B8F87AB847A7E706C656F71
5B657580908090747F8B5B7066767A7F7A616F8765795A809686798E7787937184797C69
857679788E8A8C81909C8F8A827F80837D828E8AA085A483838985867B6F7A69767F7789
8A5B6780816C6B8094818B70719868787A818800428F838080707E867B72877699949389
777C715D8A74A285788976896B838890997281758686968981867B809563778497867F94
8C757D818E887C7D8F9B8F7C93938A7D7E8B9C8B9680936C9978929E948789A487708487
989D869185827A8F9F7B97908C977A8989929583997E9088917E7E6F7281846F8782778B
778E6E8977846487706F706F5E7576717A727C79847B7F72899480817C877F7A80766A6B
848664726871866760606D697A886F7774506C918072667D87757D7E7A7276806D6D867A
7B7B7C7C6D6E7279726C705F6F6E8D9790746C858271688A8179847A9275775C5E947995
7470716D6F74846D81827E705F757480756B6C705968587A536F7080776B5E5A646B3C44
5864786C4E62516A664F6755665647585729005968526C5C545A605A6466675B4B56664C
564E4348495B5A4953314F424A583A51574A574E6060554A33455C55453C344A45353635
46404554475041FF
FF866581657A69856D6D67867B6E70587D7F627384707D7297997F6D8786937A9790926E
987F767E848A848AB78E818D7B7186748779817A90A27E738F8E8C7391887F7B67805C64
60637B7182847C7D7A5B6F546A656571577877796C9085778077818284826E7B9284896B
73868F8274867F6C8F87889083956E988394978E7192709B8B8A956B7A7475768B6F7D77
6D96709D996D825B6C757F798F75636E819D75906C777D7D6D918E77677B77736E7F7F72
818A747C858E8178636699617C8B8C8B76817477818E888A878576698F738C7E7E878B90
8B8C8D818888849F8F89888C858F979088906A9B998B8D718C9B84808C9A927E8B8E7886
958999979B9F9D9B94938D96817C8D9497829A938F889082718D97908D87748683766B82
8E908B6F857A847F77746F5D6B846C82989C8091716F68646C7F898A75847C8F5C757978
7D837B7E76616F468A638C7B7B698582886C6B796F666F78607D6D68606681726E72796B
5B717264776F536470707C716C7B907C6D7E7F6E7C72748077827E8163747A796973735D
7F8B72828773824D6A706E8281745D657262594A636372696F4B645957656443634A6645
526B60634E415A6C5B72656F666A725168595C545C4D6865676F4D5A72524E5A4561606B
595B4D59464B5642445B714A48435C4A5340505058565161595B4C4D373551615A3B5937
594D2C333B4744FF
FF6D818D8264787480776D6A7A676F747C78847B697875736F83806A767293A27C8E8483
8E767B747B858F83809897878B757B99897461858C878E9E73819097887B7872795E5B64
85808891938C9289A4877A67535E695D7562756B768473827E8E97718286828B7E7F7B88
80A180829C897F8171878A7CA88E98A2A871999C7C97A081887568A3857D60787D709395
7C8B98636A8494867C7D73846D7C81697C7D796A718774827E7887858186557A90928C70
797B877D7D77828D6885828A8A958A7E9397888F9884737495748C76797C829E807C9996
8F8690846F899581789781938B7A987E8A8D949695989A88A08D8FA1A0969F85808D9794
9E9A7C869294A1A08A837C9191798C96988F9493728E738A937C7D88798F76899188886F
6D836B68657C6D7E83797B86767A746D7A81656079838C697B8B90607C875B7B8A818578
667A6D7B6E847C85776D787B7D82717367788979827E61716B7F5D5D787D72767D8A7773
6277805C61546A6E77798E7D817A6171786B82796F736164847A9070777A866F867A7083
6E6F77787E6A6C857E4B516F69676A7F644A5074707A79663F747E67774C646268665062
6677706B4E64516780575950676A766462525F4C56635C59574B614F4963573D4556484C
5836584C63505247464B4A443F605140494538545044523E4B4C4B4555485927543E133A
3926383748333EFF
FF898376725F6478716B7C8A8084787C89838589776E6E6D84868A8970928A8688919B87
888B82836E7C7B8D8A9574867C7F917C817A8D637F8C907A9794808E787C6C865C5E7277
8C8A83809D93887889937E896F556B6D7D6F7E5E9088887C63678A89807B837B80778D8C
9B768185737F807791957D9693988A71719892879968826F888677877D8A796D796F7588
5C57607F717A7D7D8666887C7579797586868791858B766D606B7570787E7D7E7D7E6676
A57C7888847F6E828A877F89978A988E96797F8D807A8A66709986757481798D948D878F
857C639299737175897E88748966768C748D869599768D74878281AB899C8F85807A8CAF
8E91739985A2778C8F86898784928A7B6E9AA7988484869B8A6C83707E778E887F8D7F7A
7678838F807482826B666C78757F65767E657A896E7D76786F7F69897D8B757C7A8C5C67
8076717C7F778A5F75747460856E736B7E7E69826D847C64716470725C73887A7B6A6072
436C706A5B67795E637D697379617E9F8E6F70837975787C7A88868083867F744A6E878A
7B775C8A797A8B546C8780637B7B6C6F6B777C6C76657A737749515D53614E5B6652524F
60586D654C4C606257647B6D6055455D6164656C5E5C625967685B605F615A4D4F555E55
544D3C43453A4B503C35554C61495B4852583957595749545A516354393A41272E3E403E
51545E534A4B4BFF
FF868B6C8267618A686C6D796F57517772857A75967E82687C7D74757B76848C817C7E76
7C6C7E778D85678381776E707C878F8D6BA5807D8A90647A8196898D7A71645A5D796E87
7D7C8A9380798D9E8CA4656B7E746446716379856B8E7E85856A7D9B7D816D875E75747E
776A7E7E908B917181939D9C987C849A7F7A939D9175778E587B827F8E8B74886F657C78
77809D6F8E778F947B7D8175688179687C8364697C66868B7C6F807E74657E7268566773
84928979768893A0928B897D8F8C9996908B8C877A7F7A75748481937E80889390968482
87818588827C8A8C9B7996A794767D837A7A8F84867D898A837E8F869A727A967298998B
88989E988E959295A5948589928C8B95997C676F8399738A8A7899947A877F8B7C66768F
8F80827572798471988C80957C767A0061765E6C8A8D71766465798F837C7F817A756976
7E5A75796D83627B7F8B6F7B77787A5C7982715B816485857B68885E705760685E6F535B
8960705F6A657F827B816685818C826D6886717C8E748470768176736A606A535265756A
726F606A6F816B698367716E68607B7D53504B746A7A69735C50586767696D6054464A54
60625E4D794A4C66576A53555E5A75596C705451646F5E542D4F4D40554F584846504A3E
5D4D694A4A595759505840604555476439355A53625556513C464C3E56504537506A445B
5345462A48261CFF
FF8183747D747A738B647C7A678A797F8981768564887387806A807C7B79846E93849297
74757E787E9076817D728A7D728A84787D979080918994758D7B899B826F58676A678677
7F779E7F797787897F7B7C835D484D6261727B627476796070706A8F8A88928988828098
797980788C8661778077867F927E9585A47E8580853F008B7977717468667A707B737D83
80846A646686806B808A817C6B6584926F798B7E67737F6B7575776883847B79977A7287
9D888C95867C855E767F958678987695968B8F8D9377957C7D718086977D8B9696868695
988F828C8C8B92878174867E868F7D8D99818889888A70886D88929E8A8E867D9483657A
8B958D9493957F8493988A827FA0AC998F9B9A95AB82A7828C89867F9486767A89808C96
7D89868A7E5A84937F7572737B78735763707E9D8473757A777C6E61705A767D75777077
778C8686857F8194837B8F798A8A746074537B6880647B737775565774666F5463628266
456A706869645D75776F6F65748577868A8386818B7D85878F6C7D5D7855846F6E855E71
89808C6E785777876D607C767B6C5E59696B6E5C786E836C624274636F6E5065685C5681
53566A4E4B5553406A654B6C60755B59725B6E585E516C506A6244424458645252324763
4F5C4F5E4A4B3C49404357505D554E375F455C5E5B5E474856563E254C47585F4A474C4E
5A574267453733FF
FF75737E7B7B7D8062886F5F7985766179837F87938D727886948A6E7E8286818094828C
7E746991786985878A87828A9095908C927B78788A7286928D8E8A717F8F76675866596C
7E8E97A6886E7B909F795E5A59676A62646B75927B7A91838880867F887D7087745D91A3
816F8A7880817E81897E95798984819D677F7E7B8B806C86867E75688C856E80907E8A74
83757E89906E6C70887E7577828777797C6D598277807A777A74897D818C7B8975867C5B
70828B7E7C8485908F919287777B758287A1787E778C6E8CA0847F6D858F8392939A63A0
809E778C887685907E97888787A1917C73878B817796A28091768488858490848D8F9663
847B7B7A78898978948B947F778894A7A5997B847D8A90918C9E78668581898A7E897874
8878818D778C8E6C8C6C7A7677717C6C85827A735D68747E6A7D715B6A58767782797384
717083837D867B787A7B5379756F766C727B65797E4F6869705F5266605B51748758606C
576B7C7A5C717E5E7668738468737278777E7D7885767D7B7D887B8675766C6E76706F8E
7F5D597A7E826C66766C66778C6D7A5B6B5D7C7F786B6C7361616775535C6B5D51535C66
69685F5D60514C64666D674A6F5A7A6A5D5F5860685B54554A4A4340474A584E2F40525B
594643594F3E482F334146375B4543473D464659514D4457444B45424A444C39463E4448
50515535563F3EFF
FF876959897173728A5F636C7679766862848D7B777D8A92676C8D6572817D84838B988A
8A777870987A887B7A9B9588928C857E839C818A848E8F92949678849B736C657154685D
716E8A7D859673886C788F8160695B495B617E7C8A937B8A86967681887076806C6C6E71
7689858D5B8B9191957E808B8574887B877C827F8683896C7E8D72877984946F77838B95
746F6D5D4D73697E756D6D6C6B7097837E7783716C78729B69848972726F828474877E66
787176739484837A80878775827C94878774907C7A7D8A93919E80848887928FA5898B88
A583857A7B887488926B858589788975927383728D8F70857D9588838F948D83948B8C8A
758F909B988B78858894A08D9F95859A99898C7E7E9C8976905A96917B89928D96879793
799B7D838B87696F7A74897F71838B66748E737375686A7A707073696A7B696B796E767D
7F718386796B6A8275816B7270581F3F64758876604B5066636B5967666E755C5C766750
64685C5D6F495C5971807B82745D576979748D72926B7184788A7E7C767C8C8B746B667A
737178717588848C788665607685716F676A59688068766E718074747552565F5E515E6D
5964684D5E596365554F66716C6A577A6753425E565854645D67616F643E54624E595442
584D4645595E0050535A4A4332403E4D3A604F48503F4749523D3259323935484C41444E
4F3E493840454AFF
FF7B948388806973607C6973776D7E80929485929D7E847B8A79798D858A8A7775797A86
77807B71788696908F767294AA9A7C7C7E7184848D8E798E8F8782AE7F80796F5C6C7275
69915B7D95A28F997B9C7762646D76694E6582987F8C817387838E8774875F7E8375967F
76897E65807D826E8F857F8C837893878F80758F858F84828F607D90837E75876D707078
7871637E84738080725E777F6570808181808F7773807B7E8683798C78667B75757E8884
8471918B7C918F88837486957F8A937C717F8A948F8389897C7F818D87828B977D82917F
968A988B8D86928A7D8992998D7B8883768D777B78819B859B80858A8796879F969D9084
A8978C8299868D87A68D83889F947F8EA587837F919891799178788593B2978D8A99747E
A5647B747F9093768A7A7A8E8C757B82849280796E85766E7D5A576462626559627A937B
717A778CA28A797F955F00756F3200002D5C647279646B6F786274697B59636758605661
474259656A6E6A707B6F8B78788F857B78746D88938C6C7C8D778083847C838986778A71
7E798878788C8F838B71807D6E758C866C6D7371867A9168587269636A6C6D615F6E5462
4F636454695A60527669656D557D5F626F6C62504369785658594E506A5B5D4761585A60
4F476E554C2E515556354947515B6050564C6C5A5C57485B52554C5654534B3B65594B57
4A584B46525048FF
FF927D74718D8E6763725B757D7F8E7E718D857C70818C80808B8B838D90808B9E88998C
8693857F7A7E879499877E65928B8B8C82806F7982869C928483969782916E7977676372
616482887593938C73717D5A61466971716F8E82868B8F958F8A8B7B7B8D888975709574
708B8E804C84819D848B828674927C917179848C86958389847E8E9693747F96867D7A7E
70816F687C726F7E81797E80888975667F81777E9475777A787F8987857B857C9671706F
8B836C7E9D9C837A8B839C95797D777991828C8B9993857E8C79848178908C909A988496
85908491886F808B7A858B8E898F83719391A6AB8C738A9D85849C8F8F738CA97D8B8C71
8D847E82AE79A7977C7D799F888B9184998F8E947B7C938D7A80928E949093799F818193
80817F90988581817E61857D8E8375879777866D756E73655C6A535064655C6566837186
7991656B826B7E8A73665363803E0000355F6B6A7D727B7A6B798D71816A5C494D594630
3B361F4A4E5F737C76697C7D946B6D897563928E788D70837D8888998581817A76687B8A
6A60738388878A707E78755D64796877727A6D747B7576726B5F5362505B53736F6F6862
716A6163606C69626A6770746856697755616355515F505F57754A496165595D5E575562
54585551655655594B4F4D375158474745624F4455626646513B45646044314F47576D40
415F613D49475BFF
FF898A86787C84876A7C70645A77786F797A6678898477948A9B8A6E79848E7E8B989088
7D7D727A7D8D687D86757E7C8797777C8884876F88828D7688837F6C8F8281726E647168
818083836D757E815B623B706254746E7172958171869483989D85776E79897A7A6F7C7C
5C85848995838F887C6D8DA78B7D7F67818D818C9A85847F8E7E8385A1789D9177716A69
887A72716B66737576656B7A7B577A816783878B7C6B776A7B7F87807C7A6C7983768073
949A7885818488959293998E7B8897878489757A8B7A8B817C808A857A8696948380817E
8E907F7B8976777B9086788B827885788D797C798E909999938E8E808A94808179858685
9F939A9B7296908E79467E978AA480997C8F959A979D9F81979E9DA59E858E977B7F927B
7F797A7F6389877C8E748992818E918079737E68565F525A665F59656B4C705E6E4F846B
747B8E788584828882886D7975583B36746670595B65665C5E7E68646B5C4A677453321E
0000001C505D6765737470615B5781825F737281897C81617E7C7C738C6D7E86858F837F
6D8B80747F74736C7978897E8B697567706C7174626B77777D76747B736C67625C527B78
67635D54565F6D7E76706E7D5C7165867A50615F7151615A513B564D4F48415B77555946
5C4E4B6643565644625B4750564D4B504B625757543D494E5A5F655248484D554F5D4558
49544F3446375AFF
FF8A7A88727481897D8C79937E5E67758A9488867F6E777A798186808D7A7C837B878085
84A0858B7780917383979A8F7E787D898382866986918C87868C987D648290716B6E6276
75767A5B6E6D6E536A5E57605D605781748E8B818B7F8D929286867577AA9D8987958889
7774888F769A87818D72816D95706F85918D7D817D6A807C909891767B7B8C837C71857A
6D5F7D7076716E6B75787C736A775A84727E79686E897C73758474716F8F888A7D7B717A
807D8E91828C8F91959799828C797E6F7685898F818D777F7E7383788F828A9F82978A89
817D769073928D8D958B73738789818A82958A7F84918D918C77968A8B8E939073928793
908C899B9E86808A92779090909B99788FB0A09195847A8C9D9D8395969084787F878E8A
93728188848B8885848C84758192909178667E5E737B595E5055494E516058685169715E
53869194887C817B8E7892735B6C7C655684586A6F72777E866B76637175715E4C483300
00000000414C526B6F647B87718F7674867B786B697676835E887A6A938F717177758F82
997B787B8777878470747C6B728A698D7579846E706A756172604753605E77686C55545C
5E726C446A70625C6D4D5B676877664F705C70685F686F505B675F59655C495148456550
40645B46535A4B495C4E575B574954545E7357413B51483D4B5B67625C6055604E414A3B
5B514861424C4FFF
FF7C8E7A948D8E82848F967B6D757C797B79938B88819484787271769094878577687D8A
8090887F7892979287928A959E8388909D918386A687818F81937D9376937A797A867477
896F686D695F6C66675D69606E69678D8B7D848674978667868E80967073A18E87799D8D
897977908E878880768A859D72977387718889938B807789866383807888818D7079717A
768C8A767A655D6A6A8579717F788883817571738E866F7D766A909C9C7486887B92898F
797E828E8F877A9B8877877B998B88A08E7E7790827E7D9F92A4818A93737786A28F877C
988D8A9AA08172977D8D8076879C8F84907A7F8A888774947397977B73809C8989938A9B
9B949D8B917D8B92A18A8B959F9291969D84968D8DA4729F7472A2919598758A828C7E7B
84817F93917C817A8A90868474788C6464626B615B67695A49525B595A5946294D65644E
81747B6F87848A6B777A8081716B6F928386718D7A747472898278798A80615147361A00
00000000295E69857E80786A79787685808383958D66789883778E797F96847B9587707E
8684838C7B7A8B786A7E79696F665F677679646A816C6A5F5E6B57755B6A5661586A6883
68653C5861716A5960665D6B68697F75757A6A63645252667271567E666B726153535F4F
604E62434A526A56435133546D6560585859576649555259676A575945615C5746564D5E
4E455044434242FF
FF839F877E757A79747D78967C6C86836676677A74876C7F847E8C8F718C907BA97F936C
807E887E7C7986898B868A847E9A957C757F8D82807A8D9F99909D7D7C9089867E6A7E6C
6461626253634A4F6C596C717890827E726E848D9C9D907E8D7B9E837D8B9A958A8D7E8F
797F878B8E7A808685809188818A717892877B7F8A8F97848E6E6484768F937C818A8475
7B7E707777767E636B627D6C828A5F606E69757071688D7B838D6C6C8184816D797EA27E
788C818F8A999292A09090887B7C9A909984837E8F7E8A7D70868B9679867B7D89827574
858F7E666B8084818E8B87829B7D7E7D938A81A09F91A4959BA18B94B18F84737378888A
9D95848F928E90948B9A9D8B82887E9378947B90A592A5927E7783798F849C9796977484
868A867D9F9480617D7A75787D897A97877C5E7B655A4F2B715D6A647064676F634B5356
59706F846B7E8B9C898B866D827F89826F95858B82787D7F8578627B8164646040562900
000000000065896368717C85717D8B748598918F9285817E8C9888838283839076997F81
907C7C91786F5E787C786B72806E7560704F7365827773697F6E7C806657726061554F66
5C62675967646C5C6559744C576F747869476C51524F496A67846C756F5F5F614C565857
593F5054455855476052534E536064685A625B4A4338616757384E4D5E55525A6655553F
56625C3D335D57FF
FF806876817F6465886D907D80867C907374625B7C6A7E806A787675728A74816C797C7B
69918A94726D8376A08A8B848A8797818A838398837B7D8D8C9894848EB09A9488827B72
75544A5D615E63614E67637D676E818D928C7F789192867B7A90728A9A958C92969BA18F
91977D8F778A929E7B7577898480827A928272948F8282905B797D7B70637A7776767773
71788F835C5D97696D68867C757C7B68837E7B7D7678736D837E886E8A7A7F74877E8E8C
8E7D8F8E797A999A948F91888787978196947D7A9A6F7E898A8A8E948F8987A389898A84
A391847B999D7C9C89A1948974939C7C7D8670819B8D869B8B9296A27F8E9B9C9F9C8C82
9F80928B868CA08A7FA09A8D978B898EA2A5999D909BA275A5988D9681908C9980929785
8A8C7C82777077897783908DA1827D746B68777D7762446A5C6C556C6F5259666F616553
5765827C8C8183658AA07987606B7979A98975958D88827B8E816A6F6C75636767514400
000000000053687A758A6A777E7F917D7C7F947F7F948D5F8D6D838B7B908A9884808C6F
807D9174778C967D7B7265716F757B7B6F706D5F4B796A6F75746A71737A54675370575F
5C54637D54795863656065666A706E52516046625D545F497161786A656A694E5F606754
6A5B5B576D4D494D4D57683B6B5D68376B643E4A48544A49695E553D5353344760674E53
5555373C4F3A43FF
FF8C8C7F8D895B7776716C81728076698058756D666F697769767E7B7D6F818188777378
887F9B927B848A9A747D8E8896858081898F8A96AA91848F7C869B6F8999958B8A877777
65647664616D5F57727D6D8A7C72808C6F7F848B998D8F797F858D708D7C7D87898B7A7C
8D7F9D7E7CA38C8A949176867C827B857494988184897D786A6B7E7D737F747C84707D78
60677A807880806B7D6F729278827D7C6F577A7084787A8870797596896F7482808D888F
8FADABA195908A81968680B3A0A8968F7F7A74877774799290917E848F927F9B85868389
838F80968E629A7F85757C939D999A968A957986939F89759AAD8D8D8B97777A925D898D
8F72759EA09A838F808F90918E928C948DA6A78A92A6909AA880969CAB8EAB9E99909188
758D8385888E898484979D80718C7182725F5D394A6155577069727E7C6A736251492938
5C516C627B9196958E828775927D9090728183708E88826C75767568826660655167362B
020000035A6C6E75757E7E8D688E766A9675798074856D8E7A738D8B7B749B8DA29F8188
8075828785909C75638A6E858A6F62607A7373776F6F8782636F63706E657A5E5D787776
75555F605D76636259536C68816854684E62675B467B655350476A6C7B7275633F625269
61705251404748545A5B4F5F3E5844605C62445659496463633E584539544E42516B6D5B
45493C3F585353FF
FF816D786E757D969C8C797F88807A758289686578827D6E6E69687075726C846C818E8B
81826D8296888A8FA08F94989287919692889B8F68AA8A8F8F848288908F8D9386756965
778370646D867A726F697B748C8386917674829190819F8E8D7D858A8288787D7B92978E
948586826F917894848D79947B89897986989395898F86948280706B8167767985848080
6B878A7B788778737C70957C855B666474828183746E8684777781838379828699827F6A
84848B96977F82908BA08D8795999588907E9A859596827B987F8D95897CA491938A9E95
808F817C8991758C879CA17B6F7E888E918D8088899098997A8C98A49F8A8197A87F8B97
809492A49C81A3988B75A780899A997599A18EA98D9798B49587819D8EA08990928C7E8A
79888A9D948A8C79938A83888F7C7F7373545E695D5870667366586964766D6D5A555656
5A6A77688B9F999489918D837C7D91728D8583778379878691817977798A8B7571616571
5E414A786B7266837D69829B9B90826E8E9985A69182857A7B9487858B95919A6C91858E
86807C6E71817C70847A907E927A6B775E707471745964667C71636E6A875A6B6E625B51
6C64645D81706D637F6C5A615E745F6B6D4A5E77625365535F5D6B726962546966605354
583D59536A574058535C3C566F5D5B7B4763464B4A555951555451403E5C42565466584F
4B4E4757455E5BFF
FF8F7B807E88737D9487737D85767B617D6F768C5967828093587D607A6D6F768E9E8E9D
81878F708996948F8B8C8A8D979094838688A29995968B828F8E918D98707F7587937F80
927C708D845E7783887F79A2808C8A6D69907592778875797B8D947E7F8D8F8682798480
878E959596919784818F8E79998A8B847680799880626A94876C8A7D696473787160695D
727363707A827B7583896E8B65737D827A7B71637E677364738A81808B7B9593858E8B8D
957E998A9295989A7592A08A94A598A2959C80A094969EA382898380958E979C95808C92
7C8B8B8093848196A2A4626BA49478777F81818C8886856684939F8F8F758E9B838A9791
9B8D8DA1898D8E8E7A8A999B8D9E7A869BA0AA818BA790889D8EA37E8AAA8E7690779490
859B74899F8282757C69817B8199787469586B6962636B5A67686077807589766C5C5C57
5E60526F86738D8D9A8F7F929098847E917B7472878B8B676A70837F777B51796B706D78
6770736C6761896A7A90917C749B8983888D8B8A827E89847E878E9067817B768F8F8879
7E7D6C7F748075716178817761666172717E668671785B6F7A7556596166807C53545671
5151536A5265526E6E5C5E5B6C605C7A757F7F6C57616E685A77705B7363624D5A557667
4F4C57655D595F4C624545415A6051516057695D5A8157675B5B4E4D4E4A3E3A4C575A6D
5C3E4C5E654F49FF
FF91A0917E796E7473948E7A868466627F7493768A6D81816F89757C8077698E9B8F8C84
96877C7E94978E78918E8EA38D9AA38793A7818E94A09C7A8C86837B7F9C8A749791948F
7B718B7D89858B9183707D90888F7F9197798B899D859191968389A9A088897C958D618E
9685977C92857A88707C89958A7F796D918B757A82897B7D85866E7C798C728489747773
7E776D78797C6F7C88767063736A7F6E807B8A936D837F87887587898488838C8F7F9C88
7FA0919F9AAC948D9D959499949C96879B858CA08D768F899E8A9E95959599A08F837E8A
7F86909B727B9873958198787B81908A8A829E83739A909AA0888F908992859B95827B97
9194A986A4939984788E929B8D83A49EA9A69B9AA296967E7B7A8499937894A5908A788B
897B96839D9193A59879836B847883826761555C747B5F867D6388919393858360786666
5A6870727A748A8D859298968B9FA08F829BA5968D8F878F699A6C808E72656D8E686E85
7F80737A6C7E85868A8E87878D807F9A8A8A7D818D847F8B907576848C7E7BA97D8A9985
6D788F85885F7B79847765697859727A69696F6A787F7E54756B5C7F614E4A566B6C6A77
67736265535A726D6164604E8178595271746F725E735C656C4C5F5C5F475661687A6553
644A543F60686C6751646C4E6D504B5A545B6254566165596D55594D514F4449674A3F61
53514656505666FF
FF8E828698927173969C686885868B7177738484908569787E6A76887381897E8196876D
82787F7E9E939F9A8B7E9981956E8B9287848C8A9D94759892A8908A867C816F81AD9097
8F808B82849E7E7D8B94928599949292757C8E9F7D849079818F8F969A84958E878B8678
908D7D8B857E8997769C9992887B7F846F87949092847B8D93708396857E74707A957185
81917B876D8373668D8C8F7D646B706876798084717D796E7D7F8E8F8A8A93878C958E9C
85939D99A4A09D967D9B949A8E9D9994948B7D9482908D7C76907A927FA6A3878B86919C
8D8FA0728EA19485888D738A857E9A8E948E968E9475948997857A9A877A9E88A58192A6
A18486999D9A8F9788AE8DA596A5A39BA9A39CA0A69B9A97A0969A93A88894A88A85768D
7E90999A8AA28C918580849E90898A746C6C885E6461698B7B869E93758D938B7D775436
655C72666E868A819E86959B7093A2927E6E907C7E72857B6F7F76716C916F83768D8D80
93757C766B8367808C88847C8782887B757C87956F9A9E8E7476957D6A838C7E7D96958B
8A8E7B907C89776D7584747078696A6F8F666F7E6A616B8B5E6F51667D7957795A56544D
697F7D5E3D455F797155596B6574737B5C675C6E69725E63525E676076635F5E50615F45
43555F606152444E5E57515D5D59504D646756566F5D5D49475A4E5E423A515F525F6262
5A55664D755D3DFF
FF6E819B7D857A88739B928B85847F7578818E82808782888D95828A788E6C7C8D8D778E
899480AB7F9B899BA694988E8F89959D8A938D9E8F8B85918A8793818C957D8873849583
918BA4A3A3928F8E7B83889275787D8B86817A90A7927E94939C896C888992967E877E97
848C9692826A867A8BA193958D798C848775748A7F5F9666888C8E71817F676C706A7F57
758689787C83918C968C6A8573837A7687769D7A81878792888496996E7B8092998A928A
87A5A49090A8AB719EA29A9E998D929879A98D88808581A49994938FB3757F8790908A7B
9E8B7A85867688928992928B7B9EA78B75868C8483938C919393908C919C909689AC9A8C
989A8AA28F86A0A88D99AC8090909E97A3A8A78D9C95A6A0979791A48B86A589937A8789
789D8C8E8798A694888AA076848C908255675D5450668383A48D72998A797C8B877E7D51
574F6D8582948770977B8C9B9E8B959D9E99997C899F83775984957A9D7D8A8DA4997B9F
8B757D7C84787571797F7C847B7D819387848B84997A7F9185878C97869187746A916389
9B6E9D8D77847E8070828A71677E7A72656D696163796B4D71946268707A755C6475725D
6874826C6C32617B656D80796564714B707183736F676C5F6E7373746A56656A6A555968
5A4E5957585C5F58605C65605E514F665D54524E60686B62575363455B705242455C6250
5661385664583CFF
FF808A8C818E938E94817E936C81737A6385806B8996797D867A8D6E8C97878A798C7E96
9B8B838D856C7D96929FA5A08894A3978494A0968D90938E7B839593858A97928E927F87
83927C9C937B94997A807A6B7A8790839C7E718C797F7790887F826F74989886968D8A89
8694815F896D6E809E88999B89919BA38A888E817E93758E7871968184777A7C7675858A
7C7D7B788575906B787C8A7A757B796D7A6A8780778C7F82858FA0827775978B8B9C9A95
988A99909695959589959A90969FA18D8D9AA58F7589A47C80798B898F92727E6B8A90A6
9B828A908A8196978E999884978A82929F94878384828E9088A48D888C9D89A0908A9B97
9A888D7D9B9D8F8B9B9F90B18B8E99879C9AA6AE9F7E8586939495A0A090A4939E9E8377
A59193888F8C807FA5969A957D907B646A5E5C616E7B6A8E8E8C927C7DA29E7F7B79797A
59506C738C8B8A8998A99491858A84938DA19596A87D828897757D889069887370687266
789567877E826B948385818C85947C778D7E8495777A7F8D8E8E809C7E758B8D80828D8A
8488818086757977878979826C72706C5D6E666F7055696F766E6764757673696D676258
606F6E6F6669585F626864645A606E747F685F6672607C636A517D6A65565E6A5949585B
5E63545A596C6354426255805B52704F3E5E454F596E6E5D5C6365523E4A4D473E5D584F
5D627A6C5A545FFF
FF8C937E7A8D81819C8990879A896D79797F848681728A98808A86787F838C9084798790
7E81896E78777A81848F93AA8C777A8A7D8B98A186999C988E89857F9987848682909699
9C8682859C988A8F9E957492758397848084949276797864888875777C848A818681688B
6F898E84808F8F8A87A3937B8B7C7D8B8C908999846C7C7C9088708D88867F78806A816F
7C706D7A797D727B95808379676B7B7387878A808E849E83748079728A7E7E8999B0929D
98A7979E94A49797919B6E8EA7969287929D90909275898E848B86899C67916A849A7899
83A191827E89A0929891A58DA39290939586A18B9995A29788999B989E97A1949B999EA1
9489A8B18493849D87A395A2ABA0B3B8AB9094A19CA19A9AA088A6929C97999A9E90948D
9290A4758F8CA383878B8B759E9378877C4D5F74625A8471899B9196887C806378757372
685874708C777D8F8789859D959C917B85878C8A759F96769A989089897E9699987B7687
82A36475645B717F767B8E7A908E7A72907E7A8580748099A9868476848A8D888A84748E
6870698C79918A86828D8A8479667267716370755D54766F6A7D697D5D616F627063585E
636D7068645E61556E616869816456657257746A7D757F6966564F6C56675E6F5D5F645C
6D6E65574849596E555161506A79615E6F545C5D5C466373516B57465057495B62465C6C
6C6B6B6458474AFF
FF8A8287938A85788BAD7582706A70777488857EAC957C8F917B6B866088908891818A95
A18A848D8CAA9EA38D988E8A80A2928774869F809691838A9B89847E888C947B8682807D
7F8A8A936F758E9A60828383A68E7B707E9D76817F8785798AB6878E8E839D8681767F72
878896948F818B8A929798888F8C96838C668A9A8083798F9D848E70898F73746A756D8E
9470787575867090887F707E61808E8A75857B717088877D728891868A95A89B988A9894
A0A6AC7C8F988BA18BABA2AA948BAB9E92A2A26C899B846D8B77679F8F9B988792827F8D
7B938596A696879D8497A3A99F8D99939D9090A18692849D8FA2969A8E98A49A92928796
9699AFA0A19FA89FB69E9A8EBD8E9985A8CCA39692A59C90A888909B9C91A5948A958F9D
96A5838872A1909CA29D9E82879D9872615A5861725F6A6B6D9D907DA08A839387796D79
847262888686919C93908A8E939086859B849986A06BA3A279A78B8A8D8F898C7882848A
847F92818F987D6F8B7A8E927A847D9079736E878B97878294A1A07D797A948A808E8F72
7F8684947D6B787C8B7B777879716E676C67596C6B6171746F6179706074696A6F737A80
675A5B635C6F706F6A68716971717C727B64686C7576697A82666C595D605D575C67626B
54596962784D626F67666B68686740354C71685E6B5E515F5469704E5767625B47665D4B
5B5258614E635CFF
FF7C81847D747C9683837B867D7982656B7376808680A491918D86839681798F96AB8F96
8E88958A7886856F9A898D808A9A999890979683898A949CA37C8F9393766D7E7684818D
7C9079838F818A887D908590746D897D8E94956B8C818B72926B8F8993878B938B887C7B
89948093797C878EA18C8D959A8780A08A85977883838C8378797D7F9185898889748E7D
7B827E769392896F82747D7B796F687080828C9593869194788A8E9589898A93AAA69AA1
A0B991A99FA17EA0A19B8BA09E90858C919D869DA398999D7E8B8289898DA08C848B849D
A1978CA39B7FA096A78D82819FA98F8687A3959DAB8CA88C7697A391938C84979A9D9297
9EB28E9A9D839A9F93AC829F97B5AEB3B188A2898C987F8B929B888E81A89DA29F8F989B
94918797868699A096938FA494987987695D42534F5E636F7487727A8172818B836A817D
6369889496A39885998E938F7F888190958C788B89A89096A695858596948D9B94928C8A
9187818C928A917B7C818D8181899C86808178998B638E8B93B57E9E8D737A88837C7B87
547C8071908E85727F65848A8B88668769837765868E6C7074746F776C8661776B737B63
5D64676C665E856169685C797176846D796B725C7C6F73686C6D67726B8367705E5A6579
71776A7B64636F6F626C6950545B525353495C605D5662577C6B64606E5C536C67376A67
6159625E6A516CFF
FF7D79898F7B9C8A949A898A7D917168757D8A8273608B95957D7B836E808688809C9898
979582788A818E8D7EABA595A08C9DA095978B959E858A8B91A88691979496788A828894
8F829C8487A693948C81776C976D80A1968E85A78C81847F8198988E9D9986768691838C
95999092998A8A8B92909A8DA2A79F88877E9688787E8F848A889B60828E696E75857686
87847E7E96799F82737B88728264889389907CA27C899C77877F76929E9B7D9CA5839492
87949A9B8F97AAB38AA19E9C969097928D90988EA193848F8E708F9F838499989A8C919F
9FA6A39F809E8B878F949F809F8D9489A69DA3787E9F988E9F99997C90B1A292A38E8E9E
A6AC9AA8AFB2B3B4969CA0B0A691A8A2BDA7AD9AA89CACAAA6849DA79C9B9A97C6AD9C9D
8DA19F8D82A6989D8BA181949D96898162606C5C666861808974838C7C7C7A767D7D6F86
6E737D888B8E8E9EA6AAA28B978D9596997B83859C8A96858F90AF9F92918490A18D8C9B
837C87938E6E6C7B8D7D716C828681748F7B8A838999889178958D8C7E8292918B9C7875
8E65749099878E7A8A7383845D6E797A7D707B8D778E83736E7F747D687E6E728A7D6B74
656B726F8169623C5E737B60675A6B67676E7B7A747174737C6D817F5F79724D5F717C64
555268556C726D6B715A6A674F5462654E596960485B68637250516347555E5364516351
5F69635A53505AFF
FF99978A9092888B867C857684857F75859075767A737F807584818E87899692928A9093
8F8A83598A7D7C8C9E7E9F878C8A9897A9899D789793958D7F688D9E9C9C7F8D71807D90
8A90949F82918A83A19A95867E847B838D989180878D72799098999583928DA38991738A
82858C82948F899C80879D999D918B9A8A8B7E87999C638C7D8389816C7A829271837C89
7F78837B75837DA1777C6D7E967076898A869392898184A38A7EA49B9F8F95A8988D8C97
94A4A29C869699B8A2A4AAA58396877B9A929B89929A8FA393857A92928D8CA5969E9B93
9690957E8D949D93ACA6738CA0818DB38CA6A29C848F9A84899F8A8A8A939EA69E8EB1B1
A39C8193809C99A8BAAAB497A9A4C0B0838B899F999BA39E92AD9F9E98A199A29AA69BAC
A8958F95A39FA68E95A48A7A977C8B844F5F4D4E4A4862776A7E637A87777479827E7F67
7491879399919C8085947475868E988B78908D94919E928B84839891887481918BA6AB94
8E8F8E8CA079976991898496888D8D878D827F77856A879782A58D888C8B8E8C7F8C6F8E
767981987A757D76627366687D71676781576B4E7E6F72746E64837B7571776E6E6D7585
62795B6965726A658A797A6668786F6E80866A666F7A766E766D535D6C4F665F7C816651
565B697168606B7A686E6965826363636C776D4157594E51514F57604E635C575D46464C
6064575B623D42FF
FF8F7D82908E908E7C8F80847F8C746B7E90868F7C7C757A73748078918E93A58883A996
9F9F91979B93909A8C9F8994838D8D9485A4AF9E8CA1888392A57B8C948E8B7D8A7F7880
87A29E8D8B929691848E949879828A8875917D9594938D9A91957D7D988B888584958985
7E8A7FAB6C769D8D879C919D8585789E929C9F826F7E9382958D8B9672856677716A758A
978B819165907C857B927E778B908F968CA46F95A19B8D91959398A0A3959590919DA199
7F8E93A8AFB69E92B89B969C96819D969F929499967D898C95878E87AA8797909F998A96
9D91A39A90919283858DA9919192A390968993919F91A1989B9685978F9AA79B9CA0A992
B2A78EAAA3919F9AA2AF9EA4ACB4BC98B5B89A929EAEA0A59E93AB979C96AD968DAAA4A9
93AAA0A2859C8F9693968A9180847F8E774D6B5D69515E636F68656F707C7B7C6F707664
68707991919AA2948E998E6E879C969E979AA19494988C5C98A68EA09590888E8D857B8C
718B9F857C8A93857690917D8A857F937BA28E856A798E87908E779E9E8A8F7883838A92
8C848973637A7A755D818B7C77818D8376684D688B7F858369744F837D7F5D63766A7C7F
796C765D6877786B8376556C57627474646C778770674D67566B767A736C84696B615C66
737761615B6266548354685A66695568644E57575E61716948675E5E63596559605F4F6F
5E5B5D713E5664FF
FFA19A8E8B9887A3979F8F797199817F78838F8AA0746F77737F7F8B8A7E7C98928F78A5
8697A6A584A7988698988D8B89778B9780848E86988AA599758A908B88848A837F859984
9597A29EA499A19C92809676797F94868A8A8E8893648C9B859396927B96987E918F977A
9C9E9797919D9AA09490869290948FA0A08A889A8575857B83809C858B98A1707A8A787D
7B8F8D8C88849A96A486A09E9F94958C94909D888D9B7B998F928091A5AD9EAAA5B69A9E
90A19E9EA3918C83959498A4A69E949599A49290A28E999B9F989EA1959391938297879C
95A6A5848CA97F989DAF8C9C818D96A298A698A69A81A09695AAA2979790899E999EA69F
A78E869EA6939FA2A099A0A4BEA88FA79E95A0859AA79894A08FA194A0A2A1AFB79EA4A1
A099B399A496829A917F7079828F928091787460553F4E4D51406369757C7D7173735A7C
738E959395AAABAA8C94AB7793868EA589848E9697A395987476898C84A49B8F8A808899
86807A7A8A8F86A0916D71A686838378939C988A848C9D81847B8C8C8496868981997D80
74697B75887C7E7684707859836E6B7885605E5F758A767D7D8786807F7769678C80656D
6D456C5968756B795A7B81767A7285686466796775747960646E6660567C77585C6D6D67
6A6F6C4E55605F71686071686A515E6F6167515B4D5A56596169735F4A43717775715E6F
6B65674C615B4EFF
FF858D9C9B92A09289897A7B965D7E837993947180849580767E848B96928C989E9A8E7F
8096818A90757587887E92937798A0989B829FA07E89A99B7B8195A376797A8B786B8983
858A8592AC966A9E867A818F8F80968F9A8E90988A8973780A7D8C909E9C92AC99967D8E
8D9283839DB29491897E8B928284919B97909C7E8FAD887C937B8A9C9A88888B8080A28E
7C89878F6A6F97B08B868F777378A09090868EA28B9496A28A989489A588A5A5AB8E96A2
9DA49DA39DB5949D87A7A79EA9A1A29C9C9E9B9B897C7A9C9996A9A38FB4878EA1969495
8A959C999E96C79291929E939D8D8892A98F928896A0A98FB09596A882A19B92A6A7A2AB
9A977C94A1BAB8B1A7A78FABA9948BACA7B698839E9BBCA79AA59A9EA494A99E80A87D7B
8AA3AF958EA0AE8991928F95947F94A0855B668052614E5360624B5A6E58746A617F7B96
7C8AA699A2A798A4AB9E888CA18C849390B3A59E8B959D8479977E86987D899B857A9274
8171878886757E7F7A8A6D7BA68986777E8C8E8D95827798949B86A4B2719A958D798083
7F907B746B968281817C78787B6C8E846F756A6C828A868B60677472817D7F63766A7A62
7196787C54668883806D6C6A726E7C757C8D7E6C6C6B6A4F68675570666F655D6186735B
5978725D67664F4F6B5E4F795F656975735B6355615F5A4A5F4F57475B5F5E69525C5151
7D76564C695958FF
FFAC8D709395718B8C9265756F8C8D89888188627B80717C72767B8782A29A968D90938D
8EA0A58A988B9D948F8C9090B48A9194919F91A0A3A78489719D9798984A8A8F8C988D8B
829A8E988A898D7D80A299807D7E9C8E99879C818F909B88898791A1937993995F899799
867E8D9290828B938B94A0A1939085928F7397A28C93939E859C818285778E86909E898F
8972879286867C91B5969D90828C86958B917A8E9AA0A5AB9BACA198AEBC8EA8AF93B98D
8D9D99B08AAEB3B487ACB0A5A1A695A89A9A9DA4A1919C8B9F7297909D81A49C919B9594
928EABA1A09D8EA1968A82998CB299908294958F99B18D90A39C9A919EA18A9C979184A9
94AABDB284979CA48CA7A29EA392AFA1B4A800006DA69592998DAB94A8A0A8ABA2949497
9DAC99959A9D9E988C8AA78897858A90877E7F7A595071626558537057626C6F7081795A
7593A894AA8F8B9F8B7AA0999CA1A5AFA9849BADA2A89A77828B89856D7D7E827C847A5F
6E8B8D98779280967A788587838E90848A8F91726F6E8C91817E948D878E839090918576
7B75978583828185797D7B7975847A6E7971717B867B868D9B8182636E7D76805F667D75
766D6A6B768279726E7A8779826B746E7F666464635B5D7F725875767F725C6F6B756776
6263716D66556F766266685F776767556B7362686A714A715E62666C6368816A81716C47
5D6E69624E7974FF
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{350, 350},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005N0001GR000`400?l00000o`00003oo`3IfMUO
0=WIf@00o`3IfMUO0=WIf@00o`3IfMUO0=WIf@00o`3IfMUO0=WIf@00o`3IfMUO0=WIf@00o`3IfMUO
0=WIf@006`3IfMT2000003@0fMWI1@0000020=WIf@800000103IfMT2000002l0fMWI100000030=WI
f@800000103IfMT2000002l0fMWI0P0000040=WIf@800000103IfMT200000300fMWI0`0000020=WI
f@800000103IfMT200000300fMWI0P0000040=WIf@800000103IfMT2000000P0fMWI000J0=WIf@04
0000003IfMT0fMWI000003D0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@040000003IfMT0
fMWI00000080fMWI00<000000=WIf@3IfMT0;03IfMT00`000000fMWI0=WIf@030=WIf@040000003I
fMT0fMWI00000080fMWI00@000000=WIf@3IfMT00000;@3IfMT010000000fMWI0=WIf@0000020=WI
f@040000003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT00000<03IfMT010000000fMWI0=WI
f@0000020=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT0;03IfMT010000000
fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT000001`3I
fMT001X0fMWI00@000000=WIf@3IfMT00000=@3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI
00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0fMWI0080
fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@00000_0=WIf@050000003IfMT0
fMWI0=WIf@0000000P3IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI02/0fMWI
1@0000001@3IfMT000000=WIf@3IfMT000000080fMWI00@000000=WIf@3IfMT00000<@3IfMT01000
0000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT01@3I
fMT001X0fMWI00@000000=WIf@3IfMT00000=@3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI
00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@0^0=WIf@050000003IfMT0fMWI0=WI
f@0000000P3IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI02h0fMWI00@00000
0=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI02/0fMWI
00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI
000002l0fMWI0P0000030=WIf@040000003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT00000
1`3IfMT001X0fMWI00@000000=WIf@3IfMT00000=@3IfMT01@000000fMWI0=WIf@3IfMT000000080
fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@0/0=WIf@040000003IfMT0fMWI
00000080fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@00000]0=WIf@040000
003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@00000^
0=WIf@030000003IfMT000000080fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WI
f@00000_0=WIf@030000003IfMT0fMWI0080fMWI00@000000=WIf@3IfMT000000P3IfMT010000000
fMWI0=WIf@0000070=WIf@006`3IfMT2000003D0fMWI0P0000040=WIf@800000103IfMT200000300
fMWI0P0000040=WIf@800000103IfMT2000002l0fMWI0P0000040=WIf@800000103IfMT200000300
fMWI0P0000030=WIf@800000103IfMT200000300fMWI0`0000030=WIf@800000103IfMT2000000P0
fMWI003o0=WIfEl0fMWI003o0=WIfEl0fMWI003o0=WIfEl0fMWI003o0=WIfEl0fMWI003o0=WIfEl0
fMWI003o0=WIfEl0fMWI000F0=WIfOl00000B00000010=WIf@005P3IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0:
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0:
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0:
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT02@3IfMT200000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0>P3IfMT00`000000fMWI0=WIf@0k0=WI
f@030000003IfMT0fMWI03X0fMWI00<000000=WIf@3IfMT0>P3IfMT00`000000fMWI0=WIf@0k0=WI
f@030000003IfMT0fMWI00X0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WIfD@0
fMWI0@0000010=WIf@003P3IfMT2000000H0fMWI00<000000=WIf@3IfMT0o`3IfMU40=WIf@400000
0@3IfMT000d0fMWI00@000000=WIf@3IfMT000001@3IfMT00`000000fMWI0=WIf@3o0=WIfD@0fMWI
0@0000010=WIf@003@3IfMT010000000fMWI0=WIf@0000050=WIf@<00000o`3IfMU20=WIf@<00000
0@3IfMT000d0fMWI00@000000=WIf@3IfMT000001@3IfMT00`000000fMWI0=WIf@030=WIf@1B0?oo
o`2GUiL0Z:RX092@T02QXJ40ZZZZ0:6QX@28R8P0Y:BT09BDU02FUYH0Z:RX0;2`/02SXj<0WYjN09ZJ
VP2KVi/0XZ:R0:BTY02QXJ40YjNW0:^[Z`2`/;00YjNW09^KV`2f][H0Zj^[08^;R`2^[Zh0YZJV0;2`
/02XZ:P0W9bL0;6a/@34a<@0]kNg0::RXP2m_Kd0_;bl09ZJVP2UYJD0UiNG0;^k^`2_[jl0YJFU0:VY
Z@2a/K40Rh^;0;^k^`2][Jd0OGem09^KV`2IVIT0Zj^[09RHV02TY:@0W9bL0;jn_P2b/[80/K6a0:b/
[032`/80b/[:0;Zj^P2TY:@0_kno0:NWY`3IfMT0hn?S0;^k^`2`/;00][Jf0=3@d036a/H0_[jn0:RX
Z02[Zj/0/K6a0:j^[P2o_kl0d=3@0;no_`80_Kfm02h0b<S80;:b/P2ZZZX0W9bL0:FUY@2a/K40Y:BT
0;no_`2m_Kd0`<3008^;R`25QHD0][Jf0<30`031`L40Y:BT0;Jf]P30`<00SHf=0:2PX02SXj<0`<30
0:f][@31`L40^KVi0:6QX@30`<00UYJF0;bl_02c/k<0_kno09FEU@2e]KD0`l?30;Fe]@2RXZ80_Kfm
0<W9b@3Cdm<0^;Rh0:b/[03=cLd0aLG50;^k^`3@d=00b/[:0P2h^;P0W03Lg=`0a/K60<30`032`/80
g=cL0;:b/P2m_Kd0Xj>S0<71`@36a/H0];Bd0<30`02XZ:P0Zj^[0;Bd]02_[jl0_[jn0:^[Z`2e]KD0
WYjN0<[:bP2h^;P0XJ6Q0:RXZ02d];@0]kNg0:6QX@2`/;00[jn_0;6a/@2ZZZX0VYZJ0:ZZZP2d];@0
_;bl0:6QX@2WYjL0YZJV0;Ng]`3@d=00W9bL0;Jf]P27QhL0/[:b0;Bd]02TY:@0/K6a0:f][@2a/K40
Y:BT09VIV@2?Shl0WIfM092@T02?Shl0U9BD092@T035aLD0[:b/0:2PX02][Jd0XZ:R0:j^[P2CTi<0
/;2`08J6QP2=SHd0Xj>S0:JVYP2NWYh0SHf=0:2PX02ZZZX0UYJF08>3P`2HV9P0Xj>S0:2PX02QXJ40
VIVI09:BTP2WYjL0Q8B408F5Q@23Ph<0P82009RHV02@T900V9RH07moO`2HV9P0Shn?09JFUP27QhL0
WYjN09NGU`2BTY80Zj^[09RHV02OWil0UiNG09fMW@2GUiL0VIVI09JFUP2RXZ80YZJV09JFUP2TY:@0
Shn?0:>SX`1kNg/0Y:BT07moO`2DU9@0XZ:R08b<S023Ph<0O7al08>3P`22PX80T92@0:RXZ02;Rh/0
R8R808B4Q02<S8`0TY:B08R8R02WYjL0XZ:R0:6QX@2=SHd0K6a/055AD@1EEED0DU9B06=SH`2ATI40
NWYj0:6QX@1lO7`0LW9b07YjNP1ZJVX0IFEU06UYJ@1`L700Q8B40:f][@2SXj<0RXZ:07inOP23Ph<0
SHf=07AdM080Q8B400L0Shn?07YjNP1]KFd0Ph>3079bLP26QXH0H61P0080R8R800l0VYZJ0861P@2O
Wil0QhN7092@T02CTi<0UIFE07moO`1PH600Ogmo08b<S01IFET0TY:B08:2PP3oool01P3IfMT10000
0040fMWI000=0=WIf@040000003IfMT0fMWI000000D0fMWI00<000000=WIf@3IfMT00`3IfMT03`3o
ool0Vi^K0::RXP29RHT0QXJ608B4Q02?Shl0VIVI09fMW@1UIFD0QXJ609FEU@2VYZH0P82007inOP02
09^KV`0l09:BTP2HV9P0QhN70:2PX02LW9`0RHV909VIV@2>SXh0Vi^K0:6QX@2=SHd0TI6A09FEU@2f
][H0TY:B0:NWY`2EUID0[:b/0:ZZZP2XZ:P0Zj^[096AT@2SXj<0MGEe09RHV023Ph<0Ti>C08j>SP2D
U9@0Vi^K09>CT`2@T900OGem092@T02=SHd0TY:B09RHV02`/;00VIVI0:2PX02SXj<0Vi^K08Z:RP2<
S8`0X:2P0:6QX@2f][H0Xj>S09JFUP2WYjL0[Zj^0;2`/02PX:00XJ6Q09>CT`2KVi/0[jn_09ZJVP2N
WYh0UiNG0P2NWYh02`2CTi<0Y:BT0:2PX02f][H0U9BD09nOW`2:RXX0P82009nOW`2TY:@0/k>c0080
X:2P05X0[jn_09^KV`20P800RXZ:09fMW@2RXZ80]KFe09jNWP2ATI40Vi^K08^;R`2TY:@0VIVI09ZJ
VP2IVIT0T92@0:b/[02@T900Zj^[0;:b/P2OWil0[jn_0:>SX`2GUiL0_kno0:ZZZP2QXJ40ZJVY0<_;
b`2=SHd0alO709VIV@2WYjL0[jn_0;Zj^P2b/[80^k^k0;2`/02ATI40a<C409jNWP2HV9P0YZJV0:FU
Y@3<c<`0/[:b092@T02IVIT0XZ:R09jNWP2/[:`0XJ6Q0;6a/@2_[jl0TI6A0:>SX`2UYJD0`L710:f]
[@2[Zj/0L71`09nOW`2ATI40WIfM0;bl_02OWil0VIVI0;>c/`2UYJD0[:b/0:NWY`2YZJT0/;2`0;Ng
]`2VYZH0ZJVY0:ZZZP1PH600[:b/0:6QX@2PX:00ZZZZ07IfMP23Ph<0O7al07emO@2TY:@0T92@08f=
S@26QXH208N7Q`040;jn_P2MWId0Jf][08^;R`80OGem00/0UiNG08Z:RP2=SHd0[:b/08R8R02FUYH0
RHV907]kN`2>SXh0RXZ:09nOW`0207moO`0407AdM02FUYH0RXZ:09NGU`80SHf=0P25QHD05@1aLG40
U9BD0:BTY02;Rh/0Ng]k09VIV@1dM7@0R8R807inOP2DU9@0Ph>308b<S023Ph<0W9bL08J6QP1ZJVX0
Ogmo08^;R`1`L700Q8B408n?S`0208F5Q@0608j>SP22PX80PX:208B4Q023Ph<0QXJ60P1bLW80B01j
NWX0K6a/09>CT`1kNg/0SXj>09ZJVP21PH40Ng]k0861P@20P800Ogmo08R8R01nOWh0JVYZ08V9R@1h
N7P0PH6107inOP2EUID0LW9b09^KV`25QHD0OGem08J6QP0e=CD0DU9B051@D01]KFd0T92@07EeM@1[
Jf/0P82007]kN`1MGEd0EEEE06EUI@1=CDd0Ng]k07inOP20P800M7Ad08j>SP1eMGD0O7al04m?C`1>
CTh0MgMg07QhN01TI6@0LG5a06][J`22PX80Hf=S061PH01eMGD0L71`08Z:RP23Ph<0IFEU06YZJP25
QHD0QXJ6071`L01_Kfl0NGUi06QXJ029RHT0RXZ:04i>CP1ADE40Ogmo0?ooo`H0fMWI0@0000010=WI
f@003P3IfMT2000000H0fMWI00<000000=WIf@3IfMT00`3IfMT0S@3oool0QhN708J6QP23Ph<0SXj>
07AdM026QXH0W9bL07QhN02@T900SHf=09BDU02GUiL0Ti>C09RHV02QXJ40Zj^[08N7Q`1oOgl0WYjN
08B4Q02=SHd0OWin08V9R@2ATI40[:b/0:6QX@2BTY80Q8B40:NWY`2>SXh0VYZJ09fMW@2:RXX0Ti>C
08b<S02WYjL0^;Rh09ZJVP2VYZH0V9RH0:2PX01iNGT0Vi^K0820P02OWil0VYZJ092@T02?Shl0Ng]k
08f=S@2GUiL0U9BD09ZJVP2EUID0`l?309:BTP2`/;00R8R809fMW@2?Shl0UYJF09>CT`2=SHd0XZ:R
09>CT`2][Jd0U9BD09jNWP2BTY80/K6a0::RXP2LW9`0Z:RX0::RXP2SXj<0/K6a0;Bd]02MWId0UIFE
0;Jf]P2?Shl0Ti>C08^;R`1gMgL0TI6A0:f][@2<S8`0VIVI08b<S027QhL0UYJF0:>SX`27QhL0SXj>
09ZJVP2KVi/0SHf=09>CT`2:RXX0WIfM0:NWY`1lO7`0WIfM07YjNP2UYJD0]KFe09^KV`2XZ:P0Xj>S
0:ZZZP2UYJD0WYjN0:n_[`2DU9@0][Jf0:ZZZP2][Jd0Xj>S08N7Q`2GUiL0^;Rh0;Fe]@2NWYh0XJ6Q
09BDU02WYjL0WIfM09bLW02BTY80WYjN08J6QP2<S8`0T92@08^;R`2RXZ80a<C40:BTY027QhL0OWin
0;6a/@0209ZJVP1>0;6a/@2HV9P0XJ6Q0:NWY`2PX:00W9bL0:BTY02NWYh0]kNg09nOW`2LW9`0[:b/
0<;2`P2b/[80/K6a08R8R02QXJ40SXj>09>CT`23Ph<0SXj>09VIV@2LW9`0Shn?0:RXZ02PX:00Ph>3
08n?S`2FUYH0PX:20:ZZZP2>SXh0Rh^;096AT@1hN7P0RXZ:08j>SP2QXJ40TY:B09JFUP2c/k<0XJ6Q
09nOW`2NWYh0SXj>08^;R`1mOGd0QHF508j>SP2EUID0R8R80820P028R8P0S8b<08V9R@2@T900SXj>
08b<S01mOGd0Q8B407UiN@1lO7`0SXj>08F5Q@2;Rh/0Ng]k08R8R02MWId0QXJ608V9R@24Q8@0PH61
08Z:RP2MWId0Ti>C0:JVYP2GUiL0R8R80P22PX805@1cLg<0SXj>08f=S@1kNg/0Ph>306a/K01iNGT0
PX:207moO`1/K6`0MGEe07IfMP23Ph<0UiNG08F5Q@20P800VIVI08R8R01bLW80Ti>C07MgM`0207in
OP0X06m_K`29RHT0NGUi07IfMP1`L700NGUi08R8R01iNGT0Rh^;07UiN@1jNWX0R8R808B4Q01mOGd0
WYjN07QhN023Ph<0O7al05]KF`1VIVH0Bd];04i>CP1;Bd/0M7Ad06EUI@1jNWX0Ogmo09:BTP28R8P0
KFe]05iNGP0n?Sh0D51@05ADE01WIfL0HF5Q06IVIP26QXH0Kfm_06][J`80SHf=01X0L71`08F5Q@1U
IFD0KFe]07IfMP1OGel0JVYZ079bLP1WIfL0JVYZ06IVIP26QXH0P82006m_K`1SHf<0N7Qh06i^KP1`
L700IFEU07moO`1SHf<0RXZ:08:2PP1dM7@0GEeM0?ooo`H0fMWI0@0000010=WIf@005P3IfMT00`00
0000fMWI0=WIf@030=WIf@090?ooo`2DU9@0T92@09bLW01cLg<0N7Qh09NGU`1bLW80Rh^;0080U9BD
00L0UYJF09RHV02RXZ80T92@096AT@2IVIT0T92@0080QXJ603h0U9BD0861P@29RHT0Z:RX0:NWY`2@
T900YjNW08f=S@2VYZH0Y:BT09FEU@2QXJ40XZ:R08^;R`2OWil0ZJVY08V9R@26QXH0T92@09RHV02?
Shl0T92@08b<S02BTY80Shn?08^;R`2DU9@0WinO09ZJVP2TY:@0Ti>C08N7Q`2UYJD0SXj>09:BTP2C
Ti<0S8b<096AT@2CTi<0/K6a092@T021PH40QXJ609:BTP2KVi/0XJ6Q0:JVYP2GUiL0UYJF09FEU@2=
SHd0Y:BT09>CT`2FUYH0[jn_0:JVYP2@T900Ti>C08R8R02ZZZX0Vi^K0<K6aP80SXj>0100U9BD07Mg
M`2;Rh/0Q8B40:2PX02OWil0Xj>S09bLW020P800Ti>C0:BTY02GUiL0Y:BT09^KV`27QhL0XJ6Q0P2I
VIT04`2][Jd0RXZ:08>3P`2PX:00ZJVY0:6QX@2ZZZX0[:b/09:BTP2^[Zh0YJFU0;>c/`2RXZ80YZJV
0:NWY`34a<@0`<300<;2`P2WYjL00P2f][H04`2TY:@0[jn_0;^k^`2UYJD0_[jn09fMW@2][Jd0[Zj^
0:6QX@2_[jl0];Bd0:JVYP2KVi/0U9BD0:JVYP2^[Zh0/;2`0:n_[`2NWYh00P2ZZZX0Q@2XZ:P0WYjN
0:JVYP2/[:`0RXZ:09:BTP2LW9`0YjNW0::RXP2EUID0/[:b0;Rh^02PX:00WinO0:ZZZP26QXH0Zj^[
0;Vi^@2`/;00WinO09:BTP2WYjL0XZ:R08f=S@2NWYh0T92@08V9R@2JVYX0WYjN096AT@2;Rh/0RHV9
08>3P`2;Rh/0R8R807alO01oOgl0[:b/0;2`/02;Rh/0WIfM092@T02GUiL0W9bL07alO03:b/X0Shn?
09RHV02:RXX0TI6A079bLP2;Rh/0Ogmo0861P@1mOGd0VYZJ08n?S`1iNGT0OGem07AdM020P800RHV9
09BDU024Q8@0TI6A08n?S`2TY:@0SHf=09JFUP2;Rh/0UIFE06a/K027QhL0WIfM09:BTP1`L700WIfM
09jNWP2:RXX0MgMg08V9R@27QhL0UIFE08B4Q027QhL0LG5a08:2PP2EUID0PX:208Z:RP2YZJT0SHf=
092@T02=SHd0UiNG08Z:RP2ATI40O7al08B4Q028R8P0NWYj07UiN@28R8P0J6QX071`L01iNGT0Q8B4
07YjNP26QXH0PH6107QhN01UIFD0Q8B408V9R@1nOWh0Q8B407IfMP29RHT0S8b<09BDU022PX80EeMG
03Xj>P15ADD0BDU9071`L01_Kfl0Rh^;07YjNP1gMgL0MGEe05IFEP16ATH00P1@D50205iNGP0Q06YZ
JP1SHf<0LW9b06ATI01lO7`0Kfm_07IfMP1aLG40MgMg07EeM@1CDe<0FEUI06YZJP1UIFD0OGem04m?
C`1ADE40Fe]K075aL@1EEED0O7al08F5Q@1^KVh0G5aL061PH01YJFT0MWIf06e]K@3De=@0I6AT07Mg
M`1bLW80oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0<0?ooo`2C
Ti<0TY:B08>3P`2?Shl0Ph>308j>SP1YJFT0LG5a092@T02CTi<0OWin0P2DU9@01P28R8P0QXJ609:B
TP2OWil0RXZ:08>3P`80RHV900d0Z:RX0:>SX`28R8P0V9RH08B4Q02<S8`0UIFE0:j^[P2JVYX0YJFU
09VIV@2@T900PX:20080TI6A00<0UIFE0820P025QHD00P2<S8`06`20P800QXJ608R8R02@T900UYJF
08f=S@2EUID0NGUi09BDU02OWil0U9BD08>3P`27QhL0Y:BT07QhN02NWYh0UIFE09BDU01`L700TI6A
09fMW@2_[jl0P82008b<S02SXj<0TY:B09bLW00209RHV00e0;6a/@2BTY80Xj>S0:6QX@2IVIT0YjNW
0:2PX02[Zj/0UiNG0::RXP2IVIT0S8b<0:6QX@29RHT0VIVI09bLW02NWYh0W9bL0:6QX@2ZZZX0Ogmo
09FEU@2=SHd0T92@08Z:RP2VYZH0RHV90::RXP2OWil0[:b/092@T02EUID0VYZJ09bLW02GUiL0XZ:R
0:j^[P2QXJ40][Jf0:^[Z`2OWil0Y:BT0:>SX`2m_Kd0];Bd0:JVYP2RXZ80/;2`0;no_`2WYjL0]KFe
09bLW02a/K400P2ZZZX03`2WYjL0Z:RX09ZJVP2^[Zh0Z:RX09:BTP2?Shl0UIFE08j>SP2c/k<0VIVI
09nOW`2/[:`0Z:RX09JFUP020:b/[0040:FUY@2>SXh0UiNG0:>SX`80Z:RX0:D0X:2P09bLW02j^[X0
WIfM0<30`02TY:@0[jn_09RHV02`/;00TY:B0:NWY`2JVYX0]KFe0;2`/02VYZH0Q8B409BDU02HV9P0
[:b/0:6QX@2JVYX0W9bL08j>SP27QhL0][Jf08f=S@27QhL0S8b<07alO01eMGD0QXJ609bLW02OWil0
PX:208V9R@2DU9@0Y:BT09RHV02GUiL0P82007=cL`2PX:00V9RH07]kN`1fMWH0RXZ:09BDU02?Shl0
TI6A07UiN@2DU9@0TY:B08:2PP1iNGT0Ph>306UYJ@2?Shl0SHf=06YZJP1[Jf/0RHV909>CT`2GUiL0
RHV908b<S01gMgL0RXZ:07alO02FUYH0Ph>3092@T02NWYh0R8R807]kN`28R8P0Rh^;07alO02LW9`0
TI6A07emO@1oOgl0QhN707MgM`2;Rh/0MgMg07IfMP2>SXh0Lg=c07IfMP1kNg/0OWin0820P02<S8`0
MGEe08F5Q@1jNWX0KVi^06e]K@1oOgl0Lg=c08^;R`1`L700N7Qh061PH023Ph<0Hf=S0861P@1EEED0
MWIf06m_K`1cLg<0IFEU08f=S@1fMWH0RHV9079bLP1VIVH0CDe=04Y:BP1>CTh0KVi^05aLG01CDe<0
LG5a08B4Q01dM7@0GEeM04U9B@1@D500JFUY05eMG@1EEED0F5QH07=cL`1TI6@0Ti>C08:2PP1aLG40
MgMg07QhN01GEeL0N7Qh07YjNP1OGel0Ti>C07MgM`1WIfL0Kfm_07QhN01NGUh0DU9B07IfMP1dM7@0
FEUI06QXJ01`L700IfMW05ADE01WIfL0IVIV06UYJ@1]KFd0G5aL07inOP3oool01P3IfMT100000040
fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0380oooo0820P01lO7`0PX:2096AT@28R8P0RXZ:
08J6QP27QhL0RXZ:07emO@23Ph<0Lg=c08Z:RP2CTi<0T92@07moO`2QXJ40OWin06UYJ@27QhL0Ng]k
08j>SP2JVYX0RHV90:6QX@2PX:00WYjN09>CT`2WYjL0WIfM08N7Q`2JVYX0O7al09RHV027QhL0Ogmo
0861P@24Q8@0Ng]k08V9R@2IVIT0Ph>308F5Q@24Q8@0SXj>09VIV@1kNg/0RHV909VIV@80Ogmo02P0
QXJ609FEU@2:RXX0P82008F5Q@2GUiL0SHf=08B4Q02=SHd0RXZ:0:VYZ@1ZJVX0Y:BT07IfMP2IVIT0
Xj>S0:NWY`2;Rh/0V9RH07moO`2ZZZX0/;2`09VIV@2BTY80XJ6Q08Z:RP23Ph<0TY:B0:VYZ@2@T900
Y:BT08:2PP2?Shl0PH6108:2PP2IVIT0W9bL09NGU`2LW9`0Shn?0P2KVi/04P2;Rh/0PX:2092@T027
QhL0PH610:^[Z`2;Rh/0/K6a0:b/[02ZZZX0NWYj08R8R02RXZ80YJFU0<G5a@2KVi/0TY:B0:BTY080
[Zj^0<P0[Jf]0:ZZZP2_[jl0[Jf]09ZJVP2OWil0/k>c0;:b/P2f][H0[jn_0:f][@2^[Zh0Ph>30;Fe
]@2XZ:P0ZJVY0:j^[P2b/[80WinO09bLW02VYZH0QHF50:f][@2NWYh0WIfM0;>c/`3@d=00XJ6Q09jN
WP2PX:00QHF50;6a/@2d];@0VIVI0:VYZ@2o_kl0XJ6Q0:RXZ02`/;00UYJF09VIV@2CTi<0ZZZZ09fM
W@2DU9@0Y:BT08j>SP2b/[80YJFU09BDU02VYZH0UYJF09^KV`20P800UYJF09fMW@2_[jl0R8R809bL
W02XZ:P0R8R807AdM025QHD0FUYJ08Z:RP29RHT0TY:B06a/K02TY:@0YJFU09:BTP1PH600QhN707in
OP2?Shl0QXJ60::RXP2EUID0QHF508R8R01[Jf/0IfMW07]kN`2IVIT0UIFE08Z:RP2NWYh0Ogmo09RH
V01^KVh0Kfm_09BDU025QHD0Shn?08:2PP2EUID0OGem08n?S`1`L700QXJ608R8R01kNg/0OGem08R8
R02GUiL0UYJF09ZJVP2HV9P0U9BD08>3P`2?Shl0P82008:2PP24Q8@0YZJV09fMW@29RHT0Q8B407Ad
M01jNWX0QXJ6075aL@1:BTX0UYJF0:2PX01oOgl0PX:207inOP2@T900PX:20861P@1ZJVX0I6AT07Ee
M@1iNGT0Kfm_07AdM01VIVH0N7Qh09RHV01WIfL0GUiN075aL@1YJFT0Ti>C06QXJ01QHF40GemO07in
OP2>SXh0LW9b07alO01DE5@0C4a<05=CD`1PH600QXJ606ATI01JFUX0D51@06m_K`1TI6@0HF5Q05IF
EP1KFe/0E5AD07=cL`28R8P0EeMG07MgM`25QHD0IFEU07AdM01lO7`0MGEe06QXJ01SHf<0L71`06a/
K021PH40Hf=S071`L01JFUX0LG5a06YZJP1kNg/0JFUY07EeM@1WIfL0QHF506UYJ@0U9BD0CDe=07Ad
M01jNWX0CTi>055AD@1ZJVX0MGEe0?ooo`H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WI
f@030=WIf@100?ooo`1/K6`0SXj>096AT@26QXH0NGUi09VIV@2@T900N7Qh08^;R`23Ph<0VIVI08F5
Q@1jNWX0Jf][05YJFP1;Bd/0T92@09:BTP1lO7`0V9RH0::RXP2VYZH0RXZ:08V9R@2KVi/0SHf=09:B
TP2;Rh/0YjNW09fMW@1lO7`0PH6107]kN`2CTi<0Ph>307moO`2>SXh0PH6108B4Q025QHD0TY:B09ZJ
VP2>SXh0RHV909BDU02IVIT0QXJ608^;R`26QXH0S8b<08:2PP2EUID0S8b<09JFUP2SXj<0TI6A08F5
Q@2ATI40VYZJ09>CT`24Q8@0Vi^K09FEU@80SXj>0240YZJV09bLW02IVIT0VIVI08^;R`2FUYH0PX:2
096AT@2BTY80WYjN08j>SP2CTi<0UIFE0:JVYP2CTi<0WIfM09>CT`2FUYH0VYZJ08n?S`23Ph<0PH61
075aL@1oOgl0SXj>09fMW@2/[:`0SHf=09^KV`2WYjL0WIfM09JFUP2RXZ800P2PX:006P2XZ:P0R8R8
08^;R`2OWil0[Zj^09ZJVP24Q8@0Zj^[0:FUY@2=SHd0Y:BT0;fm_@2SXj<0]KFe0:ZZZP33`l<0ZJVY
0:2PX02b/[80Xj>S0:^[Z`2VYZH0/k>c0:6QX@29RHT0X:2P0P2TY:@02@2:RXX0ZZZZ0:n_[`2KVi/0
ZZZZ0::RXP2TY:@0`<3007alO00209fMW@1F096AT@2JVYX0Vi^K0:JVYP2>SXh0]kNg096AT@2YZJT0
UiNG096AT@2NWYh0Xj>S0;:b/P27QhL0Y:BT09nOW`2^[Zh0UiNG09VIV@2^[Zh0QhN707EeM@1oOgl0
Rh^;09FEU@2@T900WinO0:6QX@2LW9`0Q8B40::RXP2DU9@0W9bL0:f][@22PX80WinO07emO@27QhL0
R8R807emO@20P800QXJ608j>SP29RHT0S8b<0820P02BTY80QHF508:2PP1eMGD0HF5Q0:VYZ@20P800
Ti>C09FEU@2[Zj/0Ph>307EeM@24Q8@0S8b<09VIV@2EUID0VYZJ09bLW021PH40QXJ607inOP25QHD0
O7al09FEU@2BTY80PH6108:2PP2ATI40KVi^079bLP2@T900MgMg09BDU028R8P0XJ6Q08b<S024Q8@0
TY:B06m_K`2FUYH208R8R00708:2PP2MWId0XZ:R07]kN`1dM7@0PH6106QXJ00207]kN`1=06][J`2:
RXX0FEUI08Z:RP21PH40SHf=07inOP1LG5`0Ng]k06e]K@1`L7007QhN08N7Q`1YJFT0LW9b061PH01R
HV80LW9b06EUI@1gMgL0J6QX07emO@1oOgl0OWin07QhN020P800MWIf08F5Q@1WIfL0GemO05EEE@1K
Fe/0Cdm?069RHP1WIfL0EEEE05=CD`1SHf<0Jf][069RHP1NGUh0HV9R06YZJP1UIFD0P82007AdM020
P800QHF506][J`1WIfL0RXZ:06UYJ@1_Kfl0N7Qh06IVIP21PH40J6QX06a/K01aLG40Shn?06ATI01=
CDd0Ng]k06i^KP1IFET0Lg=c05QHF01ADE40ATI606QXJ02;Rh/0Hf=S06ATI01ZJVX0Jf][06=SH`3o
ool01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI01X0oooo08N7Q`2>SXh0
QhN707MgM`1aLG40PH6109fMW@26QXH0Ph>306e]K@1mOGd0TY:B08f=S@20P800S8b<09VIV@2HV9P0
PX:209ZJVP20P800XJ6Q08b<S027QhL0QXJ608j>SP80SHf=00T0VIVI0:VYZ@1oOgl0P82008:2PP1_
Kfl0QHF507QhN02OWil00P2;Rh/0S01oOgl0RXZ:07moO`1_Kfl0Shn?071`L02IVIT0SHf=08Z:RP2=
SHd0Rh^;09nOW`1_Kfl0X:2P0::RXP2JVYX0Rh^;08F5Q@2ATI40V9RH08Z:RP2VYZH0Shn?08F5Q@1i
NGT0WinO08b<S027QhL0U9BD09jNWP2OWil0UYJF0:ZZZP2<S8`0Shn?0861P@25QHD0Q8B409BDU027
QhL0U9BD09JFUP2e]KD0WIfM08n?S`2MWId0TY:B08^;R`21PH40SXj>08^;R`2ATI40TY:B0820P02>
SXh0PX:209nOW`2f][H0[Jf]0:FUY@2KVi/0YjNW08f=S@2CTi<0TI6A0;Fe]@2MWId0Shn?08b<S02/
[:`0U9BD0:FUY@2QXJ40Zj^[0:VYZ@2>SXh0][Jf0<o?c`2UYJD0Ti>C0:FUY@2d];@0W9bL0;:b/P2c
/k<0TI6A09>CT`2[Zj/0TY:B0:RXZ02a/K40VYZJ096AT@2QXJ40Xj>S08f=S@2RXZ80SXj>09ZJVP2E
UID0Shn?0;>c/`2/[:`0X:2P0:VYZ@2WYjL0VYZJ09:BTP2JVYX0[Zj^08f=S@2SXj<0T92@0:2PX02`
/;00ZZZZ08b<S02ATI40][Jf0;2`/02DU9@0Ph>30;Vi^@2<S8`0X:2P07emO@2BTY80Xj>S09NGU`2V
YZH0/k>c09RHV02VYZH0SHf=09^KV`28R8P0P82008B4Q01aLG40SHf=0P1iNGT0Q@1cLg<0G5aL06m_
K`1fMWH0PX:207]kN`2ATI40YZJV07YjNP28R8P0WinO0:j^[P1aLG40Rh^;07alO022PX80Rh^;07Ee
M@2?Shl0RXZ:08B4Q021PH40OGem07alO02EUID0Shn?08:2PP27QhL0O7al08Z:RP1hN7P0R8R809RH
V02GUiL0Rh^;08J6QP2:RXX0PH6108R8R027QhL0[Jf]092@T025QHD0Y:BT08b<S02FUYH0SHf=08V9
R@2WYjL0PH6105]KF`1^KVh0MGEe07alO01>CTh0EEEE0820P01aLG40QHF508>3P`28R8P0PX:207in
OP20P800GEeM07EeM@1]KFd0IFEU03lo?`1iNGT0QhN706a/K01ZJVX0N7Qh06=SH`1^KVh0PX:208N7
Q`1YJFT0QhN706m_K`1[Jf/0N7Qh07AdM01]KFd0HV9R05iNGP1RHV80CDe=05MGE`1cLg<0HF5Q05QH
F01CDe<0EUIF03/k>`1YJFT0GEeM06MWI`1hN7P0M7Ad07=cL`2IVIT0M7Ad065QH@1^KVh0NWYj05mO
G`1aLG40J6QX07moO`1XJ6P0IfMW075aL@1ZJVX0FEUI05YJFP18B4P0HV9R04m?C`1;Bd/0Lg=c069R
HP1ZJVX0N7Qh05iNGP1DE5@0R8R806i^KP29RHT0L71`06QXJ03oool01P3IfMT100000040fMWI000F
0=WIf@030000003IfMT0fMWI00<0fMWI02P0oooo08B4Q01bLW80Ph>307YjNP2RXZ80Ogmo07YjNP2:
RXX0Vi^K06a/K01_Kfl0NGUi08^;R`1]KFd0MGEe08V9R@1jNWX0PX:208Z:RP2MWId0Q8B407]kN`2<
S8`0SHf=08R8R022PX80VIVI09ZJVP2@T900R8R808V9R@2<S8`0Ogmo0::RXP2DU9@0PX:207QhN026
QXH0MWIf0P1jNWX0A027QhL0RXZ:07=cL`29RHT0V9RH07emO@2BTY80Shn?09bLW02FUYH0Y:BT09^K
V`2UYJD0QhN709ZJVP2DU9@0Zj^[09FEU@2JVYX0Shn?08R8R02c/k<0T92@0:BTY024Q8@0WinO0:j^
[P2FUYH0Xj>S092@T02SXj<0V9RH09JFUP2ATI40MWIf09fMW@2DU9@0RXZ:0:2PX02<S8`0UiNG0:NW
Y`2^[Zh0Vi^K07emO@2>SXh0P82009^KV`1bLW80SXj>08Z:RP2GUiL0Rh^;09NGU`2IVIT0Z:RX0:VY
Z@2d];@0RXZ:0;Rh^02KVi/0U9BD08V9R@26QXH0SXj>0;Jf]P2DU9@0X:2P0P2UYJD0B02SXj<0ZJVY
0:>SX`2_[jl0XZ:R0<;2`P2TY:@0Xj>S0:2PX02TY:@0^[Zj0;:b/P2PX:00^KVi0;:b/P2JVYX0SHf=
0:JVYP2@T900VIVI0;6a/@2SXj<0WinO09JFUP2NWYh0VIVI0:6QX@2;Rh/0UiNG07inOP2TY:@0TI6A
0:^[Z`2UYJD0Ti>C0:6QX@2OWil0[Jf]09BDU02PX:00XZ:R09RHV02UYJD0/k>c0:JVYP2@T900[Jf]
07emO@2GUiL0WinO0:2PX02JVYX0R8R809BDU02IVIT0PH6107moO`1cLg<0PX:208J6QP2VYZH0WIfM
0::RXP25QHD0WYjN07moO`29RHT0MGEe06IVIP1mOGd0FUYJ08^;R`80RXZ:01h0WIfM07]kN`1jNWX0
UiNG09RHV022PX80Shn?09>CT`2:RXX0Q8B406MWI`2>SXh0Shn?06EUI@1lO7`0QhN708j>SP25QHD0
KFe]07IfMP1hN7P0MGEe06][J`1cLg<0MgMg079bLP2;Rh/0M7Ad08B4Q021PH4208:2PP0609bLW026
QXH0QHF507=cL`1lO7`0Ti>C0P29RHT0F02@T900QHF507AdM020P800Ng]k06m_K`1LG5`0BDU906IV
IP1QHF40De=C079bLP1UIFD0NGUi079bLP23Ph<0N7Qh06m_K`1cLg<0QHF507UiN@1/K6`0MgMg07mo
O`1[Jf/0EUIF059BDP23Ph<0FUYJ06][J`26QXH0L71`07UiN@29RHT0Ph>3061PH01YJFT0LG5a07al
O01cLg<0L71`05MGE`1JFUX0HV9R061PH01SHf<0EeMG069RHP1:BTX0Fe]K05EEE@1jNWX0L71`06YZ
JP1fMWH0Kfm_07EeM@1bLW80Lg=c06UYJ@1aLG40NGUi06i^KP1eMGD0IVIV079bLP1oOgl0IfMW05YJ
FP1MGEd0IfMW05eMG@1VIVH0IFEU07EeM@1VIVH0L71`05iNGP1/K6`0FUYJ08B4Q01UIFD0K6a/07Ad
M01oOgl0O7al06e]K@3oool60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0
1`3oool0Q8B409nOW`2=SHd0OWin08R8R01nOWh00P1mOGd0A`1hN7P0Ng]k06a/K02GUiL0S8b<075a
L@1`L700P8200861P@2GUiL0PX:207IfMP1bLW80S8b<09BDU01iNGT0RXZ:08>3P`26QXH0VYZJ08J6
QP29RHT0RXZ:08F5Q@1jNWX0QXJ6096AT@1oOgl0KVi^05]KF`1cLg<0PH6105MGE`1SHf<0MgMg08>3
P`1nOWh0SXj>07MgM`2EUID0SHf=06ATI023Ph<0SXj>09JFUP22PX80RHV9096AT@2JVYX0Y:BT09bL
W02>SXh0UYJF09VIV@2ATI40Xj>S07inOP2QXJ40YjNW0::RXP1mOGd0Q8B409JFUP2>SXh0WYjN08^;
R`25QHD0TY:B09RHV02VYZH0T92@0080TI6A03@0Rh^;07YjNP1eMGD0PX:20861P@2<S8`0V9RH09bL
W01fMWH0VYZJ092@T02NWYh0W9bL0:NWY`2<S8`0W9bL0:JVYP2QXJ40VYZJ0:b/[02GUiL0W9bL08V9
R@2PX:00/k>c0:f][@2XZ:P0YJFU0:>SX`2BTY80UIFE0:FUY@2c/k<0aLG50;6a/@2d];@0X:2P0:>S
X`2i^KT0X:2P0;Jf]P2PX:00WinO0:2PX02RXZ80][Jf0:BTY02`/;00YZJV0::RXP2>SXh0XJ6Q0P2I
VIT02`29RHT0MgMg08V9R@2JVYX0Ti>C09ZJVP2XZ:P0XJ6Q0;jn_P2TY:@0YZJV0080Y:BT01H0U9BD
08Z:RP2NWYh0OWin09VIV@2_[jl0QHF509NGU`2@T900N7Qh08F5Q@26QXH0RXZ:09NGU`1aLG40UYJF
0:ZZZP2EUID0Xj>S08V9R@2HV9P0UIFE0P2FUYH0F02;Rh/0R8R807MgM`2LW9`0Shn?07emO@25QHD0
Lg=c06][J`2>SXh0U9BD08b<S023Ph<0S8b<0:b/[024Q8@0O7al0:RXZ024Q8@0V9RH09ZJVP29RHT0
PH6108^;R`2?Shl0T92@08F5Q@1_Kfl0Hf=S07moO`2=SHd0R8R807emO@2>SXh0RXZ:07=cL`1aLG40
Ph>3079bLP28R8P0QHF5092@T01jNWX0S8b<09BDU02PX:00O7al08J6QP2:RXX0T92@08N7Q`23Ph<0
PH6108B4Q020P800M7Ad0820P01NGUh0Fe]K06ATI01/K6`0JFUY055AD@1SHf<0IVIV059BDP1@D500
FEUI05]KF`2;Rh/0LW9b05mOG`1]KFd0J6QX07EeM@1_Kfl0QXJ607inOP1iNGT0Jf][06e]K@1cLg<0
T92@07emO@1kNg/0NGUi07YjNP1LG5`207EeM@0c0820P01VIVH0F5QH07UiN@1eMGD0F5QH04a<C01[
Jf/0I6AT079bLP1eMGD0IFEU04M7A`1IFET0O7al05mOG`1_Kfl0Ogmo07UiN@1/K6`0G5aL06UYJ@1c
Lg<0Jf][06MWI`1]KFd0QXJ606m_K`1KFe/0Jf][05]KF`1JFUX0Jf][06e]K@1[Jf/0HF5Q05eMG@1Y
JFT0Jf][079bLP1JFUX0CDe=07IfMP1PH600LG5a05]KF`1OGel0OWin07emO@15ADD0oooo00H0fMWI
0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@1H0?ooo`2:RXX0TI6A07AdM02<S8`0
Vi^K07QhN024Q8@0JFUY07QhN01WIfL0QXJ606IVIP2?Shl0UYJF08V9R@28R8P0NGUi06YZJP24Q8@0
RXZ:08^;R`26QXH0Lg=c07emO@29RHT0P82006i^KP1bLW80UYJF08f=S@26QXH0L71`07AdM01SHf<0
IfMW06a/K01GEeL0FEUI06m_K`1]KFd0Lg=c06YZJP1hN7P0JVYZ07EeM@29RHT0UiNG08n?S`1YJFT0
/k>c09fMW@1gMgL0SXj>09FEU@1kNg/0N7Qh09:BTP1kNg/0Rh^;08V9R@1eMGD0S8b<08:2PP2ATI40
S8b<08V9R@2<S8`0TI6A0:ZZZP2DU9@0V9RH09nOW`2CTi<0W9bL0;no_`2HV9P0U9BD09>CT`2SXj<0
UYJF08J6QP2CTi<0UYJF08n?S`2<S8`0Shn?09JFUP80QXJ60240PX:209FEU@2PX:00VYZJ09fMW@2W
YjL0Vi^K09FEU@2?Shl0WIfM0:NWY`2a/K40WIfM09JFUP2a/K40[Jf]09nOW`2YZJT0Zj^[0;Zj^P2T
Y:@0^KVi0:FUY@2WYjL0];Bd0:^[Z`2/[:`0T92@09RHV02h^;P0ZJVY08^;R`2HV9P00P2:RXX0602V
YZH0XZ:R08N7Q`2OWil0UIFE08N7Q`2QXJ40Vi^K0:ZZZP2YZJT0W9bL06][J`2MWId0Ti>C0861P@2B
TY80V9RH0:RXZ02n_[h0T92@0;2`/02BTY80TI6A0:>SX`80YjNW05X0YJFU09:BTP2UYJD0Xj>S09bL
W02SXj<0V9RH08J6QP2NWYh0/;2`0::RXP20P800UIFE09NGU`2_[jl0Q8B407EeM@2XZ:P0UYJF092@
T02YZJT0WinO09>CT`1hN7P0Vi^K0:VYZ@26QXH0OWin0;Fe]@29RHT0SHf=08F5Q@2?Shl0MGEe08^;
R`1jNWX0UIFE08b<S02TY:@0Vi^K08^;R`2FUYH0XJ6Q06e]K@2DU9@0OGem08j>SP2=SHd0Ti>C07Mg
M`2=SHd0M7Ad07QhN01TI6@0Lg=c07alO01YJFT0MWIf09jNWP26QXH0QhN707moO`1[Jf/0QXJ608:2
PP2BTY80PH610:FUY@2=SHd0Shn?075aL@2@T900RXZ:08n?S`21PH40OWin08N7Q`26QXH0Ng]k07Ad
M01WIfL0KFe]05mOG`1dM7@0Lg=c06e]K@1XJ6P0Fe]K03`l?01RHV8207AdM00R08>3P`1hN7P0OWin
06a/K028R8P0U9BD07]kN`1VIVH0PH6109>CT`2:RXX0J6QX08R8R01/K6`0O7al08J6QP1iNGT0N7Qh
08:2PP1MGEd0MWIf07inOP1QHF40JFUY07=cL`1UIFD0NGUi06][J`1LG5`0FUYJ07AdM01@D500J6QX
06EUI@80KVi^02<0HF5Q07inOP1mOGd0MgMg07inOP1KFe/0FEUI05=CD`1WIfL0KVi^06][J`1<C4`0
HV9R06QXJ01/K6`0AdM705IFEP1aLG40EEEE05QHF01ZJVX0D51@06=SH`1YJFT0K6a/04Q8B01UIFD0
GUiN06QXJ01fMWH0LW9b07=cL`1[Jf/0>3Ph0?ooo`060=WIf@4000000@3IfMT001H0fMWI00<00000
0=WIf@3IfMT00`3IfMT0>P3oool0Rh^;09FEU@2EUID0Q8B407UiN@1gMgL0PX:208Z:RP1]KFd0KVi^
07emO@1IFET0UYJF08b<S025QHD0PH610:VYZ@1eMGD0Q8B407YjNP27QhL0O7al07UiN@21PH40Ti>C
09JFUP2GUiL0SXj>0820P023Ph<0KVi^08R8R01_Kfl0I6AT07MgM`1IFET0ATI606QXJ01QHF40FEUI
075aL@1`L700MWIf06EUI@1[Jf/0PH6106YZJP2EUID0YJFU075aL@20P800Y:BT092@T020P800TI6A
07AdM02=SHd208n?S`0c092@T02IVIT0Rh^;09NGU`2KVi/0WIfM08B4Q02IVIT0QXJ609ZJVP2ATI40
UiNG08^;R`2OWil0N7Qh09nOW`2PX:00UYJF08Z:RP2OWil0NWYj075aL@2?Shl0WinO0820P02@T900
OWin07emO@2EUID0XJ6Q092@T02EUID0[Zj^0:>SX`2FUYH0QHF50;Jf]P2VYZH0WYjN0:^[Z`2RXZ80
YJFU0:2PX02ZZZX0]kNg0;bl_02@T900[Jf]0<_;b`2c/k<0[Zj^0080VIVI0<T0^KVi0:RXZ02NWYh0
W9bL0:RXZ02d];@0]KFe09ZJVP2e]KD0Y:BT08Z:RP2TY:@0^[Zj09ZJVP2][Jd0T92@09nOW`2CTi<0
Zj^[08j>SP2CTi<0Q8B408Z:RP2CTi<0SXj>0:>SX`2:RXX0R8R80:6QX@2RXZ80S8b<0::RXP2=SHd0
YJFU0:b/[02OWil0Y:BT09VIV@2?Shl0X:2P09nOW`2ZZZX0Xj>S0:j^[P2OWil0Rh^;08N7Q`24Q8@0
PX:20;Fe]@2JVYX0Ti>C09fMW@2UYJD0MgMg09BDU02UYJD0NWYj07inOP2DU9@0P82008n?S`2TY:@0
Rh^;08F5Q@20P800LW9b0:BTY02DU9@0Ti>C09^KV`2NWYh0YJFU08f=S@2HV9P0Xj>S08J6QP2<S8`0
P82007emO@1gMgL0O7al08>3P`2NWYh0Ogmo07emO@1eMGD0Shn?07EeM@1mOGd0JFUY07=cL`22PX80
GemO08>3P`21PH40KFe]08n?S`24Q8@0N7Qh08Z:RP1iNGT0MGEe0820P01kNg/0Ph>30861P@1lO7`0
I6AT07MgM`1kNg/0Q8B408R8R027QhL0P82006ATI01RHV80FEUI06IVIP1XJ6P0K6a/06QXJ01NGUh0
HV9R03lo?`18B4P0CTi>06MWI`1RHV80OGem07QhN01dM7@0NWYj07moO`1eMGD0Shn?07YjNP1WIfL0
MGEe0861P@1fMWH0WYjN07UiN@2@T900De=C06e]K@1eMGD0HF5Q05=CD`1bLW80Hf=S06UYJ@1LG5`0
JVYZ07alO01cLg<0Kfm_05ADE01WIfL0JFUY04Y:BP1TI6@0Ng]k06IVIP1QHF40L71`06ATI01WIfL0
K6a/0451@@1YJFT0KFe]06YZJP1/K6`0DE5A075aL@1^KVh0RXZ:06a/K01UIFD0I6AT08B4Q01HF5P0
N7Qh05mOG`1VIVH0KFe]05MGE`0f=SH0MWIf06EUI@1EEED0De=C06e]K@1^KVh0Jf][06e]K@1UIFD0
GUiN038b<P3oool01P3IfMT100000040fMWI000F0=WIf@800000103IfMT0BP3oool0T92@08n?S`29
RHT0Jf][07alO01dM7@0MWIf092@T01fMWH0IfMW0820P01aLG40Shn?08R8R02DU9@0Lg=c06i^KP23
Ph<0PX:20820P01`L700H61P0861P@2:RXX0Ph>30861P@2LW9`0Rh^;08n?S`26QXH0H61P05EEE@17
AdL0HF5Q03dm?@19BDT0De=C04i>CP1TI6@0H61P075aL@1YJFT0PX:206MWI`1;Bd/0MWIf0861P@2D
U9@0QHF507IfMP25QHD0Ti>C08J6QP1lO7`0Shn?08f=S@2JVYX0PH6109JFUP2@T900UiNG08f=S@29
RHT0Ng]k07EeM@2NWYh0TY:B08R8R02LW9`0RHV909ZJVP21PH40NGUi0P2=SHd05`2EUID0/;2`0:VY
Z@2OWil0PH6109>CT`2<S8`0Xj>S0:FUY@25QHD0W9bL08f=S@27QhL0RHV909JFUP2DU9@0VYZJ07em
O@2JVYX0X:2P09:BTP2HV9P0]KFe0080Z:RX0=D0VYZJ0:>SX`2MWId0[:b/09bLW02WYjL0[Jf]0<?3
``2/[:`0U9BD0;2`/02RXZ80^;Rh09jNWP2VYZH0[Zj^09fMW@2PX:00RHV90:^[Z`2GUiL0Lg=c0:j^
[P2JVYX0T92@0:FUY@2GUiL0Rh^;0:ZZZP1lO7`0Vi^K09RHV02<S8`0W9bL09BDU02PX:00YJFU0:NW
Y`2GUiL0Rh^;09jNWP2HV9P0XZ:R0:b/[02d];@0WYjN08f=S@1oOgl0W9bL07EeM@2FUYH0Vi^K09fM
W@28R8P0V9RH09VIV@2NWYh0Y:BT0::RXP29RHT0U9BD09VIV@2?Shl0X:2P08^;R`2CTi<0U9BD09RH
V02^[Zh0RXZ:09NGU`1aLG40W9bL07moO`2SXj<0TI6A08R8R02YZJT0V9RH09fMW@2GUiL0Vi^K092@
T02JVYX0YJFU0:b/[02QXJ40WinO08^;R`2EUID0TI6A0820P026QXH0NGUi08F5Q@2CTi<0Vi^K07Ee
M@23Ph<0Ng]k07emO@2>SXh0QHF507emO@1RHV80NWYj05iNGP28R8P0M7Ad06QXJ01nOWh0KVi^08:2
PP2>SXh0Ti>C07]kN`20P800JVYZ06MWI`2@T900QXJ607YjNP26QXH0VIVI09BDU01^KVh0O7al06QX
J018B4P0AdM706EUI@1/K6`0MGEe06YZJP1iNGT0KFe]03Ph>01>CTh0AdM706=SH`1EEED0M7Ad09ZJ
VP2DU9@0M7Ad06ATI01dM7@0OWin07EeM@1lO7`0SXj>08F5Q@29RHT0L71`06=SH`1IFET0KVi^07Yj
NP1PH600Lg=c07inOP1eMGD0GUiN065QH@26QXH0PX:206=SH`1XJ6P0L71`075aL@1QHF40EUIF06YZ
JP1MGEd0DE5A07=cL`1VIVH0OWin07UiN@1TI6@0J6QX06e]K@1EEED0KFe]07AdM01ZJVX0IVIV06][
J`1^KVh0HF5Q06e]K@1DE5@0CDe=07MgM`1nOWh0HF5Q06QXJ01_Kfl0FUYJ05iNGP1LG5`0Hf=S069R
HP1aLG40NGUi065QH@1]KFd0H61P06IVIP1nOWh0@d=301HF5P3oool01@3IfMT200000040fMWI000F
0=WIf@030000003IfMT0fMWI00<0fMWI05@0oooo07AdM02:RXX0KFe]09>CT`20P800KVi^08>3P`1l
O7`0TY:B071`L01OGel0EEEE071`L02BTY80P82008V9R@2@T900Hf=S0861P@20P800M7Ad06IVIP1]
KFd0IVIV09:BTP2FUYH0Ti>C09BDU02?Shl0EUIF04Q8B00m?Cd0E5AD01LG5`0`<300=CDe04a<C01=
CDd0E5AD04i>CP1FEUH0LG5a06a/K01gMgL0Hf=S075aL@2:RXX0O7al08b<S01/K6`0PX:207UiN@2<
S8`0UIFE09BDU027QhL0RHV907=cL`22PX80Y:BT075aL@29RHT0WIfM09BDU01oOgl0OWin08J6QP2_
[jl0Shn?08b<S02>SXh0Ng]k09ZJVP2EUID0Ti>C09ZJVP2KVi/0U9BD0:6QX@2JVYX0Rh^;09JFUP28
R8P20:6QX@2L09>CT`2BTY80TY:B08Z:RP2>SXh0Ti>C08^;R`2a/K40VYZJ0;Fe]@2MWId0X:2P0:NW
Y`2][Jd0Z:RX0:6QX@2`/;00_[jn0:JVYP2HV9P0YJFU09jNWP2k^k/0/[:b09NGU`2c/k<0W9bL0;2`
/02c/k<0[Jf]09bLW02/[:`0[Jf]0;Vi^@2HV9P0YJFU08:2PP2k^k/0ZJVY0;:b/P2TY:@0ZJVY0:JV
YP2JVYX0Kfm_0::RXP2JVYX0T92@07QhN027QhL0RHV909VIV@2NWYh0SXj>09bLW02YZJT0V9RH09ZJ
VP2KVi/0OWin0:>SX`2`/;00WIfM09RHV029RHT0Xj>S09JFUP2[Zj/0Ti>C0861P@2[Zj/0V9RH09nO
W`2?Shl0Y:BT08B4Q028R8P0U9BD0:^[Z`2?Shl0WinO08V9R@2=SHd0OWin09JFUP26QXH0Z:RX06YZ
JP2@T900SXj>08R8R02EUID0VYZJ06IVIP1IFET0QHF5071`L02QXJ40PX:209FEU@2GUiL0VIVI08V9
R@2PX:00VYZJ09VIV@2MWId0R8R807alO02SXj<0UYJF07moO`25QHD0T92@09ZJVP21PH40LW9b08>3
P`1SHf<0H61P07alO01LG5`0KVi^07QhN01nOWh0Rh^;08N7Q`2>SXh0Jf][09:BTP2HV9P0PH6109JF
UP2HV9P0VYZJ092@T01oOgl0W9bL09ZJVP2:RXX0MGEe05]KF`1QHF40EUIF06MWI`23Ph<0PX:207in
OP1eMGD0EeMG07AdM014A4@0@4100492@P13@d<0=cLg0P2:RXX04@29RHT0OWin01lO7`1kNg/0Jf][
07]kN`1hN7P0Ogmo06e]K@2BTY80LW9b07QhN01mOGd0KFe]07]kN`1mOGd0LG5a0080Jf][01l0K6a/
07UiN@1/K6`0JVYZ06=SH`1lO7`0Jf][06i^KP1jNWX0HF5Q06a/K01JFUX0GUiN06QXJ01QHF40F5QH
06UYJ@1WIfL0JFUY07IfMP1aLG40J6QX06UYJ@1EEED0OGem06QXJ01[Jf/0LG5a06EUI@1YJFT0JVYZ
0080H61P00@0GemO05YJFP13@d<0ADE50P1MGEd0201>CTh0@d=304I6AP1JFUX0IFEU065QH@1[Jf/0
NWYj0P1FEUH00`0i>CT0oooo0=WIf@050=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT0
0`3IfMT0]@3oool0J6QX08R8R01gMgL0NGUi06UYJ@21PH40Rh^;08F5Q@1^KVh0O7al08B4Q01hN7P0
K6a/06YZJP23Ph<0IVIV07AdM01iNGT0PX:207EeM@2:RXX0Ti>C08R8R01hN7P0Y:BT0:NWY`2CTi<0
JVYZ051@D00Z:RX05ADE02LW9`0g=cL0:BTY03lo?`1@D500G5aL06m_K`1IFET0F5QH06a/K01cLg<0
KFe]07=cL`1WIfL0H61P071`L01dM7@0RHV908B4Q01WIfL0N7Qh08F5Q@2:RXX0NGUi09>CT`2PX:00
WIfM06YZJP2MWId0U9BD08F5Q@2ZZZX0KVi^092@T02=SHd0OGem06MWI`29RHT0OGem08n?S`2KVi/0
QhN708:2PP1nOWh0UIFE09:BTP2<S8`0V9RH09NGU`2][Jd0Zj^[09bLW02IVIT0T92@08Z:RP2[Zj/0
MWIf08^;R`2BTY80ZJVY0:NWY`2VYZH0SHf=09BDU02h^;P0^KVi09VIV@2/[:`0Xj>S0:FUY@2MWId0
[:b/0:n_[`38b<P0/;2`0:BTY02b/[80Vi^K0:VYZ@2o_kl0Y:BT08J6QP2a/K40UIFE0<G5a@2c/k<0
Vi^K0::RXP2/[:`0/[:b0:2PX02g]kL0UiNG09^KV`2DU9@0[jn_0;>c/`2JVYX0U9BD09ZJVP26QXH0
K6a/06MWI`2:RXX0W9bL09BDU02;Rh/0R8R807IfMP2ATI40UYJF0:6QX@2YZJT0Xj>S09jNWP2PX:00
SHf=09fMW@2VYZH0Vi^K09BDU01:BTX0PH6108:2PP26QXH0MGEe09^KV`2BTY80QhN708B4Q02DU9@0
L71`09jNWP2a/K40Z:RX0::RXP1oOgl0R8R807]kN`2ATI40Ti>C08^;R`2IVIT0NWYj09RHV02:RXX0
Ph>307inOP1mOGd00P2LW9`0P`2GUiL0SHf=08R8R02XZ:P0TY:B09jNWP2=SHd0Vi^K09ZJVP2DU9@0
RHV90861P@2RXZ80PX:207MgM`26QXH0L71`07EeM@21PH40NGUi06UYJ@1jNWX0Ph>306e]K@1^KVh0
M7Ad08:2PP1hN7P0QhN708^;R`1cLg<0MGEe0820P01iNGT0UIFE07IfMP1]KFd0MGEe08R8R01WIfL0
NWYj07QhN020P800OGem06m_K`1YJFT0B4Q804U9B@1CDe<0GemO06m_K`1GEeL0MGEe075aL@19BDT0
BTY:034a<@0b<S80=cLg075aL@2HV9P0MGEe09JFUP20P800GemO08b<S01kNg/0LW9b06QXJ01gMgL0
IfMW07alO022PX80N7Qh06ATI01dM7@0OWin06e]K@1oOgl0Kfm_07QhN01PH600JFUY06e]K@1cLg<0
EUIF07inOP1;Bd/0IFEU06m_K`1KFe/0MGEe06MWI`1[Jf/0M7Ad06a/K01KFe/0IFEU07AdM01:BTX0
LG5a069RHP1SHf<0M7Ad079bLP1SHf<0C4a<06a/K01`L700KFe]07=cL`1UIFD0LW9b05iNGP12@T80
Hf=S07=cL`1/K6`0P82006MWI`1@D500FEUI05]KF`1VIVH0LW9b05mOG`2=SHd0HV9R04E5A@0U9BD0
oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@090?ooo`1`L700Q8B4
06QXJ026QXH0T92@09BDU01bLW80J6QX0080OWin03@0O7al06m_K`1ZJVX0PH6107moO`1`L700Q8B4
07EeM@27QhL0MgMg09VIV@28R8P0V9RH08R8R01FEUH0HV9R07inOP0Z:RX09RHV00H61P0H61P0<S8b
03Xj>P0i>CT0=CDe04I6AP1ADE40KVi^06EUI@1HF5P0IfMW0861P@22PX80Hf=S06e]K@1eMGD0Ng]k
07emO@1jNWX0P82008J6QP1jNWX0LG5a092@T02ATI40TY:B01XJ6P030`<0EEEE09JFUP2ATI40T92@
0P2FUYH0202CTi<0U9BD09RHV02HV9P0YjNW08^;R`1jNWX0Ti>C0`2FUYH06`2LW9`0S8b<08j>SP2E
UID0WIfM0820P02;Rh/0Y:BT08^;R`2VYZH0Vi^K08R8R02FUYH0TY:B09FEU@2BTY80Vi^K0;Bd]02L
W9`0Shn?06MWI`2IVIT0X:2P08R8R02e]KD0Xj>S08:2PP0209VIV@1E08n?S`2WYjL0a/K60:BTY02^
[Zh0ZJVY09jNWP2TY:@0/K6a0:f][@2b/[80Vi^K09fMW@2a/K40Shn?09jNWP2RXZ80bLW90:2PX02K
Vi/0P8200:2PX02NWYh0ZZZZ08Z:RP2IVIT0QXJ608>3P`2FUYH0U9BD08N7Q`2PX:00Ph>308V9R@2T
Y:@0RXZ:0820P02?Shl0ZJVY07alO02>SXh0ZJVY08b<S02=SHd0UiNG092@T02QXJ40OGem09>CT`2A
TI40RXZ:0::RXP2JVYX0Ti>C08B4Q02NWYh0XJ6Q0:2PX02TY:@0TI6A09:BTP22PX80Y:BT08n?S`2N
WYh0Y:BT08>3P`2:RXX0YjNW09BDU029RHT0IFEU07EeM@1hN7P0Rh^;0861P@1mOGd0TY:B07inOP2<
S8`0WYjN09RHV021PH40UYJF079bLP0208J6QP1j07EeM@1nOWh0SXj>09:BTP26QXH0NWYj0820P024
Q8@0Rh^;071`L01jNWX0GEeM08Z:RP2BTY80Ph>30820P01[Jf/0LG5a079bLP1[Jf/0GemO07emO@24
Q8@0TY:B06MWI`20P800OWin07EeM@1cLg<0PX:208j>SP2;Rh/0Q8B409RHV01fMWH0JVYZ05=CD`19
BDT0E5AD04I6AP1ZJVX0OWin06MWI`1OGel0LW9b06e]K@1GEeL0=SHf04a<C00S8b<0GemO079bLP1Z
JVX0LG5a05iNGP1gMgL0QXJ609BDU01eMGD0OWin07alO01SHf<0J6QX07MgM`1OGel0M7Ad061PH023
Ph<0M7Ad07moO`2;Rh/0I6AT05mOG`1CDe<0IfMW07YjNP1MGEd0G5aL07IfMP1`L700GemO06][J`1j
NWX0JVYZ06MWI`1dM7@0Ng]k071`L01OGel0MGEe071`L028R8P0G5aL08J6QP1WIfL0HF5Q07moO`1Y
JFT0E5AD075aL@1SHf<0FUYJ059BDP1`L700GEeM06EUI@1LG5`0F5QH065QH@1IFET0G5aL04U9B@1D
E5@0@41005aLG01OGel0F5QH06e]K@1IFET0=cLg010@403oool60=WIf@4000000@3IfMT001H0fMWI
00<000000=WIf@3IfMT00`3IfMT0>03oool0MGEe0861P@1^KVh0QhN706a/K01nOWh0T92@07moO`1j
NWX0PH6107IfMP24Q8@0Kfm_06YZJP1kNg/0Lg=c07alO029RHT0O7al09ZJVP1^KVh0SXj>08J6QP1d
M7@0R8R805]KF`1?Cdl0:b/[02TY:@0L71`07QhN03dm?@0k>c/0>CTi059BDP1CDe<0Kfm_069RHP1I
FET0DE5A04m?C`0l?3`0P82007inOP1VIVH0IfMW07IfMP1_Kfl0TI6A09>CT`2OWil0RHV908^;R`27
QhL0S8b<0`000000602?Shl0W9bL092@T02GUiL0NGUi08J6QP2PX:00S8b<09^KV`2FUYH0OGem0:>S
X`2=SHd0UIFE0:6QX@21PH40T92@075aL@2GUiL0V9RH08b<S02MWId0Rh^;09fMW@80YJFU02D0T92@
09FEU@2ZZZX0WIfM09RHV02VYZH0SHf=08n?S`29RHT0VIVI08j>SP2TY:@0SXj>08N7Q`2LW9`0UYJF
0:VYZ@2^[Zh0UIFE0:>SX`2a/K40ZZZZ0;:b/P2BTY80Zj^[08N7Q`2CTi<0]KFe0:^[Z`2KVi/0/K6a
09RHV02`/;00WinO09VIV@2ATI40_Kfm0080VYZJ0;h0^KVi09jNWP2DU9@0SXj>0:b/[02EUID0Xj>S
0:f][@2:RXX0MWIf09bLW025QHD0Ph>30::RXP20P800XZ:R0:ZZZP2UYJD0YjNW09ZJVP2QXJ40TI6A
0:>SX`2ATI40N7Qh0;Bd]02=SHd0Rh^;09NGU`28R8P0QHF50::RXP1aLG40U9BD08R8R02@T900PH61
06YZJP1jNWX0PH6109ZJVP2?Shl0UiNG0;:b/P1oOgl0Rh^;08j>SP2FUYH0SXj>0:2PX02/[:`0PH61
092@T02KVi/0Ti>C08V9R@1bLW80QHF508B4Q02SXj<0YjNW08R8R024Q8@0Vi^K07MgM`23Ph<0Lg=c
08j>SP2;Rh/0U9BD09FEU@2>SXh0MWIf07emO@2XZ:P0PX:207MgM`2>SXh0VYZJ0861P@1lO7`0QHF5
07emO@1iNGT0RXZ:075aL@1kNg/0EeMG09fMW@1oOgl0QHF50:6QX@2PX:00PH6108R8R02?Shl0QhN7
08b<S01fMWH0QXJ60820P029RHT0OGem07alO01DE5@0JVYZ04Q8B01HF5P0EUIF07inOP1fMWH0U9BD
06i^KP1`L700Fe]K04i>CP14A4@08B4Q04e=C@1aLG40Hf=S07QhN020P800N7Qh07]kN`1nOWh0F5QH
071`L01oOgl0NGUi07YjNP1ZJVX0P82008>3P`1iNGT0MWIf0820P01lO7`0NGUi08B4Q01eMGD0JFUY
05eMG@1HF5P0EeMG06m_K`1QHF40MgMg06MWI`26QXH0IVIV06EUI@1=CDd0Bd];05UIF@1QHF40N7Qh
05aLG01aLG40IfMW079bLP27QhL0MGEe08>3P`1]KFd0FUYJ071`L01LG5`0IVIV06QXJ01aLG40F5QH
04i>CP1UIFD0Hf=S06YZJP1GEeL0Cdm?05ADE01OGel0JFUY05UIF@1SHf<0PH6105UIF@1bLW80D51@
02h^;P0P8200oooo1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI04L0oooo
075aL@1bLW80MgMg08B4Q02=SHd0IVIV06i^KP1WIfL0LG5a06m_K`1mOGd0Ng]k08R8R01hN7P0O7al
079bLP1ZJVX0NWYj05UIF@2EUID0RXZ:07EeM@20P800MGEe075aL@1TI6@0ATI602h^;P0K6a/08B4Q
02`/;00g=cL0HF5Q04U9B@1GEeL0FEUI06ATI01EEED0A4A405UIF@1=CDd0E5AD061PH01NGUh0MGEe
05eMG@23Ph<0MgMg08V9R@2KVi/0YjNW08R8R01gMgL0LW9b08R8R0000000JFUY09^KV`26QXH0Shn?
09:BTP2=SHd0QhN70:6QX@2>SXh0V9RH09:BTP2GUiL0Q8B409JFUP0209VIV@0Q09FEU@2XZ:P0V9RH
08^;R`2@T900IFEU09RHV02VYZH0PX:20:j^[P2[Zj/0Ogmo096AT@2_[jl0[Jf]09ZJVP2GUiL0TY:B
09RHV02MWId0SXj>0;6a/@2GUiL0YjNW08Z:RP2FUYH0[Zj^09nOW`2;Rh/0VIVI0:BTY02a/K40Y:BT
0080Xj>S03D0ZJVY0:b/[02IVIT0WinO09bLW02f][H0YZJV0:RXZ02>SXh0ZJVY07IfMP25QHD0Ti>C
08J6QP2EUID0UiNG09FEU@2DU9@0VYZJ07moO`2DU9@0Y:BT09ZJVP2:RXX0Vi^K08N7Q`1fMWH0SXj>
08^;R`1oOgl0VIVI0::RXP2EUID0ZZZZ0:>SX`1^KVh0XJ6Q0:BTY026QXH0W9bL09>CT`2PX:00YZJV
0:>SX`2HV9P0UIFE0:6QX@2TY:@0]KFe09ZJVP2f][H0QhN70:JVYP0209NGU`0:08^;R`2NWYh0ZJVY
08:2PP2CTi<0Shn?08:2PP2>SXh0SHf=09bLW080Zj^[0340W9bL08V9R@2MWId0N7Qh08:2PP21PH40
YJFU09NGU`2<S8`0TI6A092@T02LW9`0S8b<0:JVYP25QHD0YZJV08b<S02DU9@0VYZJ07=cL`1]KFd0
PX:209BDU02=SHd0NGUi07=cL`27QhL0Ng]k07QhN01[Jf/0G5aL08b<S02:RXX0IfMW08:2PP1/K6`0
HV9R07alO02IVIT0WYjN07QhN029RHT0NGUi08Z:RP26QXH0L71`06m_K`28R8P0KVi^0080QhN701<0
ZZZZ09bLW01XJ6P0ATI605MGE`1:BTX0>CTi069RHP1QHF40S8b<06IVIP1GEeL0HV9R059BDP11@D40
ATI603hn?P1ZJVX0BDU90080M7Ad00d0O7al06ATI01dM7@0Ph>306i^KP1DE5@0MgMg07QhN028R8P0
Kfm_07emO@1iNGT0O7al0080LG5a00H0KFe]069RHP1[Jf/0GEeM07YjNP1EEED206YZJP0/07IfMP1P
H600NGUi05mOG`1EEED0L71`06=SH`1XJ6P0OWin06m_K`1^KVh0IVIV07inOP21PH40Ph>3069RHP1m
OGd0HF5Q07UiN@1cLg<0PH6107emO@1KFe/0KVi^08Z:RP1/K6`0LW9b05]KF`1ZJVX0I6AT05aLG01H
F5P0DE5A065QH@1XJ6P0DE5A06MWI`1^KVh0HV9R06MWI`0_;bl0IfMW0451@@3oool60=WIf@400000
0@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT01`3oool0GemO07]kN`1QHF40NGUi06IVIP1m
OGd00P1YJFT01@2:RXX0IFEU05mOG`2ATI40MGEe0080LG5a03<0KFe]071`L01]KFd0IVIV07MgM`1c
Lg<0OGem05EEE@14A4@0Jf][03dm?@0d=3@0?Cdm02/[:`18B4P0GEeM07=cL`1WIfL0LW9b06a/K01J
FUX0HV9R04i>CP1EEED0I6AT04A4A01@D500GemO06YZJP1EEED0QHF507inOP2?Shl0VIVI09>CT`2?
Shl0NWYj08:2PP28R8P0PH6108Z:RP2GUiL0WIfM08^;R`1dM7@0Vi^K0:VYZ@2PX:00T92@08Z:RP2<
S8`00P2FUYH01@1gMgL0O7al07]kN`2HV9P0SXj>00<0R8R803X0Ti>C09VIV@26QXH0V9RH09JFUP2:
RXX0Z:RX0:NWY`2/[:`0W9bL09nOW`2IVIT0S8b<0:FUY@2OWil0XJ6Q08R8R02FUYH0Z:RX0:j^[P2@
T900Zj^[0:2PX02NWYh0Shn?09^KV`2BTY80/;2`09bLW02WYjL0TY:B0;jn_P2IVIT0/;2`0:JVYP2O
Wil0[Jf]09NGU`2RXZ80[Jf]0::RXP2_[jl0VIVI07moO`1nOWh0QhN70:>SX`2<S8`0VIVI09RHV02Q
XJ40^[Zj09bLW028R8P0T92@08^;R`20P800PX:20P1eMGD0=02KVi/0Shn?09>CT`2IVIT0Shn?0:>S
X`2`/;00YZJV0:VYZ@2RXZ80TY:B0;6a/@2QXJ40Z:RX07]kN`2EUID0V9RH08n?S`2=SHd0TY:B0820
P01jNWX0/K6a08B4Q02MWId0U9BD09^KV`2BTY80SHf=0:VYZ@2PX:00WinO07YjNP2<S8`0LW9b07=c
L`2EUID0Z:RX09:BTP2IVIT0Ng]k09JFUP2NWYh0Q8B40861P@2>SXh0OGem07moO`1nOWh0N7Qh08J6
QP1fMWH2092@T00b09NGU`2>SXh0Rh^;09ZJVP1lO7`0OWin09^KV`2@T900QhN7079bLP29RHT0Q8B4
06QXJ02<S8`0MGEe08>3P`1TI6@0OGem08J6QP2;Rh/0PH61065QH@25QHD0QhN709JFUP21PH40QHF5
07inOP29RHT0M7Ad09bLW028R8P0PX:207YjNP2;Rh/0WIfM08b<S01`L700FUYJ04Q8B015ADD0Bd];
06e]K@1ZJVX0E5AD06a/K021PH40GEeM05aLG01BDU8204E5A@0V06QXJ01UIFD0Lg=c06=SH`2>SXh0
TY:B07YjNP2GUiL0IFEU08J6QP1mOGd0OWin06m_K`1cLg<0K6a/07]kN`1jNWX0G5aL061PH01OGel0
HF5Q055AD@1GEeL0M7Ad069RHP1YJFT0IFEU06IVIP1JFUX0IVIV05iNGP1UIFD0HV9R05eMG@1TI6@0
JVYZ071`L01WIfL206m_K`0O06][J`1KFe/0GUiN069RHP0g=cL0GUiN06QXJ01>CTh0HV9R06a/K01f
MWH0J6QX065QH@1`L700?clo075aL@1]KFd0G5aL061PH01fMWH0GEeM07YjNP1]KFd0OGem061PH01G
EeL0K6a/05MGE`1IFET0EeMG0?ooo`060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT0
0`3IfMT09`3oool0MWIf07UiN@24Q8@0K6a/07QhN02>SXh0NGUi07alO01aLG40Hf=S06i^KP1nOWh0
O7al07]kN`29RHT0PH6108B4Q020P800OWin06][J`1VIVH0Bd];06EUI@1aLG40?3`l03dm?@0h>3P0
>CTi04i>CP0`<300IFEU06ATI01WIfL0NGUi06m_K`1RHV80CTi>059BDP0201lO7`80CDe=00L0Bd];
07EeM@1WIfL0MgMg0820P022PX80UIFE0080QhN701H0VIVI08J6QP1oOgl0JVYZ08j>SP20P800Lg=c
08Z:RP2BTY80QhN7096AT@2;Rh/0TY:B09NGU`2?Shl0S8b<07QhN02HV9P0PX:209JFUP2?Shl0QHF5
0P2;Rh/03`2BTY80OWin08f=S@2HV9P0Z:RX0:FUY@2=SHd0S8b<0:BTY02GUiL0Vi^K096AT@2KVi/0
S8b<08n?S`0208F5Q@0G09NGU`2TY:@0Q8B407YjNP22PX80SXj>09FEU@2CTi<0NGUi09ZJVP2YZJT0
VYZJ08>3P`2ZZZX0S8b<0:BTY02CTi<0UiNG09jNWP2RXZ80/;2`09:BTP2EUID00P2KVi/20:>SX`0H
07alO02MWId0Ph>309VIV@2LW9`0VIVI08V9R@26QXH0ZJVY09:BTP2DU9@0RXZ:07inOP2][Jd0W9bL
0861P@2:RXX0_;bl09JFUP2IVIT0U9BD08j>SP2@T900SXj>0P2EUID0@P2<S8`0M7Ad08f=S@2NWYh0
UiNG0:BTY024Q8@0OWin09>CT`2DU9@0WIfM07YjNP2IVIT0LW9b0:BTY02?Shl0Ph>30820P02ATI40
Vi^K09JFUP2=SHd0Z:RX08V9R@28R8P0Q8B4092@T01mOGd0WinO0:FUY@2=SHd0OGem0:>SX`2EUID0
QHF509>CT`2EUID0PH6109RHV01oOgl0Vi^K096AT@2JVYX0PH6109:BTP2;Rh/0LW9b08^;R`2ATI40
P82006YZJP2>SXh0RHV907emO@2IVIT0Rh^;07EeM@1JFUX0IFEU071`L02FUYH0FEUI08B4Q01lO7`0
K6a/08F5Q@80Rh^;00`0LG5a079bLP2@T900Ogmo0861P@2;Rh/0UiNG08:2PP23Ph<0O7al08J6QP1Y
JFT207EeM@0k06=SH`1EEED0B4Q80410@014A4@0ATI604e=C@1BDU80Hf=S05]KF`1VIVH0D51@05EE
E@16ATH0CTi>04I6AP1/K6`0PH61092@T025QHD0QXJ607alO01gMgL0IfMW07]kN`2?Shl0P820055A
D@1oOgl0LG5a05MGE`1JFUX0Jf][05ADE01>CTh0Jf][07MgM`22PX80Ph>307IfMP1HF5P0KFe]05=C
D`1RHV80IFEU06YZJP1bLW80J6QX06MWI`1NGUh0HF5Q04I6AP1PH600BTY:061PH01WIfL0BDU908B4
Q01HF5P00P1lO7`06@12@T80H61P06UYJ@1XJ6P0IfMW05ADE01aLG40De=C06QXJ015ADD0FUYJ05=C
D`1KFe/0EUIF065QH@1cLg<0GUiN05MGE`1:BTX0ADE503lo?`1PH600GEeM04i>CP3oool01P3IfMT1
00000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00`0oooo07emO@1lO7`0JFUY079bLP21
PH40QhN708J6QP1YJFT0Q8B4065QH@1oOgl207YjNP0L08:2PP2>SXh0Q8B406i^KP1lO7`0QhN708>3
P`21PH40LG5a05MGE`1OGel0C4a<06MWI`1GEeL0L71`04m?C`18B4P0IFEU05EEE@1iNGT0J6QX06a/
K01;Bd/0>CTi038b<P0N7Qh05ADE03Xj>P80FEUI02d0M7Ad075aL@2=SHd0TY:B09>CT`2DU9@0VIVI
09BDU01iNGT0Vi^K09JFUP29RHT0MWIf0:FUY@25QHD0R8R808V9R@2WYjL0RXZ:092@T02LW9`0Ogmo
07alO02?Shl0U9BD07inOP2ATI40T92@09FEU@1`L700TY:B0;>c/`2FUYH0Xj>S07AdM02GUiL0V9RH
0::RXP2KVi/0U9BD08:2PP2;Rh/0Shn?09nOW`2NWYh00P2PX:00HP2;Rh/0YjNW09BDU02ZZZX0QXJ6
0:^[Z`2HV9P0UYJF08b<S02UYJD0[Zj^0:2PX02][Jd0Shn?09BDU02<S8`0ZZZZ0:VYZ@2UYJD0WIfM
0<;2`P23Ph<0XJ6Q09fMW@2EUID0X:2P0<;2`P2[Zj/0XJ6Q08J6QP2MWId0V9RH09fMW@2TY:@0UIFE
09bLW02VYZH0[jn_08j>SP2QXJ40Xj>S0:NWY`2QXJ40_kno07inOP21PH40XJ6Q09VIV@2HV9P0YjNW
09BDU01kNg/0WIfM08b<S02^[Zh0[:b/096AT@2TY:@0Ng]k0:VYZ@28R8P0YjNW0:>SX`2[Zj/0RXZ:
08R8R02:RXX0Vi^K08V9R@24Q8@0RHV909BDU02/[:`0UYJF0:FUY@2XZ:P0VIVI08f=S@2BTY80SHf=
07=cL`25QHD0MGEe09FEU@2LW9`0RHV909>CT`2KVi/0RHV907inOP21PH40QHF509bLW02=SHd0QHF5
08V9R@1gMgL0WinO0P29RHT207alO01608^;R`24Q8@0SHf=08J6QP1FEUH0QhN709ZJVP1fMWH0Lg=c
07moO`21PH40M7Ad08b<S01`L700Ph>307moO`1bLW80RXZ:08>3P`1aLG40RHV908J6QP28R8P0Ogmo
09VIV@2BTY80PH6108b<S01iNGT0PH6107YjNP2PX:00S8b<07alO02DU9@0Ph>307]kN`1NGUh0>c/k
02l_;`17AdL0B4Q805aLG01OGel0MWIf075aL@1SHf<0Fe]K06UYJ@1VIVH0Lg=c08F5Q@2@T900Ogmo
0861P@1bLW80MGEe07UiN@27QhL0N7Qh06ATI01UIFD0Q8B408V9R@1eMGD0GemO06ATI01gMgL0Jf][
04m?C`80FEUI02X0KFe]07AdM01[Jf/0MWIf06=SH`1PH600Ng]k05eMG@1^KVh0HV9R07IfMP1PH600
Cdm?07IfMP1KFe/0Ph>307QhN01:BTX0I6AT071`L01KFe/0M7Ad07emO@1/K6`0IfMW06m_K`1/K6`0
HV9R07UiN@1jNWX0LG5a06MWI`1LG5`0De=C05UIF@1[Jf/0FUYJ05=CD`1fMWH0IVIV069RHP1^KVh2
061PH00506i^KP1EEED0EUIF0451@@3oool01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0
fMWI00<0fMWI0340oooo07UiN@1]KFd0NWYj07alO01YJFT0L71`07=cL`23Ph<0JVYZ07moO`1mOGd0
N7Qh07=cL`21PH40Q8B408Z:RP1fMWH0P82007AdM01eMGD0LW9b06QXJ01FEUH0BDU9075aL@23Ph<0
MWIf06EUI@11@D40JFUY05IFEP1?Cdl0Jf][06IVIP0i>CT0Hf=S06ATI00i>CT08B4Q02h^;P0g=cL0
HF5Q05QHF01jNWX0QHF508f=S@2NWYh0UIFE0080VYZJ0P2>SXh04P2KVi/0NWYj08n?S`2;Rh/0Vi^K
09fMW@2UYJD0RHV908B4Q025QHD0RHV906a/K02FUYH0QHF507EeM@23Ph<0OWin0:f][@80WIfM01H0
PH6107=cL`2HV9P0QhN708b<S02PX:00XJ6Q09ZJVP2HV9P0S8b<09JFUP1hN7P0QhN70;Jf]P2HV9P0
Rh^;092@T02ATI40VIVI09BDU02ZZZX0XZ:R0P2PX:007P2JVYX0WIfM0:JVYP2OWil0UIFE0;Ng]`2J
VYX0Ti>C09nOW`2GUiL0YJFU092@T02XZ:P0XJ6Q0:RXZ02EUID0XZ:R096AT@2>SXh0]kNg08j>SP2P
X:00VYZJ0:6QX@2ATI40WinO0;2`/02CTi<0VIVI0:ZZZP80UiNG0780V9RH0:RXZ02MWId0WinO09NG
U`2m_Kd0UYJF09BDU02LW9`0S8b<0:6QX@1kNg/0WinO09fMW@2OWil0V9RH09VIV@2BTY80WYjN092@
T02CTi<0XZ:R08^;R`23Ph<0IfMW09jNWP2>SXh0RHV908f=S@26QXH0VIVI09JFUP2HV9P0TI6A0:RX
Z022PX80Rh^;09fMW@2JVYX0R8R807UiN@2g]kL0TY:B09RHV020P800SHf=08N7Q`29RHT0RXZ:08n?
S`2YZJT0U9BD09^KV`2OWil0ZZZZ07inOP2GUiL0Shn?09bLW01YJFT0S8b<09JFUP1nOWh0Ogmo092@
T01^KVh0UiNG07moO`1bLW80SHf=08F5Q@22PX80QhN709>CT`1kNg/0MgMg09FEU@27QhL0SHf=08n?
S`1oOgl0QXJ608>3P`2FUYH0PH61096AT@20P800S8b<08V9R@24Q8@0QXJ607QhN01fMWH0Q8B4096A
T@2CTi<0SHf=08>3P`24Q8@0QXJ605mOG`1:BTX0BDU905QHF017AdL0C4a<06e]K@1IFET0JVYZ07Mg
M`1^KVh0F5QH06m_K`1fMWH206EUI@0S079bLP1mOGd0QHF509bLW01/K6`0NGUi06MWI`1_Kfl0QXJ6
079bLP25QHD0LG5a07IfMP1ZJVX0KFe]0820P01eMGD0000005iNGP27QhL0O7al06=SH`1ZJVX0K6a/
05]KF`1DE5@0GUiN05UIF@1KFe/0Jf][04Y:BP1TI6@0Kfm_075aL@1VIVH00P1WIfL06`1OGel0LW9b
07inOP1mOGd0FEUI05]KF`1]KFd0HV9R06YZJP1UIFD0FUYJ04m?C`1QHF40GUiN06i^KP1[Jf/0MGEe
07inOP1QHF40JFUY061PH01/K6`0@d=306MWI`1PH600OGem06QXJ00205aLG00306ATI012@T80oooo
00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@1K0?ooo`1lO7`0I6AT08^;
R`1kNg/0Kfm_07]kN`1;Bd/0MWIf061PH029RHT0LG5a092@T027QhL0Ogmo08V9R@1lO7`0RXZ:07Ad
M01WIfL0HV9R06m_K`1FEUH0LW9b06][J`1gMgL0NGUi07EeM@1TI6@0CDe=05eMG@1:BTX0>c/k05YJ
FP1FEUH0CTi>03Ti>@0d=3@0AdM702@T901<C4`0BTY:07moO`1kNg/0VIVI06m_K`1jNWX0O7al07em
O@1_Kfl0W9bL07inOP2JVYX0SXj>08:2PP2GUiL0Rh^;08F5Q@2DU9@0MGEe08R8R02IVIT0][Jf09ZJ
VP2PX:00V9RH08J6QP1iNGT0UIFE07MgM`24Q8@0Rh^;09BDU02PX:00RXZ:08:2PP2=SHd0TI6A0:JV
YP2WYjL0Rh^;09BDU02<S8`0V9RH08R8R02?Shl0TY:B08j>SP2MWId0Y:BT09nOW`0209VIV@0I08J6
QP2?Shl0WIfM09RHV02LW9`0VYZJ09FEU@2MWId0[Jf]0:JVYP21PH40Ti>C08B4Q01lO7`0RHV907Yj
NP2CTi<0LG5a0:>SX`2TY:@0U9BD0:6QX@2CTi<0[Jf]0:VYZ@020;Bd]01N0;no_`2/[:`0ZZZZ09nO
W`2=SHd0RXZ:0:ZZZP2OWil0QHF509FEU@2JVYX0UIFE09jNWP2RXZ80Ph>30820P02LW9`0Ti>C0;2`
/02MWId0S8b<0:2PX02?Shl0RHV90:RXZ02`/;00NWYj0:FUY@2JVYX0SHf=06i^KP1cLg<0Y:BT09ZJ
VP1kNg/0UiNG08B4Q02QXJ40Shn?08>3P`2@T900UYJF09fMW@2IVIT0Vi^K08b<S02BTY80Shn?09NG
U`2HV9P0O7al07inOP2PX:00UIFE09RHV020P800Ti>C08^;R`2JVYX0U9BD08j>SP1jNWX0QXJ608j>
SP2[Zj/0VIVI092@T01jNWX0L71`08F5Q@2JVYX0[Zj^09NGU`23Ph<0VIVI08J6QP2:RXX0Ogmo08:2
PP1YJFT0RXZ:092@T01_Kfl0G5aL07QhN02IVIT0R8R809jNWP29RHT0Rh^;07moO`2CTi<0R8R808N7
Q`80RHV90240QhN706i^KP1eMGD0S8b<0:NWY`1dM7@0OGem07YjNP1gMgL0UiNG08B4Q01fMWH0Vi^K
08N7Q`1XJ6P0GUiN065QH@1?Cdl0EeMG04i>CP1kNg/0K6a/06MWI`1UIFD0Hf=S05mOG`1@D500Jf][
06MWI`1]KFd0IFEU0861P@1]KFd00P1bLW802P1jNWX0L71`08F5Q@1iNGT0UiNG07YjNP29RHT0Kfm_
09VIV@28R8P206IVIP0B07QhN01aLG40GUiN06][J`1kNg/0GemO079bLP0o?cl0CTi>06UYJ@1>CTh0
K6a/07EeM@1MGEd0JFUY065QH@1YJFT0Cdm?0P1aLG407`1_Kfl0GEeM05mOG`1VIVH0FUYJ06e]K@1b
LW80KFe]06IVIP1>CTh0J6QX05ADE01`L700ATI606QXJ01SHf<0MWIf06][J`1XJ6P0HV9R061PH01Z
JVX0MgMg06MWI`1MGEd0Lg=c061PH01WIfL0Cdm?04I6AP3oool01P3IfMT100000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI0140oooo079bLP1iNGT0Hf=S08:2PP2:RXX0PX:206YZJP1jNWX0
Hf=S07inOP26QXH0PH6107IfMP1mOGd0MgMg07moO`0207MgM`0j08^;R`1kNg/0LG5a07MgM`1UIFD0
Hf=S06a/K02?Shl0Lg=c06IVIP1>CTh0B4Q804Y:BP0g=cL0:RXZ0000000J6QX0=CDe03Ti>@14A4@0
CTi>05=CD`1/K6`0RHV909^KV`22PX80Rh^;07]kN`1mOGd0RXZ:08B4Q02FUYH0LG5a08R8R01gMgL0
OWin0:FUY@2CTi<0QHF508f=S@2@T900ZZZZ08F5Q@2CTi<0QXJ608f=S@2>SXh0UiNG07IfMP1_Kfl0
UYJF06m_K`2LW9`0Y:BT092@T02CTi<0SXj>0:2PX080U9BD0480QXJ609BDU02XZ:P0XJ6Q09bLW02O
Wil0/[:b08j>SP29RHT0WYjN0:2PX023Ph<0RHV90861P@20P800VIVI0;:b/P2CTi<0];Bd0:BTY02_
[jl0VYZJ09fMW@2;Rh/0L71`06YZJP1QHF40Hf=S06QXJ01hN7P0MgMg0820P02EUID0U9BD0:b/[02[
Zj/0XJ6Q0:f][@2j^[X0Shn?0:NWY`2GUiL0YjNW09bLW02?Shl0SXj>0;Bd]02TY:@0TY:B09VIV@1g
MgL0WIfM08N7Q`2LW9`0Ti>C08:2PP1iNGT0Q8B407MgM`2LW9`0Shn?08F5Q@1lO7`0KVi^08V9R@1i
NGT20:ZZZP0:071`L02WYjL0[jn_0:>SX`2RXZ80Zj^[08j>SP2ZZZX0S8b<09NGU`80U9BD00P0V9RH
0::RXP2MWId0UYJF09:BTP2XZ:P0Y:BT09ZJVP80ZZZZ01@0WYjN0:n_[`2LW9`0UYJF07emO@2ATI40
PX:209bLW02<S8`0V9RH09JFUP25QHD0UYJF08f=S@2EUID0P82008f=S@1`L700T92@09JFUP80U9BD
00X0NGUi0:RXZ026QXH0R8R809ZJVP25QHD0TI6A09RHV02CTi<0VIVI0P2BTY804P2ATI40MWIf08F5
Q@2FUYH0Jf][06a/K02PX:00R8R808b<S023Ph<0QXJ609BDU01UIFD0UIFE092@T02JVYX0Ph>307If
MP80PX:20580Xj>S08:2PP1_Kfl0UiNG06m_K`1iNGT0SHf=07=cL`1UIFD0GUiN061PH01?Cdl0GemO
05UIF@1ZJVX0Jf][06ATI01/K6`0HF5Q06i^KP2?Shl0Ng]k07QhN01nOWh0Q8B408Z:RP1`L700NGUi
06UYJ@1iNGT0RXZ:08^;R`1fMWH0LG5a06a/K026QXH0U9BD06YZJP1XJ6P0FEUI08F5Q@1^KVh0Jf][
07MgM`1UIFD0FUYJ04];B`1UIFD0O7al06MWI`1`L700QhN705iNGP21PH40MgMg06UYJ@1`L700LW9b
06m_K`1XJ6P0IFEU06UYJ@1hN7P0K6a/06ATI029RHT0DU9B03`l?01ZJVX0GemO06a/K01>CTh0Lg=c
06EUI@1ZJVX0JFUY0861P@1hN7P0K6a/08B4Q01bLW80G5aL0P1ZJVX01`1VIVH0HF5Q03lo?`15ADD0
@d=302d];@3oool01P3IfMT100000040fMWI000F0=WIf@800000103IfMT06@3oool0Q8B405mOG`1g
MgL0QHF508R8R01cLg<0N7Qh08:2PP1jNWX0PH6108Z:RP1^KVh0N7Qh07moO`28R8P0PH6109bLW02B
TY80Ph>305eMG@1EEED0G5aL07]kN`1ZJVX00P1gMgL206e]K@0804=3@`1ADE40BTY:04U9B@0Y:BT0
61PH03Hf=P0I6AT203Ph>00A06YZJP24Q8@0QXJ609fMW@2[Zj/0R8R808j>SP1eMGD0NGUi07QhN022
PX80Ph>307IfMP2?Shl0SHf=08n?S`2KVi/00P2MWId00`2WYjL0TY:B075aL@02092@T01J09>CT`2F
UYH0UiNG0:6QX@2PX:00T92@07EeM@2<S8`0RXZ:092@T02EUID0O7al0:2PX02CTi<0XZ:R09JFUP2:
RXX0VIVI0;Bd]02/[:`0VYZJ09NGU`2@T900RXZ:08f=S@2TY:@0Ph>30:6QX@20P800N7Qh0::RXP2A
TI40YjNW07AdM02QXJ40UIFE0:ZZZP29RHT0P820069RHP1WIfL0FEUI04E5A@0k>c/0Bd];06QXJ01Y
JFT0QhN707IfMP2:RXX0XJ6Q09JFUP2HV9P0]KFe0;2`/02NWYh0ZJVY0:BTY02NWYh0QXJ609jNWP2P
X:00WinO0:^[Z`2HV9P0XJ6Q09BDU02ATI40Y:BT09JFUP2=SHd0[Jf]09^KV`2VYZH0SXj>09nOW`2:
RXX0T92@0:^[Z`2DU9@0MgMg08b<S02^[Zh0XJ6Q09>CT`2BTY80QHF50820P02@T900Ti>C0P2SXj<0
FP2;Rh/0Y:BT08f=S@2>SXh0KVi^09JFUP2PX:00WinO09>CT`2GUiL0Vi^K09VIV@2YZJT0TY:B092@
T02OWil0UiNG0:j^[P2NWYh0S8b<09RHV02UYJD0T92@0861P@2JVYX0T92@08V9R@2HV9P0Q8B408Z:
RP2QXJ40PX:20:b/[02IVIT0U9BD096AT@29RHT0T92@08j>SP1ZJVX0QXJ609^KV`21PH40P82008:2
PP29RHT0R8R809:BTP1eMGD0VIVI08N7Q`2;Rh/0MWIf08j>SP1oOgl0Ph>307]kN`2DU9@0S8b<07Yj
NP1hN7P0PH610820P02=SHd0Ogmo08Z:RP2?Shl0MGEe07UiN@1cLg<0O7al06ATI01lO7`0QXJ60820
P02BTY80IVIV04Y:BP1<C4`0MWIf06IVIP1DE5@0IVIV05]KF`1^KVh0NWYj06a/K01[Jf/0J6QX07Ee
M@80SHf=01D0MGEe08V9R@2CTi<0I6AT08V9R@1^KVh0VIVI08F5Q@27QhL0M7Ad08N7Q`1XJ6P0Ph>3
07alO01XJ6P0I6AT05]KF`1TI6@0IVIV069RHP1WIfL00P1KFe/0;01iNGT0HF5Q05UIF@1JFUX0Hf=S
05ADE01VIVH0MWIf06=SH`1_Kfl0LW9b04m?C`1aLG40LW9b06][J`1ADE40NWYj06EUI@1PH600I6AT
06UYJ@1aLG40Ng]k06QXJ01iNGT0Jf][069RHP1dM7@0OGem04a<C01`L700JVYZ075aL@1_Kfl0J6QX
06ATI01`L700MWIf065QH@1`L700Bd];055AD@0l?3`0oooo1@3IfMT200000040fMWI000F0=WIf@03
0000003IfMT0fMWI00<0fMWI01/0oooo06YZJP1kNg/0H61P08B4Q01oOgl0OWin07YjNP1eMGD0L71`
08F5Q@1kNg/0Q8B408j>SP1QHF40Ogmo096AT@2>SXh0YjNW09fMW@1`L700M7Ad06i^KP1gMgL0TY:B
06][J`1/K6`00P1^KVh0B@1HF5P0CDe=03Hf=P15ADD0=CDe03Xj>P0`<300B4Q802TY:@15ADD0OGem
09>CT`24Q8@0PX:2096AT@26QXH0R8R807EeM@2>SXh0P82009nOW`28R8P0Kfm_08Z:RP2=SHd0Q8B4
0::RXP2:RXX0T92@09JFUP2GUiL0W9bL08f=S@1]KFd0RXZ:0820P02FUYH0R8R809JFUP1kNg/0IfMW
07inOP2EUID0MGEe0:NWY`2ATI40T92@08:2PP24Q8@0UIFE0:2PX02KVi/0V9RH08f=S@2b/[80T92@
08J6QP2^[Zh0Ogmo08f=S@2TY:@0NGUi0820P02;Rh/0/[:b09jNWP2=SHd0Vi^K092@T01eMGD0IVIV
05IFEP0M7Ad00P0B4Q802P051@D0;Bd]02TY:@0X:2P0E5AD05=CD`1NGUh0NGUi07IfMP2GUiL209jN
WP0e0:BTY02FUYH0VYZJ0:2PX01cLg<0MWIf08F5Q@2>SXh0Q8B408V9R@2>SXh0OWin09>CT`2c/k<0
WYjN09bLW02SXj<0SHf=0820P01FEUH0QHF508V9R@2?Shl0O7al0:VYZ@2=SHd0U9BD09VIV@26QXH0
UYJF0:2PX02HV9P0UIFE08f=S@2CTi<0U9BD09JFUP2=SHd0Ogmo08f=S@2a/K40/[:b0:BTY02MWId0
T92@08:2PP1/K6`0Ti>C0861P@2@T900V9RH08R8R02_[jl00P2<S8`0>02@T900QHF50:NWY`1oOgl0
YJFU0::RXP2LW9`0R8R809ZJVP2;Rh/0VIVI08^;R`2VYZH0P82008^;R`2<S8`0RXZ:09FEU@2=SHd0
WinO07UiN@2EUID0UYJF07moO`2DU9@0Rh^;08b<S01kNg/0YJFU08Z:RP1kNg/0YJFU0820P01hN7P0
PH6109BDU027QhL0TY:B07IfMP23Ph<0QXJ609FEU@2BTY80Q8B408:2PP1mOGd0SXj>0861P@1mOGd0
QXJ608V9R@2GUiL0NWYj07alO01aLG40L71`0P25QHD0<P1bLW80I6AT08F5Q@1QHF40JFUY07alO01T
I6@0KFe]05]KF`1FEUH0DU9B05UIF@1bLW80S8b<07=cL`1nOWh0NGUi08B4Q023Ph<0EeMG07emO@26
QXH0N7Qh08>3P`2BTY80JVYZ07UiN@1UIFD0P82006=SH`1[Jf/0Hf=S079bLP1QHF40Hf=S07alO01Q
HF40Bd];05mOG`1]KFd0LG5a071`L01UIFD0PX:206a/K01TI6@0M7Ad05mOG`1[Jf/0L71`0P1VIVH0
8@1cLg<0K6a/05IFEP1LG5`0EeMG07EeM@1kNg/0FUYJ07=cL`1VIVH0GEeM06ATI01cLg<0MgMg06a/
K01IFET0Hf=S07moO`22PX80OGem075aL@1/K6`0Q8B406UYJ@1mOGd0EeMG06][J`1_Kfl0JVYZ030`
<01?Cdl0@T920?ooo`060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0C03o
ool0LG5a079bLP1gMgL0P82006e]K@2:RXX0Jf][07UiN@1aLG40S8b<09>CT`1fMWH0UYJF07alO02;
Rh/0PX:208f=S@1HF5P0OGem07IfMP1^KVh0LG5a07UiN@1oOgl0OWin05YJFP1[Jf/0?Cdm0492@P0i
>CT0FUYJ06=SH`1MGEd0@d=306YZJP1ADE40Fe]K065QH@2DU9@0QHF509>CT`27QhL0V9RH09BDU01l
O7`0MgMg092@T02<S8`0TY:B08N7Q`2CTi<0S8b<09^KV`27QhL0UiNG09jNWP2:RXX0ZZZZ0:VYZ@2I
VIT0UIFE096AT@1WIfL0SHf=09nOW`1lO7`0WYjN08V9R@2DU9@0VIVI08Z:RP29RHT0TI6A0;>c/`2J
VYX209VIV@0F08f=S@25QHD0V9RH08n?S`25QHD0Zj^[09fMW@2DU9@0TY:B09>CT`2RXZ80P82009FE
U@22PX80TY:B096AT@2HV9P0Ng]k07inOP1dM7@0=3@d01XJ6PH0000002`02`/;034a<@0i>CT0EUIF
04m?C`1YJFT0Kfm_09BDU02HV9P0S8b<0;Ng]`22PX80QhN707UiN@1QHF40IfMW06m_K`1:BTX0GEeM
059BDP1[Jf/0O7al07UiN@2QXJ40Ph>3092@T02FUYH0VIVI09JFUP2OWil0TI6A08F5Q@2FUYH0Xj>S
08R8R01hN7P0T92@0:>SX`2JVYX0U9BD09fMW@2;Rh/0WYjN0:^[Z`80WinO00<0Zj^[08b<S020P800
0P2:RXX0?@2CTi<0R8R809ZJVP1_Kfl0Ti>C08^;R`2ATI40V9RH07]kN`2OWil0VYZJ0;2`/02QXJ40
R8R809JFUP23Ph<0ZZZZ08B4Q02QXJ40Y:BT09fMW@2OWil0UIFE09RHV028R8P0Xj>S0;>c/`2BTY80
WYjN0;Fe]@2MWId0YjNW07emO@2FUYH0Q8B408>3P`2>SXh0RXZ:09RHV02=SHd0M7Ad08^;R`21PH40
Ng]k0:JVYP1lO7`0QhN708b<S022PX80Ti>C079bLP28R8P0Shn?0000001eMGD0QhN709>CT`2:RXX0
Shn?06YZJP1_Kfl00P21PH40@`22PX80PH6108R8R01/K6`0QXJ606e]K@1kNg/0SHf=0861P@23Ph<0
KFe]071`L01iNGT0MWIf07MgM`1cLg<0MGEe06QXJ01mOGd0KFe]079bLP1LG5`0N7Qh06EUI@1kNg/0
OGem07=cL`21PH40QXJ604I6AP26QXH0Kfm_08f=S@1oOgl0OGem07EeM@1bLW80Kfm_06i^KP1kNg/0
EEEE0861P@20P800KFe]05UIF@1=CDd0Fe]K075aL@1bLW80K6a/061PH01XJ6P0M7Ad05iNGP1jNWX0
MgMg07=cL`1`L700HF5Q07EeM@1iNGT0I6AT06EUI@1IFET0MgMg06i^KP1_Kfl00P1NGUh06@1ZJVX0
IfMW06MWI`1EEED0De=C051@D01lO7`0E5AD04m?C`1OGel0DE5A05iNGP1HF5P0GEeM07AdM01LG5`0
CTi>05mOG`1PH600:BTY05]KF`1:BTX0B4Q803Xj>P3oool01P3IfMT100000040fMWI000F0=WIf@03
0000003IfMT0fMWI00<0fMWI0200oooo08j>SP1eMGD0NWYj06e]K@2IVIT0JFUY08B4Q01^KVh0Shn?
09>CT`1jNWX0QXJ6061PH028R8P0RXZ:08f=S@27QhL0OGem07YjNP1VIVH0MgMg06m_K`1aLG40Ogmo
07]kN`1gMgL0J6QX051@D019BDT0BTY:051@D080ADE500l0K6a/06IVIP1aLG40Q8B407AdM02OWil0
T92@08^;R`2<S8`0XZ:R092@T02BTY80Y:BT0:RXZ02OWil00P2JVYX0<02FUYH0Y:BT096AT@2DU9@0
VYZJ0:>SX`2UYJD0R8R808B4Q021PH40R8R809^KV`2DU9@0UiNG09^KV`2CTi<0RXZ:07alO02ZZZX0
T92@08V9R@2<S8`0RHV909FEU@21PH40V9RH09NGU`2;Rh/0VYZJ092@T02IVIT0XZ:R0:2PX02KVi/0
SHf=08J6QP27QhL0NWYj07UiN@2:RXX0UIFE08:2PP2JVYX0Y:BT08n?S`1_Kfl0Fe]K01lO7`P00000
048092@T02HV9P0T92@0=CDe03Hf=P1jNWX0IFEU08Z:RP2;Rh/0_[jn07inOP1XJ6P0G5aL07]kN`1X
J6P0BDU906=SH`1UIFD0FEUI06ATI01ZJVX0Lg=c08V9R@2LW9`0YZJV0:b/[020P800Z:RX0:2PX02b
/[80VIVI0:6QX@2SXj<0Ph>307moO`2@T900NGUi0:RXZ02;Rh/0ZJVY09NGU`2VYZH0Zj^[09>CT`1h
N7P0UIFE09jNWP2>SXh0YjNW0:BTY02UYJD0RHV908:2PP2][Jd0Rh^;09JFUP2?Shl0Vi^K08Z:RP24
Q8@0W9bL08n?S`2DU9@0X:2P08j>SP2g]kL208f=S@0n09fMW@2;Rh/0RHV909>CT`28R8P0Ti>C09FE
U@23Ph<0TI6A08F5Q@2ATI40PH6109bLW02NWYh0QHF509FEU@20P800O7al08f=S@23Ph<0QHF508:2
PP2=SHd0VIVI0;2`/02@T900X:2P07alO024Q8@0PH6108N7Q`1bLW80VIVI09jNWP2:RXX0IfMW06QX
J02<S8`0Xj>S08^;R`20P800N7Qh075aL@1lO7`0Y:BT075aL@22PX80O7al08Z:RP25QHD0MWIf07Ad
M02>SXh0Rh^;08:2PP1]KFd0UIFE08f=S@1ZJVX0S8b<07AdM01lO7`206m_K`1806IVIP1cLg<0NWYj
06MWI`2<S8`0RHV908F5Q@26QXH0JFUY07QhN01SHf<0PX:207]kN`1bLW80Lg=c096AT@2?Shl0PH61
08>3P`1mOGd0N7Qh06ATI01aLG40Ogmo07UiN@1mOGd0F5QH07alO01RHV80IfMW06][J`1?Cdl0F5QH
06i^KP1EEED0Hf=S06e]K@1nOWh0Q8B408F5Q@1fMWH0Lg=c05MGE`1CDe<0IVIV04U9B@1OGel0NWYj
059BDP1nOWh0HV9R07EeM@1TI6@0IFEU06=SH`1aLG40CDe=05iNGP1iNGT0PH6106EUI@1QHF40H61P
05UIF@1bLW80J6QX061PH021PH40IFEU071`L01KFe/0DE5A0P1:BTX00`3oool0fMWI0=WIf@040=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT05`3oool0QHF50861P@1gMgL0TY:B
06m_K`23Ph<0J6QX0820P02@T900PH61071`L01YJFT0H61P08R8R02<S8`0NGUi06a/K01]KFd0NGUi
06EUI@2>SXh0Ng]k0080OGem01H0MWIf06IVIP1DE5@0MGEe04a<C014A4@0Lg=c08R8R01]KFd0Ti>C
08R8R02?Shl0MWIf08F5Q@2VYZH0W9bL09:BTP2?Shl0XZ:R08N7Q`2TY:@0U9BD0P2EUID0<@1oOgl0
V9RH08V9R@2JVYX0Jf][096AT@2GUiL0V9RH08n?S`2NWYh0WinO0:NWY`1oOgl0UYJF08J6QP2JVYX0
R8R809>CT`1gMgL0P82009^KV`2<S8`0Y:BT09fMW@2CTi<0UYJF0:FUY@2PX:00UiNG09jNWP2KVi/0
TY:B0:RXZ02/[:`0T92@0;6a/@1TI6@0MGEe06m_K`2OWil0U9BD0:JVYP2^[Zh0ZZZZ09BDU01oOgl0
HV9R05=CD`0j>SX02@000000B00R8R8092@T03@d=00N7Qh0;Rh^04E5A@2;Rh/0MgMg07YjNP2=SHd0
N7Qh04I6AP1GEeL0IFEU05eMG@1UIFD0KVi^06MWI`1iNGT0GemO05UIF@1ZJVX0Lg=c08J6QP2VYZH0
UiNG09JFUP2BTY80VYZJ09FEU@2ATI40Ogmo09:BTP1mOGd0W9bL0861P@2QXJ40YZJV09FEU@2NWYh0
T92@08N7Q`2?Shl0Z:RX08j>SP2CTi<0Rh^;05eMG@2?Shl0WinO0:NWY`1nOWh0UIFE0:BTY022PX80
RXZ:0:NWY`2?Shl0UYJF09:BTP2TY:@0VIVI09RHV02?Shl0[Jf]0:RXZ02^[Zh0UYJF09bLW02VYZH0
V9RH0:^[Z`80YjNW00l0S8b<08J6QP2>SXh0VYZJ0:RXZ02@T900Vi^K08N7Q`1lO7`0/[:b08R8R02N
WYh0Ph>308n?S`2<S8`00P2ATI404`2MWId0SXj>07alO02@T900PX:209>CT`2ATI40UIFE0820P02I
VIT0PX:208F5Q@2ATI40P82008V9R@20P800UIFE09bLW01nOWh00P1iNGT0102=SHd0V9RH09VIV@2J
VYX208N7Q`0X07emO@1_Kfl0Shn?0820P01iNGT0PX:207IfMP1XJ6P0Ph>307YjNP1aLG40H61P0861
P@1cLg<0QHF5079bLP1gMgL0QXJ6092@T02<S8`0KFe]07YjNP1dM7@0Shn?08V9R@21PH40R8R808Z:
RP1[Jf/0Lg=c07inOP1jNWX0M7Ad08B4Q01XJ6P0MWIf06e]K@1bLW80Lg=c08j>SP80QHF502l0RHV9
07=cL`1XJ6P0GUiN06QXJ01eMGD0Kfm_07IfMP1/K6`0Fe]K061PH01WIfL0LG5a06ATI01?Cdl0FUYJ
05MGE`13@d<0HV9R05]KF`1IFET0O7al05eMG@1dM7@0I6AT06][J`1CDe<0FEUI079bLP1?Cdl0H61P
06=SH`1OGel0M7Ad07emO@1dM7@0K6a/059BDP1^KVh0JFUY06ATI01QHF40FUYJ03/k>`1<C4`0>3Ph
0?ooo`060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0>P3oool0O7al07Ui
N@1oOgl0Jf][075aL@2;Rh/0SXj>08:2PP1oOgl0KVi^0820P01OGel0J6QX06a/K02;Rh/0QhN7092@
T029RHT0P820079bLP2>SXh0S8b<08R8R02?Shl0RXZ:06a/K01hN7P0LG5a05ADE01PH600MWIf07Yj
NP2QXJ40V9RH0:j^[P2CTi<0OWin079bLP2;Rh/0UYJF0820P02ATI40/;2`07MgM`2;Rh/0Shn?092@
T02;Rh/0N7Qh07]kN`2ATI40MWIf09nOW`25QHD0MGEe07emO@2DU9@208b<S00V0:6QX@2GUiL0Ng]k
08R8R02PX:00RXZ:09:BTP2@T900VYZJ08F5Q@2HV9P0Rh^;09>CT`1nOWh0UIFE08:2PP2QXJ40S8b<
08F5Q@29RHT0WinO09NGU`2<S8`0X:2P08N7Q`23Ph<0MWIf08N7Q`1kNg/0X:2P09JFUP2DU9@0YJFU
07moO`21PH40De=C03Lg=`0M7Ad90000001/01dM7@0B4Q80?clo02h^;P071`L0;Rh^06m_K`1dM7@0
Ng]k079bLP1;Bd/0ATI60410@00g=cL0IFEU07IfMP1WIfL0HF5Q06QXJ01YJFT0G5aL05YJFP2?Shl0
R8R809NGU`2`/;00UiNG09RHV02MWId0Ph>309RHV02<S8`0UYJF0::RXP26QXH0XZ:R0:b/[02EUID0
[Jf]0;2`/02UYJD0Ti>C0861P@2d];@0RHV908B4Q01kNg/0V9RH07QhN024Q8@0Ogmo07inOP1eMGD0
UYJF07inOP1gMgL0TI6A08Z:RP2QXJ40TI6A0820P02NWYh0U9BD08^;R`2OWil0UiNG09fMW@2KVi/0
RXZ:08^;R`2BTY80U9BD09nOW`2?Shl0UiNG0:>SX`2PX:00XJ6Q09BDU01iNGT0Q8B408V9R@2@T900
MWIf0820P02?Shl0NWYj07UiN@2ATI40O7al0:2PX02;Rh/0SXj>09fMW@2EUID0R8R809nOW`2QXJ40
IfMW08f=S@24Q8@0O7al0861P@1dM7@0OGem08b<S02;Rh/0UYJF0P2?Shl03P2:RXX0UiNG07inOP2A
TI40Jf][08F5Q@2TY:@0Q8B407inOP2KVi/0R8R807IfMP1RHV80LW9b0P1aLG408@1RHV80Lg=c07al
O026QXH0MGEe07YjNP1hN7P0T92@08J6QP1hN7P0TI6A08V9R@1cLg<0LW9b07EeM@1cLg<0TY:B09bL
W01aLG40NGUi07alO01`L700NWYj06a/K01XJ6P0MGEe06EUI@051@D0Ng]k07AdM01ZJVX0OGem069R
HP0206QXJ00^07UiN@1dM7@0FUYJ05eMG@1YJFT0HF5Q06=SH`1gMgL0IFEU07EeM@1_Kfl0Lg=c0820
P016ATH0E5AD05mOG`0h>3P0KFe]059BDP1UIFD0IVIV05mOG`1ADE40Hf=S05UIF@1bLW80Fe]K06QX
J01gMgL0J6QX07MgM`1]KFd0H61P07inOP1[Jf/0J6QX07emO@1MGEd0MGEe069RHP1gMgL0KFe]03Hf
=P0k>c/0>3Ph0?ooo`H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0=0?oo
o`1iNGT0Ph>307QhN029RHT0L71`06m_K`29RHT0Kfm_08B4Q029RHT0NGUi07]kN`020861P@0N08B4
Q01iNGT0QHF5059BDP1`L700QHF508R8R02:RXX0SXj>08J6QP1jNWX0JFUY08j>SP1XJ6P0Lg=c07If
MP1SHf<0Ng]k08V9R@2;Rh/0WIfM079bLP2@T900OGem09NGU`2d];@0WIfM08b<S01[Jf/0NGUi0P1_
Kfl0202ATI40QXJ606][J`1aLG40Jf][08Z:RP1_Kfl0O7al0P1iNGT0:02<S8`0TY:B08V9R@2CTi<0
Y:BT0:RXZ02HV9P0Vi^K08n?S`25QHD0SHf=08V9R@27QhL0RHV90861P@2PX:00Ti>C09FEU@2SXj<0
ZZZZ08b<S02[Zj/0`<3009JFUP2ATI40Zj^[0:f][@2BTY80VIVI08Z:RP2CTi<0WinO0;Jf]P2HV9P0
T92@0:FUY@1RHV80FEUI0492@P0Q8B450000000B00/;2`0G5aL0000000d=3@0>3Ph0>CTi028R8P0Y
:BT0000000`<3016ATH0A4A407IfMP1IFET0J6QX05eMG@12@T80BTY:0P1WIfL0<`1]KFd0R8R808:2
PP1hN7P0R8R807MgM`1TI6@0MgMg07=cL`2CTi<0UYJF0:6QX@2ATI40SXj>0<71`@2IVIT0VYZJ09jN
WP2IVIT0TY:B09FEU@2JVYX0V9RH096AT@2FUYH0Vi^K08N7Q`2>SXh0/[:b0:b/[026QXH0Shn?09bL
W02=SHd0PX:207MgM`22PX80X:2P09VIV@2>SXh0RHV909jNWP2GUiL0N7Qh0:>SX`2MWId0TI6A08n?
S`2DU9@0W9bL08R8R00209bLW01408b<S02IVIT0W9bL08Z:RP2TY:@0UIFE09NGU`22PX80Shn?09FE
U@26QXH0TY:B0:^[Z`2CTi<0SHf=09^KV`23Ph<0R8R808>3P`2DU9@0WYjN08b<S02EUID0PH6109JF
UP1iNGT0SHf=07alO02<S8`0SXj>07inOP2BTY80V9RH09^KV`1hN7P0LW9b09BDU01nOWh0RXZ:06UY
J@2EUID0M7Ad08N7Q`29RHT0SHf=08R8R01lO7`0N7Qh08>3P`1bLW80E5AD07moO`1hN7P0GUiN075a
L@2;Rh/0M7Ad05iNGP2=SHd0PH6107AdM01`L700NWYj06IVIP1ZJVX0Ph>307alO01cLg<207YjNP0X
071`L01oOgl0G5aL08J6QP1bLW80SXj>07=cL`24Q8@0MGEe07IfMP1]KFd0R8R808^;R`1/K6`0Jf][
07=cL`20P800Ng]k07emO@1kNg/0RXZ:07EeM@1gMgL0CDe=07QhN01fMWH0GemO06MWI`1^KVh0HV9R
05mOG`1PH600KFe]061PH01eMGD0Kfm_06YZJP1SHf<0JVYZ059BDP80L71`01/0FEUI06YZJP1XJ6P0
PH6105QHF013@d<0CTi>059BDP1MGEd0C4a<069RHP1UIFD0H61P06m_K`1oOgl0DE5A05iNGP1lO7`0
Lg=c06IVIP1/K6`0H61P05IFEP1GEeL0?clo051@D03oool01P3IfMT100000040fMWI000F0=WIf@03
0000003IfMT0fMWI00<0fMWI01@0oooo07EeM@1ZJVX0NWYj06QXJ01hN7P0RXZ:07alO021PH40N7Qh
0861P@29RHT0Ogmo08Z:RP22PX80NGUi07inOP20P800MgMg08Z:RP80KVi^0200Lg=c08V9R@2LW9`0
UYJF09VIV@2CTi<0LG5a07YjNP1_Kfl0O7al07moO`22PX80JFUY07=cL`1kNg/0VYZJ092@T02?Shl0
Ph>307UiN@1_Kfl0QHF506EUI@2CTi<0U9BD08n?S`2HV9P0M7Ad06i^KP1XJ6P0N7Qh08F5Q@80RHV9
02P0UYJF08b<S01lO7`0R8R808F5Q@2;Rh/0Vi^K06e]K@1kNg/0QhN708j>SP2MWId0V9RH09nOW`2`
/;00OGem09RHV02LW9`0YZJV0:2PX02IVIT0UIFE09NGU`2@T900[Jf]09nOW`2VYZH0YjNW07YjNP2>
SXh0IVIV0:^[Z`2FUYH0_Kfm09fMW@2PX:00TI6A06YZJP1=CDd0@d=31@000000200D51@0ADE5055A
D@19BDT0:b/[01DE5@0@41004A4A0`000000?@0A4A40FEUI05mOG`1YJFT0KVi^06][J`1>CTh0H61P
07YjNP1@D500IfMW07alO01gMgL0UiNG07IfMP1nOWh0N7Qh05IFEP21PH40SXj>09bLW02MWId0UYJF
08^;R`2BTY80K6a/09FEU@2TY:@0X:2P07MgM`2^[Zh0VIVI0;Bd]02UYJD0Y:BT09VIV@20P800XJ6Q
08V9R@2][Jd0`l?308Z:RP2FUYH0Vi^K09nOW`2MWId0ZJVY092@T02^[Zh0Ph>308^;R`2FUYH0[jn_
0:b/[02HV9P0QHF508Z:RP26QXH0WinO0;Bd]029RHT00P2GUiL08@1oOgl0Ph>30:6QX@2CTi<0Y:BT
0::RXP24Q8@0SXj>0861P@2ATI40RHV908^;R`29RHT0Vi^K09RHV02EUID0QhN708b<S01iNGT0Ogmo
08>3P`2PX:00QhN70:NWY`20P800TY:B092@T01nOWh0XJ6Q07inOP21PH40VIVI08:2PP0208^;R`1X
0861P@2;Rh/0RXZ:08J6QP1mOGd0IVIV08f=S@26QXH0PH6109>CT`1eMGD0QhN708V9R@1oOgl0O7al
05iNGP22PX80Ng]k05QHF01eMGD0KVi^06QXJ01kNg/0Jf][0861P@2DU9@0R8R808B4Q02DU9@0S8b<
07inOP2=SHd0R8R807MgM`1oOgl0GUiN0861P@20P800SXj>08B4Q01XJ6P0O7al08J6QP1XJ6P0IFEU
07MgM`1_Kfl0Q8B407]kN`21PH40PX:207moO`26QXH0Lg=c07QhN01^KVh0D51@069RHP1XJ6P0MGEe
05aLG01<C4`0MWIf06QXJ01UIFD0Ng]k06EUI@1`L700PX:206e]K@1[Jf/0GemO06a/K01aLG40GemO
06YZJP1fMWH0GUiN06i^KP1=CDd0LG5a05mOG`1ZJVX0K6a/075aL@1_Kfl0FUYJ079bLP1^KVh0DE5A
05UIF@1iNGT0J6QX05UIF@1ZJVX0Kfm_07MgM`1PH600LW9b04M7A`1=CDd0FEUI05mOG`3oool60=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0AP3oool0KFe]06][J`1jNWX0L71`
0820P01YJFT0OWin08:2PP1VIVH0Ng]k07YjNP2=SHd0OWin08f=S@1fMWH0OGem08V9R@1nOWh0QHF5
07UiN@2@T900Ogmo08b<S02FUYH0OWin08b<S02KVi/0MWIf07alO02BTY80Ti>C07EeM@26QXH0Ph>3
08b<S02:RXX0T92@09ZJVP24Q8@0VYZJ092@T01nOWh0Q8B4075aL@1mOGd0RHV908:2PP2=SHd0Ng]k
07moO`1IFET0O7al05iNGP1mOGd0GUiN08N7Q`1kNg/0M7Ad08>3P`2ATI40O7al09^KV`2MWId0N7Qh
07emO@2DU9@0MGEe0:JVYP24Q8@209jNWP0I0:>SX`2CTi<0W9bL09fMW@2ZZZX0S8b<0:>SX`22PX80
TI6A0:FUY@2GUiL0UYJF096AT@22PX80WYjN09ZJVP2EUID0XJ6Q09fMW@2BTY80XJ6Q06e]K@11@D40
ADE501DE5@0400000008024Q8@1@D500BTY:055AD@0Q8B407alO000000030`<30000001F02DU9@1E
EED0I6AT07emO@1`L700I6AT07EeM@1bLW80NWYj08^;R`27QhL0Rh^;08F5Q@2JVYX0NWYj08b<S01g
MgL0H61P07EeM@2?Shl0UIFE08V9R@2FUYH0LG5a0:VYZ@2CTi<0TI6A0:>SX`1mOGd0WIfM0:2PX02B
TY80X:2P09:BTP2;Rh/0VIVI09BDU02@T900PH610;no_`2`/;00WIfM0:FUY@2KVi/0VYZJ09fMW@2:
RXX0Rh^;08F5Q@2QXJ40T92@09ZJVP1dM7@0VIVI08V9R@28R8P0SXj>09NGU`2;Rh/0SHf=07AdM02S
Xj<0[Zj^06][J`2=SHd0VIVI08R8R02=SHd0Ti>C07moO`28R8P0N7Qh09bLW02:RXX0SHf=09JFUP2L
W9`0VIVI0:RXZ021PH40N7Qh09BDU01iNGT0Rh^;09NGU`28R8P209:BTP1b08:2PP2ATI40VYZJ09:B
TP1mOGd0OWin08R8R02XZ:P0RXZ:092@T01eMGD0P82008j>SP2HV9P0S8b<07emO@2KVi/0Ti>C08>3
P`1`L700OWin08^;R`1`L700S8b<08f=S@12@T80Q8B407MgM`24Q8@0Ph>308F5Q@1?Cdl0MgMg06EU
I@25QHD0QXJ608f=S@2;Rh/0KFe]07AdM01oOgl0P82007IfMP1oOgl0P820079bLP25QHD0Lg=c07Ee
M@1mOGd0Ng]k07IfMP1ZJVX0Ph>307=cL`1IFET0JVYZ07UiN@21PH40GUiN07YjNP1TI6@0PX:207in
OP1iNGT0O7al05eMG@1aLG40Ogmo06m_K`1cLg<0P820079bLP1TI6@0JVYZ079bLP1eMGD0KVi^06e]
K@1PH600IFEU061PH01SHf<0L71`06i^KP1JFUX0H61P05UIF@1]KFd0De=C05IFEP1LG5`0EUIF06i^
KP1gMgL0L71`07UiN@1]KFd0BDU905mOG`1FEUH0M7Ad065QH@26QXH0IFEU04Y:BP1/K6`0IFEU04m?
C`1JFUX0CTi>03lo?`10@400oooo1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0
fMWI00T0oooo06][J`1nOWh0JVYZ065QH@1`L700QXJ60820P01oOgl00P1dM7@08P1kNg/0PX:207Yj
NP1FEUH0MWIf08J6QP2=SHd0T92@0820P01cLg<0LG5a07alO02@T900MgMg09VIV@2ATI40MWIf07Ee
M@2;Rh/0RXZ:0:RXZ02GUiL0SXj>06e]K@2h^;P0Ti>C08Z:RP1iNGT0QXJ60820P02CTi<0RXZ:07=c
L`26QXH209FEU@0l09RHV01mOGd0Ogmo06a/K01oOgl0WIfM08n?S`2GUiL0RXZ:09NGU`2:RXX0P820
06UYJ@25QHD0MGEe08^;R`2MWId0Ti>C0:ZZZP2YZJT0WIfM08^;R`2MWId0WYjN0;2`/02JVYX0YJFU
09BDU02[Zj/0Xj>S08>3P`2k^k/0VIVI0;Vi^@2e]KD0`L710:6QX@2XZ:P0Shn?08^;R`1kNg/0RHV9
09>CT`2i^KT0XZ:R09JFUP1WIfL0>c/k03`l?00B4Q80000000@4100?3`l04a<C03Ti>@14A4@0JFUY
0451@@030`<01`L71@000000BP0O7al0ATI607alO01mOGd0Hf=S07EeM@1cLg<0Ng]k07inOP1hN7P0
QHF506ATI01oOgl0RXZ:07YjNP1YJFT0JVYZ06EUI@000000WIfM08F5Q@2MWId0Y:BT08n?S`2EUID0
QHF509:BTP2ZZZX0L71`09:BTP2QXJ40YZJV07emO@2?Shl0X:2P09nOW`2BTY80WinO0:BTY022PX80
[jn_09jNWP2LW9`0WYjN09NGU`28R8P0QhN70:ZZZP1iNGT0Y:BT0::RXP2IVIT0UYJF0:RXZ029RHT0
TY:B08N7Q`2/[:`0VYZJ09:BTP29RHT0PH6108^;R`22PX80UiNG09^KV`25QHD0Y:BT08J6QP2<S8`0
RXZ:08N7Q`2BTY80a<C40P2>SXh0<`2ATI40Ogmo0:>SX`2HV9P0MGEe09jNWP2>SXh0SHf=09jNWP25
QHD0Shn?08b<S02NWYh0Q8B407inOP2=SHd0Ti>C08N7Q`2BTY80Ogmo08f=S@2KVi/0Shn?079bLP2I
VIT0UYJF096AT@1^KVh0Ng]k08n?S`1VIVH0TI6A08N7Q`2<S8`0Ph>306UYJ@28R8P0JVYZ09ZJVP1m
OGd0LG5a07IfMP1YJFT0PH61059BDP1RHV80LG5a07alO01WIfL0Kfm_06YZJP0207emO@0R07inOP2<
S8`0OGem08Z:RP1TI6@0K6a/08>3P`2<S8`0NWYj07=cL`1mOGd0GemO08>3P`1cLg<0LG5a08N7Q`21
PH40MWIf08>3P`1_Kfl0NGUi06=SH`1iNGT0MWIf06IVIP1[Jf/0MGEe08^;R`22PX80Bd];08B4Q023
Ph<0HF5Q05iNGP80JFUY02D0I6AT06EUI@25QHD0HF5Q05ADE01WIfL0G5aL07=cL`1RHV80N7Qh06i^
KP1ZJVX0FEUI061PH01RHV80DE5A07EeM@1PH600IfMW07=cL`22PX80Ogmo05QHF01YJFT0DU9B07Ee
M@25QHD0IVIV07IfMP1TI6@0Cdm?05mOG`1HF5P0FEUI055AD@1FEUH0oooo00H0fMWI0@0000010=WI
f@005P3IfMT00`000000fMWI0=WIf@030=WIf@1Q0?ooo`1dM7@0O7al06=SH`1aLG40O7al06e]K@22
PX80NGUi05iNGP1[Jf/0Ogmo096AT@1ZJVX0Lg=c0820P01/K6`0R8R807alO01fMWH0OGem09FEU@1i
NGT0TY:B09NGU`1fMWH0KVi^09FEU@22PX80QXJ607YjNP2HV9P0S8b<09JFUP2:RXX0X:2P09jNWP2<
S8`0Ti>C09jNWP2CTi<0NWYj07MgM`1`L700LW9b09JFUP2>SXh0NWYj06a/K024Q8@0Kfm_06][J`2>
SXh0VIVI096AT@22PX80S8b<08B4Q02@T900RHV907alO029RHT0[:b/09FEU@2HV9P0/K6a0;Zj^P2T
Y:@0RHV909:BTP2HV9P0UIFE09BDU02f][H0UYJF0:NWY`2ZZZX0VYZJ0:NWY`2RXZ80U9BD0:2PX02<
S8`0WinO0:BTY025QHD0X:2P06QXJ01nOWh0VIVI0:2PX01mOGd0L71`07AdM01:BTX0=cLg01TI6@02
0000000601/K6`0Y:BT0:b/[03Ph>00[:b/092@T1P000000Z0092@T0@D5106e]K@2DU9@0SHf=092@
T01`L700IfMW06m_K`20P800Jf][06m_K`2@T900Jf][079bLP1/K6`0HV9R06QXJ01gMgL0Q8B409^K
V`24Q8@0Ti>C0:FUY@1jNWX0JVYZ09:BTP2QXJ40WIfM09jNWP2;Rh/0ZZZZ0:BTY02KVi/0XZ:R09:B
TP27QhL0X:2P092@T02d];@0MGEe09bLW02NWYh0RHV909jNWP2=SHd0Vi^K0:FUY@2DU9@0XZ:R09JF
UP2CTi<0ZZZZ09^KV`2FUYH0JFUY09fMW@23Ph<0ZJVY08b<S02KVi/0T92@0::RXP2EUID0Rh^;08V9
R@2IVIT0XJ6Q08J6QP2CTi<0Lg=c09jNWP2LW9`0S8b<09ZJVP1fMWH0Xj>S08>3P`2EUID0S8b<09fM
W@2FUYH0Zj^[0:BTY01aLG40V9RH07MgM`2=SHd0UiNG09:BTP2IVIT0Shn?09>CT`1kNg/0SXj>07If
MP1nOWh0OGem079bLP1mOGd0RXZ:0820P028R8P0PH6107QhN021PH40NWYj08n?S`21PH40S8b<08N7
Q`22PX80MWIf08f=S@21PH40RXZ:0820P01FEUH0N7Qh06ATI01hN7P0P820092@T023Ph<0QXJ607If
MP24Q8@0Ti>C05ADE022PX80GemO05UIF@2;Rh/0RXZ:07alO01UIFD0HF5Q075aL@20P800RHV906m_
K`1lO7`0NGUi07YjNP23Ph<0Jf][065QH@21PH40Kfm_08J6QP22PX80IFEU08>3P`1UIFD0Lg=c07Ad
M01/K6`0LG5a05EEE@1[Jf/0J6QX06MWI`1XJ6P0Hf=S06ATI01bLW80N7Qh06UYJ@80M7Ad0240Cdm?
07QhN01kNg/0O7al05IFEP1[Jf/0H61P06IVIP1FEUH0Kfm_059BDP1PH600Ng]k06IVIP18B4P0IFEU
06ATI01UIFD0Jf][05ADE01ZJVX0KVi^08B4Q01FEUH0N7Qh05eMG@19BDT0CDe=06UYJ@1PH600Cdm?
071`L03oool01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI03P0oooo08R8
R01VIVH0LW9b07IfMP1JFUX0SXj>08B4Q01UIFD0Rh^;06e]K@1_Kfl0Jf][07]kN`1TI6@0Hf=S07Yj
NP29RHT0H61P06ATI020P800IfMW07EeM@1_Kfl0QHF508B4Q01cLg<0O7al08Z:RP1mOGd0R8R808j>
SP22PX80Ogmo0:6QX@27QhL0SHf=09VIV@2VYZH0WIfM0:2PX02IVIT0RXZ:07YjNP2FUYH0W9bL09^K
V`23Ph<0QhN708V9R@1fMWH0GUiN07inOP1oOgl0QHF508^;R`80TI6A02l0QXJ606a/K01dM7@0Lg=c
06UYJ@2UYJD0Ng]k09ZJVP2LW9`0][Jf09FEU@2:RXX0VYZJ09jNWP2UYJD0U9BD08F5Q@2VYZH0[Jf]
0:2PX02XZ:P0VIVI0;Rh^02[Zj/0YjNW0:f][@2MWId0SXj>09fMW@2<S8`0K6a/0820P02?Shl0RHV9
08b<S028R8P0B4Q802<S8`0@4100820P01HF5P0G5aL0;bl_00@4100N7Qh0000000<30`070000000a
03`l?02<S8`0PX:20::RXP1YJFT0OGem06a/K01_Kfl0HF5Q06EUI@1GEeL0I6AT06][J`1TI6@0MgMg
04Q8B01cLg<0MGEe0820P01`L700ZZZZ08b<S02KVi/0RHV909ZJVP2IVIT0ZJVY09bLW02PX:00V9RH
07]kN`1nOWh0WIfM0:^[Z`2IVIT0UIFE0:>SX`2][Jd0RHV908N7Q`2c/k<0Xj>S0:2PX02OWil0LW9b
07YjNP1gMgL0WIfM09jNWP020820P00D09JFUP26QXH0TY:B09jNWP2ZZZX0]KFe08>3P`28R8P0XZ:R
08N7Q`2BTY80Ti>C08V9R@2IVIT0/;2`07alO01eMGD0Q8B409bLW02:RXX209:BTP0D08n?S`2OWil0
UYJF08Z:RP2>SXh0X:2P092@T02BTY80SXj>08V9R@2QXJ40YZJV09BDU02RXZ80SHf=07alO022PX80
Ti>C09FEU@2BTY8208j>SP1[08N7Q`1kNg/0Ng]k07]kN`1nOWh0RHV909:BTP2;Rh/0KFe]0861P@1o
Ogl0VYZJ07emO@1PH600TY:B092@T024Q8@0L71`07QhN01[Jf/0M7Ad06EUI@1bLW80OWin08N7Q`1i
NGT0OGem0861P@2FUYH0TY:B08R8R01bLW80OGem096AT@1gMgL0T92@08>3P`1kNg/0MGEe09JFUP1Q
HF40TY:B08>3P`1oOgl0KVi^07emO@1[Jf/0T92@06ATI01XJ6P0MgMg07EeM@1_Kfl0KFe]04a<C022
PX80JVYZ0861P@1gMgL0H61P05YJFP1[Jf/0MgMg05UIF@1^KVh0L71`07YjNP1kNg/0E5AD06MWI`1Q
HF40KVi^075aL@1ADE40KVi^06YZJP1MGEd0JVYZ079bLP27QhL0Ogmo06][J`1/K6`0G5aL07UiN@1S
Hf<0R8R807IfMP1YJFT0JVYZ051@D01OGel0F5QH06UYJ@17AdL0EEEE05eMG@1cLg<0C4a<06=SH`19
BDT0EUIF079bLP1OGel0G5aL04E5A@3oool01P3IfMT100000040fMWI000F0=WIf@800000103IfMT0
7`3oool0Kfm_06a/K01fMWH0Ng]k08j>SP1hN7P0J6QX06IVIP1IFET0MWIf075aL@1oOgl0Q8B406IV
IP1[Jf/0U9BD08>3P`27QhL0TY:B09^KV`24Q8@0SHf=08B4Q02SXj<0OGem07moO`2@T900UYJF09NG
U`28R8P00P1lO7`08P27QhL0Q8B408R8R020P800Vi^K07MgM`2>SXh0PX:207=cL`26QXH0VYZJ08:2
PP2HV9P0TY:B07emO@1eMGD0De=C05eMG@1mOGd0Ti>C08R8R02?Shl0Ti>C09NGU`24Q8@0U9BD08n?
S`28R8P0SHf=08^;R`2YZJT0VIVI0;6a/@2b/[8209JFUP0K09bLW02BTY80R8R80:JVYP2PX:00UiNG
0::RXP2PX:00P82008Z:RP2a/K40YJFU08F5Q@2DU9@0VYZJ096AT@2[Zj/0Z:RX0:>SX`26QXH0QhN7
07alO01[Jf/0QXJ608>3P`1MGEd0Hf=S00802@T90P0000000`0410@0000000D51@070000000P020P
800X:2P0HF5Q08b<S02;Rh/0U9BD08f=S@1aLG40NWYj06QXJ01UIFD0Bd];05eMG@1/K6`0EeMG05AD
E01XJ6P0KVi^06][J`2ATI40Ogmo09BDU02BTY80S8b<08j>SP2LW9`0UYJF09BDU02i^KT0QXJ60;2`
/02FUYH20:2PX00m09>CT`2FUYH0YZJV0:^[Z`2FUYH0VIVI0:NWY`2KVi/0[Jf]08Z:RP2SXj<0Vi^K
09fMW@2@T900VYZJ08b<S02=SHd0V9RH09BDU02ATI40VIVI08V9R@25QHD0LW9b09^KV`2c/k<0OWin
09:BTP2OWil0P8200:BTY02OWil0WYjN08:2PP20P800R8R809^KV`2PX:00PH6109NGU`1nOWh0O7al
07inOP1kNg/0YjNW08V9R@2;Rh/0R8R809^KV`2>SXh0RHV908R8R02QXJ40NGUi09ZJVP2=SHd0WinO
09RHV02GUiL0Ph>308^;R`0208Z:RP1J06MWI`28R8P0KVi^09ZJVP22PX80QHF508f=S@2?Shl0XJ6Q
08f=S@24Q8@0Kfm_06YZJP24Q8@0QhN708Z:RP1cLg<0PX:207inOP1mOGd0LW9b06QXJ027QhL0NGUi
0861P@2>SXh0S8b<08R8R01cLg<0Ph>308F5Q@1oOgl0MWIf069RHP1mOGd0KVi^07inOP1ZJVX0TI6A
07YjNP1fMWH0WIfM08F5Q@1WIfL0Ph>307YjNP1nOWh0Rh^;08N7Q`21PH40Ti>C07MgM`1KFe/0EEEE
05MGE`1fMWH0I6AT07MgM`1]KFd0JFUY05YJFP1`L700Lg=c07alO01aLG40G5aL075aL@1LG5`0Lg=c
07AdM01`L700H61P07emO@1XJ6P0Lg=c08b<S01`L700Shn?061PH01oOgl0Jf][075aL@1jNWX0LG5a
07EeM@1OGel0Ph>305ADE01QHF40QhN70P1JFUX03`1ZJVX0Hf=S06EUI@1BDU80H61P069RHP1KFe/0
FEUI061PH01JFUX0Fe]K03Lg=`1MGEd0G5aL0?ooo`050=WIf@8000000@3IfMT001H0fMWI00<00000
0=WIf@3IfMT00`3IfMT0H`3oool0HV9R06m_K`1dM7@0K6a/06YZJP1aLG40JVYZ06a/K028R8P0Lg=c
07AdM024Q8@0RXZ:07moO`25QHD0Ng]k07moO`1eMGD0FUYJ06a/K01[Jf/0MgMg07EeM@1`L700O7al
09^KV`2DU9@0PX:20:2PX02BTY80U9BD0820P02>SXh0EEEE06YZJP1jNWX0RXZ:09BDU02`/;00WinO
07]kN`2FUYH0SHf=092@T02;Rh/0RHV90861P@1dM7@0GUiN069RHP1HF5P0KVi^08F5Q@2EUID0/[:b
06i^KP2:RXX0V9RH08j>SP2DU9@0Ph>309BDU02JVYX0V9RH09:BTP2GUiL0/K6a0::RXP2=SHd0^k^k
09nOW`2b/[80[Jf]0;2`/02_[jl0QHF509jNWP2a/K40VIVI09ZJVP2VYZH0Z:RX09fMW@2XZ:P0[:b/
09bLW02IVIT0/;2`0:>SX`2IVIT0SHf=08j>SP2EUID0EEEE04i>CP0U9BD04a<C00820P0:0000000:
00T92@19BDT0BTY:07IfMP2BTY80RXZ:08R8R01mOGd0RXZ:06ATI080Jf][00D0I6AT04U9B@1:BTX0
C4a<04e=C@0205=CD`1Z055AD@1mOGd0WIfM0:>SX`2YZJT0S8b<09:BTP2<S8`0Vi^K0:2PX025QHD0
XJ6Q0;6a/@2PX:00V9RH08^;R`1^KVh0QhN70:JVYP1eMGD0YjNW0:f][@2ATI40V9RH08Z:RP2i^KT0
S8b<0:>SX`23Ph<0UiNG07moO`2`/;00YZJV09ZJVP2_[jl0Zj^[09FEU@22PX80Rh^;0861P@2UYJD0
Xj>S09fMW@2DU9@0TY:B09bLW02HV9P0Ti>C0:2PX02EUID0TY:B07EeM@29RHT0TY:B08J6QP28R8P0
QHF507UiN@1lO7`0RXZ:06ATI02JVYX0R8R80::RXP2JVYX0Shn?0;Fe]@2?Shl0Vi^K07QhN02:RXX0
SXj>0861P@22PX80RXZ:0820P01nOWh0PX:208^;R`26QXH0Rh^;09JFUP2HV9P0RHV907UiN@1oOgl0
UiNG07emO@2>SXh0Ph>308n?S`1_Kfl0Lg=c07MgM`1`L700Ogmo07EeM@1UIFD0Lg=c08F5Q@1aLG40
MgMg092@T02ATI40NGUi08:2PP80Ph>302<0QhN709bLW020P800QHF508b<S024Q8@0Hf=S08f=S@1j
NWX0Kfm_05mOG`1RHV80Ph>308N7Q`1fMWH0XJ6Q08F5Q@1cLg<0NGUi06][J`1aLG40H61P07=cL`1_
Kfl0Lg=c06EUI@1jNWX0JVYZ05ADE01TI6@0IfMW02@T901ZJVX0IFEU07alO00207IfMP0U05eMG@1i
NGT0Lg=c06YZJP21PH40Cdm?06e]K@25QHD0IVIV06e]K@1[Jf/0J6QX08J6QP1WIfL0M7Ad06][J`1b
LW80R8R8079bLP1TI6@0IfMW07QhN01^KVh0E5AD06=SH`1KFe/0JFUY08>3P`1QHF40OWin06YZJP0n
?Sh0HF5Q079bLP1EEED0C4a<04Y:BP0203`l?003065QH@3oool0fMWI00D0fMWI0@0000010=WIf@00
5P3IfMT00`000000fMWI0=WIf@030=WIf@1S0?ooo`1eMGD0OGem07emO@23Ph<0K6a/05aLG01_Kfl0
J6QX079bLP1]KFd0K6a/08:2PP1_Kfl0N7Qh09:BTP1gMgL0UYJF07alO023Ph<0OWin07]kN`1YJFT0
QXJ607emO@1bLW80WYjN08j>SP29RHT0PH6108:2PP2;Rh/0RHV907UiN@28R8P0V9RH0::RXP2@T900
QHF509fMW@2TY:@0VIVI09BDU02<S8`0KFe]07AdM01iNGT0R8R807]kN`1ZJVX0KFe]08:2PP1cLg<0
UiNG0:BTY02^[Zh0U9BD07MgM`2ATI40Ogmo08j>SP2?Shl0SXj>09JFUP2IVIT0Rh^;0::RXP2EUID0
U9BD09JFUP2ATI40N7Qh0:b/[02HV9P0Vi^K07inOP2ATI40T92@09VIV@2CTi<0RXZ:08j>SP27QhL0
UIFE0:^[Z`2VYZH0Z:RX09ZJVP2^[Zh0SXj>08B4Q02GUiL0RXZ:09fMW@2:RXX0JVYZ04U9B@0j>SX0
71`L00P0000001d00P8201lO7`13@d<0OGem08B4Q025QHD0Shn?0820P01cLg<0NGUi0820P01kNg/0
K6a/04A4A015ADD0DE5A04E5A@0e=CD0CDe=05YJFP1TI6@0QHF50820P02BTY80`l?309BDU02RXZ80
/[:b09:BTP0209RHV00;09ZJVP2BTY80VYZJ0:RXZ02FUYH0VYZJ09RHV027QhL0YjNW0:FUY@2a/K40
0P2;Rh/01`2<S8`0Z:RX09FEU@2@T900Vi^K09JFUP2MWId00P2@T9001P2VYZH0XJ6Q08f=S@2PX:00
Lg=c09BDU080VIVI00T0UiNG09bLW02PX:00S8b<09bLW02WYjL0WinO08Z:RP2GUiL00P27QhL0K`1[
Jf/0VYZJ0;bl_02UYJD0TY:B08F5Q@2IVIT0W9bL09RHV02FUYH0Ng]k0;2`/02ATI40XJ6Q08n?S`2F
UYH0SHf=0:6QX@2<S8`0Ti>C0:NWY`2>SXh0WIfM0:RXZ023Ph<0O7al09FEU@27QhL0K6a/07EeM@24
Q8@0SXj>07IfMP2<S8`0MgMg08B4Q01lO7`0L71`06=SH`1jNWX0J6QX06YZJP1^KVh0QhN707QhN01m
OGd0Shn?065QH@1hN7P0OWin07YjNP28R8P0QhN707IfMP2IVIT0QhN708>3P`2LW9`0KVi^07alO01`
L700LG5a08>3P`2ATI40Q8B408V9R@1iNGT0P82007moO`23Ph<0N7Qh05UIF@22PX80QXJ607QhN01_
Kfl0MWIf07moO`1hN7P0Q8B408F5Q@2JVYX0U9BD06m_K`1eMGD0KFe]07IfMP1SHf<0Lg=c07moO`1Z
JVX0PX:206a/K01fMWH0Ph>307UiN@1lO7`0Q8B407emO@20P800QHF506QXJ01_Kfl0De=C08J6QP1o
Ogl0KFe]079bLP1SHf<0M7Ad06ATI002051@D00705eMG@21PH40De=C05MGE`1/K6`0GEeM07moO`02
06EUI@0=05eMG@1_Kfl0GUiN03hn?P1SHf<0@d=305MGE`1@D500Bd];079bLP1WIfL0HF5Q0?ooo`06
0=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT03`3oool0Lg=c07YjNP1bLW80
MGEe07moO`1jNWX0GemO07QhN01YJFT0PH6106e]K@1lO7`0KFe]075aL@0207UiN@0606ATI01cLg<0
G5aL08^;R`1dM7@0QXJ60`2=SHd04`1gMgL0WYjN09RHV01TI6@0Rh^;08V9R@25QHD0Shn?07MgM`2F
UYH0TY:B08f=S@28R8P0MGEe09bLW01oOgl0UIFE09NGU`1jNWX00P2@T900501gMgL0MGEe07AdM01/
K6`0MGEe09:BTP2LW9`0XJ6Q08Z:RP2RXZ80UiNG08N7Q`26QXH0Ogmo0:ZZZP2g]kL0[:b/0;6a/@2d
];@0Z:RX0P2KVi/08@2XZ:P0QXJ60:6QX@2PX:00[:b/09BDU01UIFD0MWIf09BDU02PX:00WinO0:>S
X`2KVi/0UIFE0:BTY02RXZ80WinO0:FUY@2<S8`0T92@09:BTP2i^KT0PX:208b<S02m_Kd0SHf=09FE
U@29RHT0EeMG04];B`0M7Ad0410@00h>3P030000001F00/;2`0M7Ad0<S8b05EEE@24Q8@0XZ:R0:RX
Z024Q8@0N7Qh07emO@1iNGT0R8R808>3P`20P800M7Ad06IVIP1`L700E5AD05=CD`1FEUH0IfMW08^;
R`2IVIT0WIfM0861P@2WYjL0[Zj^09fMW@2BTY80Shn?09jNWP2OWil0Xj>S09:BTP2DU9@0[Jf]0;2`
/02^[Zh0S8b<0::RXP2k^k/0UYJF09RHV02>SXh0TY:B0:2PX02TY:@0SHf=09>CT`2TY:@0WIfM0:2P
X021PH40UIFE08f=S@25QHD0Lg=c09bLW01jNWX0Ti>C09jNWP2@T900PH6109jNWP1_Kfl0V9RH08:2
PP2SXj<0VIVI0::RXP2JVYX0TI6A0861P@2HV9P0WinO08>3P`2;Rh/0TI6A0:6QX@2ZZZX0X:2P0:NW
Y`2BTY80U9BD09nOW`2HV9P20:NWY`1808B4Q02WYjL0IVIV096AT@1mOGd0NWYj09VIV@2=SHd0R8R8
09ZJVP2<S8`0Zj^[09JFUP2RXZ80Ph>309^KV`28R8P0];Bd0820P026QXH0G5aL07=cL`1gMgL0Ogmo
096AT@1_Kfl0TI6A09BDU01gMgL0Hf=S08Z:RP1lO7`0NGUi06UYJ@2=SHd0RXZ:06a/K01YJFT0Kfm_
08>3P`1kNg/0IVIV09FEU@21PH40OGem06][J`1mOGd0R8R806m_K`1]KFd0UYJF08B4Q02:RXX0OWin
08b<S023Ph<0NGUi079bLP1^KVh0JVYZ07=cL`1oOgl0JVYZ07=cL`1`L700RXZ:069RHP1/K6`0IFEU
075aL@1_Kfl0JFUY0P1gMgL0;`1UIFD0IVIV07alO01/K6`0T92@08B4Q01VIVH0M7Ad08J6QP1NGUh0
G5aL08V9R@23Ph<0Hf=S06a/K01[Jf/0Q8B406i^KP21PH40MGEe07]kN`1jNWX0I6AT07IfMP20P800
N7Qh07=cL`1XJ6P0Ogmo05iNGP17AdL0GEeM06a/K01KFe/0OWin05iNGP23Ph<0LW9b07EeM@1OGel0
H61P05iNGP1PH600JFUY065QH@1[Jf/0oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI
0=WIf@030=WIf@0>0?ooo`1WIfL0JVYZ06MWI`1cLg<0EEEE06UYJ@1eMGD0NWYj08R8R022PX80Fe]K
06][J`1mOGd205iNGP0C08V9R@1bLW80V9RH08J6QP2>SXh0QhN707EeM@2MWId0SHf=0820P02?Shl0
S8b<09VIV@2LW9`0QHF509RHV02FUYH0VIVI092@T00208N7Q`0Y09bLW020P800UYJF0::RXP2HV9P0
TY:B08j>SP2UYJD0U9BD08N7Q`1jNWX0R8R8075aL@28R8P0Ph>308f=S@2CTi<0WYjN08>3P`22PX80
S8b<08>3P`2TY:@0Ti>C0:NWY`2SXj<0R8R80:>SX`2;Rh/0X:2P0;Bd]02BTY80XZ:R0:BTY02LW9`0
SXj>09VIV@2NWYh0T92@0:VYZ@2^[Zh00P2LW9`00`2YZJT0VIVI0;Fe]@0209nOW`0/09fMW@2LW9`0
WIfM07alO027QhL0];Bd09JFUP2@T900/K6a0<30`02a/K40OGem071`L01IFET0CDe=01TI6@0a<C40
5QHF02@T900M7Ad0Bd];03hn?P1cLg<0Kfm_0;2`/02n_[h0ZZZZ07moO`1ZJVX0N7Qh08b<S02:RXX0
HF5Q07AdM022PX80OWin06i^KP1WIfL0MGEe09JFUP20P800QXJ608^;R`2OWil20:NWY`0A07moO`20
P800[:b/0:f][@2?Shl0VIVI08n?S`2@T900/K6a0;:b/P2/[:`0WinO09fMW@2_[jl0VYZJ092@T02T
Y:@00P2ZZZX0L@2YZJT0Vi^K0:j^[P2TY:@0WIfM09jNWP2HV9P0UiNG08N7Q`2IVIT0WinO09^KV`2U
YJD0[jn_09bLW027QhL0W9bL08J6QP27QhL0WinO0:6QX@2NWYh0UYJF08b<S02][Jd0V9RH09fMW@2B
TY80[Jf]0:6QX@2FUYH0[jn_092@T02JVYX0UIFE09jNWP2BTY80ZJVY09ZJVP2GUiL0X:2P08j>SP28
R8P0XZ:R0:j^[P2EUID0R8R809RHV02XZ:P0SXj>08Z:RP2@T900ZZZZ07MgM`1YJFT0QhN70861P@2?
Shl0P82008V9R@22PX80VIVI092@T01EEED0NWYj07EeM@23Ph<0KVi^08Z:RP2DU9@0R8R806m_K`27
QhL0OGem07inOP26QXH0K6a/07AdM01hN7P0QHF507emO@1nOWh0NWYj08B4Q01mOGd0R8R809:BTP1j
NWX0IVIV075aL@26QXH0Lg=c07IfMP1gMgL0Shn?08V9R@22PX80K6a/07UiN@26QXH0RHV907alO01W
IfL0LW9b075aL@1_Kfl0OWin07emO@1LG5`0QHF507=cL`1eMGD0M7Ad0080EUIF02H0OGem06EUI@1^
KVh0Ph>306IVIP1_Kfl0Ogmo07EeM@1bLW80OWin07emO@1UIFD0KVi^07AdM01UIFD0QHF508B4Q01h
N7P0I6AT07MgM`2?Shl0NWYj05]KF`1nOWh0EEEE069RHP1^KVh0JFUY06e]K@1gMgL0QXJ605iNGP22
PX80MGEe06YZJP1CDe<0LW9b07AdM080F5QH00T0I6AT05mOG`1QHF40JFUY05EEE@1@D500IFEU05IF
EP3oool01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI04P0oooo07MgM`1a
LG40Ng]k06][J`1jNWX0Jf][06UYJ@1[Jf/0O7al09>CT`1kNg/0GUiN05IFEP2=SHd0NGUi09bLW01R
HV80PX:207MgM`1`L700R8R80861P@2>SXh0Q8B409ZJVP2TY:@0QhN708f=S@2;Rh/0T92@08Z:RP29
RHT0ZZZZ0:>SX`1oOgl0UIFE09fMW@2?Shl0Y:BT09fMW@24Q8@0SXj>08b<S02=SHd0Shn?09>CT`2W
YjL0WIfM0:BTY02CTi<0R8R808>3P`2?Shl0RHV90:BTY01eMGD0TI6A08B4Q01`L700X:2P0;Fe]@2U
YJD0WinO08j>SP2:RXX0];Bd0:VYZ@2QXJ40Ti>C09JFUP29RHT2096AT@0A0:>SX`2HV9P0WYjN0;Ng
]`2QXJ40Y:BT0:f][@2RXZ80QhN708f=S@2BTY80Ti>C09^KV`2?Shl0[Zj^0:VYZ@2EUID00P2[Zj/0
;P2IVIT0YJFU0;Ng]`2MWId0V9RH08J6QP1`L700HF5Q08V9R@1OGel0I6AT06QXJ01nOWh0Jf][07Qh
N02XZ:P0][Jf09VIV@2KVi/0Ti>C09BDU01lO7`0TY:B07MgM`1aLG40L71`08>3P`26QXH0W9bL09nO
W`2SXj<0ZZZZ09BDU01oOgl0TI6A0:b/[02FUYH0Zj^[08j>SP22PX80QHF509ZJVP2ZZZX0UYJF0:b/
[02EUID20:RXZ00O0::RXP2/[:`0YJFU0:j^[P2DU9@0TY:B09bLW027QhL0O7al09:BTP2>SXh0S8b<
09jNWP2ZZZX0R8R809fMW@2KVi/0Rh^;09>CT`2BTY80XZ:R08^;R`28R8P0Ph>309bLW02BTY80RXZ:
0;>c/`2^[Zh0UYJF07alO00208b<S00B09nOW`2LW9`0UiNG08N7Q`29RHT0TY:B08b<S02FUYH0UiNG
0:>SX`2VYZH0QXJ607QhN022PX80SHf=09ZJVP2LW9`0Xj>S0P2>SXh0@02;Rh/0VIVI096AT@2<S8`0
UIFE08>3P`2^[Zh0X:2P09VIV@29RHT0W9bL08:2PP2IVIT0Ti>C08R8R01iNGT0MWIf06][J`25QHD0
Ng]k08:2PP1LG5`0S8b<08n?S`1`L700RXZ:00l?3`1PH600NGUi07AdM022PX80JVYZ05UIF@1EEED0
TY:B06a/K01fMWH0L71`07moO`2?Shl0QXJ608>3P`2NWYh0KVi^06MWI`2:RXX0QXJ607EeM@1kNg/0
LW9b06ATI02>SXh0Shn?07=cL`20P800L71`075aL@1JFUX0N7Qh07alO026QXH0MGEe06UYJ@1cLg<2
0861P@0f065QH@1TI6@0I6AT06YZJP1OGel0LW9b07IfMP1SHf<0HF5Q07QhN01MGEd0E5AD07inOP1k
Ng/0Hf=S0861P@1`L700I6AT06UYJ@1[Jf/0IVIV05QHF01nOWh0LW9b06e]K@21PH40FUYJ071`L021
PH40L71`05ADE01OGel0KFe]06m_K`1`L700GEeM079bLP1XJ6P0KVi^06QXJ01TI6@0G5aL05IFEP1T
I6@0KVi^07]kN`1nOWh0C4a<05MGE`10@400B4Q805]KF`1GEeL0oooo1P3IfMT100000040fMWI000F
0=WIf@030000003IfMT0fMWI00<0fMWI03`0oooo07MgM`1bLW80GEeM06EUI@1SHf<0L71`06YZJP1k
Ng/0IVIV08b<S01VIVH0N7Qh07inOP1cLg<0EeMG071`L01_Kfl0Lg=c08>3P`24Q8@0Ph>308V9R@1g
MgL0UiNG096AT@1WIfL0SXj>08J6QP2;Rh/0Ti>C07=cL`2VYZH0UiNG096AT@2TY:@0S8b<09fMW@2C
Ti<0Ph>309RHV02;Rh/0TI6A09bLW02GUiL0UYJF08:2PP26QXH0MgMg096AT@28R8P0T92@0:VYZ@2N
WYh0UiNG07moO`20P800QHF5092@T02NWYh20:>SX`0809nOW`2PX:00V9RH0:ZZZP2NWYh0X:2P09RH
V02ATI4209ZJVP0A0:j^[P2CTi<0ZZZZ07]kN`2UYJD0VIVI09fMW@2CTi<0RXZ:08V9R@2VYZH0W9bL
0;6a/@2GUiL0OGem09>CT`2NWYh00P2@T900N`2][Jd0W9bL092@T02BTY80YJFU0:RXZ02MWId0XJ6Q
07inOP25QHD0Vi^K07]kN`26QXH0TY:B07IfMP2SXj<0Ph>309VIV@27QhL0SHf=0;2`/02IVIT0YjNW
09>CT`2DU9@0Vi^K09VIV@27QhL0Q8B409VIV@2e]KD0WYjN09JFUP2KVi/0XJ6Q09nOW`2NWYh0]KFe
0:6QX@2c/k<0QhN708B4Q02SXj<0VYZJ07UiN@2ZZZX0S8b<09JFUP2LW9`0X:2P08^;R`2DU9@0/K6a
0:6QX@2WYjL0UIFE09:BTP2IVIT0Y:BT08f=S@2NWYh0SHf=08N7Q`2CTi<0SXj>09:BTP2PX:00XZ:R
08n?S`2;Rh/0U9BD09ZJVP2FUYH0R8R807inOP20P800VYZJ08Z:RP2GUiL0WinO08n?S`2:RXX0VYZJ
07IfMP1nOWh0SHf=0:>SX`2KVi/0XJ6Q092@T02MWId0Vi^K08J6QP21PH40ZJVY09:BTP1/K6`0WIfM
0::RXP2DU9@0VYZJ07emO@2OWil0TI6A09>CT`2BTY80QhN709>CT`2KVi/0O7al08n?S`2:RXX0TI6A
09:BTP1JFUX0QXJ607EeM@27QhL0P82007UiN@2FUYH0MGEe08^;R`02079bLP0M08f=S@21PH40Jf][
07EeM@1XJ6P0JVYZ07IfMP1lO7`0Hf=S07moO`1/K6`0JVYZ07emO@20P800NGUi06a/K01ZJVX0IVIV
07inOP1gMgL0SXj>08:2PP2:RXX0QHF508b<S027QhL0S8b<08^;R`1gMgL00P29RHT09@1/K6`0Lg=c
07alO01hN7P0QXJ606QXJ01hN7P0RXZ:06ATI01MGEd0IVIV06a/K01fMWH0JFUY069RHP1NGUh0Lg=c
05MGE`1oOgl0V9RH075aL@1YJFT0J6QX05YJFP1UIFD0Ng]k05aLG01SHf<0Ng]k06EUI@1nOWh0J6QX
07MgM`1GEeL0NWYj06m_K`1eMGD00P1cLg<0701^KVh0G5aL06a/K01RHV80LG5a06ATI01HF5P0JFUY
05UIF@1/K6`0HV9R06][J`1DE5@0KFe]065QH@1]KFd0C4a<06ATI01@D500Kfm_07AdM01LG5`0H61P
06UYJ@1<C4`0GUiN07=cL`3oool60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3I
fMT0?@3oool0M7Ad065QH@1dM7@0I6AT06m_K`1XJ6P0MWIf06i^KP1VIVH0LW9b06i^KP1YJFT0MWIf
07inOP1lO7`0RXZ:06YZJP1kNg/0O7al09:BTP26QXH0Shn?0820P023Ph<0Q8B40820P01hN7P0Kfm_
06e]K@2=SHd0VIVI09:BTP2CTi<0Ph>308R8R02=SHd0TY:B08B4Q02LW9`0TI6A07emO@2RXZ80WinO
08R8R02WYjL0U9BD09FEU@2ATI40PH6109fMW@2YZJT0X:2P09^KV`2@T900VIVI08F5Q@2GUiL0[Zj^
0;Rh^02j^[X00P2HV9P01`2KVi/0SHf=0:RXZ02QXJ40Shn?0:ZZZP2[Zj/00P2VYZH01@2CTi<0XZ:R
08F5Q@1gMgL0WIfM0080XZ:R0200YZJV09NGU`2ATI40X:2P08R8R02BTY80UIFE0:2PX02CTi<0[:b/
08b<S02FUYH0WinO0:BTY02[Zj/0S8b<09BDU02FUYH0VIVI0;Ng]`31`L40WIfM096AT@2KVi/0XZ:R
09VIV@2SXj<0TI6A09RHV02XZ:P0ZZZZ09BDU080SXj>00`0];Bd0:ZZZP2XZ:P0RXZ:0:^[Z`2IVIT0
SHf=09bLW02QXJ40Xj>S0861P@2OWil20:2PX00F08n?S`2SXj<0ZZZZ0:f][@2PX:00Rh^;08>3P`2P
X:00YJFU0:NWY`2c/k<0UIFE09jNWP2UYJD0/[:b09RHV02[Zj/0XZ:R0:VYZ@2PX:00Xj>S09NGU`80
Vi^K03L0VYZJ09nOW`2][Jd0X:2P0:ZZZP2IVIT0TY:B09^KV`2>SXh0XJ6Q06m_K`2JVYX0X:2P08B4
Q01aLG40]kNg08B4Q02HV9P0S8b<09JFUP2LW9`0R8R80:FUY@2>SXh0QhN708F5Q@2;Rh/0QhN709jN
WP23Ph<0SXj>0:VYZ@2<S8`0UYJF0:j^[P2/[:`0Vi^K07moO`28R8P0YJFU092@T02?Shl0TI6A0::R
XP2MWId0YZJV08Z:RP2@T900[jn_0:NWY`2/[:`0VYZJ07moO`23Ph<0VIVI0080QhN700@0PH6108f=
S@2>SXh0N7Qh0P1lO7`20861P@1R08F5Q@2CTi<0Q8B406QXJ01WIfL0MGEe06QXJ01WIfL0MgMg06YZ
JP1bLW80MGEe06=SH`1eMGD0O7al08b<S01HF5P0NWYj07inOP26QXH0OWin07EeM@28R8P0EEEE07Qh
N021PH40O7al08^;R`2JVYX0NGUi07QhN01kNg/0O7al06i^KP23Ph<0P82007UiN@1gMgL0KFe]07]k
N`15ADD0KVi^06=SH`1^KVh0EEEE07]kN`1DE5@0P82006ATI013@d<0Ogmo0:2PX01@D500Ng]k07em
O@1DE5@0Fe]K05eMG@22PX80Lg=c05mOG`1JFUX0HF5Q07=cL`1KFe/0R8R807UiN@1WIfL0MgMg07Yj
NP23Ph<0LW9b05YJFP1/K6`0LW9b06i^KP26QXH0N7Qh07YjNP1cLg<0FUYJ059BDP1VIVH0?clo06EU
I@1dM7@0EUIF0451@@1LG5`0IVIV061PH01GEeL0EUIF05iNGP1UIFD0De=C04i>CP3oool60=WIf@40
00000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT05`3oool0Hf=S07EeM@24Q8@0NGUi08F5
Q@2=SHd0Rh^;0820P02EUID0LG5a079bLP1[Jf/0Shn?06a/K01nOWh0NGUi08V9R@1kNg/0SXj>08^;
R`21PH40P8200080TY:B0;P0Ogmo08b<S028R8P0NGUi08:2PP20P800QhN707inOP2IVIT0TY:B0:VY
Z@2=SHd0Vi^K07QhN02KVi/0Z:RX06i^KP1mOGd0J6QX08B4Q02=SHd0RHV909fMW@2:RXX0S8b<0:RX
Z02BTY80Z:RX0;:b/P2PX:00/k>c09nOW`2UYJD0Xj>S0:VYZ@2GUiL0V9RH0:ZZZP2FUYH0/;2`08Z:
RP2h^;P0XZ:R09fMW@2b/[80SXj>09RHV02][Jd0Z:RX09jNWP2b/[80YZJV0;:b/P2RXZ80YJFU09ZJ
VP2SXj<0X:2P0:f][@2KVi/0Z:RX09JFUP2=SHd0ZJVY0:ZZZP36a/H0Xj>S0;Fe]@1lO7`0Vi^K0:FU
Y@2][Jd0Zj^[0:f][@2SXj<0Vi^K0:>SX`2BTY80Zj^[09RHV02j^[X0YZJV0:>SX`2h^;P0YjNW0:6Q
X@2YZJT0/K6a0:f][@2n_[h0_Kfm0:FUY@2MWId0YjNW0:BTY02@T900XJ6Q09bLW02SXj<0^k^k0;Rh
^02GUiL0T92@0::RXP2;Rh/0QXJ60:^[Z`2RXZ80Xj>S08B4Q02DU9@0Vi^K0::RXP2[Zj/0/;2`0:b/
[02d];@0/[:b0:BTY02YZJT0[:b/0:NWY`2QXJ40/K6a0:6QX@2JVYX0[:b/0;fm_@2GUiL0WYjN06UY
J@2NWYh0ZZZZ0:NWY`2FUYH0X:2P09fMW@21PH40Q8B40820P01oOgl0WYjN09RHV02=SHd0RHV908Z:
RP2WYjL0RHV909>CT`28R8P0WinO08F5Q@2ATI40Shn?0:ZZZP2JVYX0[:b/08n?S`2=SHd0WinO09ZJ
VP2^[Zh0TI6A08B4Q02>SXh0TY:B09fMW@2JVYX0SXj>0:>SX`2RXZ80V9RH08V9R@2YZJT0TI6A09RH
V02ZZZX0SHf=07emO@2ATI40OWin09RHV01nOWh0N7Qh0P2HV9P0I`2<S8`0NGUi07YjNP2>SXh0Lg=c
07alO02EUID0Q8B408Z:RP1YJFT0P82007QhN01cLg<0MWIf08Z:RP21PH40IVIV06UYJ@1bLW80I6AT
07EeM@24Q8@0Rh^;06m_K`2HV9P0S8b<07QhN022PX80QHF508R8R026QXH0Ogmo075aL@1dM7@0RXZ:
0861P@2;Rh/0MWIf07emO@1_Kfl0P82008n?S`1kNg/0OGem05iNGP1YJFT0NGUi0820P01MGEd0HF5Q
06MWI`1VIVH0MgMg07emO@1TI6@0IVIV06=SH`1fMWH0MgMg075aL@1_Kfl0LG5a07AdM01EEED0OWin
06YZJP1SHf<0Kfm_07EeM@1jNWX0Bd];07EeM@1WIfL0MWIf08N7Q`1iNGT0I6AT075aL@1YJFT0GEeM
06QXJ01fMWH0IfMW06m_K`1TI6@0MWIf079bLP1WIfL0GEeM05aLG01QHF40EeMG05eMG@1aLG40De=C
05]KF`1IFET0>c/k06IVIP1UIFD0I6AT06][J`3oool01P3IfMT100000040fMWI000F0=WIf@030000
003IfMT0fMWI00<0fMWI04`0oooo075aL@1aLG40PX:2071`L01gMgL0O7al07MgM`1cLg<0MgMg07al
O01dM7@0O7al07MgM`1cLg<0PX:208V9R@1WIfL0PX:206MWI`1lO7`0UiNG07moO`22PX80LW9b08Z:
RP2TY:@0P82008b<S01kNg/0RHV908B4Q01nOWh0QXJ60;2`/02:RXX0K6a/09JFUP1oOgl0RXZ:07Qh
N02@T900SHf=09bLW02NWYh0SXj>0:JVYP2HV9P0UYJF0:RXZ02SXj<0/[:b0;Jf]P2YZJT0XJ6Q0:BT
Y02XZ:P0XZ:R09jNWP2SXj<0XZ:R0<?3``2h^;P0XJ6Q09VIV@2a/K40ZZZZ08b<S02k^k/0WIfM0:b/
[02MWId0/;2`0:6QX@2TY:@0X:2P0P2LW9`01@2i^KT0W9bL09jNWP2UYJD0UiNG0080[Jf]01D0V9RH
0:2PX02b/[80WIfM0;:b/P2/[:`0ZJVY096AT@2:RXX0Xj>S09jNWP2ATI40S8b<0:VYZ@2KVi/0[Zj^
08F5Q@2VYZH0Vi^K09nOW`2`/;000P2CTi<04`2KVi/0M7Ad08Z:RP2][Jd0WIfM09nOW`2EUID0[:b/
09ZJVP2f][H0YZJV08^;R`2XZ:P0XJ6Q0:n_[`2RXZ80WIfM0;Rh^02[Zj/00P2JVYX03@2RXZ80WYjN
09nOW`2g]kL0^KVi0:RXZ02e]KD0V9RH09VIV@2NWYh0ZZZZ0;>c/`2^[Zh00P2[Zj/0=@2BTY80XZ:R
0:^[Z`2b/[80X:2P08V9R@2RXZ80WIfM0:j^[P2>SXh0Y:BT09:BTP2EUID0XZ:R0<71`@2UYJD0TY:B
08^;R`2CTi<0QhN708^;R`2CTi<0Y:BT08Z:RP2ZZZX0WIfM096AT@2WYjL0ZJVY08j>SP2CTi<0WinO
08V9R@2FUYH0/k>c09:BTP2>SXh0TY:B0::RXP2?Shl0WIfM09JFUP2c/k<0QXJ608b<S02JVYX0RXZ:
08f=S@2YZJT0Ph>309ZJVP2BTY80Ti>C0080R8R800/0VYZJ08Z:RP1`L700UIFE09RHV02<S8`0QXJ6
0820P02MWId0WinO08F5Q@0209FEU@0508F5Q@26QXH0PH6109JFUP1]KFd00P1iNGT0F02<S8`0NWYj
08N7Q`1mOGd0MGEe08F5Q@1PH600MgMg07=cL`27QhL0NGUi07AdM01jNWX0SHf=07emO@21PH40U9BD
065QH@1bLW80QXJ608j>SP1fMWH0UIFE07YjNP2BTY80Q8B408:2PP2FUYH0RXZ:08F5Q@1fMWH0L71`
08b<S01eMGD0G5aL06QXJ02<S8`0P82007emO@23Ph<0H61P06i^KP1lO7`0KVi^07alO01IFET0NWYj
07]kN`1BDU80Ng]k07QhN01fMWH0LW9b06MWI`1SHf<0Ng]k08F5Q@23Ph<0LG5a07alO01`L700LW9b
07MgM`1aLG40MWIf07]kN`1iNGT0IFEU06IVIP1QHF40H61P05eMG@1ZJVX0G5aL06=SH`1]KFd0O7al
069RHP1VIVH0I6AT05]KF`1PH600C4a<07=cL`1YJFT0MWIf05IFEP1KFe/204i>CP0504];B`1iNGT0
F5QH06][J`3oool01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0100oooo
07inOP1ZJVX0MgMg06m_K`1`L700Ogmo07QhN01lO7`0RXZ:07inOP1hN7P0MgMg06UYJ@1ZJVX0R8R8
0P22PX80B`1oOgl0Ph>308>3P`29RHT0R8R8096AT@2;Rh/0SXj>08Z:RP2ATI40Q8B408V9R@23Ph<0
N7Qh08J6QP2>SXh0VYZJ07YjNP20P800QhN706MWI`22PX80SHf=06m_K`1nOWh0KFe]07QhN02MWId0
UYJF09VIV@2@T900Zj^[09RHV02l_;`0b<S808N7Q`2CTi<0[:b/0<G5a@30`<00VYZJ09VIV@2QXJ40
/[:b0;Fe]@29RHT0WIfM0:n_[`2f][H0UiNG0;:b/P2][Jd0XJ6Q09VIV@2FUYH0WinO0:JVYP2h^;P0
[Jf]0;Jf]P2FUYH0/k>c0::RXP26QXH0SHf=08J6QP2b/[80XJ6Q0:>SX`2[Zj/0[Jf]0;Rh^02FUYH0
YjNW0<30`00209bLW0030:>SX`2_[jl0Zj^[0080Vi^K04@0Ph>309jNWP2JVYX0Shn?0:VYZ@2[Zj/0
_Kfm09nOW`2f][H0Vi^K08B4Q02LW9`0Xj>S09fMW@2g]kL0VIVI09fMW@2?Shl0XZ:R09fMW@2ZZZX0
UIFE07MgM`2IVIT0Zj^[0;6a/@2?Shl0Vi^K0:ZZZP2/[:`0WIfM0:VYZ@2PX:00ZJVY09nOW`2YZJT0
VIVI09nOW`2PX:00XZ:R0;:b/P2@T900ZJVY0;>c/`2QXJ40Y:BT0:NWY`2>SXh0/[:b09ZJVP2KVi/0
Xj>S0:RXZ02;Rh/0U9BD0:BTY02:RXX0UiNG08b<S02b/[80TI6A05eMG@1fMWH0SXj>09VIV@2TY:@0
UiNG0;:b/P80SXj>0500Ti>C09ZJVP2QXJ40Q8B408f=S@21PH40Shn?0:FUY@1fMWH0YZJV096AT@1i
NGT0WIfM09nOW`2EUID0UiNG09jNWP2EUID0Ph>308^;R`26QXH0T92@09JFUP2`/;00TY:B092@T01n
OWh0TY:B09nOW`2HV9P0Vi^K0::RXP2<S8`0XZ:R08J6QP2FUYH0Ti>C08j>SP21PH40Q8B407moO`1h
N7P0OWin08>3P`1iNGT0LG5a07moO`1gMgL0Lg=c092@T02ATI40Kfm_06a/K023Ph<0MgMg07alO01j
NWX0I6AT07AdM01bLW80JFUY07=cL`2<S8`0Lg=c09VIV@1dM7@0JFUY0861P@1^KVh0Ng]k08F5Q@2<
S8`0QHF508R8R01dM7@0RHV907=cL`1ZJVX0LW9b08^;R`80R8R801l0L71`07QhN01gMgL0JFUY07al
O01cLg<0KFe]08b<S01`L700E5AD079bLP1eMGD0LW9b0861P@27QhL0JVYZ07inOP1RHV80NGUi06][
J`1KFe/0GemO08V9R@1jNWX0KVi^051@D01`L700LG5a06m_K`1SHf<0JFUY0080K6a/01d0Ng]k069R
HP1oOgl0FEUI08Z:RP1SHf<0Kfm_08:2PP1[Jf/0Kfm_05EEE@1iNGT0FEUI06MWI`1PH600Fe]K06AT
I01cLg<0CTi>069RHP16ATH0FUYJ06e]K@1ZJVX0HV9R06QXJ01SHf<0Kfm_0?ooo`060=WIf@400000
0@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0<P3oool0L71`08>3P`1bLW80HF5Q06YZJP1m
OGd0MgMg07IfMP26QXH0NGUi06IVIP2?Shl0NGUi08F5Q@28R8P0F5QH09:BTP2LW9`0MgMg08n?S`1l
O7`0OWin09NGU`1hN7P0WYjN08j>SP2LW9`0S8b<07YjNP1hN7P0OGem07inOP1cLg<0I6AT08V9R@28
R8P0Lg=c075aL@1/K6`0EeMG03/k>`1nOWh0H61P06IVIP1]KFd0M7Ad07inOP2PX:00UYJF0P2@T900
>P2o_kl0VYZJ09>CT`2MWId0YZJV0:RXZ02GUiL0/;2`0:ZZZP2>SXh0ZJVY0:b/[02][Jd0Xj>S0<71
`@2c/k<0/;2`0:f][@31`L40][Jf0:^[Z`2b/[80T92@0:b/[02OWil0YZJV0;>c/`2NWYh0E5AD09jN
WP2HV9P0ZZZZ09RHV02GUiL0/K6a096AT@2UYJD0UYJF09^KV`2BTY80Y:BT08Z:RP2CTi<0VYZJ0:BT
Y02JVYX0V9RH09FEU@27QhL0YJFU09BDU02[Zj/0[:b/09BDU029RHT0Y:BT09ZJVP2PX:020:6QX@0j
09bLW02GUiL0UiNG0:JVYP2][Jd0/;2`0:ZZZP2j^[X0VIVI0;Fe]@2_[jl0W9bL09NGU`2CTi<0XZ:R
0:2PX02BTY80Vi^K09fMW@2EUID0TY:B08J6QP2VYZH0[Jf]08b<S02DU9@0QXJ60:2PX02_[jl0U9BD
0::RXP2i^KT0Ti>C09JFUP2ATI40WYjN09bLW02:RXX0W9bL08>3P`1dM7@0QHF509ZJVP2FUYH0SXj>
09VIV@2VYZH0UIFE09JFUP26QXH0[:b/09BDU022PX80Shn?09BDU01mOGd0Vi^K09RHV080UiNG02<0
VIVI08^;R`2LW9`0XZ:R09JFUP2IVIT0Xj>S0;6a/@2PX:00[Zj^09bLW02RXZ80TY:B08n?S`2:RXX0
WYjN0;:b/P2HV9P0R8R809>CT`2<S8`0RXZ:08b<S02NWYh0T92@0:BTY02DU9@0SHf=09NGU`2WYjL0
VIVI08Z:RP29RHT0PX:209FEU@0208J6QP0F06=SH`1gMgL0Kfm_08Z:RP1[Jf/0UIFE07inOP2;Rh/0
N7Qh096AT@2:RXX0MGEe06YZJP2;Rh/0Shn?04E5A@1QHF40Ph>3075aL@21PH40Ng]k0861P@80MWIf
00/0Ogmo096AT@1cLg<0P82009JFUP23Ph<0Ng]k092@T01iNGT0PH6108n?S`0208:2PP0o07emO@1j
NWX0Ng]k08F5Q@2;Rh/0IFEU06m_K`1fMWH0FEUI06e]K@2=SHd0MgMg05YJFP1jNWX0L71`07=cL`23
Ph<0Ng]k06IVIP1eMGD0HV9R06MWI`1_Kfl0H61P05mOG`1bLW80PH61075aL@1eMGD0PH6106YZJP1H
F5P0RXZ:0861P@1hN7P0KFe]08J6QP1mOGd0G5aL04];B`20P800L71`07]kN`1VIVH0H61P0820P01h
N7P0HV9R07AdM01XJ6P0KFe]06YZJP1kNg/0Q8B405EEE@1/K6`0IVIV075aL@1EEED0ADE504Y:BP1V
IVH0GemO0080IfMW00<0H61P04M7A`3oool01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0
fMWI00<0fMWI03H0oooo07moO`1aLG40QHF506QXJ02@T900KFe]06i^KP1`L700Ti>C07inOP1WIfL0
L71`075aL@2:RXX0TI6A07UiN@25QHD0Shn?09>CT`2BTY80V9RH09VIV@1`L700QHF507AdM02:RXX0
Ti>C07]kN`2IVIT0S8b<06ATI01^KVh0OWin07UiN@1cLg<0OWin08>3P`1WIfL0Jf][07AdM01XJ6P0
PH6106MWI`1iNGT0DU9B08F5Q@27QhL0Ph>307YjNP2PX:00Y:BT0:b/[02TY:@20;>c/`0<0:2PX02J
VYX0[Zj^0:JVYP2NWYh0Y:BT0:>SX`2j^[X0[jn_0;Zj^P2][Jd0Zj^[0P2WYjL04@2JVYX0V9RH0;Fe
]@2CTi<0][Jf0861P@2e]KD0Vi^K08N7Q`2KVi/0VYZJ09JFUP2_[jl0Shn?0:VYZ@2[Zj/0[Jf]0080
Vi^K01/0X:2P0:>SX`2JVYX0UYJF07alO029RHT0Zj^[0:FUY@2`/;00Y:BT0:NWY`2n_[h0WinO09fM
W@2TY:@0TY:B0:f][@2NWYh0UiNG09^KV`2PX:00TI6A09nOW`2`/;00TI6A0:JVYP2JVYX00P2VYZH0
?P2][Jd0X:2P0:b/[02TY:@0[jn_0;:b/P2CTi<0VYZJ09VIV@2i^KT0][Jf0;2`/02IVIT0_Kfm0;Ng
]`2WYjL0T92@0<30`02i^KT0^[Zj0:j^[P2GUiL0_kno09BDU02PX:00/K6a08B4Q02h^;P0WinO0:b/
[02XZ:P0WYjN0:FUY@2HV9P0VIVI07emO@2PX:00V9RH07moO`2KVi/0Ph>30:FUY@23Ph<0QXJ607al
O027QhL0U9BD0:2PX02BTY80ZZZZ09>CT`1fMWH0Ogmo08R8R02LW9`0Ti>C0:ZZZP23Ph<0SXj>09ZJ
VP2][Jd0VYZJ0P2KVi/09@20P800Ng]k09:BTP2MWId0XJ6Q09RHV028R8P0Shn?0:6QX@29RHT0Vi^K
0:ZZZP2WYjL0Ti>C0::RXP1jNWX0SHf=08>3P`2EUID0WIfM09^KV`2DU9@0XJ6Q08N7Q`2JVYX0PH61
08R8R02:RXX0QhN708J6QP22PX80NWYj07=cL`1]KFd0RHV90:6QX@1mOGd00P2?Shl02`23Ph<0Rh^;
07moO`2@T900TY:B07alO02:RXX0Jf][08:2PP2BTY80TI6A00<0NGUi02`0PX:20820P01_Kfl0Ph>3
06MWI`1/K6`0GEeM07=cL`28R8P0SXj>08F5Q@1_Kfl0OWin08B4Q01bLW80P82008B4Q01lO7`0KFe]
07emO@1lO7`0NGUi07emO@1ADE40O7al07EeM@1OGel0PH6108>3P`27QhL0QXJ607MgM`1eMGD0MWIf
05YJFP1iNGT0H61P04e=C@000000SHf=08F5Q@1fMWH0O7al061PH080LG5a00d0HV9R08:2PP1iNGT0
Shn?06i^KP1OGel0NWYj06=SH`1/K6`0Q8B4079bLP1YJFT0HF5Q0080GEeM0180PX:206i^KP1lO7`0
J6QX06a/K01HF5P0GEeM05mOG`1;Bd/0HF5Q06i^KP1QHF40C4a<05UIF@1EEED0E5AD075aL@3oool6
0=WIf@4000000@3IfMT001H0fMWI0P0000040=WIf@0E0?ooo`1nOWh0N7Qh07inOP1RHV80LW9b09>C
T`1eMGD0Ogmo08Z:RP1gMgL0OGem07QhN01nOWh0Rh^;06MWI`28R8P0W9bL09fMW@2ATI40R8R80080
OGem0?l0MgMg08f=S@20P800LG5a07]kN`2GUiL0VIVI08j>SP1dM7@0Ph>307emO@2DU9@0UIFE06i^
KP1_Kfl0LW9b06UYJ@1/K6`0Fe]K08>3P`22PX80LG5a05=CD`1RHV80KVi^0820P02CTi<0S8b<096A
T@2f][H0/[:b09VIV@2XZ:P0YZJV0:j^[P2k^k/0YZJV0:6QX@2HV9P0XZ:R0;2`/02b/[80/K6a09nO
W`2LW9`0/[:b0:2PX02a/K40[:b/0:6QX@2NWYh0Y:BT0;Fe]@2NWYh0U9BD09nOW`2c/k<0XZ:R09VI
V@2?Shl0ZJVY09BDU02QXJ40^k^k0:JVYP2CTi<0Y:BT08b<S02JVYX0ZJVY09BDU02_[jl0[Jf]0;Jf
]P2WYjL0];Bd0<C4a02UYJD0Y:BT0;Ng]`2UYJD0WinO0:>SX`2>SXh0VYZJ0;jn_P2ZZZX0Y:BT0;^k
^`2c/k<0`/;20:RXZ02:RXX0SHf=0:j^[P2SXj<0ZZZZ0:NWY`39bLT0^;Rh09:BTP2VYZH0]KFe08f=
S@2NWYh0MGEe08^;R`2ATI40^[Zj09jNWP2a/K40T92@0;>c/`2DU9@0XJ6Q0;Rh^02e]KD0]kNg0:^[
Z`2g]kL0XJ6Q0;jn_P2QXJ40/[:b092@T02QXJ40TI6A09ZJVP2?Shl0UiNG08R8R02MWId0UIFE07]k
N`28R8P0WYjN08Z:RP2;Rh/0RHV907YjNP2;Rh/0WYjN0:ZZZP2BTY80Lg=c09ZJVP2OWil0Ng]k07=c
L`1dM7@0SXj>08n?S`2=SHd0U9BD09ZJVP2NWYh0QhN708R8R021PH40YZJV092@T02HV9P0SXj>08R8
R02WYjL0RHV90:6QX@1mOGd0TY:B09ZJVP29RHT0RXZ:0:JVYP2:RXX0VIVI07emO@2QXJ40Q8B40:VY
Z@23Ph<0UIFE08f=S@2BTY80SXj>06ATI02;Rh/0OGem07EeM@1lO7`0UIFE09BDU021PH40GemO08J6
QP20P800PH61079bLP1aLG40T92@07moO`1iNGT0KVi^07QhN02FUYH0QXJ607emO@1eMGD0RHV908b<
S01oOgl0Shn?08F5Q@1mOGd0UIFE06YZJP1[Jf/0OGem07alO01_Kfl0Shn?08F5Q@1`L700N7Qh07in
OP1iNGT0Q8B408n?S`1`L700Q8B408Z:RP1_Kfl0MWIf06YZJP1gMgL0SHf=06MWI`1SHf<0IfMW07Qh
N022PX80OGem079bLP1`L700O7al06UYJ@1gMgL0R8R807]kN`1QHF40N7Qh0::RXP1[Jf/0Hf=S05EE
E@1LG5`002@0N7Qh09>CT`2;Rh/0NGUi07]kN`1fMWH0MGEe06e]K@1mOGd0OWin07alO028R8P0K6a/
07]kN`1lO7`0GEeM06][J`1VIVH0Jf][079bLP1KFe/0I6AT06][J`1RHV80GEeM04U9B@1IFET0EeMG
055AD@1VIVH0HV9R06a/K01DE5@0IfMW04Y:BP3oool50=WIf@8000000@3IfMT001H0fMWI00<00000
0=WIf@3IfMT00`3IfMT0C`3oool0Q8B407moO`20P800UIFE07inOP1mOGd0RXZ:08B4Q01mOGd0Ng]k
06QXJ02;Rh/0Ogmo08:2PP23Ph<0MWIf09FEU@2IVIT0QhN708j>SP2KVi/0OWin07emO@1oOgl0QXJ6
075aL@1fMWH0Ogmo07MgM`1fMWH0U9BD08F5Q@2CTi<0X:2P08V9R@24Q8@0@D5106=SH`1LG5`0B4Q8
05]KF`1iNGT0MGEe08R8R01eMGD0G5aL07IfMP2>SXh0NWYj09NGU`2OWil0[Zj^0;6a/@2TY:@0YZJV
0;Bd]02e]KD0YjNW0;:b/P2l_;`0];Bd0;bl_02WYjL0ZJVY0:2PX02WYjL0[:b/0:j^[P25QHD0[jn_
0:FUY@2b/[80W9bL09nOW`2`/;00ZZZZ0;Zj^P2f][H00P2ZZZX0B02YZJT0W9bL0:b/[02XZ:P0WYjN
0:FUY@2LW9`0XZ:R09JFUP2h^;P0TI6A0:f][@2>SXh0W9bL0:6QX@29RHT0SXj>08R8R02ZZZX0/K6a
08^;R`2ZZZX0YZJV09bLW02YZJT0MGEe0:VYZ@2i^KT0TI6A09jNWP2^[Zh0][Jf09^KV`2o_kl0/[:b
0::RXP2^[Zh0]kNg0;Zj^P2LW9`0Xj>S09ZJVP28R8P0SHf=0:JVYP2FUYH0TY:B0:j^[P2][Jd0/[:b
0:ZZZP2o_kl0WinO0;>c/`2/[:`0];Bd0;bl_02BTY80Vi^K0:n_[`2VYZH0SXj>0;Fe]@2ZZZX0TY:B
0:ZZZP2VYZH0TI6A0:FUY@2NWYh0UIFE09BDU080WYjN06T0W9bL0:RXZ02GUiL0SXj>09^KV`2=SHd0
OGem0861P@24Q8@0UIFE08Z:RP2_[jl0Ph>307UiN@2>SXh0X:2P08>3P`2@T900UIFE08:2PP29RHT0
RXZ:0;Fe]@2ATI40Ti>C09FEU@2GUiL0UIFE09jNWP2LW9`0YZJV08B4Q022PX80PH6104];B`1mOGd0
VIVI08n?S`20P800QXJ607emO@24Q8@0WinO07moO`26QXH0Ng]k09jNWP2LW9`0Q8B40:VYZ@2BTY80
V9RH0:RXZ02?Shl0P8200861P@1lO7`0Jf][08R8R01iNGT0M7Ad06YZJP1VIVH0Kfm_07AdM01lO7`0
RXZ:08b<S022PX80QXJ609:BTP2GUiL0RXZ:096AT@23Ph<0TI6A0820P01TI6@0Q8B406a/K01_Kfl0
OGem08B4Q02>SXh0PX:208>3P`2=SHd0QHF508b<S026QXH0Ti>C08f=S@22PX80IfMW075aL@1kNg/0
O7al08R8R01gMgL0NGUi07=cL`1aLG40PX:206a/K01iNGT00P1XJ6P0=01]KFd0MGEe07YjNP1WIfL0
MGEe05MGE`1hN7P0M7Ad079bLP1KFe/0Jf][08f=S@1bLW80M7Ad071`L01]KFd0GUiN065QH@1JFUX0
HV9R06i^KP1hN7P0JFUY06a/K01QHF40Lg=c08>3P`1VIVH0O7al06QXJ01_Kfl0Ng]k06MWI`1TI6@0
C4a<07MgM`1`L700EeMG06a/K00Y:BT0EeMG07IfMP1aLG40Fe]K06=SH`0E5AD0HV9R08>3P`1eMGD0
Bd];04I6AP3oool60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0:`3oool0
Ti>C08j>SP2EUID0VIVI08:2PP2FUYH0JVYZ08B4Q025QHD0RXZ:08V9R@2BTY80MgMg08F5Q@26QXH0
RXZ:0861P@1cLg<0QhN707inOP2@T900PH6108F5Q@2=SHd0PX:208Z:RP29RHT0Ti>C08n?S`1OGel0
NGUi07YjNP2MWId0Rh^;0:>SX`1^KVh09RHV03lo?`1CDe<0IfMW06m_K`1gMgL00P20P800901UIFD0
OWin07UiN@1oOgl0Ph>309JFUP2_[jl0^[Zj0;Ng]`2[Zj/0ZZZZ0<?3``2[Zj/0ZZZZ0:b/[02XZ:P0
RHV90:BTY023Ph<0ZJVY0;bl_02PX:00Y:BT0:FUY@2XZ:P0^[Zj09ZJVP2[Zj/0XZ:R0:VYZ@2h^;P0
ZZZZ0:6QX@2KVi/0X:2P0:f][@80U9BD00L0][Jf08f=S@2/[:`0S8b<0;bl_027QhL0Shn?0080Xj>S
04<0T92@07QhN02YZJT0WIfM08n?S`2XZ:P0Zj^[09^KV`2TY:@0Vi^K09FEU@2d];@0WIfM0;Bd]02g
]kL0ZZZZ08f=S@2e]KD0Ti>C0;bl_02=SHd0YZJV0;6a/@2VYZH0Y:BT0;:b/P2WYjL0X:2P08R8R01k
Ng/0V9RH08n?S`1lO7`0MGEe08N7Q`2IVIT0OGem0;Vi^@2/[:`0_;bl0:f][@2TY:@0SXj>09nOW`2Y
ZJT0X:2P0:VYZ@2SXj<0WIfM09^KV`2YZJT0bl_;0;Jf]P2WYjL0]kNg0:>SX`2h^;P0YjNW09^KV`2Z
ZZX0/;2`09RHV023Ph<0Ti>C08J6QP23Ph<0Xj>S0080RHV90200X:2P08Z:RP2OWil0UYJF08Z:RP2D
U9@0VYZJ09JFUP2[Zj/0NWYj09FEU@1mOGd0RXZ:06QXJ02NWYh0SXj>0:6QX@2d];@0WIfM09BDU02L
W9`0Q8B409JFUP2CTi<0X:2P08j>SP25QHD0S8b<08>3P`2ATI40OWin07alO080U9BD00@0UiNG09VI
V@2CTi<0Z:RX0P25QHD01@2JVYX0SXj>08n?S`2CTi<0VYZJ0080Ogmo00@0Ti>C08n?S`1jNWX0Rh^;
0P24Q8@09P2=SHd0EeMG07emO@1jNWX0R8R807IfMP1nOWh0OGem08N7Q`1jNWX0Ti>C09bLW02;Rh/0
TI6A0861P@1WIfL0QhN707=cL`1lO7`0LG5a09NGU`24Q8@0NGUi0820P01nOWh0Ogmo07emO@21PH40
JVYZ08:2PP23Ph<0OWin07emO@1XJ6P0H61P071`L01/K6`0PH610P28R8P04029RHT0P820071`L01f
MWH0KVi^07QhN01JFUX0IfMW04m?C`1gMgL0L71`06ATI01PH600J6QX069RHP1kNg/206IVIP0Z07Mg
M`1hN7P0I6AT08f=S@2>SXh0Q8B407AdM01mOGd0Kfm_07MgM`2:RXX0MgMg071`L01bLW80IfMW051@
D01lO7`0L71`08F5Q@1aLG40F5QH06YZJP1iNGT0IfMW06=SH`1ADE40JFUY07MgM`1EEED0De=C07Mg
M`1YJFT0K6a/05UIF@1UIFD0De=C04e=C@1<C4`0MgMg05IFEP1VIVH0oooo1P3IfMT100000040fMWI
000F0=WIf@030000003IfMT0fMWI00<0fMWI0240oooo08B4Q01mOGd0Ogmo08:2PP24Q8@0KFe]07Ui
N@1]KFd0Ph>309FEU@1jNWX0O7al08Z:RP21PH40PX:209FEU@2FUYH0Q8B408^;R`2TY:@0Ti>C09bL
W02?Shl0RHV909RHV02:RXX0RHV90861P@26QXH0QhN709FEU@2IVIT00P2BTY801P1_Kfl0Fe]K04];
B`1@D500Fe]K07MgM`80LG5a00/0RHV9096AT@1mOGd0N7Qh06MWI`27QhL0N7Qh0:ZZZP2][Jd0_Kfm
0:BTY0020:NWY`0/0:FUY@2VYZH0];Bd0;Fe]@2LW9`0ZJVY0;Jf]P2YZJT0[:b/0;Bd]02e]KD0[Jf]
0:2PX02YZJT0/[:b0;Fe]@2KVi/0_[jn0:>SX`2e]KD0Rh^;0<71`@2QXJ40][Jf0:^[Z`2XZ:P0/k>c
0:RXZ02VYZH0WinO0;:b/P2MWId0W9bL0:FUY@29RHT0[Jf]08Z:RP2GUiL0ZZZZ0::RXP2QXJ40TY:B
0;Bd]02HV9P209VIV@0F0;Jf]P2FUYH0[Zj^09FEU@2c/k<0/;2`0:VYZ@2TY:@0[:b/09RHV02][Jd0
VYZJ09RHV02OWil0X:2P07inOP2>SXh0Shn?06QXJ023Ph<0PH6109NGU`80Ogmo06l0QhN709NGU`22
PX80U9BD0:FUY@2o_kl0^;Rh09VIV@2JVYX0^k^k08N7Q`2ZZZX0W9bL0;Zj^P2e]KD0VYZJ0;Fe]@2Z
ZZX0WIfM0:f][@2HV9P0WIfM0:VYZ@2_[jl0TY:B0:b/[02ATI40X:2P09fMW@2k^k/0N7Qh07AdM01n
OWh0Ph>308F5Q@2ATI40Z:RX08^;R`25QHD0MGEe09RHV02EUID0VIVI0:JVYP2BTY80Z:RX0:6QX@2I
VIT0YjNW0;6a/@2GUiL0VIVI08j>SP2OWil0XJ6Q096AT@2UYJD0PX:209bLW022PX80QHF508N7Q`1n
OWh0XJ6Q075aL@1fMWH0R8R80:FUY@2DU9@0RHV909nOW`21PH40UYJF09^KV`2WYjL0WinO0:BTY02S
Xj<0YjNW08f=S@2:RXX0NWYj092@T023Ph<0OWin07AdM020P800KVi^06MWI`21PH40Lg=c07YjNP1M
GEd0Ogmo06i^KP2CTi<0H61P08b<S022PX80TI6A09>CT`2JVYX0KFe]09ZJVP28R8P0WIfM08F5Q@2=
SHd0O7al07MgM`2BTY800P1iNGT0>01/K6`0PX:20861P@2JVYX0Ng]k06QXJ01mOGd0PH6108B4Q01[
Jf/0LW9b06EUI@22PX80Q8B408Z:RP1mOGd0Lg=c08^;R`1`L700Jf][07MgM`1XJ6P0O7al07emO@1Q
HF40Fe]K061PH01fMWH0F5QH04U9B@1XJ6P0M7Ad069RHP24Q8@0QhN708:2PP2IVIT0TI6A07MgM`1J
FUX0PH6108J6QP1lO7`0MGEe06UYJ@27QhL0Q8B409:BTP25QHD0K6a/08N7Q`1RHV80MgMg096AT@1c
Lg<0GUiN0P1YJFT04@1MGEd0E5AD05MGE`21PH40@D51071`L01IFET0EEEE06IVIP1MGEd0E5AD07Ad
M01KFe/0I6AT05QHF01TI6@0oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@03
0=WIf@0I0?ooo`1kNg/0Q8B409FEU@26QXH0JFUY06i^KP2GUiL0SHf=08Z:RP1oOgl0PX:208F5Q@2:
RXX0Rh^;08B4Q026QXH0RHV907inOP2ATI40MWIf07YjNP2FUYH0SXj>08b<S002096AT@0708F5Q@24
Q8@0T92@09NGU`2<S8`0RHV907alO002092@T00H06QXJ01=CDd0H61P069RHP1mOGd0RHV909>CT`2P
X:00T92@09JFUP22PX80LW9b06IVIP1XJ6P0Q8B40:6QX@2_[jl0YjNW09nOW`2o_kl0]KFe0;jn_P2f
][H0XZ:R0P2[Zj/09@2ZZZX0[Jf]0:BTY02_[jl0ZJVY09RHV02^[Zh0XZ:R0:6QX@2c/k<0[Zj^0:ZZ
ZP2QXJ40/K6a0:^[Z`2=SHd0/[:b0;Vi^@2c/k<0Z:RX0820P02[Zj/0_;bl09^KV`2`/;00X:2P0;:b
/P2c/k<0WinO09bLW02YZJT0SXj>09NGU`2MWId0[Jf]0:n_[`2[Zj/00P2:RXX07P2VYZH0Vi^K09:B
TP2o_kl0T92@0;Bd]02@T900UYJF0;Fe]@2^[Zh0PX:209:BTP2TY:@0YjNW0;^k^`2NWYh0Shn?05EE
E@23Ph<0JVYZ07emO@1PH600KVi^06UYJ@1`L700Ogmo06][J`1gMgL0YJFU08V9R@80Zj^[00T0ZZZZ
0:f][@2XZ:P0_Kfm0<C4a02][Jd0WYjN08N7Q`2ZZZX00P2_[jl0E@2n_[h0/k>c0:BTY02QXJ40WinO
09RHV02MWId0VIVI08J6QP2OWil0UYJF0:6QX@2TY:@0ZZZZ09BDU02<S8`0PX:207UiN@2YZJT0RHV9
08R8R025QHD0KVi^07UiN@2QXJ40QHF508>3P`2UYJD0WinO08V9R@2=SHd0S8b<09RHV029RHT0VYZJ
09>CT`2FUYH0X:2P08:2PP1cLg<0UiNG07alO02HV9P0TI6A0861P@2<S8`0QHF507MgM`2<S8`0R8R8
0:ZZZP20P800RXZ:0:f][@2ZZZX0UYJF09RHV02QXJ40SHf=0::RXP1gMgL0SHf=08V9R@27QhL0MWIf
08^;R`21PH40QhN708f=S@1hN7P0Kfm_07EeM@1jNWX0GEeM07AdM02;Rh/0SHf=08F5Q@2VYZH0Ogmo
08>3P`26QXH0UIFE09bLW020P8000P1gMgL00`2YZJT0VIVI08B4Q00207UiN@80P82001X0J6QX07al
O02>SXh0NGUi07MgM`1nOWh0SXj>08J6QP2ATI40MgMg07alO01oOgl0OWin07alO01]KFd0IfMW079b
LP1^KVh0SHf=07=cL`1LG5`0OGem071`L01UIFD0L71`05IFEP80HV9R00D0N7Qh06i^KP1jNWX0EUIF
0861P@0206m_K`0Y07alO02?Shl0JFUY092@T01cLg<0KVi^06=SH`1bLW80J6QX07YjNP1YJFT0RXZ:
08R8R01oOgl0R8R806i^KP1XJ6P0NGUi07emO@24Q8@0H61P08Z:RP1]KFd0EUIF04];B`0U9BD0Jf][
05eMG@0m?Cd0NWYj06YZJP1/K6`0EEEE061PH01OGel0J6QX05=CD`1YJFT0J6QX05mOG`3oool01P3I
fMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00X0oooo0;6a/@2MWId0U9BD08N7
Q`1eMGD0Shn?08B4Q02JVYX0T92@0P2CTi<0;01nOWh0RHV907inOP24Q8@0SXj>06UYJ@1fMWH0WIfM
09^KV`2TY:@0SXj>09:BTP2TY:@0TY:B09RHV02>SXh0LW9b09fMW@2PX:00UYJF08J6QP2<S8`0MGEe
079bLP1QHF40B4Q803Ti>@1QHF40UIFE07YjNP2MWId0WinO092@T02<S8`0Ng]k06m_K`1SHf<0LW9b
08N7Q`2/[:`0a/K60:NWY`2QXJ40^k^k0P2MWId09`2WYjL0]KFe0;Jf]P2][Jd0PH610;Ng]`2h^;P0
_kno0:NWY`2d];@0/;2`09>CT`2/[:`0/[:b09^KV`2DU9@0][Jf09bLW02e]KD0SXj>0;>c/`2CTi<0
/[:b0:RXZ02>SXh0WIfM0:>SX`2MWId0/[:b08b<S02ZZZX0TI6A07UiN@2TY:@0T92@08B4Q02SXj<0
WYjN0;2`/0020;:b/P060:^[Z`2VYZH0Ti>C0;2`/02:RXX0ZZZZ0P2b/[807@2][Jd0Xj>S0:VYZ@2H
V9P0P82009VIV@2MWId0Vi^K09FEU@1iNGT0FEUI065QH@1/K6`0Fe]K03`l?01/K6`0T92@0820P02:
RXX0Ph>309BDU01aLG40N7Qh07UiN@2SXj<0]kNg0;Vi^@2UYJD0]KFe0080WYjN0100[Jf]0;jn_P2j
^[X0^;Rh0:VYZ@2SXj<0[Zj^092@T03@d=00UiNG0;:b/P2/[:`0RXZ:0;jn_P2IVIT0YjNW0P2KVi/0
9@2?Shl0R8R809VIV@2YZJT0T92@09VIV@21PH40YZJV07moO`2NWYh0Xj>S09FEU@1hN7P0UiNG09>C
T`1`L700WYjN0:6QX@2SXj<0Rh^;0:>SX`2ATI40Shn?08Z:RP1oOgl0OGem09ZJVP23Ph<0JVYZ08b<
S02IVIT0O7al08V9R@2?Shl0P82008:2PP2EUID00P2:RXX0IP2<S8`0Q8B40;2`/02QXJ40O7al08n?
S`2<S8`0R8R80:>SX`2CTi<0J6QX08R8R01^KVh0SXj>07inOP2JVYX0SXj>08:2PP1eMGD0Q8B407Ui
N@2KVi/0YJFU08V9R@26QXH0N7Qh08f=S@28R8P0L71`09fMW@2GUiL0NWYj09FEU@2ATI40O7al08B4
Q02EUID0Ogmo092@T020P800RXZ:07moO`21PH40QHF507inOP1mOGd0Ogmo08V9R@1nOWh0J6QX07If
MP1mOGd0RHV907AdM01/K6`0R8R80861P@20P800Kfm_071`L01GEeL0MGEe08F5Q@1gMgL0K6a/096A
T@1@D500GEeM06IVIP1/K6`0NGUi06EUI@1`L700R8R808F5Q@1GEeL0K6a/092@T01VIVH0OWin07Yj
NP1RHV80Jf][07YjNP1hN7P0Ng]k075aL@1eMGD0QHF507QhN01oOgl0OGem06UYJ@1SHf<0FEUI06UY
J@1^KVh0LW9b05iNGP21PH40LW9b05YJFP80IVIV00l0GemO05iNGP1^KVh0CDe=05IFEP1_Kfl0L71`
04a<C01OGel0Ng]k07MgM`1DE5@0JFUY04m?C`3oool01P3IfMT100000040fMWI000F0=WIf@030000
003IfMT0fMWI00<0fMWI01d0oooo08j>SP1`L700PH6106UYJ@23Ph<0PX:207moO`29RHT0U9BD08N7
Q`2ATI40UIFE08:2PP1gMgL0LG5a08^;R`20P800QXJ607UiN@2IVIT0TY:B08j>SP1oOgl0QHF509jN
WP1`L700RXZ:09FEU@0208F5Q@1608R8R02RXZ80Lg=c09bLW02IVIT0G5aL04U9B@1QHF40JFUY09^K
V`2JVYX0U9BD09^KV`2PX:00K6a/071`L01NGUh0EUIF06YZJP2BTY80][Jf0;:b/P2`/;00ZZZZ0;Rh
^02JVYX0U9BD09NGU`2NWYh0Z:RX0:FUY@2`/;00ZJVY09JFUP2b/[80X:2P0;bl_02_[jl0Z:RX0;Vi
^@2o_kl0YJFU0::RXP2OWil0VIVI08f=S@2a/K40WYjN0:^[Z`2MWId0X:2P09jNWP2^[Zh0/k>c09^K
V`2XZ:P0W9bL0:RXZ02CTi<0WYjN09JFUP2>SXh0V9RH0:f][@2QXJ40_;bl09ZJVP2HV9P0RXZ:09ZJ
VP80W9bL04h0YZJV0;Fe]@2?Shl0RXZ:09JFUP2JVYX0RXZ:08f=S@2GUiL0VYZJ09bLW029RHT0QXJ6
05]KF`1[Jf/0:b/[02TY:@0n?Sh0MgMg0820P02HV9P0Y:BT09^KV`2BTY80Rh^;08b<S01oOgl0SHf=
079bLP2EUID0a/K60;Fe]@34a<@0/[:b09fMW@2YZJT0YZJV0:2PX02h^;P0Zj^[0:BTY02JVYX0][Jf
0<;2`P2RXZ80XJ6Q09FEU@2XZ:P0WinO09ZJVP2HV9P0Shn?08>3P`2BTY80QHF50:6QX@2GUiL0Xj>S
09^KV`2ATI40YJFU08V9R@2IVIT0Ti>C09VIV@2:RXX0Ti>C09RHV02RXZ80UIFE092@T02GUiL0Vi^K
0:6QX@21PH40P820092@T029RHT207alO010096AT@26QXH0VYZJ08Z:RP2BTY80S8b<08^;R`2JVYX0
Shn?09:BTP2TY:@0MGEe08R8R020P800Ti>C07alO02HV9P0SHf=08Z:RP2DU9@0Ti>C08Z:RP2DU9@0
Ti>C09:BTP2b/[80T92@0::RXP2LW9`0QXJ608f=S@24Q8@0V9RH096AT@2:RXX0S8b<07UiN@1nOWh0
MWIf06m_K`1dM7@0T92@08J6QP2;Rh/0Vi^K08F5Q@1fMWH0SHf=08>3P`2HV9P0WinO08J6QP2;Rh/0
UYJF06ATI01aLG40MWIf079bLP2;Rh/0MgMg071`L01jNWX0K6a/0861P@80KVi^00X0K6a/06YZJP1o
Ogl0SHf=07emO@1MGEd0PX:206EUI@20P800Jf][0P1WIfL0=@1cLg<0I6AT075aL@21PH40GEeM05iN
GP1_Kfl0GemO0820P01eMGD0LG5a0820P01bLW80LG5a09>CT`1bLW80NGUi07moO`2>SXh0OWin059B
DP28R8P0L71`07QhN01dM7@0L71`07YjNP26QXH0DU9B07alO01nOWh0J6QX06YZJP1_Kfl0MWIf06MW
I`1PH600Hf=S061PH01EEED0I6AT01dM7@0Q8B40De=C05mOG`1ZJVX0K6a/04E5A@1ADE40QHF5065Q
H@1eMGD0oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@1c0?ooo`1c
Lg<0EeMG06ATI021PH40HV9R08b<S02SXj<0SHf=07QhN02WYjL0V9RH07AdM01lO7`0QHF508n?S`27
QhL0T92@09:BTP2<S8`0R8R807UiN@1lO7`0UYJF092@T02KVi/0YjNW07]kN`1gMgL0P82009nOW`2@
T900QXJ609>CT`1fMWH0PX:206UYJ@17AdL0@410071`L01dM7@0TY:B0861P@2ATI40NWYj08V9R@1e
MGD0G5aL06i^KP1HF5P0TY:B09jNWP2e]KD0Xj>S0;Rh^02XZ:P0S8b<0:JVYP2l_;`0/k>c0:>SX`2X
Z:P0YJFU0:j^[P2ATI40RHV90;2`/02XZ:P0Zj^[0:n_[`2XZ:P0XJ6Q0;Bd]02VYZH0X:2P0;Zj^P2a
/K40_;bl09>CT`2PX:00^;Rh09:BTP2RXZ80UIFE0:>SX`2DU9@0Rh^;08J6QP2NWYh0Vi^K09jNWP2K
Vi/0XJ6Q09RHV02YZJT0RXZ:08n?S`2MWId0XJ6Q0:j^[P2QXJ40_Kfm09^KV`26QXH0WIfM0:JVYP2M
WId0/K6a0;Fe]@2CTi<0Xj>S09:BTP2DU9@0Shn?079bLP0207moO`1f04];B`0j>SX0C4a<04i>CP1[
Jf/0M7Ad09NGU`2NWYh0UIFE07alO02FUYH0Rh^;0:6QX@2BTY80TI6A0:JVYP2b/[80Zj^[0;Ng]`2d
];@0_Kfm09jNWP2RXZ80QXJ60;Vi^@2RXZ80Z:RX0:FUY@2o_kl0[Jf]0:2PX026QXH0WinO09RHV02X
Z:P0T92@09JFUP2TY:@0S8b<09NGU`2ATI40Ti>C09:BTP20P800YZJV07inOP2CTi<0SHf=0:>SX`2L
W9`0V9RH09VIV@2ATI40T92@09NGU`24Q8@0KVi^08R8R02:RXX0YZJV09VIV@27QhL0OWin08J6QP2;
Rh/0UIFE08R8R02=SHd0XJ6Q07YjNP2HV9P0Ng]k07moO`25QHD0RXZ:09>CT`2KVi/0WIfM08>3P`1l
O7`0RXZ:08V9R@25QHD0R8R8096AT@2IVIT0WIfM06m_K`1iNGT0PH6108b<S029RHT0O7al096AT@2:
RXX0T92@09jNWP2ATI40UYJF09nOW`29RHT0Shn?09:BTP2NWYh0UiNG07UiN@1cLg<0QhN70820P02D
U9@0LW9b07YjNP20P800UYJF08^;R`2XZ:P0T92@09JFUP80Ogmo03D0Ph>307alO01iNGT0MWIf07al
O01bLW80TY:B07YjNP1kNg/0LW9b07IfMP1XJ6P0M7Ad06m_K`1`L700Lg=c05UIF@1cLg<0MGEe08F5
Q@1nOWh0P82006YZJP1eMGD0KVi^07moO`1VIVH0F5QH06][J`1ZJVX0PH6107YjNP1`L700PX:2061P
H01jNWX0PH6107AdM027QhL0L71`06=SH`25QHD0OWin06IVIP1fMWH0IfMW06a/K01SHf<0LG5a0820
P01KFe/0OWin0820P00208B4Q00?07EeM@1OGel0JVYZ079bLP1[Jf/0Fe]K061PH015ADD0OWin03/k
>`0];Bd0CDe=05]KF`1EEED0Fe]K0080GemO00D0De=C05MGE`1aLG40IVIV0?ooo`060=WIf@400000
0@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT07@3oool0HV9R06IVIP1WIfL0RHV906YZJP1^
KVh0Lg=c08j>SP2<S8`0Vi^K09bLW01fMWH0SXj>07inOP1mOGd0O7al09RHV02TY:@0NWYj08j>SP27
QhL0TI6A09bLW02BTY80RHV908R8R02MWId0UiNG0080UYJF0P2KVi/0B@2_[jl0YjNW096AT@1RHV80
EEEE05IFEP1/K6`0F5QH06i^KP1SHf<0JVYZ06i^KP21PH40G5aL06MWI`1dM7@0P82008V9R@2XZ:P0
XZ:R0;:b/P2ZZZX0RXZ:0:^[Z`2HV9P0`/;20:FUY@2g]kL0Z:RX0<?3``2f][H0Y:BT0;Fe]@2o_kl0
]kNg0:ZZZP2^[Zh0];Bd0:VYZ@2MWId0V9RH09ZJVP2<S8`0SXj>0:^[Z`2KVi/0ZZZZ0;Ng]`2VYZH0
[Jf]09^KV`2^[Zh0YJFU0:b/[02UYJD0Shn?07alO02PX:00/k>c0:ZZZP2HV9P0YjNW0:VYZ@2LW9`0
VIVI0:n_[`2XZ:P0UiNG09fMW@29RHT0VYZJ0;6a/@2FUYH00P2UYJD0:`2e]KD0SHf=0:f][@22PX80
T92@075aL@2?Shl0OGem07inOP1VIVH0ATI605aLG01IFET0N7Qh08j>SP2VYZH0U9BD0:FUY@23Ph<0
RHV908B4Q01hN7P0Rh^;09BDU02HV9P0/;2`0<?3``2NWYh0ZZZZ0;Fe]@2ZZZX0_;bl0:6QX@2GUiL0
/k>c0;Vi^@2c/k<0^KVi09BDU02RXZ80YJFU09NGU`2KVi/00P2FUYH0<`1mOGd0MgMg08f=S@1gMgL0
V9RH07]kN`1mOGd0PH610:BTY02WYjL0Shn?096AT@2CTi<0W9bL08N7Q`2^[Zh0UiNG07inOP2IVIT0
Ph>308Z:RP1YJFT0WYjN09RHV02TY:@0T92@07moO`2GUiL0MGEe09>CT`2;Rh/0T92@07]kN`2?Shl0
QHF508N7Q`2?Shl0WYjN09nOW`2ATI40QhN707IfMP2CTi<0UiNG0861P@2ATI40U9BD08n?S`1nOWh0
YZJV07alO00208Z:RP0408F5Q@1[Jf/0P82008N7Q`80N7Qh00X0X:2P079bLP2IVIT0XJ6Q09RHV02L
W9`0HV9R092@T01eMGD0Ng]k0P28R8P07P1VIVH0Ogmo096AT@27QhL0N7Qh09:BTP25QHD0Ph>308R8
R020P800SXj>08b<S020P800GUiN09>CT`25QHD0UIFE07QhN027QhL0NGUi08F5Q@1[Jf/0NWYj07Qh
N029RHT0RXZ:08R8R020P800Ng]k07EeM@80I6AT00X0GUiN06a/K01gMgL0LW9b07inOP1aLG40IFEU
069RHP1iNGT0PH610P1eMGD0101_Kfl0Q8B407EeM@26QXH207EeM@0C07=cL`1gMgL0Lg=c06YZJP1l
O7`0M7Ad07emO@24Q8@0I6AT08>3P`1fMWH0LG5a08J6QP1]KFd0Fe]K07=cL`1TI6@0Fe]K061PH002
06MWI`0C065QH@1PH600GUiN04i>CP1bLW80CTi>05aLG01[Jf/0G5aL069RHP1`L700CTi>069RHP1/
K6`0KVi^069RHP1PH600LW9b0?ooo`060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT0
0`3IfMT0;`3oool0ADE506MWI`1YJFT0FEUI051@D01bLW80MgMg08N7Q`2@T900R8R80861P@1nOWh0
LW9b07moO`2@T900RXZ:071`L01kNg/0PX:207YjNP2@T900W9bL07inOP29RHT0RXZ:08>3P`2[Zj/0
T92@0:2PX024Q8@0Zj^[08:2PP2?Shl0SXj>07AdM01RHV80KVi^05MGE`1[Jf/0HF5Q06][J`1OGel0
KVi^05UIF@1iNGT0Fe]K0080GUiN0400PX:209JFUP2`/;00cLg=0:2PX02BTY80ZJVY0;no_`33`l<0
]kNg0;Fe]@30`<00Y:BT09NGU`2a/K40Zj^[0:b/[02:RXX0][Jf0:ZZZP2d];@0YZJV0:NWY`2UYJD0
Y:BT09jNWP2PX:00];Bd0:VYZ@2b/[80W9bL09nOW`2a/K40Zj^[09NGU`29RHT0W9bL092@T02JVYX0
WinO0:2PX02_[jl0[:b/0;>c/`2BTY80X:2P0::RXP2QXJ40YjNW0:FUY@2WYjL0W9bL08n?S`2UYJD0
ZZZZ0;Vi^@2`/;00[Zj^0:VYZ@2DU9@0RHV90:>SX`1ZJVX0Vi^K0P2EUID0<`2?Shl0WIfM06ATI01/
K6`0R8R806a/K02CTi<0WYjN0:^[Z`2VYZH0ZJVY09RHV02GUiL0P82008N7Q`1hN7P0UIFE0:n_[`2m
_Kd0e]KF09jNWP2^[Zh0SXj>0;Bd]02@T900[Zj^0;Zj^P2][Jd0];Bd08^;R`2g]kL0[jn_08F5Q@2G
UiL0X:2P07moO`2XZ:P0Ti>C08Z:RP1mOGd0WIfM09jNWP26QXH0Ph>30:b/[028R8P0YZJV08R8R02F
UYH0PX:208R8R00209VIV@0R09>CT`1jNWX0QXJ609:BTP1fMWH0TY:B08b<S02WYjL0UiNG08V9R@2D
U9@0WYjN0;6a/@2PX:00PX:2079bLP29RHT0Ph>309JFUP2:RXX0Xj>S09RHV023Ph<0W9bL0:^[Z`2>
SXh0OWin06MWI`2EUID0Rh^;09BDU025QHD0VIVI09nOW`80RHV90200WYjN07IfMP1gMgL0P82006QX
J01iNGT0Shn?09RHV01mOGd0JVYZ07=cL`28R8P0M7Ad09bLW01nOWh0QhN708n?S`1/K6`0R8R807Ui
N@22PX80Q8B407QhN020P800V9RH06a/K02DU9@0SHf=09:BTP2QXJ40Shn?08f=S@80MGEe00/0NGUi
07moO`26QXH0Ng]k07QhN01gMgL0Ng]k079bLP1fMWH0Q8B406m_K`020861P@0o069RHP1`L700Shn?
07UiN@1[Jf/0P82006MWI`1fMWH0O7al08Z:RP1SHf<0Kfm_0820P01]KFd0K6a/07MgM`1/K6`0OGem
07QhN021PH40MGEe08B4Q01cLg<0OGem07MgM`1KFe/0LG5a08j>SP24Q8@0Kfm_06e]K@1VIVH0KVi^
079bLP1QHF40L71`05=CD`1^KVh0Kfm_075aL@1]KFd0KVi^07alO01YJFT0MWIf06UYJ@1GEeL0Ph>3
06i^KP1JFUX0I6AT07MgM`1`L700CDe=06m_K`1aLG40IFEU08:2PP1CDe<0G5aL05UIF@1YJFT0oooo
00H0fMWI0@0000010=WIf@0000<0fMWI0000000000000`0000020=WIf@800000103IfMT2000000H0
fMWI00<000000=WIf@3IfMT00`3IfMT0I`3oool0MWIf07IfMP1YJFT0HV9R06ATI01aLG40H61P07em
O@29RHT0Q8B409VIV@2KVi/0RXZ:08>3P`2DU9@0OGem08J6QP2=SHd0M7Ad09VIV@1YJFT0R8R808>3
P`2BTY80Ng]k08n?S`2IVIT0Y:BT09JFUP2HV9P0ZZZZ0:JVYP2[Zj/0RXZ:0::RXP28R8P0Kfm_06e]
K@1QHF40L71`07UiN@1mOGd0OWin07moO`1`L700HV9R07]kN`21PH40YZJV09jNWP2KVi/0[jn_0:>S
X`2^[Zh0ZJVY0:2PX02e]KD0Vi^K0::RXP2^[Zh0YZJV09fMW@2WYjL0_;bl0<30`02?Shl0W9bL09NG
U`2UYJD0/[:b0<O7a`2i^KT0][Jf0:b/[02QXJ40`l?30;fm_@2XZ:P0Vi^K0;Bd]02/[:`0/k>c0:b/
[02KVi/0[Jf]09bLW02QXJ40Vi^K092@T02=SHd0UIFE0:n_[`27QhL0[Jf]0:RXZ02OWil0^[Zj08F5
Q@2[Zj/0[:b/09^KV`2SXj<00P2?Shl20;fm_@0D0:RXZ02d];@0T92@08b<S01nOWh0P82008N7Q`2G
UiL0VYZJ09BDU02?Shl0LG5a06][J`1fMWH0QHF50:>SX`2a/K40[Zj^09JFUP2EUID208^;R`0g08:2
PP28R8P0J6QX09NGU`2VYZH0_kno09NGU`36a/H0/k>c09jNWP2_[jl0VYZJ09bLW02VYZH0X:2P0:b/
[02^[Zh0Xj>S0;Vi^@2][Jd0VYZJ08n?S`2JVYX0WinO09NGU`1SHf<0SHf=0:RXZ02FUYH0Shn?09BD
U02ATI40QHF5071`L020P800LG5a09JFUP2HV9P0S8b<09JFUP2SXj<0Ti>C07QhN02;Rh/0Xj>S09bL
W02VYZH0WinO09BDU02ZZZX0VYZJ09:BTP2FUYH0YZJV0820P00208>3P`0`08f=S@2OWil0Ph>308b<
S02@T900X:2P07moO`28R8P0N7Qh08B4Q029RHT0WYjN09VIV@1mOGd0V9RH09NGU`2EUID0Ph>308V9
R@20P800H61P08V9R@2IVIT0SHf=09BDU02=SHd0UYJF07alO02?Shl0X:2P08^;R`29RHT0S8b<07em
O@1]KFd0N7Qh07inOP1fMWH0OWin08n?S`2@T900NGUi06UYJ@25QHD0VIVI08R8R020P800XZ:R0P1i
NGT05`22PX80SHf=06i^KP24Q8@0Rh^;06a/K01gMgL0LW9b06a/K01aLG40P82008N7Q`1ZJVX0Q8B4
07alO020P800M7Ad079bLP1_Kfl0M7Ad06m_K`1PH600Kfm_0080LG5a01D0I6AT071`L01]KFd0JFUY
08^;R`1ZJVX0PH6107emO@1^KVh0R8R807UiN@1YJFT0LW9b09NGU`1KFe/0HV9R07YjNP1hN7P0Kfm_
06e]K@1oOgl00P1gMgL07P1aLG40KVi^07UiN@1CDe<0K6a/07]kN`1ZJVX0LG5a05mOG`1oOgl0GUiN
05mOG`1=CDd0EeMG05QHF01iNGT0GemO06QXJ01iNGT0IFEU04m?C`1RHV80GEeM07=cL`10@400D51@
055AD@1FEUH0MWIf0?ooo`H0fMWI0@0000010=WIf@000`3IfMT01@000000fMWI0=WIf@3IfMT00000
0080fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI00<0fMWI00`0oooo06a/K01cLg<0Lg=c08R8R01oOgl0B4Q807emO@1bLW80Ph>308n?S`26QXH2
08N7Q`0G0820P01nOWh0JVYZ07YjNP2EUID0Lg=c069RHP1`L700R8R80861P@2CTi<0QXJ609NGU`2U
YJD0Ng]k09ZJVP2PX:00WinO09VIV@2EUID0Ti>C0:BTY01]KFd00P1mOGd04`22PX80Lg=c08n?S`20
P800PH6108F5Q@1_Kfl0GEeM06a/K02BTY80X:2P0:VYZ@2FUYH0[:b/0;:b/P2XZ:P0`l?30:j^[P1l
O7`00P2:RXX0D`2m_Kd0/K6a0:f][@2OWil0ZZZZ0;fm_@2WYjL0^KVi0:2PX02QXJ40R8R8096AT@2=
SHd0Zj^[0;Fe]@2MWId0YZJV0:ZZZP2a/K40[jn_0;2`/02RXZ80YjNW0:BTY02`/;00Xj>S09^KV`2F
UYH0RXZ:0:BTY02MWId0SXj>08b<S02MWId0Ti>C09jNWP2@T900XJ6Q0:f][@2PX:00W9bL0::RXP2/
[:`0YjNW08b<S02HV9P0];Bd09^KV`2@T900U9BD07YjNP29RHT0WinO08b<S02>SXh0Rh^;08J6QP2Q
XJ40OGem05EEE@1VIVH0NWYj07AdM02HV9P0UIFE0::RXP28R8P0Ogmo08>3P`2?Shl0QhN70:RXZ02^
[Zh0_;bl0<S8b02UYJD0Y:BT0;:b/P2RXZ80W9bL09nOW`2/[:`0]KFe0080_kno04@0XZ:R09ZJVP2R
XZ80TY:B0;Fe]@2^[Zh0Ti>C08b<S02LW9`0XZ:R09RHV02`/;00VYZJ09:BTP2RXZ80VIVI09jNWP21
PH40R8R8096AT@2NWYh0R8R807MgM`2DU9@0YJFU08n?S`28R8P0WIfM08b<S01lO7`0SXj>08n?S`2=
SHd0Ogmo09:BTP2@T900TI6A07moO`23Ph<0Ogmo075aL@28R8P0Ng]k08Z:RP2CTi<0R8R809ZJVP2;
Rh/0XJ6Q08J6QP2CTi<0PH6108b<S02/[:`0O7al08V9R@2CTi<0QhN707inOP1ZJVX0SHf=08>3P`2=
SHd0W9bL0:BTY02KVi/0MgMg08f=S@80MWIf04X0QhN707EeM@2>SXh0PH6108Z:RP2BTY80VIVI07=c
L`23Ph<0PH6107inOP1mOGd0KVi^08Z:RP1iNGT0Z:RX08n?S`1]KFd0RXZ:07alO027QhL0M7Ad07em
O@22PX80O7al08B4Q01jNWX0PH6106MWI`1iNGT0R8R8079bLP1KFe/0EEEE0820P01bLW80W9bL06][
J`21PH40PX:2065QH@1oOgl0KFe]07UiN@1ZJVX0GUiN092@T01`L700KFe]08N7Q`1gMgL0O7al07Ui
N@22PX80JVYZ06MWI`1lO7`0Lg=c06YZJP24Q8@0JVYZ08^;R`1]KFd0N7Qh0861P@1hN7P0NGUi07Mg
M`1YJFT0De=C08:2PP1MGEd0Hf=S02d];@80H61P01L0N7Qh079bLP1JFUX0I6AT065QH@1kNg/0I6AT
05MGE`1QHF40K6a/0410@01PH600GEeM05IFEP1SHf<0I6AT05]KF`1UIFD0JVYZ05IFEP1=CDd0Hf=S
0?ooo`060=WIf@4000000@3IfMT000<0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@040000
003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT00`3IfMT3000000<0fMWI00H0oooo061PH01i
NGT0UYJF07alO01OGel206IVIP0=07QhN02@T900UIFE08B4Q01aLG40PX:205iNGP1aLG40PX:207Ee
M@1/K6`0Ogmo09>CT`0208n?S`0b08Z:RP29RHT0Ti>C08:2PP29RHT0Shn?09jNWP2CTi<0YZJV09RH
V02RXZ80VIVI09BDU02:RXX0Ogmo08:2PP2ATI40Shn?06m_K`20P800Q8B407YjNP28R8P0OWin09BD
U02FUYH0[jn_09RHV02RXZ80Ti>C0;2`/02@T900Q8B409fMW@2EUID0^[Zj0::RXP2@T900VYZJ0;Rh
^02NWYh0^k^k0:RXZ02:RXX0YZJV09NGU`2SXj<0Vi^K0:JVYP2DU9@20:RXZ00c0:n_[`2MWId0ZZZZ
0;Fe]@2GUiL0YJFU0:>SX`2JVYX0ZZZZ0:JVYP2^[Zh0Ogmo09BDU02[Zj/0UYJF0;2`/02;Rh/0WinO
0:BTY029RHT0Z:RX0:6QX@2HV9P0Ng]k09jNWP2[Zj/0[:b/08B4Q02LW9`0Zj^[09jNWP2<S8`0X:2P
09FEU@22PX80QHF507IfMP2VYZH0VIVI0:NWY`2_[jl0Ti>C0:>SX`26QXH0K6a/07IfMP1MGEd0EeMG
07]kN`2ATI40O7al0080MGEe03`0MgMg08^;R`2>SXh0WinO09fMW@2PX:00YjNW0;Jf]P2[Zj/0^[Zj
0;^k^`2j^[X0cLg=09nOW`2c/k<0/;2`092@T02YZJT0_[jn09FEU@2GUiL0SHf=0:6QX@2IVIT0[Jf]
09:BTP2HV9P0UYJF08Z:RP1jNWX0OWin09fMW@2WYjL0Ng]k092@T02UYJD0Ogmo09BDU02;Rh/0XJ6Q
0:^[Z`2@T900XZ:R0:6QX@24Q8@0RXZ:08n?S`2TY:@0WIfM07emO@1lO7`0TY:B09^KV`2EUID0UiNG
08^;R`2=SHd0VIVI09JFUP2BTY8208b<S00707IfMP2KVi/0/[:b09FEU@2<S8`0OGem09ZJVP0208Z:
RP0;0:BTY02JVYX0RXZ:08f=S@2?Shl0L71`08N7Q`29RHT0X:2P09^KV`2BTY800P20P80208R8R00V
08>3P`2MWId0Xj>S09^KV`28R8P0RHV907alO01eMGD0Vi^K08N7Q`1dM7@0LG5a07AdM020P800QHF5
06UYJ@2EUID0KFe]08V9R@1^KVh0Ti>C07emO@2?Shl0P82008n?S`2JVYX0QXJ607inOP1/K6`0MWIf
07moO`1lO7`0JVYZ07YjNP1aLG40PH61079bLP1UIFD2071`L00W075aL@1YJFT0LG5a07IfMP1PH600
LG5a07EeM@1RHV80K6a/08N7Q`2@T900VYZJ08J6QP1cLg<0K6a/07QhN01BDU80Fe]K07QhN01JFUX0
J6QX06UYJ@1XJ6P0Ogmo07=cL`28R8P0O7al06EUI@1lO7`0F5QH06=SH`1^KVh0JVYZ061PH01KFe/0
OWin05QHF00H61P0JFUY0080IfMW00@0IVIV055AD@1TI6@0I6AT0P1cLg<03@1ZJVX0L71`06QXJ01k
Ng/0D51@06YZJP1aLG40MGEe05eMG@1jNWX0IFEU0451@@3oool0103IfMT300000040fMWI00030=WI
f@050000003IfMT0fMWI0=WIf@0000000P3IfMT010000000fMWI0=WIf@0000020=WIf@030000003I
fMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT0=@3oool0Q8B409JFUP2CTi<0IfMW05EEE@1N
GUh0IVIV06i^KP25QHD0LW9b08>3P`22PX80MGEe07emO@1[Jf/0Ogmo08R8R026QXH0OWin0820P02@
T900PX:20:2PX02?Shl0Ogmo09nOW`2PX:00ZZZZ0:FUY@20P800[Jf]0:FUY@2YZJT0WinO096AT@2R
XZ80ZJVY0:>SX`2@T900Vi^K0:RXZ02:RXX0J6QX096AT@23Ph<0UiNG08R8R02_[jl0XJ6Q08Z:RP2K
Vi/0Y:BT0080/[:b00@0ZJVY09bLW02MWId0Vi^K0P2YZJT04`2EUID0VYZJ0;Bd]02QXJ40WIfM08f=
S@2TY:@0YZJV08Z:RP2?Shl0X:2P09RHV027QhL0Xj>S0:ZZZP2OWil0XZ:R0:VYZ@33`l<00P2MWId0
2P2n_[h0[Jf]0:BTY02`/;00R8R80:2PX02UYJD0X:2P0:b/[02QXJ420:JVYP0=09JFUP2YZJT0VIVI
0:^[Z`21PH40UYJF08Z:RP2VYZH0[Zj^0:f][@2GUiL0[jn_0:6QX@0209FEU@0I08J6QP25QHD0Shn?
07=cL`2_[jl0SXj>0::RXP2_[jl0WinO08J6QP1OGel0DE5A05IFEP1<C4`0L71`05MGE`1RHV80IVIV
06][J`1/K6`0KVi^08n?S`2PX:00/k>c0:6QX@020;Vi^@040;Bd]038b<P0Xj>S0;Jf]P80ZJVY00T0
WinO09:BTP2QXJ40WYjN0:NWY`2b/[80Rh^;0:NWY`2`/;000P2EUID08@2CTi<0Z:RX08:2PP24Q8@0
PX:207=cL`1jNWX0^KVi0:VYZ@1kNg/0Ti>C08N7Q`2GUiL0Xj>S0:FUY@2XZ:P0SHf=0:6QX@2TY:@0
RXZ:079bLP2QXJ40Z:RX0:BTY027QhL0QHF509jNWP2=SHd0Q8B409BDU01gMgL0O7al09VIV@0209BD
U00M09VIV@2>SXh0V9RH07inOP22PX80U9BD09JFUP1ZJVX0OWin09VIV@2=SHd0Q8B409NGU`1VIVH0
KFe]06a/K01fMWH0V9RH0:^[Z`2@T900VYZJ096AT@2CTi<0MWIf07moO`2ATI40JFUY07]kN`2CTi<0
0P2KVi/02P27QhL0Ogmo08b<S02<S8`0Shn?0861P@24Q8@0Lg=c06YZJP1]KFd207YjNP0C07UiN@1h
N7P0Lg=c08V9R@1[Jf/0Ph>307MgM`2=SHd0TY:B09JFUP22PX80Ng]k07IfMP1SHf<0IVIV08>3P`2?
Shl0O7al07moO`0207emO@0G07inOP1iNGT0PX:206a/K01jNWX0SXj>06m_K`1?Cdl0J6QX06e]K@25
QHD0J6QX08^;R`2DU9@0Q8B407moO`1eMGD0GEeM07QhN01lO7`0LW9b07]kN`1eMGD00P1jNWX06P2@
T900NGUi096AT@1[Jf/0KVi^07AdM01XJ6P0NGUi06][J`1oOgl0OWin08n?S`1XJ6P0F5QH06YZJP1T
I6@0JVYZ06e]K@1WIfL0IFEU05QHF01IFET0E5AD06e]K@1_Kfl0MGEe0P1OGel02@1VIVH0E5AD08V9
R@1?Cdl0L71`06][J`12@T80FEUI0?ooo`060=WIf@4000000@3IfMT000<0fMWI00D000000=WIf@3I
fMT0fMWI000000020=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@030=WIf@0C0?ooo`2<S8`0TI6A09FEU@2<S8`0Ogmo05QHF01lO7`0L71`0820
P01mOGd0QXJ6071`L01iNGT0N7Qh08B4Q026QXH0Lg=c08F5Q@02096AT@2907UiN@1lO7`0Lg=c09NG
U`29RHT0Ph>308N7Q`24Q8@0YZJV0:BTY02QXJ40W9bL09FEU@2OWil0RXZ:0:RXZ02>SXh0YJFU09VI
V@2BTY80[Zj^0:VYZ@2CTi<0T92@08j>SP1oOgl0U9BD0:>SX`2CTi<0U9BD0;no_`2HV9P0/;2`09bL
W02i^KT0];Bd0:j^[P2e]KD0Z:RX0;:b/P2EUID0Ti>C0:6QX@2CTi<0UYJF0:b/[02VYZH0Vi^K096A
T@2NWYh0]KFe0:>SX`2@T900X:2P09bLW02[Zj/0UIFE0:JVYP2ATI40VYZJ0:n_[`2PX:00/[:b0:RX
Z02WYjL0TY:B0:2PX02QXJ40[Zj^09FEU@2GUiL0/K6a08Z:RP2HV9P0Shn?0:6QX@2SXj<0SHf=09VI
V@2SXj<0Vi^K09NGU`2RXZ80Ph>30:VYZ@2k^k/0Z:RX09:BTP2SXj<0T92@07]kN`1oOgl0Ng]k07in
OP2i^KT0Q8B409FEU@28R8P0MgMg05]KF`1MGEd0IVIV05QHF01`L700Kfm_05eMG@1PH600Rh^;09>C
T`2MWId0YjNW0:BTY02e]KD0aLG50;Ng]`2_[jl0TY:B09BDU02WYjL0];Bd0:f][@2YZJT0VIVI0:j^
[P2@T900TY:B08f=S@2MWId0VYZJ0:b/[026QXH0WIfM096AT@1`L700UYJF09BDU02BTY800P29RHT0
5@20P800PH6108f=S@27QhL0U9BD09VIV@22PX80S8b<0:BTY02LW9`0PH6108B4Q02KVi/0OWin08j>
SP2@T900UiNG09jNWP2PX:00XZ:R09RHV00208J6QP0]07QhN02UYJD0Ng]k08R8R02>SXh0YjNW08>3
P`2>SXh0Rh^;09jNWP2>SXh0CTi>071`L02@T900QHF5092@T02EUID0Q8B408:2PP1nOWh0L71`09NG
U`2>SXh0UYJF09ZJVP2LW9`0QHF508Z:RP20P800RHV909FEU@2BTY80U9BD09RHV01ADE40QhN708f=
S@21PH40O7al08j>SP28R8P0MGEe08j>SP1cLg<0PH610080Q8B400l0Y:BT09BDU023Ph<0Ph>308J6
QP1RHV80PX:20861P@1hN7P0PX:207QhN026QXH0Q8B406=SH`1YJFT00P20P8004`2=SHd0MGEe07Mg
M`1ZJVX0E5AD05]KF`1YJFT0Hf=S08n?S`1kNg/0Ogmo06e]K@1VIVH0MgMg06EUI@1/K6`0R8R806UY
J@2DU9@00P1kNg/03P1aLG40N7Qh06ATI01nOWh0Kfm_07QhN01eMGD0KFe]05YJFP1cLg<0QhN706e]
K@1_Kfl0J6QX0P1^KVh03@1QHF40KFe]071`L01nOWh0JFUY079bLP1UIFD0Kfm_05mOG`24Q8@0L71`
065QH@1fMWH00P1ZJVX03`1JFUX0GUiN06QXJ01VIVH0DU9B055AD@1WIfL0K6a/079bLP1QHF40M7Ad
06e]K@1XJ6P0G5aL0?ooo`060=WIf@4000000@3IfMT00080fMWI0P0000040=WIf@800000103IfMT2
000000H0fMWI00<000000=WIf@3IfMT00`3IfMT01`3oool0OWin096AT@26QXH0IfMW075aL@1fMWH0
0P1^KVh2092@T01F07inOP2HV9P0LW9b08R8R01lO7`0L71`08V9R@2PX:00R8R808^;R`27QhL0IVIV
09fMW@1mOGd0P82009RHV02<S8`0]KFe09>CT`2SXj<0Zj^[09jNWP2FUYH0SXj>08b<S026QXH0U9BD
08R8R02DU9@0LW9b08f=S@1mOGd0Shn?09>CT`2TY:@0UIFE09VIV@27QhL0WIfM0:BTY024Q8@0WYjN
09JFUP2KVi/0W9bL0:BTY02f][H0/K6a09fMW@2/[:`0[Zj^08J6QP2RXZ80Ng]k08Z:RP2TY:@0VIVI
0;Rh^02;Rh/0V9RH08N7Q`2ATI40U9BD09bLW02GUiL0Rh^;09FEU@2g]kL0XZ:R0<71`@2ZZZX0/K6a
0:n_[`2^[Zh0[jn_0:b/[02=SHd0][Jf0;Rh^02SXj<0TY:B0:f][@2JVYX0T92@096AT@1hN7P209FE
U@1L092@T02IVIT0SHf=0:2PX02SXj<0UYJF09fMW@2KVi/0_kno0;>c/`2IVIT0SXj>08f=S@1aLG40
N7Qh096AT@2MWId0QhN708j>SP1jNWX0LG5a07emO@1>CTh0FEUI079bLP1XJ6P0OWin09FEU@21PH40
ZZZZ0:RXZ02/[:`0Zj^[0:j^[P2IVIT0Y:BT0:ZZZP2f][H0Vi^K0;6a/@2b/[80ZJVY0:FUY@2e]KD0
/;2`0:RXZ02ZZZX0c<c<092@T02CTi<0RXZ:09>CT`2_[jl0XJ6Q096AT@23Ph<0/k>c08B4Q02QXJ40
Shn?09jNWP2`/;00UIFE07alO02?Shl0W9bL08n?S`2JVYX0RHV9092@T026QXH0Rh^;08b<S02ATI40
S8b<08N7Q`1kNg/0IfMW096AT@22PX80MgMg09^KV`2PX:00VIVI08^;R`21PH40Shn?09FEU@2CTi<0
S8b<0820P02MWId209nOW`1i08n?S`2<S8`0RHV909FEU@2KVi/0LW9b08N7Q`1oOgl0S8b<07emO@28
R8P0TI6A07emO@2IVIT0RHV90:n_[`2OWil0Ti>C0:BTY02:RXX0Rh^;07alO02LW9`0PH6107moO`1h
N7P0O7al08V9R@21PH40R8R808B4Q02<S8`0U9BD09NGU`1iNGT0Vi^K07moO`2GUiL0Kfm_09VIV@2E
UID0VIVI09BDU01[Jf/0LG5a08N7Q`25QHD0Ng]k08j>SP1hN7P0MGEe092@T01oOgl0N7Qh07YjNP26
QXH0P82006=SH`1UIFD0MWIf08^;R`29RHT0J6QX08J6QP1/K6`0NWYj0820P01RHV80E5AD0861P@1d
M7@0PH6107]kN`2<S8`0NWYj07AdM023Ph<0JVYZ07AdM01gMgL0KVi^08J6QP1aLG40J6QX08^;R`1g
MgL0K6a/04Y:BP1iNGT0MWIf07]kN`1bLW80L71`07MgM`1dM7@0IVIV04Q8B01/K6`0MgMg06a/K01X
J6P0O7al06EUI@1TI6@0EeMG06e]K@1OGel0K6a/06UYJ@1SHf<0MWIf02HV9P1JFUX0EEEE05IFEP1f
MWH0Kfm_055AD@1UIFD0KFe]0?ooo`060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT0
0`3IfMT0403oool0MgMg09^KV`1eMGD0N7Qh06MWI`1:BTX0KFe]06EUI@21PH40QhN708J6QP2@T900
Rh^;08F5Q@1]KFd207IfMP0K075aL@1QHF40PX:206EUI@1`L700Shn?08V9R@27QhL0RHV90:RXZ02A
TI40X:2P0:>SX`2k^k/0Zj^[08^;R`1cLg<0O7al061PH01YJFT0O7al07AdM01^KVh0QXJ607moO`1l
O7`0RHV90080W9bL0P2DU9@06@23Ph<0/K6a07=cL`2CTi<0Vi^K09VIV@28R8P0Ti>C0:2PX02d];@0
YJFU0;:b/P2RXZ80YJFU08Z:RP2g]kL0/[:b08Z:RP2[Zj/0^k^k0:FUY@2SXj<0Y:BT0:f][@2EUID0
0P2JVYX0/`2VYZH0Q8B40;:b/P2ZZZX0]KFe0:>SX`2^[Zh0W9bL09ZJVP2NWYh0_;bl0:b/[02EUID0
TI6A0:ZZZP1nOWh0PH6108Z:RP21PH40Rh^;09FEU@1SHf<0Ng]k0:BTY02KVi/0ZJVY0;6a/@2_[jl0
Y:BT09bLW024Q8@0Xj>S0::RXP2FUYH0Vi^K09VIV@2@T900QhN708F5Q@24Q8@0Lg=c065QH@1YJFT0
MWIf07YjNP1eMGD0MWIf08V9R@1lO7`0NGUi0:6QX@2[Zj/0WinO0<30`02TY:@0WYjN0:n_[`27QhL0
_kno0:NWY`2`/;00YJFU08R8R02_[jl0UIFE09bLW02WYjL0XZ:R0;^k^`2VYZH0S8b<0:ZZZP2=SHd0
VIVI08j>SP2c/k<0VIVI09nOW`2[Zj/0Shn?09bLW02?Shl0S8b<09bLW02<S8`0XZ:R09ZJVP26QXH0
Shn?092@T02PX:00U9BD0820P02WYjL0QhN707IfMP2JVYX0QhN709^KV`1]KFd0MWIf08B4Q02MWId0
WYjN08Z:RP20P800X:2P09ZJVP2FUYH0M7Ad08J6QP2>SXh0T92@09:BTP2=SHd0V9RH07UiN@2JVYX0
MWIf08F5Q@1nOWh0QhN70861P@1]KFd0UiNG0:^[Z`1dM7@0UYJF09>CT`1nOWh0RXZ:0:6QX@2?Shl0
WIfM092@T028R8P0S8b<08f=S@23Ph<0QXJ609nOW`2IVIT0LW9b04e=C@2CTi<0MgMg07IfMP2OWil0
SHf=08n?S`1nOWh0KVi^096AT@2@T900R8R809FEU@2GUiL0RXZ:0861P@2?Shl0UIFE08>3P`20P800
UIFE0820P02CTi<0OGem07IfMP2JVYX0Jf][07IfMP1gMgL0I6AT06IVIP1eMGD0IVIV071`L023Ph<0
QHF500<0MgMg03P0IVIV06ATI01bLW80I6AT06][J`2CTi<0Jf][06i^KP1`L700NGUi06IVIP1^KVh0
Ogmo07alO02BTY80Ng]k079bLP29RHT0MWIf06m_K`1FEUH0FUYJ0861P@1iNGT0QhN705eMG@2MWId0
D51@06=SH`1nOWh0HF5Q04E5A@1OGel0JVYZ07EeM@1bLW80MgMg05aLG01QHF40CTi>05MGE`0h>3P0
Cdm?061PH01DE5@0M7Ad05aLG01KFe/0De=C06e]K@19BDT0M7Ad06EUI@1CDe<0Kfm_0?ooo`H0fMWI
0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@1K0?ooo`1mOGd0QHF508>3P`1[Jf/0
FEUI04e=C@1hN7P0HF5Q0861P@28R8P0O7al07inOP1hN7P0LG5a07QhN01bLW80MGEe07moO`1fMWH0
RXZ:0861P@20P800LG5a08f=S@2NWYh0UIFE09RHV02EUID0Xj>S0:BTY02OWil0XJ6Q079bLP1TI6@0
MGEe079bLP1hN7P0J6QX06YZJP25QHD0MWIf07inOP2DU9@0S8b<0820P025QHD0Ph>308f=S@2?Shl0
NWYj07UiN@2IVIT0QhN708^;R`2UYJD0RHV909:BTP2XZ:P0T92@09bLW02UYJD0U9BD0:j^[P2CTi<0
UIFE0:f][@2/[:`0WIfM09JFUP2=SHd0TY:B09VIV@2i^KT0WYjN092@T02WYjL0Shn?0:2PX02DU9@0
[Zj^0::RXP2FUYH0WinO09jNWP2RXZ80]kNg0:FUY@2/[:`0Zj^[09BDU00206m_K`0C07IfMP1[Jf/0
MGEe07MgM`1QHF40O7al09nOW`2HV9P0XZ:R09BDU02VYZH0XJ6Q0;^k^`2c/k<0XJ6Q09BDU029RHT0
XZ:R08^;R`0207inOP0h08^;R`21PH40O7al08F5Q@1YJFT0Lg=c07UiN@2NWYh0NGUi09bLW02b/[80
YjNW0;:b/P2d];@0WIfM08J6QP2SXj<0_;bl0:FUY@2/[:`0X:2P08n?S`2QXJ40SHf=0:f][@2DU9@0
W9bL0:VYZ@2NWYh0Z:RX09nOW`2LW9`0WinO09JFUP2HV9P0UIFE096AT@2KVi/0/[:b09BDU02RXZ80
Kfm_092@T02TY:@0Vi^K08N7Q`23Ph<0ZZZZ0:^[Z`2NWYh0T92@096AT@2?Shl0UYJF08R8R02;Rh/2
09FEU@0D09ZJVP23Ph<0Vi^K07alO02DU9@0TY:B07inOP2ATI40R8R808j>SP2;Rh/0SXj>08J6QP1/
K6`0UIFE0:2PX01jNWX0Y:BT0861P@2][Jd2096AT@1J0861P@1/K6`0QXJ609nOW`27QhL0UIFE08^;
R`2BTY80RXZ:096AT@2JVYX0Vi^K09VIV@2<S8`0TI6A08R8R02:RXX0W9bL08R8R02FUYH0SXj>09VI
V@2<S8`0P82008j>SP23Ph<0P820061PH029RHT0VIVI07emO@1_Kfl0BTY:07emO@24Q8@0Ti>C06YZ
JP2@T900QHF507moO`2:RXX0RHV908b<S02:RXX0UiNG07]kN`25QHD0NWYj08F5Q@1]KFd0WIfM07If
MP1kNg/0OWin08Z:RP1TI6@0MgMg07QhN01NGUh0PH6107=cL`25QHD0IFEU06=SH`1bLW80NGUi06QX
J02:RXX0OWin07=cL`24Q8@0Ogmo07QhN01[Jf/0L71`06EUI@1aLG40Kfm_07UiN@1^KVh0Ogmo06e]
K@1`L700F5QH06UYJ@1lO7`0IfMW071`L01HF5P0EEEE0P1/K6`0201GEeL0HF5Q08:2PP1/K6`0JVYZ
07EeM@1^KVh0Kfm_0P1KFe/03`1?Cdl0I6AT05aLG01YJFT0IVIV06m_K`1aLG40Hf=S06UYJ@1KFe/0
EEEE05eMG@1cLg<0GemO03De=@0205iNGP030?ooo`3IfMT0fMWI00@0fMWI0@0000010=WIf@005P3I
fMT00`000000fMWI0=WIf@030=WIf@050?ooo`1fMWH0O7al07MgM`1UIFD00P1`L700AP20P800NGUi
07inOP2MWId0Rh^;06][J`2JVYX0U9BD07=cL`1kNg/0QHF505eMG@2BTY80X:2P08Z:RP20P800QXJ6
08F5Q@2BTY80XZ:R07EeM@2EUID0^;Rh09bLW02YZJT0MGEe07MgM`23Ph<0NWYj07AdM01aLG40GEeM
07]kN`1]KFd0R8R807IfMP1dM7@0SXj>08^;R`2MWId0UIFE09jNWP21PH40KFe]08>3P`2ATI40QXJ6
0820P01jNWX0VYZJ07moO`2/[:`0Xj>S0:NWY`2h^;P0[Jf]09bLW02NWYh0TY:B0:b/[02e]KD0^[Zj
09NGU`2b/[80XJ6Q0:f][@2DU9@0SXj>0:FUY@2l_;`209jNWP090:VYZ@2ZZZX0XJ6Q0:6QX@2][Jd0
`/;20:^[Z`2`/;00YZJV0080WYjN02h0RHV9061PH01QHF40SHf=09>CT`26QXH0SXj>07moO`1nOWh0
UIFE0::RXP2_[jl0[Jf]0;Zj^P2XZ:P0X:2P0:ZZZP2JVYX0Vi^K0;2`/02PX:00/;2`08J6QP22PX80
Ti>C09:BTP2?Shl0Lg=c09FEU@2LW9`0RHV90:RXZ02d];@0ZJVY0:BTY02_[jl0_kno0:JVYP2n_[h0
V9RH0;Zj^P29RHT0[:b/0:VYZ@2][Jd0][Jf0P2WYjL0B`2e]KD0Zj^[0:>SX`2NWYh0aLG50:n_[`2O
Wil0Vi^K09:BTP2[Zj/0^KVi0:ZZZP2NWYh0YjNW0:2PX02WYjL0Xj>S07emO@2RXZ80^[Zj08n?S`2E
UID0VYZJ0820P02FUYH0];Bd0:6QX@2/[:`0T92@08b<S02ATI40/;2`092@T02IVIT0YJFU0:RXZ02Q
XJ40WinO09NGU`21PH40SXj>08b<S02FUYH0XJ6Q08J6QP2;Rh/0UiNG096AT@20P800Ph>308V9R@2P
X:00Vi^K09:BTP1dM7@0U9BD08V9R@2ATI40MGEe08N7Q`1_Kfl0SXj>08:2PP2ZZZX0WIfM09ZJVP29
RHT0UiNG09jNWP1lO7`0VIVI09FEU@2FUYH0TY:B09jNWP0208f=S@0K09JFUP29RHT0UYJF09NGU`2:
RXX0PX:207YjNP2DU9@0RXZ:0:FUY@23Ph<0MGEe08^;R`2<S8`0SXj>09>CT`26QXH0Kfm_07QhN02:
RXX0NGUi06e]K@2QXJ40TY:B08F5Q@2?Shl0Ph>30080RXZ:00P0QHF508:2PP1ZJVX0O7al0861P@2?
Shl0HV9R07inOP80L71`00D0MWIf07EeM@1aLG40L71`08:2PP0207moO`0A06MWI`1oOgl0O7al08>3
P`1UIFD0N7Qh07emO@22PX80OGem06QXJ01TI6@0QXJ6075aL@28R8P0MWIf08N7Q`1/K6`00P1KFe/0
8P1bLW80NWYj05QHF01eMGD0IVIV071`L025QHD0L71`06EUI@1YJFT0OWin07UiN@1ZJVX0IVIV065Q
H@1jNWX0I6AT05eMG@1`L700FEUI051@D01bLW80NGUi07moO`1VIVH0EUIF06a/K01@D500GEeM06e]
K@1QHF40@d=306EUI@3oool60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0
3@3oool0GemO06UYJ@1cLg<0HV9R05MGE`2;Rh/0W9bL07inOP1`L700Ph>308J6QP1kNg/00P2CTi<0
?`2FUYH0PH6108^;R`2HV9P0Kfm_0:2PX02ATI40XZ:R08V9R@2ATI40QXJ60:2PX025QHD0TI6A07If
MP25QHD0RXZ:08F5Q@1cLg<0AdM706a/K01nOWh0Ti>C0;:b/P1nOWh0UIFE079bLP1QHF40FUYJ06IV
IP1mOGd0K6a/09:BTP29RHT0V9RH0:BTY02NWYh0Ogmo07emO@1hN7P0S8b<07QhN01iNGT0T92@08f=
S@2IVIT0^k^k0:ZZZP2KVi/0W9bL0:RXZ026QXH0];Bd0;Rh^02YZJT0[jn_0;:b/P2RXZ80W9bL09NG
U`1^KVh0TI6A09BDU0020;:b/P1l08f=S@2JVYX0YjNW08f=S@2][Jd0Zj^[09VIV@2MWId0TY:B09BD
U025QHD0KFe]08V9R@1aLG40QHF507alO025QHD0EUIF07MgM`29RHT0MGEe09:BTP28R8P0][Jf0:^[
Z`2HV9P0VYZJ0:VYZ@2PX:00U9BD0:^[Z`2f][H0Zj^[09VIV@2PX:00Shn?09nOW`2FUYH0[Zj^0:FU
Y@2`/;00[Zj^0;Zj^P2a/K40[:b/0:f][@2WYjL0WinO0:ZZZP2[Zj/0XJ6Q0<71`@29RHT0[:b/0;Fe
]@2f][H0W9bL0;>c/`2UYJD0Vi^K0;Bd]02TY:@0SXj>09VIV@2ZZZX0XJ6Q0:JVYP2[Zj/0U9BD09FE
U@2[Zj/0Shn?0:BTY02?Shl0YJFU08N7Q`2XZ:P0SHf=0:2PX02CTi<0WYjN08n?S`2QXJ40W9bL09FE
U@2?Shl0Ti>C09^KV`2BTY80VIVI09nOW`2WYjL0UIFE09nOW`2>SXh0PX:209VIV@2PX:00PX:20::R
XP1oOgl0QhN709ZJVP24Q8@0U9BD08N7Q`1]KFd0TY:B08j>SP2?Shl0SHf=05iNGP28R8P0SXj>06YZ
JP1mOGd0T92@07EeM@2<S8`0EUIF08^;R`20P800QhN709JFUP80S8b<0240WinO08b<S01lO7`0V9RH
096AT@2>SXh0V9RH09NGU`2MWId0QXJ608V9R@1cLg<0SHf=0861P@26QXH0O7al05iNGP1mOGd0Ng]k
06QXJ01bLW80IVIV08F5Q@2IVIT0Ph>309:BTP29RHT0Lg=c079bLP24Q8@0H61P07moO`2OWil00P25
QHD08@1iNGT0TI6A07UiN@1jNWX0SHf=092@T028R8P0QXJ6075aL@1lO7`0MgMg079bLP1_Kfl0KVi^
09BDU025QHD0JFUY079bLP1[Jf/0PH6107YjNP1_Kfl0LG5a07YjNP1nOWh0Ph>307]kN`1QHF40KFe]
07MgM`1bLW80L71`08N7Q`0207MgM`0D05eMG@1hN7P0PH6106e]K@21PH40MgMg07inOP2<S8`0KVi^
055AD@1QHF40LW9b07UiN@1LG5`0K6a/06EUI@1HF5P0Hf=S05IFEP1dM7@206a/K00@05EEE@1PH600
IFEU06ATI01GEeL0G5aL05IFEP1IFET0K6a/05QHF01kNg/0GUiN07AdM01/K6`0LG5a0?ooo`H0fMWI
0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@3H0?ooo`1WIfL0GEeM061PH01`L700
Ogmo07]kN`28R8P0PX:207IfMP2=SHd0T92@08B4Q01nOWh0Ti>C07moO`28R8P0GemO075aL@2@T900
V9RH09JFUP1iNGT0UYJF08F5Q@2VYZH0T92@09JFUP27QhL0R8R808b<S01hN7P0OGem079bLP1[Jf/0
MgMg079bLP2_[jl0Ti>C0::RXP2;Rh/0PH6105UIF@1JFUX0EEEE08V9R@2FUYH0Y:BT08B4Q02OWil0
Shn?08j>SP22PX80X:2P08F5Q@1RHV80R8R807]kN`2?Shl0VIVI0;bl_02/[:`0^KVi0:FUY@2FUYH0
T92@0<K6aP2h^;P0Y:BT0:>SX`2<S8`0ZZZZ0:VYZ@22PX80Vi^K08f=S@2?Shl0/k>c09FEU@2d];@0
TY:B0:BTY02l_;`0X:2P09jNWP2`/;00W9bL0:VYZ@2>SXh0Y:BT079bLP23Ph<0OWin07alO02CTi<0
R8R809FEU@2PX:00WinO06i^KP2;Rh/0RXZ:09jNWP2PX:00UYJF0:2PX02QXJ40ZZZZ09fMW@2[Zj/0
VIVI0:f][@2QXJ40[:b/0;Rh^01nOWh0Ph>30:JVYP2^[Zh0]kNg0;Jf]P2j^[X0alO70:VYZ@2_[jl0
XZ:R0;no_`2a/K40TI6A0;Ng]`2j^[X0WinO08N7Q`2OWil0[:b/09nOW`2][Jd0UYJF0:NWY`2m_Kd0
Z:RX09bLW02[Zj/0[Zj^09:BTP2VYZH0XJ6Q0:2PX02f][H0VIVI0:j^[P2VYZH0S8b<0:ZZZP2QXJ40
Zj^[0:6QX@2SXj<0QHF508^;R`20P800VYZJ0::RXP2ATI40X:2P09jNWP2PX:00V9RH08Z:RP2?Shl0
XZ:R09fMW@2<S8`0NGUi08F5Q@2>SXh0Ph>309JFUP2EUID0U9BD07inOP2=SHd0X:2P08R8R026QXH0
N7Qh08:2PP20P800QHF508n?S`2=SHd0Ti>C096AT@29RHT0NGUi09VIV@28R8P0P82008Z:RP2FUYH0
Ti>C07YjNP2=SHd0UYJF09:BTP1gMgL0P820096AT@1kNg/0Q8B40:n_[`2DU9@0TI6A08n?S`2IVIT0
SHf=0`2>SXh0G`2RXZ80UIFE09ZJVP27QhL0SHf=07moO`2;Rh/0QHF509ZJVP1bLW80PH6106][J`25
QHD0Rh^;08f=S@21PH40QHF508R8R02LW9`0S8b<0820P022PX80Ti>C092@T025QHD0GemO08J6QP23
Ph<0R8R806ATI01fMWH0Rh^;08:2PP25QHD0M7Ad07=cL`1TI6@0KFe]07emO@1iNGT0JFUY0861P@1l
O7`0M7Ad06UYJ@1RHV80Jf][071`L01oOgl0K6a/08>3P`1VIVH0QHF508:2PP1bLW80Q8B407alO01i
NGT0Jf][075aL@1YJFT0O7al07EeM@1cLg<0Kfm_07MgM`1]KFd0Hf=S04];B`1^KVh0MGEe05=CD`1N
GUh0Ng]k071`L01]KFd0GUiN069RHP1kNg/0KVi^06][J`1EEED0EeMG03Ph>019BDT0MWIf06UYJ@1b
LW80JFUY04a<C01EEED0MWIf07QhN01JFUX0oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000
fMWI0=WIf@030=WIf@0E0?ooo`1eMGD0KVi^06a/K01fMWH0Q8B406YZJP25QHD0SHf=07inOP1aLG40
OWin08f=S@2FUYH0UIFE092@T01kNg/0R8R808j>SP2<S8`0QHF50080WYjN0`2GUiL09`2FUYH0Vi^K
09NGU`1jNWX0Ng]k05mOG`1YJFT0GemO07=cL`1WIfL0R8R80:FUY@2[Zj/0TY:B0;:b/P2PX:00Ph>3
07YjNP1aLG40TY:B08:2PP2DU9@0QhN708n?S`2CTi<0Vi^K09bLW01mOGd0TY:B096AT@1_Kfl0Ph>3
07EeM@1XJ6P0UiNG08n?S`2VYZH0/;2`0:b/[0020:n_[`0Z0:NWY`2RXZ80[Zj^0:BTY024Q8@0YJFU
09bLW027QhL0XZ:R07inOP2e]KD0Xj>S0;Zj^P2OWil0TY:B0:RXZ02i^KT0[Zj^0;:b/P2WYjL0[Zj^
09ZJVP2[Zj/0MGEe08F5Q@29RHT0X:2P0;Fe]@2c/k<0QXJ60:FUY@21PH40NGUi08F5Q@1kNg/0V9RH
0:JVYP2SXj<0S8b<09VIV@2VYZH0TY:B0P2c/k<0A`2][Jd0/k>c0;bl_02d];@0^k^k0:FUY@2c/k<0
Ph>30;2`/02/[:`0/;2`0;6a/@2j^[X0RXZ:0:ZZZP2l_;`0/;2`09bLW02/[:`0[jn_0<30`02SXj<0
VIVI08b<S01hN7P0Y:BT0:f][@2n_[h0WYjN0::RXP2KVi/0[Jf]08j>SP2VYZH0ZJVY0:2PX02ZZZX0
YJFU09nOW`2KVi/0Shn?09^KV`1lO7`0Xj>S09:BTP2HV9P0[:b/09fMW@2NWYh0W9bL0:n_[`2SXj<0
R8R809ZJVP2UYJD0RHV909:BTP2WYjL0NWYj0820P02CTi<0VYZJ0:JVYP25QHD0V9RH08n?S`2;Rh/0
X:2P0:RXZ02HV9P0WIfM0080QXJ602h0QHF508J6QP2LW9`0RHV909>CT`27QhL0QXJ608j>SP2KVi/0
QXJ608R8R01WIfL0Ogmo09BDU027QhL0O7al0861P@2=SHd0U9BD08Z:RP2MWId0KFe]07]kN`1aLG40
YJFU08B4Q027QhL0];Bd09FEU@1ZJVX0Ng]k08n?S`2=SHd0SXj>0:JVYP2DU9@0YZJV08V9R@2IVIT0
NGUi08j>SP1cLg<0TY:B079bLP24Q8@0Ogmo0P2:RXX05P2@T900P82008B4Q02TY:@0Q8B408^;R`25
QHD0Ti>C07MgM`1VIVH0KFe]09RHV023Ph<0UYJF08f=S@1lO7`0PX:206i^KP1dM7@0MgMg0861P@1a
LG4206EUI@0j0861P@1jNWX0JVYZ08:2PP23Ph<0NWYj08^;R`23Ph<0JVYZ0861P@1UIFD0BDU907Mg
M`1`L700MWIf06YZJP1oOgl0Hf=S06UYJ@1hN7P0JVYZ079bLP1OGel0Fe]K07UiN@1gMgL0K6a/08f=
S@1;Bd/0H61P05eMG@1TI6@0JVYZ06i^KP1cLg<0IFEU06e]K@1RHV80GEeM06=SH`1_Kfl0Ng]k07Ee
M@1ZJVX0IFEU061PH01TI6@0F5QH065QH@1>CTh0De=C051@D01RHV80J6QX08J6QP1VIVH0P8200?oo
o`H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0k0?ooo`29RHT0R8R808^;
R`2QXJ40Rh^;08Z:RP2LW9`0UIFE09VIV@2SXj<0X:2P0:f][@2VYZH0VYZJ09^KV`20P800TY:B08j>
SP2TY:@0XJ6Q092@T02:RXX0Xj>S0:n_[`2CTi<0S8b<07=cL`1/K6`0MWIf069RHP23Ph<0Jf][06e]
K@1fMWH0NGUi09RHV02GUiL0X:2P0;Rh^02^[Zh0Xj>S08F5Q@28R8P0MWIf08b<S026QXH0RHV90;6a
/@27QhL0PH6109NGU`2HV9P0LG5a09NGU`1bLW80SHf=0861P@1nOWh00P1fMWH03@21PH40QhN708>3
P`2KVi/0XJ6Q09fMW@2d];@0TI6A0;Jf]P2_[jl0[Jf]09^KV`1^KVh00`2OWil0;P2XZ:P0[jn_0:NW
Y`2MWId0X:2P0::RXP2NWYh0V9RH0::RXP2f][H0/K6a07QhN02:RXX0UiNG08n?S`2GUiL0ZZZZ0:2P
X02SXj<0V9RH09:BTP2LW9`0Lg=c071`L025QHD0QhN70:RXZ02OWil0XZ:R09ZJVP2SXj<0Z:RX0;2`
/02DU9@0T92@0:RXZ02VYZH0[Zj^0:NWY`1gMgL0_kno08n?S`2MWId0VIVI0:^[Z`2TY:@20;Bd]00Y
0:f][@2WYjL0[Jf]0<[:bP2RXZ80`<300:RXZ02g]kL0[jn_09ZJVP2i^KT0Ti>C0:j^[P2QXJ40Zj^[
0:NWY`2SXj<0Y:BT0;Rh^02WYjL0[Jf]0;2`/02YZJT0/K6a0:2PX02DU9@0YjNW09bLW02<S8`0UYJF
09VIV@2RXZ80WYjN0:n_[`2TY:@0UIFE08>3P`2ATI40PX:209:BTP1hN7P00P2FUYH0F@21PH40Shn?
0:2PX02LW9`0U9BD0:2PX01lO7`0PH6107moO`1mOGd0PH61092@T02KVi/0Xj>S08B4Q02CTi<0TI6A
0:6QX@1`L700MGEe06QXJ02CTi<0QhN708R8R02KVi/0WinO092@T02CTi<0Vi^K07=cL`29RHT0YJFU
09bLW02:RXX0WYjN07UiN@2=SHd0KVi^08:2PP2?Shl0R8R807inOP1jNWX0Shn?08B4Q02RXZ80Ph>3
08n?S`2@T900QHF509jNWP2TY:@0UiNG02HV9P1nOWh0R8R807QhN028R8P0RXZ:09JFUP1mOGd0RHV9
08F5Q@2>SXh0Rh^;09>CT`2ATI40EUIF07moO`2:RXX0Xj>S0:NWY`2MWId0VYZJ06YZJP2ATI40U9BD
06m_K`1kNg/0LG5a092@T01dM7@0Ph>305EEE@1lO7`0P82007IfMP1`L700LG5a0080MGEe03L0JVYZ
05UIF@26QXH0DU9B06m_K`1ZJVX0Ph>304A4A01UIFD0Lg=c08J6QP20P800KFe]08:2PP1TI6@0EeMG
08J6QP1kNg/0SHf=075aL@1_Kfl0LW9b06YZJP1HF5P0KVi^06=SH`1fMWH0GUiN071`L01aLG40PH61
05aLG020P800Ogmo06UYJ@1OGel0HV9R06EUI@1FEUH0LW9b06ATI01IFET0H61P07=cL`1VIVH0I6AT
06a/K011@D40F5QH065QH@1dM7@0H61P05UIF@1;Bd/0oooo00H0fMWI0@0000010=WIf@005P3IfMT0
0`000000fMWI0=WIf@030=WIf@080?ooo`2LW9`0U9BD0:VYZ@20P800RHV90:2PX02=SHd208n?S`0Q
08N7Q`2HV9P0Shn?075aL@1kNg/0MWIf0820P01bLW80K6a/061PH02CTi<0SXj>096AT@2[Zj/0VIVI
09RHV01nOWh0Ogmo07inOP1jNWX0Rh^;07]kN`1mOGd0Jf][06e]K@21PH40L71`0;fm_@2UYJD0Z:RX
0;2`/02ZZZX0Rh^;0080PX:200d0Ph>306][J`1[Jf/0OGem08^;R`2:RXX0]KFe09BDU02RXZ80Z:RX
0:2PX01`L700KFe]0080Lg=c0?h0NWYj09NGU`1hN7P0W9bL09fMW@2UYJD0WinO0:JVYP2e]KD0P820
0:BTY01nOWh0QXJ607YjNP2JVYX0X:2P09>CT`2SXj<0QXJ609bLW02_[jl0ZJVY08N7Q`2NWYh0Y:BT
08n?S`2ZZZX0Zj^[092@T02FUYH0W9bL07AdM01jNWX0VIVI09^KV`2UYJD0V9RH09BDU02?Shl0NGUi
06UYJ@2BTY80UiNG09fMW@2[Zj/0Shn?07IfMP2[Zj/0YZJV08n?S`2DU9@0[Zj^0;Bd]02VYZH0][Jf
0:FUY@2KVi/0/;2`09ZJVP2[Zj/0[Zj^0:>SX`2`/;00Vi^K09NGU`2@T900Xj>S0<C4a02LW9`0YJFU
0;2`/02OWil0XZ:R0:VYZ@34a<@0Xj>S08N7Q`2HV9P0][Jf09FEU@24Q8@0[Zj^08N7Q`2NWYh0/;2`
09VIV@2a/K40YZJV092@T02k^k/0TI6A08N7Q`2SXj<0Vi^K09NGU`2DU9@0UYJF09FEU@2GUiL0TY:B
08Z:RP1lO7`0SHf=09nOW`2@T900TI6A09VIV@21PH40U9BD0861P@2;Rh/0LW9b09>CT`2EUID0W9bL
0:2PX02SXj<0R8R809bLW01oOgl0WYjN0:>SX`2HV9P0TI6A09VIV@2KVi/0KVi^09bLW01`L700IVIV
07IfMP2KVi/0QHF507alO02IVIT0XZ:R0820P02GUiL0PH6108^;R`2:RXX0PH61092@T02<S8`0Vi^K
0:6QX@2MWId0QHF509BDU029RHT0UYJF09^KV`2=SHd0TY:B09JFUP2QXJ40Ng]k07moO`2BTY80YZJV
09BDU01TI6@0WinO08n?S`22PX80Shn?07AdM01jNWX0Ti>C08F5Q@2GUiL0QHF508Z:RP1nOWh0T92@
08F5Q@1lO7`0RXZ:09FEU@1hN7P0TI6A08F5Q@20P800Ng]k06UYJ@1XJ6P0Rh^;07emO@21PH40Lg=c
07]kN`1RHV80OGem07AdM01QHF40Jf][07UiN@1MGEd0Lg=c08j>SP1jNWX0MWIf06i^KP1/K6`0KFe]
07EeM@1GEeL0GUiN06MWI`22PX80QhN70820P01XJ6P0Jf][08B4Q02;Rh/0KVi^07moO`1`L700DE5A
07QhN01jNWX0LW9b06IVIP1dM7@0N7Qh07=cL`1PH600IFEU06][J`1iNGT0C4a<07MgM`1PH600IVIV
06EUI@1@D500Hf=S061PH01JFUX0N7Qh05=CD`1KFe/0IVIV07]kN`1RHV80BTY:059BDP1EEED0IVIV
05QHF01XJ6P0EEEE0?ooo`H0fMWI0@0000010=WIf@005P3IfMT2000000@0fMWI06H0oooo0:VYZ@2E
UID0WinO0861P@2QXJ40PX:208^;R`2JVYX0P82008Z:RP2CTi<0Rh^;07moO`1mOGd0QhN708n?S`1Q
HF40Shn?0:BTY029RHT0YjNW07alO02_[jl0QHF5065QH@1hN7P0Rh^;09nOW`1dM7@0XJ6Q08Z:RP1k
Ng/0MGEe07alO01jNWX0SXj>092@T02ATI40U9BD09NGU`2PX:00O7al07moO`1iNGT0OGem08n?S`22
PX80Rh^;09:BTP2ZZZX0K6a/0820P02XZ:P0UiNG09JFUP2MWId0TY:B05]KF`1kNg/0IfMW06YZJP2E
UID0WIfM08Z:RP2JVYX0VIVI0:6QX@2HV9P0X:2P08n?S`24Q8@0ZZZZ0:^[Z`2?Shl0[jn_09ZJVP2Z
ZZX0Ti>C0:JVYP2UYJD0^[Zj0820P02a/K40W9bL0:n_[`2j^[X0`<300861P@2BTY80NGUi08V9R@2X
Z:P0Shn?09NGU`2EUID0WYjN09RHV02FUYH0Rh^;08Z:RP1mOGd208R8R00V09RHV02WYjL0^[Zj09RH
V02FUYH0[jn_092@T02ZZZX0[Jf]08^;R`2][Jd0YZJV0;:b/P2WYjL0ZJVY0;Jf]P2`/;00^[Zj0;jn
_P2RXZ80Z:RX0;Bd]02c/k<0/K6a0:JVYP2_[jl0bLW90:VYZ@2_[jl0[:b/0::RXP2e]KD0_[jn0:2P
X02TY:@0XZ:R09jNWP2OWil20:RXZ00A09nOW`2MWId0RHV908n?S`2VYZH0U9BD0:>SX`21PH40WYjN
0:2PX02OWil0Ti>C0:>SX`2TY:@0WIfM096AT@2DU9@00P2TY:@08P2CTi<0YJFU08F5Q@2XZ:P0Ti>C
09:BTP2OWil0QhN706e]K@2MWId0PX:208J6QP2GUiL0UIFE07moO`2OWil0QHF505eMG@2j^[X0UiNG
08f=S@1kNg/0QhN707moO`25QHD0RXZ:07inOP27QhL0TY:B07emO@20P800KFe]08Z:RP2<S8`208Z:
RP0A08>3P`29RHT0UYJF08j>SP2ATI40PX:208b<S01iNGT0QhN70::RXP2;Rh/0LG5a07QhN02=SHd0
TY:B096AT@2FUYH00P2>SXh0G02;Rh/0R8R808:2PP2:RXX0Q8B4092@T029RHT0O7al09bLW02UYJD0
V9RH08^;R`2BTY80SHf=08b<S02=SHd0OGem09bLW02=SHd0PX:20:>SX`22PX80X:2P07]kN`2HV9P0
Shn?07moO`23Ph<0L71`07]kN`1ZJVX0Jf][08n?S`1FEUH0P82004e=C@1ZJVX0IfMW08>3P`1kNg/0
QXJ607inOP1bLW80MWIf08b<S01gMgL0MWIf071`L021PH40Jf][07inOP1LG5`0FUYJ07AdM029RHT0
H61P06m_K`1aLG40N7Qh07UiN@1XJ6P0NGUi06QXJ01RHV80LG5a06][J`1VIVH0DU9B07EeM@1^KVh0
ADE5079bLP1]KFd0HV9R06][J`1`L700H61P03Xj>P0L71`0=SHf02l_;`19BDT0EUIF05UIF@1]KFd0
GUiN075aL@0m?Cd0G5aL06a/K01RHV80MgMg0P1[Jf/00`1hN7P0oooo0=WIf@040=WIf@8000000@3I
fMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT01@3oool0RXZ:09ZJVP2TY:@0RXZ:0080TY:B00/0
WinO09NGU`2:RXX0Vi^K0820P02EUID0TY:B09nOW`2][Jd0YJFU08b<S00208V9R@0W096AT@2NWYh0
VIVI08R8R02RXZ80I6AT08R8R01oOgl0U9BD09NGU`2IVIT0VYZJ08F5Q@28R8P0Lg=c06e]K@1eMGD0
OGem08>3P`1kNg/0XZ:R09RHV01mOGd0OWin08j>SP1oOgl0RHV9092@T01jNWX0P82008n?S`2IVIT0
V9RH09FEU@2UYJD0QHF50:FUY@1lO7`0N7Qh0080Ogmo00/0LG5a08J6QP28R8P0TY:B0:>SX`2RXZ80
][Jf09bLW02ZZZX0R8R809VIV@0209^KV`0d0<c<c02][Jd0UYJF0:VYZ@2_[jl0WYjN08f=S@2QXJ40
YJFU0;fm_@2`/;00XZ:R0:RXZ02?Shl0YZJV09bLW024Q8@0TY:B09^KV`2l_;`0YjNW08b<S02KVi/0
QXJ6079bLP1oOgl0OGem07]kN`27QhL0TY:B09JFUP1mOGd0ZJVY0:ZZZP1oOgl0Xj>S0:6QX@2IVIT0
Zj^[09VIV@2WYjL0XZ:R0;:b/P2PX:00[Zj^0:>SX`2ZZZX0Ti>C09VIV@2[Zj/0[:b/09ZJVP80^;Rh
00L0`l?30;>c/`2VYZH0Vi^K0::RXP2UYJD0UIFE0080W9bL02/0/;2`0:b/[030`<00U9BD09bLW02T
Y:@0WinO0:FUY@2WYjL0WIfM09JFUP2VYZH0WinO0:6QX@26QXH0Y:BT09bLW02FUYH0UiNG09bLW02X
Z:P0UYJF09ZJVP2FUYH0SXj>08V9R@25QHD0UIFE08j>SP2XZ:P0U9BD09RHV02SXj<0UIFE08N7Q`2F
UYH0P82009nOW`2QXJ40R8R809NGU`2KVi/0UiNG0080S8b<05d0W9bL08:2PP2LW9`0QXJ606m_K`2U
YJD0TY:B08F5Q@2;Rh/0OGem08:2PP2FUYH0Ti>C0::RXP2IVIT0Xj>S0:VYZ@2<S8`0WIfM0:FUY@2:
RXX0Shn?0861P@2MWId0SHf=09NGU`2OWil0YjNW08b<S02YZJT0V9RH0:VYZ@2LW9`0N7Qh09JFUP2e
]KD0QhN707moO`28R8P0QHF50861P@25QHD0T92@07YjNP23Ph<0N7Qh09:BTP2@T900UIFE0:>SX`1l
O7`0V9RH07moO`27QhL0TY:B09RHV025QHD0W9bL0820P02FUYH0Ogmo07AdM01kNg/0Ogmo06e]K@1M
GEd0IfMW06e]K@1YJFT0LW9b06YZJP1cLg<0J6QX065QH@1eMGD0M7Ad07MgM`1QHF40P82007IfMP1U
IFD0MWIf06e]K@1dM7@0MGEe08:2PP1ZJVX0J6QX079bLP1UIFD0GUiN079bLP1IFET00P1SHf<04`1`
L700KFe]05]KF`1nOWh0QHF507inOP1ZJVX0Hf=S05EEE@1VIVH0MGEe059BDP1gMgL0MGEe05mOG`1Y
JFT0@T9204E5A@0G5aL00`0000001`0`<300@d=3071`L01RHV80N7Qh0410@01hN7P00P1WIfL01P1_
Kfl0GemO05iNGP1JFUX0JFUY0?ooo`H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@03
0=WIf@2n0?ooo`2[Zj/0U9BD08b<S025QHD0WYjN09nOW`2][Jd0XJ6Q09VIV@1nOWh0QXJ609fMW@2`
/;00VYZJ08V9R@2EUID0U9BD08f=S@1lO7`0U9BD06UYJ@27QhL0QXJ608n?S`28R8P0MWIf07QhN02X
Z:P0ZJVY0;Rh^02ATI40V9RH06EUI@1YJFT0N7Qh069RHP1iNGT0CDe=0::RXP1hN7P0MWIf06m_K`2<
S8`0SXj>07IfMP28R8P0OWin07QhN01_Kfl0MGEe07IfMP28R8P0X:2P09fMW@2HV9P0TI6A08f=S@28
R8P0RHV907=cL`1mOGd0V9RH08B4Q02DU9@0[:b/09BDU02IVIT0W9bL09BDU02FUYH0YjNW0;Zj^P2D
U9@0UYJF09nOW`2FUYH0RHV908n?S`2MWId0UIFE08Z:RP2FUYH0/[:b0:JVYP2;Rh/0YjNW09NGU`2C
Ti<0RHV907moO`26QXH0T92@0:2PX02CTi<0PX:20:j^[P2:RXX0MgMg08j>SP1bLW80Jf][07EeM@21
PH40Y:BT09ZJVP2OWil0UYJF0:n_[`2VYZH0SXj>0:b/[024Q8@0RHV909:BTP2g]kL0/[:b09NGU`2J
VYX0[jn_0:FUY@2OWil0[:b/0:VYZ@2][Jd0/;2`0:RXZ034a<@0[:b/09ZJVP2<S8`0W9bL09fMW@2_
[jl0Vi^K0;2`/02SXj<0/K6a09ZJVP2b/[80[Zj^0:6QX@2[Zj/0Ti>C09nOW`2IVIT0/[:b09bLW02R
XZ80WIfM0::RXP2JVYX0S8b<09jNWP1oOgl0TY:B07moO`2LW9`0U9BD09>CT`2MWId0YjNW0;2`/028
R8P0UYJF0::RXP26QXH0N7Qh096AT@2][Jd0TY:B0:BTY02PX:00YZJV08^;R`1hN7P0SHf=08j>SP2<
S8`0[jn_08R8R02GUiL0S8b<07emO@1eMGD0V9RH0:^[Z`2@T900Ti>C08Z:RP80PX:202d0LW9b08V9
R@2@T900QhN70:6QX@25QHD0RHV908f=S@2CTi<0VYZJ092@T02ATI40SHf=08j>SP2EUID0S8b<08Z:
RP2<S8`0SHf=09^KV`1hN7P0TI6A09fMW@2>SXh0X:2P092@T02EUID0QXJ607YjNP2OWil0OGem08j>
SP2LW9`0VYZJ07MgM`21PH40PX:2079bLP2=SHd0QXJ607QhN02FUYH0Vi^K0:ZZZP2VYZH00P2BTY80
1`2KVi/0UIFE08j>SP21PH40JFUY07IfMP28R8P00P1mOGd0<01WIfL0VYZJ05iNGP1YJFT0OWin08J6
QP1iNGT0GEeM06i^KP1bLW80J6QX06EUI@1TI6@0MGEe071`L01cLg<0K6a/07IfMP1kNg/0O7al075a
L@1jNWX0M7Ad06MWI`1VIVH0Fe]K05eMG@1mOGd0M7Ad08>3P`1_Kfl0M7Ad071`L01UIFD0LG5a07Qh
N01/K6`0Q8B406EUI@1CDe<0Jf][06QXJ01^KVh0Cdm?05YJFP0i>CT0=3@d01TI6@<0000000l0;2`/
04m?C`1ADE40;Rh^07IfMP1NGUh0KFe]04e=C@1VIVH0CDe=075aL@1DE5@0Fe]K07alO03oool01P3I
fMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI07<0oooo08^;R`2=SHd0UiNG09RH
V02NWYh0SHf=08B4Q029RHT0SXj>08V9R@21PH40Rh^;09VIV@29RHT0Ti>C09FEU@1iNGT0OWin08>3
P`2DU9@0Shn?096AT@2LW9`0XZ:R07IfMP1bLW80Ph>309FEU@2m_Kd0`L710:>SX`2CTi<0VYZJ07in
OP1RHV80Hf=S05eMG@1^KVh0I6AT0820P01jNWX0SXj>07inOP2a/K40Xj>S0:6QX@2=SHd0QHF507em
O@1kNg/0PX:207QhN02;Rh/0OWin08^;R`2?Shl0T92@08:2PP21PH40M7Ad08:2PP2:RXX0VYZJ08b<
S02JVYX0VIVI0:>SX`2n_[h0[Zj^0:f][@2PX:00YJFU0:f][@2EUID0YJFU0::RXP2_[jl0WinO0:2P
X02NWYh0QhN708R8R02RXZ80_Kfm09jNWP2ZZZX0V9RH09NGU`2YZJT0QXJ607MgM`1iNGT0Ti>C07=c
L`1jNWX0RXZ:06UYJ@1JFUX0TI6A07moO`25QHD0Ti>C08R8R021PH40/k>c0:2PX02MWId0Zj^[0;2`
/02PX:00XJ6Q09NGU`2[Zj/0U9BD0080VIVI00L0ZZZZ09jNWP2^[Zh0a/K60:VYZ@2_[jl0VIVI0080
_Kfm08T0/k>c0;no_`2`/;00][Jf0;:b/P2][Jd0WinO09FEU@2UYJD0Ti>C0:6QX@2IVIT0[:b/0;:b
/P2/[:`0];Bd0;^k^`2d];@0Y:BT0:n_[`2[Zj/0Y:BT0:2PX02ZZZX0VYZJ0:JVYP2f][H0YZJV0:2P
X02HV9P0RXZ:0:>SX`2VYZH0OGem09NGU`28R8P0Ogmo08:2PP2VYZH0Y:BT08Z:RP1jNWX0OGem08R8
R02LW9`0XJ6Q07emO@26QXH0NWYj06e]K@2BTY80TI6A0:FUY@2@T900Ti>C07AdM02FUYH0UIFE0:6Q
X@29RHT0TI6A0::RXP2d];@0Ti>C092@T025QHD0Rh^;0:JVYP21PH40O7al09:BTP1kNg/0WIfM0:6Q
X@2LW9`0Vi^K0:FUY@2>SXh0RXZ:09RHV01^KVh0P82008Z:RP2IVIT0X:2P08J6QP1gMgL0U9BD0:6Q
X@2JVYX0UIFE09^KV`2:RXX0RHV907inOP2HV9P0Rh^;08f=S@28R8P0TI6A07EeM@29RHT0UYJF08B4
Q02ATI40XZ:R0:6QX@1jNWX0OWin08N7Q`21PH40TI6A07alO028R8P0WinO09FEU@26QXH0LW9b07in
OP1hN7P0P82004m?C`2<S8`0QhN706m_K`1jNWX0PH6108n?S`1TI6@0MGEe075aL@1OGel0M7Ad05mO
G`1@D500J6QX06=SH`0208j>SP0O08n?S`2DU9@0MgMg06a/K01lO7`0L71`06e]K@1jNWX0K6a/07Ee
M@1TI6@0RHV907alO01OGel0Lg=c05]KF`1eMGD0P82005iNGP2<S8`0GEeM06a/K01bLW80GUiN055A
D@1WIfL0IFEU05mOG`1XJ6P07alO00X:2P030000000?02HV9P0l?3`0H61P05IFEP1PH600Bd];06IV
IP1YJFT0GemO06UYJ@1PH600F5QH07IfMP1FEUH0oooo00H0fMWI0@0000010=WIf@005P3IfMT00`00
0000fMWI0=WIf@030=WIf@0M0?ooo`2CTi<0V9RH09VIV@2:RXX0PX:209^KV`2MWId0OGem0:6QX@2?
Shl0Rh^;09^KV`2;Rh/0ZJVY09BDU02CTi<0MWIf09BDU01fMWH0QXJ6096AT@1mOGd0SXj>08F5Q@1g
MgL0PH6109FEU@2CTi<00P2GUiL0=`2CTi<0WinO096AT@1fMWH0I6AT079bLP1SHf<0Fe]K06YZJP1f
MWH0QhN707]kN`2HV9P0R8R809ZJVP2_[jl0MgMg06=SH`29RHT0O7al08>3P`1aLG40TI6A08j>SP2;
Rh/0P82005aLG01fMWH0N7Qh07inOP1mOGd0W9bL0861P@23Ph<0QHF506a/K02WYjL0Ogmo09fMW@2V
YZH0[Zj^0:^[Z`30`<00X:2P09bLW02][Jd0ZZZZ0:>SX`2c/k<0VYZJ0:6QX@2a/K40WIfM096AT@2D
U9@00P2ZZZX04P2BTY80R8R807moO`1gMgL0N7Qh08F5Q@24Q8@0Ph>309BDU02FUYH0MgMg07emO@23
Ph<0PH610:6QX@1nOWh0UYJF0;Bd]080[Jf]00H0ZJVY09VIV@2PX:00U9BD09RHV02CTi<20:ZZZP0<
0:2PX02[Zj/0YjNW0<?3``2e]KD0WinO0;:b/P2SXj<0UYJF09>CT`2NWYh0UIFE0P2KVi/0<02QXJ40
VIVI09fMW@2HV9P0XZ:R08N7Q`2BTY80XJ6Q09^KV`2TY:@0XJ6Q0:FUY@2LW9`0][Jf0:n_[`2LW9`0
WIfM06i^KP2GUiL0VYZJ08J6QP2XZ:P0][Jf09FEU@26QXH0/k>c092@T02NWYh0[:b/096AT@2BTY80
R8R809bLW02;Rh/0SXj>08J6QP25QHD0RHV907moO`2BTY80YJFU08^;R`20P800MWIf0861P@2@T900
NWYj08^;R`80UIFE04/0Ph>308n?S`2GUiL0U9BD08F5Q@1oOgl0P82007inOP2DU9@0T92@08f=S@1i
NGT0QHF508n?S`22PX80WIfM08V9R@1WIfL0Vi^K08b<S026QXH0M7Ad08b<S022PX80Shn?06QXJ02I
VIT0QhN709FEU@2SXj<0P82008j>SP2_[jl0Vi^K08B4Q01]KFd0Shn?092@T01oOgl0SXj>07AdM02E
UID0Ng]k09FEU@2HV9P0TI6A09BDU02:RXX0TI6A07UiN@2=SHd0N7Qh08V9R@1TI6@0W9bL079bLP1k
Ng/0MGEe05UIF@23Ph<0QhN707IfMP1NGUh0Ph>30820P01gMgL0JVYZ05EEE@1]KFd0Ph>307inOP1o
Ogl0Jf][06ATI01NGUh00P1TI6@02@1gMgL0Q8B407AdM01jNWX0GEeM04];B`1TI6@0MgMg08>3P`02
08Z:RP0E07alO01fMWH0L71`06QXJ021PH40NGUi05iNGP1bLW80QXJ606YZJP1hN7P0O7al07=cL`1^
KVh0MgMg08N7Q`1^KVh0MWIf06i^KP1XJ6P0DU9B0080I6AT00D0EUIF04=3@`19BDT0<C4a02h^;P03
0000000?03Hf=P1=CDd0ATI606e]K@1OGel0Kfm_07]kN`1TI6@0LW9b07AdM01LG5`0Ogmo06][J`1l
O7`0oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@1>0?ooo`2UYJD0
LG5a096AT@2EUID0S8b<09jNWP23Ph<0Ti>C07alO027QhL0Ng]k079bLP2?Shl0UIFE0:BTY01kNg/0
QHF50820P02@T900MWIf09nOW`2ATI40VYZJ0820P02[Zj/0PX:209fMW@2ATI40R8R809NGU`2_[jl0
^[Zj08V9R@2;Rh/0NGUi07IfMP1OGel0MGEe08N7Q`24Q8@0RHV909FEU@2OWil0ZZZZ0;Rh^026QXH0
VYZJ09VIV@2SXj<0U9BD07moO`1lO7`0JVYZ075aL@1XJ6P0M7Ad065QH@1]KFd0LG5a09FEU@1nOWh0
RXZ:09BDU02ATI40JFUY07AdM020P800SXj>09FEU@2RXZ80ZZZZ092@T02KVi/0Xj>S09VIV@2?Shl0
YJFU0P2IVIT02@2FUYH0W9bL08J6QP2RXZ80[jn_0;Bd]02UYJD0UIFE09ZJVP0208b<S01209:BTP1^
KVh0M7Ad08V9R@1oOgl0Q8B408^;R`1aLG40V9RH08J6QP2JVYX0U9BD0:JVYP26QXH0Xj>S0:^[Z`2A
TI40Shn?09RHV02LW9`0Zj^[0:f][@2OWil0V9RH0<g=c@2a/K40YZJV0;Fe]@2ZZZX0b<S80;Jf]P2Z
ZZX0YJFU0;2`/02KVi/0WIfM08Z:RP2OWil0W9bL0:ZZZP2LW9`0FEUI08f=S@2XZ:P0WIfM0:6QX@2a
/K40[:b/09jNWP2HV9P0UiNG0:2PX02][Jd0WIfM09ZJVP2?Shl0YJFU08R8R02XZ:P0Xj>S0:VYZ@2f
][H0YZJV08V9R@2EUID0YZJV0P2IVIT0K`2YZJT0[jn_0;Ng]`2PX:00^[Zj0:n_[`2d];@0S8b<09ZJ
VP2;Rh/0QhN708V9R@2RXZ80UiNG09ZJVP29RHT0Vi^K07AdM01aLG40TI6A0:f][@1nOWh0X:2P071`
L021PH40ZZZZ08F5Q@2JVYX0[jn_096AT@2IVIT0SXj>07YjNP2BTY80U9BD08^;R`26QXH0RXZ:08n?
S`20P800NWYj08j>SP2UYJD0P82008j>SP2SXj<0QhN70861P@22PX80MWIf096AT@2NWYh0NWYj071`
L020P800Shn?092@T02g]kL0SXj>09:BTP27QhL0P82008>3P`1kNg/0SXj>09VIV@2RXZ80OWin08V9
R@2FUYH0Lg=c07inOP2TY:@0TY:B0:JVYP1kNg/0SHf=07=cL`2HV9P0JFUY07moO`2@T900MGEe096A
T@20P800YZJV07IfMP20P800K6a/07IfMP23Ph<0IFEU06a/K023Ph<0MGEe05]KF`1;Bd/0IFEU065Q
H@1@D500@D5105QHF01ZJVX0K6a/07UiN@1eMGD0PH61079bLP1oOgl0P82006][J`0205QHF00Q07Ui
N@1@D500LG5a07AdM01cLg<0PH6108>3P`27QhL0Lg=c06][J`1oOgl0MWIf06UYJ@1/K6`0EeMG0861
P@1bLW80Kfm_06MWI`1jNWX0@D5104Y:BP19BDT0ATI6024Q8@0U9BD0<c<c04e=C@19BDT0DU9B06MW
I`1fMWH0ATI60080KVi^00L0K6a/05YJFP1YJFT0Jf][05EEE@1KFe/0oooo00H0fMWI0@0000010=WI
f@005P3IfMT00`000000fMWI0=WIf@030=WIf@0<0?ooo`2JVYX0UIFE0::RXP2:RXX0X:2P0:VYZ@2Q
XJ40PH6109BDU02PX:00U9BD0`2GUiL0<`2RXZ80];Bd0::RXP2^[Zh0[Jf]0820P02=SHd0SXj>0:b/
[02GUiL0RHV908R8R02HV9P0O7al09NGU`1oOgl0TI6A09RHV02?Shl0WIfM07=cL`22PX80SXj>08n?
S`2XZ:P0]kNg09fMW@2=SHd0XJ6Q0:RXZ02NWYh0UiNG0;bl_02EUID0QHF5079bLP2KVi/0T92@08R8
R01fMWH0GemO04];B`17AdL0M7Ad09BDU01mOGd0UYJF09^KV`29RHT0PX:206a/K00208Z:RP0=09FE
U@2/[:`0_Kfm0:f][@2IVIT0V9RH08f=S@2SXj<0VYZJ09fMW@2d];@0VIVI0:JVYP0209:BTP0V09jN
WP2@T900Ti>C07moO`22PX80W9bL0:2PX02l_;`0Ph>308R8R01lO7`0PX:2069RHP0b<S80QhN709:B
TP2WYjL0VIVI0:NWY`2CTi<0XZ:R08>3P`1nOWh0YjNW0:2PX02d];@0ZJVY08j>SP2ATI40`L710:RX
Z02^[Zh0XJ6Q0:VYZ@2FUYH0YJFU0;Rh^02IVIT209:BTP0Y08b<S02QXJ40WIfM09RHV02KVi/0[:b/
08B4Q02FUYH0S8b<0:n_[`2DU9@0WinO0:6QX@2e]KD0Y:BT0:n_[`2[Zj/0VIVI0:FUY@2?Shl0VYZJ
0:6QX@2_[jl0Ti>C08>3P`2FUYH0Xj>S09bLW02NWYh0UYJF09^KV`2?Shl0QHF509jNWP2CTi<0RXZ:
0:j^[P2TY:@0WYjN09ZJVP2SXj<00P2WYjL03@2QXJ40V9RH07IfMP25QHD0W9bL0:2PX01eMGD0Ti>C
0:2PX02NWYh0SHf=0:VYZ@2=SHd00P24Q8@01`28R8P0T92@0:>SX`2<S8`0V9RH09JFUP2JVYX00P1Z
JVX0102@T900UYJF08b<S02LW9`20:6QX@0609VIV@2HV9P0ZJVY0:BTY024Q8@0Ti>C0P2LW9`0B`2F
UYH0TI6A09FEU@25QHD0ZJVY09NGU`2QXJ40YJFU0:6QX@2>SXh0Ng]k09^KV`2JVYX0Z:RX08n?S`1h
N7P0T92@0:6QX@1ZJVX0MgMg08j>SP2CTi<0WYjN08B4Q01iNGT0UYJF0820P01jNWX0PH6107alO02J
VYX0RHV908Z:RP25QHD0R8R807emO@2IVIT0MWIf07inOP2=SHd0Rh^;069RHP1fMWH0MGEe07]kN`1O
Gel0J6QX07IfMP1lO7`0Fe]K05EEE@1_Kfl0OGem06EUI@1NGUh0KFe]06a/K01aLG40GEeM065QH@1]
KFd0OGem07MgM`1^KVh0DE5A06IVIP1aLG40G5aL06a/K01XJ6P0NWYj06i^KP1cLg<0H61P07EeM@02
06MWI`0Q08:2PP1XJ6P0OWin07IfMP1_Kfl0E5AD05IFEP1VIVH0F5QH059BDP1;Bd/0HV9R05UIF@1?
Cdl0HF5Q030`<00o?cl0DU9B04=3@`12@T80JFUY06m_K`1WIfL0ADE506i^KP1ZJVX0J6QX05aLG01V
IVH0Kfm_04];B`1XJ6P0oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WI
f@0k0?ooo`2IVIT0R8R809RHV02?Shl0X:2P08>3P`1^KVh0Ph>308f=S@2GUiL0Ti>C09ZJVP2IVIT0
Ti>C08V9R@28R8P0VIVI092@T02RXZ80Vi^K09jNWP2WYjL0UIFE0:6QX@26QXH0Vi^K09BDU02?Shl0
GEeM07YjNP2DU9@0Ti>C069RHP1lO7`0J6QX08^;R`23Ph<0W9bL0;Fe]@2][Jd0^KVi09FEU@2a/K40
YjNW0;>c/`2VYZH0`L710;Vi^@2/[:`0QhN70::RXP1`L700Kfm_05=CD`1:BTX0E5AD06UYJ@1eMGD0
0P2;Rh/0;025QHD0Ogmo09FEU@2:RXX0TI6A08J6QP1oOgl0V9RH0:FUY@2MWId0UiNG09nOW`2GUiL0
UIFE08f=S@2LW9`0[jn_09^KV`2`/;00WIfM09ZJVP2WYjL0OWin08n?S`2=SHd0UIFE0::RXP2i^KT0
S8b<08B4Q02IVIT0WinO07MgM`2=SHd0QHF504e=C@29RHT0RXZ:0;Bd]02HV9P0WIfM0:>SX`2FUYH0
VYZJ0P2RXZ809`2][Jd0VYZJ08f=S@2d];@0ZZZZ0::RXP2m_Kd0V9RH0:ZZZP2[Zj/0/[:b0;jn_P2R
XZ80ZJVY0;bl_02NWYh0/[:b0:>SX`2EUID0^k^k0:FUY@2JVYX0VIVI08J6QP2UYJD0[Jf]0;fm_@2K
Vi/0UIFE0:6QX@2KVi/0[Zj^0:2PX02@T900^k^k0:>SX`2OWil0^;Rh09:BTP0209NGU`1X09nOW`2`
/;00Xj>S09FEU@2WYjL0W9bL096AT@2OWil0UIFE07]kN`1nOWh0TY:B09fMW@2KVi/0/K6a0:FUY@2<
S8`0Z:RX0861P@2FUYH0Ogmo09ZJVP2ATI40T92@09FEU@1lO7`0ZJVY06a/K02;Rh/0U9BD0:6QX@2A
TI40QXJ60:FUY@1iNGT0SHf=07alO02MWId0UiNG0820P02VYZH0UiNG08f=S@2MWId0VYZJ09FEU@2V
YZH0O7al09>CT`2HV9P0Ogmo0:2PX02BTY80ZZZZ08>3P`1gMgL0Ph>307alO02=SHd0UIFE09ZJVP2Y
ZJT0^[Zj09bLW025QHD0Kfm_08F5Q@2IVIT0XJ6Q0:n_[`22PX80VYZJ09^KV`28R8P0LG5a09NGU`2C
Ti<0UIFE092@T021PH40P8200:JVYP2LW9`0VYZJ09RHV01lO7`0WIfM09VIV@21PH40I6AT096AT@2?
Shl0X:2P08j>SP1fMWH0O7al08Z:RP1kNg/0M7Ad07inOP1cLg<0G5aL08B4Q01^KVh206e]K@0A071`
L01QHF40P82006i^KP1TI6@0JFUY06MWI`1YJFT0H61P05aLG01fMWH0JFUY061PH01aLG40M7Ad079b
LP1aLG400P1]KFd0:@1gMgL0MWIf071`L020P800M7Ad07=cL`1`L700QHF507QhN01?Cdl0M7Ad07Ee
M@1cLg<0NWYj0861P@1HF5P0IFEU05YJFP1KFe/0Jf][06YZJP1lO7`0Hf=S05UIF@1NGUh0@T9204Q8
B01OGel0FUYJ06YZJP1gMgL0G5aL06QXJ014A4@0FEUI05aLG01cLg<0K6a/079bLP1DE5@0oooo00H0
fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@060?ooo`2QXJ40Ng]k08Z:RP21
PH40QXJ60P21PH407P2ATI40QhN708f=S@2<S8`0QXJ608f=S@2CTi<0UIFE07inOP2BTY80Shn?09jN
WP1iNGT0Y:BT0:JVYP2ZZZX0X:2P0;Ng]`27QhL0TY:B08n?S`2CTi<0UiNG08F5Q@2ATI40NGUi06a/
K024Q8@0TI6A0:6QX@80YJFU02h0WinO0:b/[02LW9`0WYjN08R8R02_[jl0[Zj^0;Bd]02`/;00^KVi
09ZJVP26QXH0YjNW07alO01/K6`0Cdm?04I6AP1FEUH0O7al07moO`25QHD0S8b<0:2PX022PX80TI6A
07inOP1`L700Cdm?09VIV@2TY:@0YZJV09:BTP2QXJ40/[:b08V9R@2EUID0UiNG09BDU02PX:00U9BD
09fMW@2DU9@0T92@09BDU02FUYH0VIVI0P2QXJ40A`2EUID0_kno0;:b/P2`/;00XJ6Q09BDU026QXH0
QhN709ZJVP2WYjL0XZ:R0;2`/02KVi/0Xj>S09fMW@1oOgl0Ti>C08V9R@1ZJVX0YjNW09FEU@2CTi<0
UYJF09VIV@2PX:00Z:RX096AT@2YZJT0X:2P0:RXZ02ZZZX0W9bL0:ZZZP2IVIT0_Kfm0:ZZZP2g]kL0
/[:b0:^[Z`2BTY80YJFU0:6QX@2`/;00Xj>S092@T02EUID0][Jf0;Rh^02`/;00Y:BT09nOW`2QXJ40
XZ:R0:6QX@2TY:@0SXj>0:j^[P2RXZ80Z:RX0:2PX023Ph<0Z:RX09^KV`2SXj<0Y:BT09VIV@2=SHd0
X:2P06m_K`20P800XJ6Q0080Z:RX09T0YjNW0:2PX02^[Zh0SHf=09BDU02[Zj/0UYJF07QhN02;Rh/0
SHf=092@T01oOgl0WYjN09^KV`2LW9`0UIFE0::RXP26QXH0Y:BT0;Jf]P2GUiL0NWYj09^KV`2@T900
RHV906EUI@23Ph<0RHV909nOW`2PX:00RHV909jNWP2HV9P0TI6A08N7Q`2UYJD0SXj>08Z:RP2ATI40
W9bL0:6QX@22PX80O7al092@T01`L700WIfM0:n_[`2FUYH0UIFE0:j^[P2NWYh0UiNG09bLW01nOWh0
TY:B09JFUP2?Shl0VYZJ09RHV02FUYH0S8b<08f=S@1^KVh0TI6A07moO`2UYJD0UIFE09fMW@27QhL0
QXJ607EeM@21PH40LG5a09:BTP23Ph<0T92@08j>SP2FUYH0MgMg09FEU@24Q8@0Ogmo07UiN@1TI6@0
NGUi08:2PP1kNg/0P82008j>SP1WIfL0MWIf05IFEP2@T900KVi^07QhN01dM7@0L71`06YZJP1VIVH0
PH6108V9R@1oOgl0PH6107QhN023Ph<0MWIf07AdM01iNGT0Ng]k05aLG01XJ6P0JVYZ08>3P`1gMgL0
Hf=S06QXJ01BDU80P82006MWI`2CTi<0GEeM07=cL`1SHf<0EeMG05QHF01cLg<0I6AT061PH01UIFD0
FEUI05EEE@1VIVH0Lg=c069RHP1:BTX0F5QH06a/K01TI6@0ADE504U9B@1PH600LW9b07=cL`1SHf<0
H61P05iNGP1nOWh0J6QX06YZJP1RHV80Fe]K06EUI@3oool01P3IfMT100000040fMWI000F0=WIf@03
0000003IfMT0fMWI00<0fMWI0440oooo09^KV`2@T900VIVI07emO@1RHV80Zj^[079bLP1cLg<0S8b<
09JFUP2JVYX0PH6108n?S`2CTi<0U9BD08B4Q02PX:00Ph>309FEU@1mOGd0Rh^;08J6QP2>SXh0V9RH
08n?S`2XZ:P0`l?30:2PX01iNGT0KVi^08R8R02NWYh0TI6A09NGU`2WYjL0W9bL0;6a/@2o_kl0YjNW
09nOW`2XZ:P0UYJF0:RXZ02/[:`0/K6a09ZJVP2SXj<0/;2`0:j^[P2RXZ80/[:b0;Bd]02;Rh/0MgMg
05=CD`1TI6@0CTi>05iNGP1iNGT0QXJ607moO`2KVi/0RHV907IfMP0207alO01F08J6QP25QHD0YJFU
0=GEe@2XZ:P0VYZJ0:>SX`2MWId0YZJV08f=S@29RHT0Y:BT08R8R02KVi/0VIVI08>3P`2CTi<0RXZ:
096AT@2m_Kd0SXj>0:6QX@2PX:00Vi^K0:JVYP2XZ:P0XZ:R09BDU02RXZ80Ti>C09nOW`2ATI40UiNG
08n?S`2KVi/0VIVI07MgM`1lO7`0RXZ:0820P02=SHd0WinO09VIV@2`/;00YZJV09>CT`2EUID0Ph>3
0;Bd]02_[jl0Vi^K0:JVYP2JVYX0ZJVY09JFUP2RXZ80Shn?09:BTP29RHT0U9BD09VIV@2WYjL0Rh^;
08f=S@2SXj<0R8R80:FUY@2o_kl0YjNW09^KV`2f][H0WinO0:2PX02UYJD0V9RH09NGU`2QXJ40Zj^[
0;6a/@2/[:`0R8R809RHV02LW9`0M7Ad08f=S@1mOGd209JFUP0A09ZJVP20P800T92@0861P@2LW9`0
SXj>09NGU`2LW9`0/[:b0:>SX`2NWYh0WinO09fMW@27QhL0QXJ609jNWP2DU9@00P1eMGD0F024Q8@0
PH6107inOP26QXH0XJ6Q09^KV`2>SXh0TI6A08b<S026QXH0Rh^;09^KV`2=SHd0VIVI07IfMP2HV9P0
P82008n?S`1gMgL0P82008J6QP2UYJD0P82009jNWP2YZJT0UiNG0:BTY02RXZ80Ph>309JFUP2JVYX0
LG5a09RHV02FUYH0Ng]k0:NWY`25QHD0V9RH0::RXP24Q8@0ZJVY079bLP24Q8@0P82009nOW`2][Jd0
WYjN08>3P`1gMgL0[Jf]08b<S02BTY80RXZ:092@T02HV9P0U9BD08V9R@2FUYH0Ti>C08B4Q02DU9@0
MgMg069RHP21PH40OWin09BDU01XJ6P0Ti>C05mOG`1mOGd0U9BD075aL@27QhL0Ti>C06][J`1eMGD0
Ng]k065QH@1TI6@0JFUY06a/K01eMGD0P82007QhN01cLg<0HF5Q079bLP1_Kfl208N7Q`0b06a/K025
QHD0KVi^07EeM@1cLg<0HV9R07MgM`1fMWH0KVi^06MWI`1bLW80BDU906UYJ@1nOWh0Hf=S05eMG@1a
LG40FEUI06][J`1LG5`0LG5a07inOP1`L700MGEe05MGE`1bLW80ADE507YjNP1@D500Hf=S05]KF`1F
EUH0JFUY05YJFP1HF5P0DU9B071`L01PH600Ogmo05iNGP1KFe/0FUYJ06UYJ@1OGel0EEEE06ATI01U
IFD0IfMW06EUI@3oool60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT03`3o
ool0WIfM08f=S@1_Kfl0N7Qh08R8R025QHD0U9BD07moO`2:RXX0NGUi09JFUP2DU9@0S8b<09:BTP02
09JFUP0O08f=S@2LW9`0WYjN07moO`2KVi/0W9bL09NGU`2_[jl0YjNW0;Fe]@2EUID0VIVI0:BTY02>
SXh0WYjN08R8R01]KFd0WYjN0:VYZ@2i^KT0WIfM07emO@2BTY80XZ:R09BDU02KVi/0^;Rh0;Jf]P2V
YZH0^k^k096AT@020:j^[P1J0;>c/`2KVi/0/[:b09RHV01cLg<0Fe]K0410@00d=3@0O7al07EeM@28
R8P0QXJ608N7Q`1RHV80Q8B407moO`1XJ6P0PX:208>3P`2][Jd0`L7108B4Q02^[Zh0/k>c09BDU02?
Shl0W9bL08Z:RP2LW9`0Y:BT08f=S@2?Shl0Xj>S09FEU@2XZ:P0XZ:R096AT@2XZ:P0RHV90;>c/`2H
V9P0Y:BT09>CT`2@T900U9BD08b<S02][Jd0X:2P0::RXP2XZ:P0TY:B08:2PP2KVi/0/k>c08f=S@2A
TI40WinO0:VYZ@2o_kl0SXj>09BDU02UYJD0ZZZZ0:6QX@2YZJT0^;Rh0::RXP37alL0T92@09^KV`2j
^[X0XZ:R09BDU02PX:00YjNW09ZJVP2SXj<0YZJV0:ZZZP2][Jd0[:b/0:^[Z`2b/[80ZZZZ07YjNP2L
W9`0UiNG09JFUP2LW9`0Vi^K0P2MWId01@2:RXX0V9RH0:b/[02JVYX0^k^k0080W9bL02P0UIFE09bL
W02VYZH0Y:BT09jNWP2OWil0S8b<08R8R022PX80NGUi08^;R`2IVIT0UIFE092@T02UYJD0O7al092@
T024Q8@0Rh^;0:ZZZP2PX:00Ti>C08R8R02:RXX0LG5a09BDU02PX:00T92@09:BTP2EUID0/;2`08:2
PP2LW9`0L71`09bLW01lO7`0TI6A07inOP2MWId0V9RH0P23Ph<0;`2:RXX0UiNG0:6QX@2_[jl0QXJ6
0:2PX02@T900SHf=08Z:RP2SXj<0Shn?09FEU@26QXH0UIFE08f=S@20P800SHf=08:2PP2>SXh0TY:B
08f=S@2HV9P0WinO08N7Q`2ATI40UiNG0::RXP21PH40OWin06YZJP2NWYh0Xj>S07]kN`2DU9@0Shn?
08R8R024Q8@0XJ6Q09:BTP2NWYh0RXZ:08>3P`2EUID0Rh^;08b<S02CTi<0Shn?0080PH6102X0Q8B4
08V9R@24Q8@0Q8B4092@T02<S8`0Ph>306][J`24Q8@0Lg=c07EeM@1kNg/0OWin06IVIP1WIfL0GEeM
06e]K@2<S8`0NWYj07=cL`1ADE40HV9R07IfMP26QXH0UIFE08>3P`1VIVH0O7al08>3P`29RHT0Lg=c
05MGE`1mOGd0NGUi075aL@1FEUH0GemO06ATI01bLW80De=C069RHP1UIFD206m_K`0805QHF01PH600
MGEe07alO01JFUX0E5AD06=SH`1bLW8206=SH`0<06ATI01ADE40J6QX03@d=011@D40R8R806YZJP1P
H600L71`0861P@1SHf<0GEeM0P1QHF401P10@400JVYZ05IFEP1bLW80LG5a0?ooo`H0fMWI0@000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0L0?ooo`1oOgl0S8b<08b<S01oOgl0M7Ad08f=
S@2DU9@0T92@08J6QP2KVi/0QXJ608j>SP2SXj<0UYJF09>CT`2@T900/;2`07UiN@2ATI40RXZ:0:6Q
X@2XZ:P0VYZJ0;6a/@2WYjL0[Jf]09NGU`80WYjN01T0SXj>09:BTP26QXH0X:2P0;6a/@2PX:00QHF5
08j>SP22PX80R8R80:NWY`2h^;P0Vi^K0:ZZZP26QXH0S8b<0:2PX02FUYH0]kNg0<?3``2UYJD0ZZZZ
0:b/[02MWId0Shn?0080LG5a00`0Kfm_06ATI02BTY80MGEe08B4Q01hN7P0Rh^;07EeM@1]KFd0O7al
0820P02>SXh20;Ng]`0509ZJVP2^[Zh0Vi^K0:NWY`2DU9@00P26QXH08`2][Jd0UiNG09fMW@2?Shl0
Q8B408n?S`2ATI40Ng]k08V9R@2b/[80U9BD0;Zj^P35aLD0[:b/08N7Q`2PX:00WinO0::RXP2VYZH0
Vi^K07]kN`2:RXX0ZJVY08^;R`2=SHd0T92@07AdM02a/K40WYjN0:BTY02WYjL0PX:208J6QP2WYjL0
/K6a0080VYZJ02`0SXj>0:2PX02_[jl0VYZJ09fMW@2SXj<0^[Zj0:>SX`2XZ:P0SHf=096AT@2MWId0
U9BD0:JVYP2UYJD0Z:RX09ZJVP2b/[80VYZJ08n?S`2EUID0UYJF09BDU02WYjL0WYjN08^;R`2YZJT0
[Zj^0:^[Z`2VYZH0/[:b0:b/[02WYjL0[:b/0:NWY`2LW9`0Zj^[0:JVYP2MWId0Zj^[08b<S02BTY80
U9BD09NGU`80X:2P05P0Vi^K07]kN`2<S8`0V9RH09VIV@2QXJ40RHV909jNWP2MWId0UYJF08N7Q`2C
Ti<0JVYZ08b<S026QXH0RXZ:09bLW02`/;00YJFU09:BTP27QhL0S8b<0:>SX`2>SXh0RXZ:08b<S01h
N7P0X:2P09VIV@2?Shl0UYJF0:6QX@2DU9@0W9bL0:2PX02CTi<0UiNG09BDU02MWId0T92@08:2PP2?
Shl0OGem09nOW`1lO7`0QhN707MgM`1dM7@0R8R809JFUP2TY:@0TI6A08F5Q@1oOgl0RHV9096AT@1o
Ogl0[:b/08F5Q@2;Rh/0UIFE09RHV02FUYH0RXZ:09RHV026QXH0UYJF09VIV@1iNGT0O7al07MgM`2?
Shl0RXZ:07alO022PX80UiNG0820P01eMGD0OWin08N7Q`1mOGd0Ti>C0820P01oOgl0IVIV08:2PP2=
SHd0P8200P1nOWh09`1]KFd0K6a/06][J`1cLg<0JVYZ07UiN@2CTi<0L71`08f=S@1^KVh0JFUY075a
L@1lO7`0P82006MWI`1dM7@0Shn?06e]K@1bLW80Lg=c08>3P`1XJ6P0OWin06][J`1=CDd0O7al079b
LP21PH40I6AT08F5Q@1WIfL0MGEe06IVIP1_Kfl0MgMg06][J`1YJFT0MgMg05MGE`0206YZJP0F03De
=@1SHf<00000034a<@1_Kfl0GemO05QHF01fMWH0OWin06YZJP12@T80G5aL05QHF01VIVH0HV9R055A
D@1ZJVX0NGUi075aL@1cLg<0CDe=0?ooo`H0fMWI0@0000010=WIf@005P3IfMT2000000@0fMWI0300
oooo08R8R024Q8@0OGem0:>SX`1hN7P0QhN709JFUP2TY:@0T92@08R8R02FUYH0Kfm_09JFUP2WYjL0
Vi^K09ZJVP2?Shl0YZJV09RHV02FUYH0WYjN0;Fe]@2SXj<0XZ:R09jNWP2PX:00M7Ad0:BTY02FUYH0
VYZJ0:FUY@2c/k<0XZ:R0:b/[02f][H0/K6a07moO`1kNg/0UIFE0;Jf]P2GUiL0[Jf]0;>c/`2:RXX0
UiNG09fMW@2PX:0208V9R@0o0:n_[`2c/k<0VYZJ09>CT`2IVIT0?clo05=CD`23Ph<0PH6106QXJ02<
S8`0Kfm_08Z:RP2GUiL0KFe]07QhN029RHT0O7al09JFUP2i^KT0/[:b09bLW02d];@0/k>c0:ZZZP2E
UID0YJFU09JFUP2QXJ40ZJVY09jNWP2PX:00QHF50:6QX@2:RXX0V9RH0:n_[`2HV9P0X:2P09jNWP2F
UYH0YJFU0:b/[02LW9`0[Jf]09JFUP2=SHd0YZJV08b<S02YZJT0V9RH08Z:RP2=SHd0P82007inOP2f
][H0[jn_0:^[Z`2a/K40];Bd08b<S01aLG40XJ6Q0080YZJV01D0[Jf]0;no_`2KVi/0[jn_08f=S@2V
YZH0Xj>S0:^[Z`2XZ:P0Xj>S0:JVYP2FUYH0_;bl0:FUY@2^[Zh0Vi^K0:^[Z`2RXZ80YjNW09^KV`1j
NWX00P2^[Zh0302/[:`0[Jf]09^KV`2SXj<0[Jf]0:VYZ@2c/k<0];Bd0:n_[`2PX:00ZZZZ0;Jf]P80
UiNG00h0N7Qh08j>SP2@T900SXj>0:^[Z`2OWil0YjNW09nOW`2LW9`0WIfM08j>SP2/[:`0Vi^K09bL
W080U9BD00/0QhN708R8R02>SXh0R8R807UiN@2UYJD0Ph>308^;R`29RHT0K6a/09NGU`0207inOP1]
08N7Q`1WIfL0XJ6Q09fMW@2QXJ40NWYj08j>SP2FUYH0T92@09ZJVP2<S8`0LW9b08b<S02JVYX0T92@
0:BTY02[Zj/0/K6a0:^[Z`2JVYX0QHF50:BTY029RHT0PX:208^;R`23Ph<0QhN70::RXP2DU9@0V9RH
08f=S@2?Shl0Ti>C09BDU025QHD0RHV909FEU@27QhL0OWin09:BTP2FUYH0Ph>309BDU02OWil0UiNG
06i^KP1nOWh0S8b<06m_K`23Ph<0RXZ:08V9R@2:RXX0SXj>0:>SX`2:RXX0PX:208B4Q01oOgl0KVi^
08f=S@1cLg<0M7Ad07YjNP25QHD0N7Qh07MgM`28R8P0T92@06UYJ@1PH600Hf=S08j>SP1^KVh0F5QH
04Q8B01HF5P0Ogmo06i^KP1_Kfl0JVYZ092@T022PX80OWin07alO01]KFd0MgMg07AdM023Ph<0MWIf
071`L01MGEd0Kfm_06i^KP1TI6@0HF5Q03Ph>01jNWX0MGEe07IfMP1mOGd0Lg=c04M7A`1bLW80LG5a
08:2PP1FEUH0N7Qh0820P002075aL@08059BDP1LG5`0IFEU04i>CP1HF5P0IfMW05QHF01EEED206QX
J00707=cL`1dM7@0MWIf05mOG`1^KVh0MWIf06a/K00206=SH`0304A4A01>CTh0oooo00D0fMWI0P00
00010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@1I0?ooo`2OWil0VIVI09ZJVP2UYJD0T92@
0:2PX02FUYH0SXj>09VIV@2HV9P0WIfM09RHV02?Shl0MWIf07QhN023Ph<0TY:B08b<S02ATI40WinO
0:JVYP2/[:`0V9RH0:VYZ@2c/k<0TI6A0:VYZ@1jNWX0_[jn09fMW@2ZZZX0[Zj^0:6QX@23Ph<0Ng]k
08n?S`2BTY80W9bL09NGU`28R8P0RXZ:08:2PP24Q8@0QhN709bLW02RXZ80R8R808>3P`2LW9`0[:b/
0:>SX`2^[Zh0Rh^;06YZJP2=SHd0RHV908J6QP1`L700UIFE08Z:RP2GUiL0R8R80861P@1NGUh0Ogmo
07inOP2ATI40YZJV0:NWY`2a/K40Xj>S0:JVYP2IVIT0/[:b08n?S`2XZ:P0Shn?0:6QX@2PX:00S8b<
08f=S@2:RXX0TI6A08B4Q01kNg/0[Zj^0:FUY@2:RXX00P2`/;003@2BTY80ZZZZ0861P@2QXJ40X:2P
08F5Q@2DU9@0YJFU0:JVYP2e]KD0];Bd08J6QP2ATI400P2;Rh/0RP2IVIT0Xj>S0:JVYP2HV9P0OWin
08j>SP2DU9@0V9RH0:2PX02KVi/0W9bL08^;R`2[Zj/0WinO07]kN`2_[jl0Zj^[0:b/[02^[Zh0WinO
09jNWP2RXZ80YjNW0:6QX@2KVi/0WYjN0:n_[`2TY:@0Shn?09fMW@2c/k<0UYJF0:2PX02h^;P0/[:b
0:2PX02d];@0[:b/09NGU`2c/k<0Zj^[0:b/[02f][H0Z:RX09^KV`2IVIT0W9bL09fMW@2b/[80X:2P
09jNWP2PX:00Zj^[0:NWY`2JVYX0XJ6Q0:2PX02CTi<0WYjN08j>SP2QXJ40WIfM08n?S`2CTi<0MGEe
0:BTY02>SXh0WYjN07=cL`29RHT0UiNG07inOP2MWId0VYZJ08b<S02@T900TY:B08j>SP2LW9`0SXj>
08>3P`1hN7P0NGUi08:2PP1PH600M7Ad09JFUP26QXH0RHV909NGU`22PX80Zj^[0:>SX`2RXZ80RHV9
07emO@2LW9`0Ti>C09NGU`29RHT0V9RH079bLP24Q8@0TY:B0::RXP2BTY80YZJV08F5Q@26QXH0VYZJ
09jNWP2JVYX0Rh^;09>CT`2@T900YZJV08F5Q@1nOWh0Vi^K09>CT`28R8P0WIfM08N7Q`2BTY80WIfM
08Z:RP2@T900UiNG07EeM@29RHT0PX:208F5Q@1mOGd0VIVI08B4Q02:RXX0Jf][07alO080QhN701l0
OWin07moO`24Q8@0PH6106IVIP1jNWX0GemO08:2PP1IFET0Kfm_07=cL`1eMGD0KVi^06m_K`1dM7@0
PH6107MgM`1lO7`0S8b<08V9R@1_Kfl0OGem06IVIP29RHT0MWIf07=cL`1QHF40Ogmo06ATI01QHF40
JVYZ0080Jf][02<0GUiN06UYJ@1OGel0JFUY065QH@1OGel0Lg=c06][J`1WIfL0NWYj05UIF@1UIFD0
HF5Q06YZJP1OGel0BTY:05QHF01XJ6P0HF5Q05eMG@1UIFD0Fe]K06QXJ01QHF40GEeM06YZJP1OGel0
M7Ad06QXJ01aLG40Lg=c05MGE`1RHV80GUiN0?ooo`060=WIf@4000000@3IfMT001H0fMWI00<00000
0=WIf@3IfMT00`3IfMT0G`3oool0TI6A09JFUP2RXZ80UYJF07QhN02@T900VIVI0861P@1gMgL0XJ6Q
09FEU@25QHD0TI6A08j>SP24Q8@0Ng]k09nOW`25QHD0U9BD092@T02FUYH0WYjN0:f][@2FUYH0L71`
09>CT`2GUiL0]kNg0820P023Ph<0O7al09VIV@2?Shl0VYZJ0:RXZ02PX:00RXZ:071`L02WYjL0TY:B
092@T023Ph<0RHV909bLW020P800WIfM06MWI`2YZJT0WIfM09BDU02RXZ80Y:BT0861P@1LG5`0NWYj
07]kN`20P800QhN709JFUP2HV9P0WIfM09FEU@22PX80N7Qh06YZJP1/K6`0VYZJ0:f][@37alL0[:b/
0:f][@2k^k/0YZJV09:BTP2OWil0P8200:f][@2;Rh/0WinO08N7Q`2NWYh0VIVI096AT@2JVYX0W9bL
09>CT`2IVIT0XJ6Q0;:b/P2FUYH0OGem071`L01kNg/0LG5a0080Ph>301<0Q8B407moO`2@T900Zj^[
09JFUP1`L700TI6A09VIV@2LW9`0_[jn0:j^[P2EUID0SXj>09ZJVP2RXZ80Zj^[0:n_[`2j^[X0[Jf]
0080XJ6Q00/0Y:BT0:>SX`2@T900S8b<0:FUY@2XZ:P0[Zj^0;Rh^01kNg/0WIfM09^KV`020:ZZZP0F
0;2`/02YZJT0[Jf]09nOW`2c/k<0[Zj^0:RXZ02DU9@0WYjN0:b/[02MWId0UIFE0;Fe]@2TY:@0Vi^K
0:^[Z`2XZ:P0YZJV0:NWY`2GUiL0Vi^K0:JVYP80Xj>S05X0[jn_09fMW@2c/k<0/;2`08V9R@2GUiL0
TI6A08F5Q@21PH40Xj>S08Z:RP2BTY80S8b<09jNWP2LW9`0KVi^08F5Q@2MWId0Shn?0:2PX02?Shl0
JVYZ07alO02LW9`0QhN7061PH021PH40L71`08j>SP2=SHd0UIFE08J6QP2JVYX0YJFU0;bl_02>SXh0
T92@08F5Q@22PX80Vi^K0:2PX022PX80VYZJ09NGU`21PH40Shn?08V9R@1oOgl0WinO0:j^[P2EUID0
QXJ609BDU02CTi<0U9BD08V9R@2@T900U9BD09>CT`2PX:00O7al06a/K021PH40Z:RX0:^[Z`25QHD0
RXZ:08>3P`26QXH0W9bL09NGU`2@T900VYZJ08f=S@2DU9@0Q8B409:BTP2=SHd0NWYj07]kN`22PX80
LG5a0:2PX02=SHd0RXZ:07UiN@1cLg<0Q8B408:2PP23Ph<206e]K@1307QhN022PX80R8R807IfMP1W
IfL0JVYZ079bLP1TI6@0KFe]061PH01gMgL0LG5a07AdM01YJFT0OWin05aLG01ZJVX0IVIV07IfMP1g
MgL0Hf=S07IfMP1eMGD0L71`06UYJ@2;Rh/0MGEe07AdM01]KFd0E5AD06EUI@1_Kfl0PH61065QH@1R
HV80K6a/07MgM`1IFET0R8R8069RHP1mOGd0NWYj03Ti>@1<C4`0E5AD071`L01_Kfl0Rh^;06m_K`1M
GEd0DU9B05EEE@1lO7`0GEeM06][J`1:BTX0Lg=c05ADE01kNg/0NGUi06QXJ01LG5`0JVYZ04e=C@17
AdL0I6AT0?ooo`060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT07P3oool0
RHV908:2PP27QhL0YjNW09BDU02CTi<0RXZ:09FEU@2QXJ40YJFU08n?S`28R8P0UYJF08B4Q02MWId0
RXZ:06m_K`2VYZH0VYZJ08N7Q`22PX80MGEe08^;R`2<S8`0VIVI0820P02=SHd0Shn?0::RXP80U9BD
03X0Xj>S0:ZZZP2:RXX0Xj>S0:FUY@2i^KT0Q8B409>CT`2>SXh0TI6A09>CT`22PX80UYJF0:BTY02A
TI40Xj>S07QhN02>SXh0Vi^K09NGU`2a/K40OWin08F5Q@1`L700OGem09ZJVP2>SXh0Shn?0:>SX`2[
Zj/0Ph>3079bLP1TI6@0O7al07IfMP2;Rh/0[:b/0;jn_P2j^[X0YJFU09BDU02^[Zh0Z:RX0:VYZ@2>
SXh0Vi^K09jNWP2ZZZX0TI6A0:>SX`2>SXh0XZ:R0;Rh^02BTY80WYjN09RHV026QXH0U9BD0P1fMWH0
Q01VIVH0GUiN07QhN01EEED0HV9R06][J`1gMgL0[Jf]0:RXZ02j^[X0Rh^;09^KV`2<S8`0X:2P09fM
W@2BTY80Rh^;09NGU`1eMGD0TI6A0;Bd]02WYjL0]KFe0:^[Z`2PX:00UYJF09jNWP1iNGT0SHf=09nO
W`2XZ:P0XJ6Q0:b/[02^[Zh0/K6a0;Jf]P2KVi/0[:b/0;bl_02/[:`0[Jf]0;:b/P2HV9P0[jn_0;Jf
]P2SXj<0/k>c09VIV@2c/k<0/[:b09VIV@2PX:00^[Zj0:BTY02^[Zh0_;bl0;:b/P2NWYh0/K6a0:n_
[`2GUiL0WIfM0:f][@2XZ:P0WinO0:6QX@2ATI40NGUi09BDU02HV9P0VYZJ0:>SX`2HV9P0UYJF0:ZZ
ZP2VYZH0XJ6Q08F5Q@2:RXX0CTi>09FEU@1mOGd0O7al08f=S@1jNWX0KVi^08f=S@1mOGd0PH6107al
O01]KFd0ZJVY09VIV@2<S8`0RHV908b<S02KVi/0VYZJ0;>c/`2d];@0ZZZZ08J6QP2^[Zh0RXZ:09ZJ
VP2=SHd0PX:208n?S`2PX:00OGem08f=S@2@T900UYJF08f=S@29RHT0RXZ:09JFUP25QHD0QhN708:2
PP2<S8`0OGem08J6QP2EUID0];Bd09^KV`20P800QXJ607emO@2MWId0L71`09FEU@<0S8b<00L0RHV9
09VIV@1`L700Rh^;08:2PP27QhL0OGem0080Ng]k02X0Lg=c08N7Q`1bLW80V9RH08b<S022PX80LG5a
07MgM`1`L700Q8B406e]K@1fMWH0EeMG07YjNP1ADE40Lg=c08>3P`1`L700MWIf06e]K@1KFe/0IFEU
06i^KP1kNg/0MWIf07YjNP20P800Ng]k06UYJ@22PX80Q8B4069RHP1jNWX0P82007AdM01bLW80H61P
07EeM@1EEED0Jf][07EeM@1HF5P206QXJ00R0820P01XJ6P0HF5Q071`L01SHf<0Kfm_05ADE01VIVH0
GUiN06e]K@1CDe<0Cdm?06i^KP2_[jl0GemO06=SH`1VIVH0EeMG06ATI01IFET0Fe]K08>3P`1LG5`0
Jf][06i^KP1VIVH0Cdm?06][J`1fMWH0JFUY05EEE@1/K6`0Jf][0?ooo`H0fMWI0@0000010=WIf@00
5P3IfMT00`000000fMWI0=WIf@030=WIf@1h0?ooo`2;Rh/0PH6109NGU`1mOGd0WinO0861P@2EUID0
WYjN09NGU`2DU9@0LW9b08>3P`2HV9P0QHF508>3P`2FUYH0P82009NGU`1aLG40UYJF09^KV`2=SHd0
NGUi08B4Q02CTi<0V9RH08V9R@2IVIT0Shn?09BDU02<S8`0WYjN09ZJVP2RXZ80U9BD08b<S022PX80
S8b<07YjNP1kNg/0SXj>07IfMP2IVIT0Rh^;09JFUP2?Shl0TY:B09>CT`2ATI40RHV909>CT`2IVIT0
QXJ6079bLP1^KVh0RXZ:08J6QP2LW9`0[Jf]09JFUP2CTi<0TY:B06ATI01jNWX0OWin07alO02KVi/0
b<S80:NWY`2JVYX0^;Rh09fMW@2`/;00^k^k09VIV@1jNWX0Ti>C06i^KP2EUID0[:b/0;>c/`2HV9P0
[Jf]09ZJVP24Q8@0YJFU08R8R01oOgl0H61P06QXJ018B4P0D51@075aL@1>CTh0Jf][04=3@`15ADD0
MGEe06][J`23Ph<0Xj>S0:RXZ02@T900SHf=0::RXP2LW9`0Xj>S09NGU`22PX80P8200:n_[`2=SHd0
WinO08V9R@1lO7`0YjNW08F5Q@2MWId0XZ:R0P2QXJ401@2LW9`0SHf=09^KV`2_[jl0SXj>0080Ti>C
00H0ZJVY0:NWY`2/[:`0[Zj^0:b/[02QXJ420:>SX`0<0:j^[P2HV9P0Z:RX08b<S02/[:`0[Jf]09NG
U`2RXZ80SHf=09bLW02NWYh0_Kfm0P2_[jl0B@2EUID0[:b/08B4Q02_[jl0V9RH09jNWP21PH40VYZJ
0:ZZZP2MWId0V9RH08J6QP1kNg/0Ti>C09ZJVP2QXJ40Kfm_08R8R02=SHd0Vi^K08J6QP23Ph<0R8R8
08^;R`2DU9@0TY:B05mOG`2FUYH0SHf=08F5Q@2;Rh/0SXj>092@T02:RXX0VIVI0:VYZ@2VYZH0NGUi
09NGU`22PX80X:2P08f=S@2:RXX0UiNG0:2PX02MWId0W9bL0:n_[`2EUID0Rh^;08j>SP1`L700FUYJ
08b<S02>SXh0S8b<08Z:RP1eMGD0Rh^;08b<S01iNGT0RXZ:09FEU@2YZJT0[Zj^096AT@1kNg/0S8b<
09RHV027QhL0U9BD07MgM`27QhL00P2@T9005`1oOgl0WIfM0861P@1XJ6P0NWYj08^;R`2CTi<0Ph>3
07=cL`1eMGD0RXZ:07YjNP2KVi/0OGem09:BTP1gMgL0L71`06QXJ020P800UIFE071`L01gMgL0N7Qh
0080OWin03l0NWYj08R8R01CDe<0GEeM07AdM01[Jf/0Ogmo075aL@1VIVH0SHf=07UiN@23Ph<0HF5Q
07emO@1XJ6P0LG5a07MgM`1TI6@0LW9b07=cL`1MGEd0GUiN04m?C`1[Jf/0Hf=S05]KF`22PX80OGem
06m_K`1NGUh0MWIf06ATI01HF5P0GEeM069RHP1WIfL0LW9b06EUI@1dM7@0MgMg055AD@1hN7P0EUIF
06MWI`1dM7@0J6QX05mOG`1SHf<0DE5A06i^KP1GEeL0MWIf05iNGP1EEED0MWIf07emO@1DE5@0Jf][
04=3@`1XJ6P0IFEU04i>CP3oool01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0
fMWI0240oooo09FEU@2=SHd0XJ6Q08:2PP2HV9P0VIVI096AT@2OWil0VIVI08V9R@2=SHd0SXj>08b<
S02SXj<0Vi^K08n?S`2NWYh0Shn?09JFUP2?Shl0Z:RX0:BTY02BTY80Rh^;08j>SP1fMWH0TY:B08b<
S01nOWh0LW9b09VIV@2GUiL00`2CTi<0I@26QXH0SHf=08f=S@27QhL0R8R8065QH@2RXZ80YZJV0;2`
/02OWil0/k>c0:2PX02WYjL0Q8B40:^[Z`2HV9P0S8b<0861P@1kNg/0QHF506i^KP2KVi/0[:b/08j>
SP2MWId0YZJV09^KV`1mOGd0NGUi05mOG`1kNg/0/k>c0;Bd]02^[Zh0_;bl0:n_[`2a/K40Shn?0;Ng
]`2YZJT0YZJV0;2`/02KVi/0/k>c0<K6aP2YZJT0YZJV09nOW`2RXZ80/k>c09:BTP28R8P0MGEe06AT
I01GEeL0MgMg069RHP1ZJVX0MgMg06][J`1SHf<0DE5A04Y:BP1OGel0QXJ608>3P`2TY:@0XZ:R08Z:
RP2?Shl0XZ:R0;6a/@2>SXh0PH610;6a/@2h^;P0_;bl0;:b/P2_[jl0Xj>S0;>c/`2][Jd0ZJVY09RH
V02n_[h0Y:BT0:n_[`2LW9`0UIFE0;jn_P2a/K40YjNW0:b/[039bLT0^k^k09JFUP2RXZ80];Bd0:6Q
X@2e]KD0/k>c0080[Jf]0100]kNg0:FUY@2RXZ80Z:RX0:ZZZP2/[:`0[jn_0;Fe]@2][Jd0_Kfm0<K6
aP2[Zj/0W9bL0:b/[02QXJ40][Jf0P2HV9P09@2^[Zh0VIVI09^KV`2RXZ80Vi^K07UiN@29RHT0U9BD
0861P@2MWId0OWin08B4Q02<S8`0PH610:JVYP2CTi<0TI6A08N7Q`24Q8@0Y:BT09jNWP2=SHd0RXZ:
096AT@2<S8`0T92@09VIV@2RXZ80X:2P09nOW`2MWId0Z:RX09jNWP2@T900V9RH0:^[Z`2XZ:P00P2;
Rh/07@2CTi<0U9BD0;Vi^@2/[:`0S8b<09:BTP2EUID0UiNG0::RXP2KVi/0Ti>C0:NWY`2:RXX0Ogmo
09^KV`2@T900WIfM09BDU02FUYH0V9RH096AT@22PX80Q8B409ZJVP2;Rh/0VIVI075aL@2:RXX0QhN7
0080ZZZZ0100TI6A08^;R`24Q8@0R8R80:6QX@2=SHd0Ng]k08V9R@1?Cdl0QXJ60:b/[020P800N7Qh
09ZJVP22PX80RHV90P25QHD0A@1mOGd0QXJ608^;R`2KVi/0IVIV069RHP1WIfL0N7Qh07YjNP1aLG40
S8b<08:2PP1YJFT0OWin09ZJVP1gMgL0KFe]07]kN`1lO7`0MGEe06e]K@1_Kfl0HV9R05]KF`1/K6`0
Lg=c08>3P`1ZJVX0GEeM07]kN`2BTY80Hf=S07]kN`1^KVh0QXJ608b<S01`L700Lg=c0861P@1fMWH0
KFe]07IfMP1eMGD0EeMG06m_K`1GEeL0IFEU06UYJ@1aLG40@T9207emO@1UIFD0MGEe071`L01ZJVX0
GUiN059BDP1^KVh0GUiN06e]K@1[Jf/0L71`06QXJ01QHF40Jf][04];B`1MGEd0PX:20?ooo`060=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT01@3oool0OGem09^KV`2XZ:P0Shn?
0080UIFE05h0WYjN09VIV@1fMWH0Zj^[08J6QP2;Rh/0Shn?08j>SP1dM7@0ZJVY08F5Q@2BTY80T92@
07MgM`2HV9P0Z:RX0:f][@2XZ:P0MgMg08F5Q@1_Kfl0MgMg09NGU`1bLW80SHf=09FEU@2SXj<0ZZZZ
09NGU`2^[Zh0UiNG09^KV`27QhL0O7al08J6QP1hN7P0WIfM0:n_[`2c/k<0R8R80:BTY02BTY80OWin
09fMW@2?Shl0UYJF08F5Q@2:RXX0WinO08^;R`2:RXX0Rh^;09^KV`2FUYH0WinO0820P024Q8@0LG5a
08V9R@26QXH0VIVI0;Ng]`30`<00a/K60:n_[`2h^;P0_[jn09jNWP2a/K40V9RH09:BTP2EUID0W9bL
0:NWY`2b/[80VIVI09bLW02^[Zh0VIVI0:b/[02SXj<0O7al06][J`1LG5`0GEeM0861P@1/K6`0Lg=c
07QhN01mOGd0Kfm_07=cL`1YJFT0I6AT0P2HV9P02P2EUID0WinO09FEU@2CTi<0UiNG09RHV02XZ:P0
/;2`09jNWP2:RXX20:j^[P0@08F5Q@2LW9`0Z:RX09VIV@2UYJD0UYJF0;fm_@2IVIT0W9bL0:f][@2S
Xj<0XJ6Q0:FUY@2d];@0YJFU09bLW080_Kfm02@0]kNg0;bl_02m_Kd0/;2`09^KV`2PX:00/K6a0;bl
_02h^;P0[Jf]09nOW`31`L40X:2P0:n_[`2YZJT0^[Zj0:j^[P2n_[h0[jn_09^KV`2][Jd0RXZ:0:2P
X02UYJD0UiNG08f=S@2PX:00[Jf]0:>SX`2:RXX0WinO08J6QP2LW9`0Vi^K0;Bd]02UYJD209JFUP13
07]kN`2JVYX0NGUi09^KV`2`/;00WIfM09FEU@2KVi/0VYZJ07EeM@28R8P0PX:20:j^[P2EUID0YJFU
0:VYZ@2ZZZX0T92@09VIV@2ZZZX0WIfM09NGU`2/[:`0XJ6Q08f=S@2MWId0U9BD08f=S@2DU9@0Shn?
09VIV@26QXH0T92@09FEU@2NWYh0TI6A09jNWP2QXJ40[jn_07inOP2PX:00R8R809jNWP1^KVh0WYjN
08J6QP28R8P0QhN708^;R`1_Kfl0SXj>09FEU@2MWId0UiNG09nOW`28R8P0RHV909>CT`21PH40O7al
08N7Q`2CTi<0MgMg065QH@2:RXX0VIVI08j>SP0209BDU0080861P@28R8P0Q8B40820P01XJ6P0TI6A
06a/K01bLW8207]kN`0[06m_K`1TI6@0Q8B408R8R01lO7`0QHF506EUI@1dM7@0NWYj07QhN02CTi<0
O7al0820P01bLW80J6QX07MgM`1lO7`0Kfm_07EeM@2:RXX0N7Qh08j>SP1bLW80PH6105iNGP1cLg<0
L71`06YZJP22PX80K6a/05QHF01CDe<0L71`07YjNP1]KFd0MWIf06a/K01?Cdl0F5QH08>3P`2?Shl0
IFEU05IFEP0207AdM00C05]KF`1hN7P0Jf][061PH01[Jf/0GemO061PH010@400HF5Q07EeM@1XJ6P0
Fe]K071`L019BDT0IVIV071`L01EEED0F5QH0?ooo`060=WIf@4000000@3IfMT001H0fMWI00<00000
0=WIf@3IfMT00`3IfMT0MP3oool0WIfM08f=S@2@T900X:2P08F5Q@2LW9`0VYZJ09bLW028R8P0WYjN
09:BTP1oOgl0QHF50:>SX`2;Rh/0TI6A0::RXP2CTi<0SHf=08j>SP2OWil0[:b/08n?S`2ATI40OWin
07IfMP1eMGD0KVi^055AD@19BDT0UYJF09FEU@2=SHd0WinO0:2PX02FUYH0TY:B09JFUP1gMgL0H61P
06m_K`2HV9P0UYJF09>CT`2FUYH0V9RH09bLW02[Zj/0S8b<07=cL`2HV9P0X:2P08j>SP2;Rh/0S8b<
09ZJVP2IVIT0X:2P08J6QP2OWil0RXZ:08V9R@1cLg<0R8R808Z:RP2DU9@0Zj^[0:b/[02`/;00_;bl
0<?3``2i^KT0Zj^[0;:b/P2g]kL0YJFU0:ZZZP2EUID0NGUi0:6QX@2MWId0[:b/0;:b/P2XZ:P0S8b<
08j>SP1jNWX0IFEU059BDP1_Kfl0OGem09FEU@28R8P0][Jf0:NWY`2:RXX0Rh^;08n?S`1_Kfl0LG5a
07IfMP2FUYH0VYZJ0;Fe]@2][Jd0SXj>0:6QX@2;Rh/0Xj>S09fMW@2a/K40Zj^[0;6a/@2MWId0W9bL
0;>c/`27QhL30:2PX00?08B4Q02KVi/0]kNg0;>c/`2g]kL0V9RH0;Fe]@33`l<0Zj^[0:f][@2j^[X0
ZJVY0;Fe]@2RXZ80XJ6Q0080^;Rh09`0/;2`0;jn_P3;bl/0XJ6Q0;Fe]@33`l<0[Jf]0;Zj^P2b/[80
YZJV0:n_[`2[Zj/0^;Rh0;2`/02/[:`0Y:BT0:^[Z`2PX:00WYjN0:^[Z`2/[:`0Vi^K0:j^[P2QXJ40
Ph>308Z:RP2CTi<0T92@09bLW01mOGd0R8R809JFUP2>SXh0Ti>C09RHV02?Shl0PH6109>CT`2/[:`0
XZ:R0:JVYP2UYJD0V9RH0:VYZ@2NWYh0WinO09ZJVP2FUYH0Xj>S0::RXP2UYJD0QHF508f=S@2RXZ80
ZJVY09bLW02JVYX0Rh^;0:>SX`2TY:@0UiNG09JFUP2VYZH0Y:BT0:6QX@2;Rh/0Shn?092@T02VYZH0
Q8B4092@T02EUID0WinO0:^[Z`2LW9`0Ogmo09JFUP2=SHd0Ph>309:BTP29RHT0WIfM08:2PP2WYjL0
XJ6Q08n?S`2>SXh0Vi^K08B4Q020P800Vi^K0:2PX02BTY80RHV90:6QX@2BTY80SXj>07EeM@1`L700
QhN708J6QP1eMGD0UYJF08n?S`1jNWX0RXZ:08F5Q@1_Kfl0QHF508Z:RP2;Rh/0K6a/08N7Q`1oOgl0
S8b<05iNGP1ZJVX0R8R807emO@2?Shl0O7al08V9R@1UIFD0Ng]k07MgM`1]KFd0PX:208F5Q@1kNg/0
MgMg05=CD`1_Kfl0HV9R05mOG`1aLG40MWIf07emO@1YJFT0Jf][075aL@1eMGD0Kfm_05aLG01hN7P0
MGEe08R8R01iNGT0ATI606UYJ@1VIVH0Jf][065QH@1IFET0Lg=c07emO@1HF5P206IVIP0B06e]K@1U
IFD0K6a/09>CT`1SHf<0K6a/08:2PP1XJ6P0MWIf06=SH`1JFUX0GEeM055AD@1SHf<0LW9b07]kN`1B
DU80oooo1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI04D0oooo09fMW@2D
U9@0RHV908R8R02:RXX0UIFE09bLW029RHT0S8b<0820P02BTY80Q8B408j>SP2=SHd0Shn?09VIV@27
QhL0W9bL09:BTP2=SHd0Vi^K08n?S`1ZJVX0Shn?06][J`21PH40M7Ad06EUI@1HF5P0QXJ6096AT@2;
Rh/0KFe]08:2PP2:RXX0XZ:R08B4Q027QhL0Ti>C08Z:RP1`L700S8b<09jNWP2EUID0WYjN0:FUY@2L
W9`0UIFE08V9R@2EUID0WinO08b<S02NWYh0SXj>08B4Q02VYZH0Vi^K08N7Q`2KVi/0Rh^;0:BTY027
QhL0Ph>308V9R@2?Shl0T92@0<C4a02WYjL00P2][Jd0:`2TY:@0c<c<08b<S034a<@0][Jf0:2PX02Y
ZJT0aLG50:>SX`2;Rh/0[jn_09nOW`2IVIT0_[jn0;Zj^P1nOWh0Q8B407AdM01MGEd0Ph>307=cL`2D
U9@0_Kfm09ZJVP2DU9@0ZJVY09JFUP1gMgL0Kfm_07=cL`20P800S8b<08J6QP2QXJ40Zj^[0<30`02L
W9`0YJFU0;Bd]02l_;`0_Kfm0:2PX02a/K400P2IVIT03`2VYZH0ZJVY0;6a/@2b/[80X:2P0;Rh^031
`L40TI6A0;Zj^P2OWil0Ti>C09bLW02?Shl0/k>c0:NWY`020:ZZZP0G0:f][@2JVYX0Z:RX0:FUY@2b
/[80];Bd0;no_`2UYJD0S8b<0:^[Z`2b/[80VYZJ0=CDe02d];@0a<C40;Ng]`30`<00UIFE0:RXZ02V
YZH0XJ6Q0:FUY@2n_[h00P2][Jd20:n_[`0P0:j^[P2ZZZX0RHV90:2PX02=SHd0MgMg08n?S`27QhL0
UiNG09fMW@2?Shl0SXj>08J6QP2:RXX0VYZJ092@T02JVYX0WinO09:BTP2@T900S8b<09fMW@26QXH0
WIfM0<71`@2DU9@0[:b/09:BTP2MWId0XZ:R0:FUY@2HV9P20:>SX`0X0:2PX02ATI40VIVI09NGU`2R
XZ80VIVI0:2PX02OWil0UYJF0:BTY02JVYX0WIfM08V9R@2HV9P0P8200;>c/`2HV9P0UiNG092@T02?
Shl0SXj>09>CT`2?Shl0TY:B09jNWP2EUID0Vi^K09ZJVP26QXH0GEeM07MgM`25QHD0V9RH08>3P`26
QXH0RXZ:08j>SP2?Shl0QHF509RHV080S8b<03D0U9BD092@T01jNWX0QhN706i^KP1SHf<0Lg=c07Ad
M023Ph<0Ng]k092@T026QXH0LW9b08:2PP1/K6`0IFEU071`L02=SHd0Jf][08:2PP1gMgL0N7Qh071`
L01YJFT0OWin06UYJ@1UIFD0M7Ad05mOG`1RHV80Lg=c06IVIP1MGEd0J6QX069RHP20P800SXj>06QX
J022PX80JFUY06ATI01RHV80KFe]065QH@1MGEd0JFUY05ADE01/K6`0HF5Q07EeM@1QHF40LG5a06m_
K`0306a/K00F06ATI01eMGD0NWYj079bLP1_Kfl0Hf=S07IfMP2^[Zh0KFe]06QXJ01TI6@0Kfm_04U9
B@1eMGD0KFe]06i^KP1KFe/0J6QX05QHF01>CTh0MgMg0?ooo`H0fMWI0@0000010=WIf@005P3IfMT0
0`000000fMWI0=WIf@030=WIf@0]0?ooo`2RXZ80QXJ609ZJVP27QhL0RXZ:08b<S02?Shl0SXj>0:JV
YP26QXH0R8R808b<S024Q8@0UYJF0:2PX02CTi<0UYJF06m_K`2DU9@0Rh^;07emO@20P800O7al0861
P@1eMGD0JVYZ06MWI`1[Jf/0P82007IfMP1bLW80HF5Q0861P@2MWId0V9RH0:VYZ@2>SXh0QhN707mo
O`2=SHd0[:b/07emO@2TY:@0WYjN0080XJ6Q05P0X:2P096AT@2CTi<0Kfm_08f=S@28R8P0YJFU0:RX
Z02NWYh0Vi^K08J6QP2@T900Shn?0:2PX021PH40SXj>0:2PX02NWYh0V9RH09JFUP2<S8`0WIfM09jN
WP2RXZ80YJFU0:ZZZP2l_;`0_kno0:ZZZP2>SXh0YJFU0:j^[P35aLD0[jn_0:NWY`2g]kL0/k>c0;:b
/P2IVIT0RXZ:08J6QP1eMGD0IFEU06QXJ02BTY80XZ:R0;:b/P2FUYH0]KFe0:JVYP2JVYX0P820051@
D01CDe<0PH6109nOW`2g]kL0Zj^[09VIV@2YZJT0VYZJ0::RXP2d];@0Zj^[09BDU02a/K40TI6A0:n_
[`2e]KD0[jn_09FEU@33`l<0][Jf0:^[Z`2^[Zh0Zj^[09nOW`2`/;00XZ:R0;Bd]02`/;00^[Zj08j>
SP2OWil0[Zj^0;Fe]@38b<P0ZZZZ0`2_[jl02P2ZZZX0/K6a09fMW@2_[jl0Z:RX07inOP2b/[80YjNW
09RHV02VYZH20;Vi^@0F0:VYZ@2b/[80ZZZZ08J6QP2b/[80VIVI09nOW`2QXJ40U9BD0:NWY`2a/K40
Z:RX09FEU@2@T900W9bL0:NWY`2GUiL0Vi^K0:6QX@2?Shl0R8R808b<S080Ph>300<0YJFU0:BTY023
Ph<00P25QHD0:P2HV9P0TI6A0:j^[P2OWil0RHV909JFUP2g]kL0YjNW0<C4a02UYJD0Xj>S0:6QX@2Z
ZZX0XZ:R09ZJVP2VYZH0/[:b0:JVYP2CTi<0W9bL0:FUY@22PX80QXJ60;Ng]`27QhL0W9bL09nOW`2A
TI40N7Qh08:2PP2<S8`0UYJF09nOW`2[Zj/0SHf=09:BTP2NWYh0];Bd08:2PP1WIfL0S8b<08:2PP80
UiNG0100RXZ:07YjNP2:RXX0T92@09>CT`2FUYH0Zj^[0:b/[026QXH0RXZ:08b<S02BTY80R8R808F5
Q@2EUID0SHf=0P1kNg/0B@26QXH0LW9b08F5Q@2BTY80Ph>307alO01bLW80S8b<08B4Q023Ph<0M7Ad
05aLG01kNg/0IfMW06i^KP1`L700IVIV07]kN`1oOgl0O7al08F5Q@23Ph<0Kfm_06IVIP20P800JFUY
07alO020P800JVYZ06i^KP2@T900Lg=c07alO01kNg/0GUiN06YZJP1KFe/0HV9R0820P01^KVh0N7Qh
07IfMP1DE5@0GEeM07UiN@1ZJVX0HF5Q07MgM`1/K6`0JVYZ065QH@1NGUh0E5AD065QH@1dM7@0GemO
06=SH`1@D500I6AT06MWI`1YJFT0FUYJ065QH@1/K6`0EUIF06e]K@1TI6@0F5QH06IVIP1^KVh0F5QH
065QH@3oool01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00D0oooo09fM
W@26QXH0Xj>S08B4Q00209FEU@1B09>CT`2<S8`0J6QX09BDU01jNWX0UIFE061PH028R8P0WIfM09nO
W`2<S8`0QhN709NGU`2<S8`0RHV907EeM@1cLg<0DE5A06MWI`1fMWH0FUYJ07=cL`1WIfL0IFEU071`
L01oOgl0OWin07EeM@2@T900Kfm_09jNWP2GUiL0VIVI09>CT`1^KVh0R8R808>3P`2LW9`0UIFE09:B
TP2TY:@0TY:B09FEU@2@T900LW9b0;Fe]@2`/;00YjNW0:6QX@2JVYX0/;2`08B4Q028R8P0XJ6Q08j>
SP2TY:@0UIFE09RHV02PX:00VYZJ09^KV`2l_;`0VIVI0:VYZ@2e]KD0[Jf]0;>c/`3@d=00VIVI09fM
W@2d];@0YjNW0;2`/02DU9@0XJ6Q0;2`/02DU9@0YJFU08j>SP2BTY80L71`06MWI`80N7Qh01H0SXj>
0::RXP2b/[80`L710:JVYP2HV9P0/;2`08>3P`1TI6@0KFe]08V9R@2HV9P0T92@0::RXP2e]KD0]kNg
09jNWP2MWId0QhN70:n_[`2HV9P0YZJV0P2ATI408@2TY:@0[jn_09NGU`2LW9`0VYZJ08^;R`2b/[80
]KFe0:ZZZP2VYZH0[:b/0:f][@2_[jl0X:2P0:BTY02`/;00Zj^[0:BTY02][Jd0/k>c09RHV02^[Zh0
WinO0<K6aP2[Zj/0[Jf]0;^k^`2WYjL0ZZZZ0;^k^`2`/;00^[Zj0;fm_@020<S8b00Z0:JVYP2MWId0
U9BD0:FUY@26QXH0X:2P09FEU@2`/;00VIVI0:j^[P2SXj<0/[:b0:ZZZP2IVIT0WinO0:JVYP2MWId0
VYZJ08f=S@2?Shl0Xj>S08^;R`1/K6`0UIFE08Z:RP2<S8`0Vi^K08n?S`2ATI40UYJF08R8R02<S8`0
R8R80:VYZ@29RHT0YZJV0;6a/@2d];@0UiNG09VIV@2j^[X0OWin0P2EUID02@2RXZ80VYZJ07YjNP2c
/k<0YJFU0:JVYP2NWYh0U9BD0::RXP0209bLW00=0;Bd]02LW9`0TY:B06m_K`1eMGD0VIVI096AT@2D
U9@0RXZ:09jNWP1`L700R8R808j>SP0209RHV00309ZJVP2YZJT0TY:B0080YJFU03`0OWin07moO`2A
TI40SXj>07=cL`2TY:@0QXJ608R8R02>SXh0N7Qh09>CT`2=SHd0OGem07MgM`2>SXh0UiNG08n?S`28
R8P0P82008F5Q@1lO7`0PH6107UiN@1kNg/0OWin06m_K`24Q8@0K6a/07QhN01jNWX0LG5a06m_K`1a
LG40Ogmo06a/K01RHV80I6AT07IfMP1]KFd0L71`07EeM@1kNg/0PH6105aLG01_Kfl0QXJ608R8R01m
OGd0MWIf071`L01]KFd0Hf=S07=cL`1eMGD0KVi^07alO017AdL0R8R8065QH@1OGel207EeM@0K06EU
I@1RHV80PX:206][J`1HF5P0GUiN05aLG024Q8@0OWin06EUI@1[Jf/0MGEe06i^KP1XJ6P0E5AD06QX
J01eMGD0GEeM07=cL`1`L700EeMG06IVIP1ZJVX0FUYJ05mOG`1cLg<0oooo00H0fMWI0@0000010=WI
f@005P3IfMT00`000000fMWI0=WIf@030=WIf@040?ooo`2JVYX0VYZJ07IfMP80Shn?0540SXj>09^K
V`2CTi<0U9BD07YjNP2FUYH0M7Ad08b<S01kNg/0Shn?0:NWY`2KVi/0X:2P08^;R`2HV9P0MgMg07=c
L`28R8P0MWIf07alO01EEED0Hf=S09^KV`1lO7`0Ogmo071`L01EEED0GEeM06m_K`1^KVh0XZ:R0:VY
Z@2EUID0TI6A07moO`2:RXX0QXJ607QhN01mOGd0VIVI08^;R`2OWil0Q8B409JFUP29RHT0ZZZZ092@
T02TY:@0WIfM09ZJVP23Ph<0RHV908>3P`2WYjL0XJ6Q09RHV02;Rh/0][Jf09>CT`2IVIT0SXj>0:b/
[02FUYH0^k^k0<?3``2CTi<0/;2`09>CT`2PX:00^KVi08:2PP2/[:`0VIVI0:2PX02_[jl0YJFU0:2P
X02RXZ80[Jf]04M7A`2>SXh00P1mOGd0;@1;Bd/0OGem07YjNP2@T900Vi^K09NGU`2b/[80Zj^[0:2P
X01gMgL0Rh^;07MgM`1aLG40QHF509nOW`2o_kl0bl_;09fMW@2@T900[Jf]09BDU031`L40/;2`0;:b
/P2UYJD0Zj^[0:NWY`2GUiL0YJFU0;6a/@2PX:00YJFU0<?3``2HV9P0_;bl0:JVYP2j^[X0aLG50;Zj
^P3?cll0Z:RX09bLW02e]KD0UYJF092@T0020:RXZ02/0:6QX@2VYZH0`/;20:f][@2[Zj/0a<C40;fm
_@2o_kl0ZJVY0;^k^`2LW9`0_;bl0;Bd]03@d=00^KVi0:RXZ02WYjL0][Jf0;Fe]@2`/;00Y:BT08N7
Q`1mOGd0VIVI0:2PX02b/[80Zj^[09NGU`2NWYh0QhN70820P02DU9@0Y:BT0:j^[P2LW9`0V9RH0:NW
Y`2UYJD0RXZ:09ZJVP28R8P0UYJF0:ZZZP2OWil0YjNW07moO`2QXJ40YZJV08^;R`2MWId0WYjN092@
T02EUID0W9bL0::RXP27QhL0ZJVY09RHV02UYJD0V9RH08f=S@2JVYX0R8R80:>SX`2`/;00Ph>30:JV
YP2IVIT0/;2`09ZJVP1oOgl0SHf=07emO@2:RXX0XJ6Q09>CT`2NWYh0SXj>0861P@2FUYH0RXZ:09JF
UP1mOGd0UIFE09NGU`2:RXX0U9BD08^;R`26QXH0PX:208N7Q`1gMgL0PH610:6QX@1nOWh0Ti>C08J6
QP24Q8@0T92@08V9R@24Q8@0Ogmo0:ZZZP1nOWh0Ng]k07emO@2DU9@0R8R808f=S@1nOWh0I6AT079b
LP21PH40KVi^07alO01ZJVX0HV9R071`L01YJFT0JVYZ07emO@1cLg<0JFUY07MgM`1TI6@0MWIf06m_
K`1hN7P0QHF505eMG@1[Jf/0MWIf04m?C`1mOGd0KVi^07alO01ZJVX0Lg=c07YjNP1TI6@0E5AD07Ad
M01aLG40MgMg06=SH`1aLG40GUiN05QHF01lO7`0Ph>304E5A@1ZJVX0LW9b07EeM@1XJ6P0PX:2065Q
H@1[Jf/0E5AD071`L01oOgl0HV9R05iNGP1ZJVX0LG5a05QHF01YJFT0?clo05=CD`1UIFD0MgMg07]k
N`80Jf][00@0KVi^06e]K@1WIfL0oooo1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI
00<0fMWI03H0oooo092@T02KVi/0YjNW09jNWP2?Shl0[:b/08J6QP2FUYH0TI6A09VIV@2CTi<0Xj>S
09>CT`25QHD0Q8B406a/K026QXH0OWin09bLW02;Rh/0O7al06QXJ01QHF40Hf=S065QH@1YJFT0QXJ6
07MgM`2>SXh0KFe]06UYJ@1QHF40E5AD051@D01LG5`0MGEe08>3P`2OWil0UiNG0861P@29RHT0OGem
07UiN@2@T900PH6108N7Q`2QXJ40W9bL0::RXP29RHT0Vi^K0:ZZZP2FUYH20:6QX@1g0:NWY`29RHT0
Rh^;09^KV`2NWYh0]kNg08n?S`2d];@0^[Zj0:VYZ@2a/K40a<C40:JVYP2GUiL0OGem0;>c/`3;bl/0
^;Rh0;Fe]@2i^KT0ZJVY0:ZZZP2`/;00/[:b0::RXP3AdM40]kNg09:BTP2NWYh0XJ6Q0:VYZ@26QXH0
GemO07=cL`1XJ6P0LG5a092@T020P800WIfM0:f][@2LW9`0PH6106e]K@1_Kfl0K6a/07alO02MWId0
Z:RX0<K6aP2][Jd0X:2P0;2`/02[Zj/0X:2P0:n_[`2PX:00ZZZZ0:NWY`2RXZ80WinO0;2`/02OWil0
^k^k0:f][@2`/;00YZJV0:b/[03AdM40[:b/0;Bd]02QXJ40`/;20;2`/02_[jl0]KFe0:j^[P29RHT0
RXZ:0<c<c02k^k/0/K6a0<[:bP2ZZZX0_[jn0:b/[02k^k/0][Jf0;6a/@2c/k<0Z:RX0;>c/`39bLT0
]kNg0<o?c`2XZ:P0]kNg0;Fe]@2^[Zh0_[jn0;Fe]@2^[Zh0][Jf0:RXZ02GUiL0SXj>0:RXZ02BTY80
SXj>09RHV02DU9@0WinO0;2`/026QXH0QhN7092@T02FUYH0R8R809>CT`2<S8`00P2GUiL02@2=SHd0
WYjN09VIV@2LW9`0[Jf]09:BTP2TY:@0/[:b09NGU`02096AT@1J0;:b/P000000QHF507MgM`2KVi/0
VIVI092@T02YZJT0VIVI0:NWY`29RHT0]KFe09ZJVP2RXZ80]kNg0;Fe]@2TY:@0Vi^K09RHV02<S8`0
VIVI09JFUP2RXZ80]KFe08j>SP2XZ:P0Vi^K09:BTP1nOWh0RHV90:2PX02=SHd0V9RH0:NWY`2EUID0
X:2P096AT@1jNWX0SHf=08B4Q020P800MGEe09JFUP2:RXX0NWYj08^;R`1HF5P0K6a/08N7Q`2@T900
P82007emO@22PX80W9bL08^;R`22PX80XZ:R07emO@1iNGT0I6AT075aL@27QhL0Lg=c08J6QP2?Shl0
KFe]061PH02FUYH0Ng]k06i^KP1fMWH0JVYZ07]kN`1`L700Ogmo07UiN@1`L700I6AT06=SH`1IFET0
QXJ607inOP1jNWX0EeMG03`l?01hN7P0IFEU051@D0000000HF5Q0P1ZJVX00`1WIfL0MGEe08^;R`02
07emO@0M07=cL`1]KFd0MgMg07IfMP1`L700Lg=c05UIF@1cLg<0HF5Q06m_K`1]KFd0IVIV07=cL`1S
Hf<0R8R804I6AP1TI6@0LW9b05YJFP1aLG40HF5Q07emO@1[Jf/0>SXj05iNGP1^KVh0K6a/05QHF03o
ool01P3IfMT100000040fMWI000F0=WIf@800000103IfMT0303oool0SXj>0:>SX`2MWId0XJ6Q096A
T@2PX:00[jn_09NGU`2FUYH0Q8B409jNWP80Ph>300T0YJFU09nOW`26QXH0Ng]k08f=S@2;Rh/0TY:B
06QXJ01aLG400P1PH600R`1]KFd0O7al08R8R02CTi<0Xj>S08V9R@1MGEd0FEUI04Q8B01LG5`0F5QH
09NGU`2YZJT0S8b<0:n_[`2LW9`0PH6108b<S02HV9P0PH6107UiN@25QHD0NWYj08j>SP22PX80ZJVY
0;6a/@2[Zj/0YJFU0;Jf]P2KVi/0W9bL08B4Q01YJFT0[jn_08n?S`2GUiL0Z:RX0;Bd]033`l<0clo?
0:JVYP2e]KD0/[:b09JFUP2UYJD0[Jf]0;jn_P2b/[80/;2`0;>c/`2PX:00_kno0:ZZZP2LW9`0ZJVY
0:n_[`2j^[X0_kno0:RXZ02/[:`0WinO07]kN`1dM7@0PH6106][J`1MGEd0Hf=S07EeM@21PH40MgMg
06][J`1_Kfl0IfMW08V9R@1lO7`0UIFE0;:b/P2_[jl0[:b/0:JVYP2QXJ40ZZZZ0:6QX@2TY:@0YJFU
0:VYZ@2DU9@0X:2P0:ZZZP2XZ:P0^k^k0:j^[P2LW9`0/;2`0:f][@2QXJ40_;bl0:b/[02b/[80YZJV
0:j^[P2d];@0]kNg0;Vi^@2LW9`0WYjN08f=S@0:2PX0^k^k0;Jf]P2o_kl0[jn_09NGU`2e]KD0]kNg
0;Fe]@3=cLd0YZJV0;Fe]@2h^;P0];Bd0;>c/`2][Jd0ZJVY0;Zj^P2g]kL0_[jn0:6QX@2YZJT0/;2`
0;>c/`2:RXX0UYJF09^KV`2<S8`0XZ:R09BDU02LW9`00P2ATI40?`2GUiL0T92@0:JVYP1lO7`0Ti>C
08F5Q@27QhL0PX:2096AT@24Q8@0U9BD092@T01VIVH0OWin09fMW@2QXJ40VIVI0:j^[P2QXJ40`L71
0:b/[02TY:@0ZJVY0:NWY`2FUYH0Ogmo08N7Q`21PH40Z:RX08^;R`2RXZ80[Jf]0;Ng]`2`/;00Vi^K
09bLW02[Zj/0XJ6Q096AT@2DU9@0TI6A07moO`2DU9@0Ph>30;jn_P2OWil0XJ6Q08n?S`2<S8`0[Zj^
08>3P`1mOGd0SXj>09BDU027QhL0TI6A0:NWY`2VYZH0PX:207EeM@2DU9@0L71`09FEU@0209NGU`1C
05UIF@23Ph<0QHF508R8R01cLg<0UYJF09ZJVP29RHT0UiNG07emO@1iNGT0RHV908F5Q@2CTi<0OWin
08:2PP23Ph<0Ng]k07alO01`L700Ogmo07emO@1dM7@0Ng]k071`L01fMWH0IVIV075aL@1lO7`0MgMg
07EeM@27QhL0N7Qh0820P01bLW80J6QX075aL@1iNGT0Ogmo07YjNP1dM7@0EeMG075aL@1`L700O7al
065QH@21PH40L71`05MGE`1HF5P0FEUI07YjNP1mOGd0Kfm_05]KF`1fMWH0Ph>307alO01[Jf/0JVYZ
06IVIP1TI6@0PX:207emO@1kNg/0Lg=c06][J`1bLW80Jf][069RHP1/K6`0Fe]K07EeM@1JFUX0H61P
06IVIP1[Jf/0IfMW06IVIP1GEeL0H61P06EUI@3oool01@3IfMT200000040fMWI000F0=WIf@030000
003IfMT0fMWI00<0fMWI0;/0oooo0:VYZ@2YZJT0T92@0820P024Q8@0KVi^09>CT`22PX80SHf=0:2P
X02LW9`0Ti>C07inOP2<S8`0UIFE07YjNP22PX80NWYj0::RXP2CTi<0DE5A059BDP1OGel0HV9R08:2
PP1jNWX0Ph>308F5Q@1aLG40YjNW06ATI01LG5`0EUIF04];B`1PH600U9BD0:>SX`2[Zj/0XZ:R0:JV
YP2FUYH0UIFE08j>SP2IVIT0PH610820P02?Shl0YZJV0820P02DU9@0Xj>S0;Rh^02VYZH0[jn_08Z:
RP2JVYX0W9bL09fMW@2PX:00Y:BT09BDU02e]KD0^;Rh0;Fe]@2/[:`0YZJV0:j^[P2YZJT0[jn_0:>S
X`2KVi/0/K6a0;Vi^@2m_Kd0_[jn0<S8b02m_Kd0[Jf]0::RXP2`/;00]kNg0:JVYP2NWYh0Z:RX0:FU
Y@2HV9P0WYjN09:BTP2:RXX0IVIV06a/K01SHf<0Lg=c07YjNP1WIfL0I6AT06i^KP1YJFT0K6a/0861
P@2_[jl0Z:RX0;fm_@2o_kl0^[Zj0:VYZ@2i^KT0ZJVY0:RXZ02b/[80X:2P0:BTY02LW9`0Y:BT0:ZZ
ZP2HV9P0X:2P08b<S02OWil0][Jf0:f][@2MWId0/K6a08f=S@2VYZH0X:2P0;2`/02l_;`0YjNW0:VY
Z@2UYJD0W9bL0:j^[P2YZJT0WIfM09VIV@2][Jd0T92@0;jn_P2j^[X0_;bl0;Ng]`2OWil0/;2`0;Fe
]@2TY:@0Z:RX0:VYZ@2RXZ80YJFU0:j^[P2YZJT0ZZZZ0:j^[P2RXZ80WinO09RHV02UYJD0/K6a08Z:
RP2DU9@0TY:B0:VYZ@2JVYX0Ti>C08V9R@2LW9`0SHf=0:b/[028R8P0WinO08f=S@2LW9`0V9RH08^;
R`2GUiL0U9BD06=SH`2ATI40TY:B09nOW`30`<00/;2`0:BTY02UYJD0][Jf0080Xj>S01X0/K6a09NG
U`2SXj<0YZJV09RHV02>SXh0YjNW09bLW02PX:00][Jf09fMW@2RXZ80[Zj^09RHV02LW9`0Zj^[09RH
V02:RXX0YJFU09FEU@25QHD0U9BD08F5Q@2KVi/0Xj>S096AT@80V9RH02/0U9BD08J6QP2PX:00XZ:R
08N7Q`2LW9`0TY:B08^;R`1UIFD0SXj>08J6QP2BTY80S8b<06i^KP1VIVH0VYZJ08^;R`20P800WIfM
07UiN@1SHf<0Ti>C07moO`22PX80N7Qh08F5Q@2=SHd0O7al07inOP1lO7`0M7Ad096AT@1eMGD0HF5Q
06=SH`20P800I6AT05iNGP1bLW80HV9R06i^KP1QHF40LW9b0080J6QX03@0I6AT069RHP1aLG40MGEe
06IVIP1gMgL0IFEU06MWI`1lO7`0IFEU07MgM`22PX80J6QX05QHF01dM7@0IVIV07=cL`1[Jf/0OGem
08>3P`1mOGd0Lg=c06UYJ@1IFET0OWin06e]K@1VIVH0M7Ad06a/K01`L700Kfm_05MGE`1SHf<0K6a/
075aL@1oOgl0Fe]K06YZJP1OGel0Ng]k07inOP1OGel0K6a/05ADE01XJ6P0HV9R06EUI@1HF5P0I6AT
07moO`1ADE40oooo1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00`0oooo
09JFUP2DU9@0RXZ:0::RXP2@T900QhN7096AT@2SXj<0WinO08V9R@2>SXh208N7Q`0308b<S025QHD0
K6a/0080V9RH0480VIVI09RHV01jNWX0GemO04];B`1@D500PX:207inOP2ATI40Ti>C0:RXZ02HV9P0
KFe]07moO`0k>c/0Fe]K05QHF01`L700[:b/0:ZZZP2RXZ80WIfM0:JVYP2KVi/0MgMg0;Fe]@27QhL0
T92@0:JVYP2MWId0Y:BT0:RXZ01fMWH0^KVi0:f][@2YZJT0XZ:R0:^[Z`2?Shl0Vi^K0:n_[`2h^;P0
Xj>S0;>c/`2OWil0Z:RX0:b/[02PX:00/[:b09jNWP2VYZH0XZ:R0:b/[02TY:@0^KVi09VIV@2j^[X0
^;Rh0:FUY@2IVIT0^[Zj0;Vi^@2EUID0Zj^[09>CT`2b/[820::RXP0`0:ZZZP2UYJD0Ph>308j>SP1/
K6`0Hf=S06UYJ@1LG5`0Jf][05UIF@1^KVh0LW9b096AT@2BTY80/k>c0:f][@2JVYX0`<300:^[Z`2o
_kl0^k^k0<C4a033`l<0/k>c0:JVYP2`/;00Xj>S0;6a/@2`/;00W9bL0:f][@2_[jl0WinO0;Jf]P2J
VYX0/[:b0;Bd]02WYjL0YJFU08n?S`2;Rh/0VYZJ0:2PX02EUID0_;bl0861P@2_[jl0X:2P0P2f][H0
Z02SXj<0YJFU0:RXZ034a<@0];Bd0;^k^`2LW9`0[jn_0;Zj^P2][Jd0]kNg0;6a/@36a/H0WinO092@
T02_[jl0Y:BT0<;2`P2l_;`0XJ6Q0;Jf]P2XZ:P0Rh^;0;Fe]@2WYjL0/[:b0:FUY@2<S8`0O7al09RH
V02<S8`0Xj>S0::RXP2EUID0UiNG08n?S`2ATI40ZJVY0:6QX@2@T900UYJF09jNWP2m_Kd0UYJF08B4
Q02TY:@0Xj>S08B4Q02IVIT0^KVi08b<S02PX:00Zj^[0::RXP2WYjL0ZJVY09fMW@2?Shl0U9BD0:^[
Z`2TY:@0Kfm_0:RXZ02=SHd0WYjN07inOP27QhL0YZJV09FEU@2<S8`0WYjN08n?S`2LW9`0WIfM0:>S
X`2JVYX0Shn?09:BTP2>SXh0Ph>309NGU`1jNWX0@T9207]kN`22PX80QXJ608j>SP28R8P0TI6A09RH
V02CTi<0V9RH08N7Q`1hN7P0UIFE07IfMP23Ph<0TI6A08Z:RP2;Rh/0OWin07alO027QhL0OWin07Ad
M01/K6`0UiNG07IfMP2=SHd0R8R807AdM01iNGT0TY:B07AdM01XJ6P0JVYZ07alO026QXH0Q8B407em
O@1]KFd0JVYZ075aL@1`L700Hf=S05UIF@1]KFd0Hf=S08:2PP1YJFT0IFEU071`L01OGel0IFEU075a
L@1gMgL0M7Ad06MWI`28R8P0UYJF06EUI@1hN7P0NGUi065QH@1iNGT0K6a/055AD@1<C4`0KFe]075a
L@1ZJVX0TY:B06a/K01cLg<0JVYZ05IFEP1^KVh0J6QX069RHP1^KVh0Q8B407moO`1XJ6P0M7Ad04Q8
B01GEeL0FUYJ07]kN`80KFe]00L0KVi^06a/K015ADD0G5aL04a<C01YJFT0oooo00H0fMWI0@000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@1l0?ooo`2IVIT0Ogmo0:2PX025QHD0YZJV08>3
P`1kNg/0Jf][0:BTY02LW9`0YJFU08j>SP1kNg/0MGEe08N7Q`2EUID0TY:B08^;R`2HV9P0Q8B407If
MP1HF5P0EUIF05]KF`1TI6@0NWYj06e]K@20P800VIVI0;6a/@2?Shl0KVi^055AD@16ATH0B4Q808>3
P`2:RXX0VIVI08Z:RP2KVi/0XZ:R0;2`/02/[:`0Xj>S09:BTP2SXj<0W9bL09fMW@2=SHd0WIfM09jN
WP2RXZ80^k^k0:f][@2c/k<0Y:BT08R8R02QXJ40XZ:R0:FUY@2XZ:P0UIFE08b<S02PX:00UiNG0:6Q
X@2_[jl0Q8B408j>SP2NWYh0SHf=09VIV@3=cLd0b<S80;Rh^03:b/X0^;Rh0:VYZ@33`l<0ZZZZ0<71
`@2ZZZX0[Jf]0;2`/02/[:`0];Bd0:ZZZP1cLg<0/;2`08n?S`23Ph<0GemO07inOP1JFUX0MGEe08j>
SP1PH600W9bL0:NWY`2^[Zh0[jn_0:f][@2XZ:P0[Zj^0:^[Z`2QXJ40^;Rh0<G5a@2UYJD0U9BD0;:b
/P2^[Zh0]KFe08R8R02[Zj/0[:b/08^;R`2YZJT0[Jf]0:j^[P2o_kl0YZJV09>CT`80^;Rh01D0a<C4
0;6a/@2UYJD0Y:BT09jNWP2f][H0Zj^[09fMW@2e]KD0VYZJ0;Ng]`2`/;00bLW90:^[Z`2f][H0/K6a
09bLW02GUiL0WIfM0::RXP2VYZH00P2NWYh0@@2TY:@0[Zj^0:JVYP2XZ:P0^;Rh0:6QX@2[Zj/0VYZJ
09:BTP29RHT0UYJF09jNWP2>SXh0]KFe0:>SX`2NWYh0SXj>0:>SX`2MWId0UYJF08R8R026QXH0QhN7
08^;R`1nOWh0V9RH09NGU`2RXZ80Zj^[08V9R@2JVYX0_kno0::RXP2@T900U9BD0;2`/02TY:@0XJ6Q
0;Ng]`2d];@0Zj^[0:b/[02PX:00XJ6Q09:BTP2QXJ40VIVI09:BTP2KVi/0TI6A09fMW@2NWYh0SHf=
08j>SP2CTi<0W9bL09jNWP1nOWh0Lg=c06IVIP1iNGT0UYJF0;Jf]P2HV9P0YZJV0080Q8B400H0JFUY
06][J`1fMWH0QHF508Z:RP2FUYH208f=S@0=0861P@1eMGD0M7Ad08b<S02@T900Rh^;08F5Q@2EUID0
R8R807alO02:RXX0Ogmo08N7Q`0208J6QP1;08f=S@1[Jf/0Rh^;09NGU`1gMgL0U9BD07IfMP26QXH0
QHF506a/K01eMGD0IfMW0820P01UIFD0M7Ad071`L01PH600JFUY06ATI028R8P0Jf][08F5Q@1=CDd0
LW9b06e]K@2=SHd0F5QH06ATI01NGUh0SXj>07UiN@1hN7P0LW9b07moO`1dM7@0IVIV06ATI01eMGD0
K6a/07IfMP23Ph<0QXJ606=SH`18B4P0@41004Y:BP2:RXX0IFEU06YZJP1UIFD0Lg=c059BDP1RHV80
FUYJ06EUI@21PH40KFe]06YZJP1YJFT0Kfm_065QH@1MGEd0F5QH065QH@1ZJVX0OWin069RHP1YJFT0
Hf=S06QXJ01WIfL0K6a/071`L01mOGd0oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI
0=WIf@030=WIf@0Z0?ooo`2EUID0RXZ:08J6QP2FUYH0YJFU09>CT`2IVIT0[Zj^0:NWY`1lO7`0RXZ:
0820P025QHD0TI6A09NGU`2:RXX0HV9R096AT@22PX80[:b/065QH@1MGEd0F5QH069RHP1EEED0V9RH
07IfMP1iNGT0S8b<096AT@1WIfL0K6a/04M7A`1bLW80O7al08^;R`2SXj<0UiNG0:ZZZP2?Shl0TY:B
0P2@T900?02RXZ80TI6A0:f][@2GUiL0/[:b09bLW02>SXh0QhN70<G5a@2f][H0Z:RX0:JVYP2b/[80
ZZZZ09ZJVP25QHD0N7Qh0;Fe]@2k^k/0[jn_09fMW@2RXZ80[jn_09NGU`23Ph<0/K6a09^KV`2l_;`0
SHf=0;>c/`2a/K40X:2P0:b/[02f][H0[jn_09jNWP2[Zj/0UIFE0;jn_P2c/k<0/[:b0;Zj^P2k^k/0
ZJVY0<c<c02k^k/0SXj>0;6a/@2HV9P0WinO07emO@2;Rh/0SXj>09fMW@2DU9@0_kno0:j^[P2_[jl0
`L710;Bd]080YZJV03<0ZJVY0<;2`P2MWId0ZZZZ0;^k^`2/[:`0^KVi0;jn_P2d];@0RXZ:08f=S@2X
Z:P0/k>c0<C4a02/[:`0W9bL0:NWY`2YZJT0_kno0:2PX02[Zj/0Shn?0;:b/P2i^KT0Z:RX09nOW`2W
YjL0XJ6Q0;>c/`2IVIT0X:2P0:VYZ@36a/H0/[:b0<;2`P33`l<0^;Rh0:j^[P2][Jd0/;2`0;Rh^02/
[:`0]kNg0;fm_@3<c<`0/k>c08j>SP2/[:`0UIFE0:FUY@2RXZ800P2JVYX209nOW`0R08V9R@2>SXh0
Z:RX07alO02QXJ40WYjN09fMW@2GUiL0T92@09fMW@2ATI40]KFe09jNWP2?Shl0T92@08j>SP2LW9`0
ZZZZ0:BTY02EUID0/;2`0861P@2EUID0Z:RX09JFUP2/[:`0W9bL0;>c/`2JVYX0QXJ609:BTP2/[:`0
Vi^K08R8R080Vi^K02D0W9bL09FEU@2;Rh/0WYjN08>3P`2JVYX0UYJF09BDU01iNGT0Rh^;09jNWP2J
VYX0QHF50:b/[02GUiL0VYZJ09NGU`20P800KFe]06UYJ@1nOWh0Jf][07alO01fMWH0QXJ60861P@2T
Y:@0QHF509RHV022PX80SXj>08F5Q@2?Shl0V9RH09^KV`2@T900NWYj0080Q8B402@0PH6107inOP22
PX80Ph>308^;R`2DU9@0NGUi08>3P`1IFET0O7al0820P02HV9P0SXj>07MgM`1aLG40H61P06UYJ@1`
L700KVi^07emO@1oOgl0Ng]k06EUI@1ADE40DU9B07UiN@1fMWH0QXJ608:2PP1[Jf/0:RXZ04a<C01[
Jf/0MWIf071`L01EEED208V9R@0Q06EUI@1VIVH0IfMW04i>CP1SHf<0Ph>306i^KP1<C4`0KVi^07If
MP1/K6`0HF5Q07QhN021PH40N7Qh06EUI@1WIfL0Kfm_06ATI01`L700GemO061PH012@T80LW9b07Ee
M@1oOgl0L71`05IFEP1TI6@0K6a/06i^KP24Q8@0KVi^0080IFEU00D0H61P05YJFP1IFET0NWYj0?oo
o`060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT02P3oool0VIVI0;>c/`2Q
XJ40_;bl09NGU`2FUYH0T92@08j>SP22PX82096AT@0608Z:RP2GUiL0RXZ:08V9R@2?Shl0QXJ60P29
RHT0C028R8P0Kfm_069RHP12@T80ADE504m?C`1XJ6P0MWIf069RHP1iNGT0T92@08R8R01bLW80EEEE
07]kN`25QHD0VIVI0;6a/@2JVYX0/K6a06m_K`2JVYX0X:2P09FEU@2ATI40YJFU08j>SP2a/K40XZ:R
08b<S02^[Zh0Zj^[09bLW02PX:00XJ6Q0;Fe]@2CTi<0TI6A0:6QX@2NWYh0SXj>09BDU02LW9`0UiNG
08j>SP2MWId0TY:B0:6QX@2FUYH0R8R80:JVYP38b<P0_[jn0<30`034a<@0^KVi0:6QX@2k^k/0X:2P
09^KV`2VYZH0a<C40<K6aP2ZZZX0W9bL0;Vi^@2KVi/0YJFU0;>c/`3Bd]80[jn_0<;2`P2j^[X0[Jf]
09BDU02k^k/209nOW`1809ZJVP2MWId0YJFU0:>SX`3<c<`0_;bl0;^k^`2MWId0YZJV0:2PX02l_;`0
Ti>C0:2PX02d];@0QXJ608N7Q`2^[Zh0alO70:b/[02UYJD0[:b/0<?3``2^[Zh0S8b<09ZJVP2OWil0
X:2P0:n_[`2BTY80UiNG096AT@2MWId0][Jf0;:b/P2_[jl0V9RH0:BTY02RXZ80Y:BT0;Rh^02`/;00
WinO0:^[Z`2TY:@0/k>c0<K6aP2/[:`0ZJVY0;6a/@2m_Kd0_kno0<?3``2f][H0aLG50;bl_02EUID0
[:b/0;6a/@2GUiL0TI6A0;:b/P2OWil0[jn_09fMW@2YZJT0TY:B0:2PX02QXJ40X:2P08b<S02YZJT0
KFe]0P2OWil0>@2?Shl0SHf=08n?S`2;Rh/0UIFE08N7Q`1mOGd0OWin09:BTP2LW9`0Xj>S0:^[Z`2K
Vi/0/K6a09bLW02JVYX0VIVI0:j^[P2WYjL0W9bL0820P02GUiL0SXj>07MgM`29RHT0YJFU0861P@2J
VYX0V9RH09>CT`2RXZ80SHf=09fMW@23Ph<0V9RH08:2PP2HV9P0VYZJ08n?S`20P800Kfm_05eMG@1c
Lg<0PX:207]kN`2=SHd0IFEU07moO`1lO7`0OWin06QXJ02LW9`0WinO09bLW02JVYX0WIfM0:>SX`02
0820P01C08N7Q`2GUiL0SHf=06i^KP2FUYH0S8b<09jNWP2PX:00QXJ607UiN@1^KVh0P82008j>SP2:
RXX0IFEU07]kN`1UIFD0Ph>307moO`1_Kfl0JFUY06=SH`1gMgL0MGEe065QH@2:RXX0Ph>307=cL`1V
IVH0NGUi0820P01bLW80KVi^08>3P`1fMWH0NWYj07AdM01OGel0L71`06UYJ@26QXH0MGEe07alO01e
MGD0KFe]06=SH`1fMWH0KFe]079bLP1YJFT0Kfm_07EeM@1]KFd0KVi^06ATI01`L700NGUi06ATI01e
MGD0H61P05eMG@1gMgL0I6AT07moO`1dM7@0IFEU07EeM@1[Jf/0Lg=c05IFEP15ADD0JFUY07QhN01o
Ogl0LW9b06=SH`1cLg<0J6QX08B4Q01hN7P0IVIV0861P@3oool01P3IfMT100000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI02@0oooo0;6a/@2ATI40RXZ:08V9R@2d];@0O7al07IfMP2ATI40
RHV909:BTP1iNGT0O7al08:2PP26QXH0N7Qh0861P@29RHT0Xj>S09>CT`2LW9`0Rh^;07alO01FEUH0
EeMG05eMG@1UIFD0LG5a06MWI`1ZJVX0HV9R06IVIP1_Kfl0JFUY07inOP1hN7P20:2PX00D09JFUP2E
UID0VIVI06a/K02IVIT0Shn?08^;R`2_[jl0S8b<09JFUP2d];@0_;bl0:2PX02WYjL0Xj>S096AT@2^
[Zh0[jn_09RHV02BTY8209^KV`0<09RHV023Ph<0LG5a07IfMP2HV9P0Lg=c09>CT`2EUID0^[Zj0:>S
X`2EUID0Y:BT0P2f][H02P2`/;00V9RH0<?3``2ZZZX0XZ:R0;Ng]`2c/k<0TI6A0;Rh^02QXJ420:BT
Y00<0;2`/038b<P0YZJV09jNWP2BTY80Z:RX0:^[Z`31`L40/k>c0;6a/@2j^[X0YjNW0P2f][H0?P2j
^[X0];Bd0<S8b02i^KT0XZ:R0;6a/@2k^k/0VYZJ0:BTY02b/[80]kNg0<71`@20P800[:b/0;bl_02m
_Kd0[:b/09jNWP2/[:`0XZ:R0:RXZ02PX:00Z:RX0::RXP2b/[80[Jf]0<71`@2QXJ40Ti>C09BDU02U
YJD0^;Rh09bLW02VYZH0Ng]k09RHV02_[jl0^k^k0<O7a`2h^;P0ZZZZ0;6a/@2XZ:P0/k>c0=3@d02O
Wil0[Zj^0:RXZ032`/80/[:b0;jn_P2f][H0_kno08R8R02`/;00[jn_0;6a/@2WYjL0ZZZZ09NGU`2k
^k/0_[jn0P2WYjL06`2KVi/0WIfM0:NWY`2>SXh0UIFE096AT@26QXH0[Zj^0:JVYP2XZ:P0QHF509RH
V01jNWX0TY:B09VIV@2OWil0RXZ:0::RXP2LW9`0Shn?0;Jf]P2MWId0VIVI0:RXZ02>SXh0XJ6Q08^;
R`0208b<S00X0:>SX`2IVIT0RXZ:08R8R01nOWh0QhN708F5Q@2CTi<0Shn?09NGU`21PH40UiNG07in
OP2EUID0X:2P08B4Q02;Rh/0UiNG08f=S@1eMGD0PX:207YjNP28R8P0UYJF09BDU02?Shl0PX:208f=
S@25QHD0QXJ606QXJ026QXH0QHF50861P@2JVYX0SXj>0861P@1eMGD0RHV907UiN@80R8R800l0Ph>3
08F5Q@1kNg/0OWin08f=S@1cLg<0IFEU08V9R@1hN7P0LW9b06i^KP1iNGT0NWYj08F5Q@1^KVh00P29
RHT0?P28R8P0LW9b06a/K02=SHd0J6QX06i^KP26QXH0L71`079bLP1dM7@0Hf=S07=cL`1iNGT0QXJ6
07YjNP1cLg<0MWIf0820P01`L700MWIf05IFEP1bLW80Ng]k05aLG01WIfL0P82007AdM01YJFT0H61P
08>3P`25QHD0IFEU06MWI`13@d<0OWin07EeM@1`L700JFUY07YjNP1TI6@0O7al05EEE@1VIVH0Rh^;
06e]K@1nOWh0HV9R07emO@1gMgL0DU9B07EeM@1OGel0D51@04a<C01MGEd0KVi^07IfMP1ZJVX0AdM7
07AdM01HF5P0oooo1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI07H0oooo
0::RXP2LW9`0PX:2096AT@2VYZH0S8b<08R8R02FUYH0OWin09NGU`2=SHd0YZJV0:RXZ026QXH0XZ:R
092@T02ATI40PH6109FEU@2LW9`0L71`08J6QP1]KFd0LW9b04I6AP1HF5P0DE5A06QXJ01TI6@0Cdm?
06=SH`1JFUX0M7Ad07QhN01gMgL0UIFE0:n_[`2>SXh0V9RH07moO`2a/K40ZJVY0:ZZZP28R8P0T92@
06YZJP2a/K40WIfM09nOW`2WYjL0UiNG0;jn_P2h^;P0Y:BT09NGU`2^[Zh0]KFe0:^[Z`29RHT0ZZZZ
0;Zj^P2MWId0YJFU0;bl_02FUYH0YZJV0:BTY02CTi<0Z:RX0:^[Z`2j^[X0^;Rh0<?3``2ZZZX0Y:BT
0;fm_@2XZ:P0^[Zj0:VYZ@2g]kL0_[jn0:NWY`2NWYh0^k^k0:NWY`2k^k/0VIVI0;Fe]@2_[jl0WYjN
09RHV02a/K40YJFU0;2`/02^[Zh0WIfM0::RXP2`/;00VYZJ0;jn_P2YZJT0_Kfm0:VYZ@2XZ:P0VYZJ
0::RXP2^[Zh0b/[:0<?3``2TY:@0`/;20:b/[02WYjL0U9BD0:b/[02m_Kd0YZJV0P2e]KD0;`2JVYX0
QHF50:j^[P2GUiL0V9RH0:RXZ02YZJT0YjNW0:n_[`2?Shl0T92@0>[ZjP2j^[X0V9RH0:n_[`2RXZ80
Xj>S09jNWP2a/K40_kno0;Zj^P2i^KT0`/;20;Ng]`2m_Kd0bl_;0<C4a02/[:`0]KFe0:FUY@2PX:00
[jn_0;Fe]@2QXJ40_Kfm0<G5a@2^[Zh0XZ:R0<K6aP2/[:`0ZZZZ09NGU`2^[Zh0/[:b09nOW`2/[:`0
UiNG0080UIFE01T0TI6A09>CT`2=SHd0Ti>C09JFUP2CTi<0VIVI09FEU@2HV9P0TY:B09FEU@2GUiL0
R8R80;>c/`2g]kL0YZJV0:FUY@2ATI40V9RH0:2PX02WYjL0^;Rh09nOW`2g]kL0WinO0080U9BD03@0
W9bL09RHV02MWId0SHf=0;Vi^@2@T900RXZ:08V9R@2IVIT0S8b<09:BTP2CTi<0VYZJ08V9R@2DU9@0
Ogmo07=cL`1jNWX0PH6108N7Q`25QHD0Vi^K07alO02MWId0Ti>C0861P@1nOWh0Ph>308j>SP28R8P0
^;Rh08>3P`2RXZ80UiNG09VIV@1iNGT0Shn?08R8R025QHD0X:2P08B4Q02:RXX0QHF50:BTY02@T900
Ph>308^;R`2LW9`0XJ6Q06QXJ021PH40U9BD0P2=SHd0@01iNGT0Lg=c0861P@1iNGT0Ng]k06i^KP1o
Ogl0Rh^;07IfMP1`L700IVIV07UiN@1hN7P0OGem08>3P`1/K6`0MGEe08:2PP25QHD0JFUY07YjNP23
Ph<0LG5a05aLG01oOgl0NGUi07EeM@22PX80IFEU075aL@1^KVh0OWin06i^KP1GEeL0JVYZ06EUI@1L
G5`0JVYZ07EeM@1KFe/0OWin05mOG`1WIfL0KVi^06ATI01lO7`0NGUi06YZJP1dM7@0LG5a07=cL`1j
NWX0Jf][059BDP1gMgL0KFe]06IVIP1DE5@0IFEU06][J`1eMGD0IfMW05UIF@3oool60=WIf@400000
0@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0@`3oool0Vi^K09^KV`2CTi<0@41000000021
PH40TI6A0861P@1hN7P0Rh^;07AdM02BTY80WinO09NGU`2/[:`0TI6A08j>SP2;Rh/0Vi^K08R8R020
P800Q8B4075aL@1^KVh0LW9b06EUI@1]KFd0I6AT071`L027QhL0IFEU06e]K@1lO7`0Ogmo09:BTP2Y
ZJT0TI6A09fMW@1nOWh0WYjN09^KV`28R8P0Xj>S0:n_[`2VYZH0/;2`09JFUP2VYZH0[Zj^09RHV02M
WId0V9RH0:NWY`2e]KD0Vi^K0:FUY@34a<@0/;2`0:BTY02LW9`0QHF508n?S`2_[jl0VYZJ09^KV`2b
/[800P2EUID02P2[Zj/0][Jf0:6QX@2j^[X0YZJV09ZJVP2b/[80];Bd0:NWY`2/[:`20;2`/0070:n_
[`2ZZZX0XZ:R0:2PX02RXZ80/K6a0;Jf]P020;no_`0T0;:b/P3:b/X0^k^k0:n_[`2][Jd0[Zj^0:n_
[`2VYZH0^;Rh09bLW02h^;P0YZJV0;Bd]02LW9`0ZJVY0;6a/@2c/k<0^KVi0:JVYP29RHT0Rh^;0;bl
_02ZZZX0/k>c0:>SX`2MWId0/K6a0:2PX02_[jl0clo?0:6QX@2_[jl0/[:b08^;R`34a<@0^k^k0P2X
Z:P0102NWYh0Zj^[0:JVYP2VYZH209RHV00I08f=S@2UYJD0Zj^[0::RXP2b/[80UiNG0:BTY02[Zj/0
b<S80:RXZ02g]kL0W9bL0:>SX`32`/80UYJF0:RXZ032`/80^KVi0=GEe@2d];@0_[jn0;bl_02i^KT0
^[Zj0:b/[0020:^[Z`0309^KV`2?Shl0W9bL0080XZ:R04T0];Bd09^KV`2>SXh0YJFU09nOW`2VYZH0
Ti>C08j>SP27QhL0YZJV0:6QX@2@T900UiNG0:2PX026QXH0RHV908n?S`2EUID0WinO0::RXP2_[jl0
U9BD0;6a/@2^[Zh0SHf=0:NWY`2UYJD0Xj>S09ZJVP2/[:`0UIFE08n?S`2GUiL0UYJF0:ZZZP2DU9@0
]KFe07inOP2BTY80TI6A0:6QX@1mOGd0VIVI09FEU@1cLg<0OGem0861P@1kNg/0Q8B409JFUP2KVi/0
V9RH08^;R`2BTY80QhN7096AT@21PH40MWIf07moO`2=SHd0UIFE0:b/[01]KFd0S8b<09ZJVP1nOWh0
W9bL09NGU`2;Rh/0Q8B407YjNP26QXH0KVi^0080RXZ:04T0Ogmo08V9R@1gMgL0QHF509>CT`1hN7P0
Q8B409jNWP1WIfL0PH6107QhN01QHF40QhN707emO@1lO7`0HF5Q08B4Q020P800SXj>06ATI01lO7`0
J6QX07emO@1iNGT0IVIV06i^KP1jNWX0G5aL06][J`21PH40Lg=c07alO01XJ6P0Kfm_07EeM@24Q8@0
IfMW07moO`1eMGD0Ogmo06][J`1fMWH0GUiN08:2PP1NGUh0Hf=S0820P01UIFD0KFe]09VIV@1[Jf/0
Ng]k06m_K`1aLG40L71`06i^KP1iNGT0IFEU05QHF01MGEd0LG5a069RHP1UIFD0Jf][06YZJP1]KFd0
HV9R07EeM@1dM7@0MGEe051@D01=CDd0oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI
0=WIf@030=WIf@1Y0?ooo`2FUYH0L71`09NGU`1fMWH0000007]kN`2;Rh/0QHF508:2PP2GUiL0MWIf
0:BTY02YZJT0SXj>09FEU@2CTi<0YZJV09bLW028R8P0RHV909BDU01mOGd0Ogmo07YjNP1iNGT0F5QH
06i^KP1fMWH0Kfm_06UYJ@2EUID0Ng]k09JFUP2IVIT0VYZJ0;Jf]P2OWil0Xj>S0:NWY`2MWId0YjNW
0:JVYP2GUiL0/[:b09JFUP2c/k<0^KVi075aL@2QXJ40VYZJ09>CT`2`/;00[Jf]0:>SX`2e]KD0/K6a
0:BTY02:RXX0^[Zj09fMW@2CTi<0T92@0:j^[P2FUYH0V9RH09VIV@2ATI40TY:B0:n_[`2TY:@0UYJF
0:6QX@2b/[80_Kfm09fMW@2TY:@0WIfM0<30`035aLD0/[:b0;^k^`3=cLd0aLG50<71`@3:b/X0[Zj^
09nOW`2_[jl0]KFe0:^[Z`2c/k<0TI6A0:b/[02TY:@0ZZZZ09RHV02DU9@0UIFE0<o?c`2BTY80YZJV
0:2PX02c/k<0^;Rh0080Xj>S04h0/K6a0;:b/P2n_[h0^KVi0;Jf]P2h^;P0XJ6Q0;6a/@2WYjL0UYJF
0:2PX02QXJ40X:2P0:^[Z`2ZZZX0Xj>S0::RXP2/[:`0];Bd0:2PX02ZZZX0]kNg0::RXP2>SXh0Q8B4
0;Bd]02YZJT0^KVi09nOW`2_[jl0Xj>S0<C4a02JVYX0^KVi0;Bd]02/[:`0`<3007MgM`2^[Zh0][Jf
0<;2`P2h^;P0`/;20;:b/P2o_kl0YJFU0;Vi^@2XZ:P0];Bd0:n_[`2YZJT0WinO0;2`/02[Zj/0VIVI
08j>SP2m_Kd0YZJV0:BTY02OWil0Ti>C08F5Q@1eMGD0RXZ:08>3P`2GUiL0WinO08n?S`2IVIT0XZ:R
07moO`2NWYh0YjNW09:BTP27QhL0W9bL0:>SX`2FUYH209RHV0080:2PX02IVIT0YZJV0;Ng]`2NWYh0
UIFE0:2PX02_[jl209NGU`1O0:b/[02b/[80XJ6Q09bLW02UYJD0/K6a0:>SX`2BTY80YZJV08F5Q@2>
SXh0MWIf08^;R`1cLg<0MWIf06YZJP23Ph<0TY:B09JFUP1oOgl0X:2P09^KV`2PX:00V9RH08V9R@2D
U9@0L71`08n?S`2=SHd0QHF5096AT@1^KVh0Q8B409>CT`2BTY80TI6A09ZJVP2RXZ80VIVI0820P02:
RXX0Ti>C09jNWP24Q8@0MgMg0861P@2:RXX0VYZJ07emO@21PH40TI6A08R8R01gMgL0TI6A08f=S@2;
Rh/0OGem08F5Q@1oOgl0L71`06m_K`1oOgl0NGUi05iNGP1aLG40L71`06IVIP1QHF40OWin05mOG`1V
IVH0SXj>05EEE@12@T80F5QH06=SH`1/K6`0Jf][06m_K`1eMGD0DU9B06i^KP1TI6@0K6a/05eMG@1f
MWH0R8R806UYJ@1aLG40Hf=S07MgM`1WIfL0G5aL06i^KP1>CTh00`1UIFD04`1jNWX0MGEe06ATI01c
Lg<0H61P06UYJ@1SHf<0IFEU07AdM01NGUh0IfMW065QH@1>CTh0JVYZ06i^KP1kNg/0E5AD075aL@3o
ool01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI03X0oooo08R8R02<S8`0
Ti>C0:2PX02>SXh0UYJF08j>SP27QhL0TI6A08J6QP2HV9P0Ti>C0:^[Z`2;Rh/0[Jf]0;Ng]`2<S8`0
Q8B408j>SP23Ph<0QHF507]kN`2=SHd0V9RH07YjNP24Q8@0O7al08f=S@2SXj<0Q8B407moO`1hN7P0
SHf=09bLW02EUID0^;Rh0:VYZ@2@T900TI6A09RHV02IVIT0YZJV0:j^[P2FUYH0VIVI09jNWP2ZZZX0
Xj>S09jNWP2LW9`0Ti>C0:VYZ@2ZZZX0YZJV0;2`/02XZ:P0WinO0P2WYjL04P2l_;`0^KVi0;2`/02o
_kl0Xj>S0:b/[02l_;`0YjNW0<K6aP2d];@0YJFU09RHV036a/H0]kNg0:ZZZP2g]kL0V9RH0:NWY`80
[Zj^02l0YZJV0;Ng]`2c/k<0YZJV0;6a/@2h^;P0^KVi0:RXZ02SXj<0]KFe0;Jf]P2EUID0Rh^;0:RX
Z029RHT0aLG508F5Q@29RHT0MGEe0:ZZZP2a/K40WinO0:j^[P2FUYH0VIVI0<G5a@2YZJT0/[:b0;Bd
]026QXH0[Zj^0:FUY@2a/K40TY:B08n?S`2LW9`0WIfM0:2PX02^[Zh0_;bl0;Ng]`2@T900U9BD0::R
XP2SXj<0Ti>C0::RXP0209fMW@0B09bLW02RXZ80QhN709VIV@2KVi/0Zj^[09jNWP2d];@0`L710;Jf
]P2k^k/0U9BD0;:b/P2ATI40^k^k0<30`02b/[80XZ:R0P37alL05P2][Jd0Zj^[0;no_`2VYZH0X:2P
0:RXZ02b/[80_Kfm0:BTY02a/K40WIfM0:f][@2h^;P0W9bL09jNWP2?Shl0UYJF08n?S`2/[:`0ZZZZ
09FEU@2KVi/209fMW@0H0:NWY`2EUID0X:2P09JFUP2NWYh0RXZ:09^KV`1lO7`0OGem08^;R`2MWId0
PX:20:j^[P2RXZ80WinO07EeM@2YZJT0U9BD09FEU@2UYJD0RXZ:08>3P`2PX:00XJ6Q0P2HV9P0D`2P
X:00UIFE09:BTP2QXJ40Ti>C08N7Q`2`/;00ZZZZ092@T02QXJ40RHV909fMW@25QHD0I6AT07alO02E
UID0PX:208^;R`2BTY80WYjN09ZJVP25QHD0Ogmo06MWI`1oOgl0Ti>C08N7Q`26QXH0Rh^;07alO02P
X:00YjNW08>3P`20P800FUYJ0:6QX@1kNg/0LG5a07inOP1fMWH0NGUi06m_K`20P800VYZJ08V9R@1l
O7`0EEEE069RHP1nOWh0Ph>308N7Q`1fMWH0UIFE06i^KP1gMgL0MGEe04m?C`1nOWh0P82008n?S`29
RHT0J6QX06EUI@1fMWH0IVIV07IfMP21PH40NGUi07AdM01QHF40LG5a079bLP1WIfL0Fe]K0451@@1^
KVh0J6QX07=cL`1lO7`0OWin061PH01TI6@0LW9b0080MGEe00<0JVYZ06m_K`1<C4`00P1]KFd06@22
PX80LG5a07]kN`1TI6@0LG5a06YZJP1RHV80I6AT05=CD`1_Kfl0Jf][07MgM`1RHV80Ng]k05IFEP1V
IVH0Kfm_069RHP1GEeL0EEEE06i^KP15ADD0HF5Q07IfMP3oool01P3IfMT100000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI0:H0oooo096AT@1kNg/0/;2`09JFUP2<S8`0SXj>08^;R`2CTi<0
P82007IfMP1gMgL0QXJ609VIV@2RXZ80YjNW09NGU`2OWil0UYJF06QXJ01LG5`0Ogmo0:>SX`2UYJD0
X:2P07YjNP2GUiL0T92@09:BTP22PX80L71`08B4Q01VIVH0UYJF07moO`2WYjL0VYZJ0:FUY@2KVi/0
SXj>0:b/[02VYZH0W9bL08>3P`2][Jd0ZJVY0:b/[02KVi/0VIVI09jNWP2e]KD0YjNW0;Vi^@2GUiL0
VYZJ09>CT`2@T900Shn?0:n_[`2TY:@0];Bd0:f][@2f][H0/[:b0::RXP2NWYh0/K6a0:ZZZP2b/[80
YJFU08J6QP2n_[h0VIVI092@T02SXj<0YJFU09bLW02YZJT0_;bl0;Jf]P2NWYh0/k>c0;Zj^P2OWil0
_Kfm09FEU@2BTY80]kNg0;Bd]02b/[80YjNW09ZJVP2SXj<0VIVI0:j^[P2ATI40XJ6Q0:RXZ02c/k<0
[Jf]0;fm_@2WYjL0a/K60;6a/@2XZ:P0VYZJ0:^[Z`2XZ:P0WIfM0;bl_02b/[80Shn?0:n_[`2PX:00
XZ:R0:FUY@2l_;`0WIfM0:f][@2b/[80YZJV0:2PX02ZZZX0XJ6Q09ZJVP27QhL0XJ6Q0:f][@2`/;00
Zj^[0:FUY@2PX:00c<c<0;jn_P2g]kL0RXZ:0;Bd]02b/[80[:b/0::RXP2c/k<0Zj^[09fMW@2`/;00
_[jn0;bl_02b/[80YZJV0;>c/`3EeMD0[jn_0:f][@2b/[80]KFe09nOW`2>SXh0/k>c0:n_[`2`/;00
/k>c0:VYZ@2MWId0[Jf]09nOW`2][Jd0V9RH0P2;Rh/0<@2:RXX0OWin09ZJVP2=SHd0Vi^K07emO@2A
TI40Ng]k09^KV`2/[:`0QHF508f=S@2KVi/0Ng]k09BDU02PX:00OWin09nOW`2c/k<0Z:RX09:BTP2E
UID0Z:RX09jNWP2j^[X0WYjN08:2PP2^[Zh0W9bL0:BTY02ZZZX0WYjN07moO`1hN7P0T92@09BDU02O
Wil0OWin09:BTP1jNWX0NGUi079bLP22PX80O7al07AdM01bLW80Ti>C08n?S`2PX:000P2OWil0A`2Q
XJ40SXj>07moO`1oOgl0NGUi07]kN`1lO7`0YjNW0820P01mOGd0R8R80820P024Q8@0RHV909>CT`2=
SHd0S8b<07AdM02UYJD0UYJF07emO@2;Rh/0Ogmo06i^KP1oOgl0Ph>307QhN01cLg<0Q8B406i^KP1U
IFD0Ng]k07QhN01jNWX0PX:207alO01fMWH0MGEe08J6QP1VIVH0Lg=c07moO`1bLW80J6QX07QhN01S
Hf<0DE5A06UYJ@21PH40C4a<0861P@1UIFD0NGUi06m_K`0b<S80LW9b06QXJ01aLG40Hf=S06a/K01j
NWX0E5AD06EUI@1`L700M7Ad079bLP1cLg<0KVi^06YZJP21PH40HV9R0080KFe]0100K6a/07UiN@1c
Lg<0GemO07inOP1UIFD0NGUi06EUI@1aLG40H61P06=SH`26QXH0GUiN06QXJ01iNGT0KFe]0P21PH40
101PH600ADE505eMG@3oool60=WIf@4000000@3IfMT001H0fMWI0P0000040=WIf@0i0?ooo`2GUiL0
VIVI07UiN@2;Rh/0U9BD08n?S`2UYJD0U9BD07YjNP2>SXh0Ng]k09BDU02UYJD0UIFE08F5Q@1oOgl0
RXZ:07]kN`2MWId0Q8B40820P02CTi<0UYJF0:6QX@2PX:00S8b<07emO@2KVi/0Shn?07AdM02;Rh/0
TY:B09NGU`2ATI40Vi^K0;Jf]P2XZ:P0ZJVY09:BTP2:RXX0SHf=0:BTY02PX:00Rh^;09jNWP2ZZZX0
UYJF0:^[Z`28R8P0X:2P0;:b/P2LW9`0];Bd09:BTP2RXZ80W9bL0080WYjN0240[Zj^07inOP37alL0
T92@0:NWY`2b/[80]kNg0;2`/02NWYh0][Jf0:2PX02/[:`0YJFU09RHV02[Zj/0YjNW0:VYZ@2e]KD0
Xj>S0;2`/02HV9P0U9BD0:FUY@2VYZH0NGUi08F5Q@2f][H0];Bd0;Ng]`2n_[h0`l?30:j^[P2QXJ40
0P2TY:@01`2j^[X0/k>c0::RXP2;Rh/0^;Rh0=3@d02`/;000P2XZ:P03@2/[:`0V9RH0<71`@2_[jl0
[Zj^0;no_`2/[:`0/K6a0:NWY`2OWil0RXZ:0:n_[`2QXJ400P2TY:@09P2`/;00YJFU08n?S`2ZZZX0
YZJV0:b/[02WYjL0YJFU09fMW@29RHT0SXj>0<30`02SXj<0[Jf]0;Ng]`2MWId0W9bL0:NWY`2EUID0
Ti>C09^KV`2:RXX0LG5a08f=S@2;Rh/0Ti>C0<S8b02_[jl0UIFE0<71`@2e]KD0XZ:R0;jn_P2EUID0
Xj>S0<S8b02e]KD0VYZJ0P2QXJ40;@2d];@0/K6a0:FUY@2c/k<0ZZZZ0:BTY02NWYh0ZZZZ0:2PX02L
W9`0/K6a09fMW@2LW9`0ZJVY09NGU`2UYJD0WIfM08Z:RP2UYJD0TI6A07UiN@25QHD0MGEe0:6QX@2L
W9`0Z:RX0:FUY@27QhL0WinO09RHV022PX80Ph>309fMW@2QXJ40RHV908j>SP20P800Ph>308Z:RP2Q
XJ40MGEe07emO@2IVIT0QhN708J6QP02096AT@0Y08B4Q02IVIT0Y:BT09VIV@26QXH0NWYj09RHV01h
N7P0P82008N7Q`2:RXX0Q8B406i^KP1[Jf/0V9RH08^;R`23Ph<0OGem0820P021PH40W9bL09BDU02;
Rh/0V9RH0:6QX@26QXH0P82008n?S`2<S8`0JFUY07alO01fMWH0Ph>307QhN01nOWh0MWIf09>CT`24
Q8@0QXJ608Z:RP1CDe<00P23Ph<09P1/K6`0RXZ:0861P@29RHT0N7Qh079bLP1cLg<0M7Ad07EeM@1o
Ogl0P82007moO`25QHD0L71`08j>SP2<S8`0Lg=c07MgM`1oOgl0JFUY06m_K`1[Jf/0MGEe096AT@1P
H600L71`06UYJ@1fMWH0T92@07inOP1`L700HF5Q069RHP1WIfL0Q8B406a/K01cLg<0J6QX0P1eMGD0
6P2?Shl0De=C07QhN01NGUh0FUYJ061PH017AdL0J6QX06UYJ@1jNWX0LG5a051@D01IFET0IVIV059B
DP1UIFD0PX:205YJFP1]KFd0=CDe05QHF01CDe<0I6AT055AD@1UIFD0oooo1@3IfMT200000040fMWI
000F0=WIf@030000003IfMT0fMWI00<0fMWI00T0oooo08>3P`2RXZ80UYJF0;>c/`20P800RHV90:FU
Y@2OWil00P2?Shl0?`1cLg<0OGem08R8R020P800LG5a08R8R02BTY80W9bL08:2PP2<S8`0T92@09nO
W`2TY:@0UiNG079bLP2GUiL0OWin0861P@2FUYH0TY:B0:>SX`2IVIT0Vi^K0;6a/@2:RXX0Xj>S09VI
V@2][Jd0VIVI0:FUY@2@T900WIfM0:VYZ@2LW9`0TY:B08Z:RP2?Shl0UiNG0:6QX@2LW9`0RHV908n?
S`2OWil0^KVi0;2`/02][Jd0[:b/0:2PX02XZ:P0/K6a0:BTY02d];@0T92@0:RXZ02FUYH0/K6a09VI
V@2SXj<0VIVI0:b/[02XZ:P0ZJVY0:ZZZP020:^[Z`0?0:f][@2LW9`0VIVI09BDU02OWil0^;Rh0;Ng
]`30`<00[Zj^0;Ng]`2f][H0[jn_0:VYZ@33`l<0^[Zj0080ZZZZ06`0QXJ60;Zj^P2k^k/0ZZZZ0:^[
Z`2`/;00^;Rh0:b/[02?Shl0PH610:n_[`2MWId0WYjN0;jn_P2SXj<0XJ6Q0:^[Z`2WYjL0Z:RX0;>c
/`2`/;00XJ6Q08>3P`2MWId0XZ:R09ZJVP2HV9P0Ng]k0;:b/P2a/K40Zj^[0:>SX`2GUiL0/k>c0:RX
Z02`/;00ZJVY0:FUY@2a/K40YJFU09:BTP27QhL0KFe]08F5Q@1`L700H61P059BDP1CDe<0GemO071`
L01_Kfl0Vi^K0:RXZ02WYjL0^k^k0<30`02NWYh0YjNW0;>c/`2^[Zh0`L710:^[Z`2ZZZX0YjNW0;>c
/`26QXH0Zj^[0:ZZZP2b/[80Zj^[0;Jf]P2NWYh0Ti>C0:>SX`2HV9P0YJFU07]kN`2=SHd0T92@08^;
R`2OWil0Shn?08F5Q@2BTY80XJ6Q071`L02HV9P0Zj^[08J6QP2NWYh0UiNG0:>SX`2WYjL0VIVI08n?
S`2LW9`0T92@09>CT`2SXj<0S8b<0;>c/`2OWil0MgMg08J6QP1lO7`0RXZ:07AdM01^KVh208>3P`11
08Z:RP27QhL0V9RH09bLW02=SHd0T92@0:BTY01jNWX0TI6A08R8R029RHT0Jf][06UYJ@28R8P0NWYj
09^KV`2<S8`0J6QX08F5Q@1`L700QHF507YjNP2LW9`0VYZJ09:BTP20P800UYJF09^KV`1bLW80XZ:R
096AT@1bLW80RHV907moO`1`L700KFe]07AdM02>SXh0TY:B07inOP1`L700Ogmo08j>SP1TI6@0RHV9
07EeM@1VIVH0Rh^;08F5Q@1[Jf/0OWin08:2PP26QXH0J6QX08:2PP1bLW80J6QX07UiN@1PH600Hf=S
05ADE01bLW80O7al05=CD`1KFe/00P1[Jf/0;01nOWh0KFe]06e]K@1VIVH0I6AT06YZJP1TI6@0IfMW
05iNGP1VIVH0F5QH05mOG`1ZJVX0E5AD06a/K01QHF40MWIf055AD@1XJ6P0NGUi05EEE@1YJFT0KFe]
05MGE`1=CDd0MWIf069RHP1OGel0J6QX06m_K`1QHF40D51@06ATI01dM7@0I6AT08N7Q`1`L700J6QX
06][J`1/K6`0Hf=S05QHF01:BTX0oooo1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI
00<0fMWI02l0oooo0;6a/@2KVi/0VYZJ09FEU@2KVi/0UiNG09:BTP23Ph<0QHF509RHV024Q8@0NWYj
0820P01HF5P0QXJ60:6QX@2KVi/0F5QH09BDU02RXZ80UiNG08N7Q`2:RXX0Y:BT09bLW02PX:00ZZZZ
07UiN@2LW9`0]KFe0:NWY`2TY:@0NWYj09:BTP2:RXX0XJ6Q08V9R@2ZZZX0YZJV09NGU`2EUID0XZ:R
09JFUP2?Shl0QXJ60820P00209jNWP0E09bLW02b/[80XZ:R09fMW@2BTY80S8b<09JFUP2a/K40UiNG
0:b/[02DU9@0TI6A0:JVYP2GUiL0/;2`08^;R`2d];@0Xj>S0:BTY02SXj<0SHf=0080YZJV00L0ZJVY
08b<S02KVi/0VIVI0:^[Z`3Cdm<0Y:BT0080[:b/03T0`L710:VYZ@2ZZZX0YJFU0:VYZ@2XZ:P0YjNW
0:6QX@2m_Kd0UiNG0:FUY@2MWId0b/[:09ZJVP2UYJD0Y:BT0;bl_02HV9P0[:b/09bLW02XZ:P0_Kfm
0;Vi^@2m_Kd0][Jf0<K6aP2?Shl0WYjN0:VYZ@2HV9P0_[jn0:b/[02PX:00UIFE07QhN02][Jd0SXj>
09ZJVP2ATI40WYjN09FEU@2WYjL0Z:RX0;Zj^P2NWYh0[jn_0;>c/`2SXj<0/k>c0:VYZ@2RXZ80][Jf
0;Ng]`2DU9@0NWYj06QXJ01FEUH00P1QHF407`1CDe<0@410075aL@20P800VIVI092@T02f][H0[Zj^
0;Vi^@2][Jd0^k^k0:f][@3<c<`0Shn?0:NWY`3Bd]80Y:BT0:j^[P2YZJT0XZ:R09JFUP2d];@0Vi^K
096AT@2a/K40Xj>S09RHV02MWId0X:2P09JFUP1mOGd00P2>SXh0CP2<S8`0V9RH09fMW@24Q8@0XJ6Q
0861P@29RHT0Shn?0:>SX`2RXZ80Ogmo08^;R`2/[:`0^k^k09fMW@2:RXX0[jn_0:NWY`2@T900UYJF
09RHV02b/[80Rh^;09JFUP1eMGD0Q8B407EeM@2NWYh0VYZJ07EeM@1cLg<0R8R807UiN@24Q8@0T92@
09RHV02/[:`0Shn?0861P@1jNWX0OGem0820P01fMWH0Q8B407]kN`1bLW80Ogmo07=cL`1/K6`0JFUY
07alO01mOGd0QHF50:FUY@2OWil0QhN709FEU@2VYZH0W9bL0820P01/K6`0PH6109:BTP2GUiL0Rh^;
08b<S02FUYH0N7Qh06QXJ02KVi/0Jf][05EEE@1/K6`0HF5Q079bLP1OGel0Ti>C07EeM@80O7al03d0
Fe]K079bLP1^KVh0QHF506QXJ02:RXX0IfMW06EUI@23Ph<0KVi^05eMG@1NGUh0J6QX06e]K@20P800
OWin079bLP1QHF40QhN706EUI@1dM7@0EeMG07emO@1^KVh0IFEU06UYJ@1eMGD0Ogmo05aLG023Ph<0
MGEe06e]K@1RHV80HF5Q07]kN`1]KFd0Fe]K08J6QP1PH600ADE507EeM@1PH600OGem05eMG@1GEeL0
O7al05ADE01eMGD0L71`07EeM@1VIVH0LG5a05IFEP1ADE40JFUY06=SH`1`L700LG5a07emO@1KFe/0
oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0H0?ooo`2MWId0Rh^;
096AT@2a/K40RXZ:0861P@2CTi<0OWin09nOW`2>SXh0RXZ:08^;R`25QHD0OWin07emO@28R8P0O7al
08^;R`2ATI40Rh^;0:NWY`2EUID0VIVI0P2BTY80Q`2HV9P0YZJV08j>SP2:RXX0VYZJ09RHV02c/k<0
WIfM0:VYZ@24Q8@0TI6A0:n_[`2ZZZX0UYJF07moO`1hN7P0OWin08F5Q@1QHF40HV9R07QhN02<S8`0
PH6107alO02HV9P0YjNW09NGU`2DU9@0VYZJ0:VYZ@2VYZH0/[:b0:6QX@1mOGd0P82005=CD`24Q8@0
W9bL0:6QX@2k^k/0Z:RX0:BTY02OWil0WYjN0:j^[P27QhL0V9RH0:2PX02YZJT0X:2P0;Ng]`2TY:@0
_kno0;Zj^P2WYjL0WIfM0<;2`P2b/[80SXj>0;2`/02CTi<0/k>c0:RXZ02QXJ40Shn?09jNWP2KVi/0
Z:RX0;:b/P2e]KD0Zj^[0:JVYP2g]kL0Y:BT0;Jf]P2XZ:P0ZJVY0:6QX@35aLD0[:b/0:6QX@3<c<`0
UYJF09:BTP2_[jl0RXZ:0:6QX@2DU9@0[Zj^096AT@2SXj<0X:2P09ZJVP2i^KT0WinO0;Jf]P2b/[80
]KFe0:VYZ@2DU9@0^k^k0:RXZ02LW9`0];Bd0:VYZ@2/[:`0UiNG08Z:RP000000F5QH03hn?P1DE5@0
ATI603dm?@1FEUH0LG5a05QHF01]KFd0KVi^09RHV02EUID0XZ:R0:^[Z`37alL0_[jn0;Fe]@2b/[80
[Jf]0:2PX02DU9@0VYZJ0:6QX@2OWil0/;2`08j>SP020:6QX@0L09bLW02VYZH0V9RH08b<S02TY:@0
U9BD0:6QX@24Q8@0V9RH09nOW`28R8P0UYJF09>CT`22PX80Kfm_0:ZZZP2HV9P0WIfM09JFUP1nOWh0
Q8B40:6QX@2YZJT0/K6a0:VYZ@2WYjL0Y:BT09bLW080YjNW01<0VYZJ096AT@1kNg/0T92@071`L02C
Ti<0X:2P092@T02LW9`0Ng]k0:FUY@1iNGT0UIFE06e]K@23Ph<0UYJF08B4Q026QXH0V9RH0080QHF5
01@0KVi^071`L029RHT0R8R806YZJP23Ph<0Q8B405mOG`1bLW80QXJ609BDU02ATI40OWin08N7Q`28
R8P0RHV908Z:RP2FUYH0Ogmo07]kN`80NGUi04h0MWIf06m_K`1gMgL0LG5a08F5Q@1^KVh0MWIf06EU
I@21PH40Hf=S069RHP1TI6@0LW9b06][J`21PH40MGEe06MWI`1mOGd0P820071`L01ZJVX0G5aL09JF
UP1RHV80NWYj05IFEP1gMgL0N7Qh05]KF`1LG5`0GEeM07emO@1MGEd0LW9b07MgM`1]KFd0L71`06QX
J01RHV80HF5Q06=SH`1dM7@0LG5a06UYJ@1QHF40JVYZ05ADE01YJFT0L71`05aLG01`L700NWYj065Q
H@1LG5`0IVIV07EeM@1bLW80N7Qh04i>CP1QHF40E5AD061PH01JFUX0M7Ad07QhN01FEUH0K6a/06=S
H`1OGel0L71`06ATI01_Kfl0Jf][05aLG01FEUH0FEUI07MgM`3oool60=WIf@4000000@3IfMT001H0
fMWI00<000000=WIf@3IfMT00`3IfMT05`3oool0RXZ:09ZJVP2QXJ40WYjN0:2PX01hN7P0TI6A08B4
Q02@T900SXj>08V9R@2LW9`0N7Qh08f=S@1fMWH0OGem08N7Q`28R8P0XJ6Q09bLW01dM7@0Ti>C0080
QhN70P2ATI40S`2NWYh0XZ:R08Z:RP26QXH0Z:RX06e]K@2ATI40P82009VIV@2JVYX0SHf=08V9R@2D
U9@0IVIV07inOP1iNGT0GemO071`L01dM7@0De=C05eMG@1hN7P0OWin08J6QP2HV9P0XJ6Q09BDU02X
Z:P0TY:B0:VYZ@2CTi<0SXj>0861P@1VIVH0000005ADE02GUiL0WYjN0:VYZ@2ZZZX0YjNW0;Bd]02H
V9P0Xj>S0:NWY`2EUID0Rh^;0:JVYP2CTi<0/k>c0:b/[02TY:@0XJ6Q08b<S02a/K40^k^k0;Bd]02_
[jl0Z:RX09^KV`2/[:`0YJFU0:b/[02][Jd0/K6a0:6QX@2VYZH0[jn_09RHV02[Zj/0][Jf09^KV`2P
X:00]kNg0:j^[P2JVYX0Xj>S0:RXZ02ZZZX0W9bL09>CT`2BTY80W9bL0;Fe]@2_[jl0UYJF0;jn_P2P
X:00YjNW09>CT`2MWId0VYZJ0:6QX@2NWYh0/[:b09jNWP2ATI40Xj>S0:j^[P2PX:00UYJF09bLW02d
];@0Y:BT0:ZZZP2DU9@0GemO04=3@`0g=cL0=3@d04U9B@1EEED0MWIf06MWI`1aLG40MGEe06EUI@1H
F5P0GEeM08J6QP2JVYX0ZZZZ0:FUY@2[Zj/0YJFU08n?S`2^[Zh0UIFE0:JVYP2PX:00]KFe0:ZZZP2K
Vi/0SHf=08j>SP2BTY80Ph>308Z:RP2WYjL0Zj^[09^KV`2:RXX0[jn_0080VYZJ0140Vi^K08J6QP2P
X:00QXJ60820P02IVIT0NWYj08Z:RP2OWil0U9BD09NGU`27QhL0VYZJ09>CT`2^[Zh0Xj>S09fMW@02
09VIV@1k0:2PX02[Zj/0Ti>C09^KV`28R8P0Ti>C08R8R02<S8`0SXj>09NGU`2;Rh/0[:b/08n?S`25
QHD0UYJF07moO`2:RXX0Q8B40:VYZ@2HV9P0XJ6Q09:BTP1lO7`0GUiN08^;R`1VIVH0MGEe07moO`1c
Lg<0IVIV08J6QP2?Shl0Vi^K09RHV02;Rh/0MGEe09RHV024Q8@0Vi^K08j>SP25QHD0HV9R07]kN`2>
SXh0P82007moO`2>SXh0LG5a07MgM`1dM7@0Jf][08^;R`20P800SHf=07YjNP1ZJVX0LW9b07IfMP2=
SHd0NGUi06ATI01fMWH0Kfm_06e]K@1GEeL0K6a/07UiN@1eMGD0LG5a05ADE01gMgL0GUiN065QH@1I
FET0NWYj08V9R@1/K6`0De=C06ATI01RHV80Kfm_05MGE`16ATH0H61P06IVIP1YJFT0EeMG06a/K019
BDT0Hf=S06e]K@1KFe/0M7Ad05YJFP1oOgl0Fe]K08:2PP1lO7`0LW9b06m_K`1HF5P0KFe]06EUI@1P
H600NGUi06YZJP1lO7`0HV9R06MWI`1MGEd0DU9B06i^KP1TI6@0GEeM06QXJ01UIFD0F5QH07EeM@1<
C4`0CTi>07=cL`1TI6@0oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WI
f@0S0?ooo`2TY:@0Shn?09>CT`21PH40PX:20;Rh^02GUiL0P820096AT@2JVYX0RHV908^;R`20P800
UiNG08n?S`23Ph<0P82009BDU022PX80SXj>07]kN`2TY:@0Rh^;0;Bd]023Ph<0Z:RX07moO`2>SXh0
Shn?09RHV01hN7P0O7al08R8R02NWYh00P2KVi/0=@23Ph<0QHF5079bLP1DE5@0G5aL06EUI@1eMGD0
N7Qh06m_K`1`L700MGEe079bLP2CTi<0VYZJ09nOW`2MWId0UiNG09nOW`2i^KT0Rh^;09NGU`2/[:`0
Xj>S07EeM@1VIVH0RHV90:f][@2a/K40][Jf096AT@2LW9`0^[Zj09fMW@2VYZH0QXJ60:VYZ@2MWId0
/[:b09JFUP2f][H0UYJF0;>c/`2][Jd0Z:RX0:6QX@2[Zj/0ZJVY0;fm_@2PX:00WinO0;:b/P2HV9P0
SHf=0080X:2P00L0/[:b09^KV`2KVi/0]KFe0:JVYP2^[Zh0Zj^[0080YZJV0100[Zj^0;Rh^02TY:@0
_[jn0:n_[`2VYZH0Q8B409:BTP2OWil0XZ:R0:n_[`2IVIT0Z:RX0:ZZZP2`/;00[:b/0P2FUYH0@02_
[jl0[:b/08V9R@2/[:`07alO0;fm_@2b/[80Zj^[09jNWP2d];@0X:2P0<30`02MWId0NGUi07]kN`15
ADD0=cLg0410@01SHf<0H61P08:2PP1gMgL0G5aL06UYJ@1bLW80HF5Q03lo?`1NGUh0T92@08b<S02]
[Jd0Y:BT0::RXP2j^[X0Shn?09jNWP2GUiL0XJ6Q09jNWP25QHD0RHV908Z:RP25QHD0YjNW08f=S@2J
VYX0XJ6Q0:>SX`2IVIT0Zj^[09RHV02b/[80W9bL09FEU@2FUYH0RXZ:09RHV01gMgL0QXJ607QhN02U
YJD0PH6108f=S@2ZZZX207YjNP1407moO`2EUID0ZJVY0;Rh^02GUiL0[Zj^0;6a/@2_[jl0/K6a09JF
UP2MWId0VIVI07alO02DU9@0Rh^;0:j^[P2KVi/0Rh^;09bLW02CTi<0QHF507moO`25QHD0OGem09>C
T`27QhL0RHV909bLW02KVi/0Xj>S08f=S@1mOGd0QXJ609FEU@1WIfL0U9BD08n?S`2ATI40W9bL08n?
S`27QhL0QHF508R8R02:RXX0RHV907IfMP26QXH0OWin06][J`1eMGD0Q8B408j>SP1hN7P0Ng]k07em
O@20P800NWYj08>3P`25QHD0RHV9071`L01^KVh0PH61096AT@1lO7`0NGUi06IVIP1[Jf/208F5Q@0P
05mOG`1`L700Kfm_07=cL`1<C4`0L71`07alO00o?cl0JFUY06EUI@1MGEd0KFe]08B4Q01UIFD0OGem
06a/K01cLg<0MGEe06UYJ@23Ph<0L71`06=SH`1WIfL0GemO04];B`1iNGT0Kfm_08F5Q@1iNGT0Kfm_
07MgM`1YJFT206a/K00>04U9B@1NGUh0LW9b07=cL`1TI6@0Hf=S05EEE@1VIVH0G5aL06YZJP1FEUH0
J6QX05aLG01=CDd206][J`0906QXJ01QHF40BDU903dm?@1QHF40?Cdm05EEE@1VIVH0oooo00H0fMWI
0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@1B0?ooo`2SXj<0Ti>C09FEU@1cLg<0
WYjN09JFUP2:RXX0Vi^K09>CT`1nOWh0RXZ:0:FUY@2ATI40SHf=08:2PP2>SXh0Ti>C09JFUP2GUiL0
TI6A09NGU`23Ph<0T92@08N7Q`2PX:00U9BD09ZJVP2FUYH0XJ6Q0::RXP2ATI40X:2P09:BTP1nOWh0
Q8B407inOP21PH40OWin07QhN01jNWX0JFUY06m_K`1jNWX0UIFE08R8R01QHF40Hf=S06ATI027QhL0
PH6108B4Q02NWYh0TI6A09fMW@2CTi<0VIVI0:6QX@2/[:`0YZJV0:f][@2JVYX0V9RH08b<S02IVIT0
U9BD0;2`/02SXj<0/;2`0:NWY`2a/K40]kNg0;Bd]02EUID0UYJF0:VYZ@2UYJD0_Kfm0:j^[P2a/K40
Zj^[0;Vi^@80WYjN00@0WIfM0:VYZ@2a/K40X:2P0P2a/K407`2=SHd0YjNW0:n_[`2VYZH0^k^k0:>S
X`2f][H0/;2`09BDU02f][H0/;2`096AT@2MWId0]KFe09VIV@2e]KD0][Jf0:>SX`2o_kl0WinO0:f]
[@2XZ:P0WYjN0:6QX@2SXj<0WinO09VIV@2WYjL0Y:BT09bLW02d];@00P2XZ:P0BP2>SXh0XJ6Q08Z:
RP2MWId0Ph>309NGU`2TY:@0/;2`09RHV01@D500DE5A03Xj>P0];Bd0JFUY09ZJVP2MWId0TI6A07in
OP2BTY80IfMW04Q8B01BDU80ATI606IVIP2KVi/0XZ:R0;Ng]`2^[Zh0ZJVY09nOW`2QXJ40Vi^K0:2P
X02>SXh0TY:B0861P@28R8P0T92@06YZJP2@T900Shn?09ZJVP2][Jd0/;2`0:VYZ@30`<00ZJVY0:2P
X029RHT0UiNG09VIV@2LW9`0Z:RX0:VYZ@2=SHd0OWin09jNWP1iNGT0[:b/08N7Q`2/[:`0Vi^K08N7
Q`2/[:`0VYZJ09JFUP2ATI40OGem08b<S02TY:@0ZZZZ07UiN@2LW9`0SHf=0P27QhL09@2NWYh0X:2P
092@T026QXH0Shn?08f=S@25QHD0T92@0:2PX01]KFd0Q8B407AdM01oOgl0MgMg08Z:RP2PX:00TI6A
08>3P`2<S8`0RHV90:2PX029RHT0RXZ:09>CT`2@T900UiNG09FEU@2JVYX0QHF5096AT@1lO7`0PX:2
09ZJVP1bLW80S8b<061PH02<S8`00P26QXH0C01cLg<0Ng]k07MgM`1[Jf/0KFe]07MgM`1hN7P0OWin
07alO028R8P0QhN707YjNP1oOgl0Kfm_07emO@17AdL0F5QH07UiN@1GEeL0F5QH079bLP1TI6@0Jf][
07AdM01oOgl0HV9R07YjNP1^KVh0LG5a05MGE`1UIFD0MWIf07YjNP13@d<0M7Ad06ATI01aLG40J6QX
079bLP1GEeL0J6QX07alO01_Kfl0H61P07=cL`2:RXX0NWYj09^KV`1QHF40IVIV05YJFP1lO7`0R8R8
071`L01cLg<0>c/k04];B`1NGUh0IfMW06IVIP1bLW80Hf=S055AD@1GEeL0GUiN07YjNP1VIVH0FEUI
05iNGP1VIVH0Hf=S06i^KP1FEUH0D51@04i>CP3oool60=WIf@4000000@3IfMT001H0fMWI00<00000
0=WIf@3IfMT00`3IfMT0>03oool0RXZ:09jNWP1gMgL0TI6A0:j^[P2MWId0VIVI0;Bd]028R8P0WIfM
0861P@2MWId0R8R809RHV02OWil0Ti>C0:ZZZP2ATI40QXJ609:BTP2RXZ80X:2P0:^[Z`2>SXh0S8b<
07inOP2OWil0[:b/09RHV02PX:00W9bL0::RXP2PX:00SXj>09ZJVP2:RXX0Rh^;06IVIP1oOgl0MGEe
08b<S01kNg/0PX:209VIV@2QXJ40OGem07MgM`2<S8`0K6a/07EeM@2<S8`0Vi^K0:>SX`2>SXh0WIfM
0P2TY:@05`2ATI40Vi^K0:JVYP2RXZ80/;2`0:2PX02a/K40XZ:R09ZJVP2e]KD0^;Rh09nOW`2MWId0
Vi^K0:^[Z`2a/K40VYZJ0:2PX02XZ:P0UiNG0:FUY@2b/[80^;Rh0080/k>c00L0WinO0;:b/P2d];@0
];Bd0;Vi^@2FUYH0/K6a0080WIfM02d0_kno0:b/[02l_;`0X:2P0;bl_02LW9`0WinO0:RXZ02WYjL0
[Jf]09>CT`2MWId0YJFU08b<S02PX:00];Bd0;2`/02MWId0^[Zj0;Bd]02FUYH0YZJV0::RXP2VYZH0
YJFU09JFUP2[Zj/0/k>c08f=S@2i^KT0ZZZZ0:RXZ02`/;00Zj^[09>CT`2DU9@0YjNW0;>c/`2PX:00
ZZZZ06ATI011@D40>CTi055AD@1/K6`00P2LW9`05P2>SXh0PX:208n?S`1kNg/0L71`05ADE01GEeL0
EUIF08F5Q@2g]kL0_Kfm09jNWP2QXJ40YZJV0::RXP2WYjL0ZJVY09^KV`2PX:00TY:B09BDU01YJFT2
075aL@0K07EeM@23Ph<0Rh^;0:JVYP2QXJ40UIFE08B4Q02h^;P0T92@09JFUP2h^;P0Xj>S08:2PP2T
Y:@0XZ:R09VIV@2TY:@0TY:B09>CT`27QhL0U9BD08F5Q@2PX:00QXJ607moO`24Q8@0YJFU0080Xj>S
00d0VIVI09^KV`2KVi/0Shn?0:6QX@2>SXh0PH6109nOW`2PX:00RHV90:j^[P2JVYX0SHf=0080QhN7
00L0Rh^;08Z:RP2;Rh/0QHF508b<S02DU9@0WIfM0080TI6A01h0RXZ:09BDU02EUID0QXJ6092@T02=
SHd0PX:207moO`2JVYX0Ph>308b<S02:RXX0MWIf07QhN021PH40O7al07UiN@1mOGd0JFUY06MWI`23
Ph<0LW9b07AdM020P800IFEU07MgM`20P800MWIf0861P@1XJ6P208^;R`05079bLP2;Rh/0Kfm_0820
P01`L7000P000000>`1eMGD0Lg=c06m_K`1RHV80M7Ad06a/K01dM7@0F5QH07moO`1VIVH0Kfm_07Qh
N01<C4`0Jf][06m_K`1>CTh0HF5Q07]kN`1aLG40Lg=c05]KF`1XJ6P0JVYZ06e]K@1nOWh0NGUi07Yj
NP1fMWH0Hf=S075aL@1CDe<0L71`06e]K@1_Kfl0IfMW05QHF01]KFd0H61P06QXJ014A4@0J6QX03Lg
=`1BDU80HV9R06MWI`1dM7@0I6AT075aL@1KFe/0I6AT051@D01FEUH0IVIV05=CD`1eMGD0Fe]K05iN
GP1PH600oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0:0?ooo`2M
WId0Zj^[0:BTY02KVi/0XZ:R08^;R`2GUiL0PX:208n?S`80WYjN04`0RHV909:BTP2UYJD0Y:BT08N7
Q`2IVIT0Ti>C06QXJ01aLG40T92@09nOW`2=SHd0YJFU09NGU`2FUYH0SXj>0::RXP2LW9`0[Zj^09bL
W02DU9@0WIfM09JFUP2DU9@0R8R805EEE@1kNg/0Lg=c07EeM@1oOgl0V9RH0:2PX02b/[80/k>c096A
T@2:RXX0Ph>3071`L01UIFD0EUIF08n?S`2YZJT0S8b<09FEU@2ATI40T92@0;Vi^@2MWId0SXj>0::R
XP2d];@0Ti>C08J6QP2ATI40WinO09BDU02_[jl0WinO0;:b/P2/[:`0[Zj^09nOW`2h^;P0VYZJ0:ZZ
ZP2NWYh0XZ:R0:JVYP2JVYX0/K6a09JFUP33`l<0YZJV0:b/[02ZZZX0VIVI0P2WYjL0102l_;`0XJ6Q
0:6QX@2JVYX20:FUY@0C0;Vi^@2=SHd0b/[:0:n_[`36a/H0/K6a09VIV@2YZJT0Xj>S09VIV@2<S8`0
_;bl0;Rh^02/[:`0_[jn0:6QX@2WYjL0/k>c0;:b/P020;2`/080WYjN0980UYJF09BDU01hN7P0WYjN
0;Rh^02KVi/0YjNW0:f][@2/[:`0VIVI09RHV02[Zj/0NWYj05aLG012@T80>SXj04i>CP26QXH0YjNW
0<C4a02UYJD0W9bL0:FUY@1cLg<0BDU904Q8B00j>SX0ADE507emO@2h^;P0b<S80;Ng]`2CTi<0WinO
09^KV`2SXj<0[Zj^08^;R`2EUID0Vi^K08>3P`1nOWh0QXJ607inOP1MGEd0NWYj07inOP2RXZ80T92@
0::RXP2g]kL0UIFE09JFUP2MWId0Vi^K0:6QX@2IVIT0PH6109BDU024Q8@0R8R808^;R`2XZ:P0[:b/
09ZJVP2@T900TI6A09bLW02CTi<0X:2P09NGU`2LW9`0ZZZZ0:FUY@2JVYX0Ph>309fMW@1NGUh0Rh^;
0::RXP2>SXh0UiNG092@T02MWId0VIVI08f=S@1fMWH0LW9b096AT@26QXH0RHV908n?S`2NWYh0UiNG
08J6QP1oOgl0PX:209JFUP28R8P0XZ:R09nOW`2ATI40PX:208^;R`1/K6`0VYZJ092@T02EUID0VIVI
079bLP2DU9@0QhN705=CD`1hN7P0I6AT07UiN@2<S8`0OWin0861P@1YJFT0P82008V9R@1WIfL0Lg=c
05YJFP1RHV80Ogmo075aL@1XJ6P0Jf][0861P@1fMWH0E5AD075aL@1CDe<0EUIF05EEE@1LG5`0HF5Q
051@D01VIVH0IfMW05mOG`1YJFT0GUiN07AdM080IFEU00X0K6a/07=cL`1/K6`0Lg=c07EeM@1`L700
GEeM092@T01IFET0IFEU0P1gMgL05024Q8@0H61P06UYJ@1mOGd0I6AT05UIF@1=CDd0K6a/06UYJ@1F
EUH0PX:207EeM@0k>c/0GemO05QHF01YJFT0HV9R04Q8B01PH600GemO0P1[Jf/03@1@D500L71`05=C
D`1IFET0DU9B069RHP15ADD0I6AT05aLG01OGel0IVIV05MGE`3oool01P3IfMT100000040fMWI000F
0=WIf@030000003IfMT0fMWI00<0fMWI05h0oooo08V9R@2c/k<0SXj>09nOW`22PX80UIFE0:RXZ02U
YJD0TY:B0:6QX@2DU9@0RXZ:09jNWP2GUiL0Ti>C08n?S`2KVi/0W9bL08^;R`2OWil0UIFE08j>SP2:
RXX0YJFU09bLW01jNWX0QhN707QhN028R8P0Ph>30:ZZZP2;Rh/0Q8B408n?S`2MWId0XZ:R08:2PP1]
KFd0Lg=c096AT@1oOgl0[jn_08Z:RP2YZJT0RHV90:RXZ022PX80Jf][07emO@1`L700J6QX09:BTP2E
UID0Q8B409fMW@2OWil0TI6A0;:b/P2MWId0XJ6Q0:NWY`2UYJD0[jn_0:^[Z`2e]KD0Y:BT0:NWY`2L
W9`0_[jn0;6a/@2c/k<0Y:BT0::RXP1hN7P0/;2`0:b/[02_[jl0Xj>S0;6a/@2n_[h0[Zj^0:RXZ02c
/k<0Xj>S08f=S@2^[Zh0ZZZZ0:6QX@2b/[80X:2P0;6a/@1nOWh0Vi^K0P2c/k<0:P31`L40/;2`09fM
W@2/[:`0]KFe0;^k^`2TY:@0VYZJ0;:b/P2ZZZX0VYZJ09:BTP2HV9P0YjNW0:j^[P2f][H0X:2P0;>c
/`2QXJ40YJFU08j>SP2c/k<0WinO0:>SX`2][Jd0[jn_0;2`/025QHD0^KVi0<71`@2^[Zh0YZJV0:VY
Z@2KVi/0Ogmo08R8R01FEUH0De=C028R8P11@D40N7Qh07alO080Vi^K02/0Rh^;0::RXP1iNGT0B4Q8
02d];@0o?cl0ATI608B4Q02e]KD0ZJVY0;Ng]`2e]KD0W9bL092@T01[Jf/0VYZJ09bLW02RXZ80[Jf]
09^KV`2TY:@0UiNG06a/K01eMGD0MWIf08b<S02CTi<0[:b/0:>SX`27QhL0Rh^;07QhN02XZ:P0/K6a
08f=S@27QhL0R8R809JFUP2HV9P0YjNW09BDU02ATI40U9BD0080R8R801`0W9bL0::RXP2QXJ40YZJV
09RHV02ZZZX0Ogmo07]kN`2b/[80R8R80861P@2VYZH0Xj>S09bLW02DU9@0RXZ:0:2PX02DU9@0W9bL
0::RXP1cLg<0QXJ609VIV@2CTi<0O7al09FEU@28R8P0[Jf]0P2QXJ40>P2MWId0YJFU09VIV@2GUiL0
TY:B0:^[Z`2EUID0YZJV0::RXP26QXH0SXj>08b<S02[Zj/0PX:208b<S01YJFT0L71`079bLP1kNg/0
KVi^075aL@1/K6`0OGem08^;R`1dM7@0QhN7092@T01^KVh0Hf=S06e]K@1OGel0PH6106QXJ01NGUh0
LW9b071`L01BDU80@D51061PH018B4P0GEeM06YZJP1^KVh0HV9R071`L01PH600NWYj065QH@1cLg<0
NGUi06QXJ01[Jf/0Lg=c06UYJ@20P800IFEU06MWI`1EEED2071`L00M05EEE@1OGel0L71`06YZJP13
@d<0ATI6055AD@1UIFD0Lg=c05eMG@1YJFT0I6AT06i^KP1LG5`0JFUY071`L01VIVH0LW9b05mOG`1/
K6`0IfMW06][J`1KFe/0GUiN06MWI`1KFe/0FUYJ06m_K`1]KFd00P1CDe<0201gMgL0K6a/04Q8B01J
FUX0FEUI04E5A@1GEeL0oooo1P3IfMT100000040fMWI00000`3IfMT0000000000002000000<0fMWI
0P0000040=WIf@8000001P3IfMT00`000000fMWI0=WIf@030=WIf@190?ooo`2HV9P0NWYj08j>SP2B
TY80VYZJ09RHV02KVi/0QHF508>3P`20P800QHF507]kN`2MWId0WinO08B4Q02MWId0OGem08R8R02J
VYX0ZJVY09:BTP28R8P0RHV908^;R`2CTi<0WYjN09RHV02KVi/0Ti>C0::RXP2:RXX0/K6a09jNWP2`
/;00U9BD0861P@1mOGd0Lg=c06IVIP1mOGd0KVi^09JFUP2OWil0Shn?0:RXZ02/[:`0UYJF08R8R01j
NWX0MWIf06m_K`2>SXh0QhN708Z:RP2UYJD0Z:RX0:NWY`2PX:00/;2`08n?S`2LW9`0YjNW0;Fe]@2Q
XJ40XZ:R0;Ng]`2XZ:P0N7Qh08^;R`2PX:00YJFU0:JVYP020:6QX@1U09fMW@2OWil0W9bL0:6QX@30
`<00]KFe09NGU`2QXJ40^;Rh0;>c/`3>c/h0_kno0<;2`P2_[jl0VIVI0;>c/`2FUYH0[Jf]0;^k^`2S
Xj<0YjNW0:6QX@2YZJT0YjNW0;Vi^@2_[jl0Xj>S0;>c/`2OWil0VYZJ09nOW`2LW9`0R8R809fMW@2Q
XJ40YjNW09NGU`2e]KD0Y:BT0:f][@2VYZH0Rh^;09VIV@2FUYH0V9RH09VIV@2SXj<0Zj^[0:n_[`2/
[:`0XZ:R0:^[Z`2c/k<0Vi^K0:j^[P2GUiL0UIFE06MWI`15ADD0>c/k03lo?`1WIfL0[Jf]09VIV@22
PX80OGem09:BTP1UIFD0FUYJ04=3@`12@T80Lg=c0;:b/P2IVIT0`<300<?3``2JVYX0TY:B092@T02C
Ti<0U9BD09^KV`2RXZ80[Jf]0<K6aP2UYJD0OWin07YjNP1mOGd0PX:206QXJ01kNg/0Y:BT09fMW@2D
U9@0PX:209JFUP2CTi<0TY:B09jNWP2PX:000P2QXJ40202][Jd0WIfM09RHV02FUYH0S8b<07QhN02Y
ZJT0WIfM0P2OWil0C@2DU9@0UYJF09JFUP2:RXX0I6AT0:RXZ02EUID0XZ:R07=cL`2FUYH0Q8B407=c
L`2:RXX0JFUY08Z:RP1ZJVX0OWin08f=S@1eMGD0Ti>C08B4Q02QXJ40TY:B07inOP2LW9`0[Jf]0;Jf
]P2ATI40UYJF07YjNP2GUiL0V9RH08j>SP2LW9`0X:2P0:VYZ@2BTY80V9RH09ZJVP20P800NWYj08:2
PP29RHT0IFEU06=SH`1WIfL0OWin06a/K028R8P0IfMW06QXJ01YJFT0G5aL06MWI`1dM7@0F5QH06e]
K@1eMGD0Hf=S071`L029RHT0Fe]K069RHP1iNGT0CDe=06m_K`1KFe/0GemO04m?C`1LG5`0NWYj0451
@@1DE5@0HV9R05QHF00j>SX0OGem0080MWIf02l0EeMG06ATI022PX80LG5a06EUI@1KFe/0K6a/07]k
N`1;Bd/0FUYJ06i^KP1]KFd0H61P069RHP1TI6@0HF5Q071`L01dM7@0Kfm_075aL@1_Kfl0BTY:05YJ
FP1PH600Ng]k07MgM`1dM7@0HV9R06EUI@1ADE40De=C071`L01cLg<0JFUY05aLG01IFET0LG5a06MW
I`1mOGd0B4Q8069RHP1UIFD0HF5Q04E5A@1DE5@0Hf=S0?ooo`060=WIf@4000000@3IfMT000030=WI
f@000000fMWI00@0fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@0000050=WI
f@030000003IfMT0fMWI00<0fMWI01D0oooo0:BTY027QhL0TI6A07inOP2RXZ80QhN709jNWP2LW9`0
Ogmo08f=S@2ATI40V9RH09NGU`2NWYh0PH6108R8R02QXJ40OGem06i^KP2BTY800P2HV9P0`@2;Rh/0
PX:209NGU`2:RXX0PH6108V9R@2;Rh/0Ti>C0861P@1oOgl0YZJV09bLW02g]kL0Xj>S06m_K`1oOgl0
MWIf07=cL`1lO7`0QHF50:f][@2CTi<0YZJV0:RXZ01_Kfl0MGEe07]kN`2>SXh0TY:B08f=S@2PX:00
ZJVY0;bl_02GUiL0TI6A08:2PP2c/k<0/;2`0;jn_P2EUID0SHf=09^KV`2NWYh0Zj^[0:n_[`1oOgl0
TY:B096AT@2TY:@0ZJVY0:ZZZP2d];@0/k>c0:j^[P2SXj<0ZZZZ0<30`02j^[X0/k>c0:2PX02XZ:P0
YZJV0:n_[`2VYZH0];Bd0:RXZ02k^k/0_Kfm0;Ng]`2i^KT0Z:RX0;^k^`2NWYh0]KFe0;>c/`2[Zj/0
[jn_0:ZZZP2OWil0XJ6Q09jNWP2RXZ80XJ6Q0:j^[P2WYjL0Zj^[0;2`/02EUID0UYJF09NGU`2WYjL0
/K6a09:BTP2HV9P0^;Rh09bLW02b/[80UiNG09jNWP2h^;P0/;2`0:>SX`2XZ:P0/K6a0:j^[P2PX:00
ZJVY092@T02KVi/0De=C06ATI01@D500GUiN05IFEP1lO7`0FUYJ08>3P`21PH40NWYj0451@@19BDT0
>c/k05=CD`1NGUh0WinO0<C4a02h^;P0`<300::RXP2LW9`0Ogmo07emO@2KVi/0Z:RX0:FUY@2TY:@0
ZJVY0;Bd]026QXH0Shn?08B4Q026QXH0OGem08f=S@2>SXh0NGUi09ZJVP2CTi<0WIfM0:n_[`2ZZZX0
[Zj^092@T02^[Zh0NGUi09:BTP29RHT0WIfM0:n_[`2LW9`0_;bl0;>c/`2VYZH0TI6A07emO@2VYZH0
WIfM09BDU02CTi<0]KFe09ZJVP2BTY80T92@07AdM02KVi/0NGUi08f=S@2?Shl0SXj>08F5Q@2:RXX0
TI6A08^;R`25QHD0UIFE0::RXP1jNWX0PX:208n?S`24Q8@0[jn_0:VYZ@2UYJD00P2XZ:P06`2][Jd0
QhN708N7Q`2=SHd0UiNG08R8R02IVIT0Q8B408f=S@2HV9P0O7al07=cL`1CDe<0T92@07IfMP2:RXX0
K6a/061PH024Q8@0EUIF07QhN01UIFD0LG5a07=cL`1aLG40PH61051@D002079bLP1307MgM`1jNWX0
JFUY06m_K`1JFUX0BTY:06m_K`1mOGd0NGUi07IfMP1WIfL0IFEU07YjNP1KFe/0G5aL05IFEP1[Jf/0
NWYj06][J`1WIfL0NWYj06YZJP1TI6@0Kfm_07]kN`1[Jf/0K6a/06e]K@1;Bd/0Kfm_065QH@1WIfL0
<S8b05YJFP1UIFD0JVYZ05UIF@1jNWX0?Shn06=SH`1nOWh0L71`055AD@1PH600IFEU069RHP1]KFd0
NGUi06i^KP11@D40H61P02PX:01_Kfl0IfMW06YZJP1[Jf/0FEUI06][J`1`L700J6QX04Y:BP1UIFD0
G5aL03@d=01ADE40De=C0?ooo`060=WIf@4000000@3IfMT00080fMWI00<000000=WIf@3IfMT00P3I
fMT010000000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI000000D0fMWI0`0000030=WIf@0D
0?ooo`2IVIT0R8R809JFUP2=SHd0T92@08^;R`2DU9@0Xj>S09fMW@2BTY80W9bL0:6QX@2;Rh/0RXZ:
0:6QX@1hN7P0UYJF07inOP25QHD208n?S`0N0820P02EUID0WinO096AT@2FUYH0Ng]k09JFUP2[Zj/0
QhN709FEU@24Q8@0UIFE0::RXP2JVYX0UIFE0820P01dM7@0KFe]06YZJP1fMWH0Ogmo09JFUP2SXj<0
QhN70861P@2=SHd0NGUi07YjNP2<S8`0N7Qh0P2NWYh0=`2ZZZX0WinO0:BTY02QXJ40X:2P0:ZZZP2<
S8`0Zj^[09FEU@2VYZH0Shn?08f=S@2MWId0UiNG0:NWY`2?Shl0YJFU09FEU@2d];@0[:b/0;:b/P2W
YjL0W9bL0;Ng]`2m_Kd0YZJV0;jn_P37alL0Zj^[0:b/[02^[Zh0Vi^K0;^k^`2LW9`0/;2`09RHV02R
XZ80Xj>S09fMW@2^[Zh0X:2P0:n_[`2EUID0Y:BT0:FUY@27QhL0[Zj^09nOW`2YZJT0UiNG09bLW02I
VIT0Vi^K08F5Q@2CTi<00P2SXj<0D@2YZJT0XJ6Q0:NWY`2ATI40];Bd0;fm_@2d];@0YjNW0:VYZ@2U
YJD0VYZJ092@T02QXJ40];Bd09RHV02`/;00VIVI08n?S`2DU9@0X:2P09:BTP1`L700N7Qh06e]K@1I
FET0JVYZ02/[:`19BDT0DU9B05aLG011@D409BDU05=CD`1>CTh0K6a/09:BTP2_[jl0^KVi0<?3``37
alL0Rh^;07alO01dM7@0Ph>309RHV02EUID0UiNG09bLW02QXJ40/;2`096AT@2QXJ40UYJF071`L01Z
JVX0TI6A0;bl_02LW9`0VYZJ08V9R@2>SXh0QXJ60:NWY`1mOGd0TY:B09VIV@2NWYh0Z:RX08j>SP2I
VIT0Z:RX08Z:RP2ATI40V9RH0:RXZ02NWYh0YZJV08V9R@1mOGd0YJFU09fMW@0208n?S`0709nOW`2=
SHd0UYJF0820P025QHD0OWin0861P@0207alO00L08f=S@25QHD0PH6109RHV02DU9@0Zj^[0:NWY`2H
V9P0XZ:R08j>SP1cLg<0T92@06=SH`2;Rh/0U9BD09^KV`1lO7`0OWin07alO02KVi/0OGem07alO01f
MWH0Q8B407alO020P800Lg=c096AT@80Jf][0100IfMW07emO@1fMWH0HV9R06m_K`1nOWh0LW9b07in
OP1[Jf/0OGem06QXJ01WIfL0LG5a07AdM01gMgL0GEeM0P1QHF40?`1HF5P0FEUI05IFEP1ZJVX0Kfm_
08N7Q`0i>CT0KVi^07emO@1fMWH0GemO05iNGP1ZJVX0I6AT06QXJ01YJFT0IfMW06QXJ01/K6`0OWin
05iNGP1aLG40IFEU065QH@1TI6@0DU9B04i>CP1kNg/0MGEe06=SH`1GEeL0JFUY075aL@1RHV80K6a/
055AD@1GEeL0HF5Q069RHP1NGUh0HF5Q06ATI01BDU80JFUY05UIF@1XJ6P0D51@04Q8B01`L700Hf=S
05iNGP1?Cdl0FUYJ06a/K01PH600HV9R04M7A`1UIFD0CDe=04Y:BP1KFe/0EeMG0?ooo`040=WIf@<0
00000@3IfMT000<0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@040000003IfMT0fMWI0000
0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@040?ooo`29RHT0QXJ6
08n?S`80Rh^;00L0S8b<0:n_[`2LW9`0UYJF0:NWY`2@T900VIVI0080S8b<00T0Shn?09nOW`1hN7P0
RHV908n?S`2UYJD0W9bL08V9R@2JVYX00P2:RXX208F5Q@0I08R8R02BTY80MgMg08>3P`2BTY80VYZJ
09BDU027QhL0U9BD08^;R`29RHT0KFe]06EUI@1_Kfl0Rh^;07AdM01VIVH0QHF5096AT@1gMgL0QHF5
07EeM@1hN7P0QHF50:FUY@0208j>SP1<0:n_[`2VYZH0W9bL09VIV@29RHT0Zj^[09>CT`27QhL0Zj^[
0::RXP2UYJD0UIFE09JFUP1oOgl0Vi^K08N7Q`2d];@0WinO0;Vi^@2ZZZX0VYZJ0;fm_@2:RXX0Z:RX
09bLW02_[jl0]kNg0:^[Z`2/[:`0ZJVY0:f][@2l_;`0WIfM08j>SP2SXj<0YJFU0;Fe]@2a/K40YjNW
0;:b/P2_[jl0VYZJ09NGU`2n_[h0YjNW09RHV02a/K40[jn_0:j^[P2][Jd0V9RH09jNWP1lO7`0VYZJ
09VIV@2^[Zh0YZJV0820P02HV9P0SHf=0:^[Z`2KVi/0[:b/09bLW02/[:`0ZJVY0:NWY`2][Jd0TI6A
09VIV@2ZZZX0/K6a09RHV02c/k<0/;2`0:b/[080Shn?0180RXZ:05mOG`0o?cl0BTY:05MGE`1<C4`0
@d=304E5A@0i>CT0F5QH05]KF`0k>c/0SXj>0861P@2UYJD0aLG50;Rh^033`l<20820P00407=cL`1n
OWh0RXZ:06m_K`80WIfM06@0WinO0:2PX02LW9`0TI6A08R8R01iNGT0LG5a092@T02:RXX0SHf=09FE
U@2ATI40MWIf08B4Q02GUiL0WIfM09nOW`2?Shl0UiNG09FEU@2KVi/0SXj>09bLW02SXj<0[Jf]09bL
W02OWil0Ph>309ZJVP2/[:`0YZJV0:b/[02ATI40UiNG0::RXP26QXH0UYJF09>CT`1YJFT0Vi^K096A
T@1aLG40VIVI09BDU01gMgL0WIfM0;:b/P2MWId0WinO0:NWY`22PX80TI6A09fMW@2:RXX0JFUY075a
L@29RHT0NWYj08N7Q`2BTY80Ng]k07EeM@2FUYH0V9RH09JFUP28R8P0T92@07YjNP2<S8`0P82008V9
R@1hN7P0MWIf06YZJP1nOWh0M7Ad071`L01bLW80Jf][07QhN01_Kfl0OGem07EeM@1bLW80GemO05QH
F01dM7@0PX:207EeM@1lO7`0HV9R05YJFP0g=cL0GUiN06MWI`1SHf<0PH6107=cL`1fMWH0Fe]K0P1[
Jf/04`1RHV80Bd];05=CD`1YJFT0LG5a05aLG01eMGD0JVYZ079bLP1^KVh0Kfm_07inOP1hN7P0Kfm_
079bLP1@D500DU9B06MWI`1:BTX00P1LG5`0801DE5@0K6a/06][J`1ADE40J6QX05iNGP1MGEd0De=C
061PH01RHV80Fe]K06YZJP1UIFD0FUYJ05ADE01BDU80H61P07MgM`1YJFT0H61P06QXJ01JFUX0BDU9
05MGE`1JFUX0K6a/0492@P1HF5P0EeMG04U9B@1WIfL0oooo1P3IfMT100000040fMWI00001@3IfMT0
00000=WIf@3IfMT000000080fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@00
00050=WIf@030000003IfMT0fMWI00<0fMWI0640oooo09RHV02IVIT0UIFE09jNWP2ATI40PX:209FE
U@2PX:00ZJVY09ZJVP25QHD0Vi^K0:f][@2?Shl0SXj>0:BTY028R8P0TY:B08^;R`1gMgL0T92@08b<
S02?Shl0W9bL09RHV02<S8`0V9RH09>CT`2DU9@0UYJF09FEU@1dM7@0Vi^K08J6QP2EUID0Q8B40;Fe
]@24Q8@0SXj>06][J`1_Kfl0MgMg08N7Q`1gMgL0O7al07QhN01TI6@0E5AD08f=S@2MWId0Rh^;09NG
U`2LW9`0Xj>S0:VYZ@2<S8`0Vi^K092@T02CTi<0]KFe09NGU`28R8P0SXj>09jNWP2ZZZX0M7Ad096A
T@2QXJ40V9RH08Z:RP2KVi/0VYZJ09fMW@2SXj<0[:b/0:RXZ02ZZZX0ZJVY0;2`/02XZ:P0YZJV0:f]
[@2b/[80RHV90:>SX`2ZZZX0^k^k0:FUY@2DU9@0Xj>S0:VYZ@2RXZ80YZJV0:^[Z`2HV9P0]KFe0080
UYJF01L0/[:b09VIV@2OWil0YJFU09JFUP2RXZ80YjNW09NGU`25QHD0U9BD0:2PX02TY:@0TY:B09jN
WP2JVYX0XZ:R09bLW02IVIT0YjNW08>3P`2e]KD0];Bd09nOW`020:ZZZP0U0:BTY02KVi/0Xj>S0;2`
/02LW9`0`<3009VIV@2MWId0[Jf]0:VYZ@1cLg<0MGEe055AD@16ATH0E5AD03dm?@1BDU80FUYJ05=C
D`1NGUh0QHF508b<S02f][H0YZJV08b<S030`<00[:b/0;fm_@2@T900IFEU07]kN`2ATI40Ph>308N7
Q`2FUYH0WinO09bLW00208f=S@1J09:BTP1eMGD0PH6109FEU@2HV9P0Vi^K08J6QP2FUYH0RXZ:07in
OP2=SHd0ZZZZ0:VYZ@2SXj<0UIFE09VIV@2WYjL0XJ6Q07emO@2TY:@0[Jf]09FEU@2FUYH0UiNG09:B
TP2CTi<0WIfM09>CT`2c/k<0QhN709RHV02:RXX0WIfM09bLW026QXH0TI6A09^KV`2ATI40]kNg08f=
S@2>SXh0UiNG09^KV`2HV9P0T92@0:JVYP2EUID0X:2P07alO02BTY80PX:205YJFP27QhL0LW9b06UY
J@1XJ6P0HF5Q096AT@1cLg<0Q8B409jNWP2HV9P0Shn?08Z:RP23Ph<0J6QX0861P@24Q8@0HV9R08J6
QP1jNWX0DE5A079bLP1QHF40O7al05IFEP1NGUh0IfMW07emO@1oOgl0O7al06e]K@1TI6@0Q8B406=S
H`1_Kfl0NGUi05QHF01=CDd0J6QX0P1PH6002@1mOGd0Kfm_05IFEP1ZJVX0KFe]06=SH`12@T80E5AD
05YJFP02061PH00:05IFEP1RHV80IFEU07=cL`1SHf<0L71`05MGE`1eMGD0H61P071`L080Kfm_01D0
Fe]K065QH@1GEeL0FUYJ04a<C017AdL0>CTi06][J`1:BTX0DE5A04e=C@1JFUX0EUIF05=CD`1UIFD0
BDU906MWI`1OGel0Ph>305iNGP1PH6000P1HF5P03@1QHF40?clo05UIF@1VIVH0KVi^05aLG01NGUh0
FUYJ05QHF01EEED0CDe=055AD@3oool01P3IfMT100000040fMWI00020=WIf@800000103IfMT20000
00@0fMWI0P0000060=WIf@030000003IfMT0fMWI00<0fMWI01H0oooo0:FUY@2FUYH0W9bL08j>SP23
Ph<0ZJVY08J6QP2NWYh0SXj>08Z:RP2XZ:P0XJ6Q09fMW@2HV9P0Xj>S09JFUP1/K6`0Q8B408R8R02E
UID0T92@0P2FUYH07`20P800UYJF08j>SP2EUID0P8200:b/[02=SHd0UiNG09^KV`2=SHd0[Jf]07em
O@2TY:@0S8b<08V9R@2HV9P0MGEe06a/K01_Kfl0GUiN07alO02@T900MgMg07AdM022PX80W9bL08^;
R`2FUYH0ZJVY0:b/[02][Jd00P2=SHd01P2][Jd0VIVI0:f][@2JVYX0QXJ608N7Q`80T92@06<0Vi^K
0;Jf]P2BTY80Ti>C07alO02FUYH0[Jf]09bLW02PX:00][Jf0:VYZ@33`l<0`L710:>SX`2k^k/0WinO
09fMW@2c/k<0YZJV0;fm_@2k^k/0[:b/0;Fe]@2l_;`0Vi^K0:JVYP2^[Zh0V9RH0:BTY02h^;P0VYZJ
0::RXP2`/;00UYJF09ZJVP2PX:00ZJVY0:n_[`2UYJD0X:2P09fMW@2ZZZX0[:b/0:JVYP2][Jd0YJFU
0;6a/@2JVYX0RHV90:RXZ02IVIT0^;Rh0:n_[`32`/80[jn_0:>SX`2MWId0[jn_09jNWP29RHT0YJFU
09bLW02GUiL0Xj>S0:BTY02OWil0];Bd08j>SP1iNGT0PH6108f=S@1KFe/0LG5a04];B`1CDe<0KFe]
05mOG`1WIfL0I6AT08n?S`2SXj<0YJFU0:>SX`2h^;P0VIVI0<k>cP2`/;00WYjN08N7Q`1lO7`0IfMW
0:^[Z`1oOgl0Shn?09^KV`2[Zj/0TI6A08:2PP20P8000P25QHD0F@2?Shl0SHf=09jNWP2BTY80MgMg
09BDU02YZJT0UiNG08F5Q@2ATI40WYjN08f=S@2DU9@0Ti>C08F5Q@1kNg/0X:2P07emO@2@T900V9RH
09jNWP2PX:00UIFE09nOW`2YZJT0TI6A08V9R@2ATI40WYjN08J6QP2BTY80VYZJ09^KV`2IVIT0UiNG
096AT@1^KVh0TY:B0:6QX@2HV9P0WinO09VIV@2TY:@0P82008j>SP2NWYh0TY:B06ATI01hN7P0Kfm_
05mOG`1nOWh0Jf][09:BTP1bLW80VIVI0:FUY@22PX80O7al09FEU@1eMGD0SHf=08:2PP2EUID0QXJ6
07inOP2>SXh0QXJ607AdM01MGEd0SXj>09:BTP1WIfL0MGEe06i^KP1VIVH0M7Ad08V9R@1jNWX0LG5a
07alO01FEUH0I6AT06m_K`1XJ6P0EeMG06ATI01RHV80N7Qh0080HV9R00l0H61P075aL@1RHV80LW9b
06MWI`1YJFT0HF5Q06IVIP1eMGD0GemO06ATI01^KVh0GEeM06UYJ@1]KFd00P1>CTh0:019BDT0N7Qh
06a/K01PH600MgMg05aLG01=CDd0IFEU05aLG01FEUH0De=C06e]K@1OGel0GEeM04i>CP1]KFd0FUYJ
04e=C@1mOGd0FUYJ06a/K01KFe/0EUIF05YJFP1]KFd0GemO06=SH`2;Rh/0Hf=S05ADE01aLG40IFEU
06m_K`1FEUH0IFEU05=CD`1FEUH0ATI605iNGP3oool60=WIf@4000000@3IfMT001H0fMWI00<00000
0=WIf@3IfMT00`3IfMT0;03oool0U9BD0:BTY02OWil0XJ6Q09BDU01oOgl0UYJF08f=S@2[Zj/0W9bL
0:>SX`1iNGT0X:2P08Z:RP29RHT0QXJ609>CT`1eMGD0XZ:R09NGU`28R8P0UYJF09BDU022PX80WinO
09fMW@2NWYh0V9RH07emO@2ATI40YJFU096AT@2DU9@0Xj>S09RHV02DU9@0T92@08:2PP2KVi/0TI6A
09:BTP1kNg/0MgMg0P1_Kfl0<02;Rh/0QhN708Z:RP25QHD0Ti>C09^KV`2JVYX0XJ6Q09RHV02h^;P0
Z:RX0::RXP2g]kL0VYZJ0;Rh^02OWil0RXZ:07alO02=SHd0Shn?09ZJVP2PX:00TI6A07=cL`1fMWH0
Ng]k09jNWP2ZZZX0[Zj^08n?S`2NWYh0Vi^K09nOW`2i^KT0];Bd0:RXZ02WYjL0UYJF09ZJVP2PX:00
WYjN0;Fe]@2j^[X0VYZJ0:^[Z`2/[:`0Zj^[0:f][@80XZ:R00X0Z:RX0:NWY`2HV9P0V9RH09nOW`2C
Ti<0W9bL0::RXP2IVIT0SHf=0P2MWId03P2/[:`0QHF509JFUP2_[jl0SXj>0:BTY02JVYX0SXj>0;2`
/02GUiL0X:2P0;:b/P2f][H0VYZJ0P2QXJ40B`2ZZZX0Ti>C0:VYZ@2CTi<0YJFU0<G5a@2ATI40[:b/
09VIV@2LW9`0UIFE09VIV@1iNGT0TI6A07emO@1EEED0UYJF079bLP2TY:@0TI6A09bLW031`L40Z:RX
0;jn_P2d];@0_kno0;2`/02YZJT0ZZZZ08B4Q01fMWH0IFEU0820P01cLg<0TY:B08f=S@24Q8@0NGUi
08J6QP21PH40K6a/065QH@2=SHd0];Bd0::RXP27QhL0U9BD092@T026QXH0TI6A08J6QP2GUiL0PX:2
09fMW@2SXj<0WIfM0:FUY@2HV9P0Ogmo07QhN024Q8@0S8b<09JFUP2KVi/0U9BD0861P@1dM7@0RXZ:
0:b/[02NWYh0WinO09fMW@2JVYX0XJ6Q09^KV`0208:2PP0^09BDU02YZJT0L71`09^KV`2BTY80SXj>
09jNWP2;Rh/0UiNG08f=S@22PX80Lg=c08V9R@1lO7`0RXZ:09RHV01fMWH0OWin08B4Q02CTi<0PH61
07inOP2=SHd0PH6109FEU@22PX80UIFE08>3P`27QhL0H61P07]kN`1bLW80Ogmo07=cL`1_Kfl0Hf=S
06][J`0e=CD0Lg=c06EUI@1]KFd0PX:2069RHP1^KVh0L71`04a<C080HV9R00<0HF5Q05YJFP1RHV80
0P1UIFD0101JFUX0K6a/07YjNP1YJFT2075aL@0f06=SH`1hN7P0Lg=c05YJFP1aLG40J6QX05YJFP1X
J6P0MGEe065QH@1TI6@0GemO061PH01WIfL0EeMG05mOG`1JFUX0HF5Q06QXJ01TI6@0JVYZ069RHP11
@D40Cdm?06YZJP1PH600HV9R06IVIP1aLG40EeMG04i>CP1QHF40J6QX069RHP1SHf<0KVi^069RHP1Z
JVX0IVIV05]KF`1ZJVX0LW9b07QhN01VIVH0KVi^055AD@1LG5`0IfMW04a<C010@400Lg=c04i>CP1C
De<0oooo1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00h0oooo0:VYZ@2<
S8`0T92@0861P@2JVYX0Shn?08N7Q`25QHD0/K6a09>CT`2TY:@0U9BD09>CT`80UYJF0140XJ6Q08f=
S@22PX80PX:208F5Q@2XZ:P0RXZ:07inOP2LW9`0P82008b<S02QXJ40R8R809ZJVP2QXJ40Vi^K09bL
W0020:f][@1K09fMW@2RXZ80YZJV0;6a/@2OWil0WIfM096AT@2:RXX0SXj>09ZJVP2XZ:P0YjNW08f=
S@2TY:@0UIFE08j>SP2JVYX0[:b/0:^[Z`2<S8`0W9bL0::RXP2KVi/0WinO0:n_[`2KVi/0MgMg069R
HP2;Rh/0SHf=09ZJVP1QHF40MWIf079bLP1^KVh0MGEe0820P02IVIT0U9BD09nOW`2a/K40Y:BT0:>S
X`2n_[h0[Jf]0;>c/`2DU9@0SHf=0;Jf]P30`<00][Jf0:^[Z`2i^KT0Zj^[0:b/[02WYjL0Vi^K09BD
U02EUID0T92@0:NWY`2/[:`0XZ:R0:>SX`27QhL0Z:RX09jNWP2TY:@0Zj^[0:ZZZP2YZJT0[jn_09RH
V02`/;00];Bd0::RXP2FUYH0Z:RX0:f][@26QXH0Z:RX0<71`@2`/;00^k^k08R8R02PX:00[jn_09VI
V@2OWil0Y:BT0:2PX0020:NWY`0N08b<S021PH40SXj>08>3P`2a/K40TY:B0:f][@2/[:`0WIfM08j>
SP2KVi/0TI6A09nOW`2ZZZX0[Zj^0:b/[02UYJD0WYjN0:NWY`2a/K40XJ6Q09NGU`2UYJD0^KVi0:n_
[`2BTY80UiNG0861P@1oOgl0IFEU0P1XJ6P0:01iNGT0UIFE07UiN@1TI6@0UIFE08f=S@1fMWH0Shn?
071`L02HV9P0TY:B09VIV@2CTi<0PX:20::RXP2BTY80U9BD09fMW@2SXj<0VYZJ08:2PP20P800Ti>C
09JFUP25QHD0TI6A09^KV`2[Zj/0TY:B0:JVYP2LW9`0Vi^K08^;R`2XZ:P0UiNG096AT@2QXJ40PX:2
09bLW02GUiL209ZJVP0m08>3P`2:RXX0TY:B096AT@2;Rh/0S8b<07QhN02@T900QHF508J6QP21PH40
TI6A092@T02ATI40UYJF08F5Q@2GUiL0Ogmo096AT@23Ph<0OGem079bLP23Ph<0UYJF07emO@2<S8`0
R8R807IfMP1VIVH0PX:2079bLP1`L700Jf][06YZJP1mOGd0Jf][05eMG@1eMGD0O7al05]KF`1dM7@0
RHV906i^KP1jNWX0OWin08j>SP1YJFT0Ph>305eMG@1VIVH0GUiN06ATI01^KVh0Lg=c05QHF01ADE40
HF5Q05aLG01GEeL0E5AD06EUI@0205ADE00905UIF@1MGEd0DU9B06IVIP1TI6@0DE5A05mOG`1VIVH0
NGUi0080F5QH00h0MWIf05QHF01PH600A4A4061PH01@D500HF5Q05eMG@1dM7@0Hf=S05eMG@1YJFT0
CDe=04Q8B080E5AD01H0HV9R05YJFP1VIVH0DU9B06=SH`1^KVh0Fe]K06a/K01`L700De=C05eMG@1;
Bd/0C4a<05YJFP1HF5P0DU9B05QHF01:BTX0Ng]k05]KF`0m?Cd0oooo1P3IfMT100000040fMWI000F
0=WIf@030000003IfMT0fMWI00<0fMWI00D0oooo0:>SX`2IVIT0[Jf]09RHV00208>3P`1`079bLP2I
VIT0Vi^K09bLW02WYjL0XJ6Q08J6QP23Ph<0XZ:R0;6a/@2`/;00PX:209nOW`2<S8`0SXj>08V9R@1l
O7`0Vi^K09>CT`2SXj<0SHf=09fMW@26QXH0Vi^K0:FUY@2<S8`0XZ:R0;6a/@2RXZ80Vi^K08V9R@2Q
XJ40SXj>0;bl_02MWId0WYjN0:RXZ02IVIT0X:2P06i^KP2/[:`0UYJF09RHV02GUiL0ZJVY0:^[Z`2S
Xj<0PX:209fMW@2o_kl0Xj>S0:JVYP2WYjL0Q8B40:NWY`2ATI40PX:208V9R@2=SHd0X:2P096AT@1g
MgL0IfMW0861P@2HV9P0OWin09bLW02GUiL0_kno0;>c/`32`/80];Bd0;Rh^02WYjL0_kno0:ZZZP2]
[Jd0/K6a096AT@2n_[h0/k>c0;Ng]`2YZJT0ZZZZ09ZJVP2_[jl0/;2`0;Ng]`2SXj<0T92@0:NWY`2N
WYh0`<300:FUY@2h^;P0WIfM0;2`/02XZ:P0SHf=0:2PX02OWil0WYjN09fMW@2PX:00Zj^[09^KV`2P
X:00Vi^K09ZJVP2XZ:P0];Bd08N7Q`80RHV901d0/;2`0:NWY`2RXZ80YjNW0;no_`2ATI40RXZ:0::R
XP2DU9@0]KFe09BDU02WYjL0[:b/0;fm_@2TY:@0/[:b0:BTY02`/;00RXZ:0;6a/@31`L40YjNW0;2`
/02WYjL0W9bL09fMW@2HV9P0NGUi092@T00209fMW@050<30`02f][H0TY:B09>CT`1cLg<00P23Ph<0
1`1VIVH0Ph>307]kN`2HV9P0Ti>C075aL@1hN7P00P28R8P07P2ATI40LW9b09ZJVP2BTY80Rh^;09ZJ
VP2YZJT0Ogmo09BDU01eMGD0UIFE09BDU02PX:00_[jn08>3P`2OWil0Xj>S08B4Q02LW9`0Shn?09BD
U02UYJD0QXJ609jNWP2=SHd0TI6A08>3P`2c/k<0ZJVY09BDU0<0ZJVY0740/;2`09:BTP2ATI40Shn?
08>3P`2HV9P0OWin07moO`25QHD0V9RH06e]K@1eMGD0NWYj09VIV@2?Shl0U9BD08b<S02EUID0RHV9
09RHV01`L700Kfm_08Z:RP2@T900N7Qh07]kN`1jNWX0SHf=07MgM`1/K6`0OGem07YjNP2@T900J6QX
065QH@1fMWH0JFUY07AdM01eMGD0EeMG05QHF01/K6`0QXJ606e]K@1YJFT0L71`07=cL`1JFUX0I6AT
07EeM@1RHV80@T9205eMG@1WIfL0GEeM06QXJ01NGUh0I6AT07IfMP15ADD0FEUI071`L01SHf<0H61P
04I6AP11@D40K6a/05UIF@1bLW80J6QX06=SH`1TI6@0MGEe075aL@1hN7P0E5AD05MGE`1PH600F5QH
05ADE01GEeL0I6AT04Q8B01?Cdl0CTi>05UIF@1OGel0L71`05]KF`1<C4`0EEEE05iNGP1/K6`0NWYj
06MWI`1?Cdl0K6a/05aLG01^KVh0J6QX059BDP1UIFD0KVi^06][J`1HF5P0FUYJ069RHP1MGEd0@T92
05aLG01BDU80JFUY0?ooo`060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0
1@3oool0UYJF09>CT`2SXj<0Vi^K0080Shn?0:T0TI6A0861P@2EUID0]KFe0;6a/@2=SHd0Ti>C09:B
TP2>SXh0FEUI09NGU`2JVYX0T92@09JFUP2>SXh0S8b<08j>SP2;Rh/0N7Qh0:FUY@29RHT0J6QX08^;
R`2>SXh0SHf=09:BTP2UYJD0][Jf092@T022PX80Zj^[0;6a/@2XZ:P0Shn?096AT@2WYjL0/;2`09VI
V@2<S8`0O7al0;Fe]@1gMgL0XJ6Q09BDU029RHT0SXj>0:>SX`2WYjL0WIfM09JFUP2][Jd0W9bL0:>S
X`22PX80SXj>0:b/[01LG5`0M7Ad0:>SX`2@T900RHV908>3P`2HV9P0RXZ:07=cL`1KFe/0NGUi08:2
PP2XZ:P0RHV909nOW`2^[Zh0YZJV0;2`/02OWil0[Zj^0<71`@2b/[80Y:BT0<C4a02k^k/0/[:b0:>S
X`2n_[h0Ti>C09:BTP2HV9P0Rh^;0:ZZZP2][Jd0^;Rh09bLW02OWil0YJFU0:f][@29RHT0Ti>C0;Zj
^P2OWil0Z:RX0:BTY02NWYh0Y:BT08Z:RP2XZ:P0VYZJ09^KV`2TY:@0Xj>S0:6QX@2JVYX0Xj>S08V9
R@2HV9P0Xj>S0:6QX@2RXZ80^k^k0:^[Z`2PX:00ZZZZ08F5Q@2OWil0UIFE09JFUP2EUID0X:2P09nO
W`2EUID0QHF509jNWP2^[Zh0VYZJ0;Jf]P2PX:00`<300:RXZ02c/k<0XJ6Q09RHV02][Jd0ZJVY0<?3
``2/[:`0V9RH08:2PP34a<@0YZJV09bLW02][Jd0P820079bLP1FEUH0IVIV061PH01jNWX0N7Qh08f=
S@25QHD0KVi^08V9R@2ATI40Q8B409FEU@2PX:00WIfM08^;R`2HV9P0YJFU0080Ti>C0200Vi^K09NG
U`2KVi/0SXj>06a/K02WYjL0Ti>C08V9R@2JVYX0W9bL09FEU@2?Shl0UYJF0:n_[`2GUiL0WIfM0:BT
Y02@T900U9BD08^;R`23Ph<0X:2P09VIV@2TY:@0Ti>C08n?S`1kNg/0N7Qh08N7Q`1lO7`0UIFE07Yj
NP80Q8B401@0IFEU09fMW@1lO7`0UIFE07QhN027QhL0RXZ:09BDU02=SHd0K6a/08B4Q01`L700TY:B
09RHV01bLW80K6a/075aL@1NGUh0J6QX07moO`80Ph>300D0Fe]K06m_K`1jNWX0G5aL05eMG@0206m_
K`0S08b<S01;Bd/0O7al07]kN`1FEUH0J6QX05ADE01/K6`0H61P07emO@1[Jf/0GemO06IVIP1XJ6P0
EEEE06=SH`1XJ6P0LG5a0492@P1GEeL0DE5A05QHF01>CTh0D51@03lo?`1CDe<0C4a<034a<@15ADD0
F5QH061PH021PH40Cdm?069RHP1GEeL00P1IFET02P0Q8B40Hf=S06=SH`1QHF40FUYJ04E5A@1IFET0
@d=306YZJP18B4P204e=C@0606=SH`1XJ6P0IVIV05mOG`1XJ6P0Lg=c0P1XJ6P0401cLg<0Hf=S06AT
I01RHV80@T9205iNGP0<30`0Kfm_05QHF01QHF40>CTi02HV9P1[Jf/0F5QH04m?C`3oool60=WIf@40
00000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0j`3oool0RHV909VIV@2EUID0U9BD08:2
PP2DU9@0RXZ:09fMW@2;Rh/0Vi^K0::RXP2XZ:P0[Jf]0:BTY02?Shl0WIfM08n?S`25QHD0UYJF07Yj
NP2:RXX0SXj>09^KV`2EUID0WinO09FEU@24Q8@0VIVI06YZJP2:RXX0[Zj^092@T02VYZH0[:b/0:JV
YP2[Zj/0Ng]k09ZJVP2WYjL0[Zj^08Z:RP2PX:00WYjN0:b/[027QhL0Z:RX09jNWP25QHD0ZZZZ09>C
T`1oOgl0Vi^K07MgM`2QXJ40ZJVY09fMW@28R8P0WinO09NGU`28R8P0PH6109JFUP2CTi<0OGem09VI
V@2?Shl0Vi^K08Z:RP2=SHd0RHV907UiN@1eMGD0P82006EUI@2PX:00W9bL0:ZZZP2c/k<0[Jf]0;jn
_P2m_Kd0`l?30;^k^`2c/k<0^[Zj0:^[Z`2WYjL0Xj>S0:VYZ@2GUiL0UIFE0:6QX@2a/K40XZ:R0:n_
[`2[Zj/0WinO0:NWY`2PX:00[:b/0:RXZ02?Shl0[jn_09NGU`2HV9P0^[Zj09:BTP2DU9@0_Kfm0:JV
YP2/[:`0Vi^K0:ZZZP36a/H0U9BD09fMW@2EUID0VIVI0:JVYP2][Jd0`l?30<S8b02YZJT0VYZJ09VI
V@2j^[X0/;2`0;>c/`2QXJ40UiNG09fMW@2/[:`0Zj^[0;Jf]P2EUID0Y:BT0820P02RXZ80_kno0:^[
Z`2PX:00ZZZZ0::RXP2FUYH0ZJVY096AT@2YZJT0/K6a09fMW@33`l<0SXj>0;:b/P2QXJ40WIfM0;Vi
^@2OWil0UYJF09^KV`24Q8@0Zj^[07inOP2:RXX0UYJF08J6QP2<S8`0QHF508b<S029RHT0WinO0:RX
Z02FUYH0W9bL09NGU`2NWYh0Shn?09fMW@2^[Zh0X:2P0:JVYP2XZ:P0UYJF0:2PX023Ph<0VYZJ0:b/
[02GUiL0ZJVY09RHV02KVi/0VIVI08R8R02RXZ80TY:B07QhN02:RXX0VYZJ08R8R01lO7`0Q8B40:VY
Z@2DU9@0XZ:R0:FUY@24Q8@0U9BD09VIV@1jNWX0UYJF07alO01jNWX0QHF5075aL@2^[Zh0S8b<09FE
U@1eMGD0RXZ:08N7Q`2SXj<0Ph>307YjNP24Q8@0M7Ad09>CT`2BTY80UiNG07UiN@21PH40KFe]051@
D02BTY80I6AT08B4Q01kNg/00P1SHf<01P1[Jf/0MgMg07]kN`1kNg/0HF5Q05aLG080M7Ad00l0JFUY
06a/K021PH40F5QH07UiN@1^KVh0IVIV075aL@1=CDd0Kfm_05iNGP1[Jf/0EeMG06ATI01OGel00P1P
H6004@12@T80B4Q804m?C`1^KVh0?Shn05aLG01WIfL0=3@d05QHF01MGEd0IFEU071`L01LG5`0IVIV
07MgM`1RHV80E5AD0080EeMG0240K6a/071`L01KFe/0HF5Q05mOG`1SHf<0GEeM059BDP1SHf<0FUYJ
06UYJ@1cLg<0EeMG05aLG01dM7@0CTi>055AD@1JFUX0K6a/06IVIP1YJFT0FUYJ05=CD`1OGel0DU9B
04a<C01]KFd0Hf=S05=CD`10@400EUIF06EUI@3oool01P3IfMT100000040fMWI000F0=WIf@030000
003IfMT0fMWI00<0fMWI0400oooo09JFUP2ATI40Lg=c09NGU`21PH40ZJVY09>CT`2PX:00U9BD08f=
S@2NWYh0UIFE09nOW`2KVi/0R8R80:f][@2IVIT0QXJ606IVIP2SXj<0YZJV09:BTP1nOWh0GemO09RH
V02CTi<0RXZ:0:2PX02<S8`0R8R809>CT`2MWId0XZ:R09RHV02NWYh0TI6A0:b/[02QXJ40/;2`092@
T02/[:`0YJFU0:^[Z`2ZZZX0WIfM0:NWY`2@T900QhN708^;R`2KVi/0X:2P09FEU@2NWYh0WinO0:j^
[P2_[jl0V9RH09JFUP2GUiL0RXZ:092@T01dM7@0OWin0P2=SHd20:2PX00L09^KV`2EUID0Xj>S092@
T01fMWH0KFe]07EeM@22PX80a<C40:n_[`2TY:@0bl_;0:^[Z`2OWil0ZZZZ0;Rh^02a/K40[:b/0<C4
a02IVIT0[:b/0:JVYP2OWil0WIfM09nOW`2RXZ80`<3006a/K080WIfM03H0UYJF09fMW@2WYjL0Y:BT
0:NWY`29RHT0Rh^;09bLW02SXj<0]KFe09FEU@2YZJT0/k>c08Z:RP2OWil0ZJVY0;2`/02@T900YJFU
08j>SP2SXj<0[Jf]0:RXZ02UYJD0X:2P0:6QX@2j^[X0SHf=0:n_[`2g]kL0SHf=0:JVYP2UYJD0XZ:R
0;:b/P2`/;00WIfM0;:b/P2/[:`0/[:b09FEU@2JVYX0[Zj^0:6QX@2m_Kd0^KVi0;2`/02d];@0TI6A
0:NWY`2MWId0Y:BT0;6a/@2b/[820:b/[00^09nOW`2^[Zh0YjNW09ZJVP2KVi/0/[:b0:VYZ@2CTi<0
PX:207moO`29RHT0R8R80::RXP2BTY80R8R807IfMP2>SXh0N7Qh09JFUP2PX:00SXj>0:b/[02BTY80
UiNG0;Vi^@2ATI40W9bL09nOW`2DU9@0[jn_09:BTP2KVi/0Y:BT09bLW02CTi<0Y:BT09JFUP2e]KD0
TI6A08^;R`2BTY80R8R8092@T02ATI40PX:209bLW080LW9b03H0X:2P07inOP2<S8`0Ph>3092@T01f
MWH0QXJ608n?S`2@T900J6QX075aL@1oOgl0Ph>308b<S02CTi<0UiNG08>3P`2;Rh/0Kfm_0861P@1a
LG40Fe]K07alO028R8P0IFEU08>3P`1dM7@0MgMg06e]K@2>SXh0TY:B0861P@1BDU80MGEe07AdM01W
IfL0Jf][075aL@1lO7`0NGUi06][J`1eMGD0M7Ad08J6QP1]KFd0L71`06e]K@29RHT0NWYj06MWI`1J
FUX0NGUi051@D01^KVh2075aL@0>079bLP0k>c/0G5aL06QXJ01DE5@0FEUI0861P@1QHF40Fe]K04E5
A@0i>CT0D51@05EEE@1IFET2079bLP0X06ATI01VIVH0F5QH06IVIP1UIFD0BDU9051@D01[Jf/0CTi>
06UYJ@17AdL0De=C04U9B@1:BTX0KFe]05IFEP1ADE40E5AD05=CD`1LG5`0E5AD06ATI010@400KFe]
06a/K01fMWH0J6QX05ADE01JFUX0CDe=05MGE`1<C4`0BTY:05YJFP1SHf<0GEeM03@d=00h>3P0CTi>
0?ooo`H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0M0?ooo`2YZJT0VIVI
09fMW@2EUID0Rh^;08Z:RP2LW9`0Vi^K08F5Q@1^KVh0UYJF08>3P`2IVIT0P82008N7Q`2BTY80T92@
071`L01]KFd0VYZJ08J6QP28R8P0SHf=0:NWY`2:RXX0QXJ607inOP25QHD00P2e]KD0E`2ZZZX0YJFU
09bLW02HV9P0YZJV0;2`/02PX:00Xj>S0:JVYP2MWId0SXj>09ZJVP2k^k/0XZ:R0:FUY@2`/;00Xj>S
09^KV`2MWId0XZ:R0;Vi^@2YZJT0ZZZZ09bLW02VYZH0UiNG0:2PX02OWil0YZJV0:ZZZP1nOWh0Q8B4
07inOP2NWYh0WIfM09VIV@2EUID0V9RH09^KV`2YZJT0UIFE09JFUP26QXH0OWin09RHV02OWil0Shn?
09NGU`2[Zj/0][Jf0;Zj^P1mOGd0YZJV0;Fe]@2ZZZX0X:2P0:^[Z`2<S8`0YjNW09jNWP2TY:@0WinO
09RHV02^[Zh0][Jf0:BTY02g]kL0[Jf]09fMW@2QXJ40VYZJ0;Fe]@2YZJT0WinO0:n_[`2f][H0/;2`
0;Bd]02][Jd0YZJV0:ZZZP2/[:`0];Bd0:FUY@2j^[X0Xj>S0::RXP0209^KV`1A08n?S`2][Jd0];Bd
0:2PX02XZ:P0YJFU08b<S02PX:00UIFE08F5Q@2SXj<0ZJVY0:^[Z`2^[Zh0ZJVY0:BTY02QXJ40Vi^K
0;Fe]@2EUID0U9BD0:f][@2XZ:P0/;2`09:BTP2<S8`0RXZ:08j>SP2i^KT0[:b/0;>c/`2XZ:P0ZJVY
0<S8b02WYjL0/k>c0;2`/02QXJ40WYjN07YjNP1gMgL0WinO09ZJVP2CTi<0O7al07inOP23Ph<0SXj>
08f=S@29RHT0PX:209BDU02OWil0XZ:R09^KV`2FUYH0XJ6Q08n?S`2GUiL0Shn?09jNWP2GUiL0WinO
08^;R`2ATI40U9BD0;>c/`2PX:00Vi^K08b<S02=SHd0XJ6Q08R8R02WYjL0SXj>0:JVYP1mOGd0R8R8
09NGU`2ATI40XJ6Q0080T92@02H0QHF508j>SP26QXH0Rh^;09fMW@26QXH0OWin07EeM@20P800PX:2
08^;R`1jNWX0Ph>3092@T023Ph<0RHV909FEU@1nOWh0Rh^;08F5Q@1jNWX0WIfM0820P02ATI40KVi^
059BDP1eMGD0Kfm_07YjNP24Q8@0UiNG08F5Q@28R8P0IFEU079bLP1jNWX0IfMW05UIF@80M7Ad0200
NWYj06e]K@1aLG40Ng]k06=SH`1TI6@0LW9b07YjNP1YJFT0Q8B407MgM`1kNg/0JVYZ05QHF01LG5`0
IFEU05IFEP1KFe/0?Cdm051@D01WIfL0MgMg07]kN`1SHf<0F5QH04Y:BP1<C4`0B4Q805aLG019BDT0
GUiN055AD@80HV9R02D0@41006a/K01WIfL0HV9R05QHF01^KVh0KFe]065QH@1RHV80FUYJ03Xj>P1I
FET0>3Ph05eMG@1ZJVX0ATI604M7A`1FEUH0De=C06m_K`1QHF40F5QH069RHP1ZJVX0Fe]K06][J`1^
KVh0J6QX06IVIP19BDT0E5AD04i>CP1GEeL0GEeM05IFEP1:BTX0oooo00H0fMWI0@0000010=WIf@00
5P3IfMT00`000000fMWI0=WIf@030=WIf@1<0?ooo`2ATI40SXj>08Z:RP2OWil0SHf=09VIV@2:RXX0
Ph>308Z:RP2ZZZX0[Jf]09bLW02d];@0[Zj^0;fm_@2c/k<0UYJF0000002HV9P0Xj>S092@T027QhL0
Ng]k07moO`2EUID0VYZJ09jNWP2DU9@0TY:B0:NWY`2;Rh/0U9BD0;6a/@2OWil0VIVI0:>SX`27QhL0
XZ:R0:JVYP2LW9`0XJ6Q0:ZZZP21PH40QXJ60:>SX`2TY:@0WinO09jNWP2OWil0/;2`09fMW@2OWil0
W9bL0:BTY02MWId0^;Rh0<S8b02a/K40]KFe09ZJVP2PX:00QhN7069RHP1gMgL0QHF509JFUP2HV9P0
X:2P09:BTP2ATI40L71`08J6QP2@T900UiNG0::RXP80V9RH02H0Y:BT0;Ng]`2][Jd0Z:RX0;2`/02Z
ZZX0XJ6Q08f=S@2MWId0LG5a07EeM@2NWYh0WinO0:b/[02NWYh0Ogmo0;Bd]02h^;P0^[Zj0:RXZ028
R8P0VYZJ0:j^[P2KVi/0TI6A08n?S`2l_;`0YJFU09fMW@2ZZZX0X:2P09jNWP2PX:00Ph>30:BTY02f
][H0]kNg0:FUY@80/[:b0180WIfM09ZJVP2DU9@0W9bL0:VYZ@2^[Zh0RXZ:08^;R`2PX:00SXj>09nO
W`2IVIT0X:2P09>CT`2b/[80WinO09RHV02JVYX20:VYZ@0@0:f][@2YZJT0RHV909bLW02CTi<0];Bd
0:FUY@2GUiL0^[Zj0:ZZZP2KVi/0X:2P0:b/[02a/K40]kNg0:FUY@80`<300400TY:B08f=S@2^[Zh0
Vi^K09VIV@2ATI40Ti>C08N7Q`29RHT0Ph>309BDU01lO7`0Vi^K092@T023Ph<0OGem0861P@29RHT0
U9BD09jNWP26QXH0UYJF08f=S@25QHD0UiNG08V9R@2VYZH0Vi^K0:ZZZP28R8P0W9bL09fMW@2ZZZX0
XZ:R09^KV`2?Shl0WIfM0:RXZ025QHD0XZ:R09JFUP2BTY80RXZ:08n?S`22PX80UYJF09ZJVP2;Rh/0
TI6A08^;R`2FUYH0S8b<08Z:RP27QhL0KVi^096AT@1gMgL0J6QX07QhN02FUYH0JFUY07YjNP2>SXh0
QHF50P1iNGT0G023Ph<0JFUY07]kN`2@T900J6QX07QhN01FEUH0Ogmo07alO01XJ6P0Q8B408^;R`1K
Fe/0GEeM065QH@2DU9@0Ogmo06m_K`1KFe/0EeMG08>3P`1iNGT0Ng]k07=cL`1ZJVX0QHF50820P01b
LW80P82005MGE`1TI6@0OWin08>3P`1UIFD0M7Ad07alO01KFe/0GemO061PH01@D500I6AT065QH@1S
Hf<0LW9b06=SH`1QHF40@d=304i>CP1=CDd0G5aL05YJFP1?Cdl0BTY:06e]K@1_Kfl0GUiN05MGE`1K
Fe/0H61P071`L01MGEd0BDU9051@D01WIfL0Bd];05aLG01IFET0GEeM04Y:BP1KFe/0GEeM05iNGP19
BDT0GUiN06YZJP1QHF40FEUI06IVIP1UIFD0FEUI03lo?`1/K6`0EUIF05iNGP1WIfL0GEeM069RHP1G
EeL0@D5104Y:BP1TI6@0oooo1P3IfMT100000040fMWI000F0=WIf@800000103IfMT0D`3oool0R8R8
0::RXP2GUiL0V9RH0:RXZ02TY:@0PX:208B4Q02BTY80XJ6Q0:FUY@2OWil0YjNW08f=S@2][Jd0QHF5
08B4Q02LW9`0Xj>S07moO`2GUiL0V9RH09VIV@2?Shl0YjNW08Z:RP2OWil0PH6108^;R`2MWId0TI6A
08j>SP2IVIT0YZJV09:BTP2CTi<0YJFU0:2PX02QXJ40[Jf]0:j^[P2QXJ40VYZJ08F5Q@2[Zj/0VYZJ
0:2PX02?Shl0/K6a0:RXZ02CTi<0`/;20:>SX`2e]KD0WIfM08n?S`2TY:@0`L710;Fe]@2PX:00RXZ:
08F5Q@20P800NGUi08R8R02IVIT0YJFU08V9R@22PX80SHf=09FEU@2FUYH0K6a/08J6QP2KVi/0Xj>S
0<K6aP2n_[h0^KVi0;6a/@2NWYh0_[jn0080ZJVY0:`0]KFe02h^;P0000005aLG07UiN@2KVi/0SHf=
09ZJVP2ZZZX0[Jf]0;jn_P2_[jl0];Bd0;:b/P2KVi/0[jn_0:JVYP2^[Zh0_[jn08Z:RP2IVIT0/K6a
0;jn_P2i^KT0V9RH0820P02;Rh/0XJ6Q0;Bd]02:RXX0/;2`0:^[Z`2_[jl0Lg=c08:2PP2b/[80`<30
0;Ng]`2WYjL0WinO09NGU`2b/[80TI6A09fMW@2QXJ40Y:BT0:b/[02WYjL0QhN70;Ng]`2_[jl0W9bL
0:NWY`2VYZH0Vi^K08B4Q01lO7`0Ogmo09jNWP2VYZH0ZJVY08n?S`2RXZ80_[jn08j>SP2UYJD0Y:BT
0;>c/`2IVIT0[Jf]08R8R02VYZH0XJ6Q092@T028R8P0OGem07]kN`29RHT0LG5a08b<S022PX80RHV9
08:2PP23Ph<0Vi^K08B4Q02=SHd0VYZJ09VIV@2ATI40UIFE08Z:RP2EUID0MgMg09JFUP1hN7P0UIFE
09ZJVP2DU9@0S8b<096AT@2QXJ40Z:RX0:FUY@2OWil0VYZJ0:BTY02CTi<0TY:B08^;R`2][Jd0UIFE
08n?S`2>SXh0TY:B0:2PX02:RXX0OWin08j>SP1jNWX0Vi^K08V9R@2@T900QHF507UiN@25QHD0KVi^
05UIF@1QHF40MGEe08B4Q01YJFT0LG5a06YZJP1fMWH0K6a/06][J`1`L700OGem08b<S01fMWH0QXJ6
0861P@1aLG40I6AT06a/K01hN7P0DU9B06=SH`1XJ6P0NWYj07EeM@23Ph<0LW9b08B4Q022PX80E5AD
071`L01/K6`0NGUi07IfMP1aLG40MgMg05QHF01`L700I6AT06m_K`1ZJVX0Ph>306IVIP1iNGT0P820
0P1`L700=`1TI6@0Hf=S04e=C@1fMWH0NGUi06=SH`1YJFT0QhN706=SH`1BDU80Hf=S05mOG`1=CDd0
JVYZ051@D01WIfL0EeMG05iNGP1`L700J6QX065QH@1SHf<0EUIF065QH@1FEUH0J6QX04e=C@1LG5`0
GUiN05QHF01YJFT0E5AD04i>CP1GEeL0D51@05eMG@1DE5@0BTY:05MGE`1XJ6P0JFUY05MGE`16ATH0
De=C06][J`1NGUh0IFEU051@D01TI6@0FEUI05IFEP1^KVh0@T9206ATI03oool01@3IfMT200000040
fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00X0oooo08^;R`2PX:00S8b<0:b/[02LW9`0XZ:R
08N7Q`2YZJT0S8b<0P2GUiL0<@2ZZZX0UIFE09^KV`2m_Kd0PX:20;Rh^02KVi/0OGem09VIV@20P800
SXj>096AT@2FUYH0PH6108j>SP28R8P0/;2`08b<S02][Jd0/;2`0:ZZZP2/[:`0Shn?09BDU02OWil0
YjNW09BDU02UYJD0][Jf0:FUY@2ATI40UiNG09nOW`2FUYH0TI6A0:NWY`28R8P0Vi^K0::RXP2PX:00
Shn?0;Bd]02b/[80UiNG09bLW02RXZ80^;Rh0:VYZ@2][Jd00P2BTY80701dM7@0H61P06QXJ01mOGd0
XJ6Q09bLW02ATI40VIVI09RHV02NWYh0T92@09NGU`2LW9`0Xj>S09^KV`2NWYh0a<C40;jn_P2[Zj/0
/[:b0:b/[02XZ:P0XJ6Q0861P@1;Bd/0GEeM07]kN`2[Zj/20:b/[00H0:^[Z`2ATI40Xj>S09^KV`2_
[jl0XJ6Q09:BTP2h^;P0YjNW09fMW@33`l<0]KFe09RHV02OWil0Zj^[0;fm_@2DU9@0TY:B0:RXZ02L
W9`0[Jf]0;Ng]`2WYjL0/k>c0P2SXj<0C`2TY:@0Xj>S0:FUY@2NWYh0P8200;Vi^@2VYZH0VIVI0:JV
YP2UYJD0][Jf0:ZZZP2DU9@0V9RH08R8R02WYjL0XZ:R0;Bd]02RXZ80WYjN0:6QX@27QhL0ZJVY08Z:
RP2NWYh0SHf=08j>SP2JVYX0Zj^[09NGU`2DU9@0][Jf0:NWY`2FUYH0XZ:R0;2`/02PX:00XZ:R08^;
R`2?Shl0Rh^;07moO`24Q8@0UIFE09ZJVP2VYZH0YJFU08f=S@2TY:@0P82009nOW`2^[Zh0UYJF09fM
W@2CTi<0S8b<08N7Q`1fMWH0N7Qh09>CT`1lO7`0ZJVY09JFUP2EUID0U9BD07moO`2GUiL0RHV90861
P@2TY:@0RXZ:0:BTY02DU9@0UiNG0:>SX`2WYjL0[Jf]09ZJVP2<S8`00P2GUiL08P2>SXh0SHf=0:f]
[@2HV9P0Vi^K07MgM`2UYJD0Rh^;09:BTP1VIVH0MGEe08n?S`2<S8`0Kfm_06e]K@21PH40MWIf092@
T01]KFd0Ph>307moO`28R8P0KFe]07moO`1gMgL0OWin06UYJ@1ZJVX0MGEe07inOP1kNg/0S8b<07Ad
M01VIVH206QXJ00i07=cL`1/K6`0PX:206m_K`1SHf<0QhN7092@T01gMgL0Ng]k061PH01bLW80H61P
0820P021PH40Kfm_0861P@25QHD0MWIf08j>SP1PH600MgMg08B4Q01PH600EUIF05eMG@1GEeL0D51@
05]KF`1VIVH0EEEE04Y:BP1HF5P0:BTY051@D01UIFD0JVYZ05aLG01_Kfl0GUiN07=cL`1EEED0M7Ad
06e]K@1VIVH0H61P05UIF@1>CTh0IFEU0410@01BDU80Jf][06ATI010@400H61P05eMG@1=CDd0H61P
0080CTi>01<0Cdm?065QH@1GEeL0Jf][06UYJ@1;Bd/0B4Q80451@@14A4@0NGUi059BDP1CDe<0I6AT
05]KF`1NGUh0D51@0000001NGUh0oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WI
f@030=WIf@0>0?ooo`1iNGT0N7Qh0:NWY`2CTi<0UIFE07QhN02;Rh/0Lg=c09bLW02ZZZX0TI6A09RH
V02VYZH209RHV00a0861P@1oOgl0VIVI09ZJVP2WYjL0RHV907inOP2MWId0Ng]k0:NWY`2KVi/0Rh^;
09RHV02WYjL0]KFe09bLW026QXH0WinO09:BTP2_[jl0XZ:R08B4Q02DU9@0Xj>S0:b/[02g]kL0RHV9
08F5Q@2JVYX0QHF50;:b/P2SXj<0ZJVY09JFUP2JVYX0QXJ609:BTP2>SXh0W9bL09FEU@2GUiL0YJFU
0:^[Z`2e]KD0Vi^K0;:b/P29RHT0Ph>309:BTP0207inOP0707YjNP2BTY80MGEe09ZJVP2][Jd0V9RH
08N7Q`0209NGU`2H0;Vi^@2MWId0[Jf]0:JVYP2UYJD0T92@0:f][@2_[jl0XJ6Q0;6a/@2GUiL0Ph>3
09nOW`2NWYh0Xj>S08J6QP2FUYH0Xj>S09>CT`2PX:00Vi^K09FEU@2IVIT0_[jn0:b/[02NWYh0]kNg
0:JVYP2OWil0XJ6Q0:FUY@32`/80XJ6Q09jNWP2DU9@0W9bL0:2PX02e]KD0ZJVY0:ZZZP2CTi<0Vi^K
08n?S`2SXj<0VIVI08N7Q`2RXZ80ZZZZ0:VYZ@2WYjL0Y:BT0:b/[02][Jd0][Jf09bLW02TY:@0V9RH
09jNWP2@T900];Bd0:>SX`35aLD0X:2P08R8R02IVIT0Z:RX0:2PX02HV9P0YJFU0:6QX@2PX:00TY:B
0:BTY02CTi<0Xj>S09bLW02JVYX0Rh^;09jNWP2LW9`0Shn?07inOP1kNg/0MgMg09FEU@1]KFd0T92@
08j>SP2:RXX0R8R807QhN01oOgl0TY:B08V9R@2:RXX0P82008>3P`1kNg/0RHV908N7Q`2GUiL0UIFE
06e]K@2BTY80U9BD08^;R`1eMGD0Ph>30::RXP2<S8`0QXJ608^;R`2BTY80Zj^[07MgM`2MWId0RXZ:
08>3P`1]KFd0YZJV092@T01bLW80U9BD08Z:RP20P800T92@0:BTY02MWId0YJFU09^KV`2=SHd0S8b<
07YjNP1oOgl0PH6106=SH`1hN7P0Jf][07QhN01[Jf/0EUIF06ATI01[Jf/0LW9b06EUI@1eMGD0IVIV
08>3P`20P800H61P079bLP1hN7P205aLG00406m_K`1XJ6P0QHF504E5A@80Hf=S00H0GemO07emO@1c
Lg<0000007=cL`1gMgL206m_K`0;07]kN`1_Kfl0PH6108V9R@1OGel0GEeM08:2PP1SHf<0FEUI07mo
O`1^KVh00P1bLW804`1mOGd0Fe]K06MWI`1=CDd0?clo05QHF017AdL0De=C06QXJ00o?cl0D51@05EE
E@0k>c/0M7Ad05EEE@1<C4`0Hf=S069RHP1JFUX00P1OGel0901RHV80Hf=S06i^KP1BDU80CTi>05UI
F@1GEeL0EUIF04Y:BP1YJFT0Kfm_04i>CP12@T80CTi>06IVIP10@400I6AT05MGE`1ADE40@T9204E5
A@0a<C40IFEU05YJFP14A4@0?clo04Y:BP17AdL0EeMG03Hf=P1PH600EeMG051@D0000000D51@0?oo
o`H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0N0?ooo`2ZZZX0ZZZZ08j>
SP1mOGd0P82009FEU@29RHT0WYjN0::RXP2YZJT0Z:RX09FEU@2MWId0YZJV08j>SP24Q8@0YjNW08N7
Q`2ATI40Ti>C0:2PX02KVi/0P82008^;R`2b/[80[Jf]08^;R`2^[Zh0VIVI0P2][Jd0<@2ZZZX0YJFU
0;^k^`2OWil0Rh^;09VIV@2EUID0Z:RX06a/K02GUiL0UYJF09NGU`2_[jl0]kNg09ZJVP2@T900VYZJ
09>CT`2NWYh0SHf=0:n_[`27QhL0TI6A09:BTP2`/;00ZZZZ09jNWP2VYZH0YJFU0:>SX`28R8P0OWin
092@T01kNg/0NWYj08Z:RP2QXJ40PH6109JFUP2UYJD0YZJV0:j^[P2HV9P0Shn?08:2PP2GUiL0SHf=
0:2PX02[Zj/00P2e]KD0802l_;`0YJFU0<30`02l_;`0[Jf]0;2`/031`L40_kno0;jn_P2[Zj/0[Zj^
09^KV`2WYjL0WinO09bLW02a/K40W9bL0:j^[P2HV9P0`<300:>SX`2UYJD0ZZZZ08Z:RP2RXZ80Z:RX
0;:b/P2QXJ40X:2P09VIV@0i>CT0Z:RX0P2PX:001@2`/;00[jn_0:^[Z`2LW9`0`l?30080X:2P0240
bLW90<K6aP2LW9`0dM7A0;Rh^02/[:`0Vi^K09ZJVP2UYJD0][Jf0:b/[02ZZZX0Vi^K09RHV02=SHd0
[:b/08f=S@2QXJ40ZJVY0:FUY@2LW9`0WYjN096AT@2BTY80XZ:R09ZJVP2/[:`0VYZJ09FEU@2RXZ80
^k^k0:FUY@1nOWh00P24Q8@09P1gMgL0JVYZ092@T02XZ:P0QXJ609jNWP2QXJ40WYjN07emO@20P800
WYjN08J6QP2CTi<0[:b/09bLW02PX:00Y:BT09JFUP27QhL0Ti>C08f=S@25QHD0T92@08R8R02EUID0
Shn?08N7Q`2@T900TI6A0:2PX02CTi<0UYJF07emO@2>SXh0UYJF08N7Q`2SXj<0Rh^;0P2FUYH02@2S
Xj<0WYjN09RHV02NWYh0Vi^K08n?S`2GUiL0Shn?08N7Q`0209NGU`0J09>CT`2HV9P0OWin07]kN`28
R8P0JVYZ07MgM`21PH40Q8B408F5Q@1nOWh0J6QX079bLP26QXH0GemO04i>CP21PH40PX:206a/K01i
NGT0Ng]k075aL@1XJ6P0Jf][0820P02SXj<207emO@1<05eMG@1fMWH0L71`075aL@2<S8`0KFe]0820
P01cLg<0Jf][08:2PP1XJ6P0NGUi07AdM01YJFT0IVIV08B4Q01VIVH0PH6106i^KP1jNWX0PH6106m_
K`1TI6@0FUYJ03Xj>P1;Bd/0BTY:05eMG@0f=SH0?Shn04Y:BP1BDU80GEeM051@D01[Jf/0FUYJ04U9
B@1PH600IFEU07EeM@1]KFd0HV9R06i^KP17AdL0Jf][05]KF`1YJFT0GemO061PH01?Cdl0AdM7069R
HP1fMWH0KVi^05IFEP1WIfL0J6QX05QHF01RHV80AdM704Q8B01SHf<0IVIV04A4A01CDe<0Jf][05eM
G@1UIFD0EeMG05IFEP1IFET0IVIV04M7A`1CDe<0AdM70?ooo`H0fMWI0@0000010=WIf@005P3IfMT0
0`000000fMWI0=WIf@030=WIf@0S0?ooo`2a/K40RXZ:0:2PX01nOWh0[Zj^08f=S@2JVYX0TY:B08Z:
RP2BTY80[Zj^08n?S`2XZ:P0V9RH0:b/[02QXJ40OGem08V9R@2JVYX0R8R808V9R@2OWil0W9bL0:^[
Z`1UIFD0V9RH08R8R02OWil0Ti>C0:>SX`23Ph<0X:2P0;6a/@2TY:@00P2PX:002@2RXZ80T92@096A
T@2RXZ80YJFU0:VYZ@2BTY80YJFU0;Vi^@0209jNWP0L09nOW`2@T900/[:b0:2PX02VYZH0Xj>S09nO
W`2h^;P0YjNW09:BTP32`/80Z:RX08n?S`2l_;`0bl_;09FEU@2MWId0T92@08R8R02=SHd0UIFE08B4
Q02QXJ40M7Ad09>CT`2_[jl0Vi^K0:VYZ@80[Zj^01<0[Jf]0;Ng]`2OWil0ZZZZ0;6a/@2c/k<0Xj>S
09^KV`2LW9`0[Jf]0;Vi^@2l_;`0RXZ:09jNWP2;Rh/0/[:b0:2PX02/[:`0QhN70080UiNG01P0]KFe
0;:b/P2c/k<0ZZZZ0;>c/`2MWId0Zj^[0:f][@30`<00]kNg0;2`/02EUID0XJ6Q09:BTP2][Jd0ZZZZ
0:NWY`2RXZ80W9bL0:j^[P2VYZH0_[jn0;Vi^@2UYJD20;bl_0070<30`02[Zj/0Xj>S0;6a/@2YZJT0
XJ6Q0:ZZZP020:>SX`0@09jNWP2c/k<0];Bd0<O7a`2e]KD0WYjN092@T02JVYX0Ti>C09ZJVP2UYJD0
ZJVY0:2PX02e]KD0TI6A0:>SX`80/k>c06L0TY:B096AT@2MWId0TI6A0::RXP2BTY80WYjN09VIV@2L
W9`0Z:RX09VIV@2>SXh0RXZ:08n?S`25QHD0VYZJ08^;R`2<S8`0Ng]k08b<S026QXH0T92@08f=S@2:
RXX0V9RH08^;R`2?Shl0QHF509FEU@2SXj<0TI6A0820P022PX80X:2P08J6QP2ATI40Lg=c08N7Q`2=
SHd0Ph>308R8R01lO7`0UIFE09ZJVP2FUYH0YZJV09BDU02PX:00T92@0:>SX`2?Shl0RXZ:09NGU`26
QXH0NWYj08b<S01jNWX0M7Ad09BDU01^KVh0P82007inOP1jNWX0P82009VIV@24Q8@0OWin08B4Q02@
T900SHf=06YZJP1VIVH0MWIf06a/K01ZJVX0B4Q80820P01[Jf/0G5aL05iNGP1`L700@41007IfMP28
R8P0KFe]08b<S026QXH0SXj>05MGE`26QXH0QhN707inOP1eMGD0IfMW08Z:RP1OGel0Lg=c08V9R@1f
MWH0O7al07]kN`1cLg<0RHV90080R8R803T0Kfm_07AdM025QHD0P820061PH01=CDd0EeMG03lo?`14
A4@0ADE505EEE@1QHF40EeMG07YjNP1EEED0GemO05IFEP1^KVh0H61P06e]K@1OGel0EeMG04Y:BP1P
H600BTY:06][J`1lO7`0Jf][06=SH`1@D500F5QH059BDP1VIVH0Fe]K05mOG`14A4@0Lg=c0492@P1L
G5`0FUYJ05ADE01OGel0FEUI05IFEP1;Bd/0BDU9034a<@1BDU80E5AD03dm?@1QHF40AdM705iNGP1G
EeL0BTY:03/k>`3oool01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI02L0
oooo09:BTP2MWId0Ti>C0:>SX`2;Rh/0TY:B08V9R@2SXj<0WYjN0:VYZ@2/[:`0/k>c09JFUP26QXH0
WinO09RHV022PX80WIfM09jNWP2][Jd0/[:b09BDU02YZJT0UiNG07IfMP2EUID0Ti>C0:VYZ@2LW9`0
WYjN0:JVYP2h^;P0[Jf]08V9R@2HV9P0XZ:R0:>SX`2DU9@00P2HV9P209JFUP0j0:ZZZP2_[jl0XJ6Q
0::RXP2_[jl0ZJVY0:2PX02NWYh0VYZJ09FEU@2FUYH0VYZJ09nOW`24Q8@0WIfM0;Fe]@2QXJ40Vi^K
0:FUY@2=SHd0ZJVY08J6QP2IVIT0O7al09NGU`2@T900W9bL08J6QP2QXJ40RXZ:08n?S`2IVIT0X:2P
0:BTY02VYZH0_[jn0<K6aP2/[:`0/k>c09FEU@2PX:00_Kfm09nOW`2h^;P0[Zj^09^KV`2OWil0]KFe
0:^[Z`2][Jd0SHf=0:NWY`2][Jd0Y:BT0:^[Z`2RXZ80X:2P0:f][@80Y:BT00D0UiNG0:n_[`2QXJ40
[:b/09nOW`020:ZZZP0i0;Jf]P2ZZZX0YJFU0:NWY`2ZZZX0UYJF0:VYZ@2SXj<0W9bL0:^[Z`2VYZH0
[:b/09^KV`2OWil0YZJV0;6a/@3:b/X0^KVi09VIV@2KVi/0XZ:R0:j^[P2FUYH0YZJV0:2PX02XZ:P0
TY:B09ZJVP2VYZH0TI6A0:^[Z`2HV9P0/;2`0:NWY`2ZZZX0Zj^[092@T02JVYX0Y:BT0;Bd]02IVIT0
[jn_09fMW@2SXj<0[:b/09^KV`2ZZZX0Y:BT09nOW`2ATI40NWYj0;>c/`2SXj<0QXJ608b<S024Q8@0
MWIf0080QhN701@0WIfM0:b/[02TY:@0Xj>S08N7Q`2NWYh0Ph>308^;R`1kNg/0[:b/08Z:RP1lO7`0
OWin08f=S@2KVi/0Ph>309JFUP2:RXX0Rh^;09JFUP80T92@03D0Xj>S096AT@1lO7`0S8b<092@T02C
Ti<0VYZJ09bLW024Q8@0UIFE07MgM`2GUiL0X:2P09JFUP1hN7P0R8R80820P02JVYX0Q8B408j>SP2@
T900SHf=07YjNP1XJ6P0FEUI08>3P`1fMWH0Ng]k07inOP1cLg<0KFe]065QH@1XJ6P0MGEe05iNGP21
PH40O7al075aL@1hN7P0OWin06QXJ01VIVH0B4Q806=SH`1bLW80NWYj07UiN@1gMgL0S8b<07emO@2<
S8`0R8R808:2PP0207alO00<07QhN02:RXX0QhN706e]K@1SHf<0NGUi07MgM`1mOGd0KVi^0820P01Z
JVX0IfMW0P1`L7004`23Ph<0Q8B406MWI`1EEED0L71`065QH@1EEED0IFEU05YJFP1dM7@0JFUY06AT
I01ZJVX0IVIV06YZJP1LG5`0JVYZ07IfMP1@D5000P1HF5P08@1SHf<0B4Q804];B`1NGUh0De=C06UY
J@1^KVh0B4Q8061PH01OGel0GEeM04m?C`1@D500FEUI04i>CP1GEeL0CTi>05=CD`1FEUH0Bd];06AT
I018B4P0:RXZ05=CD`10@400E5AD061PH01GEeL0DU9B03Hf=P10@400Cdm?0?ooo`060=WIf@400000
0@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT03`3oool0U9BD0:NWY`2ATI40T92@0:2PX02F
UYH0QhN709FEU@2KVi/0^;Rh09NGU`2IVIT0XJ6Q09bLW00209VIV@0I09NGU`2[Zj/0/[:b0:f][@2?
Shl0WIfM0::RXP2DU9@0VIVI0:RXZ02GUiL0WinO0;^k^`2KVi/0WinO0;Vi^@2_[jl0UYJF0:ZZZP2^
[Zh0bLW90<;2`P2/[:`0ZJVY0;6a/@020:6QX@1J0;Vi^@29RHT0YjNW0:JVYP2UYJD0Xj>S09BDU02V
YZH0Y:BT0:>SX`2HV9P0[:b/0:NWY`2OWil0UiNG0:j^[P2l_;`0YJFU0;Jf]P2i^KT0[jn_09VIV@2F
UYH0[Zj^09bLW02VYZH0YJFU07]kN`2RXZ80U9BD0::RXP2b/[80[jn_0;no_`2c/k<0ZZZZ0;Bd]02k
^k/0T92@0:j^[P2ZZZX0Y:BT0;2`/02][Jd0bLW90:VYZ@2VYZH0UYJF0:FUY@2MWId0RHV9096AT@2F
UYH0VYZJ0;2`/02;Rh/0VYZJ0:VYZ@2f][H0X:2P0:^[Z`2WYjL0RXZ:09bLW029RHT0VIVI0;jn_P2/
[:`0VYZJ0;Rh^02DU9@0Z:RX0<71`@2[Zj/0RXZ:09VIV@2JVYX0aLG50;no_`2IVIT0YJFU0:f][@2L
W9`0ZJVY0<G5a@2WYjL0UYJF0;jn_P2KVi/0QhN70`2NWYh209>CT`0I08j>SP2c/k<0]KFe09FEU@2O
Wil0U9BD09^KV`2;Rh/0WIfM0<30`02MWId0SHf=0:RXZ02ZZZX0emOG0:j^[P2VYZH0/;2`0:BTY02I
VIT0T92@09bLW025QHD0UiNG07MgM`0208b<S00P07QhN029RHT0TY:B096AT@2=SHd0Shn?0:2PX02F
UYH0PH6108:2PP1ZJVX0QhN708F5Q@2?Shl0Ti>C0::RXP24Q8@0U9BD0:f][@2`/;00S8b<08j>SP2K
Vi/0SXj>09FEU@1hN7P0S8b<07QhN02NWYh0QHF5096AT@1jNWX20:>SX`0C07moO`28R8P0Q8B40861
P@1lO7`0Q8B407MgM`24Q8@0SHf=07]kN`1nOWh0TY:B08B4Q01nOWh0TY:B05EEE@1aLG40LW9b06YZ
JP0207alO00E07MgM`1eMGD0OWin075aL@1OGel0Cdm?07YjNP1lO7`0M7Ad07YjNP23Ph<0M7Ad06e]
K@1HF5P0SXj>07YjNP1fMWH0NGUi07AdM01YJFT0UiNG0080M7Ad01d0A4A40861P@1bLW80Lg=c06][
J`1iNGT0LG5a07IfMP1mOGd0HV9R06i^KP1jNWX0Ogmo08B4Q02:RXX0OWin05eMG@1^KVh0Shn?08j>
SP1cLg<0M7Ad06YZJP27QhL0Lg=c08R8R01VIVH0OWin06a/K00205mOG`0W04m?C`1WIfL0GemO065Q
H@11@D40I6AT06i^KP1LG5`0DE5A03Ti>@1@D500K6a/0492@P1DE5@0@D5104m?C`1EEED0GUiN06IV
IP1RHV80DU9B04M7A`1FEUH0?clo05YJFP1=CDd0DU9B05UIF@1KFe/0>CTi04a<C00X:2P0C4a<061P
H01ADE40BDU904m?C`1PH600oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@03
0=WIf@080?ooo`2?Shl0XJ6Q09fMW@2WYjL0U9BD09jNWP2ZZZX209jNWP1H0:n_[`2;Rh/0W9bL08J6
QP2FUYH0Y:BT09jNWP2MWId0VYZJ0:^[Z`2KVi/0Ti>C0861P@2a/K40XJ6Q09FEU@2?Shl0YjNW0:JV
YP2NWYh0/K6a0;bl_02TY:@0/K6a09ZJVP2l_;`0`/;20:VYZ@2`/;00Zj^[07QhN02YZJT0XZ:R09JF
UP2NWYh0W9bL09nOW`2b/[80TY:B09RHV02EUID0YZJV08V9R@2TY:@0_Kfm0:>SX`2GUiL0Xj>S0;Fe
]@2KVi/0X:2P09ZJVP2c/k<0`<300<C4a030`<00VIVI09RHV02IVIT0Lg=c0:VYZ@2SXj<0Rh^;08j>
SP2MWId0YJFU09RHV02[Zj/0W9bL09NGU`2CTi<0/[:b0:n_[`2g]kL0/[:b0:RXZ02c/k<0Y:BT0::R
XP2ZZZX0ZJVY0;bl_02UYJD0VYZJ0:VYZ@2OWil0Ti>C07alO080UiNG01<0Q8B40:^[Z`2UYJD0WYjN
08N7Q`1VIVH0YZJV08n?S`2<S8`0[jn_0;:b/P2j^[X0WIfM0;fm_@2MWId0RHV90;Zj^P2a/K40_Kfm
0080YJFU02L0[jn_0;Rh^02JVYX0^KVi08j>SP2/[:`0XZ:R096AT@30`<00U9BD09NGU`2LW9`0ZZZZ
09VIV@2LW9`0];Bd09JFUP2XZ:P0Rh^;08n?S`2IVIT0ZJVY0:BTY02d];@0Z:RX09VIV@2/[:`0WinO
08>3P`2i^KT0`L7109FEU@2`/;00Z:RX09FEU@2IVIT0U9BD09VIV@2@T9000P2EUID09`23Ph<0NWYj
08:2PP2<S8`0HV9R09BDU02FUYH0WinO09jNWP2IVIT0UIFE09BDU02CTi<0QXJ607]kN`2BTY80[:b/
07YjNP2LW9`0Ti>C09ZJVP22PX80VIVI0:6QX@2CTi<0UiNG08Z:RP29RHT0Ti>C08j>SP2ATI40X:2P
08j>SP2JVYX0Rh^;09VIV@2KVi/0S8b<09nOW`0209NGU`0508:2PP2HV9P0RHV908>3P`2@T9000P21
PH402P1hN7P0PX:2071`L01XJ6P0MWIf08b<S01aLG40O7al06IVIP1XJ6P207AdM00X08B4Q01dM7@0
LW9b05aLG020P800OGem061PH01iNGT0JVYZ05eMG@1NGUh0D51@04A4A01WIfL0N7Qh06i^KP1dM7@0
MGEe06e]K@1XJ6P0MGEe06IVIP1iNGT0Hf=S07UiN@2;Rh/0Ph>307inOP1YJFT0OGem07MgM`2WYjL0
VYZJ0820P01NGUh0FUYJ071`L01YJFT0MWIf06a/K080Rh^;0380OGem07MgM`1TI6@0Kfm_07moO`1H
F5P0HF5Q06ATI011@D40KFe]05]KF`1`L700E5AD06MWI`1TI6@0G5aL04i>CP1UIFD0IfMW055AD@1P
H600F5QH04i>CP1OGel0IFEU03Hf=P14A4@0EUIF0410@01BDU80EEEE07inOP1CDe<0:b/[04E5A@1?
Cdl0A4A403Xj>P1FEUH0ATI603/k>`14A4@0DE5A05ADE01LG5`0DU9B05UIF@11@D40IVIV0?ooo`H0
fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@1;0?ooo`2=SHd0TI6A09^KV`2P
X:00TY:B09ZJVP2;Rh/0Z:RX0:NWY`2FUYH0Vi^K09:BTP2TY:@0TY:B092@T02ATI40Vi^K0:n_[`2L
W9`0WinO0:ZZZP2TY:@0TI6A09ZJVP2KVi/0UiNG0:j^[P2[Zj/0/K6a0;Ng]`2][Jd0/K6a0;Zj^P2@
T900XJ6Q0:JVYP2[Zj/0[jn_09nOW`35aLD0`L7109NGU`2WYjL0ZZZZ0:^[Z`2VYZH0W9bL0:j^[P2G
UiL0][Jf0:NWY`2UYJD0X:2P0;Rh^02WYjL0/K6a0;Jf]P2VYZH0X:2P0;Rh^02WYjL0^KVi0;bl_02K
Vi/0/;2`0;Fe]@2MWId0WinO08J6QP2@T900TY:B0;2`/02i^KT0SHf=0080/K6a08P0UYJF0<?3``2T
Y:@0/[:b09NGU`2QXJ40W9bL0:BTY02LW9`0VYZJ09FEU@2f][H0YJFU0:RXZ02b/[80UiNG0:JVYP2E
UID0XJ6Q0:>SX`2MWId0S8b<0:VYZ@2;Rh/0YZJV0::RXP2QXJ40Shn?0:JVYP2SXj<0YZJV0:2PX02H
V9P0Y:BT0:6QX@2h^;P0_;bl09bLW02>SXh0Vi^K09jNWP2i^KT0YZJV0;Bd]02^[Zh0Zj^[0:NWY`2Z
ZZX0];Bd0:6QX@2_[jl0Ti>C0:JVYP2b/[80X:2P09jNWP2JVYX0YJFU0;6a/@2VYZH0U9BD0;2`/02I
VIT0];Bd09bLW02MWId0[jn_09NGU`2ZZZX0VIVI09ZJVP2HV9P0OWin0:ZZZP2[Zj/0ZZZZ09ZJVP22
PX80[jn_09fMW@2:RXX0S8b<0:VYZ@2@T900QHF508V9R@27QhL0TY:B07inOP1UIFD0UYJF08F5Q@2E
UID0S8b<092@T02XZ:P0Zj^[0820P028R8P0TY:B09JFUP2CTi<0Q8B408N7Q`2=SHd0QHF508^;R`2R
XZ80WYjN0820P02HV9P0Kfm_08^;R`2ATI40Z:RX09bLW01WIfL0KFe]09BDU02@T900LW9b08V9R@2T
Y:@0XZ:R08^;R`2ATI40WIfM08Z:RP2BTY80PX:209:BTP2ATI40Rh^;07MgM`1dM7@0Ogmo0P1fMWH0
H`2<S8`0FEUI08N7Q`1gMgL0NGUi06ATI01oOgl0MGEe05=CD`1]KFd0L71`059BDP1RHV80J6QX07Yj
NP1/K6`0GUiN05aLG01CDe<0M7Ad07inOP23Ph<0K6a/08V9R@1WIfL0L71`065QH@2@T900Rh^;07em
O@2:RXX0QhN70861P@1^KVh0MGEe071`L01]KFd0QXJ607moO`1fMWH0I6AT071`L01kNg/0MgMg071`
L024Q8@0KFe]092@T01eMGD0MgMg065QH@22PX80O7al07UiN@1QHF40EeMG05EEE@1QHF40EUIF04m?
C`1UIFD0N7Qh06ATI01JFUX0D51@0451@@1MGEd0J6QX06][J`1KFe/0I6AT05]KF`1MGEd0H61P06EU
I@1HF5P0?Shn03Lg=`1CDe<0A4A405eMG@1/K6`0DU9B05IFEP16ATH0FUYJ03hn?P1<C4`0E5AD04E5
A@12@T80FUYJ03Lg=`1EEED0ADE505ADE015ADD0=cLg0?ooo`060=WIf@4000000@3IfMT001H0fMWI
00<000000=WIf@3IfMT00`3IfMT03P3oool0X:2P096AT@2[Zj/0_Kfm0:ZZZP2BTY80S8b<0;6a/@2^
[Zh0RXZ:0:>SX`2MWId0UiNG0P2VYZH03@2[Zj/0PH610::RXP25QHD0WYjN09RHV02[Zj/0XJ6Q09VI
V@2_[jl0XJ6Q0;>c/`2UYJD00P2ZZZX02P2>SXh0^[Zj0;Jf]P2VYZH0^;Rh0;Fe]@2LW9`0WYjN0:FU
Y@2e]KD209^KV`1O09nOW`2:RXX0UIFE0:VYZ@2HV9P0UYJF0:ZZZP2PX:00[:b/0;Bd]02VYZH0X:2P
0;^k^`2_[jl0^[Zj09FEU@2TY:@0XZ:R0<71`@32`/80/[:b0;Bd]02/[:`0/;2`0:f][@2e]KD0_;bl
09fMW@2>SXh0ZJVY0;bl_02b/[80^k^k0<30`02h^;P0[:b/0;bl_02c/k<0^k^k0:n_[`2e]KD0^;Rh
0:NWY`2NWYh0UIFE09jNWP2QXJ40XZ:R09jNWP2l_;`0Vi^K09BDU02<S8`0V9RH0:2PX027QhL0W9bL
0;>c/`2YZJT0WinO09jNWP31`L40W9bL0;Bd]02ZZZX0[Zj^09jNWP2g]kL0ZZZZ08Z:RP2RXZ80TI6A
09nOW`2][Jd0RXZ:0<;2`P24Q8@0_;bl0;fm_@2i^KT0Zj^[0;^k^`2^[Zh0WinO0;fm_@2SXj<0Vi^K
09jNWP2][Jd0[Zj^08N7Q`34a<@0UYJF09ZJVP2e]KD00P2CTi<209VIV@0a08N7Q`2?Shl0ZJVY0:^[
Z`2d];@0QhN709BDU02OWil0T92@0;Vi^@2_[jl0Zj^[0:FUY@2TY:@0VIVI08f=S@2IVIT0QXJ608Z:
RP2;Rh/0Ng]k08V9R@1eMGD0RXZ:07alO02@T900Xj>S09:BTP2QXJ40RXZ:0820P02JVYX0UYJF06i^
KP2FUYH0Ogmo096AT@1hN7P0Rh^;08Z:RP2<S8`0UiNG0:ZZZP24Q8@0Rh^;09BDU01hN7P0SXj>0820
P0020:>SX`0N08Z:RP26QXH0Rh^;08n?S`1nOWh0SHf=0::RXP2QXJ40X:2P07alO02<S8`0N7Qh09>C
T`2MWId0OWin06][J`1nOWh0Ng]k08f=S@2OWil0MgMg08>3P`22PX80Q8B40861P@25QHD0NWYj09:B
TP1iNGT0Q8B40P1ZJVX0@01DE5@0Cdm?04a<C01PH600HV9R07]kN`1UIFD0E5AD05iNGP1OGel0IFEU
06m_K`1hN7P0Ph>308V9R@28R8P0VIVI08j>SP1LG5`0GemO06m_K`1kNg/0MGEe06e]K@29RHT0Rh^;
06i^KP1jNWX0K6a/05mOG`1^KVh0MGEe05aLG01PH600MgMg07YjNP1fMWH0RHV906][J`1UIFD0HF5Q
06=SH`1hN7P0KVi^06m_K`1lO7`0GemO07QhN01QHF40I6AT06IVIP1aLG40EeMG05IFEP1JFUX0CDe=
07EeM@1ZJVX0GemO04Q8B01<C4`0Bd];065QH@1PH6020451@@0G05]KF`1NGUh0GemO059BDP1FEUH0
GUiN05UIF@0k>c/0JVYZ06i^KP1KFe/0B4Q804m?C`1OGel0>c/k04M7A`1SHf<0E5AD04i>CP1?Cdl0
ATI605ADE03oool01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00d0oooo
08V9R@2HV9P0^[Zj09JFUP22PX80LG5a08N7Q`26QXH0W9bL0:n_[`2IVIT0W9bL0080VYZJ01d0Ti>C
0:6QX@2OWil0RHV908f=S@23Ph<0U9BD09>CT`2ZZZX0TY:B0:6QX@2RXZ80UiNG0:FUY@3:b/X0ZZZZ
0:BTY02KVi/0UIFE09jNWP32`/80^KVi09BDU02][Jd0WIfM09VIV@2BTY80VIVI0;Vi^@030:6QX@1Y
09FEU@2j^[X0U9BD0:RXZ02f][H0[Jf]09:BTP2YZJT0SHf=0;Bd]02XZ:P0/K6a09bLW02d];@0^[Zj
0:>SX`2f][H0[Zj^09NGU`2g]kL0XZ:R09ZJVP2a/K40][Jf0:b/[02e]KD0^k^k0:n_[`2NWYh0`/;2
0;2`/02RXZ80TY:B0<C4a02OWil0_Kfm0:^[Z`2n_[h0WYjN0::RXP2_[jl0WIfM0:ZZZP2QXJ40TI6A
08V9R@2ATI40PX:2096AT@2MWId0YJFU0:JVYP28R8P0ZJVY09:BTP21PH40YjNW0:j^[P2[Zj/0_kno
0::RXP2b/[80QhN709jNWP2_[jl0YjNW08Z:RP24Q8@0[Jf]0;:b/P2g]kL0ZZZZ0:FUY@2`/;00Z:RX
08V9R@2BTY80];Bd0:VYZ@2XZ:P0ZJVY0:n_[`2^[Zh0Zj^[0:VYZ@2UYJD0VYZJ0:BTY02VYZH0]kNg
09BDU02NWYh0X:2P0:ZZZP2FUYH0YZJV0;Jf]P2c/k<0ZZZZ0;Zj^P2TY:@0YJFU0<30`02VYZH0TY:B
0080VYZJ01T0Ogmo0:BTY025QHD0]KFe07emO@29RHT0Ng]k08b<S024Q8@0VYZJ09^KV`27QhL0Jf][
09BDU028R8P0[:b/08V9R@20P800N7Qh09FEU@1hN7P0UIFE09BDU02ATI40SXj>0080QhN708D0P820
09RHV01eMGD0O7al09NGU`1cLg<0RXZ:07inOP21PH40Ogmo08>3P`2IVIT0Xj>S07emO@2DU9@0SXj>
07QhN02;Rh/0SHf=08j>SP29RHT0UiNG08N7Q`2DU9@0KVi^08Z:RP1dM7@0Q8B406m_K`2?Shl0R8R8
09BDU01_Kfl0MGEe08b<S01kNg/0RXZ:08^;R`1gMgL0Rh^;08n?S`22PX80D51@05YJFP1?Cdl0MWIf
05QHF01UIFD0Hf=S06UYJ@1TI6@0@D51059BDP1LG5`0Kfm_04E5A@27QhL0PX:206EUI@1eMGD0O7al
07AdM01kNg/0RXZ:07MgM`1YJFT0OWin07emO@1`L700Ph>30;Jf]P1nOWh0Q8B406m_K`1eMGD0Q8B4
079bLP1dM7@0I6AT06a/K01[Jf/0NWYj07EeM@1ZJVX0N7Qh05EEE@1lO7`0M7Ad05eMG@0h>3P0EEEE
055AD@1YJFT0GUiN04m?C`1_Kfl0Fe]K04a<C0000000HF5Q04];B`17AdL0GEeM04I6AP1GEeL0K6a/
06IVIP1?Cdl0D51@05ADE01UIFD0FUYJ065QH@1IFET0AdM703Ti>@10@400Bd];05MGE`1FEUH0L71`
03lo?`0n?Sh0Cdm?055AD@1MGEd0AdM701`L700];Bd0BTY:03Ti>@1?Cdl0oooo00H0fMWI0@000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0E0?ooo`2UYJD0[Jf]0:ZZZP2UYJD0][Jf09NG
U`2`/;00UIFE08j>SP2KVi/0W9bL06m_K`2MWId0/k>c07moO`2LW9`0Zj^[09JFUP2][Jd0WIfM0080
Ti>C01H0TY:B07moO`2DU9@0XJ6Q0:2PX02XZ:P0XZ:R0;6a/@29RHT0[Zj^0:>SX`2OWil0/[:b0:2P
X02>SXh0Rh^;0:BTY02ZZZX0W9bL0:f][@2c/k<0X:2P0`2^[Zh0N@2LW9`0WinO0;bl_02k^k/0YJFU
0:2PX02HV9P0UIFE0:b/[02CTi<0Zj^[0:FUY@2SXj<0YZJV0;^k^`2a/K40/;2`0<[:bP2FUYH0];Bd
0:^[Z`2QXJ40[:b/0:FUY@2b/[80^KVi0;jn_P2e]KD0VIVI0:f][@2e]KD0];Bd0:6QX@2JVYX0_[jn
0:FUY@2h^;P0`l?3096AT@2LW9`0WYjN0;2`/03Bd]80^k^k0:JVYP2][Jd0Rh^;08j>SP2][Jd0ZJVY
08>3P`1iNGT0VYZJ08F5Q@2LW9`0QhN70:ZZZP2c/k<0R8R80:NWY`2/[:`0[Zj^09jNWP2OWil0WIfM
0;Bd]02QXJ40ZZZZ0;jn_P2YZJT0YjNW0:ZZZP2[Zj/0_;bl0;6a/@39bLT0WIfM0:FUY@36a/H0bLW9
0:VYZ@2OWil0YjNW0;>c/`2FUYH0/;2`0:VYZ@2f][H0Y:BT0:f][@2PX:00Ti>C07alO029RHT0ZJVY
0;Jf]P2][Jd0NGUi09>CT`2QXJ40Xj>S09VIV@2WYjL0W9bL08F5Q@2_[jl0UIFE092@T028R8P0VYZJ
0:>SX`2KVi/0U9BD0:b/[02CTi<0UiNG08^;R`2QXJ40Q8B408f=S@21PH400P22PX80A@2a/K40Y:BT
08Z:RP22PX80OGem08Z:RP2CTi<0Shn?09JFUP2MWId0TI6A09:BTP2;Rh/0S8b<08f=S@29RHT0Ph>3
08Z:RP2<S8`0OGem08B4Q02DU9@0VIVI0861P@2EUID0V9RH09:BTP23Ph<0Vi^K09>CT`28R8P0V9RH
0861P@2LW9`0UIFE08N7Q`2<S8`0P82006m_K`1oOgl0NWYj08f=S@2:RXX0Q8B408^;R`1lO7`0IVIV
07AdM01DE5@0MWIf06UYJ@1MGEd0M7Ad04I6AP1ADE40Bd];069RHP1XJ6P0HF5Q04I6AP1KFe/0H61P
06ATI01CDe<0Jf][06e]K@1hN7P0MWIf08R8R00206a/K01806EUI@26QXH0KVi^07MgM`1ZJVX0Jf][
08J6QP1`L700PH61079bLP1fMWH0O7al08Z:RP1hN7P0QXJ6075aL@1iNGT0N7Qh07inOP28R8P0JFUY
05iNGP1VIVH0IfMW05eMG@1GEeL0Kfm_065QH@1GEeL0Fe]K06=SH`1WIfL0JVYZ05mOG`1PH600JVYZ
071`L01<C4`0@41003Ti>@0c<c<0>CTi03Lg=`18B4P0G5aL04I6AP1WIfL0J6QX05iNGP1<C4`0CTi>
04m?C`19BDT0GUiN03lo?`1<C4`0De=C05aLG01?Cdl0EeMG05eMG@17AdL0@T92055AD@10@400FEUI
03Hf=P1:BTX0@d=304A4A01GEeL0oooo1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI
00<0fMWI00<0oooo09fMW@2ZZZX00P2d];@0K`2UYJD0U9BD0:BTY02FUYH0[jn_09>CT`2MWId0/[:b
08Z:RP2XZ:P0WinO08J6QP2@T900X:2P0:^[Z`2TY:@0Zj^[09nOW`20P800RHV907inOP2VYZH0Y:BT
0:FUY@2JVYX0Y:BT0:f][@2ATI40]kNg09BDU028R8P0XZ:R09BDU02j^[X0Z:RX0:ZZZP2@T900][Jf
096AT@2PX:00Z:RX09bLW02SXj<0Kfm_09fMW@2c/k<0^KVi09RHV02UYJD0Y:BT09jNWP2XZ:P0Y:BT
0;Fe]@2[Zj/0VIVI0:BTY02XZ:P0b/[:0:n_[`2e]KD0/;2`0;Ng]`2][Jd0[:b/0;Fe]@2YZJT0[Jf]
0;Vi^@2e]KD0WYjN0:NWY`2f][H0[Zj^0;2`/02>SXh0XJ6Q0:NWY`2LW9`0Z:RX0:BTY02VYZH0Zj^[
0:>SX`2YZJT0X:2P0:BTY02a/K40X:2P0:BTY02OWil0S8b<08:2PP2OWil0Vi^K09JFUP2DU9@0WinO
09VIV@2LW9`0VYZJ0:NWY`2LW9`0WinO09fMW@2^[Zh0V9RH0;2`/02VYZH0];Bd092@T0020:>SX`80
][Jf01<0XJ6Q0::RXP2UYJD0YZJV09FEU@2][Jd0Z:RX0:BTY02j^[X0Xj>S0::RXP2XZ:P0/k>c0:BT
Y02d];@0VYZJ08f=S@2BTY80Ti>C0080UiNG04X0/[:b0:6QX@2YZJT0ZZZZ0;:b/P2>SXh0ZJVY0:ZZ
ZP2SXj<0ZJVY09:BTP2?Shl0Xj>S0::RXP2KVi/0W9bL08V9R@2?Shl0U9BD07YjNP25QHD0XJ6Q08F5
Q@2;Rh/0P82009fMW@2HV9P0QHF507MgM`26QXH0Shn?08Z:RP2NWYh0TY:B09RHV02;Rh/0S8b<07=c
L`27QhL0TY:B0::RXP2@T900OWin06m_K`22PX80U9BD09^KV`2;Rh/0QHF50:6QX@2ATI40WYjN079b
LP27QhL0RXZ:08R8R01jNWX0KFe]08F5Q@2FUYH0Ogmo08b<S01cLg<0SXj>08b<S01dM7@0PH6107Qh
N02>SXh0UIFE06UYJ@22PX80N7Qh0820P080R8R800l0SXj>079bLP1bLW80SHf=0861P@1^KVh0O7al
04e=C@1KFe/0I6AT05eMG@1PH600OWin06MWI`1NGUh00P1RHV80201bLW80MGEe06i^KP1fMWH0JFUY
09:BTP1RHV80EeMG0P1_Kfl0;P21PH40IfMW079bLP27QhL0Ogmo07emO@1hN7P0GemO07inOP1aLG40
NGUi06i^KP1aLG40IFEU08B4Q01kNg/0K6a/06m_K`1aLG40Jf][075aL@1gMgL0IVIV06QXJ01VIVH0
MgMg06UYJ@1OGel0De=C05MGE`1ZJVX0EEEE04U9B@1IFET0BDU903Hf=P1>CTh09bLW03hn?P0e=CD0
>SXj03<c<`1;Bd/0B4Q805QHF01:BTX205QHF00F05eMG@17AdL0CTi>03dm?@1;Bd/0?Shn05EEE@1O
Gel0EEEE04];B`1HF5P0EEEE04];B`0g=cL0>SXj05=CD`1>CTh0C4a<02PX:019BDT0@d=30?ooo`H0
fMWI0@0000010=WIf@005P3IfMT2000000@0fMWI04h0oooo0:j^[P2QXJ40RXZ:0:2PX02RXZ80X:2P
08^;R`2e]KD0XJ6Q092@T02OWil0MGEe09ZJVP2GUiL0Vi^K09VIV@2OWil0ZJVY0:FUY@2^[Zh0QHF5
08j>SP2EUID0TI6A0:BTY02WYjL0];Bd0;2`/02b/[80ZJVY0;:b/P2XZ:P0[Zj^09NGU`2VYZH0[Zj^
0;Jf]P2WYjL0X:2P0:BTY02c/k<0/[:b0;6a/@2HV9P0ZJVY09>CT`2;Rh/0VYZJ0::RXP2JVYX0YJFU
0;^k^`2h^;P0`/;20;Zj^P2PX:00ZJVY0:6QX@2j^[X0Vi^K09nOW`2UYJD0^KVi0;6a/@2KVi/0WinO
0:VYZ@2g]kL0][Jf0:^[Z`2GUiL0]kNg09:BTP2i^KT0YJFU0;:b/P2f][H20:2PX01C09bLW02n_[h0
^k^k0:JVYP2d];@0W9bL0:>SX`2VYZH0];Bd0:FUY@2/[:`0WIfM0::RXP2XZ:P0Xj>S0:n_[`2[Zj/0
V9RH06e]K@2SXj<0UYJF09NGU`2:RXX0V9RH0:2PX02GUiL0[:b/09RHV02_[jl0RHV90:^[Z`27QhL0
/K6a0:2PX02FUYH0bl_;0;6a/@2PX:00XJ6Q0;fm_@2XZ:P0_Kfm0;bl_02`/;00^k^k0:BTY02h^;P0
/;2`08:2PP2QXJ40Zj^[0:FUY@2FUYH0/;2`0;Vi^@2=SHd0YZJV0:b/[02LW9`0]kNg0;Rh^02[Zj/0
[Zj^09bLW02WYjL0`L710:b/[02YZJT0[:b/0:2PX02>SXh0Zj^[0:NWY`2c/k<0RXZ:0:>SX`2NWYh0
W9bL09ZJVP2QXJ40S8b<08V9R@1hN7P00P29RHT0U@27QhL0Shn?096AT@2KVi/0Rh^;07AdM020P800
Z:RX08f=S@26QXH0O7al07moO`2KVi/0RXZ:096AT@2MWId0QXJ609RHV026QXH0Rh^;07moO`2?Shl0
RHV908Z:RP1dM7@0RXZ:09nOW`2LW9`0TI6A08F5Q@29RHT0GEeM09bLW025QHD0MgMg0861P@28R8P0
VYZJ09FEU@27QhL0M7Ad079bLP23Ph<0T92@08:2PP21PH40Ti>C07]kN`2DU9@0Lg=c07]kN`20P800
Ogmo092@T01iNGT0Ng]k06=SH`1_Kfl0LG5a061PH01;Bd/0E5AD06][J`1SHf<0IfMW07=cL`1>CTh0
Jf][0861P@1NGUh0JVYZ05IFEP1XJ6P0PH61075aL@1TI6@0MWIf07EeM@1gMgL0Kfm_06a/K01aLG40
I6AT07inOP1dM7@0GUiN08^;R`1]KFd0IFEU0820P01kNg/0KFe]09fMW@21PH40LG5a06e]K@1gMgL0
K6a/05]KF`1/K6`0LG5a06e]K@1QHF40D51@07AdM01:BTX0I6AT0451@@1OGel0MWIf04I6AP1XJ6P0
BDU90451@@1?Cdl0?clo03@d=01=CDd0FEUI03/k>`0i>CT0DU9B03hn?P1BDU80EUIF05MGE`18B4P0
>SXj05=CD`12@T80E5AD0492@P0m?Cd0EeMG04A4A01OGel0@T9204a<C010@4000`<302XZ:P1>CTh0
ADE504Y:BP1PH600@d=305EEE@15ADD0oooo00D0fMWI0P0000010=WIf@005P3IfMT00`000000fMWI
0=WIf@030=WIf@0G0?ooo`28R8P0QHF508b<S02?Shl0UYJF09jNWP2XZ:P0TY:B09RHV02QXJ40/;2`
08n?S`2PX:00S8b<08>3P`2UYJD0VYZJ09jNWP2YZJT0_[jn09FEU@2UYJD00P2o_kl0201nOWh0VIVI
0:JVYP2RXZ80Zj^[09nOW`2b/[80Z:RX0P2RXZ80Q@2KVi/0[jn_0;2`/02WYjL0`/;209JFUP2?Shl0
RXZ:09VIV@2d];@0UiNG09fMW@2_[jl0UIFE0:2PX02^[Zh0Y:BT0:b/[02o_kl0E5AD09JFUP2e]KD0
ZJVY0<;2`P2j^[X0/k>c0<30`02c/k<0dM7A0:2PX02TY:@0`l?30;Rh^02^[Zh0][Jf0;Ng]`2XZ:P0
ZJVY09bLW02XZ:P0`/;209ZJVP2ZZZX0eMGE0<?3``2i^KT0[Jf]08b<S037alL0Y:BT09nOW`2i^KT0
YjNW09ZJVP2LW9`0ZJVY0:RXZ02LW9`0[:b/09RHV02MWId0UYJF0:JVYP2IVIT0VYZJ09JFUP2MWId0
T92@0:FUY@2OWil0Zj^[08b<S02OWil0SXj>0;6a/@2WYjL0[:b/0;Bd]02OWil0[:b/09bLW02QXJ40
WIfM0;Rh^02_[jl0WinO0;Vi^@2h^;P0XJ6Q0;^k^`2`/;00Xj>S0:f][@2/[:`0TY:B0:f][@2XZ:P0
WIfM09ZJVP2][Jd0/;2`09>CT`2JVYX0SXj>0;>c/`2GUiL0V9RH09bLW02YZJT0YZJV0:f][@21PH40
XJ6Q09VIV@2KVi/0WinO08j>SP2HV9P0Xj>S09^KV`27QhL0S8b<08n?S`2GUiL0SHf=08n?S`23Ph<0
Ogmo08n?S`1VIVH0QHF508n?S`2>SXh00P2MWId0701oOgl0PX:209bLW02IVIT0Ogmo024Q8@2>SXh0
LG5a08n?S`2MWId0X:2P08Z:RP1iNGT0VIVI08J6QP2IVIT0SHf=08F5Q@1nOWh0Xj>S096AT@1jNWX0
SXj>08>3P`1fMWH0O7al05eMG@1nOWh2096AT@0n0:2PX024Q8@0N7Qh07YjNP2FUYH0UiNG08R8R02=
SHd0MGEe08^;R`1nOWh0OGem07moO`1aLG40Ph>3079bLP28R8P0WinO07EeM@1^KVh0FUYJ071`L01O
Gel0N7Qh05EEE@1IFET0F5QH05MGE`1^KVh0Hf=S06e]K@1=CDd0JFUY051@D01TI6@0DE5A06i^KP20
P800QXJ609FEU@24Q8@0OGem07alO01PH600QhN706][J`1bLW80Hf=S07alO01ZJVX0LG5a06ATI01Y
JFT0IfMW06i^KP2@T900M7Ad06IVIP1cLg<0GemO05UIF@1GEeL2061PH00@06][J`1OGel0DU9B06IV
IP1nOWh0LG5a05UIF@1TI6@0KFe]05ADE01/K6`0MgMg04i>CP1@D5009bLW04m?C`80>CTi0200De=C
03Ti>@13@d<0EUIF03De=@0c<c<09RHV05EEE@10@400?3`l04Y:BP1@D500@D5103Hf=P1GEeL0BTY:
05QHF011@D40>3Ph04=3@`0f=SH0DE5A06=SH`1IFET0Cdm?05=CD`1BDU80EEEE04m?C`1>CTh0BTY:
0?ooo`H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0Q0?ooo`2@T900O7al
09NGU`2PX:00WYjN0:BTY02GUiL0QhN70;Jf]P2EUID0S8b<0:RXZ02<S8`0V9RH09JFUP26QXH0XZ:R
09jNWP2[Zj/0UiNG09^KV`2UYJD0WinO0::RXP28R8P0Xj>S0;Jf]P2SXj<0];Bd0:JVYP2HV9P0VIVI
0080UiNG01H0ZZZZ0;:b/P2YZJT0[:b/09:BTP2QXJ40YJFU09nOW`2NWYh0YJFU09VIV@2:RXX0Y:BT
0;>c/`2^[Zh0XJ6Q0:>SX`2QXJ40YJFU09FEU@2b/[80WinO0P2b/[80[@34a<@0W9bL0:RXZ03AdM40
XZ:R0;Bd]02@T900[Jf]0;Fe]@2o_kl0_;bl0:b/[02FUYH0[Zj^0:NWY`2h^;P0[:b/09fMW@2NWYh0
^;Rh0;Jf]P2`/;00]kNg0;6a/@2b/[80V9RH0;6a/@2QXJ40Vi^K0:BTY02_[jl0XJ6Q09jNWP2RXZ80
WYjN0:n_[`2PX:00Rh^;08b<S02HV9P0RXZ:08R8R02DU9@0V9RH08R8R02JVYX0^;Rh09>CT`27QhL0
[:b/0:JVYP2KVi/0^;Rh09fMW@2k^k/0ZJVY0<k>cP2EUID0YjNW0:JVYP2UYJD0]kNg0:^[Z`2/[:`0
P82009fMW@2EUID0Zj^[0:BTY01fMWH0WYjN08R8R02g]kL0U9BD0:n_[`2i^KT0VYZJ09>CT`2NWYh0
X:2P08F5Q@2[Zj/0X:2P0:NWY`2KVi/0UIFE08V9R@2PX:00Ph>30:NWY`2a/K40VIVI09BDU026QXH0
Xj>S0:NWY`2SXj<0SXj>08n?S`2g]kL0UiNG0:2PX029RHT0Shn?08:2PP1]KFd0QXJ608j>SP2<S8`0
KFe]09NGU`27QhL0QXJ608n?S`2BTY80NGUi04Q8B02:RXX0Ph>308B4Q02ATI40Vi^K075aL@2][Jd0
TY:B09nOW`1jNWX0Shn?08F5Q@2BTY80OWin08R8R02LW9`0QhN709NGU`2CTi<0V9RH08:2PP2DU9@0
MWIf06a/K024Q8@0KVi^08f=S@2BTY80U9BD05YJFP1fMWH0RHV907]kN`1iNGT0OGem07YjNP1/K6`0
LW9b07EeM@1fMWH0LG5a06QXJ01/K6`0QXJ607MgM`1nOWh0M7Ad06][J`1ADE40Hf=S05MGE`1VIVH0
C4a<04U9B@29RHT0IfMW0080Hf=S0500G5aL06QXJ01TI6@0MWIf051@D01/K6`0H61P06a/K01NGUh0
N7Qh06EUI@26QXH0Ti>C07=cL`1TI6@0Lg=c06QXJ01iNGT0M7Ad06a/K01eMGD0Lg=c07AdM01VIVH0
JFUY07=cL`1iNGT0MGEe08n?S`1^KVh0HF5Q05mOG`1UIFD0Jf][071`L01LG5`0HV9R06EUI@1XJ6P0
MGEe069RHP1`L700BTY:03Hf=P0d=3@0?3`l04I6AP1aLG40CTi>04e=C@1BDU80?Shn02TY:@0[:b/0
?clo030`<01EEED0@41003`l?01DE5@0F5QH06=SH`1aLG40>CTi05=CD`1VIVH0I6AT069RHP1MGEd0
J6QX04];B`1@D500@41003Lg=`1@D500BTY:03De=@0l?3`0:2PX0?ooo`H0fMWI0@0000010=WIf@00
5P3IfMT00`000000fMWI0=WIf@030=WIf@0A0?ooo`2DU9@0XJ6Q08J6QP21PH40S8b<0:6QX@2KVi/0
Q8B409^KV`2ATI40QHF50:>SX`2>SXh0XZ:R08^;R`2KVi/00P2FUYH20:2PX00J0:>SX`2HV9P0OGem
09ZJVP2DU9@0ZZZZ0:RXZ02FUYH0UIFE0;Fe]@2k^k/0Vi^K0:JVYP2e]KD0WYjN0;Zj^P2GUiL0ZJVY
0;6a/@2ATI40[Zj^09:BTP2i^KT0[:b/0:2PX02YZJT20:>SX`0_0;Zj^P2b/[80TY:B0:RXZ02[Zj/0
Z:RX0:NWY`2l_;`0][Jf0<30`037alL0Y:BT0:VYZ@2QXJ40WIfM0:b/[03AdM40]KFe0:^[Z`2d];@0
TY:B09BDU02a/K40ZJVY0:ZZZP2=SHd0WIfM096AT@2l_;`0Vi^K0:6QX@30`<00_;bl0:VYZ@2UYJD0
[:b/09VIV@2GUiL0QHF50;2`/02n_[h0[Jf]09NGU`2?Shl0UYJF0:FUY@24Q8@00P2@T900202a/K40
T92@096AT@2UYJD0[:b/08n?S`2KVi/0Xj>S0P2a/K405@2UYJD0][Jf09RHV01gMgL0YJFU0:ZZZP2P
X:00YjNW09bLW02UYJD0T92@0:NWY`2MWId0`l?30;Jf]P2=SHd0[:b/0:VYZ@2d];@0WYjN07emO@02
0:j^[P160:b/[02<S8`0SXj>09^KV`2ZZZX0WYjN09VIV@2SXj<0^k^k0:RXZ02CTi<0Vi^K0:n_[`29
RHT0X:2P09VIV@2XZ:P0Xj>S0:f][@27QhL0/k>c09:BTP2FUYH0RXZ:09jNWP1hN7P0RXZ:0:b/[01V
IVH0T92@08:2PP27QhL0NWYj075aL@22PX80Zj^[08Z:RP2GUiL0R8R808Z:RP2@T900MgMg092@T02A
TI40O7al08N7Q`1eMGD0OGem08:2PP2XZ:P0UYJF07EeM@2CTi<0TY:B0;6a/@2KVi/0VIVI06i^KP1a
LG40OWin092@T029RHT0MGEe08N7Q`2<S8`0TY:B07alO02LW9`0OGem07YjNP80O7al00l0RHV908Z:
RP25QHD0Kfm_08:2PP1TI6@0MGEe07emO@1bLW80NWYj09>CT`1UIFD0O7al07IfMP1iNGT00P2;Rh/0
1P2>SXh0SHf=07]kN`20P800Hf=S05EEE@80E5AD0100JFUY05mOG`1`L700F5QH069RHP1FEUH0HF5Q
06QXJ01LG5`0IfMW065QH@1UIFD0Ng]k06UYJ@1dM7@0MGEe0P1VIVH0;01IFET0G5aL06e]K@1XJ6P0
Lg=c07alO01jNWX0LG5a06YZJP1nOWh0IFEU05=CD`1kNg/0QXJ607UiN@1[Jf/0H61P07MgM`0l?3`0
K6a/051@D01=CDd0Jf][07inOP1LG5`0E5AD059BDP1MGEd0I6AT05EEE@1_Kfl0?3`l02l_;`0g=cL0
BTY:04];B`1?Cdl0@d=304e=C@11@D40;Rh^03Ti>@0d=3@0@d=30P1HF5P05P13@d<0BTY:05=CD`1B
DU80QXJ605iNGP1DE5@0@D5105ADE01JFUX0GEeM05ADE016ATH0>CTi05aLG00g=cL0?Cdm04E5A@1<
C4`0>c/k03`l?03oool60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0H@3o
ool0U9BD09^KV`2TY:@0W9bL09RHV02JVYX0ZZZZ0:VYZ@2=SHd0Zj^[0:n_[`2KVi/0ZJVY0::RXP2=
SHd0SXj>07YjNP2;Rh/0Y:BT0:b/[02FUYH0UiNG09RHV02ATI40W9bL0:^[Z`2IVIT0XJ6Q0::RXP2U
YJD0YZJV09:BTP2OWil0TI6A0;Bd]02RXZ80^KVi0;^k^`2MWId0ZZZZ09nOW`2JVYX0W9bL0<k>cP2V
YZH0Z:RX0:ZZZP2_[jl0^;Rh0:ZZZP2g]kL0^;Rh08j>SP2UYJD0V9RH09jNWP2YZJT0[Zj^0;2`/02j
^[X0]KFe09jNWP2^[Zh0[:b/0;bl_02n_[h0Z:RX09bLW038b<P0WYjN0:RXZ032`/80/[:b0;fm_@2D
U9@0_Kfm0;>c/`2][Jd0];Bd0:j^[P2FUYH0Z:RX0:f][@2=SHd0[:b/0;:b/P2d];@0Xj>S09ZJVP2Z
ZZX0UYJF09>CT`2FUYH0^k^k0:>SX`2OWil00P2EUID0<02XZ:P0UiNG08^;R`2CTi<0UiNG0:b/[02P
X:00[Jf]0:VYZ@2_[jl0Vi^K0:RXZ02IVIT0^k^k0<O7a`2a/K40WYjN0:ZZZP2`/;00[Zj^09nOW`2^
[Zh0]KFe09jNWP2YZJT0]KFe0:NWY`2OWil0[Zj^0;6a/@2QXJ40W9bL0;:b/P1jNWX0O7al0;Rh^02P
X:00Z:RX0;2`/02XZ:P0];Bd0820P02DU9@0YJFU08f=S@2YZJT0T92@08^;R`80RHV90200Xj>S07em
O@2GUiL0Shn?0;Jf]P2PX:00U9BD0:VYZ@2ATI40VYZJ07MgM`1dM7@0Lg=c06QXJ01RHV80NWYj075a
L@2LW9`0Ti>C09NGU`20P800VYZJ07inOP24Q8@0N7Qh07]kN`2LW9`0QHF508V9R@2VYZH0W9bL09fM
W@80R8R804P0UIFE08R8R02RXZ80SXj>0::RXP29RHT0V9RH08f=S@23Ph<0OGem06YZJP29RHT0T92@
08:2PP1oOgl0QhN709VIV@2=SHd0PH61096AT@2EUID0EeMG07]kN`23Ph<0RXZ:07IfMP27QhL0PX:2
07alO02DU9@0R8R807inOP1@D500P82007QhN026QXH0MWIf08J6QP1iNGT0MgMg06QXJ01YJFT0>CTi
04i>CP1TI6@0N7Qh05IFEP1/K6`0HV9R05mOG`1TI6@0Hf=S05iNGP1;Bd/0HV9R06ATI01/K6`0KFe]
08Z:RP23Ph<0IFEU07moO`1PH600LG5a06a/K01XJ6P0IVIV07EeM@1/K6`0Hf=S05eMG@1JFUX206QX
J00@06i^KP1QHF40PX:206IVIP1@D500GUiN06QXJ01:BTX0CDe=0492@P15ADD0<C4a06EUI@1cLg<0
OWin04Q8B080JVYZ00D0B4Q806QXJ00g=cL0:RXZ04I6AP0303Ti>@0L051@D01JFUX0D51@04E5A@0a
<C40=SHf04I6AP11@D40=cLg03`l?01/K6`0ATI6051@D011@D40D51@03/k>`1HF5P0>SXj05]KF`15
ADD0CTi>03/k>`0l?3`0EEEE04E5A@1<C4`0GUiN03lo?`80?Cdm00<0oooo0=WIf@3IfMT0103IfMT1
00000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0200oooo0;Bd]023Ph<0XJ6Q09NGU`26
QXH0YJFU08^;R`2PX:00Xj>S0;6a/@2i^KT0YjNW0:b/[02SXj<0VYZJ0;Vi^@2BTY80WIfM0:2PX02<
S8`0Ti>C08N7Q`2UYJD0UIFE0:JVYP2/[:`0[Jf]0:j^[P2MWId0Xj>S09FEU@80[:b/06L0/;2`0:BT
Y02PX:00Z:RX0;:b/P2e]KD0XZ:R09:BTP2YZJT0Z:RX08R8R02c/k<0][Jf08V9R@2`/;00U9BD0:n_
[`2ZZZX0VYZJ09jNWP2][Jd0ZJVY0:JVYP2NWYh0ZZZZ0<71`@2`/;00ZZZZ0:^[Z`2WYjL0Ti>C0<30
`02JVYX0_[jn0;fm_@2i^KT0h>3P0:2PX02QXJ40`<3008:2PP2VYZH0VIVI0;Vi^@2h^;P0ZZZZ0;Ng
]`2c/k<0^k^k09nOW`2SXj<0XZ:R09fMW@2l_;`0Q8B40:n_[`2b/[80WinO0:FUY@2;Rh/0O7al09RH
V02:RXX0X:2P09^KV`2XZ:P0Xj>S08J6QP2a/K40Xj>S0::RXP2PX:00Y:BT092@T02KVi/0/[:b0:2P
X02QXJ40]kNg0:ZZZP2TY:@0/[:b0:6QX@2JVYX0WIfM0;Bd]02j^[X0Zj^[0;2`/02_[jl0Vi^K0:ZZ
ZP2j^[X0^KVi0;Jf]P2OWil0XZ:R08:2PP2UYJD0ZJVY08n?S`2WYjL0W9bL0080Xj>S00l0WYjN0:6Q
X@2XZ:P0VYZJ09^KV`2HV9P0VYZJ0::RXP2EUID0VIVI09^KV`2@T900RXZ:09fMW@2PX:000P2=SHd0
S`2<S8`0NGUi09>CT`1eMGD0NGUi06m_K`1[Jf/0NGUi05UIF@1hN7P0OWin08R8R01jNWX0OGem07in
OP2?Shl0QHF509BDU027QhL0PX:207inOP1`L700UYJF07moO`2KVi/0Ph>30:b/[02<S8`0WIfM08^;
R`2:RXX0U9BD09ZJVP2>SXh0Rh^;08J6QP2PX:00RHV908J6QP1gMgL0WIfM08f=S@1kNg/0Rh^;08j>
SP29RHT0R8R807EeM@1oOgl0JFUY08R8R01YJFT0Lg=c06a/K01jNWX0QhN708j>SP28R8P0Ogmo06][
J`1mOGd0Ng]k06i^KP1nOWh0L71`06a/K01nOWh0FUYJ065QH@1gMgL0C4a<04E5A@1LG5`0IFEU04];
B`1VIVH0@T9205mOG`1hN7P0Bd];071`L01>CTh0I6AT07UiN@1kNg/0LG5a08j>SP1lO7`0Fe]K07If
MP1;Bd/0GEeM06UYJ@1_Kfl0DU9B06IVIP1SHf<0M7Ad05aLG01OGel0HV9R06=SH`1ADE40IfMW05IF
EP1PH600Fe]K059BDP0n?Sh06a/K0492@P1HF5P0EEEE03hn?P1gMgL0Ph>307alO01MGEd0IfMW065Q
H@1UIFD0ATI603Xj>P1>CTh0?3`l04E5A@1KFe/0F5QH03De=@0/;2`0:b/[01PH600U9BD0Bd];03dm
?@1GEeL0?Shn04e=C@17AdL0FUYJ04e=C@16ATH0E5AD0080>c/k00P0ADE505IFEP1EEED0A4A40410
@00f=SH0=CDe03<c<`80BTY:00<0@41003lo?`3oool01P3IfMT100000040fMWI000F0=WIf@030000
003IfMT0fMWI00<0fMWI03h0oooo09nOW`2FUYH0X:2P08n?S`2FUYH0RXZ:08F5Q@2KVi/0QXJ609^K
V`2FUYH0W9bL08n?S`1hN7P0X:2P0:j^[P28R8P0UiNG09RHV02TY:@0WYjN09FEU@2LW9`0WYjN0;Bd
]02^[Zh0^[Zj0;Vi^@2OWil0XZ:R0:VYZ@2KVi/0Z:RX09FEU@29RHT0TI6A0;2`/02RXZ80[jn_0;Bd
]02OWil0]KFe0;>c/`2b/[80WinO09>CT`2YZJT0XJ6Q0::RXP2XZ:P0WYjN08b<S02PX:00_;bl0:>S
X`2YZJT0[jn_09bLW02a/K40ZZZZ0<K6aP80/[:b0240X:2P0;Fe]@2ZZZX0aLG50:f][@2<S8`0Z:RX
0:^[Z`30`<00/K6a0<?3``2f][H0^[Zj0:FUY@30`<00/k>c0:2PX034a<@0[jn_0:ZZZP2HV9P0UYJF
08F5Q@2YZJT0W9bL0:JVYP2SXj<0YJFU09bLW01nOWh0VYZJ09VIV@2GUiL00P2OWil0K@2[Zj/0UIFE
0:n_[`2YZJT0YZJV0:FUY@2YZJT0SHf=08j>SP2FUYH0WinO0:>SX`2NWYh0UiNG0;Zj^P3=cLd0XJ6Q
09fMW@2SXj<0Z:RX0:^[Z`1kNg/0U9BD09^KV`2>SXh0T92@0:JVYP2PX:00];Bd0;Fe]@2MWId0XZ:R
0:2PX02;Rh/0WYjN0:2PX02`/;00[jn_0:>SX`2HV9P0ZJVY0;2`/02CTi<0V9RH0:BTY02VYZH0UYJF
0:>SX`2LW9`0SHf=0:j^[P2OWil0X:2P08Z:RP2NWYh0WinO09RHV02DU9@0MWIf0820P02<S8`0LW9b
09^KV`1`L700OWin0820P023Ph<0OWin08J6QP2EUID0MgMg0:2PX01hN7P0QhN708n?S`1aLG40S8b<
0:2PX026QXH0UiNG08n?S`2=SHd0Q8B4092@T02NWYh0U9BD096AT@28R8P0V9RH08B4Q01dM7@0QhN7
08>3P`2:RXX0T92@08F5Q@1mOGd0Shn?09fMW@20P800KFe]08b<S028R8P0Ti>C07UiN@23Ph<0Ng]k
08:2PP24Q8@00P1`L700G@24Q8@0QXJ6079bLP1nOWh0PX:207YjNP1QHF40JVYZ07emO@1kNg/0K6a/
05YJFP18B4P0I6AT06QXJ019BDT0G5aL05MGE`1;Bd/0H61P06][J`1BDU80IVIV05iNGP1QHF40G5aL
051@D01OGel0LG5a06e]K@1UIFD0QHF5079bLP1ZJVX0Ogmo06][J`1cLg<0Kfm_07=cL`1bLW80NGUi
07QhN01YJFT0L71`061PH019BDT0MgMg075aL@1JFUX0BDU905EEE@1;Bd/0;Bd]03Ti>@0g=cL0DE5A
03Xj>P0f=SH0A4A4038b<P1/K6`0HV9R05IFEP1CDe<0Fe]K04E5A@1SHf<0F5QH04e=C@0d=3@0820P
03Ti>@1CDe<0>SXj03<c<`0S8b<09bLW024Q8@1;Bd/0BTY:034a<@1VIVH0AdM704E5A@1?Cdl0>3Ph
03De=@16ATH0ADE504=3@`0m?Cd0EeMG04i>CP0204Y:BP0903Lg=`1:BTX0@d=304e=C@0h>3P0=3@d
0451@@0i>CT0oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0f0?oo
o`2IVIT0TY:B09BDU02NWYh0UYJF09bLW022PX80[:b/09fMW@2/[:`0XZ:R08f=S@2TY:@0Vi^K0;>c
/`2JVYX0WinO09FEU@2e]KD0UIFE09VIV@2OWil0[:b/0;Rh^02e]KD0WIfM0861P@2HV9P0[:b/09bL
W02IVIT0VYZJ0:^[Z`2SXj<0[jn_09:BTP2DU9@0XZ:R09NGU`2l_;`0/K6a0::RXP2g]kL0Zj^[09BD
U02f][H0[jn_0:f][@2o_kl0XJ6Q0:f][@2_[jl0VYZJ0P2/[:`0102`/;00[Zj^0:2PX02@T9020:ZZ
ZP080;2`/02a/K40YJFU0:FUY@2MWId0Xj>S0;6a/@2b/[820:^[Z`0Z0;Fe]@2`/;00_Kfm09NGU`2i
^KT0X:2P096AT@2JVYX0WinO09^KV`2LW9`0Q8B409FEU@2DU9@0W9bL0:b/[02PX:00Zj^[09bLW02/
[:`0/;2`0:FUY@2QXJ40Shn?09^KV`1[Jf/0WIfM0:j^[P2ATI40Shn?071`L02d];@0Y:BT0:6QX@2F
UYH0SXj>0;Jf]P2PX:00YjNW0:2PX02NWYh0YJFU0P2PX:003`2WYjL0];Bd0:VYZ@2/[:`0YjNW09VI
V@2YZJT0VYZJ09JFUP2HV9P0U9BD0:j^[P2n_[h0Rh^;09nOW`020:6QX@80[Jf]00D0XJ6Q0:RXZ02B
TY80XJ6Q0;2`/00209RHV00^0:VYZ@28R8P0Vi^K09nOW`1mOGd0VIVI08J6QP21PH40T92@0::RXP26
QXH0W9bL08^;R`2TY:@0PH6108F5Q@28R8P0OWin08Z:RP2DU9@0S8b<06=SH`2EUID0QHF506a/K01i
NGT0S8b<08f=S@2;Rh/0TI6A08:2PP2MWId0Ti>C09jNWP20P800MGEe08V9R@28R8P0U9BD09^KV`1l
O7`0V9RH07emO@2;Rh/0QXJ607emO@80QhN702<0Ph>308B4Q01kNg/0RHV9092@T02LW9`0TI6A06QX
J029RHT0Rh^;09fMW@25QHD0UiNG092@T02GUiL0OGem08F5Q@1XJ6P0NWYj07MgM`26QXH0Shn?08V9
R@1/K6`0Q8B408:2PP1bLW80Kfm_069RHP1LG5`0N7Qh06i^KP1VIVH0JFUY065QH@0206i^KP0J065Q
H@1kNg/0E5AD05EEE@17AdL0?Shn06MWI`1OGel0IFEU07EeM@1ZJVX0L71`07IfMP1^KVh0QHF5075a
L@1eMGD0OGem05eMG@1hN7P0M7Ad065QH@1nOWh0I6AT06=SH`1@D50207IfMP0g05MGE`1QHF40F5QH
05MGE`1>CTh0?Cdm03Ph>01>CTh0ADE504m?C`1;Bd/0B4Q803Hf=P0l?3`0<c<c02l_;`0b<S80CTi>
05QHF01DE5@0KVi^07=cL`1UIFD0EeMG05ADE00G5aL0>3Ph04E5A@0];Bd0>SXj01lO7`0/;2`0<30`
04E5A@13@d<0EUIF030`<01<C4`0=SHf030`<019BDT0ATI604E5A@1BDU80DE5A04I6AP1PH600@410
03Hf=P1CDe<0>c/k01@D5018B4P0>c/k02TY:@0203<c<`0304a<C03oool0fMWI00D0fMWI0@000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@2Q0?ooo`2;Rh/0Shn?08V9R@2FUYH0XJ6Q08j>
SP2EUID0Shn?09bLW02PX:00U9BD0:f][@2^[Zh0W9bL0:RXZ02YZJT0Ti>C09RHV02c/k<0VYZJ0:2P
X02VYZH0UYJF0:VYZ@2QXJ40RXZ:0:NWY`2a/K40ZJVY09nOW`2][Jd0[Zj^0:VYZ@2[Zj/0Xj>S096A
T@2`/;00Vi^K09RHV02YZJT0Z:RX09VIV@21PH40alO70;Vi^@2MWId0Y:BT0;Rh^02ZZZX0[:b/08b<
S02KVi/0Z:RX0:f][@2PX:00[:b/0:j^[P2VYZH0YJFU0;:b/P34a<@0_Kfm0<G5a@2ZZZX0Zj^[0:VY
Z@2f][H0YJFU0;>c/`2a/K40[Zj^0;jn_P2g]kL0_[jn0:ZZZP2>SXh0YJFU09^KV`2@T900ZJVY08V9
R@2WYjL0VYZJ0:NWY`2>SXh0QhN70::RXP2NWYh0XJ6Q0:RXZ02HV9P0UiNG0:f][@2NWYh0SHf=0:^[
Z`2m_Kd0[Zj^0:f][@2KVi/0Xj>S0;Bd]02SXj<0YZJV0:>SX`2VYZH0UiNG0:RXZ02YZJT0]KFe0:j^
[P2/[:`0Zj^[0;Fe]@30`<00^[Zj0:j^[P2e]KD0Z:RX0;Fe]@35aLD0VYZJ0:n_[`2SXj<0ZZZZ0;Jf
]P2][Jd0W9bL09BDU02LW9`0[jn_08^;R`2NWYh0W9bL0:BTY02ATI40V9RH09jNWP2PX:00VIVI0:6Q
X@2[Zj/0Y:BT0:ZZZP2NWYh0]KFe09fMW@2JVYX0/;2`0:j^[P28R8P0RHV908Z:RP2IVIT0Ti>C09NG
U`2<S8`0RHV909nOW`1gMgL00P2HV9P09P2EUID0S8b<08F5Q@2:RXX0SHf=06IVIP28R8P0P82008b<
S02IVIT0PX:209VIV@29RHT0Xj>S09BDU02;Rh/0OGem092@T020P800R8R808F5Q@2:RXX0TY:B08n?
S`2MWId0UIFE08F5Q@2CTi<0TI6A07YjNP1nOWh0QhN70861P@29RHT0SHf=09FEU@1bLW80GUiN0P2I
VIT01P24Q8@0e]KF07inOP1^KVh0TI6A08:2PP80SHf=06L0Lg=c07inOP2:RXX0Ph>3061PH02:RXX0
H61P05eMG@1GEeL0Kfm_06IVIP1WIfL0JVYZ079bLP1]KFd0LG5a059BDP1<C4`0CDe=05ADE011@D40
FEUI051@D01JFUX0Fe]K06EUI@1VIVH0IFEU05ADE01jNWX0K6a/06YZJP1fMWH0Jf][05eMG@1hN7P0
D51@06MWI`1QHF40K6a/07=cL`1lO7`0IfMW08R8R01LG5`0Ng]k05iNGP1LG5`0B4Q804I6AP0/;2`0
CDe=03`l?01EEED0Fe]K04Q8B00g=cL0>c/k04m?C`0a<C40B4Q804i>CP1WIfL0IVIV06UYJ@17AdL0
EEEE04m?C`0m?Cd0?Shn04m?C`0d=3@0CDe=01lO7`0`<300>SXj030`<00h>3P0Bd];059BDP1ADE40
F5QH05=CD`0];Bd0Bd];04M7A`1ADE40ADE504Q8B01CDe<0@T9204i>CP1CDe<0>c/k03Ph>012@T80
B4Q803Lg=`1>CTh0Bd];03lo?`0l?3`0oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI
0=WIf@030=WIf@0P0?ooo`2@T900WinO0:FUY@2:RXX0[Jf]09BDU02][Jd0WYjN07YjNP2JVYX0S8b<
07moO`2VYZH0[jn_09RHV02EUID0ZZZZ0:^[Z`2e]KD0S8b<0::RXP2][Jd0WinO0;Vi^@2VYZH0VIVI
09RHV02_[jl0^[Zj08Z:RP2NWYh20;2`/00=0:JVYP2MWId0[jn_0;Zj^P2NWYh0_kno0:n_[`2TY:@0
[jn_0;Vi^@2PX:00WIfM0:2PX00209bLW01Y0:6QX@29RHT0Xj>S0:2PX02RXZ80Shn?0;2`/02VYZH0
ZJVY0<;2`P2GUiL0WinO08n?S`2d];@0]KFe0;fm_@2g]kL0`<300;fm_@2VYZH0ZJVY09nOW`2[Zj/0
R8R80;^k^`2n_[h0Y:BT0:2PX02QXJ40^k^k09^KV`2LW9`0XZ:R096AT@2`/;00WinO0::RXP2DU9@0
UIFE0:RXZ02YZJT0WinO0:2PX02=SHd0_[jn0:NWY`2d];@0]KFe0:n_[`2HV9P0VYZJ0:ZZZP2TY:@0
S8b<0;Fe]@2@T900[Jf]0:^[Z`2ZZZX0Z:RX0<C4a02`/;00^;Rh0:RXZ02[Zj/0^KVi0:VYZ@2l_;`0
YjNW09NGU`2_[jl0]kNg0:RXZ02ZZZX0`l?30:VYZ@2][Jd0XZ:R0:b/[02^[Zh0XZ:R0;Rh^02WYjL0
VYZJ0:BTY027QhL0UiNG0:JVYP2IVIT0YjNW0;:b/P2`/;00Vi^K09jNWP1gMgL0WinO0:RXZ02d];@0
WinO09^KV`2XZ:P0WinO08V9R@2IVIT0TI6A0080Shn?01l0Zj^[0861P@2FUYH0Rh^;08j>SP22PX80
NWYj0:2PX021PH40MgMg06m_K`1kNg/0TY:B0:j^[P2HV9P0XJ6Q08j>SP2PX:00Ti>C07]kN`2OWil0
SHf=08n?S`1hN7P0K6a/09:BTP2TY:@0NGUi08N7Q`2LW9`0Q8B40080P8200140Ph>30820P01jNWX0
RHV908:2PP24Q8@0IfMW09bLW01lO7`0P82008:2PP1eMGD0IFEU096AT@29RHT0RXZ:06EUI@0206i^
KP1Z06a/K01cLg<0Ogmo07emO@1hN7P0Ph>3079bLP1NGUh0O7al06IVIP2;Rh/0H61P06QXJ01gMgL0
Lg=c071`L01ZJVX0N7Qh06a/K01ZJVX0MGEe05YJFP1=CDd0C4a<04U9B@1>CTh0IVIV061PH01hN7P0
GemO05YJFP1YJFT0MGEe08J6QP1NGUh0JVYZ06QXJ01EEED0NGUi08:2PP1`L700G5aL05]KF`1nOWh0
Ogmo06YZJP1IFET0JFUY0861P@1RHV80>CTi05UIF@0b<S80A4A404I6AP1?Cdl0IfMW05iNGP1[Jf/0
CDe=0410@00g=cL0=CDe04A4A00f=SH0Hf=S05ADE01EEED0Cdm?04a<C010@400?clo051@D014A4@0
BTY:05]KF`1DE5@0?3`l05iNGP1EEED0ATI605UIF@1@D500F5QH061PH01<C4`0ADE505QHF019BDT0
GemO04Y:BP0e=CD0Bd];04A4A01FEUH0@T9204E5A@0m?Cd0?clo02PX:015ADD0DU9B04Y:BP0l?3`0
>SXj0?ooo`H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@090?ooo`2XZ:P0
Shn?09NGU`2DU9@0WYjN08:2PP2LW9`0U9BD0080WYjN03D0Ti>C09VIV@2QXJ40XZ:R09NGU`2NWYh0
Ogmo0:^[Z`2KVi/0`/;20:j^[P2ATI40/k>c09ZJVP2ZZZX0YJFU0:JVYP2RXZ80SXj>09>CT`2UYJD0
W9bL0;Fe]@2IVIT0ZZZZ0::RXP2f][H0YJFU09fMW@2ZZZX0WinO0:>SX`2b/[80Xj>S0:NWY`2j^[X0
[:b/0;:b/P2k^k/0YjNW08Z:RP2KVi/0WinO0<30`02XZ:P0SHf=0<30`02NWYh0ZZZZ0:VYZ@2MWId0
_Kfm0:6QX@020;>c/`0Y0::RXP2][Jd0];Bd0::RXP26QXH0`/;209JFUP2BTY80[jn_0:JVYP2KVi/0
/k>c0:VYZ@2[Zj/0ZJVY0:>SX`2RXZ80SXj>096AT@2DU9@0Xj>S08Z:RP2=SHd0YZJV09FEU@2d];@0
Xj>S0:6QX@2VYZH0VYZJ09JFUP2@T900WYjN08f=S@2TY:@0Zj^[0:NWY`2ZZZX0Zj^[08V9R@2g]kL0
0P2`/;004P2_[jl0YZJV0;Bd]02CTi<0XZ:R0;:b/P2[Zj/0[:b/09fMW@36a/H0UIFE09ZJVP2i^KT0
UYJF0:BTY02WYjL0WinO0;Bd]080WIfM05@0UIFE0;jn_P2FUYH0Xj>S0;>c/`2HV9P0XZ:R0;Bd]02H
V9P0YjNW08f=S@2NWYh0YjNW08F5Q@2LW9`0]kNg0;2`/02QXJ40^KVi0::RXP2b/[80QhN709nOW`2C
Ti<0ZZZZ0:2PX02KVi/0UiNG08V9R@2:RXX0SXj>09BDU02EUID0Rh^;0:2PX029RHT0YJFU07emO@1g
MgL0TI6A092@T02BTY80UYJF07inOP2CTi<0Ng]k0861P@2CTi<0RHV9092@T021PH40RXZ:07alO02C
Ti<0Q8B408V9R@1aLG40SHf=0861P@1fMWH0QXJ607emO@2>SXh0QXJ608V9R@26QXH0Ogmo092@T02C
Ti<0MgMg08B4Q02?Shl0[Jf]07UiN@24Q8@0SHf=096AT@22PX80R8R806][J`25QHD0Rh^;08:2PP2L
W9`207alO00L06IVIP1/K6`0NWYj07MgM`1bLW80IVIV06=SH`1MGEd0G5aL05mOG`1cLg<0JFUY06=S
H`1EEED0E5AD06ATI01ADE40E5AD05UIF@1dM7@0IVIV065QH@1cLg<0G5aL05QHF01EEED0N7Qh07in
OP80Jf][00P0LG5a07alO01CDe<0JFUY08B4Q01BDU80CTi>06a/K080KVi^01L0F5QH07IfMP1NGUh0
@d=303Xj>P0Y:BT0HF5Q04U9B@1GEeL0Kfm_07MgM`1HF5P0Cdm?04i>CP0f=SH0:RXZ02HV9P18B4P0
F5QH07MgM`1ZJVX0F5QH069RHP0205ADE00704e=C@1KFe/0?Cdm05=CD`1;Bd/0BTY:02l_;`0204m?
C`0I04U9B@1@D500ATI605iNGP1GEeL0DE5A0492@P0k>c/0@d=303lo?`1[Jf/0FUYJ04Y:BP0a<C40
=cLg04m?C`0k>c/0?3`l03Ph>00j>SX0;Bd]03/k>`14A4@0?Shn0?ooo`060=WIf@4000000@3IfMT0
01H0fMWI00<000000=WIf@3IfMT00`3IfMT0H03oool0Vi^K0:n_[`2/[:`0VIVI0;>c/`2TY:@0[:b/
0;:b/P2GUiL0V9RH0:6QX@2LW9`0Z:RX0:>SX`2][Jd0TI6A0:ZZZP2;Rh/0WIfM0861P@2GUiL0XZ:R
0:JVYP2[Zj/0V9RH09FEU@2SXj<0WinO0;6a/@2c/k<0XJ6Q0:NWY`2IVIT0[:b/09VIV@2k^k/0S8b<
0::RXP2PX:00[Zj^0:VYZ@2[Zj/0Q8B40;bl_02DU9@0VIVI09:BTP2GUiL0WIfM09jNWP2o_kl0Zj^[
0<W9b@2_[jl0YjNW0;Vi^@33`l<0/;2`0:6QX@2e]KD0[Jf]0;Vi^@2^[Zh0^k^k0;jn_P2VYZH0/K6a
0<30`02NWYh0[:b/0;Rh^02f][H0YJFU0:^[Z`2YZJT0]kNg09bLW02@T900TI6A0:2PX02QXJ40YZJV
0:6QX@2UYJD0/k>c08Z:RP2VYZH0^KVi0;Fe]@2SXj<0WinO0:2PX029RHT0/;2`0;Bd]080[Zj^00@0
/K6a09jNWP2UYJD0TI6A0P2TY:@0WP2VYZH0^k^k0;Vi^@2o_kl0[Jf]09>CT`2SXj<0WinO0;Rh^02>
SXh0T92@08f=S@2CTi<0Vi^K0:j^[P2XZ:P0ZJVY0;^k^`2l_;`0ZJVY0:6QX@2VYZH0YjNW0:RXZ02f
][H0WinO0;Jf]P2MWId0ZZZZ09fMW@2^[Zh0UIFE0:VYZ@2SXj<0YZJV09VIV@2SXj<0QXJ609>CT`2N
WYh0YjNW09JFUP2UYJD0WinO0:j^[P2LW9`0Zj^[0:>SX`2JVYX0XJ6Q09nOW`2HV9P0PX:207YjNP20
P800RXZ:08N7Q`2@T900/K6a096AT@2:RXX0Ph>307moO`1hN7P0QHF508R8R01cLg<0PH6108V9R@2=
SHd0WIfM08Z:RP2HV9P0P82008Z:RP2IVIT0M7Ad07QhN02>SXh0MgMg0861P@2?Shl0TI6A07UiN@1R
HV80Q8B409NGU`2@T900UIFE08N7Q`2LW9`0UiNG07=cL`1iNGT0NWYj07MgM`1lO7`0Ogmo092@T01g
MgL0SHf=08J6QP25QHD0KVi^06UYJ@1fMWH0Q8B408Z:RP1eMGD0MWIf08V9R@22PX80Fe]K06QXJ01f
MWH0KFe]07QhN021PH40K6a/05iNGP1TI6@0@d=3055AD@1ZJVX0EUIF07MgM`1?Cdl0GEeM05UIF@1?
Cdl0IfMW065QH@1[Jf/0LG5a05aLG01`L700J6QX06m_K`1/K6`0LW9b05iNGP1dM7@0GemO06IVIP1K
Fe/0L71`059BDP1WIfL0Lg=c065QH@1jNWX0Kfm_06i^KP1]KFd0DU9B03/k>`0b<S80EeMG0P1TI6@0
<P1LG5`0CTi>04i>CP1PH600FEUI05]KF`0a<C408b<S0492@P10@400GemO05YJFP1OGel0JVYZ02TY
:@1:BTX0G5aL055AD@0o?cl0F5QH03`l?01<C4`0B4Q805eMG@0h>3P0ADE503dm?@1@D500A4A404I6
AP1DE5@0B4Q805mOG`1DE5@0Bd];05]KF`1YJFT0>SXj04Q8B01:BTX0?3`l03Lg=`1?Cdl0=cLg05AD
E01;Bd/0@D51034a<@0l?3`0oooo1P3IfMT100000040fMWI000F0=WIf@800000103IfMT0`P3oool0
XJ6Q09jNWP2BTY80UIFE08N7Q`2PX:00RHV90:6QX@2UYJD0Y:BT08J6QP2<S8`0XJ6Q07emO@2LW9`0
Ph>309FEU@2MWId0U9BD08b<S02[Zj/0PX:208f=S@2o_kl0XZ:R09^KV`2BTY80YJFU0:>SX`2>SXh0
][Jf0:NWY`2/[:`0P82009^KV`2^[Zh0UiNG08F5Q@2ATI40YZJV08b<S02RXZ80UIFE09bLW02MWId0
Xj>S09:BTP2XZ:P0X:2P09BDU02YZJT0^[Zj0:NWY`2g]kL0WYjN09nOW`2e]KD0ZZZZ0;Bd]02/[:`0
SXj>0:^[Z`2b/[80VIVI09BDU02d];@0Vi^K09jNWP2LW9`0X:2P0:RXZ02MWId0VYZJ09jNWP2=SHd0
W9bL0:VYZ@2PX:00W9bL09RHV02GUiL0WinO0:f][@2RXZ80U9BD09nOW`2ZZZX0ZJVY0:>SX`2JVYX0
Ti>C0:n_[`2RXZ80UiNG0:JVYP2RXZ80WYjN09fMW@2SXj<0Zj^[0:2PX02NWYh0_[jn09ZJVP2d];@0
XJ6Q0;Ng]`2XZ:P0][Jf0;6a/@2YZJT0RXZ:0;>c/`2SXj<0[jn_0:b/[02TY:@0[jn_0;:b/P2JVYX0
b<S809JFUP2KVi/0WIfM096AT@2TY:@0][Jf09JFUP1fMWH0[jn_09jNWP1oOgl0ZZZZ0:>SX`2BTY80
QhN707]kN`2][Jd0Vi^K0::RXP22PX80VIVI0:n_[`21PH40UIFE0820P02m_Kd0ZJVY09jNWP26QXH0
XJ6Q09VIV@2;Rh/0V9RH0:2PX02BTY80SHf=08b<S01kNg/0NWYj08:2PP2HV9P0Q8B406i^KP1=CDd0
MGEe08n?S`1kNg/0O7al08N7Q`29RHT0GEeM0861P@28R8P0P82006MWI`1mOGd0P82008N7Q`1oOgl0
MgMg07QhN02ATI40NGUi08j>SP1]KFd0MWIf07alO01kNg/0P82007MgM`1jNWX0S8b<0P1aLG407@1h
N7P0MGEe06ATI01XJ6P0NGUi09nOW`1eMGD0M7Ad09FEU@2<S8`0Ogmo08Z:RP1aLG40PH6107moO`24
Q8@0Ng]k06QXJ01bLW80FEUI06m_K`1OGel0IfMW07AdM01nOWh0QhN707MgM`1^KVh0G5aL00<0IVIV
0P1aLG40;01iNGT0FEUI065QH@1UIFD0FEUI04a<C01JFUX0D51@06UYJ@1WIfL0EeMG07AdM01;Bd/0
D51@061PH01ADE40IVIV06e]K@1?Cdl0FEUI05YJFP1bLW80LG5a07QhN01QHF40Jf][07=cL`1nOWh0
=CDe02TY:@17AdL0>c/k0492@P0f=SH0HF5Q04Q8B01OGel0GEeM05YJFP15ADD0=CDe038b<P0i>CT0
@D510P1@D5001P1EEED0EUIF06a/K010@400EEEE051@D080GUiN01H0ADE504e=C@1=CDd0GUiN04Y:
BP18B4P0<c<c069RHP12@T80@d=30410@01DE5@0Bd];04A4A01=CDd0@T9204I6AP0g=cL0AdM705UI
F@0d=3@0=CDe0P0`<3001P0e=CD07alO02/[:`0W9bL0B4Q80?ooo`D0fMWI0P0000010=WIf@005P3I
fMT00`000000fMWI0=WIf@030=WIf@0L0?ooo`2ZZZX0WinO0:^[Z`2DU9@0XJ6Q0:FUY@2ATI40YJFU
09bLW02OWil0YjNW0:RXZ02^[Zh0WIfM09VIV@2MWId0O7al08n?S`2>SXh0R8R808n?S`1^KVh0W9bL
09BDU031`L40TI6A07QhN080UYJF0P2XZ:P0^P2JVYX0^KVi0;6a/@2m_Kd0/k>c0:ZZZP2NWYh0ZJVY
09bLW02:RXX0ZZZZ0:JVYP30`<00Xj>S0:RXZ02GUiL0V9RH09fMW@2GUiL0V9RH09:BTP2ZZZX0X:2P
0:JVYP2c/k<0XJ6Q0;Ng]`2QXJ40_Kfm08f=S@2PX:00SHf=0;2`/02ZZZX0YjNW0;6a/@2LW9`0YZJV
0:BTY02g]kL0[Jf]09FEU@2PX:00^KVi09fMW@2<S8`0WinO0:BTY02?Shl0TI6A0:2PX02BTY80/[:b
0:>SX`2^[Zh0VYZJ09FEU@2LW9`0O7al0:JVYP2LW9`0X:2P09ZJVP2MWId0WinO0;2`/02YZJT0QhN7
0::RXP2j^[X0VYZJ0::RXP2[Zj/0[:b/0;2`/02][Jd0]kNg0:FUY@2][Jd0VIVI09RHV02RXZ80WinO
09>CT`2MWId0[Zj^0;bl_02_[jl0^[Zj0;Vi^@31`L40][Jf0;bl_02[Zj/0Y:BT07alO02ZZZX0WinO
09:BTP2HV9P0Y:BT092@T02DU9@0SXj>09RHV02^[Zh0XZ:R09JFUP2ATI40Rh^;0:FUY@2XZ:P0YjNW
09JFUP2XZ:P0Vi^K0:2PX02QXJ40Q8B409>CT`2>SXh0WYjN08B4Q02HV9P0S8b<09JFUP1hN7P0QHF5
07]kN`1MGEd0Ogmo08:2PP1ZJVX0Hf=S07YjNP1aLG40W9bL08Z:RP2;Rh/0YZJV07=cL`2ATI40P820
08b<S024Q8@0LW9b08N7Q`1QHF40NGUi08^;R`1kNg/0R8R808j>SP1UIFD0JFUY08^;R`28R8P0Q8B4
07]kN`1iNGT0M7Ad061PH01oOgl0I6AT07alO01mOGd0RXZ:07=cL`1bLW80M7Ad06=SH`1LG5`0KVi^
07EeM@24Q8@0FEUI07]kN`1XJ6P0Lg=c06IVIP1`L700NWYj06m_K`24Q8@0L71`08V9R@80IFEU00@0
QXJ607QhN01bLW80HF5Q0P1RHV80=P1SHf<0OWin071`L01NGUh0GEeM08:2PP1MGEd0JVYZ06QXJ01/
K6`0HF5Q061PH01oOgl0IfMW06IVIP1ADE40MgMg05mOG`1eMGD0HF5Q06EUI@1dM7@0IFEU06IVIP1H
F5P0D51@05]KF`1LG5`0Fe]K051@D01JFUX0GUiN061PH00m?Cd0BTY:03dm?@1=CDd0IfMW065QH@1L
G5`0FEUI04=3@`1EEED0<30`034a<@0g=cL0>3Ph04e=C@1PH600>CTi04e=C@1DE5@0De=C05MGE`80
GEeM0200A4A405iNGP1QHF40Fe]K05IFEP19BDT0A4A4030`<00o?cl0Bd];05EEE@0g=cL0ADE5051@
D01EEED0DE5A03Ph>01LG5`0;Rh^04Q8B00m?Cd0C4a<03Ph>00^;Rh06QXJ04=3@`12@T80Cdm?03Ti
>@0j>SX0@D510?ooo`H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0>0?oo
o`2VYZH0XZ:R0:JVYP2RXZ80][Jf0861P@2ATI40Z:RX0;Rh^02JVYX0Y:BT09:BTP2EUID209jNWP0/
08:2PP2FUYH0UYJF08:2PP2g]kL0IVIV00000023Ph<0Xj>S0:2PX02FUYH0VIVI09RHV02CTi<0];Bd
09ZJVP2>SXh0[jn_0:^[Z`2LW9`0U9BD08B4Q02PX:00UiNG096AT@2UYJD0Xj>S0:NWY`2PX:00YJFU
0;Vi^@2QXJ40S8b<0;Ng]`2d];@0ZZZZ0::RXP2^[Zh0UiNG0;>c/`2NWYh0QhN70:VYZ@2SXj<20:BT
Y0100;Zj^P2][Jd0Ogmo0:6QX@2JVYX0Q8B40:JVYP29RHT0/K6a0:VYZ@2LW9`0[Zj^0:NWY`2CTi<0
Rh^;09NGU`2ZZZX0WYjN09^KV`2e]KD0[Zj^0;:b/P2MWId0X:2P0:^[Z`2ATI40WIfM0:RXZ02CTi<0
S8b<09FEU@2NWYh0TI6A09NGU`2IVIT0YZJV09fMW@2f][H0_Kfm09RHV02m_Kd0ZZZZ0:>SX`2^[Zh0
Xj>S0:JVYP2][Jd0SHf=0;fm_@2k^k/0YJFU09JFUP2XZ:P0>CTi00H61P2^[Zh0[Jf]0:NWY`2h^;P0
ZJVY0<71`@2][Jd0Y:BT0:b/[080VYZJ0280SXj>09fMW@2b/[80[Jf]0:j^[P2QXJ40YZJV0:>SX`2g
]kL0XZ:R0:2PX02CTi<0WIfM08n?S`2QXJ40S8b<0:>SX`2MWId0S8b<09fMW@2?Shl0Vi^K08R8R02A
TI40XZ:R08n?S`34a<@0UYJF08B4Q02:RXX0VYZJ08Z:RP1mOGd0Ph>30P1nOWh0;@25QHD0PH61075a
L@2?Shl0MgMg092@T02HV9P0QXJ608j>SP2DU9@0Shn?08F5Q@1kNg/0VYZJ08Z:RP27QhL0QXJ608j>
SP1jNWX0JVYZ07AdM026QXH0FEUI07UiN@1mOGd0SHf=08F5Q@1gMgL0NGUi08^;R`1hN7P0Jf][08V9
R@22PX80VIVI08:2PP2KVi/0MGEe07YjNP1ZJVX0L71`08b<S01nOWh0J6QX07YjNP0208f=S@0g08b<
S02;Rh/0Jf][07=cL`1QHF40Hf=S069RHP1OGel0MgMg07inOP1<C4`0PX:206ATI01]KFd0JVYZ06m_
K`1`L700IVIV06][J`1mOGd0FEUI069RHP1cLg<0EeMG06e]K@1RHV80Hf=S06MWI`1`L700DU9B06YZ
JP1SHf<0IVIV06UYJ@1[Jf/0Fe]K06UYJ@1?Cdl0Bd];04a<C01QHF40FEUI06MWI`1eMGD0Lg=c04m?
C`1ZJVX0HV9R02l_;`0L71`0<S8b04Y:BP18B4P0J6QX05IFEP0205eMG@0^04U9B@0Z:RX0?Cdm04A4
A015ADD0IfMW05MGE`18B4P0CTi>04Y:BP1ZJVX0GEeM05EEE@1NGUh0FEUI04U9B@1BDU80G5aL0492
@P1;Bd/0H61P059BDP1MGEd0ATI604M7A`1PH600DU9B04e=C@1BDU80CDe=04Y:BP0h>3P0CDe=06i^
KP10@400DE5A04I6AP18B4P0@d=30492@P0l?3`0?Shn04E5A@0b<S80DE5A0?ooo`H0fMWI0@000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0V0?ooo`2;Rh/0Z:RX08n?S`2FUYH0UiNG0;Vi
^@2;Rh/0W9bL08F5Q@29RHT0Ti>C0:RXZ02?Shl0QXJ609>CT`2MWId0VYZJ096AT@2WYjL0VYZJ09NG
U`2SXj<0Q8B409^KV`2g]kL0/;2`0:VYZ@33`l<0QhN709bLW02ATI40/k>c0:f][@2BTY80VYZJ0;2`
/02PX:020:FUY@030::RXP2LW9`0Ti>C0080/[:b0180SXj>08V9R@2[Zj/0W9bL09NGU`2PX:00XJ6Q
08b<S02b/[80WIfM09VIV@2QXJ40YJFU0:BTY02UYJD0T92@08B4Q02TY:@20:2PX00;09nOW`2ZZZX0
XJ6Q0:6QX@2DU9@0YjNW09:BTP2ATI40W9bL0:RXZ02VYZH00P2YZJT01@2ZZZX0SXj>08R8R02>SXh0
Xj>S0080UYJF00l0ZZZZ0:j^[P2e]KD0VIVI09ZJVP2OWil0[Jf]0:6QX@2d];@0][Jf0:ZZZP2a/K40
][Jf09>CT`2HV9P00P2RXZ80>@2SXj<0V9RH0<;2`P31`L40^KVi0:b/[02?Shl0X:2P0;fm_@2o_kl0
Z:RX0<;2`P2YZJT0];Bd0<C4a02DU9@0XZ:R0;Bd]02RXZ80^;Rh0:^[Z`2o_kl0U9BD09VIV@2MWId0
/K6a09bLW02YZJT0SXj>0:JVYP2FUYH0VIVI09BDU02SXj<0U9BD0;2`/02OWil0W9bL09BDU02@T900
U9BD0;Fe]@2NWYh0QHF509jNWP29RHT0VIVI08n?S`2>SXh0RXZ:08J6QP2BTY80QhN70:j^[P2=SHd0
S8b<08f=S@020::RXP0P08j>SP1cLg<0S8b<096AT@2h^;P0N7Qh09VIV@2;Rh/0PH6109RHV02:RXX0
Shn?07emO@2KVi/0V9RH08J6QP2KVi/0MgMg09VIV@1eMGD0QHF507QhN01eMGD0Q8B406IVIP1fMWH0
LW9b069RHP1jNWX0J6QX06e]K@1`L70207AdM00b071`L01fMWH0Ng]k07emO@2@T900MgMg0861P@1_
Kfl0Shn?071`L01jNWX0JFUY08J6QP25QHD0KFe]06=SH`1lO7`0Ph>308:2PP1fMWH0M7Ad08:2PP1[
Jf/0G5aL07YjNP1/K6`0JFUY07MgM`1eMGD0Ng]k05iNGP1XJ6P0MGEe05eMG@1JFUX0JVYZ06i^KP1_
Kfl0JFUY055AD@1RHV80Jf][06EUI@1XJ6P0Fe]K07EeM@1cLg<0IFEU07inOP1hN7P206EUI@060861
P@1[Jf/0MGEe04i>CP1OGel0EEEE0P1[Jf/05P1oOgl0@d=306ATI017AdL0@d=3030`<00b<S80:b/[
04A4A01@D500ATI603lo?`1=CDd09BDU04M7A`12@T80=cLg04A4A01EEED0IfMW04];B`1<C4`205IF
EP0S05MGE`0h>3P0ATI604A4A01/K6`0HF5Q055AD@0i>CT0CTi>055AD@0h>3P0ATI603/k>`10@400
D51@059BDP19BDT0De=C051@D01GEeL0EEEE04m?C`1=CDd0>c/k03`l?01?Cdl0@41003/k>`1=CDd0
=3@d03/k>`0o?cl0=CDe03`l?03oool01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI
00<0fMWI04T0oooo0:2PX02JVYX0Rh^;09:BTP2?Shl0YjNW09BDU02OWil0R8R809RHV02RXZ80UIFE
09nOW`2KVi/0Shn?08N7Q`2XZ:P0T92@09NGU`2a/K40YZJV07MgM`2JVYX0UiNG09jNWP2SXj<0X:2P
09bLW02YZJT0YZJV09VIV@2[Zj/0VIVI0:j^[P2FUYH0XZ:R0:BTY02a/K40YZJV0;Rh^02WYjL0Y:BT
0;Jf]P2RXZ80WIfM08^;R`2DU9@0^;Rh0:FUY@2_[jl0YZJV0:NWY`2?Shl0Z:RX0<30`02MWId0V9RH
09^KV`2BTY80/K6a08Z:RP2EUID0^[Zj08n?S`2b/[80XZ:R0:6QX@23Ph<0TI6A08B4Q02QXJ40U9BD
0080XZ:R05D0YZJV0:FUY@2b/[80WYjN0:FUY@2EUID0[jn_09RHV02RXZ80VIVI0;6a/@2h^;P0UIFE
09fMW@2RXZ80X:2P0:VYZ@2CTi<0XZ:R09nOW`2HV9P0UYJF08J6QP2g]kL0XJ6Q09VIV@2c/k<0ZZZZ
09fMW@2e]KD0YJFU0;Jf]P2g]kL0[:b/09jNWP2WYjL0Zj^[09jNWP2RXZ80QHF508>3P`2ZZZX0]kNg
09^KV`2VYZH0/K6a0:n_[`2][Jd0_;bl09^KV`2RXZ80X:2P0;bl_02_[jl0/K6a0:^[Z`2UYJD0Y:BT
09nOW`2VYZH0^[Zj0:VYZ@2QXJ40V9RH09VIV@2NWYh0UiNG08^;R`2IVIT0ZJVY0;fm_@2GUiL0Rh^;
0:NWY`2OWil0Xj>S0:BTY01cLg<0Z:RX09>CT`2FUYH0YJFU0::RXP27QhL0OGem0080PX:201L0SXj>
0:^[Z`2WYjL0Ng]k09BDU02@T900MWIf08F5Q@2GUiL0U9BD07inOP1/K6`0Rh^;07YjNP27QhL0Ph>3
07QhN021PH40UIFE07]kN`1jNWX0PH6104m?C`0207IfMP1Q07]kN`1ZJVX0DU9B07alO01kNg/0NWYj
07AdM01gMgL0UiNG07]kN`2:RXX0M7Ad09:BTP2=SHd0LG5a07IfMP1hN7P0R8R808V9R@22PX80Jf][
079bLP2=SHd0KFe]07=cL`1oOgl0JVYZ07YjNP1MGEd0JFUY08R8R01RHV80NWYj065QH@1MGEd0Jf][
07EeM@1OGel0De=C06UYJ@1[Jf/0IVIV05eMG@1ZJVX0Kfm_05aLG01[Jf/0Q8B406QXJ01PH600LW9b
06QXJ01IFET0D51@06IVIP1TI6@0GemO061PH015ADD0EUIF079bLP1VIVH0IfMW04a<C01JFUX0Q8B4
05iNGP1`L700;2`/0000001SHf<0L71`05=CD`0j>SX0=3@d04M7A`0k>c/0ADE503hn?P1?Cdl0@T92
04a<C00P8200CDe=0492@P1EEED0FUYJ04A4A01DE5@0KVi^069RHP1[Jf/0IVIV05UIF@1PH600EeMG
06QXJ00205eMG@0L03Ti>@0m?Cd0>CTi05EEE@0n?Sh0:RXZ03<c<`1JFUX0ADE505QHF01:BTX0CTi>
05IFEP11@D40BDU904e=C@1KFe/0C4a<05]KF`1DE5@0@d=304Q8B01<C4`0EEEE02h^;P0=3@d0@D51
0?ooo`H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@1I0?ooo`2:RXX0WYjN
0:VYZ@2c/k<0TY:B0:JVYP2_[jl0UiNG09fMW@2GUiL0W9bL08j>SP2WYjL0W9bL09>CT`2EUID0UiNG
09JFUP2BTY80Ti>C0861P@2DU9@0PX:208b<S02QXJ40S8b<09BDU02IVIT0/;2`09bLW02CTi<0Y:BT
0:JVYP2YZJT0/[:b09FEU@2WYjL0XJ6Q0;>c/`2][Jd0Q8B40:RXZ02:RXX0[:b/0:2PX02NWYh0/k>c
0:2PX02MWId0YjNW0;:b/P2EUID0WYjN0:6QX@2LW9`0Q8B409VIV@2NWYh0Xj>S08j>SP2[Zj/0XZ:R
096AT@2UYJD0QhN708R8R02FUYH0ZZZZ09^KV`2QXJ40VIVI0<30`02KVi/0]KFe0:RXZ02RXZ80Y:BT
09BDU025QHD0OGem0:^[Z`2VYZH0]KFe09VIV@2][Jd0Xj>S0;:b/P2_[jl00P2/[:`0902GUiL0YZJV
0:VYZ@2][Jd0Y:BT0:RXZ02VYZH0Vi^K0:j^[P2EUID0ZZZZ09RHV02_[jl0UiNG0:b/[02[Zj/0/K6a
09ZJVP2b/[80ZJVY0:f][@2c/k<0^KVi0:b/[02h^;P0XJ6Q09RHV02GUiL0ZJVY09BDU02CTi<0PX:2
0:6QX@2=SHd0[Jf]09fMW@80[jn_00P0ZZZZ0:>SX`2^[Zh0YjNW09JFUP2WYjL0Q8B409RHV080Ti>C
00<0]kNg08J6QP2HV9P00P2>SXh0402GUiL0Ti>C08F5Q@2OWil0VYZJ09:BTP2?Shl0T92@08j>SP28
R8P0WinO08J6QP2UYJD0OGem08Z:RP28R8P208n?S`0E08Z:RP2HV9P0RHV909>CT`1iNGT0U9BD09jN
WP2RXZ80RHV9071`L02CTi<0S8b<08J6QP1hN7P0TY:B07alO01gMgL0Ogmo09VIV@1mOGd0RXZ:0080
HV9R00`0PH6107AdM020P800SXj>07alO020P800NGUi08B4Q01dM7@0E5AD08J6QP1dM7@207]kN`1U
07alO01XJ6P0W9bL07alO02>SXh0PH61069RHP2>SXh0KFe]07AdM029RHT0Ng]k07moO`1YJFT0P820
08:2PP1cLg<0OWin08>3P`1ZJVX0NWYj05]KF`1cLg<0Jf][07IfMP1_Kfl0PX:205iNGP1QHF40KVi^
04a<C01NGUh0H61P06UYJ@1GEeL0I6AT06e]K@1cLg<0M7Ad075aL@1RHV80SHf=07QhN01JFUX0A4A4
075aL@1LG5`0DE5A06IVIP1TI6@0DE5A05mOG`1VIVH0Fe]K04M7A`1IFET0NGUi065QH@1MGEd0IfMW
06UYJ@1[Jf/0=SHf02d];@0_;bl09RHV034a<@0S8b<0=CDe03lo?`13@d<0GemO059BDP1CDe<0JFUY
014A4@1>CTh0?3`l0451@@13@d<0BTY:04Q8B01EEED0J6QX059BDP1PH600@D5104];B`1DE5@0BTY:
03<c<`1HF5P0BDU905EEE@13@d<0B4Q805EEE@1JFUX0?clo05=CD`12@T800P1BDU80301=CDd0@D51
055AD@1GEeL0>3Ph02`/;016ATH0=CDe04A4A011@D409bLW0?ooo`H0fMWI0@0000010=WIf@005P3I
fMT00`000000fMWI0=WIf@030=WIf@0I0?ooo`1iNGT0Ti>C09ZJVP2UYJD0/[:b09RHV02BTY80Ti>C
09NGU`2SXj<0WIfM09VIV@2GUiL0YJFU08:2PP2[Zj/0Ng]k08f=S@2LW9`0V9RH09:BTP2CTi<0/k>c
0;2`/00209nOW`0_09FEU@2HV9P0WYjN0:ZZZP2NWYh0UYJF09jNWP2LW9`0WYjN0:6QX@2SXj<0YZJV
0;>c/`2SXj<0YJFU0:2PX02o_kl0]kNg092@T02b/[80W9bL0:n_[`2YZJT0XZ:R09nOW`2ATI40YZJV
0:FUY@2WYjL0Y:BT08J6QP2[Zj/0QXJ609JFUP2YZJT0U9BD0:BTY02OWil000000;>c/`2ATI40RHV9
0:RXZ02PX:00UiNG0:ZZZP2SXj<00P2WYjL0?`2[Zj/0/[:b0:VYZ@2`/;00]KFe0:NWY`2_[jl0WinO
0:f][@2CTi<0V9RH0:BTY02IVIT0ZJVY0:^[Z`35aLD0];Bd0;Vi^@2][Jd0UiNG0;Ng]`3Kfm/0/k>c
07alO02>SXh0Xj>S09nOW`2TY:@0W9bL08F5Q@2CTi<0]kNg0:b/[02LW9`0WIfM0:^[Z`2YZJT0Y:BT
0:NWY`2^[Zh0RHV90:^[Z`2h^;P0[Jf]0:BTY01jNWX0UiNG07MgM`2FUYH0XJ6Q0:n_[`2RXZ80Zj^[
0;Fe]@2/[:`0_kno0:VYZ@2@T900];Bd09:BTP1jNWX0Ng]k08:2PP020:>SX`0L0::RXP2][Jd0XJ6Q
09>CT`2?Shl0ZJVY08f=S@2HV9P0K6a/09^KV`2NWYh0S8b<08J6QP2>SXh0Ti>C08:2PP2HV9P0VIVI
07AdM02<S8`0MGEe092@T01QHF40NGUi09RHV02KVi/0]KFe06m_K`80Ogmo05h0QHF5092@T028R8P0
QhN707MgM`29RHT0PH6109fMW@26QXH0JFUY07QhN02ATI40MWIf07YjNP1YJFT0PX:207YjNP1/K6`0
MGEe08^;R`1aLG40O7al07moO`2DU9@0UYJF07alO01dM7@0UiNG06YZJP2DU9@0Ng]k08F5Q@1dM7@0
Ph>30861P@1oOgl0MWIf07MgM`27QhL0R8R807emO@22PX80Rh^;0:JVYP1dM7@0MWIf06m_K`1lO7`0
L71`07=cL`1OGel0Fe]K059BDP1LG5`0Lg=c065QH@1LG5`0LG5a06YZJP1XJ6P0EEEE069RHP1UIFD0
L71`07MgM`1HF5P0IFEU06e]K@1XJ6P0LW9b06ATI01GEeL0Jf][065QH@1HF5P0J6QX06IVIP1=CDd0
EEEE06m_K`1VIVH0CDe=06m_K`1WIfL0Fe]K06QXJ01ADE40De=C06EUI@1ZJVX0KVi^05ADE013@d<0
?Shn0P0g=cL0;`0f=SH0BDU9051@D01LG5`0>SXj06a/K01SHf<0I6AT05UIF@1VIVH0CTi>05ADE01<
C4`0D51@05]KF`1<C4`0BTY:05eMG@1BDU80@d=3059BDP19BDT0Bd];05YJFP1>CTh0>SXj05EEE@17
AdL0?clo059BDP0o?cl0B4Q802LW9`0b<S80?Shn06IVIP11@D40@d=303De=@0`<300?clo04=3@`0e
=CD0>SXj02h^;P000000oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WI
f@0a0?ooo`2HV9P0WIfM096AT@29RHT0U9BD092@T02UYJD0ZZZZ08^;R`2LW9`0UiNG09jNWP2SXj<0
PX:20:JVYP2LW9`0WinO08B4Q02UYJD0Xj>S08Z:RP2BTY80WIfM09ZJVP2RXZ80UIFE0;Fe]@2CTi<0
PH6109FEU@2PX:00UiNG09bLW02GUiL0[jn_0:^[Z`20P800Q8B40:NWY`2BTY80V9RH09jNWP2KVi/0
Z:RX0;>c/`2a/K40[jn_09:BTP0209jNWP0J08V9R@2XZ:P0SXj>09:BTP2/[:`0UiNG09jNWP2EUID0
V9RH0:BTY02b/[80YjNW09RHV02NWYh0/K6a0:^[Z`2SXj<0/;2`0:JVYP2IVIT0WIfM0;Bd]02PX:00
XZ:R09ZJVP2<S8`209VIV@0H0;2`/033`l<0YZJV0:FUY@2EUID0XZ:R0;Rh^02KVi/0Rh^;09fMW@2O
Wil0YZJV0:^[Z`2WYjL0Y:BT09VIV@2@T900d];B0:j^[P1hN7P0YZJV09jNWP2SXj<0^[Zj0P2f][H0
702IVIT0/K6a0:JVYP2FUYH0U9BD0:2PX02k^k/0UIFE0:RXZ02f][H0Y:BT09jNWP2LW9`0MgMg09nO
W`2FUYH0UIFE09NGU`2=SHd0TI6A08^;R`29RHT0U9BD0<_;b`2PX:00Vi^K0;>c/`2WYjL209fMW@0a
0:2PX02HV9P0Zj^[09^KV`2>SXh0S8b<08R8R02=SHd0RXZ:08F5Q@2PX:00Ti>C08>3P`2EUID0Xj>S
07moO`2GUiL0[Zj^08N7Q`2@T900YJFU08j>SP24Q8@0WIfM08N7Q`2HV9P0IVIV05]KF`23Ph<0WYjN
096AT@1iNGT0Ti>C08f=S@1nOWh0O7al07moO`2:RXX0Ng]k07UiN@2DU9@0T92@07moO`21PH40TY:B
06EUI@1kNg/0NWYj07UiN@0207QhN00Z06EUI@1WIfL0Hf=S06MWI`2:RXX0TY:B06m_K`1jNWX0HV9R
07inOP2GUiL0HF5Q071`L021PH40Rh^;07YjNP26QXH0Lg=c09VIV@2<S8`0K6a/08V9R@1gMgL0IfMW
08B4Q01[Jf/0MWIf08n?S`1SHf<0Jf][06QXJ020P800R8R807emO@1ADE40GUiN06i^KP1IFET0KFe]
05IFEP1HF5P0FUYJ0P1[Jf/206IVIP1B05QHF01PH600MGEe071`L01HF5P0BTY:06EUI@1TI6@0KVi^
05ADE01nOWh0K6a/08>3P`1UIFD0Hf=S06a/K01KFe/0K6a/07EeM@1]KFd0IfMW05]KF`1UIFD0Fe]K
05iNGP1_Kfl0KVi^06MWI`1SHf<0F5QH05aLG01CDe<0JFUY030`<019BDT0?3`l04I6AP0e=CD0CTi>
07AdM01=CDd0IVIV04Q8B01BDU80?Shn05QHF01JFUX0BDU905=CD`0e=CD0EEEE04e=C@1GEeL0=3@d
04i>CP1EEED0L71`03@d=012@T80F5QH04e=C@0o?cl0=3@d04M7A`18B4P0GUiN05MGE`0f=SH0<C4a
05iNGP1:BTX0GUiN04];B`13@d<0EEEE059BDP10@400De=C03Hf=P0/;2`04Q8B0?ooo`H0fMWI0@00
00010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0I0?ooo`2LW9`0XZ:R096AT@2RXZ80UYJF
0:6QX@2<S8`0ZZZZ09bLW02MWId0ZJVY0:FUY@28R8P0WIfM0;2`/02<S8`0YZJV08b<S02MWId0[Jf]
0:6QX@1fMWH0UIFE09NGU`020:>SX`070:^[Z`21PH40X:2P08b<S02MWId0T92@09NGU`0208n?S`0@
0:BTY02h^;P0XZ:R0:2PX02QXJ40ZZZZ0:JVYP2YZJT0Vi^K0:RXZ026QXH0Ti>C0:ZZZP23Ph<0W9bL
0:>SX`80Shn?02l0NGUi09FEU@27QhL0S8b<08B4Q025QHD0TI6A09RHV02BTY80[jn_0:>SX`2_[jl0
TI6A08f=S@2?Shl0RXZ:0:FUY@2HV9P0PH610;jn_P2FUYH0_[jn096AT@2][Jd0[:b/0:ZZZP2`/;00
UYJF09bLW02PX:00/;2`09NGU`2j^[X0[Zj^09nOW`2RXZ80UIFE0;Bd]036a/H0/k>c0:VYZ@2UYJD0
WYjN08n?S`2^[Zh0Z:RX0:2PX00209bLW00K096AT@2TY:@0aLG50<?3``2BTY80ZZZZ0:6QX@2MWId0
/K6a0;2`/02ZZZX0X:2P09NGU`2HV9P0VIVI0:JVYP2ZZZX0[Jf]092@T02RXZ80B4Q807IfMP21PH40
RHV909FEU@2NWYh0^[Zj0080YjNW02P0XZ:R09FEU@2?Shl0WinO09VIV@2MWId0YZJV09RHV02GUiL0
X:2P08:2PP2XZ:P0PX:207alO028R8P0QXJ606=SH`2>SXh0Shn?08:2PP2CTi<0UYJF07emO@2QXJ40
Q8B408n?S`2KVi/0QHF50:2PX02;Rh/0Ogmo07AdM02EUID0Lg=c07alO02XZ:P0QhN708Z:RP25QHD0
KFe]0P2ATI40>`1aLG40L71`07]kN`2MWId0OWin06i^KP20P800QHF507YjNP1UIFD0NWYj0:>SX`1W
IfL0Q8B407inOP2:RXX0M7Ad05QHF01WIfL0N7Qh08J6QP1`L700KVi^07alO01]KFd0J6QX06EUI@1B
DU80J6QX07AdM01^KVh0Rh^;075aL@23Ph<0N7Qh08J6QP24Q8@0W9bL07emO@1eMGD0GEeM08F5Q@1i
NGT0Ng]k079bLP1GEeL0C4a<05aLG01^KVh0GemO04U9B@1WIfL0GEeM06=SH`1YJFT0FUYJ06IVIP1/
K6`0>3Ph0080JVYZ03D0JFUY07AdM01^KVh0RXZ:05]KF`1nOWh0Ng]k06=SH`1[Jf/0EUIF06][J`1I
FET0NGUi04e=C@1GEeL0IFEU06e]K@1BDU80CTi>07UiN@1BDU80BTY:04i>CP1JFUX0LW9b05UIF@1M
GEd0I6AT04a<C01QHF40FUYJ04m?C`1;Bd/0AdM70492@P1:BTX0DE5A05MGE`1BDU80JVYZ05UIF@0`
<300@d=3034a<@1FEUH0BTY:04m?C`17AdL0<C4a05UIF@1<C4`0FEUI061PH00205YJFP0H04e=C@13
@d<0DE5A05UIF@1KFe/0BDU90451@@17AdL0;bl_04i>CP1JFUX0BTY:05iNGP0l?3`0@d=305MGE`0n
?Sh0E5AD03Hf=P0d=3@0ATI605IFEP0f=SH0oooo1P3IfMT100000040fMWI000F0=WIf@030000003I
fMT0fMWI00<0fMWI05P0oooo09nOW`2PX:00SXj>09^KV`2[Zj/0ZZZZ09NGU`26QXH0WIfM09^KV`2H
V9P0UIFE08F5Q@2BTY80WYjN0:b/[02TY:@0VYZJ0:BTY031`L40VYZJ09:BTP2LW9`0YjNW092@T02<
S8`0UYJF0:RXZ01cLg<0OWin09jNWP2DU9@0XZ:R08R8R02CTi<0T92@0:f][@2KVi/0[jn_09ZJVP2[
Zj/0Ti>C0:j^[P2FUYH0[jn_09NGU`1oOgl0UIFE09JFUP2RXZ80P82008J6QP25QHD0RHV906i^KP22
PX80S8b<09FEU@2FUYH0Y:BT0:2PX02SXj<0YjNW09:BTP24Q8@0V9RH09:BTP2JVYX0RHV909^KV`2W
YjL0UYJF09FEU@2LW9`0];Bd09fMW@2UYJD0[jn_09RHV02NWYh0Zj^[0:2PX02h^;P0Xj>S0;Vi^@2[
Zj/0Vi^K0P2`/;00AP2f][H0`l?30;Bd]02e]KD0_kno0;fm_@2d];@0YjNW0:b/[027QhL0X:2P09bL
W02=SHd0[Zj^0:JVYP2SXj<0Vi^K0;Jf]P2TY:@0/k>c0:FUY@2[Zj/0Rh^;08Z:RP2c/k<0T92@07Ee
M@24Q8@0W9bL08n?S`28R8P0MWIf096AT@1iNGT0PX:207AdM01oOgl0Shn?09^KV`3:b/X0/k>c0::R
XP2HV9P0Z:RX0:6QX@2OWil0X:2P0:f][@2=SHd0TY:B09VIV@2>SXh0Ogmo06i^KP2EUID0P82005eM
G@2EUID0IFEU07EeM@1iNGT0WIfM0:f][@2NWYh0Zj^[06EUI@2HV9P0PH610:2PX02FUYH208j>SP0Q
07inOP2<S8`0Ng]k09JFUP28R8P0Rh^;07inOP2BTY80Ng]k08N7Q`29RHT0U9BD0861P@1fMWH0P820
0:JVYP1hN7P0S8b<07QhN01aLG40OWin07moO`2>SXh0PH61071`L01SHf<0Q8B408N7Q`1iNGT0Vi^K
07YjNP1lO7`0NWYj0080QhN706X0IfMW069RHP1mOGd0GUiN092@T01SHf<0PX:207EeM@2@T900UIFE
07AdM01[Jf/0MWIf06][J`25QHD0Lg=c08F5Q@1kNg/0Rh^;08R8R026QXH0Lg=c079bLP1NGUh0G5aL
071`L01YJFT0J6QX059BDP1ADE40GEeM06QXJ01eMGD0FUYJ06IVIP1DE5@0EeMG05YJFP25QHD0EUIF
05QHF01_Kfl0K6a/07emO@1KFe/0DE5A08F5Q@1nOWh0LW9b08:2PP1ZJVX0HF5Q02PX:01?Cdl0FEUI
0410@01UIFD0CTi>07inOP18B4P0LG5a05ADE021PH40DE5A05YJFP1cLg<0CTi>05QHF01NGUh0H61P
04=3@`1LG5`0EEEE06QXJ01EEED0EUIF051@D01GEeL0@d=306QXJ01ADE40HF5Q05]KF`1ADE40F5QH
04Q8B017AdL0DU9B04Q8B00n?Sh0EeMG06IVIP1:BTX0IFEU04a<C01CDe<0@D5104M7A`1CDe<09bLW
04A4A017AdL0DU9B03lo?`0Z:RX0KFe]0P0m?Cd02@0T92@0@41004A4A017AdL0<30`0410@00o?cl0
=SHf0?ooo`060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0503oool0XZ:R
0:BTY02LW9`0X:2P09^KV`2JVYX0V9RH0;Ng]`2LW9`0ZZZZ09VIV@2PX:00Ti>C09bLW02DU9@0Ti>C
08n?S`2MWId0^[Zj0P29RHT0>02CTi<0WinO09NGU`1UIFD0UYJF0:n_[`2:RXX0Ph>309nOW`2;Rh/0
U9BD0:NWY`2/[:`0UIFE096AT@2XZ:P0UIFE0;Fe]@2YZJT0]kNg09VIV@2^[Zh0VIVI0:6QX@2IVIT0
V9RH07YjNP26QXH0LG5a069RHP2KVi/0SHf=07emO@29RHT0M7Ad08B4Q02?Shl0TI6A09FEU@2GUiL0
Vi^K0:RXZ02GUiL0LG5a09nOW`2FUYH0S8b<09bLW02OWil0^[Zj09BDU02EUID0XJ6Q09nOW`2>SXh0
Q8B40P2e]KD20:j^[P1E0;Fe]@2HV9P0WYjN0:JVYP2e]KD0YZJV0<C4a02n_[h0Y:BT0:j^[P2d];@0
WinO09ZJVP2XZ:P0VYZJ09>CT`1kNg/0Y:BT08N7Q`2QXJ40UIFE0;Rh^02OWil0VYZJ08F5Q@2RXZ80
/k>c0:RXZ028R8P0YjNW0;6a/@2d];@0ZJVY09>CT`2BTY80UYJF096AT@2@T900S8b<08V9R@2KVi/0
LW9b07inOP2>SXh0M7Ad079bLP1/K6`0U9BD09ZJVP2BTY80Y:BT09nOW`2HV9P0SXj>09:BTP2;Rh/0
UIFE0:^[Z`29RHT0Shn?092@T02OWil0OGem08n?S`1lO7`0RXZ:09BDU026QXH0JVYZ09:BTP2JVYX0
QHF508V9R@2EUID0Xj>S08j>SP2<S8`0W9bL07alO01_Kfl0QHF50820P02EUID0S8b<08j>SP0207em
O@0g07moO`2JVYX0UYJF08^;R`2CTi<0NWYj09BDU020P800F5QH08J6QP1lO7`0OGem06YZJP1gMgL0
K6a/07AdM01eMGD0UYJF08j>SP29RHT0Jf][07inOP1fMWH0NWYj08F5Q@1aLG40MWIf071`L01UIFD0
S8b<06MWI`1eMGD0PH61071`L01SHf<0RHV906a/K01^KVh0NWYj07UiN@1]KFd0NWYj06IVIP1TI6@0
OGem08N7Q`1mOGd0NGUi08b<S01ADE40MWIf07QhN01LG5`0EEEE06MWI`0207EeM@1H04i>CP1ADE40
EEEE05UIF@15ADD0EUIF05mOG`1]KFd0JVYZ069RHP1XJ6P0NWYj07inOP1>CTh0JFUY06m_K`1XJ6P0
FEUI065QH@1RHV80GemO05iNGP1PH600NWYj07UiN@1VIVH0Kfm_04A4A01FEUH0IFEU05eMG@1aLG40
DU9B06IVIP1GEeL0EUIF04a<C01BDU80HF5Q059BDP17AdL0@410055AD@1]KFd0DU9B04I6AP1NGUh0
@T9204a<C01CDe<0CTi>0410@01?Cdl0?Cdm04];B`0i>CT0?Cdm05eMG@1?Cdl0CDe=07EeM@1QHF40
FUYJ05iNGP1PH600ADE505ADE010@400?Shn05EEE@1>CTh0>3Ph03dm?@0i>CT0ATI603Xj>P0o?cl0
>3Ph04E5A@0o?cl0=cLg055AD@0c<c<0=3@d0451@@0h>3P0:b/[0?ooo`H0fMWI0@0000010=WIf@00
5P3IfMT00`000000fMWI0=WIf@030=WIf@0f0?ooo`2<S8`0NWYj08J6QP1kNg/0U9BD0:b/[02WYjL0
X:2P09BDU02UYJD0YZJV0820P02TY:@0RHV908R8R02@T900TI6A09jNWP2OWil0SHf=09VIV@2GUiL0
VIVI0:NWY`2b/[80Ti>C0:6QX@2SXj<0RHV90:6QX@25QHD0VYZJ0:n_[`2HV9P0Ti>C0:b/[025QHD0
Y:BT09nOW`1lO7`0XZ:R09BDU02WYjL0[jn_0:^[Z`2LW9`0YZJV09^KV`1eMGD0WIfM08N7Q`25QHD0
][Jf0P2=SHd06`29RHT0W9bL09VIV@29RHT0RXZ:09VIV@2FUYH0Xj>S07moO`0o?cl0NGUi0:6QX@2G
UiL0V9RH0;Rh^02^[Zh0XJ6Q0:>SX`2d];@0WYjN096AT@2RXZ80/[:b09JFUP2JVYX0bLW909fMW@02
0;>c/`0I0:RXZ02[Zj/0_[jn0;Ng]`2f][H0YJFU0;>c/`2n_[h0XJ6Q0:RXZ02PX:00WIfM08^;R`2K
Vi/0Ng]k09nOW`2[Zj/0W9bL0:JVYP2DU9@0YZJV0;6a/@2f][H0ZZZZ0:VYZ@020:NWY`0j09nOW`2f
][H0RHV908:2PP20P800U9BD096AT@1iNGT0NWYj09bLW029RHT0MgMg07UiN@1dM7@0KVi^05eMG@1O
Gel0MGEe08Z:RP2YZJT0[Jf]08b<S01lO7`0UIFE08N7Q`2CTi<0ZZZZ09^KV`1eMGD0R8R80861P@1/
K6`0Vi^K08^;R`2`/;00T92@08^;R`1jNWX0KVi^08>3P`2=SHd0RXZ:09RHV02JVYX0YjNW08:2PP2<
S8`0Xj>S09fMW@29RHT0SXj>08V9R@2UYJD0VIVI096AT@1hN7P0RHV90861P@80OGem02P0IfMW05EE
E@1fMWH0W9bL06UYJ@1KFe/0SHf=08F5Q@1YJFT0Rh^;07UiN@2BTY80PH6109FEU@22PX80KFe]06i^
KP1aLG40OWin08V9R@1VIVH0QhN708:2PP1/K6`0GEeM06m_K`1jNWX0QhN707EeM@24Q8@0MgMg07=c
L`1/K6`0Lg=c06ATI01`L700Q8B4079bLP2=SHd0PX:20P1oOgl0F@1JFUX0E5AD06YZJP1ZJVX0Lg=c
05MGE`1OGel0H61P07moO`1`L700GUiN06UYJ@1hN7P0GUiN03dm?@1?Cdl0EUIF05QHF01UIFD0Fe]K
05YJFP1MGEd0:RXZ0492@P1[Jf/0Fe]K065QH@1OGel0H61P07IfMP1GEeL0FEUI05EEE@1iNGT0J6QX
07=cL`1CDe<0H61P059BDP1TI6@0@d=307EeM@1BDU80GemO05YJFP1IFET0De=C05IFEP1QHF40KVi^
0451@@1;Bd/0IfMW07YjNP1ZJVX0HF5Q04];B`1HF5P0Hf=S06EUI@11@D40F5QH05mOG`13@d<0BDU9
05QHF01?Cdl0C4a<04E5A@1DE5@0HF5Q05UIF@1;Bd/0FUYJ04i>CP1MGEd0DU9B03`l?01CDe<0AdM7
06][J`1BDU80CDe=06ATI01EEED0>SXj0410@00l?3`0BTY:0080ATI600T0A4A404E5A@0h>3P0B4Q8
04];B`0`<300;bl_01XJ6P3oool01P3IfMT100000040fMWI000F0=WIf@800000103IfMT0703oool0
/k>c096AT@2FUYH0VIVI07=cL`2PX:00PX:20:RXZ02BTY80[Jf]08n?S`2JVYX0UiNG09fMW@2d];@0
U9BD08j>SP29RHT0Ti>C09BDU02QXJ40Xj>S08f=S@2QXJ40a<C409jNWP2IVIT208f=S@1K09NGU`2<
S8`0UiNG09:BTP2EUID0YjNW0:b/[02MWId0V9RH08F5Q@2XZ:P0^k^k09nOW`2TY:@0YjNW09FEU@1k
Ng/0R8R806YZJP1HF5P0Kfm_0:^[Z`2HV9P0/K6a0:JVYP2HV9P0Ph>30820P025QHD0W9bL09>CT`2Z
ZZX0Zj^[09ZJVP2GUiL0[Jf]0:2PX01kNg/0OGem09^KV`2^[Zh0WinO0:2PX02GUiL0WYjN092@T02S
Xj<0Q8B40:>SX`2XZ:P0[:b/08f=S@2ZZZX0/k>c0:BTY02WYjL0XJ6Q0;Ng]`2@T900Zj^[09NGU`2f
][H0Y:BT09jNWP2/[:`0WIfM0:2PX02OWil0T92@0:FUY@2ZZZX0/;2`0:2PX02ATI40alO70;2`/02D
U9@0V9RH0:RXZ02JVYX0QhN70:ZZZP2YZJT0VYZJ09^KV`2OWil0WIfM0861P@2UYJD0T92@07alO002
09FEU@0:09jNWP1kNg/0OWin0492@P1LG5`0MGEe08:2PP1`L700Ph>30:j^[P80SXj>0:L0UYJF092@
T02SXj<0UYJF09:BTP2XZ:P0MGEe07moO`1lO7`0Z:RX09JFUP20P800[jn_08n?S`2EUID0P82009nO
W`2IVIT0WYjN0::RXP2>SXh0UiNG096AT@2JVYX0Ti>C06i^KP2BTY80Shn?09RHV01oOgl0Y:BT07Qh
N02QXJ40WinO09^KV`2MWId0RXZ:059BDP000000QXJ608F5Q@1fMWH0TI6A092@T01[Jf/0IfMW06a/
K01iNGT0IFEU07AdM02=SHd0I6AT07QhN01/K6`0NWYj08F5Q@1mOGd0Rh^;06IVIP1oOgl0SXj>08:2
PP1fMWH0LG5a03Ph>028R8P0S8b<08^;R`28R8P0RHV906YZJP1cLg<0L71`07inOP1lO7`0Jf][07mo
O`29RHT0OGem07YjNP28R8P0M7Ad06QXJ01>CTh0PX:206EUI@1aLG40K6a/07EeM@20P800D51@06MW
I`1YJFT0DU9B02/[:`1YJFT0Jf][07IfMP1NGUh0GEeM07]kN`1DE5@0GemO06=SH`1eMGD0G5aL06YZ
JP1[Jf/0NGUi079bLP1=CDd0Hf=S07alO01bLW80IFEU055AD@1kNg/0IVIV06][J`15ADD0F5QH06=S
H`1QHF40De=C05aLG01<C4`0K6a/04E5A@1EEED0CDe=06IVIP1NGUh0GemO05UIF@1LG5`0CTi>05YJ
FP17AdL0CTi>03Ph>00a<C40F5QH051@D01YJFT0CTi>04A4A01<C4`0A4A405IFEP0f=SH0B4Q806=S
H`1IFET0D51@04I6AP1?Cdl0@d=303hn?P1RHV80A4A405EEE@0[:b/0FEUI05YJFP0k>c/09bLW03dm
?@0204e=C@0:0492@P18B4P0CDe=04a<C00Z:RX0<C4a04I6AP10@400:2PX0?ooo`D0fMWI0P000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@1S0?ooo`2UYJD0R8R808j>SP1iNGT0X:2P08R8
R020P800U9BD0:>SX`2FUYH0Ph>30:n_[`2i^KT0[:b/09fMW@21PH40RXZ:07UiN@2YZJT0XJ6Q08V9
R@2JVYX0WIfM0;Fe]@2XZ:P0T92@09ZJVP2HV9P0T92@09VIV@2EUID0X:2P08n?S`28R8P0OWin09VI
V@2SXj<0U9BD09RHV02^[Zh0V9RH0:JVYP2][Jd0Xj>S08B4Q026QXH0PX:207emO@2EUID0Q8B40:b/
[02JVYX0WIfM0;2`/02VYZH0K6a/08B4Q01kNg/0QHF50:6QX@2d];@0U9BD0:j^[P2KVi/0X:2P0::R
XP2_[jl0XJ6Q0:n_[`2EUID0`L710:JVYP2FUYH0/;2`0:2PX02:RXX0`L7109JFUP2YZJT0WinO0:b/
[02PX:00WinO09ZJVP2YZJT0Y:BT0:j^[P30`<00YJFU0:f][@2[Zj/0^;Rh0=3@d02ATI40/K6a096A
T@2XZ:P0VIVI0080X:2P0100VIVI0:>SX`2MWId0YJFU09nOW`2@T900SHf=0:BTY02GUiL0YjNW08b<
S02DU9@0O7al09bLW01]KFd0Ph>30P2DU9@06@26QXH0Ogmo096AT@2BTY80VIVI08R8R01MGEd0IfMW
05IFEP14A4@0AdM7065QH@2?Shl0VYZJ0<G5a@2FUYH0X:2P0:JVYP2KVi/0QHF509NGU`2BTY80Kfm_
08Z:RP26QXH00P2LW9`00`2NWYh0N7Qh07]kN`0207alO00O096AT@2>SXh0[Zj^09JFUP2OWil0Q8B4
0;Jf]P2IVIT0GEeM0:RXZ02FUYH0Ti>C07MgM`2OWil0VIVI07emO@26QXH0W9bL08N7Q`29RHT0X:2P
07IfMP2ATI40SXj>07EeM@1iNGT0GemO07moO`2CTi<0OGem05aLG00208:2PP0E07EeM@1`L700L71`
06a/K01nOWh0Lg=c08R8R022PX80J6QX08F5Q@1mOGd0QHF507=cL`1eMGD0Q8B408>3P`20P800Shn?
07inOP1mOGd0SXj>0080Ng]k0140Q8B406m_K`1@D500M7Ad065QH@1hN7P0H61P09JFUP1YJFT0Ng]k
07AdM01CDe<0F5QH0492@P1QHF40L71`06m_K`0206=SH`0P06QXJ01EEED0BDU904=3@`1WIfL0Hf=S
07]kN`1gMgL0Hf=S061PH01aLG40Fe]K05EEE@1@D500NGUi06m_K`1PH600KVi^061PH01aLG40J6QX
06=SH`1bLW80ATI6051@D01KFe/0C4a<05mOG`1FEUH0De=C06ATI01MGEd205EEE@0L04m?C`1IFET0
Bd];030`<01HF5P0?Shn04U9B@1IFET0ADE503hn?P1ADE40C4a<05YJFP1FEUH0Cdm?05QHF012@T80
=3@d05eMG@1DE5@0EUIF051@D01:BTX0De=C04Y:BP14A4@0D51@04E5A@80C4a<00T092@T04Y:BP1S
Hf<0BTY:05EEE@1IFET0GUiN03Hf=P0[:b/00P1:BTX03@0];Bd0BTY:04=3@`1ADE40ADE502`/;017
AdL0?Cdm02LW9`0e=CD0;2`/02DU9@3oool01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0
fMWI00<0fMWI0?l0oooo0:ZZZP2KVi/0VYZJ08j>SP29RHT0X:2P09:BTP2TY:@0Shn?09fMW@2?Shl0
WYjN09fMW@2SXj<0X:2P096AT@2NWYh0YZJV0;:b/P2IVIT0ZZZZ09ZJVP2RXZ80UIFE09RHV02@T900
TI6A0:BTY026QXH0P820075aL@2>SXh0YJFU0;^k^`24Q8@0WIfM08j>SP2?Shl0UIFE09VIV@2CTi<0
Zj^[0;Jf]P2QXJ40WYjN08n?S`24Q8@0NWYj08f=S@1nOWh0Zj^[08Z:RP22PX80]KFe0:VYZ@2QXJ40
Xj>S08Z:RP2GUiL0QHF509^KV`2SXj<0W9bL0:RXZ02QXJ40_;bl0;^k^`2SXj<0Ng]k06m_K`2NWYh0
[Jf]0:2PX02MWId0TI6A0:6QX@2WYjL0];Bd0;^k^`2MWId0Xj>S0:b/[02FUYH0UIFE0;2`/02ZZZX0
XZ:R0:NWY`2ZZZX0_kno0:b/[02o_kl0YZJV0:NWY`2BTY80ZJVY0::RXP2VYZH0YJFU0;Rh^02LW9`0
V9RH0:FUY@2:RXX0WinO0:j^[P2>SXh0_kno09FEU@2JVYX0/[:b0:VYZ@2BTY80V9RH09jNWP29RHT0
Q8B4079bLP1nOWh0Ph>307IfMP1hN7P0OGem09JFUP24Q8@0JVYZ05EEE@1?Cdl0H61P04=3@`1aLG40
R8R809FEU@2WYjL0Y:BT0;Vi^@2^[Zh0N7Qh07]kN`2@T900MWIf07YjNP2@T900TI6A0:NWY`2LW9`0
N7Qh0820P01gMgL0PH6106i^KP2:RXX0Rh^;09^KV`2ZZZX0Shn?0:2PX027QhL0T92@08>3P`2WYjL0
SXj>0:^[Z`2DU9@0Ti>C09:BTP2LW9`0O7al08F5Q@1_Kfl0OGem0861P@2<S8`0Q8B406e]K@28R8P0
Shn?08B4Q023Ph<0Ogmo08R8R01^KVh0PX:208n?S`2:RXX0V9RH092@T01VIVH0I6AT07AdM01_Kfl0
P82007inOP1PH600KFe]08V9R@1cLg<0Ti>C07EeM@1DE5@0M7Ad07moO`29RHT0PH6108:2PP1`L700
J6QX06m_K`25QHD0TI6A08Z:RP1/K6`0FEUI06a/K01dM7@0O7al0820P01?Cdl0GemO06ATI01:BTX0
LW9b06EUI@1NGUh0KFe]05mOG`1CDe<0EUIF05aLG01?Cdl0J6QX06=SH`1iNGT0MGEe08B4Q021PH40
Jf][06a/K01QHF40H61P05eMG@1SHf<0JFUY05eMG@1KFe/0EEEE06QXJ01IFET0DU9B04i>CP1IFET0
DE5A0861P@1NGUh003/0NWYj04a<C01ZJVX0CTi>06IVIP18B4P0Hf=S05QHF01NGUh0GEeM051@D01R
HV80C4a<04m?C`1GEeL0@D5104i>CP1<C4`0KVi^03dm?@0c<c<0ATI603dm?@1@D500>3Ph04i>CP0f
=SH0>3Ph04Q8B01;Bd/0?Cdm03`l?01GEeL0DE5A05UIF@0j>SX0G5aL051@D00l?3`0:b/[04];B`1@
D500EEEE0410@01EEED0;bl_03lo?`14A4@0CTi>04U9B@0W9bL0De=C051@D00Y:BT0<c<c02`/;00Y
:BT0@D510?ooo`060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0603oool0
Vi^K08f=S@2HV9P0WIfM09NGU`2QXJ40YJFU07YjNP2UYJD0WIfM09>CT`2HV9P0TY:B09VIV@2ATI40
OGem0:RXZ02OWil0TI6A08F5Q@2>SXh0WYjN08>3P`80Xj>S08T0V9RH0:>SX`2GUiL0TI6A08>3P`2X
Z:P0RHV90:2PX02;Rh/0UiNG096AT@2GUiL0[Zj^0;Rh^02MWId0M7Ad09>CT`2FUYH0[:b/0:JVYP1k
Ng/0S8b<096AT@23Ph<0KFe]09FEU@2>SXh0QXJ608F5Q@2QXJ40Ogmo09ZJVP23Ph<0P82008j>SP2:
RXX0^;Rh0;^k^`2RXZ80ZJVY09NGU`23Ph<0ZJVY08V9R@2ZZZX0VYZJ092@T02GUiL0X:2P0:BTY02a
/K40Xj>S0:n_[`2b/[80YZJV09fMW@2[Zj/0[Jf]0=OGe`2ATI40Z:RX0;Jf]P2DU9@0W9bL09JFUP2V
YZH0WinO0:VYZ@2/[:`0WIfM0:VYZ@2[Zj/0WinO0;Fe]@2i^KT0/[:b09NGU`2OWil0U9BD0:2PX02[
Zj/0W9bL09FEU@2j^[X0YjNW0;Ng]`2MWId0WinO09jNWP1jNWX0K6a/08>3P`20P800M7Ad08R8R01f
MWH0Rh^;09fMW@1]KFd0MGEe06][J`0k>c/0Bd];04=3@`1?Cdl0IVIV07emO@1aLG40YZJV08R8R02M
WId0T92@09BDU02GUiL0UYJF08^;R`26QXH0NWYj08B4Q02BTY80VIVI08R8R01hN7P0De=C07=cL`26
QXH0TY:B0:VYZ@29RHT0T92@08F5Q@27QhL0UIFE07alO02JVYX0VIVI09>CT`0209jNWP0a08N7Q`2J
VYX0QXJ608Z:RP1fMWH0Q8B408J6QP20P800Jf][07AdM01`L700FUYJ08V9R@1iNGT0OWin08Z:RP1n
OWh0QhN705UIF@1HF5P0UIFE07QhN028R8P0G5aL07EeM@22PX80Ogmo075aL@1WIfL0TY:B07AdM01T
I6@0Lg=c07moO`2=SHd0OWin08B4Q02MWId0L71`07IfMP1iNGT0L71`08F5Q@1lO7`0NWYj08R8R01S
Hf<0WIfM06m_K`0207]kN`0807QhN01eMGD0PH6106YZJP1JFUX0Bd];05QHF01@D50205QHF00H04E5
A@1?Cdl0Hf=S03`l?01MGEd0FEUI05YJFP1aLG40FUYJ07QhN01MGEd0Hf=S06YZJP1UIFD0NGUi07Mg
M`1SHf<0JVYZ071`L01SHf<0Lg=c04e=C@0d=3@0IfMW0P1XJ6P00`1QHF40C4a<05iNGP02065QH@0_
05aLG01FEUH0KVi^06MWI`1HF5P0HF5Q06MWI`1?Cdl0EeMG04Y:BP14A4@0EUIF05MGE`17AdL0EEEE
04a<C00m?Cd0?3`l03Xj>P1@D500De=C03Lg=`15ADD0A4A4038b<P0^;Rh0<C4a04e=C@1`L700D51@
059BDP1EEED0>CTi02XZ:P1:BTX0Bd];04I6AP1EEED0CTi>05]KF`1=CDd0BDU902`/;01:BTX0?clo
059BDP0R8R800P1>CTh0200h>3P04Q8B03<c<`1HF5P0B4Q80410@015ADD0oooo1P3IfMT100000040
fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI03T0oooo07inOP2;Rh/0Ti>C0:f][@2e]KD0UYJF
0:NWY`2FUYH0[Jf]0:ZZZP2RXZ80Vi^K08Z:RP2LW9`0RXZ:0:NWY`2FUYH0RXZ:08B4Q02VYZH0XJ6Q
0::RXP2XZ:P0Shn?0:JVYP000000VYZJ0:6QX@25QHD0Q8B409RHV02TY:@0X:2P07QhN025QHD0WinO
08n?S`2`/;00/[:b0:NWY`2GUiL0YjNW08V9R@2CTi<0UiNG09bLW01aLG40U9BD09ZJVP2MWId0TI6A
09>CT`2<S8`0Ng]k09ZJVP2@T9000P2:RXX0:@20P800T92@0:>SX`2VYZH0lO7a0:^[Z`2XZ:P0Zj^[
08n?S`2DU9@0VIVI0:f][@2RXZ80UiNG09RHV02FUYH0_Kfm08^;R`2^[Zh0ZZZZ0;Fe]@2XZ:P0ZZZZ
0;Fe]@2h^;P0YjNW09>CT`2l_;`0`/;209jNWP2SXj<0XJ6Q0:ZZZP2EUID0/[:b09jNWP2QXJ40VYZJ
09fMW@2BTY80YJFU0080ZJVY04X0X:2P09FEU@2YZJT0RXZ:0:VYZ@2^[Zh0UiNG09:BTP2>SXh0/;2`
0:^[Z`2VYZH0WinO096AT@1mOGd0Ph>307EeM@1MGEd0HF5Q05mOG`1^KVh0IFEU06MWI`1hN7P0HV9R
06YZJP1@D500Bd];04e=C@1IFET0IfMW07YjNP2EUID0Xj>S09JFUP2EUID0T92@09^KV`27QhL0TI6A
09>CT`2:RXX0Rh^;07inOP2FUYH0U9BD08Z:RP2FUYH0QXJ607YjNP2TY:@0Shn?09bLW02EUID0XJ6Q
0:ZZZP2YZJT0Shn?09jNWP1gMgL0WinO09:BTP2OWil0VYZJ09JFUP2TY:@0Ogmo09jNWP28R8P0T92@
08R8R02?Shl0P820096AT@80U9BD06@0Q8B40820P02IVIT0OGem07QhN01oOgl0TY:B07moO`1`L700
OGem092@T026QXH0N7Qh08n?S`1cLg<0MWIf07YjNP28R8P0MGEe07emO@1TI6@0Kfm_079bLP2:RXX0
W9bL079bLP1kNg/0SXj>07moO`1/K6`0OGem06YZJP1SHf<0Vi^K075aL@1jNWX0IfMW079bLP1_Kfl0
U9BD05ADE01BDU80BTY:065QH@16ATH0CTi>04I6AP15ADD0Cdm?05UIF@1WIfL0H61P06YZJP1MGEd0
JVYZ05YJFP1]KFd0Ng]k06MWI`1YJFT0FEUI0492@P1DE5@0EEEE06a/K020P800L71`05EEE@1PH600
I6AT05YJFP0[:b/0GEeM05iNGP1VIVH0@d=304U9B@1RHV80CTi>04];B`1XJ6P0GemO05eMG@1CDe<0
G5aL05EEE@1MGEd0IfMW04U9B@0j>SX0CDe=05eMG@1DE5@0IVIV069RHP1CDe<0>c/k030`<012@T80
:2PX0P0m?Cd08P18B4P0H61P03lo?`1LG5`0A4A404I6AP17AdL0@d=303/k>`17AdL0>SXj0451@@1A
DE40Cdm?04A4A012@T80D51@04a<C013@d<0:BTY03Ti>@0X:2P0@D51051@D017AdL0=3@d05IFEP17
AdL0@T9203De=@0l?3`0BTY:02LW9`3oool60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`3oool0QhN709RHV00209ZJVP1f09jNWP2ATI40_kno0;Fe]@2WYjL0NGUi08n?S`2R
XZ80V9RH08^;R`2NWYh0XZ:R09ZJVP2EUID0WYjN09RHV02ZZZX0Z:RX0:JVYP2c/k<0S8b<05UIF@2O
Wil0WYjN071`L01dM7@0W9bL0;6a/@2;Rh/0U9BD09RHV02PX:00W9bL0:f][@2ZZZX0XZ:R0;>c/`2M
WId0Ph>309ZJVP2BTY80WYjN09>CT`2LW9`0UiNG0861P@2GUiL0Shn?09>CT`2BTY80Y:BT09NGU`2E
UID0OGem07]kN`20P800UIFE0:>SX`2VYZH0X:2P0:FUY@2/[:`0[Jf]0:2PX02EUID0Z:RX09:BTP2L
W9`0/[:b09VIV@2b/[80Y:BT0;2`/02FUYH0^[Zj0;2`/02][Jd0YjNW0:n_[`39bLT0LG5a0:n_[`2/
[:`0[Zj^09>CT`2XZ:P0[:b/0:BTY02LW9`0Y:BT0;:b/P2RXZ80[Zj^0:2PX02MWId0O7al0:ZZZP2U
YJD0Zj^[08R8R02OWil0X:2P09^KV`2PX:00Z:RX0:2PX02RXZ80T92@0;:b/P2UYJD0RXZ:07inOP1e
MGD0LG5a06EUI@1KFe/0EEEE05=CD`80NWYj02D0Lg=c06m_K`1jNWX0L71`05]KF`1<C4`0G5aL06e]
K@1iNGT0Ogmo09^KV`2HV9P0S8b<09^KV`2@T900UIFE08:2PP1mOGd0Ph>308R8R02DU9@0QHF506QX
J01iNGT0PX:2096AT@2RXZ80RXZ:09JFUP2OWil0[:b/09fMW@26QXH0[Jf]08n?S`2RXZ80T92@0080
QHF505h0WYjN09:BTP21PH40S8b<08^;R`1mOGd0QXJ608V9R@1fMWH0W9bL09BDU02=SHd0O7al08b<
S028R8P0NGUi0:6QX@29RHT0RXZ:09BDU01dM7@0FUYJ08N7Q`2?Shl0QXJ606e]K@1OGel0NWYj06IV
IP20P800O7al07=cL`1bLW80Lg=c08B4Q01hN7P0OGem07EeM@1kNg/0VYZJ0:JVYP27QhL0Ogmo07]k
N`1dM7@0Ph>309BDU01ADE40H61P07moO`28R8P0NGUi06QXJ01SHf<0HV9R071`L01aLG40=3@d059B
DP1hN7P0Cdm?05ADE01NGUh0Fe]K05aLG01TI6@0HF5Q06ATI01ZJVX0KFe]06ATI01@D500B4Q805AD
E01RHV80IFEU07EeM@1MGEd0K6a/05QHF01UIFD0NWYj07emO@1SHf<0DE5A01`L7013@d<0IFEU06a/
K01EEED0BDU906MWI`1IFET0FUYJ0P1FEUH06P1fMWH0IVIV06MWI`1PH600GemO05IFEP1IFET0Bd];
04Q8B01HF5P0BTY:04=3@`0e=CD0?clo05aLG01<C4`0FEUI03`l?016ATH0?clo04a<C01ADE40CTi>
05=CD`1IFET0CDe=0P1@D5006P1;Bd/0:BTY04I6AP16ATH0GEeM04I6AP15ADD0ATI603dm?@11@D40
DU9B05mOG`0n?Sh0;Rh^02`/;00_;bl0?Shn03@d=00h>3P0?Shn04];B`0c<c<0:RXZ03Lg=`0n?Sh0
oooo1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI06@0oooo0:JVYP2MWId0
SXj>09JFUP2QXJ40ZJVY0:JVYP2OWil0[Zj^09fMW@1jNWX0Vi^K08:2PP1nOWh0QHF509>CT`2`/;00
U9BD09RHV02/[:`0Rh^;0:>SX`2HV9P0ZJVY0::RXP2UYJD0XJ6Q0:NWY`2KVi/0WinO08j>SP2FUYH0
SXj>09fMW@2PX:00UiNG09^KV`26QXH0UiNG0:BTY02LW9`0SXj>0861P@27QhL0[jn_09VIV@2?Shl0
OGem08b<S024Q8@0P8200:ZZZP2JVYX0Q8B409JFUP2UYJD0VYZJ0:FUY@2<S8`0T92@09bLW02?Shl0
NWYj08:2PP2:RXX0OWin0:JVYP2QXJ40K6a/09NGU`2b/[80V9RH09nOW`2QXJ40dm?C0:6QX@2<S8`0
T92@0;>c/`2o_kl0/K6a0;2`/02ATI40Q8B40;Fe]@2IVIT0WYjN0:>SX`2HV9P0W9bL0;Rh^02XZ:P0
XJ6Q0:BTY02YZJT0Q8B409VIV@2?Shl0Ti>C0P2DU9@0O02NWYh0Vi^K0:BTY02[Zj/0OWin0:VYZ@2K
Vi/0WIfM0:2PX02a/K40Y:BT09nOW`2][Jd0^[Zj09nOW`27QhL0JFUY04i>CP1?Cdl0Bd];05MGE`1i
NGT0L71`07IfMP2=SHd0MWIf07moO`1LG5`0Jf][059BDP1UIFD0LW9b06a/K01lO7`0Ti>C07alO02@
T900Shn?096AT@27QhL0[Jf]08j>SP2<S8`0R8R808^;R`1mOGd0Shn?0:f][@1hN7P0QhN709^KV`2C
Ti<0XJ6Q08f=S@2SXj<0WinO08^;R`2NWYh0Vi^K0:^[Z`2@T900UiNG08B4Q02=SHd0KVi^08B4Q02>
SXh0PX:209:BTP1eMGD0PH6108b<S026QXH0Shn?08R8R02NWYh0L71`07QhN01mOGd0V9RH0820P01d
M7@0Ng]k06UYJ@1kNg/0T92@06YZJP1gMgL0Shn?08B4Q02;Rh/0SHf=07=cL`1]KFd0Ph>30820P01f
MWH0OWin06IVIP22PX80R8R807inOP2CTi<0PX:208n?S`21PH40SHf=07=cL`2QXJ40OWin07YjNP1Y
JFT0KFe]08^;R`1SHf<0Kfm_04M7A`1eMGD0De=C06MWI`1KFe/0LG5a05]KF`1ZJVX206a/K00P05eM
G@0k>c/0EUIF05MGE`1@D500Fe]K075aL@1eMGD0MgMg071`L01MGEd0CTi>069RHP1KFe/0H61P079b
LP1LG5`0B4Q805MGE`1iNGT0IFEU04e=C@1NGUh0H61P051@D01:BTX0DE5A05IFEP1BDU80B4Q805=C
D`15ADD206ATI00M05iNGP1ADE40BTY:05EEE@1ADE40H61P04A4A01:BTX0HV9R0410@01ADE40HF5Q
02h^;P13@d<0De=C03dm?@1?Cdl0H61P03`l?01FEUH0E5AD04Y:BP1LG5`0=SHf05=CD`15ADD0C4a<
04=3@`1GEeL00P0k>c/04@1WIfL0F5QH04e=C@1;Bd/0A4A402`/;01EEED0A4A403/k>`1ADE40@T92
03hn?P0U9BD0>SXj05EEE@0/;2`0=3@d0080?3`l00<09RHV0?ooo`3IfMT01@3IfMT100000040fMWI
000F0=WIf@030000003IfMT0fMWI00<0fMWI00l0oooo08n?S`2VYZH0];Bd0:BTY02`/;00^KVi0:NW
Y`2/[:`0[Jf]09ZJVP2EUID0U9BD07]kN`2JVYX00P2SXj<0?@2EUID0V9RH08Z:RP2BTY80Rh^;0:2P
X02JVYX0X:2P096AT@2_[jl0O7al0:BTY02^[Zh0UiNG09FEU@33`l<0Vi^K0:j^[P2WYjL0[:b/0:RX
Z02UYJD0Y:BT0:f][@2BTY80YjNW09^KV`2XZ:P0YjNW09nOW`2][Jd0Q8B407=cL`2:RXX0V9RH0861
P@2<S8`0WIfM08^;R`2NWYh0SXj>0:RXZ02UYJD0SHf=0::RXP2MWId0V9RH09JFUP2?Shl0YJFU0:6Q
X@2EUID0YjNW0:ZZZP2UYJD0RHV909jNWP2@T900`<300;Bd]02RXZ800P2a/K40U`2o_kl0YZJV0:2P
X02/[:`0Vi^K0:b/[02SXj<0_kno09BDU02ZZZX0Vi^K0:>SX`2h^;P0Y:BT0:n_[`2WYjL0VYZJ0:^[
Z`24Q8@0RXZ:0:ZZZP2BTY80X:2P08R8R02CTi<0T92@08n?S`2i^KT0[:b/0;Ng]`2SXj<0YjNW0;Ng
]`2NWYh0YZJV0<71`@2XZ:P0Ph>307EeM@1dM7@0De=C04E5A@1DE5@0DU9B07alO023Ph<0SHf=08j>
SP23Ph<0TI6A07MgM`1NGUh0>CTi04U9B@1ZJVX0T92@09JFUP1oOgl0WinO09jNWP2PX:00Ng]k0:2P
X02LW9`0UiNG0:2PX02HV9P0^;Rh08n?S`2PX:00SHf=0:6QX@2ATI40Y:BT08b<S02TY:@0U9BD09:B
TP2ATI40Ng]k09fMW@1fMWH0TI6A08N7Q`22PX80Shn?07moO`2LW9`0SHf=07inOP2;Rh/0SXj>06YZ
JP20P800QHF507]kN`2<S8`0QXJ607QhN01mOGd0NGUi08R8R023Ph<0Rh^;07QhN021PH40MGEe069R
HP1cLg<0NGUi07IfMP1MGEd0IfMW06i^KP23Ph<0Kfm_092@T01eMGD0KFe]06][J`1eMGD0KVi^07Yj
NP1iNGT0RHV9079bLP25QHD0L71`07inOP1WIfL0SHf=07inOP1lO7`0IVIV06YZJP1^KVh0Jf][05]K
F`1ZJVX0Hf=S05aLG01WIfL0JFUY07IfMP1YJFT0EUIF075aL@1eMGD0M7Ad071`L01LG5`00P1TI6@0
3@1HF5P0H61P04U9B@1^KVh0F5QH04e=C@1QHF40IVIV06i^KP1dM7@0HF5Q06IVIP1YJFT00P1UIFD0
;01IFET0I6AT051@D01OGel0GEeM03Xj>P17AdL0DU9B05IFEP1XJ6P0;2`/05YJFP1TI6@0EUIF059B
DP19BDT0DU9B06e]K@1RHV80Cdm?061PH01LG5`0=CDe03Xj>P1:BTX0Bd];06YZJP0i>CT0B4Q806YZ
JP1JFUX0De=C04=3@`1LG5`0GemO04m?C`15ADD0@D5105ADE024Q8@0@41004];B`16ATH0AdM70P16
ATH05018B4P0CTi>04Y:BP1=CDd0E5AD04a<C00c<c<0?Shn01DE5@1CDe<07AdM01`L7010@400:b/[
03hn?P0`<300Cdm?03dm?@0g=cL0oooo1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI
00<0fMWI03H0oooo09BDU020P800PX:209FEU@2JVYX0Ti>C0;bl_02NWYh0T92@0:BTY02IVIT0T92@
0:VYZ@2=SHd0VIVI07AdM02WYjL0Shn?0:RXZ02HV9P0S8b<09JFUP2YZJT0^;Rh0:f][@2VYZH0WinO
09JFUP2PX:00Y:BT0;>c/`2RXZ80XJ6Q0:FUY@2KVi/0XZ:R08>3P`27QhL0UiNG0:ZZZP2SXj<0^k^k
0:FUY@2a/K40XJ6Q0:VYZ@23Ph<0WIfM08B4Q020P800T92@08B4Q02WYjL208Z:RP1X0:FUY@2NWYh0
NWYj0:2PX02@T900PX:209RHV02FUYH0/[:b09:BTP2XZ:P0ZZZZ08f=S@2^[Zh0^;Rh0;Ng]`2/[:`0
Z:RX0:j^[P2`/;00/[:b09ZJVP2UYJD0]kNg0;6a/@2ZZZX0V9RH09BDU02XZ:P0/;2`0:f][@2f][H0
Shn?0:f][@2a/K40X:2P0;Fe]@2b/[80XZ:R09fMW@2`/;00Vi^K09NGU`2SXj<0YZJV0:6QX@2/[:`0
S8b<0:BTY02<S8`0TI6A09bLW02[Zj/0[Jf]09^KV`2HV9P0VYZJ0:VYZ@2NWYh0WinO09NGU`2`/;00
RXZ:05YJFP1BDU80>CTi03`l?01>CTh0M7Ad07moO`26QXH0UIFE07=cL`24Q8@0N7Qh06m_K`1dM7@0
IfMW06=SH`21PH40Shn?0:>SX`2HV9P0Shn?09JFUP2?Shl0SHf=09VIV@21PH40Xj>S09ZJVP2>SXh0
Vi^K09jNWP2?Shl0Q8B409NGU`2?Shl0WinO09>CT`2=SHd0UYJF08B4Q01dM7@208j>SP0?09:BTP2?
Shl0T92@09>CT`2MWId0S8b<09NGU`23Ph<0SXj>08B4Q02FUYH0TI6A07YjNP24Q8@0W9bL0080QXJ6
00L0SHf=07inOP1bLW80MWIf08N7Q`2;Rh/0K6a/0080Rh^;01X0MWIf06a/K01/K6`0QHF507inOP1f
MWH0TI6A07=cL`1`L700H61P08J6QP1gMgL0Ogmo07alO01UIFD0GUiN07emO@1lO7`0OWin07UiN@20
P800U9BD08:2PP2@T900IVIV08Z:RP80MWIf00T0J6QX06m_K`1RHV80IfMW06e]K@1dM7@0Kfm_05mO
G`1YJFT00P1VIVH04@1XJ6P0KFe]05UIF@1SHf<0EUIF05mOG`1:BTX0IfMW05UIF@1JFUX0B4Q8055A
D@1`L700IVIV05aLG01SHf<0L71`0080K6a/0240Cdm?07AdM01OGel0Jf][05aLG01@D500CTi>06UY
J@16ATH0EUIF04U9B@1MGEd0EeMG05=CD`1MGEd0H61P03`l?016ATH0C4a<0451@@0c<c<0DE5A059B
DP1FEUH0@T9203Xj>P1CDe<0?Shn03Ph>01PH600Cdm?05iNGP1PH6000P1CDe<08@1>CTh0<S8b03De
=@1FEUH0BDU904e=C@0b<S80C4a<059BDP1ADE40000003@d=01CDe<0Bd];05UIF@19BDT0@D5104M7
A`1:BTX0=3@d0410@00c<c<0;Rh^04=3@`0U9BD0A4A4028R8P18B4P0?clo02`/;0000000@d=30?oo
o`060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT05`3oool0];Bd08^;R`2[
Zj/0Ti>C0;Ng]`2BTY80RXZ:096AT@1oOgl0RHV909ZJVP2i^KT0`L7109jNWP2/[:`0SXj>09bLW025
QHD0T92@07alO02SXj<0W9bL0080XZ:R00P0VYZJ09NGU`2RXZ80WIfM096AT@2PX:00/[:b0;no_`80
XZ:R0P2^[Zh0@P2TY:@0/K6a09ZJVP2FUYH0^;Rh0;Jf]P2WYjL0WYjN09^KV`2d];@0U9BD08f=S@2T
Y:@0Vi^K07alO01]KFd0UYJF09RHV02<S8`0YJFU0:JVYP2MWId0Ph>309VIV@2l_;`0[:b/0;Vi^@2P
X:00VYZJ0:RXZ02DU9@0WIfM09JFUP2;Rh/0R8R80:>SX`2UYJD0^k^k0:FUY@2JVYX0/k>c0::RXP2S
Xj<0Y:BT0:6QX@2ZZZX0Z:RX0;6a/@2HV9P0[Jf]0:6QX@2][Jd0[Zj^09jNWP2f][H0/;2`0:RXZ02e
]KD0T92@0::RXP2NWYh0[Jf]09JFUP2EUID0W9bL09ZJVP80[Jf]0:`0WYjN096AT@2FUYH0Xj>S0:b/
[02XZ:P0ZZZZ0:>SX`2/[:`0[Zj^09^KV`2QXJ40_;bl0:>SX`24Q8@0G5aL061PH01BDU80FUYJ05iN
GP1iNGT0Ph>309bLW02KVi/0IFEU079bLP1LG5`0Kfm_065QH@1gMgL0KVi^092@T023Ph<0UiNG08j>
SP2EUID0W9bL09JFUP2>SXh0Z:RX07inOP2RXZ80Rh^;0:RXZ02c/k<0OGem0:6QX@2CTi<0RXZ:075a
L@2IVIT0NWYj09RHV02DU9@0SXj>0820P02;Rh/0Shn?09ZJVP2MWId0[:b/08B4Q025QHD0NGUi092@
T02?Shl0Ogmo07alO01mOGd0R8R809ZJVP2BTY80OWin065QH@1DE5@0RXZ:08J6QP2ATI40Ogmo0861
P@1fMWH0JFUY06m_K`1`L700Hf=S08^;R`29RHT0N7Qh08R8R01kNg/0Ogmo06][J`24Q8@0Lg=c07Ui
N@1bLW80LG5a08>3P`1TI6@0O7al065QH@1gMgL0Ti>C08N7Q`1eMGD0RHV908J6QP1nOWh0RHV907Ee
M@1cLg<0IVIV07MgM`1YJFT0EUIF06UYJ@1oOgl0L71`069RHP1nOWh0HV9R061PH01FEUH0M7Ad06m_
K`1^KVh0HV9R05iNGP1QHF40@T92061PH01]KFd0IfMW055AD@1FEUH0PX:206MWI`1XJ6P0Ogmo06MW
I`1KFe/0GEeM05=CD`0l?3`0LW9b03dm?@1iNGT0@T92059BDP1ZJVX0DE5A05iNGP14A4@0KVi^04a<
C01ADE40HF5Q05MGE`1CDe<0BDU90451@@16ATH0;bl_0492@P0];Bd0?Cdm06QXJ01HF5P0E5AD04Q8
B01UIFD0>3Ph0P19BDT08`1@D500Cdm?051@D01<C4`0E5AD055AD@0L71`0Bd];05ADE01ADE40Hf=S
05aLG01BDU80C4a<06MWI`1GEeL0Bd];04i>CP1?Cdl0BDU905QHF017AdL0FUYJ04m?C`1ADE40>3Ph
02HV9P0a<C40CDe=01/K6`0^;Rh0;2`/05EEE@0k>c/0oooo00H0fMWI0@0000010=WIf@005P3IfMT0
0`000000fMWI0=WIf@030=WIf@0R0?ooo`2?Shl0W9bL09NGU`2][Jd0VYZJ0:FUY@21PH40XJ6Q0:NW
Y`2BTY80/;2`0:VYZ@1iNGT0ZJVY0861P@2h^;P0WinO08V9R@22PX80Q8B408F5Q@2EUID0VIVI09RH
V02YZJT0][Jf0:NWY`24Q8@0XZ:R08n?S`2VYZH0WinO0;>c/`80YjNW03h0[Jf]0:2PX02BTY80XJ6Q
09NGU`2b/[80Vi^K09FEU@2IVIT0T92@08V9R@2?Shl0]kNg0:NWY`2FUYH0W9bL096AT@2GUiL0/;2`
09bLW02][Jd0XZ:R0:ZZZP2IVIT0Y:BT0;Fe]@2UYJD0W9bL09nOW`2n_[h0WYjN0:^[Z`2KVi/0Z:RX
0;Zj^P2HV9P0Vi^K08b<S02KVi/0TI6A0:BTY02DU9@0UIFE09>CT`2/[:`0UiNG09jNWP2GUiL0TY:B
09VIV@2LW9`0[:b/07alO02UYJD0^KVi09ZJVP2RXZ80WYjN09FEU@2FUYH0XJ6Q0:2PX080S8b<05H0
TY:B0;2`/033`l<0UIFE0:JVYP2ATI40/;2`0::RXP2^[Zh0YJFU09nOW`2g]kL0[:b/08b<S02=SHd0
O7al0:2PX02:RXX0X:2P09NGU`1cLg<0GemO05ADE018B4P0JVYZ06m_K`1jNWX0MWIf07MgM`1jNWX0
LW9b06i^KP1_Kfl0Lg=c07inOP21PH40Xj>S092@T02=SHd0T92@0;6a/@2:RXX0T92@09RHV02=SHd0
UIFE08b<S028R8P0VIVI08f=S@2IVIT0/K6a08Z:RP2EUID0ZJVY09>CT`1iNGT0XZ:R09JFUP2OWil0
R8R809:BTP1mOGd0VYZJ07alO02>SXh0R8R808^;R`23Ph<0QhN706UYJ@2FUYH0M7Ad07MgM`2ATI40
Q8B407MgM`1bLW80KVi^079bLP29RHT0UiNG07moO`1jNWX0NGUi071`L080JFUY03L0KVi^075aL@1]
KFd0IfMW08N7Q`1YJFT0R8R808n?S`1/K6`0MGEe07emO@1;Bd/0TI6A06i^KP1YJFT0KVi^08J6QP1/
K6`0Hf=S096AT@1mOGd0P82006a/K01FEUH0O7al05YJFP1nOWh0H61P06m_K`1SHf<0JFUY06ATI01R
HV80JFUY06e]K@1^KVh0Ph>305EEE@1YJFT0E5AD05mOG`1FEUH0K6a/06UYJ@1;Bd/0DE5A05IFEP1Z
JVX0GEeM05UIF@1QHF40IfMW06a/K01ZJVX0GemO0080GEeM02D0Hf=S07AdM01aLG40NGUi05eMG@1K
Fe/0MGEe06EUI@1OGel0Jf][04A4A01QHF40EeMG05IFEP1OGel0HV9R05EEE@19BDT0DU9B05ADE01G
EeL0BDU903/k>`1CDe<0KVi^04m?C`1=CDd0?clo05aLG01MGEd0;bl_04i>CP1?Cdl0EEEE04];B`1E
EED0D51@0080A4A401h0GEeM03@d=00[:b/0DE5A03Ti>@11@D40Cdm?04];B`1JFUX0>c/k05MGE`0_
;bl0?3`l04E5A@10@400E5AD02TY:@0i>CT0@D5103/k>`10@4009RHV03De=@0l?3`0;2`/04A4A00_
;bl0=3@d03Lg=`3oool60=WIf@4000000@3IfMT00080fMWI0P0000040=WIf@800000103IfMT20000
00H0fMWI00<000000=WIf@3IfMT00`3IfMT0o`3oool0UIFE09JFUP2?Shl0UiNG0:JVYP2ZZZX0Zj^[
09^KV`2CTi<0S8b<0:ZZZP2PX:00V9RH0::RXP2TY:@0W9bL09>CT`27QhL0SHf=08j>SP1mOGd0LW9b
09bLW022PX80[:b/09ZJVP2b/[80TI6A0;Bd]02LW9`0V9RH0:BTY02SXj<0XJ6Q09:BTP2XZ:P0WinO
09fMW@2k^k/0Ti>C09fMW@2e]KD0/;2`0:VYZ@1nOWh0T92@08R8R02@T900ZZZZ0:^[Z`2RXZ80WIfM
0:2PX02IVIT0Y:BT0:>SX`2PX:00[jn_09bLW02HV9P0X:2P09:BTP32`/80XZ:R08J6QP2j^[X0^KVi
09jNWP2][Jd0Xj>S0:VYZ@2HV9P0X:2P0:VYZ@2UYJD0WinO0;2`/02<S8`0WinO08^;R`2^[Zh0VYZJ
0;Zj^P1nOWh0X:2P0;Rh^02MWId0Zj^[0:BTY02IVIT0Xj>S09^KV`2IVIT0Z:RX0:6QX@2][Jd0WYjN
08n?S`2JVYX0TY:B0:f][@2?Shl0UiNG0;^k^`2`/;00WYjN08j>SP2VYZH0`L710:f][@2a/K40Zj^[
0;Jf]P2GUiL0U9BD0:JVYP2JVYX0Zj^[0:FUY@2@T900GUiN051@D01JFUX0DU9B07YjNP1aLG40PH61
05mOG`21PH40GEeM07moO`1NGUh0JFUY08:2PP2ATI40TY:B08^;R`2=SHd0Vi^K08f=S@2PX:00WIfM
09FEU@28R8P0X:2P09nOW`2HV9P0U9BD09^KV`1lO7`0Shn?09FEU@2;Rh/0YZJV09JFUP2[Zj/0RHV9
096AT@1lO7`0QhN708>3P`2MWId0NWYj096AT@2RXZ80OGem0820P027QhL0WYjN09>CT`1mOGd0PH61
08f=S@2:RXX0QXJ60861P@28R8P0MGEe07QhN02<S8`0Q8B408R8R01_Kfl0OWin08Z:RP1nOWh0JVYZ
061PH01bLW80Kfm_09ZJVP1aLG40JVYZ07EeM@1dM7@0P82008V9R@1_Kfl0Ng]k08>3P`2=SHd0NGUi
07inOP1fMWH0DE5A07UiN@1mOGd0L71`05mOG`1hN7P0RHV907UiN@2:RXX0M7Ad055AD@1NGUh0B4Q8
05=CD`1OGel0Jf][07UiN@1]KFd0IfMW07alO01jNWX0Fe]K07QhN021PH40Jf][06i^KP1PH600F5QH
04i>CP19BDT0CDe=069RHP1ADE40EUIF05iNGP1EEED0HF5Q06][J`1>CTh0EeMG04M7A`1SHf<0HV9R
04m?C`1VIVH0H61P06i^KP1HF5P0EEEE03dm?@00>`1DE5@0GemO075aL@1MGEd0Fe]K05MGE`1ADE40
9BDU04i>CP1VIVH0:b/[04i>CP1=CDd0A4A404a<C019BDT0=cLg04Q8B01HF5P0ADE504Y:BP19BDT0
EeMG04e=C@1<C4`0@d=305UIF@0h>3P0GEeM04];B`1QHF40FUYJ05aLG01FEUH0DU9B055AD@13@d<0
C4a<04I6AP0a<C40@d=304m?C`19BDT0<c<c04M7A`0l?3`07AdM03Hf=P0b<S80EUIF03De=@0X:2P0
;Rh^03Xj>P0k>c/08R8R04U9B@0b<S80oooo00H0fMWI0@0000010=WIf@0000D0fMWI0000003IfMT0
fMWI000000020=WIf@040000003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT000001@3IfMT0
0`000000fMWI0=WIf@030=WIf@090?ooo`27QhL0R8R80820P02KVi/0UIFE09bLW02<S8`0XJ6Q0080
WIfM07L0]KFe09^KV`26QXH0WIfM08Z:RP2RXZ80VIVI092@T02:RXX0NWYj09jNWP2SXj<0Ng]k08f=
S@2<S8`0WinO09jNWP2:RXX0XZ:R0:VYZ@2NWYh0VYZJ08j>SP2[Zj/0/;2`09>CT`2EUID0ZJVY0:NW
Y`2=SHd0Ogmo0:FUY@2NWYh0U9BD09NGU`28R8P0Zj^[09NGU`2QXJ40^;Rh0;6a/@2EUID0Shn?09BD
U02d];@0W9bL0:BTY02][Jd0UYJF09bLW02UYJD0W9bL0:VYZ@2k^k/0WYjN0<30`02JVYX0YJFU0:BT
Y02SXj<0WYjN0:ZZZP2PX:00WinO0;6a/@2EUID0XJ6Q0;:b/P2SXj<0W9bL0:JVYP2QXJ40V9RH09FE
U@2GUiL0W9bL0:VYZ@2DU9@0W9bL0:VYZ@2ATI40[Zj^0:2PX02QXJ40UIFE0;6a/@2IVIT0T92@0;Jf
]P2WYjL0VYZJ0:FUY@2/[:`0];Bd0:JVYP2EUID0^[Zj0;fm_@2QXJ40Y:BT0;6a/@32`/80X:2P0;6a
/@2DU9@0XZ:R0861P@2][Jd0[jn_0::RXP2BTY80N7Qh05aLG01RHV80LG5a07EeM@1]KFd0IVIV07Yj
NP0207alO01;0861P@24Q8@0OGem07YjNP2ATI40YjNW08F5Q@2@T900[Jf]09jNWP2CTi<0Q8B409FE
U@1UIFD0QhN709:BTP1kNg/0Y:BT09RHV02ATI40TY:B09fMW@24Q8@0YjNW0:VYZ@2/[:`0Ti>C092@
T02GUiL0Vi^K09NGU`2FUYH0QHF508Z:RP2?Shl0S8b<0861P@28R8P0P82009bLW01mOGd0UYJF07Yj
NP2BTY80Kfm_07MgM`1oOgl0OGem06YZJP23Ph<0DU9B0820P01_Kfl0NWYj08Z:RP1IFET0Lg=c06m_
K`1fMWH0Lg=c07AdM027QhL0OGem09RHV01[Jf/0P82008n?S`1aLG40KVi^07alO01_Kfl0QhN707Ui
N@2EUID0OGem0080RXZ:02H0Lg=c06MWI`1jNWX0HF5Q071`L01dM7@0LW9b07=cL`1/K6`0GEeM05=C
D`1KFe/0Lg=c065QH@1jNWX0KFe]07QhN01YJFT0LG5a061PH01]KFd0HV9R05QHF01FEUH0IFEU06e]
K@1DE5@0Cdm?06e]K@1hN7P0M7Ad05mOG`1KFe/0IfMW05YJFP1WIfL0MgMg06YZJP80IfMW01P0Jf][
05mOG`1ZJVX0>c/k02DU9@1RHV80ATI605mOG`1VIVH0BTY:05eMG@1LG5`0IVIV04e=C@1MGEd0DU9B
0000001DE5@0CTi>04I6AP1<C4`0G5aL05EEE@1CDe<205ADE00W04U9B@1EEED0F5QH03hn?P1:BTX0
?Cdm03@d=00l?3`0<30`04U9B@1ADE40DU9B0451@@1fMWH0C4a<05IFEP1<C4`0EeMG04m?C`12@T80
@41004e=C@14A4@0?Shn01`L700Z:RX0;Bd]05EEE@0o?cl0;2`/01@D500Z:RX0?clo04M7A`0o?cl0
<c<c0410@01CDe<0oooo00H0fMWI0@0000010=WIf@000`3IfMT01@000000fMWI0=WIf@3IfMT00000
0080fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@030=WIf@<000000`3IfMT0
F03oool0R8R80:^[Z`2LW9`0UIFE075aL@2KVi/0XJ6Q09ZJVP2WYjL0XZ:R0:>SX`2WYjL0VIVI0:>S
X`2MWId0UYJF0:BTY02][Jd0UYJF096AT@2[Zj/0XZ:R09fMW@2?Shl0QHF50:ZZZP2LW9`0UiNG09BD
U02>SXh0Y:BT0:ZZZP2i^KT0];Bd0:b/[02a/K40WIfM09VIV@1nOWh0TI6A0:j^[P2BTY80/;2`08J6
QP2FUYH0SXj>08:2PP2SXj<0Zj^[08f=S@2][Jd0UIFE08^;R`2CTi<0/K6a09VIV@27QhL0_kno0<?3
``2`/;00WinO0;bl_02XZ:P0][Jf0;2`/024Q8@0[Zj^0;:b/P2[Zj/0WYjN0:f][@2TY:@0Zj^[0:n_
[`2ZZZX0^[Zj0:>SX`2MWId0Y:BT0;2`/02DU9@0[:b/0:^[Z`2MWId0/k>c0:NWY`2LW9`20:NWY`0L
0;>c/`2HV9P0SHf=0:>SX`2GUiL0YjNW0:2PX02OWil0[:b/092@T02HV9P0OWin0:^[Z`2YZJT0TI6A
0:b/[03?cll0]KFe0:b/[02b/[80Ti>C09fMW@2b/[80Y:BT0:JVYP2JVYX0Y:BT07QhN080UIFE05/0
/[:b09fMW@21PH40EUIF07=cL`1TI6@0IFEU07MgM`1aLG40K6a/07=cL`1oOgl0UiNG09>CT`1eMGD0
N7Qh08>3P`2?Shl0QHF506e]K@2JVYX0V9RH09fMW@2GUiL0RXZ:07emO@2=SHd0QHF509jNWP2SXj<0
R8R808n?S`21PH40RHV909^KV`2BTY80WIfM08j>SP2CTi<0PH6107YjNP2JVYX0OWin06m_K`2:RXX0
Ng]k096AT@25QHD0Ogmo07alO02EUID0P82009BDU01hN7P0VIVI08f=S@1jNWX0OWin06YZJP20P800
RHV909JFUP2<S8`0PH6108j>SP22PX80EEEE069RHP1bLW80Kfm_05mOG`1mOGd0PH6107inOP1eMGD0
M7Ad07emO@1/K6`0MGEe06i^KP2FUYH0MgMg08J6QP1_Kfl0OGem06m_K`2ATI40OWin07MgM`1mOGd0
Ti>C0080J6QX00X0Shn?07YjNP1/K6`0Q8B405YJFP1EEED0FUYJ06MWI`1RHV80MWIf0P1iNGT0F@1R
HV80Hf=S06a/K01ZJVX0KFe]07IfMP1TI6@0GEeM061PH01`L700JVYZ05EEE@1RHV80Fe]K03lo?`1W
IfL0J6QX05MGE`1EEED0GemO04e=C@1CDe<0?3`l07AdM01]KFd0JVYZ06a/K01_Kfl0GUiN06ATI01H
F5P0De=C06e]K@16ATH0Jf][06MWI`1@D500CTi>05mOG`1?Cdl0000005aLG01RHV80GemO01XJ6P0/
;2`0<S8b04Y:BP1LG5`0FUYJ04Y:BP0m?Cd0BTY:061PH01@D500Hf=S05YJFP1FEUH0?3`l04=3@`18
B4P0@T92065QH@1CDe<0FUYJ04Y:BP1=CDd0>3Ph05=CD`19BDT0>SXj03dm?@12@T809RHV01DE5@10
@40092@T0451@@0V9RH0B4Q80492@P0d=3@0<S8b01dM7@0i>CT0:b/[01`L701@D500oooo00@0fMWI
0`0000010=WIf@00103IfMT010000000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI00000080
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@130?ooo`26QXH0WYjN0:FU
Y@2[Zj/0Shn?0:FUY@2PX:00W9bL0:j^[P2ZZZX0^KVi092@T02QXJ40^[Zj09NGU`2/[:`0X:2P0:RX
Z02?Shl0[Zj^09VIV@2d];@0Y:BT092@T02<S8`0VYZJ0;Bd]02PX:00TY:B0::RXP2YZJT0TY:B09VI
V@2_[jl0WIfM0::RXP2PX:00W9bL09VIV@2RXZ80Y:BT0:j^[P2:RXX0VIVI0:>SX`2IVIT0WIfM0:n_
[`2d];@0WinO092@T02CTi<0VYZJ0:RXZ02LW9`0X:2P0:b/[02PX:00T92@0;2`/02WYjL0[Zj^09^K
V`2LW9`0_;bl0:ZZZP020::RXP0J0:RXZ02d];@0^k^k08j>SP2QXJ40TY:B09jNWP2JVYX0[Jf]0:BT
Y02DU9@0YjNW0;>c/`2LW9`0Zj^[0:b/[02c/k<0ZZZZ0:2PX02QXJ40WIfM0:2PX02JVYX0Z:RX0:j^
[P2/[:`20:>SX`0H0:^[Z`2MWId0WinO092@T02GUiL0XJ6Q0;:b/P2WYjL0Xj>S0:n_[`2e]KD0YZJV
0:2PX02^[Zh0[jn_0;bl_02c/k<0YZJV0:VYZ@2/[:`0PH6108f=S@2OWil0/[:b0P2CTi<06P2@T900
Jf][06QXJ020P800LW9b07AdM02=SHd0OGem0820P01WIfL0NWYj09nOW`20P800SHf=0820P02>SXh0
RHV908J6QP2MWId0U9BD07YjNP27QhL0WinO08b<S02LW9`0V9RH0P2@T9004`2QXJ40Ti>C0861P@2V
YZH0UiNG09VIV@2?Shl0Ogmo07inOP2EUID0S8b<08>3P`2:RXX0O7al07]kN`2:RXX0M7Ad07moO`2L
W9`00P22PX80R`2f][H0QhN7079bLP2@T900LG5a06e]K@1/K6`0N7Qh07=cL`1kNg/0UYJF079bLP2@
T900S8b<061PH01EEED0JVYZ079bLP1[Jf/0Q8B408N7Q`1]KFd0QhN707moO`1gMgL0OGem092@T028
R8P0N7Qh07IfMP1aLG40OWin07IfMP1]KFd0QHF506i^KP1KFe/0K6a/08Z:RP2>SXh0JFUY07=cL`1N
GUh0NGUi06QXJ01GEeL0N7Qh06UYJ@1SHf<0MWIf06YZJP1OGel0Bd];05]KF`1JFUX0CTi>06EUI@1P
H600?Shn04I6AP1JFUX0ATI604=3@`1FEUH0DE5A05YJFP1KFe/0Hf=S04];B`1WIfL0BDU904i>CP1N
GUh0HF5Q06a/K01YJFT0IFEU061PH01WIfL0J6QX03De=@1KFe/0JVYZ05MGE`0m?Cd0DU9B04I6AP1Y
JFT0M7Ad04Y:BP1MGEd0AdM706ATI01QHF40DU9B05QHF01ADE40GEeM04i>CP1FEUH0I6AT05iNGP1?
Cdl0D51@059BDP1TI6@0EEEE0451@@0o?cl0FEUI03Xj>P1=CDd0>SXj04Q8B00`<300@D5104U9B@1I
FET0F5QH05EEE@1IFET0F5QH0492@P0l?3`0@41004Q8B012@T80D51@028R8P16ATH0?Shn03Ti>@18
B4P0:b/[02TY:@0W9bL0<30`01/K6`0[:b/00P13@d<00`3oool0fMWI0=WIf@040=WIf@4000000@3I
fMT000050=WIf@000000fMWI0=WIf@0000000P3IfMT010000000fMWI0=WIf@0000020=WIf@040000
003IfMT0fMWI000000D0fMWI00<000000=WIf@3IfMT00`3IfMT05P3oool0QHF508J6QP2FUYH0Z:RX
09fMW@2EUID0SHf=0:j^[P2VYZH0X:2P0::RXP28R8P0^KVi09bLW02@T900WIfM08R8R02d];@0Zj^[
0:JVYP2NWYh20:NWY`1209BDU02EUID0ZJVY09fMW@2QXJ40Vi^K09fMW@2QXJ40Ti>C0:VYZ@24Q8@0
SXj>09jNWP2[Zj/0SXj>09ZJVP2?Shl0Z:RX0:ZZZP2^[Zh0UYJF09fMW@2BTY80Shn?0:6QX@2LW9`0
Ti>C0:BTY02HV9P0Xj>S0:2PX02UYJD0_[jn0:VYZ@2h^;P0ZJVY0:f][@2RXZ80YZJV08^;R`2e]KD0
Y:BT09jNWP2XZ:P0XZ:R09fMW@2n_[h0^KVi09:BTP2b/[80WinO09NGU`28R8P0UYJF0:BTY02CTi<0
Vi^K09fMW@2WYjL0WIfM09BDU02_[jl0[:b/09NGU`2a/K40WinO0`2PX:00R`29RHT0RXZ:09FEU@2Q
XJ40[jn_0;Fe]@2TY:@0UIFE0:b/[02FUYH0Z:RX09:BTP2i^KT0Zj^[0:6QX@2[Zj/0[jn_0;Rh^02[
Zj/0YZJV0:n_[`2UYJD0Ogmo0:BTY02ZZZX0XJ6Q09fMW@2;Rh/0T92@0:2PX02HV9P0S8b<07emO@1n
OWh0JFUY06YZJP1lO7`0RXZ:08F5Q@2;Rh/0QXJ60:^[Z`2MWId0OWin096AT@2DU9@0Ph>309BDU02A
TI40PH61092@T02c/k<0RXZ:09JFUP28R8P0RXZ:09FEU@2ATI40UIFE0:2PX01`L700X:2P08V9R@1g
MgL0QHF508:2PP1mOGd0QHF507MgM`1iNGT0OWin07=cL`2EUID0O7al08^;R`1lO7`0Ng]k08f=S@2:
RXX0WinO07moO`1nOWh0P82009RHV01`L700MgMg09>CT`1bLW80SXj>07YjNP1gMgL0RHV907QhN025
QHD0QhN708F5Q@1/K6`0Lg=c079bLP1dM7@0KVi^06IVIP1bLW80RXZ:079bLP1/K6`0IFEU07moO`26
QXH0L71`06m_K`29RHT0Rh^;06a/K01PH600Kfm_07AdM01RHV80L71`08R8R01kNg/0PH61096AT@1`
L700Cdm?07moO`1hN7P0HF5Q05aLG01XJ6P0PH6104a<C01`L700@d=305UIF@1XJ6P0DU9B06ATI01V
IVH00P1/K6`01`1TI6@0H61P05iNGP1hN7P0Fe]K05=CD`1QHF400P1SHf<0<P1cLg<0H61P06EUI@1/
K6`0GemO04Q8B01SHf<0F5QH04i>CP1MGEd0G5aL04i>CP1YJFT0LW9b05MGE`1CDe<0HV9R05eMG@1C
De<0=cLg05=CD`1]KFd0HV9R065QH@1MGEd0G5aL04];B`11@D40F5QH069RHP1?Cdl0B4Q806ATI01;
Bd/0F5QH051@D017AdL0BTY:05YJFP1GEeL0ADE503@d=018B4P0:RXZ04m?C`17AdL0D51@0451@@1H
F5P0=SHf0P17AdL04`1MGEd0=cLg05MGE`1GEeL0@T9204E5A@1ADE40BTY:034a<@0_;bl0;2`/04=3
@`0d=3@0>c/k02l_;`0j>SX0C4a<02l_;`3oool01P3IfMT100000040fMWI00020=WIf@800000103I
fMT2000000@0fMWI0P0000060=WIf@030000003IfMT0fMWI00<0fMWI01X0oooo09JFUP2RXZ80WIfM
09:BTP2OWil0QHF509^KV`2:RXX0]KFe0:6QX@2ATI40VYZJ09jNWP2TY:@0T92@08j>SP1oOgl0Xj>S
0;Ng]`38b<P0YjNW0:ZZZP2JVYX0SXj>09NGU`80[:b/00l0UYJF09bLW02PX:00U9BD08F5Q@2HV9P0
YjNW0;>c/`2:RXX0YJFU0:BTY02SXj<0T92@09:BTP2;Rh/00P2RXZ807@2;Rh/0YjNW0:BTY02^[Zh0
YZJV0;6a/@2/[:`0]KFe09ZJVP2UYJD0][Jf0:n_[`2ATI40[Zj^09nOW`2UYJD0XZ:R0:JVYP2WYjL0
WYjN0:6QX@2b/[80X:2P0:>SX`2i^KT0Z:RX0:JVYP2ZZZX0WIfM0080VIVI01l0T92@08Z:RP2/[:`0
XJ6Q0<C4a02e]KD0TY:B09ZJVP2SXj<0YZJV09NGU`2UYJD0XJ6Q0:NWY`2MWId0/;2`0:NWY`2g]kL0
YZJV09VIV@39bLT0/[:b09JFUP2TY:@0YjNW0:f][@2JVYX0V9RH0:>SX`2b/[80X:2P0080YZJV01l0
bl_;0;Jf]P2c/k<0];Bd0:JVYP2/[:`0YjNW09^KV`2SXj<0W9bL0:f][@27QhL0WYjN08j>SP2ATI40
Ogmo07]kN`2<S8`0PH61071`L02@T900Q8B407alO02BTY80T92@09fMW@2?Shl0VYZJ07EeM@2DU9@0
/k>c0080OGem05L0TY:B09JFUP2IVIT0Vi^K0:6QX@22PX80TY:B08N7Q`2JVYX0VIVI096AT@2EUID0
VIVI08f=S@1gMgL0NGUi0;6a/@2CTi<0WinO09jNWP2?Shl0Ph>308J6QP1_Kfl0OWin07MgM`1hN7P0
Rh^;08Z:RP1aLG40WIfM08J6QP1iNGT0QHF507UiN@21PH40Ogmo08>3P`1YJFT0K6a/08N7Q`1hN7P0
MWIf08:2PP1_Kfl0Jf][075aL@1eMGD0QHF50820P01_Kfl0Ph>306i^KP1[Jf/0Lg=c07MgM`1aLG40
Lg=c06QXJ01_Kfl0LG5a07YjNP2;Rh/0Lg=c07emO@1NGUh0Ng]k08Z:RP2>SXh0Lg=c06EUI@1hN7P0
J6QX06e]K@1XJ6P0LW9b06UYJ@1dM7@0IFEU06MWI`1SHf<0FUYJ07=cL`1bLW80MgMg05]KF`1EEED0
0P1TI6@0:`0n?Sh0GUiN06=SH`1dM7@0EUIF06MWI`1QHF40ADE505EEE@1XJ6P0EEEE06e]K@1UIFD0
Fe]K05eMG@1XJ6P0ADE505QHF01`L700Ng]k06UYJ@1aLG40FUYJ07=cL`1IFET0IfMW07EeM@1EEED0
Fe]K06i^KP1:BTX0IfMW04a<C01eMGD0NGUi06IVIP1HF5P0Cdm?04I6AP1?Cdl0BTY:059BDP1QHF40
0P1ADE407@1aLG40BDU904U9B@1>CTh0De=C05ADE01GEeL0Bd];059BDP1GEeL00@4104];B`12@T80
EUIF03/k>`1QHF40?clo03`l?01SHf<0?Shn0492@P0j>SX0<c<c03Ph>00n?Sh0;bl_04A4A00i>CT0
B4Q80080;bl_00L0<c<c04U9B@0Y:BT0DE5A03Hf=P0c<c<0oooo00H0fMWI0@0000010=WIf@005P3I
fMT00`000000fMWI0=WIf@030=WIf@0d0?ooo`2EUID0Rh^;09ZJVP2EUID0TI6A08>3P`2GUiL0YJFU
0;6a/@1iNGT0WIfM09^KV`2^[Zh0X:2P09bLW02;Rh/0RXZ:092@T02HV9P0Zj^[0;Rh^02n_[h0SXj>
09VIV@2MWId0/k>c0;2`/026QXH0X:2P0:b/[026QXH0TI6A0:^[Z`2SXj<0ZJVY09nOW`2_[jl0SXj>
0;^k^`2HV9P0YJFU09bLW028R8P0VIVI09nOW`2MWId0U9BD0;6a/@2MWId0_;bl09:BTP80^;Rh00H0
WinO0<71`@2_[jl0YZJV09nOW`2UYJD20:VYZ@1D0;Rh^02a/K40];Bd08f=S@2ZZZX0];Bd0:2PX02>
SXh0YjNW0:f][@2VYZH0WYjN09JFUP2IVIT0Rh^;09VIV@2HV9P0WIfM0:f][@2BTY80[Zj^09^KV`2^
[Zh0WYjN09ZJVP2ATI40`L7109bLW02NWYh0];Bd0:FUY@2SXj<0XJ6Q0:ZZZP2QXJ40SXj>0:NWY`2^
[Zh0[Jf]0:NWY`2BTY80XJ6Q0;Ng]`2LW9`0ZZZZ0;no_`2UYJD0^KVi0;2`/02a/K40Xj>S0;:b/P2Q
XJ40V9RH09^KV`2MWId0SXj>0:>SX`2LW9`0WYjN09VIV@2DU9@0V9RH09bLW02GUiL0Vi^K08b<S02D
U9@0PH6109VIV@2NWYh0Shn?09>CT`2FUYH0UiNG07QhN01fMWH0QHF507alO02@T900Vi^K09>CT`22
PX80RHV90P2JVYX03P2MWId0VYZJ08:2PP2;Rh/0T92@09NGU`2TY:@0PX:205YJFP2QXJ40TY:B08n?
S`2BTY80Q8B40P1fMWH04`29RHT0QHF50861P@1nOWh0LG5a08B4Q020P800QHF508B4Q02>SXh0WIfM
09^KV`26QXH0NWYj09>CT`2;Rh/0NWYj07=cL`1ZJVX00P1TI6@0201JFUX0QHF507emO@20P800O7al
07]kN`1aLG40K6a/0`1mOGd0:`1jNWX0X:2P07IfMP1cLg<0MWIf07]kN`1]KFd0O7al05iNGP28R8P0
Ng]k0861P@1/K6`0P82006IVIP1gMgL0Ng]k06a/K027QhL0MWIf06=SH`1gMgL0HF5Q07YjNP1cLg<0
IFEU06i^KP1[Jf/0GEeM06EUI@1JFUX0I6AT065QH@1NGUh0LG5a06i^KP0n?Sh0C4a<051@D01eMGD0
C4a<06i^KP1TI6@00P1HF5P0B@1OGel0FUYJ055AD@1XJ6P0JFUY06=SH`1JFUX0IfMW06e]K@1@D500
EEEE06m_K`1:BTX0Fe]K06e]K@0o?cl0GEeM06m_K`1FEUH0HV9R051@D01ZJVX0C4a<065QH@1@D500
Cdm?04I6AP1LG5`0JVYZ06a/K01JFUX0ATI60410@00o?cl0>c/k03Ti>@0b<S80CTi>04a<C00l?3`0
DU9B04e=C@1IFET0CTi>03Ti>@19BDT0?Cdm05]KF`19BDT0?Cdm04];B`1:BTX0DU9B03`l?018B4P0
?Shn03Ph>016ATH0?clo03Lg=`1<C4`09BDU059BDP0i>CT0?Shn02PX:01:BTX0=cLg03@d=00X:2P0
=cLg05mOG`3oool01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00H0oooo
08:2PP2>SXh0XJ6Q0:RXZ02ATI4208b<S01;08B4Q02][Jd0ZJVY0;Rh^02NWYh0UYJF0;2`/02IVIT0
TY:B08V9R@22PX80X:2P0;Fe]@2NWYh0SXj>09JFUP2IVIT0RHV909RHV02a/K40UiNG0:b/[02KVi/0
V9RH09bLW02YZJT0[:b/0:RXZ02HV9P0Zj^[0:JVYP2`/;00VYZJ09nOW`2ATI40P82008R8R02QXJ40
YjNW0;^k^`2[Zj/0Ti>C0;:b/P2/[:`0WYjN0:j^[P2VYZH0ZZZZ0<K6aP2XZ:P0PH6108R8R02PX:00
];Bd0;:b/P2RXZ80Z:RX0;:b/P2RXZ80/;2`0:ZZZP2WYjL0UYJF0:JVYP2MWId0/K6a0;2`/02/[:`0
R8R809ZJVP2a/K40`/;209ZJVP2[Zj/0TI6A0080Xj>S0680ZZZZ0:FUY@2KVi/0UiNG0:BTY02PX:00
VIVI08n?S`2QXJ40^;Rh09fMW@2a/K40Ogmo0:VYZ@2CTi<0XJ6Q09bLW02l_;`0WinO09RHV02NWYh0
Y:BT0;bl_033`l<0/;2`0:2PX02c/k<0Zj^[0;Zj^P2o_kl0WYjN09bLW02a/K40WinO0:ZZZP2:RXX0
Y:BT08N7Q`2RXZ80TY:B09FEU@2LW9`0VYZJ09RHV02LW9`0Y:BT09:BTP1mOGd0WinO08V9R@2BTY80
Xj>S09JFUP2DU9@0SXj>09fMW@2HV9P0OGem08V9R@1hN7P0Ph>3096AT@2CTi<0PX:209JFUP2JVYX0
O7al0820P01[Jf/0SHf=08:2PP2:RXX0RHV90:JVYP1oOgl0PH6107moO`2BTY80SHf=08F5Q@20P800
RHV909^KV`1mOGd0T92@075aL@1QHF40RXZ:09ZJVP2=SHd0QhN707inOP1WIfL0Ogmo07inOP1jNWX0
Q8B4079bLP80LG5a05@0L71`08n?S`2?Shl0O7al0820P01iNGT0MGEe0820P01eMGD0NGUi08F5Q@1j
NWX0LW9b06m_K`27QhL0Ogmo08B4Q01YJFT0Q8B40861P@1OGel0I6AT06e]K@1VIVH0Jf][06e]K@1e
MGD0QXJ606YZJP1aLG40L71`06QXJ01_Kfl0GemO05EEE@1`L700JFUY07=cL`1SHf<0HF5Q05iNGP1C
De<0FEUI04];B`1@D500EEEE06MWI`1RHV80D51@05]KF`1PH600I6AT05mOG`1TI6@0IFEU05aLG01K
Fe/0De=C05]KF`1^KVh0H61P04Y:BP17AdL0Kfm_06EUI@1OGel0DU9B061PH01NGUh0GEeM06ATI01L
G5`0I6AT05=CD`19BDT0IFEU05eMG@1KFe/0B4Q804A4A011@D40?3`l05QHF01KFe/204E5A@0=04];
B`16ATH0?clo03Ti>@1]KFd0@d=304A4A016ATH0;Rh^05IFEP17AdL0G5aL04M7A`0204i>CP0L04Q8
B00X:2P0H61P03Hf=P0b<S80;Bd]0492@P1EEED0>c/k0410@00^;Rh0@T92065QH@1=CDd0>SXj04a<
C00b<S80@41004I6AP0H61P05ADE04=3@`0[:b/0>CTi01TI6@0/;2`0@d=30?ooo`H0fMWI0@000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0:0?ooo`2:RXX0SHf=0:2PX02EUID0R8R809JF
UP2BTY80V9RH07inOP80VYZJ0400WinO09bLW02PX:00Rh^;0:ZZZP2FUYH0QXJ607YjNP2QXJ40NGUi
09JFUP1lO7`0Shn?092@T02RXZ80/;2`0;^k^`2QXJ40[Zj^08R8R02EUID0ZZZZ09jNWP2HV9P0ZZZZ
0:f][@2g]kL0U9BD0;Fe]@2>SXh0/[:b0:VYZ@2MWId0W9bL0:6QX@2JVYX0Shn?08R8R036a/H0WIfM
0:^[Z`2/[:`0][Jf0:6QX@2YZJT0[:b/09NGU`2NWYh0XJ6Q0;>c/`2OWil0UiNG0;Ng]`2YZJT0Vi^K
0:JVYP2[Zj/0Vi^K09FEU@2@T900^k^k096AT@2QXJ40VYZJ0P2LW9`0j@2a/K40X:2P09nOW`2NWYh0
PH6109fMW@2XZ:P0RHV90:2PX02NWYh0YZJV0;Bd]02JVYX0Vi^K09VIV@2MWId0Vi^K0:VYZ@2HV9P0
T92@08R8R02d];@0]KFe0:NWY`2=SHd0ZJVY09FEU@2_[jl0XZ:R0:n_[`2a/K40YjNW0;>c/`2SXj<0
Z:RX0:>SX`2MWId0Y:BT09bLW02[Zj/0YZJV09NGU`2/[:`0Xj>S0:BTY023Ph<0Q8B409RHV02ZZZX0
WYjN09RHV02IVIT0UiNG07QhN023Ph<0RXZ:0:2PX029RHT0TI6A08j>SP2ATI40QhN708F5Q@26QXH0
Shn?08J6QP2BTY80T92@08V9R@2IVIT0OGem07UiN@2>SXh0IfMW07]kN`23Ph<0Rh^;09RHV01nOWh0
PX:206m_K`1iNGT0Shn?092@T02WYjL0Rh^;08V9R@2@T900QHF508B4Q02@T900MGEe092@T01oOgl0
J6QX07emO@1oOgl0NWYj06i^KP1mOGd0NWYj07MgM`29RHT0Hf=S0820P01_Kfl0NGUi061PH01fMWH0
PH6107moO`23Ph<0TI6A069RHP1hN7P0Rh^;079bLP1oOgl0SHf=079bLP1kNg/0NGUi07emO@1fMWH0
Ogmo08B4Q029RHT0IFEU08:2PP1aLG40MGEe07alO01dM7@0IVIV06YZJP1XJ6P0O7al06ATI01UIFD0
N7Qh05QHF01DE5@0NGUi06=SH`1kNg/0H61P06EUI@1FEUH0Lg=c06UYJ@1VIVH0HF5Q051@D01/K6`0
>c/k02l_;`11@D40IVIV04U9B@1WIfL0EeMG059BDP12@T80Jf][08j>SP1bLW80FEUI06m_K`1RHV80
IFEU05IFEP1PH600M7Ad04m?C`18B4P0EeMG06MWI`1ADE40CTi>05]KF`1<C4`0JVYZ055AD@1SHf<0
@T92059BDP1=CDd0C4a<04e=C@1FEUH0C4a<06=SH`1WIfL0CTi>03Ti>@0d=3@0HV9R06QXJ01TI6@0
FEUI03hn?P1;Bd/0C4a<06=SH`1CDe<0EEEE04E5A@1?Cdl0FUYJ02HV9P15ADD0@T92034a<@13@d<0
=cLg04];B`0Y:BT0E5AD05mOG`0c<c<0BTY:034a<@1<C4`0<C4a02d];@0e=CD06a/K04I6AP13@d<0
;Bd]02TY:@0c<c<0<S8b00806QXJ00<0oooo0=WIf@3IfMT0103IfMT100000040fMWI000F0=WIf@03
0000003IfMT0fMWI00<0fMWI04h0oooo08Z:RP2UYJD0Shn?0:>SX`2ATI40UIFE08j>SP2KVi/0_;bl
0:ZZZP2SXj<0Vi^K0:b/[02][Jd0ZZZZ0::RXP2HV9P0Shn?07emO@2>SXh0X:2P08V9R@2?Shl0UiNG
0:b/[02HV9P0YJFU09jNWP2PX:00T92@09nOW`2RXZ80X:2P0:6QX@2UYJD0Zj^[0:2PX02NWYh0QXJ6
09:BTP2[Zj/0UYJF0:2PX02JVYX0ZJVY0;no_`2c/k<0XJ6Q0;Rh^02NWYh0[:b/0:>SX`2c/k<0]kNg
0:>SX`2KVi/0[jn_0;Jf]P2b/[80RHV90:n_[`2WYjL0[Zj^0:BTY02ATI40XJ6Q09bLW02JVYX0WYjN
0;2`/02PX:00Y:BT0:ZZZP2VYZH0WIfM09NGU`2IVIT20:JVYP0c0:NWY`2[Zj/0XJ6Q09nOW`2@T900
WIfM0:ZZZP2LW9`0Q8B40820P02FUYH0Xj>S08j>SP2[Zj/0T92@0;^k^`2a/K40QHF5092@T02MWId0
XJ6Q09jNWP2_[jl0YJFU08j>SP2[Zj/0[:b/0:>SX`2YZJT0Ti>C0:j^[P2o_kl0Y:BT09BDU02EUID0
V9RH0:RXZ02HV9P0XJ6Q0;^k^`2ZZZX0YZJV0::RXP25QHD0CDe=0:^[Z`2HV9P0Rh^;08n?S`2HV9P0
VIVI0080TI6A00/0PX:209nOW`2>SXh0W9bL0:2PX02FUYH0RXZ:08R8R02IVIT0Q8B408n?S`0208>3
P`0V09:BTP2ATI40Shn?08R8R025QHD0NWYj08n?S`2;Rh/0Ogmo09FEU@1fMWH0X:2P08J6QP20P800
PH6109^KV`2MWId0Q8B409BDU02CTi<0VIVI08F5Q@23Ph<0QXJ608N7Q`2>SXh0MGEe08R8R01]KFd0
NWYj08J6QP1mOGd0Xj>S08^;R`1kNg/0NGUi07=cL`23Ph<207alO00_08j>SP24Q8@0PX:207emO@1f
MWH0N7Qh09>CT`1eMGD0Ph>306MWI`1QHF40TI6A079bLP1dM7@0NWYj07moO`2?Shl0OWin06m_K`23
Ph<0LG5a069RHP1^KVh0I6AT07IfMP1lO7`0PH61075aL@1ADE40LG5a08n?S`1eMGD0PH6105IFEP1V
IVH0M7Ad07moO`1PH600Lg=c07EeM@1aLG40N7Qh06a/K01hN7P0Hf=S05YJFP1?Cdl00P1LG5`0;P1T
I6@0?Cdm05EEE@1YJFT0Fe]K06a/K01OGel0De=C05eMG@1BDU80NGUi06UYJ@1TI6@0C4a<05YJFP1P
H600BTY:04e=C@1GEeL0E5AD04U9B@1@D500CTi>04e=C@1FEUH0@d=305mOG`1DE5@0@T9204a<C01K
Fe/0ATI603dm?@1DE5@0EeMG04A4A00X:2P0ATI604E5A@1BDU80=cLg02d];@1OGel0A4A404a<C00h
>3P204E5A@0D04M7A`1<C4`0?Shn03Hf=P16ATH0>CTi034a<@15ADD0ATI605QHF00m?Cd0<S8b03Xj
>P10@4009BDU04M7A`0a<C40BDU9030`<00E5AD202TY:@09034a<@0c<c<0>3Ph04E5A@0Y:BT09RHV
03/k>`0R8R80oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@070?oo
o`2UYJD0Rh^;092@T02EUID0RXZ:08f=S@0209nOW`0I0:ZZZP2l_;`0W9bL09nOW`2KVi/0VYZJ0:ZZ
ZP2JVYX0VIVI07AdM02BTY80S8b<092@T02OWil0XZ:R0:JVYP2_[jl0WIfM08V9R@2b/[80S8b<0:b/
[02RXZ80R8R809VIV@0209bLW00?08R8R02c/k<0Y:BT09NGU`2CTi<0X:2P09:BTP2XZ:P0Xj>S092@
T02IVIT0WinO0:ZZZP2LW9`0ZJVY0080Vi^K01P0VIVI0:^[Z`2OWil0/K6a09BDU02NWYh0W9bL09VI
V@2YZJT0V9RH0:BTY02][Jd0XZ:R09>CT`2EUID0[jn_0:6QX@2VYZH0UYJF0:ZZZP29RHT0VYZJ09fM
W@27QhL20;Rh^00[0;6a/@2h^;P0[Zj^0::RXP2JVYX0Rh^;09JFUP28R8P0WinO0;Vi^@2^[Zh0W9bL
0:FUY@22PX80Ti>C0:b/[02ZZZX0VYZJ08n?S`2OWil0W9bL0:n_[`2DU9@0];Bd0:2PX02=SHd0TI6A
09fMW@2WYjL0X:2P09BDU02SXj<0ZZZZ0:b/[02ATI40RXZ:08j>SP2ZZZX0OGem0;>c/`2<S8`0TY:B
0:b/[00309JFUP0Q09NGU`2NWYh0W9bL0:RXZ02KVi/0VYZJ0:2PX02?Shl0;Rh^08n?S`2ATI40RXZ:
0;:b/P2FUYH0WYjN09:BTP26QXH0WIfM07MgM`26QXH0WYjN07emO@2XZ:P0UYJF08F5Q@26QXH0M7Ad
06m_K`2ATI40SXj>08b<S02;Rh/0S8b<0080SHf=03L0P82008Z:RP2JVYX0RHV907=cL`1ZJVX0OGem
08N7Q`2OWil0O7al092@T026QXH0GEeM06QXJ02;Rh/0QHF508:2PP2;Rh/0Ogmo0820P01fMWH0EeMG
08R8R01_Kfl0PH6108B4Q01[Jf/0QHF50820P01iNGT0NWYj06e]K@1lO7`0Kfm_09BDU02CTi<0JFUY
08V9R@2CTi<0MgMg08:2PP20P800LW9b06a/K023Ph<0MgMg07IfMP22PX80MGEe07AdM025QHD0KVi^
08B4Q01`L700LW9b0080KVi^03d0K6a/07inOP1eMGD0J6QX05mOG`1eMGD0JVYZ069RHP14A4@0Jf][
05EEE@1hN7P0GemO05]KF`1ZJVX0IVIV06YZJP1XJ6P0C4a<05]KF`1FEUH0De=C06a/K01cLg<0K6a/
065QH@1`L700LW9b04i>CP1BDU80GUiN061PH01UIFD0IfMW05aLG01=CDd0>3Ph04I6AP1DE5@0@D51
04i>CP19BDT0ATI606IVIP1KFe/0=3@d05QHF01:BTX0G5aL04Q8B01>CTh0EeMG04I6AP1KFe/0BTY:
05]KF`1@D500F5QH04E5A@14A4@0?Cdm0080H61P0280L71`04];B`0k>c/0?3`l04Y:BP0a<C40E5AD
05=CD`1<C4`0>SXj024Q8@11@D40>c/k04Q8B00e=CD0:BTY03`l?016ATH0<c<c04I6AP1@D500=cLg
02TY:@15ADD0:b/[03Xj>P0c<c<0=3@d04E5A@0h>3P07alO02HV9P0`<300oooo1P3IfMT100000040
fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI01<0oooo08f=S@2QXJ40UYJF0:BTY02KVi/0T92@
08n?S`2DU9@0^KVi09ZJVP2WYjL0RXZ:0;Jf]P2^[Zh0`<300;:b/P2<S8`0SHf=0080WYjN03T0V9RH
09^KV`2SXj<0XJ6Q09bLW02FUYH0Y:BT09fMW@2QXJ40VIVI09^KV`2EUID0YjNW09bLW02XZ:P0WIfM
09nOW`2QXJ40Y:BT0:RXZ02FUYH0QhN709VIV@2JVYX0]KFe0:2PX02BTY80/K6a09RHV02f][H0b/[:
0;Fe]@2d];@0/;2`0:b/[03;bl/0/;2`09fMW@2RXZ80Vi^K09nOW`2WYjL0/k>c0;Jf]P2c/k<0[Jf]
0:JVYP1hN7P0T92@09>CT`2OWil0U9BD09bLW02f][H0_;bl0;fm_@2k^k/00P2FUYH06@2/[:`0WinO
0;Jf]P28R8P0/[:b0:>SX`2IVIT0S8b<09FEU@1mOGd0U9BD08^;R`2BTY80Ti>C09^KV`2f][H0UYJF
0:2PX01aLG40WinO0;Jf]P2OWil0U9BD08B4Q02IVIT00P2?Shl0c`2PX:00Shn?0:JVYP2OWil0SXj>
09JFUP2DU9@0YJFU0<K6aP2TY:@0VYZJ08>3P`1iNGT0R8R80;>c/`2a/K40Shn?0:2PX024Q8@0WinO
0;:b/P1iNGT0WinO08B4Q02?Shl0KVi^08N7Q`2@T900P82009BDU02;Rh/0PH6108V9R@2BTY80UYJF
07emO@1[Jf/0NWYj08R8R01hN7P0T92@079bLP21PH40YJFU07moO`21PH40HF5Q096AT@1nOWh0SHf=
09^KV`2GUiL0QHF508^;R`24Q8@0QXJ609:BTP1kNg/0UIFE0820P01oOgl0VYZJ07=cL`1dM7@0LW9b
08F5Q@2GUiL0RHV906YZJP1RHV80Q8B407YjNP1VIVH0O7al0820P02>SXh0Q8B407AdM01oOgl0OWin
07]kN`1bLW80QHF508>3P`25QHD0PH6107QhN02<S8`0OGem07]kN`1WIfL0S8b<07emO@1lO7`0RHV9
08n?S`1eMGD0T92@075aL@1mOGd0Lg=c08Z:RP2DU9@0Q8B40861P@1jNWX0VYZJ07IfMP1`L700T92@
08b<S026QXH0IFEU05eMG@1nOWh0MGEe075aL@1FEUH0KVi^051@D01/K6`0GEeM05aLG01?Cdl0Fe]K
04=3@`1IFET0IfMW06a/K01HF5P0IVIV05MGE`1IFET0FUYJ061PH01bLW80K6a/05IFEP1RHV80@T92
04m?C`1fMWH0Bd];03/k>`1:BTX0BDU901DE5@1CDe<0I6AT030`<01CDe<0EeMG05=CD`1GEeL0EEEE
03/k>`1LG5`0@D51051@D00^;Rh0Bd];03/k>`14A4@0=3@d051@D00a<C40EeMG05eMG@1@D500GemO
04I6AP0m?Cd0AdM704Y:BP0j>SX0EeMG038b<P13@d<0EUIF0492@P0n?Sh0@T9202h^;P1HF5P0@D51
04=3@`0o?cl0=cLg030`<013@d<0>c/k03Ti>@0m?Cd0:b/[0492@P1JFUX04a<C04A4A010@400?Cdm
03Hf=P0k>c/0;2`/03De=@0f=SH04Q8B0?ooo`060=WIf@4000000@3IfMT001H0fMWI00<000000=WI
f@3IfMT00`3IfMT09@3oool0SXj>0:RXZ02HV9P0UiNG09nOW`2XZ:P0TY:B08n?S`2][Jd0PX:208b<
S01oOgl0X:2P0;2`/02NWYh0ZZZZ0;Bd]02f][H0Xj>S096AT@2e]KD0Xj>S0:JVYP2TY:@0P82009FE
U@2FUYH0S8b<0:b/[02QXJ40/K6a0:j^[P2IVIT0YJFU08b<S02VYZH00P2<S8`0;02:RXX0WIfM09NG
U`2QXJ40UiNG0;:b/P2MWId0Ti>C0;Fe]@2PX:00ZZZZ08j>SP2YZJT0`<300:^[Z`2l_;`0YJFU09^K
V`2i^KT0X:2P09RHV02RXZ80/;2`0:b/[02XZ:P0^[Zj08f=S@2a/K40ZZZZ0;:b/P2NWYh0Z:RX0:JV
YP2WYjL0ZJVY0:n_[`2i^KT0[Zj^0<;2`P2b/[80/k>c0;6a/@2UYJD0WinO0P2?Shl01`26QXH0Ph>3
08^;R`2<S8`0Ogmo09FEU@2OWil00P2CTi<0A`2NWYh0YZJV09>CT`2PX:00UiNG09fMW@2b/[80Vi^K
09>CT`2DU9@0X:2P0;Ng]`2KVi/0VIVI09ZJVP2:RXX0Y:BT0:>SX`2^[Zh0Z:RX0;:b/P2SXj<0WinO
0:j^[P2UYJD0RHV908B4Q02FUYH0W9bL0;2`/02MWId0XZ:R0:VYZ@25QHD0V9RH09nOW`20P800[Zj^
0:BTY021PH40SHf=07emO@1fMWH0U9BD09:BTP2EUID0QhN708V9R@23Ph<0T92@08n?S`2LW9`0UiNG
09jNWP21PH40Ph>307AdM01oOgl0QHF508>3P`2FUYH0P82007]kN`1oOgl0UIFE09>CT`27QhL0IVIV
0861P@25QHD0O7al0080QhN70100QXJ6092@T01hN7P0Rh^;08>3P`21PH40N7Qh092@T023Ph<0Jf][
075aL@1fMWH0RXZ:061PH01nOWh0NWYj0P2=SHd0A01jNWX0S8b<08J6QP1SHf<0KVi^06e]K@2>SXh0
QHF507inOP25QHD0NGUi07IfMP20P800MWIf08:2PP21PH40T92@06i^KP1YJFT0Ng]k0820P01XJ6P0
KVi^09NGU`2EUID0Ti>C07UiN@1bLW80Q8B40:JVYP2;Rh/0MWIf06MWI`1gMgL0RHV907=cL`1fMWH0
KVi^05iNGP1aLG40LW9b04e=C@1KFe/0G5aL06ATI01IFET0GEeM07EeM@1<C4`0DU9B07MgM`1YJFT0
IFEU06][J`1bLW80DU9B05=CD`15ADD0Fe]K04a<C01UIFD0GemO06IVIP1NGUh0Bd];05IFEP1VIVH0
JVYZ0P1QHF40701JFUX0EEEE04];B`1DE5@0?clo0451@@1:BTX0HV9R04];B`1EEED0FEUI05=CD`1=
CDd0DE5A03Ti>@10@400;Rh^051@D019BDT0GEeM04];B`1<C4`0AdM704I6AP1CDe<0>c/k055AD@1>
CTh204=3@`0M05aLG014A4@0>3Ph051@D011@D40CTi>03/k>`0Y:BT0?Shn034a<@0o?cl0F5QH03Hf
=P0k>c/0:RXZ04I6AP19BDT0@d=301LG5`0Y:BT0<C4a01hN7P0];Bd09BDU038b<P0k>c/08R8R03<c
<`3oool01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI02D0oooo0:JVYP2/
[:`0Xj>S08b<S02CTi<0OGem09bLW02>SXh0X:2P09nOW`2UYJD0Ti>C08>3P`2OWil0ZZZZ09jNWP2>
SXh0UYJF09FEU@2>SXh0TY:B09NGU`2;Rh/0S8b<09bLW024Q8@0YZJV0:FUY@2IVIT0SHf=09RHV022
PX80LW9b08Z:RP2ZZZX0W9bL0080VIVI04D0[:b/0:FUY@2NWYh0RHV909VIV@2YZJT0XJ6Q0;6a/@2K
Vi/0X:2P09BDU030`<00YJFU0;Ng]`2HV9P0R8R80;Zj^P2c/k<0Ti>C0;:b/P2RXZ80[jn_0:>SX`2>
SXh0Y:BT08R8R02UYJD0^[Zj0:^[Z`2QXJ40VYZJ0::RXP2TY:@0RHV90:NWY`2e]KD0Xj>S0<W9b@2`
/;00][Jf0:j^[P2`/;00ZJVY09RHV01oOgl0SXj>0820P02;Rh/0Ogmo08B4Q02:RXX0QHF508Z:RP1k
Ng/0IVIV09NGU`2ATI40YZJV0:j^[P2`/;00YJFU08j>SP2@T900XZ:R0:^[Z`2FUYH0VYZJ08j>SP2V
YZH00P2IVIT0;@2<S8`0W9bL0:VYZ@2LW9`0UYJF0;>c/`2YZJT0V9RH0:RXZ02/[:`0OWin09VIV@2O
Wil0TY:B09>CT`2DU9@0WYjN0:2PX02QXJ40UIFE092@T029RHT0S8b<09FEU@23Ph<0O7al08n?S`2H
V9P0U9BD09VIV@2=SHd0NGUi08N7Q`1oOgl0W9bL08f=S@2:RXX0SXj>08:2PP1lO7`0T92@07IfMP1o
Ogl0TI6A08F5Q@0208b<S00909:BTP2@T900Rh^;08J6QP2GUiL0Lg=c08N7Q`29RHT0QXJ60080OWin
01`0QHF507moO`1lO7`0NWYj079bLP2KVi/0UIFE06i^KP1fMWH0RHV907QhN021PH40Kfm_07AdM021
PH40NGUi08F5Q@1jNWX0Rh^;08b<S01lO7`0Ogmo08Z:RP1eMGD0MgMg07moO`2@T900O7al0P1^KVh0
J027QhL0Kfm_071`L023Ph<0Lg=c07EeM@1GEeL0N7Qh08n?S`1VIVH0MWIf08J6QP1oOgl0LG5a06][
J`1mOGd0Kfm_08B4Q026QXH0JFUY08:2PP1gMgL0Jf][075aL@1dM7@0Ogmo06a/K01dM7@0IVIV06i^
KP1WIfL0IVIV07QhN01JFUX0CDe=05aLG01UIFD0Hf=S06IVIP1ZJVX0Bd];04Q8B01FEUH0DU9B05IF
EP1;Bd/0GemO06m_K`1MGEd0FEUI04m?C`1>CTh0AdM703`l?012@T80;bl_03hn?P0o?cl0ATI60451
@@19BDT0@D5105IFEP1NGUh0<c<c0451@@1MGEd0I6AT03<c<`1NGUh0Bd];04i>CP1EEED0DE5A03Xj
>P1IFET0ATI60410@018B4P0@41004i>CP1@D500BDU90492@P0d=3@0B4Q803De=@10@400?clo03Lg
=`19BDT0=cLg04m?C`0d=3@0E5AD03/k>`19BDT0Cdm?04i>CP1ADE40BTY:04i>CP0a<C40@4100P0^
;Rh02P0n?Sh0:RXZ03Lg=`12@T80:BTY0451@@0/;2`0@41001/K6`3oool60=WIf@4000000@3IfMT0
01H0fMWI0P0000040=WIf@0;0?ooo`2>SXh0WinO09BDU020P800V9RH09JFUP2LW9`0Y:BT08j>SP2J
VYX00P2FUYH02@2KVi/0VYZJ08^;R`2;Rh/0X:2P0:n_[`23Ph<0WYjN096AT@0209ZJVP0^0:BTY02O
Wil0V9RH09^KV`2PX:00[jn_0:VYZ@2KVi/0[jn_0:f][@2DU9@0[:b/0::RXP2XZ:P0W9bL0:>SX`2D
U9@0/[:b0:NWY`2KVi/0Z:RX0:BTY02`/;00XZ:R0:ZZZP2f][H0Xj>S09VIV@2FUYH0[Zj^0:n_[`2^
[Zh0Z:RX0:j^[P2IVIT0Z:RX0;Rh^02f][H0/k>c09ZJVP2PX:00^[Zj08f=S@2;Rh/0Q8B409NGU`80
WIfM0;H0XJ6Q08^;R`2IVIT0W9bL0:VYZ@2UYJD0S8b<0:b/[02_[jl0YjNW08B4Q022PX80O7al07in
OP23Ph<0W9bL08F5Q@2ATI40OWin079bLP26QXH0K6a/08>3P`2:RXX0QhN709RHV02UYJD0]kNg0:j^
[P2LW9`0`/;20:^[Z`2TY:@0Zj^[09nOW`27QhL0UYJF07MgM`2;Rh/0V9RH08n?S`25QHD0WYjN09VI
V@2VYZH0VYZJ07emO@1oOgl0[:b/0:JVYP2NWYh0W9bL09>CT`2:RXX0RHV909nOW`2UYJD0OWin08j>
SP2RXZ80UYJF092@T02<S8`0PX:209RHV020P800ZZZZ08F5Q@23Ph<0O7al0861P@22PX80Vi^K08V9
R@22PX80O7al07UiN@25QHD0RXZ:08R8R02CTi<0T92@09NGU`1lO7`0SXj>07=cL`29RHT0P82007=c
L`1nOWh0R8R808:2PP1mOGd0RHV90820P01[Jf/0UYJF07EeM@2:RXX0MGEe07IfMP23Ph<0M7Ad07in
OP2@T900PH61061PH01ZJVX0QHF507UiN@2>SXh0M7Ad0820P01iNGT0KFe]079bLP21PH40Jf][07Ee
M@1VIVH0RHV907AdM021PH40RXZ:07QhN01_Kfl0I6AT07]kN`1_Kfl0MGEe07=cL`1kNg/0MGEe06EU
I@1dM7@0P82007IfMP2DU9@0PH6107]kN`1SHf<0KFe]06QXJ01]KFd0Ogmo06i^KP1gMgL0IfMW05UI
F@1JFUX0M7Ad06ATI01WIfL0RHV906ATI01]KFd0IVIV04=3@`1GEeL0EUIF051@D01^KVh0IfMW061P
H024Q8@0G5aL06m_K`10@400De=C05ADE01EEED0IfMW05aLG01VIVH0IfMW06UYJ@1NGUh0GemO06m_
K`1`L700C4a<05iNGP80C4a<01H0?Shn04A4A00k>c/0?3`l04I6AP1@D500Cdm?061PH01JFUX0D51@
05=CD`0b<S80=SHf03lo?`1IFET0;Rh^04I6AP0f=SH0DE5A04E5A@0];Bd0>SXj0P19BDT06`0f=SH0
;Bd]03/k>`0l?3`0@d=304U9B@0j>SX0@T9203Xj>P0a<C4092@T0492@P1SHf<0CDe=024Q8@1<C4`0
:2PX04I6AP1:BTX0Bd];03Xj>P0b<S80Bd];03hn?P0R8R8061PH02<S8`02034a<@0503De=@11@D40
>3Ph02`/;03oool01@3IfMT200000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI01H0oooo
0000002PX:00O7al08^;R`2:RXX0VIVI0:RXZ02EUID0Z:RX0:6QX@2EUID0U9BD08Z:RP2GUiL0WIfM
09ZJVP1kNg/0Zj^[096AT@2_[jl0WIfM0`2ATI40d02PX:00T92@09>CT`2HV9P0WYjN0:6QX@2TY:@0
Z:RX08b<S02PX:00YJFU0;6a/@2;Rh/0_kno09fMW@2NWYh0[Jf]09JFUP2RXZ80PH6109^KV`2h^;P0
ZJVY0;jn_P2e]KD0`/;20:^[Z`2h^;P0WinO08j>SP2^[Zh0T92@0:f][@2KVi/0WinO0:2PX02;Rh/0
W9bL09nOW`2e]KD0XJ6Q08N7Q`2PX:00RHV90:2PX02@T900Ti>C0;Vi^@2c/k<0WIfM0:BTY02a/K40
ZZZZ09jNWP2TY:@0QXJ609JFUP1kNg/0LW9b07IfMP2JVYX0WYjN096AT@27QhL0VYZJ08R8R01lO7`0
Q8B40820P028R8P0VIVI08n?S`2=SHd0TI6A08f=S@2OWil0UIFE0;Jf]P2QXJ40SXj>09nOW`2QXJ40
WYjN09RHV02ATI40Lg=c08J6QP2UYJD0VIVI09ZJVP1mOGd0VYZJ0:>SX`2ZZZX0S8b<0:VYZ@2PX:00
WIfM09FEU@2`/;00VYZJ0:BTY02CTi<0U9BD08J6QP2<S8`0RHV907IfMP21PH40U9BD09jNWP2:RXX0
TI6A08f=S@27QhL0P82008B4Q029RHT0MGEe092@T01/K6`0N7Qh08j>SP1VIVH0LG5a096AT@2;Rh/0
SXj>09jNWP2HV9P0UIFE09ZJVP1lO7`0QhN7092@T02:RXX0T92@07emO@1oOgl0KVi^06QXJ01TI6@0
QhN709BDU022PX80Jf][07inOP20P800Hf=S08B4Q01oOgl0MgMg08j>SP29RHT0SXj>07IfMP1cLg<0
Q8B407IfMP2?Shl0LW9b08Z:RP1kNg/0RHV908B4Q01/K6`0KFe]06EUI@1aLG40M7Ad06YZJP1^KVh0
IFEU06a/K01eMGD0Jf][07emO@1WIfL0G5aL07emO@2CTi<0JFUY07UiN@1dM7@0Ng]k07MgM`2@T900
K6a/07YjNP26QXH0OGem08:2PP25QHD0R8R808J6QP1WIfL0Kfm_061PH01/K6`0MgMg06UYJ@1HF5P0
E5AD06=SH`1;Bd/0EEEE06EUI@1YJFT205iNGP1?051@D01TI6@0DU9B06IVIP1:BTX0CTi>05UIF@1L
G5`0Bd];04=3@`1@D500DE5A06][J`1?Cdl0FEUI05=CD`1QHF40I6AT05iNGP1GEeL0I6AT05]KF`1?
Cdl0>SXj05EEE@1NGUh0=cLg05YJFP1=CDd0GUiN04E5A@17AdL0GEeM04];B`1GEeL0BTY:038b<P1G
EeL0@41004a<C012@T80ADE504Y:BP1BDU80:2PX03Xj>P12@T80?Cdm02h^;P1>CTh0@41004U9B@0g
=cL0@T9204a<C00h>3P0>c/k04U9B@0j>SX0AdM70492@P14A4@0?Cdm03/k>`16ATH0<c<c00<30`0l
?3`0:b/[034a<@0_;bl0=CDe02/[:`0^;Rh09BDU02h^;P0Q8B40>3Ph0?ooo`060=WIf@4000000@3I
fMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0VP3oool0QhN70:2PX02=SHd0VIVI09fMW@2VYZH0
MGEe07inOP25QHD0W9bL0:BTY02FUYH0RXZ:09VIV@2YZJT0WYjN071`L02>SXh0X:2P0:f][@2_[jl0
Q8B408f=S@2DU9@0WYjN09nOW`2PX:00ZJVY09fMW@2ZZZX0MgMg08V9R@2`/;00XZ:R08J6QP2RXZ80
X:2P09RHV02BTY80V9RH0:f][@2TY:@0Z:RX08n?S`2_[jl0WinO0;:b/P2PX:00V9RH0;fm_@2XZ:P0
];Bd0:2PX02YZJT0Xj>S09fMW@2WYjL0]KFe0:6QX@2ATI40/K6a096AT@2^[Zh0VIVI0:>SX`2XZ:P0
WIfM09RHV02PX:00/k>c09jNWP2][Jd0/k>c0::RXP2[Zj/0XZ:R0:^[Z`2OWil0YJFU0:6QX@2VYZH0
Rh^;08R8R024Q8@0T92@0:2PX02[Zj/0VYZJ08^;R`2DU9@0LW9b096AT@1^KVh0O7al08>3P`2TY:@0
^;Rh0:VYZ@2UYJD0VIVI09ZJVP2;Rh/0QhN709RHV02MWId0WYjN0:JVYP2TY:@0[:b/08f=S@2FUYH0
P82007inOP2IVIT0UiNG0:n_[`2KVi/0YJFU092@T02EUID0WYjN0:FUY@2YZJT0Rh^;09>CT`27QhL0
VIVI09ZJVP2GUiL0WYjN0:VYZ@2<S8`0WIfM08Z:RP25QHD0KVi^08R8R01^KVh0RHV909VIV@21PH40
IVIV08Z:RP2IVIT0W9bL08J6QP1^KVh0RHV908j>SP23Ph<0SHf=07emO@23Ph<2079bLP0L069RHP24
Q8@0NWYj09>CT`2;Rh/0SXj>08F5Q@23Ph<0Q8B407alO022PX80MGEe06ATI02=SHd0QHF507AdM01_
Kfl0R8R808:2PP20P800NWYj07emO@1dM7@0OWin09JFUP21PH40UIFE096AT@80N7Qh02d0J6QX08V9
R@1nOWh0N7Qh06e]K@25QHD0LW9b07IfMP1jNWX0MGEe069RHP1jNWX0K6a/05QHF01bLW80Cdm?06UY
J@1fMWH0OWin07YjNP21PH40VIVI0820P027QhL0PH6107IfMP26QXH0JVYZ07QhN01jNWX0MGEe07mo
O`1ZJVX0O7al069RHP1SHf<0NWYj06MWI`1mOGd0I6AT07=cL`1WIfL0JVYZ061PH01CDe<00P1PH600
601_Kfl0LG5a05MGE`1LG5`0BDU905=CD`1ADE40CTi>05IFEP0k>c/0EUIF06IVIP1LG5`0HF5Q05iN
GP1GEeL0EUIF05]KF`1;Bd/0@D5104I6AP1HF5P0IFEU04e=C@80EeMG03L0@d=304Y:BP1HF5P0C4a<
04M7A`0h>3P0@D5103Ti>@15ADD0DE5A04I6AP0T92@0;2`/05ADE011@D40FUYJ03Ph>018B4P0?Shn
03/k>`15ADD0De=C02PX:00j>SX0;Rh^03hn?P0];Bd0ADE504Q8B015ADD0=cLg03Ti>@1KFe/0B4Q8
03<c<`0M7Ad0;Rh^0451@@0k>c/0=CDe04e=C@0d=3@0:b/[0451@@0m?Cd092@T04A4A00i>CT0=SHf
02h^;P0E5AD06a/K02/[:`0N7Qh0oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WI
f@030=WIf@180?ooo`1^KVh0Vi^K09NGU`2OWil0X:2P08B4Q02FUYH0VIVI08f=S@2ZZZX0UIFE0:BT
Y02<S8`0[Jf]09jNWP2DU9@0UiNG09RHV01mOGd0T92@0:RXZ01iNGT0Shn?0:2PX02NWYh0Xj>S0:BT
Y02ZZZX0U9BD0::RXP2FUYH0V9RH08F5Q@2HV9P0YZJV0:NWY`2:RXX0VIVI0:RXZ02[Zj/0`<300;:b
/P2/[:`0YjNW0:RXZ02][Jd0][Jf0;bl_03<c<`0XZ:R0:j^[P2WYjL0Zj^[0:2PX02WYjL0[Jf]08:2
PP2NWYh0]KFe0<30`02TY:@0XZ:R0:^[Z`2BTY80SHf=0:NWY`2ZZZX0V9RH09:BTP1kNg/0P8200P2g
]kL01P2KVi/0XJ6Q0;Jf]P2MWId0Z:RX0:^[Z`80T92@0P1]KFd0<01YJFT0Q8B409bLW02RXZ80Ti>C
0:j^[P2OWil0P820079bLP1cLg<0Rh^;0:>SX`2c/k<0XZ:R0:j^[P2MWId0T92@0:BTY02QXJ40SHf=
0:RXZ029RHT0QhN70:2PX02LW9`0Vi^K08b<S01bLW80R8R809BDU02>SXh0UiNG09FEU@2KVi/0/;2`
09NGU`2_[jl0ZZZZ0:6QX@2MWId0TI6A07alO02TY:@0UiNG096AT@2FUYH0Ogmo0:2PX080Ti>C0240
QhN709FEU@2LW9`0UIFE08n?S`22PX80V9RH08:2PP1nOWh0Ti>C08f=S@26QXH0NWYj092@T01hN7P0
Q8B406i^KP1oOgl0R8R807=cL`2NWYh0RXZ:096AT@24Q8@0PX:206UYJ@2=SHd0T92@07AdM029RHT0
NWYj08N7Q`1eMGD00P27QhL07P1fMWH0QHF508J6QP25QHD0JFUY07inOP1hN7P0QhN7065QH@2:RXX0
KVi^07emO@2DU9@0WYjN09BDU01`L700O7al075aL@1`L700Lg=c08>3P`1oOgl0RHV9075aL@1^KVh0
KFe]07AdM01jNWX0MgMg05iNGP80Kfm_02D0M7Ad06=SH`2CTi<0JFUY08^;R`1mOGd0Rh^;06a/K02=
SHd0P82005mOG`1cLg<0O7al07AdM01fMWH0MgMg06MWI`1gMgL0GUiN05aLG01@D500Jf][04a<C01N
GUh0Hf=S06QXJ01RHV80J6QX04I6AP13@d<0De=C069RHP1JFUX0H61P04e=C@1KFe/0IFEU0080F5QH
01T0JVYZ04m?C`0n?Sh0=CDe05ADE00[:b/0@T9202d];@1:BTX09bLW04e=C@10@400H61P059BDP1E
EED0D51@04E5A@0j>SX0BTY:04I6AP1KFe/0ATI602XZ:P1>CTh0BDU90080@T9200d0@41004=3@`0Z
:RX0>CTi069RHP0l?3`0B4Q804E5A@0e=CD0Cdm?05EEE@12@T80=cLg0080?Cdm01/0AdM704I6AP1>
CTh0CTi>03`l?014A4@0@D5103Hf=P0g=cL0=CDe03@d=019BDT061PH03Hf=P1RHV80CTi>02l_;`1:
BTX0820P03Lg=`0o?cl0E5AD02d];@0b<S806a/K03dm?@0O7al00P0X:2P00`0O7al06QXJ0?ooo`06
0=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0;03oool0MgMg0:VYZ@2KVi/0
Rh^;0:6QX@2NWYh0W9bL0:BTY02RXZ80WYjN09bLW02@T900TY:B09jNWP2CTi<0YZJV0:6QX@2JVYX0
V9RH0:b/[02TY:@0SXj>07inOP2_[jl0UIFE0::RXP2HV9P0XZ:R09>CT`2=SHd0S8b<09fMW@2XZ:P0
^KVi09RHV02PX:00T92@08^;R`2b/[80S8b<09^KV`2VYZH0SXj>0P2LW9`01P2MWId0XZ:R0;jn_P2^
[Zh0Z:RX0:j^[P80[:b/02l0]kNg0:ZZZP2XZ:P0[jn_0:>SX`2WYjL0]kNg08Z:RP2<S8`0Y:BT0:f]
[@33`l<0]KFe0:FUY@2h^;P0Ph>3096AT@2<S8`0SHf=09fMW@2WYjL0XZ:R09jNWP2h^;P0[jn_0;Vi
^@2NWYh0T92@071`L01YJFT0Ph>309:BTP1fMWH0TY:B0:BTY02NWYh0RXZ:06QXJ01eMGD0Lg=c07mo
O`1aLG40RXZ:092@T020P800WIfM09ZJVP0209>CT`2?0:6QX@25QHD0TI6A09JFUP2DU9@0RHV908N7
Q`2;Rh/0NWYj07inOP2<S8`0[:b/09NGU`2NWYh0ZZZZ0:6QX@2EUID0S8b<0;2`/02OWil0RXZ:0:BT
Y02SXj<0UYJF07alO02a/K40S8b<08F5Q@2IVIT0Shn?0:^[Z`25QHD0SHf=09NGU`2IVIT0UiNG08J6
QP1jNWX0P82007inOP2BTY80QHF507moO`2ATI40Kfm_08B4Q01cLg<0RHV90;Jf]P2LW9`0QhN707mo
O`27QhL0NWYj07EeM@2=SHd0L71`06i^KP1kNg/0QXJ609BDU025QHD0Rh^;09jNWP26QXH0Jf][08R8
R026QXH0OWin08^;R`1hN7P0IFEU08n?S`23Ph<0Ng]k06EUI@1lO7`0S8b<07UiN@1^KVh0MWIf07Ui
N@1mOGd0Ti>C08j>SP2BTY80MWIf08n?S`1TI6@0H61P07=cL`24Q8@0PH6106MWI`1mOGd0Kfm_07If
MP1QHF40O7al06YZJP1RHV80JVYZ07alO01ZJVX0RHV907alO026QXH0OGem08>3P`1[Jf/0N7Qh06MW
I`21PH40N7Qh06MWI`1oOgl0Jf][051@D020P800MGEe059BDP1HF5P0L71`04i>CP1EEED0H61P04A4
A01UIFD0GUiN069RHP1KFe/0B4Q805=CD`0k>c/0EeMG055AD@1HF5P0GemO059BDP1PH600IVIV04a<
C01ADE400P0k>c/0:00K6a/03`l?030`<00c<c<0Cdm?0492@P1CDe<0E5AD04=3@`17AdL0820P04I6
AP1;Bd/0BTY:04a<C01@D500EUIF03@d=00i>CT0=SHf04=3@`17AdL0Cdm?03dm?@19BDT0@T9205eM
G@0h>3P0:RXZ05]KF`1EEED0CTi>03/k>`12@T80>3Ph0492@P1?Cdl0<C4a02HV9P0m?Cd203`l?00H
04I6AP0U9BD0:2PX03Ti>@13@d<0B4Q804];B`1GEeL0A4A403Lg=`0e=CD0=3@d04I6AP0g=cL0@d=3
01dM7@13@d<0;Bd]04Q8B00T92@0=CDe02DU9@0:2PX0oooo1P3IfMT100000040fMWI000F0=WIf@03
0000003IfMT0fMWI00<0fMWI01X0oooo0:6QX@2?Shl0Xj>S092@T026QXH0Ti>C08n?S`2:RXX0XJ6Q
0;6a/@1nOWh0Ti>C09fMW@2ZZZX0W9bL09jNWP2CTi<0V9RH08f=S@2ZZZX0UIFE0:b/[02JVYX0Vi^K
092@T080Xj>S01D0V9RH0:>SX`2][Jd0WinO09bLW01fMWH0VYZJ0;Jf]P2g]kL0^;Rh0:BTY02WYjL0
WIfM09^KV`2BTY80[jn_0:NWY`2XZ:P0WYjN08n?S`2^[Zh00P2KVi/08P2d];@0Zj^[09JFUP2KVi/0
X:2P0:f][@2/[:`0[Zj^0:VYZ@2KVi/0Z:RX0;Bd]02CTi<0_Kfm0;^k^`2TY:@0SHf=09RHV02ATI40
SXj>0:NWY`26QXH0UiNG09:BTP2OWil0Zj^[07emO@2XZ:P0]KFe07alO02:RXX0JVYZ05mOG`1/K6`2
08F5Q@0O092@T02NWYh0VYZJ08j>SP2;Rh/0I6AT05UIF@1NGUh0Kfm_0:FUY@2SXj<0TY:B08:2PP2;
Rh/0TI6A09JFUP28R8P0WinO09ZJVP27QhL0RXZ:07moO`24Q8@0LW9b05IFEP0X:2P0@D5105YJFP2H
V9P0RXZ:09FEU@020:^[Z`0609fMW@2OWil0[Zj^0:f][@2WYjL0UYJF0P2NWYh0V02PX:00T92@0:2P
X02NWYh0YZJV0:FUY@28R8P0WYjN09RHV01hN7P0T92@096AT@1DE5@0S8b<06UYJ@1cLg<0Rh^;07If
MP1nOWh0Jf][07emO@2:RXX0LW9b09JFUP23Ph<0VYZJ09RHV02=SHd0RHV906e]K@1lO7`0QHF5096A
T@29RHT0SXj>07]kN`2VYZH0VIVI092@T02;Rh/0N7Qh07AdM01ZJVX0GEeM0:FUY@1kNg/0GUiN07mo
O`1jNWX0P82006i^KP1OGel0MgMg07alO028R8P0RHV907]kN`1bLW80IfMW08N7Q`1^KVh0TY:B07]k
N`1^KVh0Jf][08>3P`1ZJVX0E5AD06MWI`1VIVH0LG5a08F5Q@26QXH0JFUY07AdM01;Bd/0LW9b08B4
Q01/K6`0OGem0861P@1kNg/0NWYj08>3P`1gMgL0MGEe06m_K`1SHf<0HV9R07alO01eMGD0K6a/05iN
GP1eMGD0K6a/05ADE01/K6`0Jf][06=SH`1RHV80NWYj05eMG@1QHF40Cdm?059BDP1=CDd0J6QX05]K
F`1:BTX0F5QH06i^KP1NGUh0HV9R04=3@`1BDU80<c<c04I6AP1EEED0>SXj038b<P17AdL0A4A403Hf
=P0j>SX0>3Ph05IFEP0e=CD0GEeM06IVIP1QHF40?Cdm03Hf=P1=CDd0BDU905=CD`0e=CD0?Cdm02d]
;@0a<C40CDe=04i>CP1DE5@0BDU902l_;`1ADE40AdM704Y:BP17AdL0D51@04Y:BP0a<C40?3`l0P0o
?cl0801:BTX0@T9202HV9P0a<C40<S8b04=3@`0_;bl09BDU02d];@10@400:RXZ03Ti>@1?Cdl0Bd];
03dm?@11@D40?Cdm03lo?`1=CDd0>SXj03`l?01>CTh0ATI6038b<P15ADD0>SXj05ADE00L71`0:b/[
02DU9@0l?3`0oooo1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0=80oooo
09>CT`2<S8`0S8b<08>3P`2BTY80Vi^K09>CT`2;Rh/0UYJF09FEU@2LW9`0Rh^;0:BTY02IVIT0OGem
0820P028R8P0TY:B09ZJVP2f][H0X:2P09ZJVP2GUiL0VYZJ09RHV02TY:@0WinO09bLW02;Rh/0YJFU
09fMW@2BTY80Rh^;08n?S`2PX:00Ph>308n?S`2][Jd0WinO08^;R`24Q8@0^;Rh0;fm_@2VYZH0^[Zj
0:2PX02^[Zh0[jn_0:BTY02ZZZX0XZ:R0:6QX@2^[Zh0^KVi09JFUP32`/80Z:RX09fMW@2LW9`0Z:RX
08Z:RP2RXZ80Rh^;0:>SX`2JVYX0/K6a0:j^[P2KVi/0Xj>S0;>c/`2MWId0Y:BT0:VYZ@2l_;`0YZJV
08^;R`2DU9@0[Jf]08j>SP2OWil0V9RH05eMG@1FEUH0M7Ad08V9R@28R8P0RXZ:0:BTY02ATI40L71`
07MgM`1VIVH0E5AD079bLP27QhL0XZ:R0;Ng]`2BTY80WIfM07moO`2HV9P0Zj^[0:b/[02DU9@0SHf=
0:>SX`2>SXh0Ti>C09NGU`1iNGT0ADE50000000T92@0JVYZ08Z:RP2KVi/0PX:20:2PX02=SHd0WinO
0:FUY@2QXJ40Xj>S0;Fe]@2<S8`0Y:BT09nOW`2_[jl0QXJ609ZJVP2=SHd0QHF5096AT@22PX80SHf=
0:6QX@2RXZ80RHV909>CT`2BTY80U9BD06m_K`29RHT0S8b<08F5Q@1nOWh0O7al07moO`1cLg<0SHf=
07inOP28R8P0N7Qh075aL@26QXH0L71`07YjNP1hN7P0UYJF07emO@2=SHd0MgMg07inOP28R8P0RXZ:
07inOP2=SHd0Ogmo07alO01oOgl0OWin061PH022PX80V9RH06MWI`1oOgl0Kfm_07moO`1hN7P0NWYj
08j>SP25QHD0VIVI08>3P`1aLG40MWIf06m_K`28R8P0Rh^;08J6QP1QHF40J6QX08>3P`1/K6`0GUiN
07=cL`1_Kfl0LG5a08Z:RP2@T900MGEe08B4Q01bLW80Ph>308F5Q@29RHT0NWYj07]kN`21PH4207Yj
NP0[07inOP1/K6`0LW9b05MGE`1kNg/0MGEe07YjNP1cLg<0K6a/06e]K@1aLG40KVi^05iNGP1YJFT0
BTY:05EEE@1RHV80G5aL06e]K@1LG5`0IVIV05EEE@1MGEd0HF5Q06UYJ@0l?3`0Bd];05=CD`1>CTh0
FEUI04M7A`0l?3`0:RXZ03/k>`0_;bl0?3`l024Q8@0T92@0<c<c014A4@0g=cL09BDU0492@P0203/k
>`0906QXJ017AdL0AdM7038b<P0i>CT0BDU905]KF`0l?3`08B4Q0080@41002h0>3Ph05=CD`000000
ATI604m?C`0`<300DU9B04E5A@0h>3P0Fe]K02`/;013@d<0A4A405mOG`18B4P0:BTY01`L7015ADD0
;bl_02TY:@1;Bd/0>CTi03hn?P12@T80CDe=03hn?P0a<C40>3Ph0410@00Z:RX0<c<c03lo?`1KFe/0
EeMG03De=@11@D409RHV03lo?`0Y:BT0<S8b0410@00c<c<0:RXZ020P800Y:BT0oooo1P3IfMT10000
0040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00T0oooo0:6QX@2SXj<0X:2P0:NWY`27QhL0
UYJF09nOW`26QXH00P24Q8@0:@2KVi/0O7al09VIV@2:RXX0UYJF0:FUY@2DU9@0X:2P0:VYZ@2UYJD0
YjNW09>CT`2:RXX0SHf=0;:b/P2NWYh0RHV90:>SX`2[Zj/0RXZ:0:FUY@2OWil0S8b<0:^[Z`2JVYX0
Vi^K09nOW`2j^[X0UIFE0:NWY`2_[jl0WinO0;Jf]P2LW9`0WYjN09^KV`2BTY80`L7109BDU03Bd]80
Y:BT0080YJFU0180XZ:R0:>SX`2XZ:P0[Jf]0:n_[`2RXZ80YjNW08^;R`25QHD0YZJV0::RXP2YZJT0
Zj^[09jNWP2h^;P0R8R807inOP2JVYX209nOW`0609ZJVP2e]KD0Xj>S09>CT`2YZJT0_;bl0P2SXj<0
501[Jf/0E5AD06a/K01VIVH0RXZ:09BDU02:RXX0RHV907QhN01kNg/0Jf][05eMG@1RHV80SHf=0:^[
Z`2YZJT0/[:b0:ZZZP2JVYX0Rh^;0P2LW9`0D`2MWId0QXJ608B4Q02@T900TY:B0;Vi^@1JFUX0Cdm?
014A4@1WIfL0L71`09:BTP2XZ:P0ZJVY09BDU02UYJD0WIfM0:>SX`2ZZZX0VIVI096AT@2EUID0YJFU
09JFUP2QXJ40WYjN092@T02TY:@0OGem096AT@2FUYH0RXZ:09:BTP2<S8`0^;Rh08N7Q`2IVIT0RHV9
09:BTP2KVi/0QXJ607moO`25QHD0QhN707UiN@1nOWh0Q8B4075aL@25QHD0Shn?08B4Q02=SHd0MGEe
071`L01mOGd0PH6109NGU`2HV9P0OWin08F5Q@2:RXX0P82009VIV@28R8P0OGem0861P@26QXH0H61P
0:6QX@2CTi<0T92@08n?S`1jNWX0NGUi08b<S022PX80MWIf06][J`2:RXX0QXJ608f=S@1jNWX0K6a/
0080Lg=c00T0IfMW07IfMP1MGEd0KVi^079bLP26QXH0Kfm_07alO01cLg<00P1[Jf/02@1lO7`0K6a/
06MWI`1cLg<0Ng]k08>3P`26QXH0IVIV08Z:RP0206][J`0B061PH01eMGD0MGEe06m_K`1iNGT0MWIf
0861P@1LG5`0M7Ad06YZJP1nOWh0Kfm_065QH@1EEED0EeMG06a/K01VIVH0MgMg0P1PH600C`1WIfL0
FEUI04A4A01HF5P0De=C055AD@1?Cdl0K6a/02LW9`1GEeL0DE5A02<S8`1>CTh0<c<c03Lg=`1=CDd0
BDU905=CD`1<C4`0<S8b02PX:011@D40ADE503Hf=P0h>3P0ADE504];B`1:BTX09BDU04a<C00f=SH0
BDU904I6AP0^;Rh0E5AD059BDP1>CTh0>SXj05YJFP0000008R8R04A4A00k>c/0=CDe04e=C@0c<c<0
@D510492@P16ATH0:2PX0492@P0g=cL0>c/k02PX:00c<c<0>3Ph03`l?011@D40ATI604=3@`10@400
F5QH038b<P0a<C40@d=303Ti>@0m?Cd0BTY:0410@00a<C40CDe=03Lg=`0b<S80ATI603<c<`0d=3@0
?3`l04E5A@0d=3@00P0K6a/00`0U9BD0oooo0=WIf@050=WIf@4000000@3IfMT001H0fMWI00<00000
0=WIf@3IfMT00`3IfMT0703oool0Y:BT08b<S02DU9@0Ti>C07QhN02HV9P0YJFU096AT@2>SXh0Shn?
096AT@25QHD0S8b<09ZJVP2BTY80SXj>0:j^[P1nOWh0/;2`0;fm_@2WYjL0QHF509NGU`2VYZH0XJ6Q
09VIV@2@T90208J6QP0C09FEU@2/[:`0Y:BT0;Bd]02QXJ40U9BD07alO02[Zj/0Vi^K0:n_[`2[Zj/0
UiNG09JFUP2][Jd0X:2P09fMW@2KVi/0/;2`092@T0020:ZZZP030:RXZ02i^KT0_[jn0080Z:RX0480
X:2P09nOW`2:RXX0ZJVY0;2`/02[Zj/0Q8B40861P@2QXJ40ZJVY0:2PX02TY:@0Rh^;09FEU@2QXJ40
Ph>309bLW02WYjL0YZJV09ZJVP2=SHd0UIFE09JFUP2RXZ80T92@08^;R`1oOgl0KVi^04i>CP1WIfL0
Ogmo08J6QP2:RXX0N7Qh09bLW01fMWH0HV9R05eMG@1bLW80QXJ60:2PX02a/K40_[jn09RHV02<S8`0
[Jf]09^KV`2GUiL0U9BD09RHV02NWYh0W9bL09NGU`2/[:`0SHf=06a/K029RHT0Shn?08B4Q02[Zj/0
YJFU09^KV`2/[:`0WIfM0:ZZZP2VYZH2096AT@0509nOW`2GUiL0MgMg08f=S@2HV9P00P2ATI40D@26
QXH0Vi^K09RHV028R8P0RHV908b<S01jNWX0UiNG07AdM02RXZ80UiNG07alO02>SXh0U9BD09VIV@29
RHT0Jf][079bLP2LW9`0R8R807alO01mOGd0Ph>308N7Q`28R8P0M7Ad07QhN022PX80Ng]k07inOP1a
LG40N7Qh09fMW@1`L700R8R808N7Q`2<S8`0QXJ607QhN01nOWh0Ph>308F5Q@24Q8@0Rh^;08J6QP1d
M7@0QXJ60861P@1fMWH0R8R80820P023Ph<0S8b<061PH01bLW80NGUi08F5Q@2@T900PH6107AdM01g
MgL0QHF506QXJ01MGEd0EeMG07=cL`25QHD0O7al079bLP1kNg/0KFe]07=cL`2@T900MGEe071`L01m
OGd0Q8B407QhN024Q8@0QHF507=cL`0207emO@1K08B4Q01GEeL0FUYJ08F5Q@1/K6`0KFe]069RHP1c
Lg<0JVYZ05MGE`1RHV80GEeM06EUI@1bLW80Hf=S05]KF`1HF5P0I6AT03dm?@1LG5`0IFEU069RHP1B
DU80MgMg055AD@1[Jf/0G5aL05]KF`0^;Rh0;Bd]03De=@1BDU80C4a<0410@01FEUH0Bd];04m?C`19
BDT0FUYJ0451@@0m?Cd0=CDe0492@P10@400C4a<04=3@`1HF5P0De=C02`/;00[:b/0D51@04];B`12
@T80D51@04I6AP17AdL0D51@03/k>`1@D500H61P0451@@13@d<0;Rh^04=3@`1:BTX0D51@03/k>`0f
=SH0C4a<051@D015ADD0<30`04Y:BP13@d<0Cdm?03De=@0];Bd0B4Q803/k>`0n?Sh0@d=304I6AP0c
<c<0ATI603Ph>015ADD0>SXj04I6AP1<C4`0@D5103`l?00203De=@0704Y:BP0];Bd04a<C00/;2`0D
51@08B4Q0?ooo`060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT09@3oool0
Ogmo07QhN02EUID0P82008Z:RP2XZ:P0Rh^;09jNWP2MWId0ZJVY08>3P`1hN7P0U9BD0:2PX02OWil0
YJFU08Z:RP2KVi/0XZ:R0;2`/02KVi/0QHF50:VYZ@1dM7@0PH610:VYZ@2;Rh/0WIfM0:RXZ02EUID0
]KFe0:VYZ@23Ph<0Ti>C0:FUY@2IVIT00P2OWil0<02l_;`0[:b/0:b/[02PX:00Vi^K09NGU`2IVIT0
`<300:FUY@2;Rh/0Z:RX0:BTY02YZJT0]KFe0:6QX@2NWYh0X:2P0:BTY02MWId0[Jf]0;Zj^P2][Jd0
YJFU0::RXP2j^[X0TI6A09bLW02KVi/0Xj>S0::RXP1gMgL0U9BD0;>c/`2_[jl0T92@08B4Q02WYjL0
VYZJ09RHV028R8P0Ph>30:JVYP2`/;00Kfm_075aL@1cLg<0M7Ad08b<S080OGem0340KVi^0820P01X
J6P0I6AT069RHP1lO7`0RXZ:0:^[Z`2WYjL0TY:B0:f][@2QXJ40[:b/0;:b/P2GUiL0R8R809FEU@23
Ph<0XZ:R09>CT`2HV9P0SHf=09>CT`2PX:00XJ6Q09FEU@2a/K40Zj^[0:ZZZP2KVi/0UiNG0:j^[P2E
UID0V9RH0:2PX02;Rh/0V9RH09NGU`2_[jl0TI6A08V9R@2?Shl0UiNG08Z:RP2GUiL0OWin0:2PX02D
U9@0Ogmo0080P82006H0U9BD08n?S`1lO7`0Vi^K092@T022PX80Rh^;08R8R020P800PH6107=cL`28
R8P0QXJ608B4Q022PX80Ph>306i^KP1YJFT0WIfM07UiN@1aLG40OWin05eMG@22PX80Hf=S092@T024
Q8@0TY:B08b<S020P800TY:B08n?S`1LG5`0R8R808F5Q@2FUYH0P82007YjNP24Q8@0Rh^;07QhN01V
IVH0UIFE07emO@1cLg<0FEUI06e]K@1hN7P0JVYZ06MWI`1;Bd/0JVYZ07QhN01ZJVX0I6AT08j>SP27
QhL0GEeM059BDP1hN7P0KVi^06m_K`1RHV80M7Ad07UiN@1eMGD0L71`09>CT`1hN7P0JFUY05mOG`1]
KFd0M7Ad06e]K@1OGel0Ng]k069RHP1WIfL0M7Ad05=CD`1<C4`0FUYJ05EEE@1WIfL0I6AT061PH01f
MWH0J6QX06UYJ@1TI6@0DU9B04Q8B01WIfL0De=C06ATI01LG5`0LG5a05QHF01IFET0IFEU04Y:BP12
@T8204=3@`0504Q8B00o?cl0EeMG051@D01EEED00P1GEeL05010@400BTY:03@d=00];Bd0A4A405EE
E@15ADD0@T9204U9B@1GEeL0BTY:03<c<`1NGUh0>3Ph02d];@18B4P0@41005=CD`1OGel0=SHf0P0h
>3P0:@19BDT0=3@d03Ti>@0g=cL0CDe=03Lg=`0X:2P0;bl_03@d=00`<300<C4a02`/;014A4@08R8R
03`l?00m?Cd0ADE5030`<00g=cL0F5QH02<S8`0e=CD0?clo051@D014A4@0BDU905UIF@14A4@0;Rh^
02@T9016ATH06a/K03hn?P0e=CD0<c<c02TY:@0T92@05ADE024Q8@0j>SX0oooo00H0fMWI0@000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0@0?ooo`2RXZ80Ti>C09FEU@22PX80U9BD07]k
N`2HV9P0Shn?09>CT`2FUYH0Ph>30:>SX`2=SHd0SXj>09NGU`80V9RH01h0NWYj096AT@2RXZ80WinO
08>3P`2?Shl0WIfM08V9R@2a/K40WinO08^;R`2:RXX0VIVI092@T02d];@0WinO09>CT`2MWId0SHf=
0:6QX@2=SHd0XZ:R09FEU@2;Rh/0WinO08>3P`2LW9`0Y:BT096AT@2^[Zh20:NWY`0808f=S@2l_;`0
R8R80;Vi^@2NWYh0XJ6Q0:NWY`2JVYX30:2PX0080;Ng]`2UYJD0Ti>C08J6QP1]KFd0R8R809NGU`22
PX8208Z:RP1208N7Q`2?Shl0Ogmo08b<S02CTi<0WIfM0861P@2GUiL0WYjN0:JVYP1oOgl0Lg=c06m_
K`1cLg<0Ng]k06m_K`1TI6@0EeMG06i^KP1nOWh0PH6106QXJ029RHT0S8b<09NGU`22PX80Vi^K07in
OP2QXJ40YJFU0:2PX02HV9P0VYZJ09>CT`2@T900Rh^;08n?S`29RHT0SXj>08N7Q`23Ph<0TY:B0:JV
YP2?Shl0UiNG0::RXP2[Zj/0Vi^K0:JVYP2=SHd0UYJF0:b/[02LW9`0Vi^K096AT@2^[Zh0[:b/08F5
Q@26QXH0UYJF08b<S02LW9`0Y:BT07YjNP2GUiL0Shn?0P24Q8@08`2CTi<0TI6A07inOP1dM7@0O7al
08F5Q@2<S8`0T92@07EeM@1kNg/0PX:207IfMP21PH40Ph>307inOP2JVYX0MWIf07alO028R8P0SXj>
06m_K`1XJ6P0Ng]k07=cL`26QXH0S8b<07moO`25QHD0LW9b07AdM01eMGD0KVi^06MWI`1eMGD0J6QX
0080Ogmo04H0M7Ad07emO@1XJ6P0FEUI08F5Q@1[Jf/0I6AT06a/K01cLg<0IfMW07]kN`1/K6`0JFUY
07YjNP1RHV80NWYj06UYJ@1hN7P0M7Ad05QHF01VIVH0G5aL07=cL`1CDe<0Jf][069RHP1VIVH0Kfm_
061PH01QHF40IFEU06i^KP1_Kfl0KVi^069RHP1MGEd0FEUI05mOG`1BDU80GemO05iNGP1SHf<0EEEE
069RHP10@400GUiN05eMG@1PH600MGEe04I6AP1MGEd0K6a/06MWI`20P800Fe]K07MgM`1dM7@0KFe]
06=SH`1TI6@0Lg=c059BDP17AdL0GEeM04E5A@14A4@0;Bd]0410@019BDT0IfMW0P1DE5@05`1lO7`0
GemO05EEE@0e=CD0?clo02XZ:P0>3Ph09bLW03`l?01OGel0CTi>03Lg=`0[:b/0>CTi04=3@`0U9BD0
<C4a03Lg=`0M7Ad0B4Q80410@011@D40?Shn0080ATI602T0>c/k051@D014A4@0B4Q8038b<P0f=SH0
?Shn03@d=017AdL0=SHf04Y:BP0k>c/0A4A402<S8`0^;Rh0>c/k03Xj>P0e=CD08b<S010@400h>3P0
9BDU02`/;00l?3`0=cLg0492@P0k>c/0?3`l02XZ:P0T92@03`l?038b<P11@D40;bl_02`/;00o?cl0
=3@d02d];@0H61P02`/;0?ooo`060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3I
fMT0;`3oool0S8b<08j>SP2BTY80R8R809fMW@20P800Ogmo08J6QP28R8P0WinO08j>SP27QhL0VIVI
0000002WYjL0UIFE08j>SP2HV9P0TI6A09VIV@2HV9P0Ti>C09bLW02OWil0WIfM0::RXP2KVi/0[Zj^
0;6a/@2WYjL0W9bL08b<S02QXJ40V9RH09jNWP2PX:00^;Rh0;Bd]02b/[80ZZZZ0:RXZ02=SHd0Z:RX
0<;2`P2[Zj/0];Bd0080ZZZZ0100/;2`0:RXZ02`/;00]KFe0;6a/@2KVi/0YJFU0;Jf]P2/[:`0[Zj^
0:FUY@2RXZ80X:2P0;fm_@2i^KT0X:2P0P2GUiL0d`2LW9`0V9RH0:>SX`2PX:00YJFU096AT@2LW9`0
T92@09nOW`2PX:00TI6A0:6QX@2UYJD0VIVI08F5Q@28R8P0Ph>308Z:RP25QHD0T92@09ZJVP1ZJVX0
MgMg08Z:RP29RHT0MGEe08f=S@2;Rh/0P820096AT@2MWId0WYjN09nOW`2EUID0Zj^[09BDU02<S8`0
XJ6Q09BDU02[Zj/0YJFU0;2`/02/[:`0ZZZZ08n?S`2MWId0V9RH0:FUY@2PX:00][Jf0:BTY02][Jd0
YjNW0:^[Z`2FUYH0XZ:R09bLW02KVi/0TY:B09BDU02KVi/0PH61096AT@2IVIT0OGem08f=S@2PX:00
W9bL06a/K01jNWX0QHF508B4Q027QhL0R8R809RHV02:RXX0U9BD06MWI`2;Rh/0N7Qh096AT@29RHT0
N7Qh07alO01kNg/0RXZ:07IfMP2=SHd0PX:209BDU02CTi<0Ph>30::RXP1mOGd0UIFE09ZJVP26QXH0
SXj>09ZJVP2@T900OWin07MgM`1kNg/0MgMg06e]K@1hN7P0NGUi07=cL`1oOgl0Q8B40861P@1]KFd0
QHF508f=S@21PH40O7al06i^KP1aLG40NWYj07MgM`2>SXh0Kfm_07IfMP1^KVh0LG5a05eMG@1YJFT0
Vi^K06i^KP1jNWX0KFe]07alO01UIFD0DU9B08:2PP1iNGT0IFEU06][J`1jNWX0P82006MWI`1YJFT0
Jf][06m_K`1GEeL0HF5Q069RHP1GEeL0LG5a06m_K`1BDU80HV9R05MGE`1SHf<0K6a/069RHP19BDT0
JVYZ06UYJ@1NGUh0A4A406MWI`18B4P0HV9R06i^KP1WIfL0GUiN061PH01LG5`0HF5Q0410@01UIFD0
NWYj05EEE@1NGUh0?Cdm03Ti>@1<C4`0AdM705YJFP1OGel0Kfm_07AdM01:BTX0ATI604E5A@0Y:BT0
=SHf03De=@19BDT0B4Q8034a<@1BDU80?Shn04e=C@18B4P0C4a<04i>CP1?Cdl0B4Q803hn?P0e=CD0
>SXj04Q8B00m?Cd0AdM705EEE@17AdL0=SHf04i>CP1?Cdl00P14A4@08P1>CTh0?Shn03Ti>@17AdL0
?Shn04M7A`1;Bd/0?Shn03Xj>P0K6a/0<30`01PH600V9RH0=3@d01HF5P0[:b/0?3`l03De=@0b<S80
D51@04I6AP0f=SH0:BTY03`l?00Z:RX0?Shn03<c<`0i>CT0:b/[04E5A@0[:b/0=3@d01TI6@3oool6
0=WIf@4000000@3IfMT001H0fMWI0P0000040=WIf@0:0?ooo`2=SHd0PH61092@T02DU9@0RXZ:07Ad
M026QXH0SHf=08>3P`80Shn?03h0RXZ:09jNWP2BTY80XZ:R08j>SP2GUiL0WIfM09nOW`2PX:00/K6a
0:^[Z`2?Shl0TI6A09NGU`1oOgl0ZZZZ09jNWP2^[Zh0VIVI08f=S@2GUiL0Z:RX0;Fe]@2g]kL0^[Zj
0:JVYP2][Jd0[Zj^0;Jf]P2a/K40S8b<0:n_[`2YZJT0WYjN0;:b/P2d];@0aLG50;2`/02RXZ80VIVI
0:j^[P2=SHd0[Jf]08j>SP2TY:@0Z:RX0:BTY02HV9P0TY:B0;2`/02QXJ40ZZZZ0:>SX`2YZJT0Ti>C
09nOW`1lO7`0Y:BT0:VYZ@2^[Zh0UIFE0:VYZ@80[Zj^0100VYZJ0:FUY@2MWId0Xj>S09NGU`2SXj<0
SHf=08^;R`1kNg/0QhN709^KV`2?Shl0QXJ607inOP23Ph<0QhN70P1nOWh209NGU`0608R8R02YZJT0
SHf=0:FUY@2SXj<0Vi^K0P2NWYh0502QXJ40TY:B08Z:RP2XZ:P0[Jf]09jNWP2][Jd0YZJV08R8R02b
/[80ZJVY09:BTP2OWil0_;bl0:^[Z`2ATI40YZJV09jNWP2LW9`0R8R80P2KVi/0H@2ZZZX0WIfM0:RX
Z026QXH0S8b<08f=S@2IVIT0UiNG09bLW02NWYh0UiNG06QXJ01oOgl0MgMg0820P01mOGd0J6QX07Ui
N@2@T900SXj>09NGU`1jNWX0Rh^;08j>SP1/K6`0PH6108>3P`28R8P0Lg=c07IfMP1oOgl0RXZ:07If
MP1oOgl0QhN707]kN`2>SXh0Q8B407inOP1kNg/0RXZ:06e]K@23Ph<0RXZ:0861P@22PX80LW9b07Yj
NP2:RXX0LG5a08N7Q`1IFET0RXZ:05QHF02>SXh0QHF506MWI`1aLG40MgMg06QXJ02>SXh0OGem07Qh
N01jNWX0KVi^08:2PP1YJFT0Lg=c079bLP1eMGD0M7Ad07alO01[Jf/0FEUI079bLP1cLg<0O7al071`
L01RHV80Lg=c08:2PP1`L700I6AT069RHP1ZJVX0Lg=c0861P@1/K6`0Lg=c07AdM01YJFT0KVi^05YJ
FP1]KFd0LW9b061PH01GEeL00P1KFe/0F@1RHV80OGem06YZJP1@D500HF5Q06a/K01VIVH0LG5a06i^
KP0i>CT0EUIF04e=C@1FEUH0B4Q805YJFP13@d<0?3`l03Xj>P18B4P0?clo04Q8B01[Jf/0ADE505YJ
FP1BDU80C4a<03lo?`000000>CTi04I6AP0a<C40CTi>051@D00g=cL0@T9204A4A00g=cL0AdM7038b
<P0c<c<0B4Q803lo?`0g=cL0?3`l0410@00b<S80C4a<038b<P1PH600@D5104E5A@0m?Cd0E5AD0410
@014A4@0@T9204Y:BP0i>CT0DE5A04a<C00];Bd0=3@d03Ti>@0000006QXJ018B4P0I6AT07alO024Q
8@0P8200=SHf02l_;`0[:b/0=3@d03/k>`0b<S80:BTY03/k>`0a<C40:b/[02PX:00U9BD0:2PX03Xj
>P0U9BD071`L00d=3@0I6AT0oooo00D0fMWI0P0000010=WIf@005P3IfMT00`000000fMWI0=WIf@03
0=WIf@090?ooo`2ATI40UIFE07moO`1kNg/0MWIf079bLP1ZJVX0J6QX0080O7al02l0I6AT09ZJVP2F
UYH0TY:B09FEU@2WYjL0S8b<0:j^[P2SXj<0R8R809fMW@2LW9`0WYjN0:ZZZP29RHT0XJ6Q08b<S02K
Vi/0YZJV09^KV`2MWId0ZJVY08N7Q`2LW9`0SXj>0:b/[02DU9@0YZJV07emO@27QhL0Y:BT0:2PX030
`<00`l?309^KV`2TY:@0W9bL09fMW@2][Jd0UiNG09bLW02NWYh0[jn_08J6QP2JVYX0bl_;0:>SX`02
0:NWY`0E0:ZZZP2DU9@0Q8B408^;R`2QXJ40^k^k09fMW@2OWil0^[Zj0;Vi^@2YZJT0W9bL0;:b/P2W
YjL0XZ:R09^KV`2MWId0WinO09BDU02ZZZX0XJ6Q0080WinO0200O7al08V9R@2NWYh0RHV908R8R02B
TY80WYjN09^KV`2LW9`0PH6109RHV02YZJT0YJFU09fMW@2KVi/0/k>c09NGU`2IVIT0ZZZZ0:NWY`2Z
ZZX0^[Zj09nOW`2@T900^[Zj08R8R02WYjL0Ti>C09RHV02QXJ40WinO0::RXP80YjNW01@0bLW908n?
S`2NWYh0]kNg0:VYZ@2k^k/0[Zj^0:FUY@27QhL0W9bL08Z:RP2OWil0Ti>C09fMW@29RHT0QXJ609FE
U@20P800L71`08V9R@80T92@00<0Ph>308F5Q@26QXH00P1oOgl05`26QXH0Ng]k06UYJ@2:RXX0QHF5
07UiN@20P800RHV908f=S@2>SXh0Shn?09nOW`2BTY80Shn?09RHV02PX:00Ti>C08f=S@1mOGd0O7al
08^;R`2:RXX0Shn?0080NGUi02<0Kfm_07AdM02DU9@0J6QX06a/K02DU9@0KFe]07inOP2EUID0QhN7
0820P01lO7`0LG5a07UiN@22PX80MWIf07QhN01gMgL0GEeM07alO024Q8@0OWin07IfMP21PH40NWYj
05EEE@28R8P0EeMG05mOG`25QHD0Kfm_07EeM@1XJ6P0MGEe08B4Q00206m_K`1306MWI`1oOgl0LG5a
06IVIP2:RXX0MGEe07YjNP1iNGT0KVi^06e]K@1TI6@0N7Qh061PH01QHF40GemO07EeM@1aLG40MGEe
079bLP1XJ6P0JFUY06a/K01BDU80CDe=05YJFP1>CTh0GemO07AdM01RHV80GUiN061PH01NGUh0FEUI
05EEE@1IFET0CTi>03Hf=P0n?Sh0<c<c02l_;`1ADE40EeMG065QH@0i>CT0H61P03De=@0o?cl09RHV
024Q8@0j>SX0@41004=3@`1<C4`0?Shn04e=C@1;Bd/0>CTi03Hf=P16ATH092@T04I6AP0f=SH0:RXZ
03Ti>@1HF5P0=CDe03Ph>00204a<C00K03dm?@14A4@0CDe=02h^;P0/;2`09bLW04];B`1<C4`0?3`l
03Xj>P0f=SH0J6QX02@T900O7al03`l?018B4P0U9BD08b<S01lO7`0U9BD01PH604U9B@0k>c/0=3@d
04=3@`0M7Ad0AdM70080:2PX00X0>c/k02HV9P0a<C40:b/[01XJ6P0M7Ad0?3`l034a<@0K6a/0oooo
1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI04d0oooo09JFUP2HV9P0S8b<
07MgM`1dM7@0EeMG07moO`1`L700UiNG0861P@1fMWH0U9BD08>3P`2NWYh0SXj>07QhN02FUYH0WIfM
092@T02LW9`0TI6A08:2PP1gMgL0VYZJ096AT@2EUID0X:2P08R8R02RXZ80^k^k07UiN@2RXZ80W9bL
0;Jf]P2VYZH0]KFe0:^[Z`2QXJ40ZJVY08>3P`2WYjL0XJ6Q09nOW`2IVIT0[Zj^09bLW02l_;`0VYZJ
0;Ng]`2KVi/0Xj>S09JFUP2WYjL0U9BD0;Fe]@2QXJ40[Zj^0;2`/02QXJ40V9RH09nOW`2f][H0^[Zj
09JFUP2PX:00YjNW0:n_[`2TY:@0`<300:j^[P2][Jd0Xj>S0;Zj^P2JVYX0[Jf]09RHV0020:JVYP0g
09^KV`2/[:`0XZ:R0;6a/@2FUYH0Vi^K08N7Q`2RXZ80UiNG08N7Q`2MWId0U9BD0:ZZZP2GUiL0V9RH
09NGU`2=SHd0]KFe0;fm_@2:RXX0SHf=0:j^[P2QXJ40/[:b09VIV@2l_;`0Ti>C0;fm_@24Q8@0WIfM
09^KV`2FUYH0[jn_0:j^[P2HV9P0U9BD0:n_[`2MWId0UYJF0:VYZ@2IVIT0QXJ60;2`/02YZJT0];Bd
09:BTP2PX:00Xj>S08b<S02?Shl0TY:B09>CT`2?Shl0WinO092@T00208j>SP0307inOP2<S8`0M7Ad
0080SXj>01H0WIfM06i^KP1QHF40Kfm_09>CT`2FUYH0T92@08>3P`1mOGd0QHF5071`L01eMGD0LW9b
06YZJP2>SXh0TI6A08F5Q@1nOWh0PH6107UiN@2NWYh0QHF50`2@T9000`2=SHd0TI6A08N7Q`0208V9
R@2?08F5Q@1hN7P0R8R808F5Q@23Ph<0LW9b07moO`2IVIT0OWin06EUI@1MGEd0IfMW07emO@1jNWX0
Jf][07emO@21PH40L71`07=cL`2;Rh/0NGUi06QXJ01IFET0Lg=c04E5A@1lO7`0H61P08:2PP1XJ6P0
K6a/07YjNP1ZJVX0Kfm_07QhN01`L700NWYj061PH01hN7P0BDU9069RHP1eMGD0KFe]07IfMP1KFe/0
GEeM04m?C`1ZJVX0FUYJ06][J`1iNGT0JVYZ06QXJ01RHV80FUYJ05aLG01]KFd0OWin075aL@1QHF40
EEEE06ATI01/K6`0LG5a05aLG01WIfL0DU9B05aLG01[Jf/0EEEE05]KF`1QHF40B4Q804E5A@0f=SH0
<c<c02HV9P0/;2`0ATI602l_;`0h>3P0:RXZ02@T900c<c<0@41004A4A01GEeL0HV9R04I6AP1<C4`0
51@D04M7A`0P8200CTi>04A4A00k>c/0C4a<04e=C@1NGUh0EUIF04Y:BP0m?Cd0@41003`l?00h>3P0
B4Q802/[:`11@D40AdM70451@@0Z:RX0>c/k01HF5P11@D40=SHf03Lg=`0c<c<0ATI603@d=00C4a<0
5QHF01`L700Z:RX07AdM01HF5P0f=SH00000010@400g=cL05QHF02PX:00g=cL0@d=303Xj>P0g=cL0
E5AD04a<C00Z:RX0<30`024Q8@0e=CD0;2`/02LW9`3oool01P3IfMT100000040fMWI000F0=WIf@03
0000003IfMT0fMWI00<0fMWI01d0oooo08n?S`2@T900PX:2092@T01gMgL0OGem06e]K@1kNg/0OWin
09RHV028R8P0Rh^;06YZJP2DU9@0RXZ:09nOW`2EUID0]KFe09^KV`2EUID0/[:b08f=S@2?Shl0NWYj
0:BTY02ATI40/[:b0:b/[00209jNWP1D09bLW02QXJ40Z:RX096AT@2][Jd0b<S809nOW`2EUID0/;2`
09nOW`2@T900/;2`0<K6aP2_[jl0XJ6Q0:f][@2`/;00UYJF0:NWY`2CTi<0WYjN0:FUY@2_[jl0]KFe
0:NWY`2/[:`0ZJVY0:2PX02ATI40^k^k09^KV`2QXJ40WYjN09bLW02JVYX0YjNW08b<S02JVYX0WIfM
09bLW02_[jl0UYJF09NGU`2IVIT0YZJV08f=S@2][Jd0WYjN0:VYZ@2_[jl0WYjN09fMW@2LW9`0Ti>C
09FEU@2UYJD0LW9b08b<S02@T900P82009JFUP2EUID0TI6A09bLW02IVIT0Y:BT0:b/[02d];@0UYJF
0:6QX@2^[Zh0X:2P0:RXZ02:RXX0UIFE0:JVYP2HV9P0XZ:R09FEU@2GUiL0VYZJ0:f][@2PX:00Y:BT
0P2WYjL05@2TY:@0/;2`0:j^[P2`/;00/K6a0:2PX02NWYh0/K6a09JFUP27QhL0TY:B08b<S020P800
QHF509:BTP2RXZ80UiNG07=cL`2IVIT0SHf=08V9R@0208:2PP1<08J6QP2<S8`0Lg=c07moO`2CTi<0
RXZ:06][J`2IVIT0Ti>C08j>SP29RHT0TY:B09BDU02:RXX0Shn?09^KV`2PX:00SXj>08J6QP21PH40
SHf=08F5Q@2@T900PX:2075aL@1dM7@0QXJ609JFUP20P800Ng]k06YZJP1mOGd0PX:207]kN`1cLg<0
NGUi07EeM@20P800N7Qh07]kN`21PH40CTi>08f=S@1_Kfl0N7Qh0861P@1eMGD0Lg=c0820P01_Kfl0
RXZ:07EeM@1fMWH0MgMg06m_K`1VIVH0JVYZ07QhN015ADD0OWin071`L01DE5@0MWIf075aL@1`L700
IVIV07UiN@1XJ6P0O7al0861P@1MGEd0MWIf0820P01BDU80MWIf069RHP80JVYZ0600Jf][05eMG@1e
MGD0GEeM059BDP1OGel0E5AD06QXJ01FEUH0KVi^06QXJ01]KFd0OWin06a/K01^KVh0FUYJ06UYJ@24
Q8@0GUiN07MgM`1/K6`0BDU9065QH@1HF5P0;Bd]0451@@1CDe<0>CTi02HV9P0S8b<08R8R01dM7@0^
;Rh0;Bd]01hN7P0l?3`0;2`/038b<P18B4P0CTi>03De=@0b<S80?clo04Y:BP14A4@0<c<c03Lg=`1>
CTh0@d=3055AD@0h>3P0=CDe03<c<`15ADD0>SXj055AD@13@d<0BDU902d];@0`<300ADE50451@@0b
<S80EUIF04e=C@0g=cL0BDU901XJ6P10@400=3@d03hn?P0O7al0:BTY028R8P0f=SH0@D5101PH600e
=CD04Q8B03@d=00Y:BT09RHV03Lg=`0H61P0<c<c028R8P0^;Rh0=CDe0410@00O7al0BTY:030`<00Q
8B40=CDe01TI6@3oool60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0:P3o
ool0R8R808B4Q02:RXX0S8b<08J6QP20P800Rh^;08j>SP2=SHd0WYjN0:2PX01_Kfl0T92@0:2PX01h
N7P0SHf=08N7Q`28R8P0WYjN08n?S`2LW9`0ZZZZ08V9R@2SXj<0UIFE0:n_[`2c/k<0Ng]k08j>SP2G
UiL0XJ6Q0:^[Z`2NWYh0V9RH08Z:RP2YZJT0aLG50:b/[02KVi/0U9BD0:RXZ080UYJF00d0^;Rh0:j^
[P2_[jl0YjNW09JFUP2ZZZX0]kNg0:^[Z`2OWil0Vi^K0:NWY`2HV9P0Xj>S0080YZJV0;40_[jn09ZJ
VP2/[:`0YZJV0::RXP26QXH0O7al0:j^[P2[Zj/0UiNG0;:b/P2h^;P0ZZZZ0:^[Z`2d];@0WIfM08J6
QP2TY:@0Vi^K0:FUY@2=SHd0Y:BT0;6a/@2/[:`0S8b<09bLW026QXH0WIfM08j>SP2VYZH0T92@09jN
WP2ZZZX0NWYj0:6QX@2VYZH0Rh^;0;2`/02PX:00WinO0;Jf]P2NWYh0Y:BT0;Bd]02b/[80UiNG0:j^
[P2i^KT0XZ:R0:JVYP2EUID0[Zj^0:f][@2VYZH0WinO09jNWP2LW9`0TY:B0:JVYP2l_;`0ZJVY0:b/
[02IVIT0YJFU09^KV`2NWYh0XZ:R08b<S02OWil0UiNG09RHV02GUiL0HF5Q09jNWP2JVYX0S8b<0:VY
Z@2GUiL0RXZ:08B4Q01mOGd0O7al075aL@1/K6`0JFUY06MWI`1aLG40Ph>306IVIP1;Bd/0Jf][09BD
U02;Rh/0MGEe07emO@24Q8@0QHF508B4Q02BTY80OGem09nOW`29RHT0UIFE08N7Q`29RHT0KFe]096A
T@1oOgl0QXJ608N7Q`1jNWX0QHF50820P01jNWX0LW9b075aL@20P800OGem05QHF020P800LW9b08:2
PP1eMGD0Ph>307inOP1dM7@0N7Qh059BDP1aLG40NGUi08J6QP1fMWH0Lg=c07IfMP1GEeL0MGEe06UY
J@1kNg/0K6a/04i>CP1_Kfl0MgMg05iNGP28R8P0MgMg07]kN`1hN7P0Ogmo06QXJ01NGUh0J6QX06YZ
JP1eMGD0JVYZ065QH@2=SHd0FUYJ071`L01CDe<0F5QH079bLP1aLG40FEUI06i^KP1PH600E5AD06=S
H`1:BTX0IVIV07AdM017AdL0Hf=S06e]K@1TI6@0GUiN06QXJ01/K6`00P1_Kfl01`1IFET0Kfm_05QH
F01NGUh0FEUI03lo?`12@T800P0W9bL01`0m?Cd0>SXj02<S8`0W9bL09BDU020P8017AdL00P10@400
200n?Sh0?clo03De=@0m?Cd0@T9204=3@`1GEeL0AdM70P13@d<0<00/;2`0?3`l0451@@0^;Rh0B4Q8
0492@P0K6a/0@D5105=CD`13@d<0;2`/02d];@0A4A40=CDe0410@01@D500=3@d04A4A00j>SX0:BTY
01/K6`0:2PX0>CTi01hN7P0@4100=CDe020P800T92@0@D51020P800g=cL03Ph>02LW9`0>3Ph0CTi>
03@d=00i>CT0Cdm?02HV9P0O7al0:BTY02l_;`0U9BD0:2PX04Y:BP0T92@0>3Ph0?ooo`H0fMWI0@00
00010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0o0?ooo`2>SXh0QHF507EeM@20P800PX:2
07inOP27QhL0S8b<07IfMP2BTY80IfMW08F5Q@1bLW80QhN708f=S@1lO7`0UYJF08Z:RP2BTY80XJ6Q
0:>SX`2FUYH0Shn?0:JVYP2RXZ80ZJVY0:>SX`2>SXh0UiNG08B4Q02VYZH0UiNG08^;R`2MWId0R8R8
0:>SX`26QXH0Y:BT0;Bd]02HV9P0Y:BT0;>c/`2TY:@0V9RH09jNWP2ZZZX0V9RH0820P02][Jd0XJ6Q
09RHV02m_Kd0WYjN0:n_[`2][Jd0XJ6Q0:FUY@2:RXX0YjNW0;6a/@2i^KT0[Jf]0080[:b/08h0TI6A
09VIV@2o_kl0/K6a0;Fe]@2c/k<0SHf=0:NWY`2BTY80XZ:R0:RXZ02f][H0WIfM09BDU02LW9`0YjNW
09jNWP2MWId0W9bL08f=S@2e]KD0Y:BT0:FUY@2JVYX0RXZ:09fMW@2][Jd0S8b<0:FUY@2EUID0WYjN
0:n_[`2EUID0VIVI0:^[Z`2KVi/0aLG50;Zj^P2g]kL0XJ6Q09FEU@2_[jl0SHf=08Z:RP2NWYh0XZ:R
0:RXZ02][Jd0YZJV0::RXP2g]kL0XJ6Q0:^[Z`2QXJ40WIfM0:RXZ02/[:`0ZZZZ0;2`/02IVIT0YZJV
08R8R02@T900[Zj^08^;R`2FUYH0W9bL096AT@2BTY80CDe=07alO02ATI40Shn?0820P01[Jf/0?clo
03Ph>00P82005ADE00h>3P00000030`<00/;2`0g=cL09RHV059BDP1FEUH0M7Ad08>3P`1`L700MgMg
08R8R02<S8`0W9bL08R8R01lO7`0R8R808Z:RP2;Rh/0LW9b071`L02KVi/0MGEe07AdM02BTY80Ph>3
07YjNP22PX80UYJF08>3P`2CTi<0Jf][07=cL`2<S8`0OWin07UiN@24Q8@0QXJ608N7Q`1_Kfl0JFUY
061PH01hN7P0NWYj06e]K@1=CDd0J6QX07emO@2=SHd0OWin08Z:RP1lO7`0NGUi06e]K@1RHV80H61P
07IfMP1YJFT0De=C07moO`1SHf<0J6QX0P1/K6`0BP1eMGD0GUiN071`L01[Jf/0H61P06=SH`1/K6`0
GUiN065QH@1NGUh0J6QX06YZJP1EEED0FEUI06IVIP1SHf<0LG5a065QH@1_Kfl0I6AT05IFEP1/K6`0
Ogmo05IFEP1TI6@0IFEU05=CD`20P800JFUY08:2PP1LG5`0IFEU05aLG01GEeL0Bd];05ADE00o?cl0
EUIF02HV9P0a<C40@D5104Q8B014A4@0;2`/03Lg=`1WIfL0C4a<03/k>`0^;Rh0Hf=S04A4A00e=CD0
>CTi04I6AP0f=SH0<S8b034a<@1HF5P0=SHf03dm?@10@400>3Ph03<c<`0k>c/0?Cdm04Q8B014A4@0
BTY:030`<00_;bl0?Cdm030`<017AdL09BDU0P0b<S807@0c<c<0;Rh^034a<@10@4005ADE01HF5P0@
4100A4A403@d=00/;2`061PH03De=@0Y:BT061PH01dM7@0^;Rh0:b/[02`/;00_;bl0=SHf02/[:`0/
;2`0=3@d01lO7`0m?Cd06a/K00d=3@0];Bd0oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000
fMWI0=WIf@030=WIf@1?0?ooo`2NWYh0S8b<0820P01oOgl0N7Qh09RHV024Q8@0UiNG08^;R`22PX80
TY:B08>3P`26QXH0SHf=08Z:RP2ATI40UIFE09:BTP2FUYH0T92@09ZJVP2YZJT0Ti>C0:BTY02VYZH0
[Zj^09BDU02VYZH0WYjN0:BTY02b/[80]kNg09VIV@2UYJD0Ti>C0:NWY`2MWId0W9bL0;^k^`2OWil0
VYZJ0:NWY`2HV9P0Z:RX0:b/[035aLD0ZZZZ0:b/[02EUID0XJ6Q0:b/[02DU9@0UYJF09jNWP2CTi<0
X:2P0::RXP2HV9P0WYjN0:RXZ02g]kL0T92@09VIV@2JVYX0];Bd09fMW@2PX:00UIFE0:VYZ@2LW9`0
VYZJ0:RXZ02l_;`0Ogmo0;:b/P2SXj<0ZJVY0;Bd]0020:BTY0090820P02PX:00V9RH09fMW@2NWYh0
Xj>S0;>c/`2OWil0W9bL0080/K6a0200`L710<C4a02a/K40U9BD0:2PX02b/[80/;2`09NGU`2m_Kd0
]KFe0;Bd]02_[jl0]KFe0:VYZ@2QXJ40YjNW08Z:RP2CTi<0UIFE09VIV@2NWYh0UiNG0:FUY@2GUiL0
X:2P0:f][@2LW9`0VIVI08N7Q`2JVYX0Vi^K08n?S`80WinO0180Ng]k06m_K`2:RXX0W9bL09BDU01j
NWX0U9BD06i^KP2CTi<0Rh^;07IfMP1[Jf/0EUIF03Ti>@0b<S80:2PX000000020P840000000400/;
2`0`<300>c/k05IFEP80K6a/02h0H61P08N7Q`2ATI40Shn?08Z:RP20P800R8R808N7Q`26QXH0N7Qh
08B4Q01`L700OWin08F5Q@1aLG40UYJF092@T023Ph<0O7al07emO@1kNg/0NGUi08>3P`1oOgl0N7Qh
08F5Q@22PX80Kfm_08Z:RP2IVIT0TI6A09ZJVP2;Rh/0MgMg07UiN@1eMGD0HV9R079bLP1eMGD0KVi^
08F5Q@20P800LW9b07]kN`1^KVh0Lg=c0P1VIVH03@1hN7P0Hf=S07EeM@1iNGT0J6QX075aL@1`L700
GUiN05ADE014A4@0L71`05YJFP1XJ6P00P1cLg<0>`1SHf<0HF5Q065QH@1[Jf/0MGEe06ATI01ADE40
Kfm_07EeM@1aLG40KFe]06m_K`1MGEd0KFe]055AD@1dM7@0IfMW06e]K@1PH600FEUI065QH@1?Cdl0
FEUI05MGE`1RHV80K6a/061PH014A4@0DE5A059BDP19BDT0>CTi0410@00X:2P0ATI60492@P0i>CT0
@4100451@@12@T80?Cdm0410@01;Bd/0=3@d0451@@0a<C40ADE50451@@1?Cdl0EEEE0451@@0l?3`0
AdM702PX:00`<300;2`/038b<P10@400=SHf0080?Shn02@0=CDe03Xj>P0m?Cd0@41003Xj>P0h>3P0
>c/k03<c<`0g=cL0=CDe02/[:`0R8R80:b/[024Q8@0j>SX0=cLg01dM7@0W9bL0;bl_02`/;00[:b/0
=3@d034a<@10@400=SHf01@D500S8b<09bLW02HV9P0d=3@0820P03<c<`0D51@00P8201hN7P3oool6
0=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT02@3oool0R8R807=cL`2DU9@0
Ti>C08b<S01cLg<0Vi^K08:2PP02071`L00A09>CT`2?Shl0OWin0820P01`L700VYZJ09>CT`28R8P0
PH6109nOW`2:RXX0WYjN0:RXZ02f][H0WinO09fMW@2>SXh00P2/[:`03`2EUID0RXZ:0:j^[P2@T900
YjNW0:>SX`2OWil0`/;20;:b/P2JVYX0][Jf0:2PX02][Jd0aLG509JFUP020:BTY00O0:j^[P2/[:`0
YZJV0:f][@2`/;00X:2P08f=S@2@T900WYjN09JFUP2DU9@0WYjN0:2PX02a/K40[:b/09fMW@2<S8`0
[Zj^0;Vi^@27QhL0RXZ:0:FUY@2GUiL0R8R80:b/[02ATI40UIFE09bLW02n_[h0[Zj^09:BTP020:JV
YP030:>SX`2CTi<0Zj^[0080UiNG0180^;Rh0:JVYP2^[Zh0VIVI07moO`2NWYh0U9BD0:VYZ@2GUiL0
/K6a0:6QX@22PX80ZJVY0:>SX`2ATI40PH6109RHV02XZ:P20:2PX00S09RHV02OWil0SXj>08b<S02[
Zj/0RHV909NGU`1oOgl0VIVI0:f][@2WYjL0W9bL096AT@2FUYH0WYjN09JFUP28R8P0[Jf]0:FUY@2H
V9P0XZ:R0;Bd]02UYJD0QHF50:>SX`2JVYX0WYjN08b<S025QHD0Rh^;07]kN`1SHf<0JVYZ03De=@0^
;Rh02`000000200X:2P0@D5105aLG01WIfL0HV9R07emO@2?Shl0Ogmo0P1lO7`0<P1bLW80Ng]k06m_
K`1HF5P0OWin07moO`1^KVh0Ph>308R8R01kNg/0Ph>306i^KP1jNWX0Shn?06QXJ01[Jf/0MGEe075a
L@1eMGD0Jf][07AdM01iNGT0RXZ:07IfMP20P800GUiN07QhN01iNGT0KFe]07]kN`1gMgL0Kfm_06EU
I@1hN7P0NWYj08V9R@1bLW80KFe]07YjNP1aLG40De=C07QhN01kNg/0O7al05=CD`1XJ6P0G5aL06i^
KP1GEeL0GEeM0P1FEUH206UYJ@80IVIV00d0FEUI07QhN01KFe/0H61P07=cL`1/K6`0PX:206][J`1a
LG40GUiN075aL@1NGUh0LG5a0080JFUY0580HV9R06m_K`1OGel0MGEe061PH01>CTh0Jf][06ATI01U
IFD0EUIF06m_K`1FEUH0D51@03hn?P1=CDd0EeMG04i>CP1MGEd01@D504e=C@0d=3@0@D5104Q8B017
AdL0FUYJ05IFEP12@T80ATI605=CD`10@400A4A405IFEP0_;bl0?Cdm05MGE`1HF5P0FUYJ04A4A00_
;bl0?Shn03dm?@0/;2`0DU9B04I6AP0@4100De=C030`<00g=cL0;2`/03@d=014A4@0<S8b0492@P0d
=3@09RHV030`<00O7al00000028R8P0e=CD08B4Q01<C4`0Y:BT05QHF00l?3`13@d<0?Cdm01`L700h
>3P05QHF02`/;00n?Sh071`L02h^;P12@T80<30`018B4P0e=CD09RHV02@T900M7Ad0oooo1P3IfMT1
00000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0580oooo07UiN@1lO7`0RXZ:07=cL`2?
Shl0PH6106UYJ@24Q8@0Kfm_07UiN@20P800N7Qh08^;R`28R8P0Ti>C09fMW@28R8P0O7al09:BTP2;
Rh/0YZJV0:>SX`20P800/K6a09JFUP2;Rh/0S8b<0:JVYP2MWId0Y:BT08^;R`2`/;00YZJV09BDU029
RHT0ZJVY0::RXP2l_;`0WinO0:f][@2IVIT0XZ:R0:2PX02[Zj/0QXJ60:FUY@2?Shl0S8b<0:n_[`2U
YJD0]kNg0:RXZ02SXj<0WinO09JFUP2ZZZX0^[Zj0:f][@1kNg/0^k^k09FEU@2/[:`0/K6a0;Rh^02T
Y:@0UYJF0:2PX02NWYh0V9RH0:2PX02MWId0WinO09bLW02QXJ40Vi^K0:6QX@2VYZH0RHV909>CT`2o
_kl0Y:BT0P2VYZH09P2k^k/0RHV90;Bd]02CTi<0WYjN0:b/[02UYJD0XJ6Q09ZJVP2SXj<0X:2P09nO
W`2][Jd0[jn_0;>c/`2n_[h0Z:RX0:JVYP2IVIT0YJFU0::RXP2ZZZX0_[jn0<71`@2WYjL0XZ:R0:6Q
X@2WYjL0VIVI08j>SP2HV9P0VIVI09jNWP21PH40W9bL09fMW@2RXZ80S8b<0P2BTY80402KVi/0Z:RX
09jNWP2JVYX0R8R808:2PP2BTY80WinO09jNWP1`L700PH6107QhN01dM7@0CTi>02TY:@0F5QH;0000
001400P8200@4100DE5A05UIF@1gMgL0P820079bLP2FUYH0QHF507]kN`1]KFd0QXJ607UiN@1?Cdl0
K6a/08N7Q`2?Shl0N7Qh08B4Q01dM7@0Shn?08V9R@27QhL0LG5a07inOP2<S8`0M7Ad079bLP1kNg/0
Shn?08j>SP27QhL0OGem07alO01gMgL0Ph>308B4Q01dM7@0KFe]06QXJ01^KVh0MGEe08B4Q01gMgL0
QHF505IFEP1VIVH0H61P05YJFP1]KFd0CTi>07UiN@21PH40MWIf06MWI`1GEeL0JFUY05EEE@1RHV80
IVIV05QHF01CDe<0ADE506MWI`1eMGD0I6AT07alO01iNGT206IVIP0705YJFP1SHf<0K6a/069RHP1M
GEd0L71`06a/K00206QXJ00H07=cL`13@d<0KVi^069RHP1DE5@0HV9R055AD@1kNg/0GEeM069RHP1I
FET0F5QH059BDP1FEUH0=CDe059BDP13@d<0CTi>04e=C@1VIVH0:2PX055AD@13@d<0>CTi0P1BDU80
>P19BDT0HV9R04m?C`13@d<0>3Ph04=3@`0W9bL0A4A404E5A@10@400ATI6038b<P0Q8B408b<S0492
@P0l?3`0DE5A03<c<`12@T80C4a<04I6AP0h>3P0Bd];0410@011@D40;Bd]02l_;`10@400?clo03`l
?011@D40<c<c01HF5P0W9bL05aLG018B4P0I6AT06a/K00/;2`030`<07QhN02`/;00b<S80=cLg03Ti
>@0_;bl08b<S028R8P19BDT0:b/[01@D5013@d<0:2PX02DU9@0];Bd0<S8b02DU9@3oool60=WIf@40
00000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0;03oool0Lg=c09>CT`1lO7`0Ogmo07=c
L`1]KFd0NGUi07YjNP1dM7@0NGUi096AT@25QHD0VIVI08B4Q01SHf<0KVi^08j>SP2FUYH0RHV908j>
SP29RHT0UYJF08n?S`2SXj<0QhN709ZJVP2@T900WinO08b<S02NWYh0YZJV0;:b/P2ZZZX0Ti>C0::R
XP2?Shl0YJFU0:n_[`2YZJT0QhN70;:b/P2HV9P0[Jf]0P2d];@0;02[Zj/0Xj>S0;:b/P2/[:`0[Zj^
09nOW`2YZJT0^;Rh09fMW@2OWil0Vi^K0:NWY`2ZZZX0Zj^[09jNWP2SXj<0XZ:R0:n_[`2^[Zh0TY:B
09fMW@2WYjL0VYZJ0:f][@2KVi/0U9BD09JFUP2WYjL0WIfM0:JVYP2MWId0YJFU0:RXZ02`/;00T92@
09VIV@2UYJD0[jn_0::RXP2JVYX0XJ6Q09ZJVP2f][H0X:2P0P2`/;000`2JVYX0[Jf]0:NWY`0209RH
V080YJFU02P0Xj>S0<W9b@34a<@0U9BD08n?S`2VYZH0RHV909RHV02SXj<0TI6A09RHV027QhL0SXj>
0:6QX@2KVi/0U9BD0:^[Z`2VYZH0U9BD08j>SP2^[Zh0X:2P096AT@2BTY80WYjN09>CT`2LW9`0[Zj^
09BDU02ATI40PX:208B4Q02/[:`0RHV90861P@23Ph<0NWYj04E5A@0g=cL03@d=3P0000004012@T80
<S8b06MWI`1UIFD0Ng]k08B4Q020P800Kfm_06IVIP1fMWH0Lg=c05aLG02?Shl0Ph>308N7Q`29RHT2
07inOP0U0820P01aLG40L71`08B4Q01RHV80OGem06m_K`1kNg/0MWIf07MgM`25QHD0NWYj07EeM@1g
MgL0J6QX08^;R`2:RXX0IFEU069RHP1UIFD0QXJ606a/K01OGel0MWIf08F5Q@1[Jf/0GUiN07IfMP0S
8b<0FUYJ06QXJ01CDe<0HF5Q06YZJP1XJ6P0M7Ad06=SH`02065QH@0507IfMP1hN7P0GemO05UIF@1H
F5P00P1WIfL09@1QHF40GUiN07]kN`1ZJVX0E5AD06ATI01DE5@0GUiN06IVIP19BDT0@d=306][J`1L
G5`0IVIV06MWI`1JFUX0Fe]K0820P01UIFD0EUIF05aLG019BDT0HF5Q069RHP14A4@0GEeM055AD@12
@T80I6AT051@D0000000@D5105=CD`15ADD0>CTi0451@@0^;Rh00P18B4P06P0m?Cd0CTi>04Q8B01>
CTh0DE5A01dM7@0k>c/0=3@d03dm?@1?Cdl0<30`03lo?`0n?Sh0E5AD03@d=00[:b/0>SXj03Lg=`0Z
:RX0>3Ph02h^;P12@T80=CDe03Ti>@0k>c/0<S8b0P0n?Sh07P0Z:RX06ATI02XZ:P0K6a/0Cdm?01HF
5P0Q8B407alO01DE5@0Y:BT0:2PX02l_;`0Z:RX04Q8B03Ph>00N7Qh0>c/k0000000/;2`0<S8b014A
4@0^;Rh08R8R01<C4`0:2PX0>c/k02LW9`0O7al051@D0?ooo`H0fMWI0@0000010=WIf@005P3IfMT0
0`000000fMWI0=WIf@030=WIf@0L0?ooo`21PH40VYZJ08R8R027QhL0R8R808Z:RP20P800Q8B408^;
R`26QXH0NGUi07moO`25QHD0OWin08B4Q020P800R8R809VIV@2EUID0Rh^;09FEU@2:RXX0TY:B09jN
WP2FUYH0QHF508J6QP80X:2P03T0[Jf]09NGU`1mOGd0WYjN0:2PX02DU9@0V9RH0:FUY@2ZZZX0RHV9
09RHV02KVi/0U9BD09FEU@2QXJ40UiNG09>CT`2SXj<0Rh^;0:FUY@2EUID0YZJV09FEU@2QXJ40UiNG
0:f][@2UYJD0X:2P0:ZZZP2YZJT0Y:BT0;Fe]@2PX:00YjNW08R8R02f][H0VYZJ09FEU@28R8P0[Zj^
09nOW`2?Shl0VYZJ0:2PX02BTY80UiNG09:BTP2UYJD0RXZ:0:6QX@2RXZ80Ti>C0;Bd]02/[:`0YjNW
0;2`/02g]kL00P2b/[8209fMW@0`09>CT`29RHT0WIfM0:6QX@2][Jd0Y:BT0;Rh^02d];@0Ti>C09VI
V@29RHT0/k>c092@T02HV9P0YjNW09VIV@2QXJ40Xj>S09FEU@2^[Zh0UIFE09ZJVP2/[:`0TY:B0:NW
Y`2n_[h0a<C40:^[Z`2a/K40WIfM09VIV@2CTi<0TI6A08V9R@2GUiL0SHf=08n?S`2RXZ80ZJVY096A
T@2SXj<0UYJF08R8R01`L700HV9R05ADE00_;bl05QHF3P0000004@0I6AT07QhN03lo?`1`L700Rh^;
0820P025QHD0Q8B407MgM`24Q8@0G5aL07MgM`1^KVh0Jf][08n?S`1iNGT0N7Qh0080KFe]01`0PH61
07]kN`2>SXh0RHV908J6QP1oOgl0Q8B408>3P`2:RXX0OWin07alO01hN7P0QHF507YjNP1fMWH0O7al
08n?S`20P800KVi^07=cL`1UIFD0OWin079bLP1eMGD0L71`07EeM@1IFET0I6AT0P1[Jf/0401_Kfl0
Lg=c065QH@1NGUh0EEEE05QHF01KFe/0OWin07emO@1^KVh0G5aL06IVIP1FEUH0JVYZ065QH@1_Kfl2
06QXJ00306EUI@1NGUh0JFUY0080Hf=S05T0JVYZ07QhN01^KVh0Fe]K06IVIP1<C4`0H61P04];B`1G
EeL0HV9R06a/K015ADD0G5aL04E5A@1XJ6P0HF5Q059BDP1IFET0GUiN05IFEP1JFUX0IFEU04U9B@0g
=cL0FEUI04M7A`1KFe/0A4A405IFEP1DE5@0Cdm?02d];@0c<c<0BTY:04I6AP000000@d=303lo?`0l
?3`0@T9203Lg=`0U9BD0@T9204Q8B01=CDd0A4A401/K6`0`<300<S8b04=3@`0];Bd0>c/k03Xj>P0h
>3P04A4A03Xj>P0c<c<0;Rh^03De=@0m?Cd0=cLg038b<P0k>c/092@T02LW9`0L71`08B4Q03/k>`0e
=CD03@d=02@T900Q8B40=CDe01`L700l?3`061PH04E5A@17AdL0:BTY02l_;`0j>SX09RHV02@T900:
2PX0<S8b02TY:@0A4A401`L70?ooo`060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT0
0`3IfMT01@3oool0Shn?08^;R`1kNg/0QhN70080Rh^;07d0J6QX07emO@1kNg/0RXZ:07MgM`26QXH0
W9bL0::RXP1fMWH0PX:20;:b/P2:RXX0Y:BT09^KV`2GUiL0Zj^[0:BTY02IVIT0Zj^[0:>SX`2YZJT0
WinO0:b/[02RXZ80Rh^;09RHV02NWYh0[:b/08n?S`2RXZ80YjNW07inOP2IVIT0ZJVY09fMW@2PX:00
V9RH08Z:RP2EUID0Vi^K09>CT`2OWil0UiNG09JFUP2NWYh0RHV90:>SX`2[Zj/0QhN709VIV@2QXJ40
Y:BT0;6a/@2YZJT0TY:B0:6QX@2ZZZX0O7al07QhN02UYJD0XJ6Q09jNWP2BTY80UIFE07EeM@1_Kfl0
SHf=0:NWY`2j^[X0X:2P0:6QX@2JVYX0YJFU09BDU02PX:00VIVI0;Bd]02DU9@0UYJF0:b/[02MWId0
Vi^K0:j^[P2TY:@0Zj^[0:RXZ02YZJT0UiNG0:>SX`2`/;00Y:BT09nOW`2DU9@0Vi^K09JFUP2VYZH0
XJ6Q0:b/[02QXJ40VIVI09bLW02MWId0TI6A0:ZZZP2QXJ40YjNW08f=S@2CTi<0VYZJ0:JVYP2ZZZX0
QhN709FEU@2LW9`0[Jf]09>CT`2FUYH0T92@08B4Q02FUYH0PX:209fMW@28R8P0X:2P079bLP0208>3
P`0406=SH`1=CDd0<S8b00l?3`P0000000<00@4100000000000010000000F@0?3`l09RHV04I6AP1M
GEd0LG5a07MgM`2;Rh/0OWin079bLP1aLG40I6AT08>3P`1dM7@0QhN707alO01cLg<0LW9b09JFUP1o
Ogl0PH61079bLP1kNg/0FEUI07AdM01UIFD0HV9R08:2PP1`L700UIFE08Z:RP25QHD0O7al07EeM@23
Ph<0QXJ608R8R01[Jf/0RHV907=cL`1kNg/0NWYj06=SH`1gMgL0IVIV06][J`1dM7@0LW9b06=SH`25
QHD0IFEU04m?C`1>CTh0Lg=c05QHF01CDe<0LW9b05YJFP1UIFD0MgMg07UiN@1WIfL0IVIV05EEE@1R
HV80JFUY06EUI@1CDe<0IfMW061PH01MGEd0QHF506EUI@1lO7`0Kfm_05ADE01HF5P0De=C06EUI@1g
MgL0Bd];05mOG`1HF5P0D51@05eMG@1FEUH0JFUY065QH@1;Bd/0E5AD0080FEUI04H0BDU904M7A`0l
?3`0@T9205ADE01ADE40C4a<04U9B@1FEUH0Cdm?05IFEP1GEeL0B4Q803Lg=`0k>c/0=CDe02l_;`16
ATH0?Shn03/k>`1FEUH0?clo03dm?@0o?cl0;2`/04A4A00`<300?clo03dm?@0[:b/0@T92038b<P0X
:2P0B4Q803@d=00j>SX0@T9203dm?@0T92@061PH03dm?@0c<c<0:2PX00h>3P0H61P0<S8b02XZ:P0K
6a/0:2PX02h^;P0h>3P0E5AD03`l?00e=CD0BTY:03@d=00`<300:b/[01`L700`<3008B4Q01PH600M
7Ad0000003Lg=`0=3@d092@T024Q8@0M7Ad0oooo1P3IfMT100000040fMWI000F0=WIf@800000103I
fMT0RP3oool0RXZ:09:BTP2IVIT0Q8B408j>SP28R8P0SXj>09JFUP1hN7P0QXJ60820P02>SXh0OGem
08f=S@2BTY80QXJ609bLW02<S8`0XZ:R09ZJVP2i^KT0WYjN0::RXP2ATI40ZZZZ09>CT`2BTY80/;2`
0;Jf]P2][Jd0QHF509bLW02CTi<0QXJ60:JVYP2:RXX0WYjN07UiN@2a/K40Y:BT0:JVYP2>SXh0YZJV
08>3P`27QhL0R8R80::RXP2>SXh0QHF509jNWP2GUiL0YZJV09ZJVP2@T900Vi^K0;Vi^@2`/;00[Jf]
0:>SX`2OWil0U9BD08^;R`2XZ:P0WinO09jNWP2ZZZX0Vi^K0:ZZZP2SXj<0][Jf09NGU`2DU9@0SXj>
09JFUP2/[:`0YZJV0:VYZ@2UYJD0Rh^;0:VYZ@2@T900Shn?09>CT`2PX:00VIVI0:6QX@2NWYh0T92@
0<K6aP2NWYh0QHF509FEU@2b/[80X:2P0:RXZ02CTi<0Z:RX0:ZZZP2XZ:P0UiNG09RHV02?Shl0X:2P
0;6a/@2[Zj/0ZJVY0:f][@2c/k<0Z:RX09VIV@25QHD0XJ6Q08V9R@2@T900WIfM0:NWY`2_[jl0SXj>
0:JVYP2c/k<0SHf=09VIV@26QXH0YJFU09NGU`2XZ:P0WinO0:FUY@2<S8`0TY:B07]kN`2CTi<0Ng]k
06][J`1SHf<0;Bd]014A4@H0000000@03Ph>03@d=00c<c<06QXJ1P0000006`010@40:BTY05YJFP1Y
JFT0QHF50820P01eMGD0M7Ad069RHP1fMWH0HV9R06IVIP1PH600PH6108B4Q01oOgl0Ng]k096AT@27
QhL0MWIf07EeM@1oOgl0O7al0820P028R8P0QXJ607emO@0207alO00M06m_K`2=SHd0Ph>3079bLP1d
M7@0LW9b0820P025QHD0IfMW05IFEP27QhL0IVIV05UIF@1JFUX0Jf][06QXJ01gMgL0KVi^05ADE01_
Kfl0KVi^05UIF@1EEED0GemO06IVIP1iNGT0KFe]07AdM01<C4`00P1WIfL02`1RHV80MWIf07AdM01F
EUH0IfMW06IVIP1PH600MWIf06a/K01KFe/0IfMW0080DE5A05L0GEeM05MGE`1QHF40C4a<05mOG`1[
Jf/0F5QH06IVIP1QHF40K6a/06EUI@1GEeL0EEEE05ADE01HF5P0KFe]03dm?@1?Cdl0P82006=SH`1C
De<0BTY:051@D01LG5`0>3Ph06i^KP1<C4`0BDU902h^;P11@D40=SHf03Ti>@1;Bd/0?clo04];B`1:
BTX0CTi>02h^;P1;Bd/0@41004=3@`0l?3`0A4A404=3@`1JFUX0B4Q802XZ:P0g=cL0?3`l030`<014
A4@0=3@d04A4A00e=CD0<S8b04];B`0/;2`0<c<c01lO7`0P82009RHV04Q8B00U9BD0<c<c03hn?P0o
?cl0=CDe02@T900^;Rh0<C4a03Lg=`0Q8B40=SHf04i>CP0X:2P0@41003@d=00[:b/0000002DU9@06
1PH092@T01dM7@0R8R80:b/[02DU9@3oool01@3IfMT200000040fMWI000F0=WIf@030000003IfMT0
fMWI00<0fMWI00H0oooo092@T02b/[80Rh^;08F5Q@2KVi/208Z:RP08092@T01nOWh0SHf=08R8R02;
Rh/0P8200861P@1oOgl208n?S`0`06e]K@2<S8`0XZ:R08^;R`2CTi<0QHF5092@T02OWil0[Jf]09jN
WP2QXJ40O7al08B4Q02HV9P0XZ:R09RHV02LW9`0Rh^;0;Fe]@2=SHd0V9RH09fMW@2SXj<0XZ:R08Z:
RP2ZZZX0NGUi0:FUY@2IVIT0V9RH092@T02SXj<0SXj>092@T02ATI40Ng]k08^;R`2PX:00VIVI0:j^
[P29RHT0Shn?09RHV02CTi<0T92@09fMW@2QXJ40X:2P0P2WYjL05@2^[Zh0SXj>09ZJVP2XZ:P0XZ:R
09FEU@1dM7@0];Bd09bLW02YZJT0Rh^;0:6QX@2TY:@0Ph>309RHV02EUID0/[:b09BDU02HV9P0S8b<
09BDU0020:FUY@0_0:BTY02g]kL0Ti>C0:ZZZP2>SXh0WinO08J6QP2JVYX0X:2P0:>SX`2l_;`0VIVI
09NGU`2BTY80Xj>S092@T02VYZH0Z:RX09NGU`2n_[h0X:2P0:JVYP2c/k<0d=3@0:6QX@2RXZ80MgMg
09RHV02DU9@0UiNG0<30`02GUiL0W9bL0:b/[02CTi<0W9bL092@T02HV9P0RHV907]kN`26QXH0S8b<
08N7Q`1PH600G5aL038b<P061PH01P000000100K6a/07alO01DE5@0B4Q850000001>00@4100?3`l0
@T9204A4A01XJ6P0QhN70861P@1lO7`0Shn?07MgM`1]KFd0J6QX061PH01ZJVX0Lg=c07MgM`22PX80
JVYZ07IfMP1gMgL0F5QH07EeM@29RHT0KFe]07YjNP1bLW80MgMg07inOP1kNg/0QHF507QhN02EUID0
LW9b07IfMP1ZJVX0M7Ad07UiN@1RHV80KFe]06=SH`1CDe<0Hf=S05IFEP1RHV80EUIF06IVIP1_Kfl0
O7al06a/K022PX80QhN707QhN01JFUX0>3Ph08N7Q`1`L700GemO079bLP1/K6`0H61P06m_K`1XJ6P0
GEeM06i^KP1aLG40GEeM061PH01BDU80EEEE061PH01VIVH0HV9R07EeM@2?Shl0IVIV05aLG01MGEd0
Hf=S0P1UIFD0:P1;Bd/0MWIf051@D01ADE40H61P05IFEP1BDU80FUYJ06=SH`1IFET0A4A404a<C01J
FUX0ATI605eMG@1>CTh0B4Q805=CD`13@d<0DU9B03dm?@1=CDd0De=C06MWI`16ATH0?Cdm03Ti>@0^
;Rh0CDe=04Y:BP14A4@0BDU901lO7`1@D500=3@d0410@00m?Cd0ATI602/[:`1<C4`0DE5A04=3@`<0
?Cdm01/0>CTi02h^;P17AdL061PH02/[:`0W9bL06QXJ00H61P0k>c/0>SXj03<c<`0V9RH0@D5103Ph
>00l?3`0=SHf01`L701EEED0:2PX020P800`<300:BTY04a<C01?Cdl0<30`02l_;`0D51@00P000000
1`0Q8B402PX:00/;2`0c<c<01PH6018B4P3oool01P3IfMT100000040fMWI000F0=WIf@030000003I
fMT0fMWI00<0fMWI02`0oooo08>3P`2@T900TY:B08f=S@2JVYX0Ph>308n?S`2BTY80QHF508N7Q`2;
Rh/0PH61092@T02LW9`0O7al0:>SX`2CTi<0XZ:R08n?S`2GUiL0XZ:R09JFUP2e]KD0ZZZZ0:RXZ02i
^KT0Ti>C07inOP2UYJD0Y:BT0:NWY`2YZJT0YZJV09JFUP2IVIT0TI6A0:NWY`2ZZZX0Rh^;096AT@2E
UID0Shn?09nOW`80W9bL02T0VIVI0:NWY`2ZZZX0`<300:NWY`2IVIT0WYjN0:2PX02TY:@0V9RH0:b/
[02:RXX0SXj>0:2PX029RHT0/[:b0:VYZ@2CTi<0WIfM0:j^[P2GUiL0T92@096AT@2TY:@0YJFU08J6
QP2FUYH0WYjN03/k>`2TY:@0OGem0:6QX@2][Jd0X:2P0;Jf]P2[Zj/0YZJV08f=S@2<S8`0SHf=08V9
R@0209fMW@0`0:ZZZP2GUiL0Vi^K08J6QP2EUID0VYZJ09:BTP2IVIT0Shn?09:BTP2VYZH0X:2P09FE
U@2VYZH0Zj^[096AT@2SXj<0][Jf0:>SX`2TY:@0SXj>09BDU02TY:@0W9bL09ZJVP2DU9@0/K6a0:j^
[P2a/K40TI6A09^KV`2VYZH0/k>c09ZJVP2@T900WIfM0:BTY01oOgl0WIfM09NGU`2<S8`0OGem09:B
TP28R8P0I6AT06i^KP1TI6@0CDe=1`00000010092@T02`/;01LG5`0Q8B470000000V02HV9P1?Cdl0
J6QX07EeM@1oOgl0LG5a07AdM01RHV80LW9b05IFEP1`L700Fe]K05aLG01fMWH0IfMW075aL@1eMGD0
Ng]k07=cL`1_Kfl0QhN706=SH`22PX80SHf=06m_K`25QHD0T92@08:2PP0n?Sh0KFe]069RHP1^KVh0
Kfm_07emO@10@400OGem05]KF`1WIfL2079bLP0<06ATI01LG5`0KVi^07EeM@1]KFd0GEeM06a/K01O
Gel0Lg=c05QHF01VIVH0D51@0P1IFET0?P1SHf<0I6AT06MWI`1VIVH0GUiN071`L01TI6@0MWIf05UI
F@1JFUX0LG5a05YJFP1gMgL0LG5a06YZJP1CDe<0Cdm?04a<C01?Cdl0GEeM06EUI@1HF5P0Hf=S06AT
I01JFUX0Hf=S06EUI@15ADD0EUIF04m?C`1HF5P0GUiN05]KF`1YJFT0EeMG06][J`1ZJVX0>c/k06UY
J@1>CTh0F5QH059BDP1RHV80?clo05=CD`1NGUh0EUIF05YJFP1>CTh0GEeM04i>CP0m?Cd0@T9205EE
E@0f=SH0DE5A05QHF019BDT0G5aL04I6AP0k>c/0<S8b0P11@D40:@0g=cL0:RXZ03Hf=P16ATH0=cLg
01TI6@0Q8B409RHV02LW9`0k>c/0;bl_030`<00V9RH0?clo02/[:`0];Bd07alO02@T900D51@0<c<c
028R8P0o?cl0<C4a038b<P0g=cL0=CDe034a<@0>3Ph0<S8b02<S8`0/;2`0:2PX0000000E5AD06a/K
02<S8`0R8R8071`L010@400410@0oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WI
f@030=WIf@0;0?ooo`2@T900OWin07AdM01oOgl0ZJVY07]kN`2<S8`0RXZ:06m_K`1jNWX00P29RHT0
O@2CTi<0L71`09fMW@2ATI40R8R808B4Q02GUiL0YJFU07inOP2JVYX0][Jf09:BTP2LW9`0WYjN0:JV
YP2JVYX0WYjN0::RXP2`/;00ZZZZ09VIV@2NWYh0Zj^[0;:b/P2;Rh/0/;2`0;:b/P2XZ:P0W9bL09VI
V@2HV9P0Ti>C0;>c/`2SXj<0X:2P09^KV`2@T900QHF50:RXZ02WYjL0TY:B09^KV`2MWId0YZJV09ZJ
VP2ATI40Rh^;09fMW@1mOGd0Ng]k096AT@2i^KT0Vi^K0:VYZ@26QXH0W9bL0:>SX`28R8P0/;2`09:B
TP2SXj<0R8R808>3P`1dM7@0SXj>07inOP2_[jl0S8b<09NGU`2b/[80YjNW0:j^[P2i^KT0WIfM09RH
V02RXZ80RXZ:08j>SP2MWId0NWYj0:j^[P2SXj<0VIVI08J6QP2ATI40T92@09nOW`2VYZH0SHf=0:JV
YP2YZJT0Shn?0:b/[02[Zj/0XZ:R096AT@2FUYH0X:2P09nOW`2KVi/0^k^k09bLW02[Zj/0[Zj^08V9
R@2PX:00V9RH0:6QX@2MWId0OWin0:>SX`2WYjL0PH6109>CT`28R8P0S8b<07]kN`2DU9@0TY:B08J6
QP2>SXh0LG5a05EEE@0l?3`02`/;0100000001/01@D5024Q8@1IFET0NGUi05]KF`1UIFD0UIFE06MW
I`1^KVh0GUiN07MgM`1bLW80MgMg06i^KP1RHV80PX:207=cL`1YJFT0Fe]K07EeM@1]KFd0O7al075a
L@1fMWH0D51@06QXJ024Q8@00P1eMGD0401aLG40NGUi05=CD`1/K6`0KVi^06IVIP1/K6`0IFEU08>3
P`1gMgL0Jf][05UIF@1`L700EUIF05YJFP1^KVh206a/K01a05]KF`1WIfL0Jf][05iNGP1gMgL0JVYZ
05aLG01oOgl0Jf][06e]K@1JFUX0DE5A06QXJ01PH600IfMW05iNGP1YJFT0Lg=c05aLG01gMgL0I6AT
06IVIP1EEED0FEUI069RHP1_Kfl0AdM706QXJ01;Bd/0F5QH06=SH`1>CTh0De=C04A4A01JFUX0L71`
04Y:BP1LG5`0J6QX069RHP1aLG40Fe]K0492@P13@d<0FUYJ05aLG01PH600EeMG051@D013@d<0=cLg
04E5A@1KFe/0@D51055AD@1MGEd0EUIF051@D01GEeL0E5AD04Y:BP19BDT0@41002l_;`1IFET0=SHf
03Ti>@0c<c<0BDU903Lg=`0m?Cd0ATI603Hf=P1>CTh0>SXj02HV9P0f=SH04Q8B028R8P0`<300<C4a
020P800_;bl0;Bd]01`L700Y:BT0<30`02TY:@0b<S809bLW02d];@0Q8B409BDU01hN7P0Y:BT05QHF
02@T900L71`03Ph>02DU9@0@4100;Rh^03Ti>@0N7Qh0>CTi028R8P0A4A406ATI024Q8@000000;Bd]
03@d=03oool01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00`0oooo0820
P01iNGT0SXj>07emO@1oOgl0UYJF0:2PX02:RXX0Shn?07]kN`1QHF4209NGU`100::RXP2HV9P0Q8B4
09>CT`2@T900OGem09fMW@2HV9P0Zj^[096AT@2b/[80U9BD09nOW`1kNg/0Zj^[09VIV@2?Shl0_Kfm
09VIV@1oOgl0X:2P09nOW`2JVYX0UYJF0:b/[02EUID0QhN709>CT`1oOgl0TY:B08Z:RP26QXH0[Jf]
0;Jf]P2CTi<0QXJ607=cL`2@T900VYZJ09fMW@2RXZ80VIVI0:NWY`2CTi<0VYZJ09jNWP2OWil0TI6A
0:j^[P2ATI40T92@0:FUY@2TY:@0[:b/09^KV`2JVYX0U9BD08F5Q@20P800R8R808V9R@1nOWh0YJFU
0:BTY080W9bL02`0UYJF08j>SP2HV9P0VYZJ08j>SP2MWId0XJ6Q09bLW02a/K40UYJF08b<S02HV9P0
]KFe096AT@2PX:00U9BD0:BTY02MWId0^k^k08j>SP2PX:00VYZJ0:2PX02KVi/0QHF508f=S@2KVi/0
YJFU0;Zj^P2BTY80WYjN09fMW@30`<00WIfM0:6QX@2RXZ80Zj^[08j>SP2QXJ40[Zj^09JFUP2BTY80
Vi^K0;Ng]`80WIfM00/0UiNG08F5Q@20P800QHF509JFUP2?Shl0Ti>C096AT@1jNWX0IVIV0410@00A
0000000>00D51@0f=SH0Ph>305aLG01cLg<0Ng]k06a/K01oOgl0N7Qh06EUI@1bLW80LG5a07=cL`22
PX82079bLP0=07moO`23Ph<0JFUY04Y:BP1aLG40Ogmo06e]K@2=SHd0K6a/07MgM`1_Kfl0PX:20861
P@02075aL@0>06=SH`1DE5@0LG5a06][J`20P800GUiN05mOG`25QHD0JVYZ06e]K@1WIfL0G5aL05QH
F020P80207]kN`0P06=SH`1_Kfl0G5aL07MgM`1RHV80I6AT06IVIP1RHV80Cdm?079bLP1EEED0GemO
07alO01dM7@0De=C05aLG01]KFd0LW9b05eMG@1CDe<0J6QX06=SH`1@D500Kfm_069RHP1<C4`0FEUI
06MWI`1MGEd0F5QH05]KF`1/K6`2055AD@0?05mOG`1EEED0MGEe05QHF01RHV80EUIF065QH@1NGUh0
;2`/05MGE`18B4P0FUYJ04Q8B01EEED0Bd];0080BDU903h0DU9B04e=C@1DE5@0=SHf03Ph>01UIFD0
820P03hn?P1=CDd0?clo0410@00l?3`0EUIF03Ti>@1FEUH0>CTi01PH600h>3P0<c<c03Lg=`0i>CT0
;2`/03@d=01>CTh0G5aL03dm?@0^;Rh09BDU03Lg=`0Q8B4092@T02d];@0F5QH0410@01`L700c<c<0
:2PX02DU9@0J6QX0:b/[01lO7`12@T80A4A402XZ:P14A4@0:BTY03lo?`0;2`/0;Rh^03@d=00j>SX0
5ADE02h^;P0X:2P0<C4a01LG5`0^;Rh08B4Q01@D500S8b<07AdM0?ooo`H0fMWI0@0000010=WIf@00
5P3IfMT00`000000fMWI0=WIf@030=WIf@080?ooo`27QhL0RXZ:08j>SP27QhL0R8R809VIV@29RHT2
09ZJVP0W0861P@23Ph<0O7al0:ZZZP2SXj<0YjNW0::RXP27QhL0YZJV079bLP2GUiL0[Jf]09NGU`2T
Y:@0VIVI08J6QP2QXJ40Vi^K0:j^[P2@T900[:b/0:BTY02LW9`0WYjN0:2PX02XZ:P0XJ6Q09BDU02K
Vi/0WIfM08f=S@1QHF40LW9b09nOW`2>SXh0Rh^;09nOW`2c/k<0UYJF0080U9BD01`0Ogmo08>3P`2D
U9@0Ti>C0:VYZ@2RXZ80Ti>C0:BTY02<S8`0X:2P08n?S`2OWil0U9BD09JFUP1lO7`0T92@0820P02<
S8`0]KFe0:>SX`2PX:00PX:20:RXZ01kNg/0SHf=0:n_[`2LW9`0WinO0P2HV9P08P29RHT0U9BD0:^[
Z`2HV9P0ZJVY0<30`02GUiL0^[Zj0::RXP2a/K40[Zj^09bLW02JVYX0YjNW09RHV02<S8`0Shn?08R8
R02YZJT0WinO09BDU02OWil0UIFE08^;R`2FUYH0UiNG0;Bd]02GUiL0Vi^K0:RXZ02ATI40V9RH0:6Q
X@2:RXX20:JVYP0E0;6a/@2FUYH0SXj>0:2PX02IVIT0T92@09VIV@2BTY80V9RH09FEU@1bLW80X:2P
09ZJVP2DU9@0Z:RX09BDU029RHT0SXj>05UIF@1JFUX061PH00l0000001D05QHF01`L700k>c/0IfMW
07IfMP24Q8@0MGEe071`L01iNGT0MgMg07UiN@1eMGD0Hf=S05eMG@28R8P0MgMg07AdM026QXH0LG5a
07QhN01mOGd00P21PH408@1^KVh0PX:204a<C01OGel0LW9b07alO01]KFd0HV9R07emO@1nOWh0MGEe
061PH01iNGT0GUiN0861P@1TI6@0JVYZ07=cL`1^KVh0F5QH05UIF@1GEeL0E5AD06IVIP1eMGD0J6QX
05iNGP1TI6@0Hf=S06MWI`1[Jf/0L71`07=cL`0205iNGP0Z04m?C`1QHF40K6a/079bLP1ADE40MGEe
06][J`1EEED0K6a/06i^KP1_Kfl0FEUI06YZJP1cLg<0Hf=S04Y:BP1/K6`0Hf=S05eMG@1PH600HF5Q
055AD@1LG5`0EEEE04Y:BP1gMgL0H61P04Q8B01MGEd0JVYZ05YJFP1PH600HV9R03lo?`1=CDd0H61P
04Q8B00i>CT0EEEE04Y:BP1<C4`0De=C0P1=CDd08P10@400<c<c04M7A`1OGel0=cLg05UIF@1BDU80
@T9204E5A@1:BTX0BDU902XZ:P0f=SH0DE5A03@d=00U9BD0;Rh^0410@01>CTh0;Bd]0410@00`<300
=CDe02LW9`0`<300?3`l03Lg=`0T92@04A4A02XZ:P0K6a/0>CTi03hn?P0J6QX203Hf=P0G02/[:`0f
=SH0820P00d=3@0I6AT0<30`03dm?@16ATH03@d=02@T900Z:RX08B4Q028R8P0E5AD0<30`02d];@0L
71`0:BTY02<S8`0/;2`08B4Q01DE5@3oool01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0
fMWI00<0fMWI05d0oooo07]kN`2;Rh/0WIfM06a/K01bLW80U9BD08f=S@1eMGD0W9bL08Z:RP2CTi<0
UiNG09jNWP2MWId0UYJF09ZJVP32`/80WinO0:6QX@2d];@0SXj>08R8R02LW9`0UYJF09^KV`2b/[80
[jn_08F5Q@2[Zj/0RXZ:09FEU@2CTi<0Z:RX0:BTY02MWId0UiNG08:2PP2WYjL0WYjN08j>SP2SXj<0
[jn_09fMW@2EUID0X:2P0;:b/P29RHT0TY:B08F5Q@1gMgL0QXJ608F5Q@1jNWX0Ph>309VIV@2;Rh/0
ZJVY09jNWP2BTY80VIVI09jNWP29RHT0Vi^K079bLP2;Rh/0LW9b0::RXP2TY:@0YJFU0:2PX02CTi<0
TY:B07moO`2EUID0VIVI08R8R02@T900TY:B09BDU02[Zj/0U9BD08f=S@2PX:00UIFE0;fm_@2KVi/0
S8b<08j>SP2TY:@0TY:B08R8R02FUYH00P26QXH0;022PX80XZ:R09jNWP2>SXh0JVYZ092@T01`L700
NWYj09^KV`2XZ:P0WYjN0:BTY02XZ:P0/;2`09VIV@2ZZZX0De=C08f=S@2JVYX0X:2P09JFUP2MWId0
V9RH08B4Q02RXZ80Ph>309JFUP2;Rh/0Zj^[09fMW@2VYZH0OGem08R8R02=SHd0UYJF0861P@2HV9P0
X:2P096AT@2:RXX0YjNW065QH@1JFUX0?3`l3@0000008`030`<06ATI01DE5@1VIVH0I6AT07emO@2>
SXh0Lg=c06a/K01cLg<0IVIV06YZJP1QHF40PH6107MgM`1ZJVX0QHF506YZJP1KFe/0Jf][071`L01h
N7P0H61P05mOG`1/K6`0Lg=c04m?C`1TI6@0KFe]07EeM@1UIFD0MGEe06QXJ01mOGd0MgMg0080FEUI
0200JFUY06YZJP1@D500GemO05=CD`1`L700J6QX07IfMP1RHV80De=C04i>CP1oOgl0GUiN06i^KP17
AdL0M7Ad05aLG01bLW80O7al06UYJ@23Ph<0Q8B407inOP1eMGD0D51@061PH01dM7@0ATI605mOG`1E
EED0J6QX05iNGP80NGUi01P0Fe]K06EUI@1NGUh0CDe=05mOG`10@400EEEE05UIF@1TI6@0MWIf06a/
K01FEUH0CDe=059BDP1>CTh0KVi^069RHP1IFET0EUIF04i>CP1TI6@0>CTi07MgM`1[Jf/205mOG`0M
03/k>`1KFe/0IfMW04M7A`1KFe/0E5AD05aLG01<C4`0Cdm?05QHF01PH600EEEE06QXJ011@D40A4A4
04M7A`19BDT0E5AD04A4A019BDT0DU9B04];B`0l?3`0C4a<02h^;P0f=SH0<c<c01/K6`1FEUH00P0c
<c<08P0N7Qh0?clo020P800Y:BT0?Shn038b<P0P82009BDU00D51@0M7Ad0:RXZ02`/;00Z:RX06QXJ
03Ph>00Z:RX0=CDe01XJ6P0d=3@03`l?02DU9@0i>CT0@T9202TY:@0A4A40<30`03Ti>@0M7Ad04A4A
02`/;00e=CD0=SHf03Lg=`3oool60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3I
fMT0103oool0MWIf08b<S01LG5`208f=S@030::RXP2?Shl0O7al0080Ogmo0180SHf=08n?S`2?Shl0
QhN709fMW@21PH40OGem0820P02IVIT0XZ:R09:BTP2LW9`0YJFU0;Ng]`2[Zj/0QhN70:6QX@2ATI42
0:BTY00T0:6QX@2@T900V9RH092@T02;Rh/0V9RH09NGU`2>SXh0TI6A09nOW`2TY:@0Ogmo08>3P`2T
Y:@0YJFU0:BTY021PH40QhN708B4Q01cLg<0U9BD06e]K@2a/K40UiNG07inOP2FUYH0VYZJ0;:b/P2V
YZH0Ti>C09NGU`25QHD0V9RH08Z:RP25QHD0NGUi0P2JVYX0602IVIT0X:2P0;>c/`1oOgl0SHf=08^;
R`1kNg/0UiNG08^;R`2f][H0X:2P09JFUP2CTi<0PX:207MgM`2NWYh0Ti>C09BDU02UYJD0XZ:R09:B
TP2MWId0YZJV08:2PP80RHV902d0IfMW08j>SP2HV9P0UYJF08N7Q`2@T900WinO09bLW01iNGT0PH61
0:RXZ025QHD0Z:RX09RHV02BTY80SXj>09bLW02PX:00ZZZZ0:b/[02BTY80YZJV0:>SX`2OWil0YjNW
09NGU`23Ph<0PH6109nOW`2CTi<0YJFU0;2`/02^[Zh0SXj>08N7Q`26QXH0Z:RX08j>SP2UYJD0S8b<
08>3P`1SHf<0?clo0410@00:2PX0300000006P0<30`0>c/k05iNGP1KFe/0G5aL07moO`1lO7`0L71`
08^;R`21PH40K6a/0861P@20P800SXj>06EUI@25QHD0M7Ad05IFEP1hN7P0O7al07]kN`1VIVH0LG5a
08J6QP1kNg/0IfMW0P1PH6002@1hN7P0LW9b0820P01RHV80QXJ606][J`1ZJVX0O7al09:BTP0206IV
IP1k05iNGP1DE5@0Lg=c04];B`1cLg<0EEEE05iNGP1VIVH0Hf=S05QHF01jNWX0De=C06IVIP1ZJVX0
IVIV06][J`1VIVH0MWIf075aL@1nOWh0M7Ad05mOG`1[Jf/0L71`07YjNP1gMgL0I6AT05ADE01[Jf/0
HV9R061PH01`L700Kfm_06IVIP1TI6@0F5QH06YZJP1@D500EEEE04Q8B01FEUH0KFe]05UIF@1DE5@0
>SXj03dm?@1KFe/0KFe]06UYJ@1KFe/0GEeM05IFEP18B4P0FUYJ04Q8B01KFe/0G5aL06EUI@1`L700
ATI605aLG01DE5@0I6AT06IVIP0n?Sh0;bl_04Q8B01QHF40ATI605eMG@18B4P0CTi>038b<P15ADD0
?Shn059BDP0j>SX0>3Ph03/k>`1@D500BTY:03`l?011@D409RHV04A4A00j>SX0=CDe03Lg=`0_;bl0
7alO00/;2`0m?Cd092@T02HV9P0h>3P0>c/k02XZ:P0=3@d0;Rh^02PX:00];Bd0CTi>03De=@0Y:BT0
9bLW0410@00a<C4051@D01<C4`0?3`l07AdM02`/;00d=3@0>c/k03Hf=P0`<3006QXJ01`L700M7Ad0
=cLg03De=@0d=3@0oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@1=
0?ooo`1[Jf/0S8b<08>3P`1oOgl0IVIV09ZJVP2FUYH0QhN709fMW@28R8P0Shn?07EeM@22PX80PH61
09VIV@2?Shl0XJ6Q09nOW`2;Rh/0UIFE096AT@2TY:@0YJFU09:BTP2SXj<0Zj^[0:ZZZP2/[:`0VIVI
0:BTY02:RXX0VYZJ09jNWP2/[:`0UYJF09:BTP20P800SXj>0:RXZ02VYZH0V9RH08N7Q`2>SXh0UYJF
0820P02;Rh/0OWin079bLP29RHT0NGUi08^;R`2FUYH0PX:208>3P`2JVYX0V9RH079bLP2][Jd0Y:BT
0:b/[02`/;00VYZJ09^KV`2BTY80S8b<0:6QX@2TY:@0WIfM0::RXP2KVi/0WIfM09RHV02:RXX0T92@
0:RXZ02TY:@00P2JVYX00`2>SXh0TI6A08j>SP020:ZZZP0708j>SP2PX:00UYJF08B4Q02JVYX0UYJF
0:2PX00209nOW`0C09:BTP2;Rh/0Shn?09bLW02CTi<0XZ:R0:2PX02[Zj/0Shn?092@T02>SXh0XZ:R
09ZJVP2?Shl0][Jf0:JVYP2=SHd0Xj>S092@T00209fMW@0L0:BTY02b/[80XZ:R09NGU`2`/;00Xj>S
0:RXZ01kNg/0NGUi09jNWP2ATI40Ph>309bLW02OWil0Vi^K08j>SP2QXJ40S8b<08j>SP1dM7@0SXj>
07UiN@21PH40F5QH06][J`1MGEd08R8R02l_;`P0000002`092@T04=3@`0e=CD0DE5A075aL@20P800
N7Qh075aL@1^KVh0HV9R06QXJ01aLG40K6a/071`L01[Jf/0N7Qh07YjNP1eMGD0KVi^09>CT`1SHf<0
O7al07MgM`1]KFd0N7Qh07IfMP21PH40G5aL06QXJ01lO7`0MgMg075aL@1JFUX0M7Ad05EEE@1WIfL0
EeMG07emO@1RHV80Fe]K07IfMP1CDe<0D51@04A4A080Cdm?02L0Hf=S061PH01KFe/0GemO05MGE`1`
L700H61P06][J`1ADE40HF5Q08N7Q`12@T80RHV908:2PP1dM7@0GUiN06a/K01[Jf/0Ogmo075aL@1^
KVh0PH6104A4A01GEeL0CDe=03hn?P1YJFT0Jf][06UYJ@1TI6@0H61P05aLG01WIfL0M7Ad05aLG01B
DU80C4a<069RHP1WIfL00P1GEeL0<01LG5`0>SXj05UIF@1RHV80I6AT061PH00o?cl0EEEE04m?C`10
@400JFUY06MWI`1`L700B4Q805mOG`1PH600FUYJ04a<C01:BTX0CDe=05iNGP1<C4`0=CDe05EEE@1:
BTX0@T9204U9B@1=CDd0AdM705=CD`0e=CD0?clo059BDP16ATH0<S8b05IFEP12@T80@D5103/k>`0j
>SX0820P02DU9@0d=3@0BTY:02PX:00/;2`08B4Q02HV9P80:b/[01/06QXJ02XZ:P0`<3008R8R0000
00071`L0410@03Hf=P10@4004A4A02/[:`0V9RH0;bl_01XJ6P0e=CD0=SHf03lo?`19BDT05ADE03/k
>`0E5AD0<C4a02@T900S8b<0:2PX01`L703oool01P3IfMT100000040fMWI000F0=WIf@030000003I
fMT0fMWI00<0fMWI03P0oooo08Z:RP2=SHd0WinO08b<S01VIVH0QhN708V9R@1eMGD0Q8B408f=S@2@
T900W9bL08R8R02=SHd0TY:B092@T01iNGT0Xj>S09jNWP2BTY80Xj>S09JFUP26QXH0X:2P0:b/[02B
TY80WinO09jNWP2PX:00WinO07moO`2OWil0R8R809RHV02FUYH0RXZ:08B4Q022PX80[jn_09NGU`2F
UYH0PH6109BDU02JVYX0WYjN08j>SP26QXH0Ogmo079bLP1iNGT0UIFE09NGU`2:RXX0UiNG07QhN080
R8R801h0W9bL09VIV@2QXJ40UYJF07EeM@2IVIT0SHf=0820P02@T900MgMg07YjNP2:RXX0U9BD07Ui
N@2ATI40MWIf08>3P`2JVYX0/[:b0:BTY027QhL0TY:B08n?S`27QhL0YjNW08>3P`2IVIT0TY:B08j>
SP2RXZ8208Z:RP0Y07moO`0X:2P0UIFE09FEU@29RHT0SXj>08R8R027QhL0QXJ607AdM02BTY80UiNG
09BDU02XZ:P0YZJV08f=S@2a/K40U9BD09jNWP2<S8`0QhN7092@T02TY:@0VYZJ08^;R`2CTi<0TI6A
0:n_[`26QXH0U9BD09NGU`2=SHd0XZ:R092@T02JVYX0W9bL09JFUP2ATI40R8R807YjNP23Ph<00P2;
Rh/0A@23Ph<0KVi^06=SH`1lO7`0JFUY05EEE@1aLG40HV9R04Q8B00O7al0=CDe03dm?@0Y:BT0:b/[
00d=3@16ATH0=CDe03@d=01VIVH0Lg=c06UYJ@1hN7P0GemO07IfMP1NGUh0Lg=c06m_K`1fMWH0HF5Q
07EeM@1FEUH0J6QX07alO01cLg<0HF5Q05UIF@1PH600JFUY06EUI@1XJ6P0HF5Q06a/K01fMWH0EUIF
079bLP1BDU80JVYZ07]kN`1YJFT0De=C07alO01JFUX0PH6106IVIP1<C4`0DU9B05=CD`1ZJVX0I6AT
05]KF`1HF5P0Hf=S065QH@1]KFd0Hf=S04m?C`1MGEd0:b/[075aL@0206m_K`0L04a<C01oOgl0I6AT
05EEE@1QHF40GemO06ATI01KFe/0HF5Q04A4A01DE5@0GemO069RHP1VIVH0J6QX065QH@0o?cl0GemO
07UiN@1fMWH0ATI605]KF`1DE5@0GEeM05]KF`17AdL0E5AD04E5A@80F5QH0500@T9204];B`15ADD0
H61P04M7A`1NGUh0<30`055AD@1VIVH0@d=305UIF@1RHV80;Bd]04a<C00a<C40?clo04e=C@17AdL0
FUYJ05=CD`1>CTh0@41004e=C@1LG5`0Cdm?04M7A`0o?cl0F5QH05iNGP0n?Sh0ATI602@T901@D500
>3Ph02h^;P14A4@0FEUI03Ph>00j>SX0=SHf01dM7@1:BTX0;bl_03Lg=`0O7al09RHV02<S8`0f=SH0
<c<c02LW9`0g=cL08b<S01DE5@12@T80:b/[03Hf=P0e=CD05QHF03Lg=`0J6QX06ATI01`L700N7Qh0
=SHf02h^;P0G5aL0410@01<C4`0c<c<0:b/[02h^;P0W9bL030`<02d];@0H61P03@d=01DE5@0<30`0
:2PX0?ooo`H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0<0?ooo`24Q8@0
SHf=08V9R@2;Rh/0OGem09bLW02DU9@0SHf=08N7Q`2>SXh0OWin0P1fMWH03`28R8P0T92@09NGU`2C
Ti<0WIfM09RHV02YZJT0YZJV0:ZZZP2TY:@0W9bL0:NWY`2<S8`0Zj^[09FEU@0208j>SP0709VIV@2Y
ZJT0[:b/09FEU@2RXZ80UiNG09RHV0020:FUY@0N09JFUP2:RXX0Shn?092@T02>SXh0RXZ:0:NWY`1V
IVH0Q8B408>3P`2FUYH0ZZZZ09nOW`2EUID0W9bL08n?S`2;Rh/0RXZ:0:2PX02JVYX0WinO0:6QX@2d
];@0UYJF08b<S02FUYH0Q8B408R8R02ATI40QXJ60P2BTY80702@T900VIVI0:NWY`2b/[80SXj>08b<
S02>SXh0Vi^K0::RXP26QXH0Y:BT0:>SX`2CTi<0[jn_0:JVYP2MWId0[:b/0:NWY`1LG5`061PH08b<
S023Ph<0S8b<08:2PP2LW9`0X:2P09nOW`2ATI4209BDU00?0;:b/P2FUYH0Y:BT0:JVYP24Q8@0UIFE
09fMW@2IVIT0QhN70:^[Z`2TY:@0WinO0:RXZ02YZJT0WinO0080UYJF00<0QhN709ZJVP2;Rh/00P2L
W9`05@2GUiL0VYZJ09VIV@2VYZH0TY:B092@T02IVIT0Vi^K08Z:RP2ATI40Q8B40861P@20P800L71`
07AdM01QHF40K6a/05YJFP1DE5@0Cdm?03<c<`02055AD@0303hn?P1EEED0C4a<0080H61P01L0KFe]
075aL@1_Kfl0LW9b07MgM`20P800SHf=07IfMP1`L700MgMg06ATI01mOGd0JVYZ06e]K@1^KVh0OGem
05UIF@24Q8@0G5aL06i^KP1FEUH0NWYj06ATI00208J6QP0804m?C`1[Jf/0LW9b07AdM01mOGd0CTi>
05QHF01hN7P2061PH01c071`L01]KFd0Kfm_06][J`16ATH0C4a<05=CD`1PH600Hf=S07AdM01/K6`0
IVIV04Q8B01/K6`0L71`061PH01WIfL0NGUi07EeM@14A4@0N7Qh07inOP1aLG40JVYZ07QhN01MGEd0
HV9R06QXJ01`L700JVYZ06IVIP1ZJVX0F5QH08F5Q@14A4@0I6AT05ADE01UIFD0H61P05YJFP13@d<0
GEeM05IFEP1KFe/0GUiN06][J`1SHf<0Fe]K05EEE@1TI6@0EUIF05MGE`1DE5@0FUYJ04Q8B01VIVH0
BTY:05IFEP19BDT0B4Q806m_K`1FEUH0@T9204a<C01?Cdl0D51@05mOG`17AdL0Bd];05aLG00U9BD0
E5AD05mOG`0k>c/0DU9B03lo?`0j>SX0Hf=S04m?C`0j>SX0BDU903dm?@0g=cL09BDU05ADE019BDT0
ATI605aLG00i>CT0<30`02`/;00o?cl0?3`l03Hf=P0M7Ad09BDU028R8P0O7al0@D5102LW9`0K6a/0
<c<c020P800^;Rh0=cLg01lO7`0H61P071`L01hN7P0l?3`0<C4a02/[:`0Y:BT01`L7020P8002024Q
8@0:03Ph>00M7Ad0=cLg04=3@`0R8R80:b/[0410@00X:2P0:BTY0?ooo`H0fMWI0@0000010=WIf@00
5P3IfMT00`000000fMWI0=WIf@030=WIf@0H0?ooo`27QhL0OGem071`L02GUiL0TI6A08J6QP2NWYh0
Rh^;08f=S@1mOGd0UiNG07=cL`2ATI40V9RH08N7Q`2VYZH0UYJF0:j^[P2ATI40NGUi09VIV@2JVYX0
XZ:R0P2KVi/0;P2WYjL0TI6A0:>SX`23Ph<0UiNG09VIV@2FUYH0];Bd0:n_[`2;Rh/0XJ6Q0:ZZZP2<
S8`0WinO09:BTP1oOgl0RXZ:0:6QX@2DU9@0ZZZZ092@T01kNg/0QhN708R8R02VYZH0VYZJ0:JVYP2S
Xj<0X:2P09>CT`2LW9`0TY:B0;Vi^@2IVIT0Y:BT0:2PX02NWYh0TY:B09bLW02HV9P0UYJF09:BTP2?
Shl0SHf=07MgM`29RHT209BDU02B09bLW029RHT0YjNW09FEU@2JVYX0Z:RX0:BTY031`L40V9RH09^K
V`2:RXX0Xj>S09NGU`2CTi<0U9BD08N7Q`2GUiL0S8b<09FEU@2DU9@0Vi^K08j>SP2<S8`0QXJ608V9
R@2VYZH0T92@09jNWP2LW9`0UIFE09jNWP2YZJT0Z:RX0;Bd]02YZJT0TY:B0:VYZ@2GUiL0[jn_09FE
U@2FUYH0TY:B09ZJVP2<S8`0U9BD09FEU@25QHD0Ph>309FEU@2VYZH0UIFE0:>SX`2NWYh0UYJF08^;
R`2:RXX0S8b<08V9R@2@T900PX:208J6QP2DU9@0L71`08R8R01jNWX0GEeM05MGE`14A4@0Bd];05mO
G`1VIVH0K6a/05eMG@0n?Sh0E5AD05IFEP1IFET0Kfm_04e=C@1jNWX0Kfm_07AdM01_Kfl0IfMW06=S
H`1iNGT0L71`07moO`1^KVh0AdM707EeM@1dM7@0LW9b06QXJ01eMGD0IVIV075aL@1eMGD0MWIf061P
H02<S8`0L71`07alO01RHV80Ng]k07AdM01nOWh0M7Ad08N7Q`1mOGd0GemO075aL@1QHF40GUiN05QH
F01JFUX0L71`06UYJ@16ATH0F5QH06UYJ@1^KVh0N7Qh075aL@1PH600Jf][05IFEP1gMgL0JVYZ06i^
KP1nOWh0I6AT06YZJP1dM7@0Kfm_06YZJP1LG5`0OGem07UiN@1/K6`0MWIf07moO`1@D500QhN7071`
L01YJFT2061PH00705]KF`1>CTh0JFUY06=SH`1<C4`0@T92059BDP0204Y:BP0Q05IFEP0l?3`0DU9B
02<S8`1HF5P0EEEE04i>CP1<C4`0EeMG03Ti>@0l?3`0BTY:03Ti>@0g=cL0?Cdm05MGE`1IFET0DE5A
05aLG010@400CDe=03dm?@1hN7P0HV9R0410@01BDU80?Shn05=CD`1HF5P0BTY:051@D01;Bd/0AdM7
0080B4Q80300C4a<0451@@1OGel0<30`04U9B@1>CTh0=CDe01dM7@0g=cL0BDU9030`<00h>3P07alO
03De=@0F5QH0;2`/020P800Z:RX07AdM00H61P0H61P0:BTY03/k>`0m?Cd06ATI02DU9@0F5QH07AdM
01/K6`0`<3004a<C01@D500^;Rh0;Bd]034a<@0<30`09BDU020P800H61P0=cLg01dM7@0/;2`0<C4a
00X:2P0N7Qh0<30`034a<@3oool60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3I
fMT02P3oool0Ogmo08Z:RP1VIVH0QhN707moO`1gMgL0RHV90820P02>SXh209ZJVP0O09BDU023Ph<0
Z:RX0861P@27QhL0SHf=0:ZZZP2SXj<0/[:b09^KV`2MWId0/k>c09nOW`2JVYX0[:b/08J6QP2WYjL0
Vi^K09NGU`2JVYX0YZJV08B4Q02n_[h0W9bL07emO@2CTi<0Y:BT09nOW`2KVi/0UIFE09VIV@020:RX
Z01909bLW02TY:@0RHV908R8R02:RXX0Shn?08f=S@2MWId0[Zj^09fMW@1oOgl0QhN709^KV`2CTi<0
UiNG09:BTP2LW9`0VIVI0:ZZZP2CTi<0VYZJ09>CT`23Ph<0PH6107]kN`2ATI40P82008n?S`1^KVh0
WinO09NGU`2^[Zh0VIVI0:JVYP2j^[X0[Jf]0:FUY@1kNg/0X:2P0:VYZ@2TY:@0SXj>08n?S`2WYjL0
WinO0:6QX@2IVIT0UYJF08j>SP26QXH0VIVI0::RXP2ZZZX0/;2`0:>SX`2GUiL0YZJV09^KV`2CTi<0
SHf=0:VYZ@2SXj<0[Zj^09bLW02VYZH0Shn?0;bl_01lO7`0Zj^[0::RXP2SXj<0[:b/092@T0020:>S
X`320::RXP2WYjL0YjNW092@T02;Rh/0RXZ:08^;R`27QhL0Lg=c09JFUP2LW9`0Ti>C08:2PP27QhL0
UiNG09ZJVP27QhL0I6AT06i^KP1`L700IfMW07]kN`1aLG40EeMG07QhN01aLG40IFEU04M7A`1HF5P0
De=C06ATI01UIFD0JVYZ06ATI01LG5`0IVIV075aL@1MGEd0Ph>307YjNP1XJ6P0PX:207IfMP1jNWX0
K6a/06UYJ@1NGUh0IVIV05aLG01cLg<0G5aL06UYJ@1RHV80Shn?07moO`25QHD0Ogmo08b<S01YJFT0
MgMg07alO01dM7@0Ng]k051@D015ADD0JFUY05=CD`0i>CT0FUYJ07MgM`0n?Sh0GemO05ADE01LG5`0
IVIV055AD@1LG5`0HF5Q07=cL`1[Jf/0MWIf07=cL`1bLW80Cdm?05mOG`1`L700LG5a06i^KP1]KFd0
Jf][05iNGP1ZJVX0Fe]K07YjNP1gMgL0GEeM05mOG`1VIVH0Jf][07moO`1EEED0IfMW05MGE`1LG5`0
EUIF06MWI`12@T80Bd];069RHP1^KVh0GUiN03Lg=`1@D500Fe]K04a<C01NGUh0FUYJ04E5A@19BDT0
@41004m?C`1ADE40BDU903Lg=`0m?Cd0FEUI05YJFP1CDe<0@T92051@D014A4@0IFEU05IFEP17AdL0
@D5106ATI01IFET0DE5A03dm?@11@D40D51@0492@P11@D40G5aL05=CD`10@400ATI604Y:BP0`<300
>SXj02h^;P0W9bL0B4Q804a<C00^;Rh0@d=304];B`0/;2`0>c/k02<S8`0f=SH09bLW03Xj>P1CDe<0
>CTi03@d=00m?Cd0<c<c01TI6@0[:b/0:2PX02/[:`0e=CD061PH03dm?@0k>c/09RHV03Xj>P0h>3P0
9bLW02<S8`0W9bL092@T03<c<`0G5aL08R8R02HV9P0X:2P0820P03<c<`0L71`07AdM038b<P3oool6
0=WIf@4000000@3IfMT001H0fMWI0P0000040=WIf@1M0?ooo`1mOGd0SXj>09>CT`28R8P0QXJ607Ad
M026QXH0S8b<07QhN02SXj<0ZJVY0:j^[P2JVYX0VIVI0;>c/`2YZJT0XZ:R0:n_[`2JVYX0Zj^[09>C
T`2TY:@0WIfM09FEU@2^[Zh0Shn?09>CT`2TY:@0QHF50:>SX`2IVIT0WinO09ZJVP2][Jd0WinO09jN
WP2SXj<0WinO09NGU`2LW9`0UiNG08^;R`2ATI40Q8B409JFUP29RHT0Lg=c0:2PX01lO7`0VIVI092@
T02?Shl0RXZ:08n?S`2<S8`0TY:B08f=S@2][Jd0VIVI09FEU@2ATI40Vi^K0;Bd]02NWYh0V9RH0:NW
Y`2QXJ40[Zj^09BDU02OWil0YJFU0<_;b`2b/[80XZ:R096AT@2XZ:P0X:2P0:f][@22PX80[:b/0;Vi
^@25QHD0T92@0:>SX`2IVIT0T92@0:b/[02PX:00Ogmo08b<S024Q8@0[Jf]0080WIfM02l0XZ:R08^;
R`20P800QhN708V9R@2:RXX0UIFE08^;R`2IVIT0Ogmo09FEU@2YZJT0X:2P09RHV02VYZH0VIVI08f=
S@2ATI40UiNG08n?S`2FUYH0]KFe092@T02KVi/0Ogmo09nOW`2MWId0OWin09ZJVP2IVIT0S8b<051@
D027QhL0Ng]k0:NWY`23Ph<0T92@08J6QP1cLg<0Xj>S08N7Q`1ZJVX0LG5a07moO`1LG5`0DE5A06YZ
JP02069RHP2504a<C01ZJVX0Fe]K061PH01<C4`0DE5A05]KF`1cLg<0Ph>305aLG01MGEd0IFEU075a
L@25QHD0Hf=S05]KF`1]KFd0R8R808B4Q01fMWH0OGem06ATI01OGel0LW9b08V9R@1@D500L71`06=S
H`1RHV80H61P07moO`1gMgL0EUIF07alO01aLG40KFe]08N7Q`1eMGD0MgMg07inOP1SHf<0L71`05eM
G@1VIVH0GEeM07alO01EEED0BDU905YJFP1LG5`0EeMG07emO@1=CDd0Ng]k05iNGP1ZJVX0LG5a06AT
I01MGEd0LG5a05iNGP1UIFD0JFUY06EUI@1dM7@0I6AT06EUI@1fMWH0Kfm_06IVIP1`L700K6a/06YZ
JP1gMgL0Kfm_09FEU@1EEED0K6a/061PH01UIFD0Hf=S06QXJ01@D500Hf=S059BDP1IFET0H61P04a<
C016ATH0Ogmo05IFEP1PH600J6QX0410@01OGel0D51@06YZJP1GEeL0EUIF04Y:BP1RHV80Bd];0410
@01NGUh0C4a<05EEE@1DE5@0CDe=059BDP1HF5P0Fe]K06UYJ@1LG5`0Fe]K03@d=01UIFD0?Shn051@
D01?Cdl0>SXj06YZJP0m?Cd0@41004U9B@0g=cL0?3`l03lo?`0W9bL0>CTi02XZ:P0i>CT0D51@03lo
?`0203@d=00S03Hf=P0n?Sh0?Cdm03<c<`0j>SX0<S8b034a<@0G5aL0<30`018B4P0C4a<08B4Q01PH
600`<3008R8R01dM7@0D51@0=cLg03De=@17AdL0?Shn03@d=00j>SX0@d=302h^;P0@4100=SHf01<C
4`0B4Q8051@D03Xj>P0/;2`09BDU01DE5@3oool01@3IfMT200000040fMWI000F0=WIf@030000003I
fMT0fMWI00<0fMWI0840oooo08B4Q02IVIT0Ti>C09:BTP1oOgl0Q8B406m_K`23Ph<0PH6109^KV`2Q
XJ40YJFU09:BTP1oOgl0Vi^K08F5Q@2@T900UIFE07QhN02RXZ80WIfM0:6QX@2FUYH0SHf=09ZJVP2C
Ti<0/k>c09nOW`2JVYX0ZJVY08b<S02LW9`0RXZ:09ZJVP2IVIT0J6QX07EeM@2XZ:P0U9BD07moO`2T
Y:@0VIVI08b<S02RXZ80TY:B08>3P`2KVi/0TY:B08^;R`1fMWH0Ti>C0:BTY02:RXX0N7Qh08V9R@24
Q8@0ZJVY0:b/[02KVi/0UIFE0:VYZ@2TY:@0WIfM09jNWP2HV9P0RXZ:08N7Q`2=SHd0VYZJ09NGU`2Q
XJ40XZ:R0:VYZ@2^[Zh0XJ6Q09nOW`2>SXh0QhN70:VYZ@2XZ:P0[Jf]09VIV@2UYJD0Rh^;0:>SX`2d
];@0Ti>C09JFUP2CTi<0Ph>30820P02?Shl0TY:B0::RXP2KVi/0UYJF0:n_[`2IVIT0U9BD09ZJVP2E
UID0UiNG0:>SX`2BTY80Ti>C09FEU@2JVYX0XZ:R0:2PX025QHD0UYJF0:>SX`2?Shl0XJ6Q0:2PX02L
W9`0UiNG09:BTP2TY:@0Ph>30:BTY02RXZ80Vi^K0:BTY02=SHd0YjNW07MgM`21PH400P2CTi<0502D
U9@0SHf=0:6QX@26QXH0SHf=07emO@2<S8`0RHV907alO01SHf<0LW9b07=cL`1YJFT0IfMW05mOG`1^
KVh0H61P05aLG01WIfL0O7al0P1eMGD0<P1dM7@0K6a/075aL@1PH600Lg=c07YjNP1BDU80F5QH07mo
O`1MGEd0Lg=c0861P@1ZJVX0KVi^07MgM`1iNGT0IfMW06QXJ01hN7P0IVIV06a/K022PX80Ogmo075a
L@1TI6@0Ogmo06][J`1eMGD0JVYZ07IfMP1ZJVX0FEUI05YJFP0o?cl0E5AD07EeM@1>CTh0L71`07em
O@1VIVH0IFEU06UYJ@1UIFD0Jf][06i^KP1iNGT0EUIF05YJFP1RHV80MgMg0P1^KVh05@1BDU80OGem
07emO@1^KVh0EUIF06][J`1cLg<0MgMg06][J`1oOgl0KVi^061PH01?Cdl0JFUY059BDP1@D500IVIV
08F5Q@1GEeL0IFEU06ATI002071`L00504i>CP1TI6@0GUiN06QXJ01TI6@00P1OGel0=01?Cdl0@T92
03De=@1RHV80HF5Q061PH01NGUh0Bd];05YJFP1FEUH0?Shn061PH01CDe<0BTY:05MGE`0o?cl0JVYZ
05QHF01KFe/0IVIV0492@P1EEED0I6AT04Y:BP1XJ6P0Cdm?04e=C@10@400CDe=05eMG@14A4@0BTY:
05IFEP15ADD0?3`l02`/;00o?cl0?3`l055AD@1GEeL0<30`03<c<`0T92@0<30`04Y:BP0^;Rh0=SHf
020P800_;bl0@D5103Lg=`0L71`203Lg=`80<c<c01L0;Bd]00d=3@0a<C40>CTi03@d=00c<c<0?Shn
059BDP0e=CD0:b/[03`l?00c<c<09bLW02HV9P10@400:b/[01LG5`0e=CD07QhN03Hf=P13@d<0=SHf
0?ooo`060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT04`3oool0V9RH09FE
U@2CTi<0PH6108f=S@2BTY80Ogmo08J6QP2@T900OWin09FEU@2XZ:P0PH610:BTY02RXZ80[jn_09jN
WP2RXZ800P2:RXX07P2JVYX0ZJVY08f=S@2RXZ80UiNG0;Ng]`2:RXX0Vi^K0:6QX@2`/;00WIfM0:2P
X02MWId0T92@0;6a/@2CTi<0XJ6Q07moO`1jNWX0TY:B09NGU`2OWil0Q8B409RHV02=SHd0T92@09BD
U02UYJD0Ogmo09>CT`80QhN700@0MgMg0861P@2<S8`0UIFE0P2PX:00302h^;P0XJ6Q0;2`/02RXZ80
X:2P09NGU`22PX80TY:B0:BTY02@T900UIFE09bLW080X:2P0340XJ6Q0:NWY`2HV9P0YZJV09RHV02[
Zj/0YZJV08N7Q`2@T900Ng]k09ZJVP2e]KD0[Zj^0:JVYP2WYjL0WYjN0;2`/02>SXh0QXJ60:2PX027
QhL0Vi^K06a/K025QHD0NWYj0820P02LW9`0WYjN08>3P`28R8P0Ph>30;Fe]@2TY:@0S8b<09NGU`2L
W9`0XZ:R0:f][@1`L700O7al09NGU`2CTi<0YZJV0:FUY@2a/K40WYjN07emO@2_[jl0PX:20080YjNW
0340U9BD0:>SX`2JVYX0V9RH09ZJVP2ZZZX0S8b<092@T02EUID0Shn?0:n_[`28R8P0S8b<07AdM021
PH40MGEe09ZJVP1eMGD0NGUi071`L01SHf<0Jf][07YjNP1WIfL0MgMg07=cL`1]KFd0LW9b07QhN02;
Rh/0PX:2079bLP1CDe<0H61P06i^KP1HF5P0FUYJ06m_K`24Q8@0EeMG06MWI`1dM7@0HV9R05mOG`1Q
HF40JVYZ07emO@1hN7P0Jf][0080JFUY0440Jf][05UIF@20P800JVYZ071`L01lO7`0MWIf06i^KP1X
J6P0OGem05IFEP1<C4`0Fe]K05eMG@1RHV80KVi^07MgM`1cLg<0ADE505mOG`1ZJVX0GUiN07YjNP1k
Ng/0Kfm_06EUI@1aLG40EUIF05MGE`1WIfL0HV9R07IfMP1bLW80KVi^06=SH`20P800NGUi05iNGP24
Q8@0KVi^06EUI@1WIfL0JFUY07AdM01cLg<0EeMG05iNGP1@D500IVIV06EUI@1KFe/0HF5Q061PH012
@T80I6AT04i>CP1`L700@d=305=CD`1<C4`0Cdm?05]KF`1ADE40BTY:06a/K00205iNGP0405YJFP1S
Hf<0C4a<04Q8B080FUYJ02@0E5AD03lo?`15ADD0>c/k05eMG@10@400E5AD065QH@1ADE40CTi>05QH
F013@d<0Fe]K04];B`1>CTh0?Shn04I6AP1DE5@0>CTi038b<P0o?cl0C4a<02LW9`0n?Sh0ADE502l_
;`0[:b/0;2`/03<c<`0k>c/0@41004];B`0f=SH0;Rh^02l_;`18B4P202/[:`0L01hN7P16ATH0;bl_
03@d=00T92@0:BTY00<30`0_;bl0;Rh^03De=@0c<c<0H61P03@d=00e=CD0ATI602`/;00D51@08b<S
03`l?00m?Cd0=CDe01HF5P0Q8B405ADE03Hf=P0j>SX0<S8b0?ooo`H0fMWI0@0000010=WIf@005P3I
fMT00`000000fMWI0=WIf@030=WIf@150?ooo`2<S8`0UIFE0::RXP2CTi<0Rh^;08Z:RP28R8P0VIVI
08b<S023Ph<0UiNG09bLW02CTi<0RXZ:08j>SP2SXj<0SXj>0:6QX@2?Shl0Xj>S0;Bd]02KVi/0Rh^;
08F5Q@2IVIT0UYJF0;Ng]`1lO7`0RHV909BDU02KVi/0WYjN08j>SP2=SHd0VIVI092@T02IVIT0QHF5
09ZJVP2BTY80UYJF08>3P`2PX:00QhN70:2PX02ATI40U9BD08f=S@2KVi/0QhN708f=S@2DU9@0SHf=
08J6QP2RXZ80[Zj^09>CT`2KVi/0XZ:R08f=S@2PX:00UiNG0;2`/02UYJD0VIVI09fMW@2LW9`0XJ6Q
0080T92@03L0RHV908f=S@2g]kL0WIfM09bLW02a/K40YZJV0:BTY02`/;00U9BD09RHV02GUiL0Vi^K
09>CT`2c/k<0RXZ:0:n_[`2BTY80Ph>309jNWP2BTY80Lg=c09RHV02CTi<0SHf=08V9R@24Q8@0VIVI
09FEU@29RHT0VYZJ09BDU02PX:00YJFU0=;BdP2g]kL0WinO0:n_[`27QhL0UiNG09>CT`2MWId0Y:BT
09jNWP2d];@0YjNW09bLW02;Rh/0RHV908Z:RP2HV9P0[:b/09JFUP2@T900Vi^K0080S8b<00/0TI6A
08:2PP2EUID0NWYj0:>SX`23Ph<0NWYj0:2PX02FUYH0Ph>306UYJ@020820P01:096AT@22PX80QHF5
06EUI@1iNGT0Hf=S061PH01UIFD0K6a/07alO01/K6`0NGUi07QhN01UIFD0G5aL0861P@23Ph<0IfMW
04i>CP1CDe<0PH610820P01mOGd0L71`06YZJP1bLW80Ph>306QXJ01RHV80MgMg07]kN`1/K6`0JVYZ
06UYJ@1^KVh0Jf][06e]K@1fMWH0IVIV07inOP1iNGT0KVi^06=SH`1/K6`0HV9R079bLP1cLg<0LW9b
06UYJ@1HF5P0HV9R06MWI`1JFUX0IfMW04];B`1BDU80MGEe071`L01XJ6P0LG5a065QH@1LG5`0O7al
06IVIP1>CTh0IVIV0492@P1SHf<0Q8B408V9R@1jNWX0Ng]k04M7A`1_Kfl207QhN01106i^KP1XJ6P0
FEUI075aL@1`L700EEEE06][J`1IFET0FUYJ06EUI@16ATH0Hf=S065QH@1NGUh0Kfm_04E5A@1KFe/0
DE5A05IFEP1KFe/0A4A406=SH`11@D40C4a<06UYJ@1DE5@0BDU904E5A@10@400@d=302HV9P1=CDd0
D51@04];B`1TI6@0BDU9055AD@17AdL0J6QX04E5A@1HF5P0I6AT04I6AP1FEUH0BTY:069RHP1:BTX0
?Cdm04Y:BP19BDT0?Cdm03Lg=`1JFUX0;Bd]02PX:00b<S80=CDe03Ph>00a<C40<30`02`/;00R8R80
ADE50410@01=CDd00P16ATH07P0l?3`0?Cdm01lO7`0n?Sh0AdM703/k>`0`<300=SHf04I6AP0m?Cd0
<S8b024Q8@17AdL0=3@d01hN7P0l?3`0C4a<01dM7@0n?Sh0:RXZ03Hf=P0Y:BT0<30`014A4@0W9bL0
92@T03Lg=`0V9RH0?3`l0?ooo`H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WI
f@2`0?ooo`2EUID0QhN70::RXP2DU9@0VYZJ08j>SP1oOgl0WYjN09>CT`2?Shl0S8b<09:BTP2TY:@0
P82009FEU@2SXj<0Rh^;09VIV@2EUID0YjNW07IfMP2RXZ80UIFE09NGU`24Q8@0YjNW092@T02RXZ80
UiNG08n?S`2LW9`0WinO0:VYZ@2?Shl0Vi^K08:2PP2FUYH0T92@09jNWP2:RXX0P82009NGU`1nOWh0
TI6A0::RXP2GUiL0SXj>0:>SX`2MWId0ZJVY09RHV02UYJD0U9BD0;>c/`2BTY80VYZJ0:>SX`2HV9P0
UYJF09RHV02k^k/0W9bL08n?S`2GUiL0VYZJ0:ZZZP2@T900VYZJ09nOW`2DU9@0Ti>C092@T02XZ:P0
Shn?09:BTP2<S8`0^[Zj0;6a/@2MWId0X:2P092@T02^[Zh0YZJV0:BTY02RXZ80QhN709VIV@2HV9P0
S8b<096AT@2=SHd0WYjN09^KV`29RHT0SHf=08:2PP2XZ:P0PH6109JFUP1_Kfl0XJ6Q09^KV`2MWId0
X:2P09:BTP2OWil0U9BD0:^[Z`2IVIT0XJ6Q07emO@2YZJT0X:2P09jNWP2HV9P0XZ:R09VIV@2RXZ80
VYZJ09JFUP2ATI40Y:BT092@T02CTi<0PX:208f=S@2TY:@0UiNG0::RXP2OWil0VIVI0:^[Z`2XZ:P0
UiNG075aL@2?Shl0Rh^;08j>SP27QhL0X:2P0861P@1aLG40Ng]k079bLP2@T900NWYj06m_K`1KFe/0
OWin075aL@1iNGT0Ph>308:2PP1gMgL0GemO06QXJ01bLW80QhN706m_K`1lO7`0RXZ:07AdM024Q8@0
Ogmo06IVIP1^KVh0Lg=c05iNGP1nOWh0MGEe06a/K01^KVh0GEeM07]kN`20P80207IfMP0F07EeM@1[
Jf/0O7al07QhN01fMWH0FEUI06=SH`1hN7P0M7Ad07=cL`1lO7`0GemO05aLG01jNWX0GemO05iNGP1Y
JFT0Ph>307UiN@1gMgL0JFUY065QH@80IfMW02/0Ph>307EeM@1oOgl0IfMW07IfMP1bLW80MGEe08^;
R`29RHT0SHf=06e]K@1iNGT0NWYj07QhN028R8P0NGUi06ATI01iNGT0KVi^04I6AP1ZJVX0820P071`
L01NGUh0E5AD04E5A@1LG5`0A4A404I6AP1PH600>3Ph065QH@0n?Sh0GemO04I6AP0h>3P0<30`05IF
EP0i>CT0F5QH06EUI@1@D500H61P0080FUYJ03l0G5aL05eMG@18B4P0De=C04E5A@1XJ6P0HF5Q05eM
G@16ATH0>c/k04E5A@0j>SX0?3`l05ADE00i>CT0@41004I6AP1:BTX0@D5102d];@1?Cdl0De=C03Ph
>00e=CD0;bl_02@T900e=CD0=3@d03Lg=`0_;bl0=cLg0451@@0o?cl0@41004M7A`0Z:RX0<c<c02TY
:@0X:2P0BTY:02d];@0n?Sh0EUIF04M7A`0Z:RX0>SXj04=3@`0c<c<0:2PX01hN7P1JFUX0@D51018B
4P0`<3009RHV02TY:@0c<c<06a/K02@T900M7Ad020P803<c<`0U9BD00P0L71`00`0V9RH0oooo0=WI
f@050=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT09@3oool0UYJF07YjNP1o
Ogl0TI6A07]kN`1hN7P0SHf=08b<S02GUiL0Xj>S09ZJVP2OWil0VIVI09ZJVP2;Rh/0YZJV0:2PX02=
SHd0X:2P08B4Q02EUID0];Bd08B4Q02:RXX0W9bL07YjNP2CTi<0YJFU08b<S02JVYX0XZ:R0:2PX02O
Wil0WYjN09BDU02VYZH00P2>SXh0B02KVi/0T92@0<30`027QhL0OWin07QhN02IVIT0WinO09:BTP2^
[Zh0QXJ609>CT`2QXJ40S8b<09FEU@2QXJ40SXj>0;:b/P2GUiL0VYZJ0:2PX02HV9P0U9BD0:>SX`2D
U9@0UiNG08Z:RP2CTi<0UiNG08j>SP1nOWh0Ti>C08^;R`22PX80UYJF09nOW`1lO7`0X:2P0:f][@2@
T900RXZ:09ZJVP2BTY80WYjN0:2PX02GUiL0TY:B09JFUP2CTi<0X:2P0;:b/P2NWYh0Shn?08B4Q01^
KVh0WYjN092@T02OWil0QhN70:JVYP26QXH0U9BD09RHV02CTi<0Y:BT09BDU02_[jl0SHf=08:2PP23
Ph<0XJ6Q08f=S@80TI6A02H0XZ:R0:n_[`2SXj<0UYJF0:RXZ02IVIT0TY:B09bLW02@T900S8b<0:BT
Y02RXZ80ZJVY0:2PX02KVi/0Ph>308b<S02KVi/0WYjN0861P@2=SHd0O7al09JFUP2IVIT0QHF50820
P02>SXh0TI6A07MgM`2KVi/0U9BD07moO`1ZJVX0IfMW07YjNP1ZJVX0JFUY07EeM@80MgMg02/0PX:2
08f=S@1cLg<0S8b<06ATI01mOGd0JVYZ06i^KP1/K6`0LW9b069RHP1]KFd0MWIf07UiN@2=SHd0O7al
06YZJP1gMgL0MGEe06][J`28R8P0LG5a08B4Q01/K6`0JFUY06=SH`1[Jf/0NGUi07moO`1dM7@0IFEU
06ATI01WIfL0J6QX06][J`1eMGD0De=C069RHP1dM7@0MgMg06=SH`1jNWX0GUiN0080I6AT00H0Lg=c
08B4Q027QhL0L71`06ATI01oOgl207=cL`0H07moO`2?Shl0Ng]k07UiN@1[Jf/0Lg=c06m_K`1/K6`0
LW9b07UiN@16ATH0E5AD07MgM`1ZJVX0Jf][07UiN@1OGel0OGem065QH@1EEED0H61P06UYJ@1cLg<0
MWIf0P1LG5`09@1GEeL0Cdm?03hn?P1BDU80IFEU06ATI01PH600FUYJ04M7A`1LG5`0JFUY04A4A00E
5AD0>SXj03`l?01ADE40CTi>05]KF`1HF5P0Ogmo05IFEP1?Cdl0FEUI06MWI`1ZJVX0EeMG05mOG`1I
FET0I6AT03<c<`1FEUH0D51@059BDP18B4P0ATI604E5A@0k>c/00P16ATH0101;Bd/0@d=304=3@`0c
<c<20451@@030410@00c<c<0?Shn0080>SXj00X04A4A0451@@0o?cl061PH04M7A`16ATH0BTY:03Hf
=P1>CTh0ATI60P0g=cL0500P8200ATI603dm?@0Y:BT0?Cdm02XZ:P0`<30061PH03`l?00O7al0;2`/
00`<3012@T80=SHf01`L700<30`04Q8B01XJ6P0[:b/0oooo1P3IfMT100000040fMWI000F0=WIf@03
0000003IfMT0fMWI00<0fMWI01D0oooo092@T028R8P0Ng]k09FEU@1lO7`0XZ:R08^;R`2FUYH0QXJ6
0:2PX021PH40V9RH09JFUP2LW9`0R8R8096AT@2JVYX0F5QH09:BTP2HV9P00P2d];@0]P2VYZH0PX:2
0:6QX@1^KVh0U9BD0:6QX@24Q8@0X:2P08b<S02WYjL0VIVI0:f][@2c/k<0Vi^K08Z:RP25QHD0TY:B
08f=S@2OWil0UYJF09fMW@28R8P0S8b<09>CT`1eMGD0UIFE0;6a/@2@T900YZJV0:ZZZP2@T900WYjN
09RHV02GUiL0V9RH09fMW@2;Rh/0RXZ:092@T02b/[80UIFE09RHV02@T900S8b<08B4Q02KVi/0PX:2
09nOW`2_[jl0]KFe0;2`/02FUYH0S8b<08j>SP2EUID0Xj>S09ZJVP29RHT0TY:B0:ZZZP2MWId0Ti>C
09jNWP2PX:00V9RH08f=S@2PX:00VYZJ09>CT`2EUID0YZJV09RHV025QHD0UiNG0:NWY`2JVYX0U9BD
0:j^[P2LW9`0UYJF08V9R@2HV9P0Rh^;09bLW02FUYH0[Jf]09:BTP2QXJ40Ti>C09nOW`2>SXh0RXZ:
09NGU`2RXZ80ZJVY096AT@2GUiL0WIfM0:BTY02VYZH0SHf=0:ZZZP2:RXX0YJFU09ZJVP2SXj<0Ti>C
09jNWP2>SXh0VIVI08n?S`2NWYh0TI6A08J6QP2@T900MGEe08B4Q01lO7`0LG5a08B4Q01WIfL0O7al
08N7Q`1hN7P0Ti>C08>3P`1[Jf/0NGUi06YZJP1XJ6P0MGEe075aL@20P800QHF507UiN@1_Kfl0O7al
055AD@2:RXX0QHF507UiN@2DU9@0JVYZ06e]K@26QXH0LG5a06MWI`1eMGD0K6a/071`L01[Jf/0R8R8
079bLP1cLg<0Ogmo069RHP1PH600Ng]k06ATI02>SXh0Ogmo07IfMP21PH40NGUi06EUI@1ADE40KFe]
06QXJ01iNGT0JFUY05UIF@1@D500J6QX079bLP1OGel0O7al07]kN`1IFET0GEeM06][J`1VIVH0NWYj
0P1hN7P05P20P800KVi^05IFEP1lO7`0L71`07=cL`24Q8@0J6QX04E5A@1BDU80HV9R07IfMP1eMGD0
KFe]07QhN01aLG40FEUI061PH00o?cl0D51@04E5A@18B4P2061PH017075aL@0f=SH0EUIF0410@01N
GUh0GemO071`L011@D40IVIV05MGE`13@d<0Bd];06MWI`1IFET0<30`03Ph>01;Bd/0Fe]K04e=C@1J
FUX0QhN705ADE01@D500CDe=04];B`1GEeL0=SHf05aLG019BDT0<S8b04U9B@0`<300GemO04Q8B00n
?Sh0CTi>03dm?@0n?Sh0?3`l04];B`1<C4`0;Bd]03/k>`10@400<c<c0410@00^;Rh0>c/k03Xj>P10
@400?clo04e=C@0j>SX0ADE504];B`0`<300?clo04Y:BP1>CTh0=CDe03/k>`0h>3P0>c/k055AD@0f
=SH0ATI604a<C00b<S80;Rh^03dm?@0i>CT00P0e=CD02P17AdL02PX:02h^;P0=3@d09BDU020P800[
:b/0:RXZ01XJ6P3oool60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0;P3o
ool0UYJF08j>SP1mOGd0WinO08f=S@2CTi<0P8200:6QX@2?Shl0UYJF09:BTP2CTi<0QHF507UiN@25
QHD0UYJF096AT@2HV9P0[Jf]09>CT`2^[Zh0RHV909>CT`2?Shl0XJ6Q0::RXP20P800Vi^K0:FUY@2>
SXh0WIfM0:NWY`2@T900QXJ609bLW01fMWH0TI6A09:BTP2=SHd0V9RH08j>SP2GUiL0ZJVY09^KV`2I
VIT20:b/[080QXJ60P27QhL0102MWId0X:2P09JFUP2:RXX209>CT`0609fMW@2EUID0XJ6Q0:j^[P2E
UID0Vi^K0P29RHT0F026QXH0UYJF09NGU`2OWil0ZJVY0:RXZ02ATI40Xj>S096AT@21PH40WYjN08b<
S02LW9`0WYjN08N7Q`2EUID0UiNG09BDU02JVYX0W9bL0:>SX`2BTY80TI6A09jNWP2[Zj/0W9bL0;>c
/`20P800SHf=09nOW`2BTY80U9BD096AT@21PH40Lg=c09>CT`2ATI40Y:BT08B4Q02KVi/0V9RH0::R
XP2GUiL0RHV909RHV02YZJT0TY:B08>3P`25QHD0Y:BT08N7Q`2RXZ80[Jf]09nOW`2MWId0VYZJ09^K
V`2GUiL0V9RH09BDU02HV9P0TI6A0:VYZ@2LW9`0Y:BT0::RXP2JVYX0QHF508N7Q`2OWil0QXJ6096A
T@2EUID0PX:208J6QP1nOWh0V9RH08j>SP1cLg<0QhN707emO@22PX80LW9b08:2PP2;Rh/0Kfm_08B4
Q01eMGD2075aL@0307]kN`1dM7@0S8b<0080Ogmo0100RXZ:07emO@1hN7P0PH6108:2PP1ADE40Cdm?
07EeM@1YJFT0JVYZ07emO@1QHF40Hf=S09VIV@1^KVh0K6a/0P1[Jf/0<P1TI6@0MgMg065QH@1hN7P0
Lg=c07YjNP1nOWh0Fe]K06i^KP1/K6`0GUiN075aL@1CDe<0I6AT079bLP1ZJVX0IFEU07MgM`1[Jf/0
H61P06QXJ01lO7`0MGEe07UiN@27QhL0HF5Q06][J`1eMGD0NGUi07QhN01WIfL0OWin08^;R`1XJ6P0
Ph>308f=S@1_Kfl0N7Qh06e]K@1kNg/0IFEU075aL@1VIVH0JVYZ04m?C`1[Jf/0H61P05YJFP1CDe<0
Fe]K0P1;Bd/0?`1MGEd0H61P04e=C@1@D500IFEU04U9B@1EEED0LG5a05]KF`0k>c/0A4A404Y:BP1C
De<0HF5Q05QHF01@D500HV9R04i>CP15ADD0Xj>S05eMG@1NGUh0I6AT051@D018B4P0J6QX065QH@12
@T80EeMG05ADE01;Bd/0DU9B0451@@0g=cL0A4A401`L7017AdL0Bd];03@d=015ADD0:RXZ04Q8B01E
EED0<c<c04A4A01:BTX0B4Q802<S8`1:BTX0;Bd]02LW9`0f=SH0;bl_02h^;P0[:b/0ATI604Q8B00c
<c<0;Bd]04M7A`0c<c<0:b/[04A4A002034a<@0B03hn?P18B4P0;bl_05ADE016ATH0B4Q803De=@18
B4P0ATI603lo?`0P8200?3`l02XZ:P0`<3004a<C02<S8`0V9RH0oooo1P3IfMT100000040fMWI000F
0=WIf@030000003IfMT0fMWI00<0fMWI08/0oooo09>CT`23Ph<0X:2P08f=S@25QHD0VYZJ096AT@2I
VIT0Ti>C092@T02JVYX0YJFU09>CT`23Ph<0WYjN0:JVYP2KVi/0[:b/09:BTP2@T900VIVI0:VYZ@1m
OGd0SHf=09JFUP20P800V9RH0:NWY`29RHT0RXZ:0:FUY@2PX:00WIfM08b<S02LW9`0VIVI0:JVYP2H
V9P0QXJ608Z:RP2ATI40Q8B409RHV02XZ:P0X:2P08R8R02ATI40I6AT09NGU`2OWil0XZ:R0:6QX@2L
W9`0XZ:R092@T02EUID0YjNW09fMW@2FUYH0T92@09VIV@2YZJT0Vi^K08b<S024Q8@0SXj>08^;R`2X
Z:P0XJ6Q096AT@2OWil0VYZJ0:RXZ029RHT0/;2`07UiN@2JVYX0XJ6Q08j>SP2SXj<0XJ6Q092@T02G
UiL0XJ6Q09nOW`2YZJT0UIFE09>CT`2YZJT0V9RH0:ZZZP2PX:00VYZJ0:f][@2FUYH0S8b<09fMW@2A
TI40XZ:R0:JVYP2GUiL0PX:209NGU`2QXJ40Vi^K07IfMP2XZ:P0WYjN0;Vi^@22PX80YZJV09bLW02O
Wil0VYZJ09bLW02KVi/0/[:b0:b/[02NWYh0XZ:R09VIV@2PX:00UIFE096AT@2UYJD0PH6108j>SP2@
T900Vi^K09bLW020P800Ogmo08n?S`2@T900NWYj09BDU028R8P0Ti>C0080RXZ:0300Q8B408V9R@2>
SXh0SXj>08b<S01jNWX0OWin07EeM@1mOGd0LW9b06IVIP1_Kfl0TY:B05mOG`23Ph<0OWin0861P@1n
OWh0QHF50861P@20P800R8R806QXJ01mOGd0QHF5079bLP1hN7P0L71`08b<S01gMgL0Lg=c06m_K`1g
MgL0Ph>307]kN`1YJFT0LW9b05EEE@1`L700EEEE04m?C`1TI6@0Q8B405UIF@1_Kfl0IfMW07EeM@1M
GEd206a/K00S06][J`1^KVh0HF5Q06QXJ01]KFd0KVi^07AdM01OGel0I6AT071`L01iNGT0Hf=S07Yj
NP1eMGD0Lg=c07]kN`1`L700De=C0861P@1XJ6P0N7Qh071`L02@T900MgMg07moO`1iNGT0LG5a05UI
F@1WIfL0QXJ608>3P`1VIVH0HV9R05YJFP1UIFD00P1XJ6P01`1YJFT0DU9B05iNGP1EEED0FUYJ06AT
I01KFe/00P1HF5P03@1QHF40Hf=S051@D015ADD0DU9B04m?C`0l?3`0Bd];05=CD`1OGel0Fe]K05iN
GP1LG5`00P1JFUX0=P1IFET0D51@04i>CP0e=CD0GEeM0451@@1IFET0De=C05mOG`0e=CD0D51@03Hf
=P12@T80=CDe04a<C00m?Cd0>3Ph055AD@0m?Cd0Bd];051@D017AdL0FUYJ03Ti>@0g=cL0=SHf04E5
A@0];Bd0D51@04I6AP19BDT0;Rh^03De=@1>CTh0ATI603lo?`0h>3P0;Rh^02XZ:P000000<30`03Lg
=`0b<S80?Cdm038b<P0R8R80:b/[03`l?013@d<0Cdm?03lo?`0@4100:b/[018B4P807AdM00H0820P
02l_;`0T92@0:b/[00X:2P3oool60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3I
fMT0P03oool0YjNW0:ZZZP2HV9P0Q8B4096AT@2:RXX0WYjN08B4Q028R8P0Vi^K0:BTY02PX:00VIVI
08N7Q`2BTY8010@408f=S@2>SXh0Rh^;0:ZZZP2IVIT0Zj^[08N7Q`1oOgl0[jn_0:>SX`2ATI40Xj>S
08R8R02i^KT0QHF50:JVYP2YZJT0RXZ:09>CT`2QXJ40YJFU0:6QX@2GUiL0ZJVY08f=S@2VYZH0ZJVY
07moO`2BTY80X:2P08^;R`2IVIT0Shn?09RHV020P800Xj>S09NGU`2MWId0S8b<0:b/[025QHD0^[Zj
0;:b/P26QXH0WinO0::RXP2OWil0JFUY09NGU`2;Rh/0W9bL08f=S@26QXH0[Jf]09>CT`2ATI40Rh^;
08B4Q02QXJ40SXj>09ZJVP2?Shl0WIfM0:2PX02MWId0TY:B09fMW@2PX:00Xj>S096AT@23Ph<0SXj>
0861P@2BTY80QhN7096AT@2NWYh0SXj>09>CT`2<S8`0Xj>S0861P@2SXj<0XJ6Q09FEU@2/[:`0Ti>C
0:NWY`1nOWh0UYJF09fMW@2SXj<0Z:RX08^;R`2_[jl0YZJV09^KV`2EUID0RHV909jNWP2/[:`0WYjN
09VIV@2:RXX0[Jf]07]kN`2/[:`0WIfM0:ZZZP1kNg/0UiNG0P2RXZ803@2KVi/0UiNG08f=S@1nOWh0
NWYj07EeM@20P800T92@08>3P`2@T900OGem08^;R`1oOgl00P2=SHd0V`27QhL0PH6105mOG`1jNWX0
R8R8071`L01nOWh0JVYZ08N7Q`1jNWX0JVYZ07IfMP1hN7P0Ogmo06YZJP1WIfL0Ng]k07MgM`1lO7`0
MGEe06e]K@1oOgl0KVi^059BDP1VIVH0IfMW07inOP27QhL0SHf=07moO`1lO7`0QXJ608N7Q`1dM7@0
O7al07YjNP1LG5`0K6a/08F5Q@1LG5`0OGem05UIF@1fMWH0Jf][071`L01_Kfl0LW9b07moO`1hN7P0
L71`06a/K01UIFD0F5QH059BDP1UIFD0MgMg07IfMP1/K6`0P8200861P@1^KVh0Jf][04I6AP1SHf<0
JVYZ05UIF@1YJFT0QHF5065QH@1fMWH0LG5a07moO`23Ph<0Kfm_06a/K01bLW80KVi^06IVIP1YJFT0
GemO08:2PP1OGel0Hf=S04U9B@1VIVH0GEeM06ATI01<C4`0?clo05ADE01<C4`0A4A406QXJ01hN7P0
FEUI06YZJP1/K6`0@d=3059BDP1ADE40L71`05QHF01JFUX0D51@04M7A`1ADE40JFUY05MGE`1FEUH0
EeMG05YJFP1>CTh0FEUI04Y:BP18B4P0HF5Q03De=@0^;Rh0Fe]K069RHP1FEUH0C4a<03/k>`1BDU80
?Cdm034a<@0l?3`0:b/[028R8P13@d<0Cdm?04E5A@0n?Sh0=3@d0492@P0j>SX0D51@04];B`11@D40
DE5A04m?C`1<C4`0>c/k04Q8B00W9bL0:RXZ038b<P0/;2`0@T9203`l?00e=CD0?Shn05]KF`10@400
B4Q80080?clo00`0=CDe02/[:`0f=SH0;Rh^030`<00i>CT0:b/[0492@P061PH0410@02HV9P3oool6
0=WIf@4000000@3IfMT000<0fMWI0`0000020=WIf@800000103IfMT2000000H0fMWI00<000000=WI
f@3IfMT00`3IfMT06@3oool0Vi^K092@T02KVi/0Rh^;09BDU021PH40TI6A09VIV@2GUiL0UIFE0:JV
YP2<S8`0SXj>08f=S@2KVi/0V9RH0:2PX02CTi<0UiNG09RHV02=SHd0UIFE08f=S@23Ph<00P2DU9@0
3`2IVIT0T92@0;2`/02GUiL0U9BD0:ZZZP2BTY80WIfM0820P01gMgL0WinO0:BTY02IVIT0RHV90:>S
X`0209^KV`1Q0:j^[P2@T900Zj^[09JFUP2<S8`0X:2P09bLW01dM7@0YJFU0:VYZ@24Q8@0RHV909NG
U`2@T900OWin0:6QX@2TY:@0V9RH09FEU@2TY:@0RHV90:2PX02QXJ40TI6A08n?S`2QXJ40YZJV08:2
PP2=SHd0Ph>30:2PX028R8P0UIFE09bLW02GUiL0YJFU08V9R@2WYjL0UYJF08Z:RP2UYJD0Z:RX0:6Q
X@2ATI40T92@08J6QP1jNWX0RHV909nOW`1`L700WIfM08f=S@24Q8@0WYjN06][J`2DU9@0WIfM08f=
S@2QXJ40TI6A09bLW025QHD0TY:B06QXJ01mOGd0Vi^K096AT@2WYjL0[:b/08b<S02JVYX0Vi^K0;Bd
]02OWil0UiNG09RHV027QhL0Ti>C09BDU026QXH0SHf=09:BTP27QhL0Rh^;0::RXP2EUID0UYJF09VI
V@2GUiL0SHf=0:6QX@26QXH0Xj>S08F5Q@2][Jd0VIVI0:BTY00207UiN@0_07emO@1cLg<0OWin07Yj
NP1TI6@0Kfm_0820P01lO7`0IfMW07UiN@1TI6@0MGEe07UiN@1kNg/0O7al07QhN01fMWH0OGem08>3
P`1kNg/0HV9R05]KF`1/K6`0MgMg075aL@1FEUH0Ng]k06EUI@1oOgl0PX:207]kN`1bLW80Kfm_07em
O@20P800K6a/07YjNP1hN7P0KFe]09:BTP1LG5`0Lg=c08>3P`20P800PH6106a/K01gMgL00P1[Jf/0
?`1WIfL0Ph>3079bLP1jNWX0MGEe04U9B@13@d<0MWIf06m_K`1NGUh0IVIV08J6QP1gMgL0H61P05]K
F`000000OWin08j>SP26QXH0OWin069RHP1`L700Kfm_06EUI@1bLW80QXJ606a/K01TI6@0EEEE06m_
K`1fMWH0Hf=S06YZJP1VIVH0@D5105eMG@1PH600BTY:05eMG@1XJ6P0@d=306MWI`10@400Bd];055A
D@1^KVh0F5QH059BDP1IFET0De=C05]KF`1WIfL0GUiN05MGE`1>CTh0Fe]K04I6AP1IFET0EeMG04E5
A@1KFe/0>SXj05QHF00205IFEP0i05YJFP1RHV80:b/[03Xj>P1CDe<0I6AT05eMG@12@T80Cdm?04I6
AP1MGEd0@T9205ADE00O7al0AdM703hn?P1?Cdl0>3Ph04=3@`14A4@0B4Q8059BDP1@D500:BTY0410
@01>CTh0B4Q80410@018B4P0AdM704I6AP0V9RH0?Shn030`<00^;Rh0Cdm?0451@@0i>CT0=cLg02XZ
:P18B4P0;2`/05QHF00S8b<0CTi>02TY:@0f=SH0=3@d03Ti>@0W9bL0:BTY03De=@0a<C40:RXZ03`l
?00Z:RX0oooo00H0fMWI0@0000010=WIf@00103IfMT010000000fMWI0=WIf@0000020=WIf@040000
003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@0I
0?ooo`2HV9P0U9BD0:2PX02@T900TY:B09bLW02TY:@0Rh^;09VIV@20P800SXj>07UiN@2CTi<0YJFU
0;6a/@2<S8`0VIVI096AT@2IVIT0XJ6Q0:2PX02FUYH0Ti>C09RHV0020;2`/01909VIV@26QXH0Vi^K
09JFUP2b/[80Xj>S0:6QX@2HV9P0Y:BT09VIV@2^[Zh0VIVI0:>SX`2:RXX0VYZJ08V9R@2ATI40];Bd
09^KV`2XZ:P0YZJV08f=S@2MWId0Q8B40:BTY02QXJ40Q8B409JFUP2QXJ40W9bL09BDU028R8P0UiNG
0:j^[P2a/K40T92@09ZJVP2FUYH0UIFE09JFUP2KVi/0UYJF08j>SP2PX:00V9RH09nOW`1hN7P0RXZ:
08J6QP20P800PX:208^;R`2ATI40JFUY08F5Q@22PX80I6AT06m_K`23Ph<0MgMg09JFUP2CTi<0Ph>3
0:RXZ027QhL0HF5Q0:ZZZP2EUID0[Zj^07YjNP2<S8`0Rh^;08>3P`0209JFUP1H07alO02BTY80Ph>3
0:VYZ@2CTi<0UYJF0:2PX02ATI40Shn?0:>SX`2DU9@0T92@09JFUP2_[jl0VYZJ09jNWP2@T900[Zj^
09^KV`2a/K40YZJV0:2PX02@T900R8R809:BTP2VYZH0X:2P0;Ng]`1eMGD0Ti>C09:BTP2ATI40UIFE
07YjNP2HV9P0Rh^;08R8R02>SXh0QHF507IfMP25QHD0Y:BT08Z:RP1aLG40QXJ60861P@1`L700Ng]k
075aL@1bLW80Ng]k06a/K01^KVh0Kfm_06UYJ@1iNGT0QhN706i^KP1]KFd0SHf=07MgM`2DU9@0R8R8
07alO01mOGd0H61P0820P01YJFT0N7Qh07EeM@1dM7@0JFUY08^;R`1eMGD0RXZ:0861P@2BTY80PX:2
065QH@1kNg/0JVYZ08V9R@2=SHd0Rh^;075aL@22PX80Q8B406i^KP80NGUi0P1eMGD0@P1XJ6P0Jf][
06YZJP1[Jf/0GemO07emO@1OGel0SXj>05YJFP1cLg<0PX:2079bLP1lO7`0Jf][0820P01jNWX0L71`
0861P@1jNWX0M7Ad051@D01_Kfl0Lg=c05aLG01OGel0Ph>3051@D01`L700I6AT05UIF@1NGUh0KFe]
05UIF@1VIVH0I6AT06EUI@1LG5`0FUYJ051@D01KFe/0=SHf05IFEP1LG5`0I6AT05mOG`15ADD0JVYZ
05QHF00/;2`0?Cdm05iNGP1CDe<0GemO06UYJ@0n?Sh0De=C05EEE@1DE5@0HF5Q04Y:BP1=CDd0Fe]K
06QXJ01IFET0B4Q803hn?P80@d=301D0C4a<04Q8B00m?Cd0AdM705MGE`0f=SH0AdM705YJFP1BDU80
?clo03Ti>@1=CDd0=CDe04Q8B01@D500FUYJ05MGE`0a<C40B4Q8051@D00f=SH00P16ATH02`0h>3P0
@D510410@018B4P0?clo055AD@1>CTh0?3`l02PX:012@T80;Rh^0080C4a<0100;Bd]0451@@0`<300
>c/k02DU9@0l?3`0DE5A030`<00e=CD09RHV00`<300N7Qh07alO02h^;P0Y:BT0oooo1P3IfMT10000
0040fMWI00000`3IfMT0000000000003000000050=WIf@000000fMWI0=WIf@0000000P3IfMT01000
0000fMWI0=WIf@0000050=WIf@<000000`3IfMT0=@3oool0Vi^K09jNWP2SXj<0T92@07MgM`28R8P0
UIFE08n?S`2VYZH0Ti>C09RHV02CTi<0UiNG08Z:RP2NWYh0Xj>S0:2PX02IVIT0T92@09bLW02`/;00
W9bL0;2`/02PX:00YZJV09ZJVP2GUiL0Ti>C08V9R@2ZZZX0XJ6Q09NGU`1RHV80N7Qh096AT@2YZJT0
W9bL09^KV`2QXJ40Shn?092@T02RXZ80WIfM0:BTY021PH40[Zj^09NGU`1oOgl0Vi^K08>3P`2d];@0
UiNG0080SXj>02L0Ti>C09ZJVP2PX:00V9RH09BDU02=SHd0WinO0:BTY02:RXX0VYZJ071`L027QhL0
Ph>309FEU@2OWil0S8b<09jNWP2GUiL0WYjN09FEU@2<S8`0Z:RX09:BTP2>SXh0JFUY08B4Q021PH40
U9BD05mOG`1TI6@0Fe]K079bLP2DU9@0Shn?0:^[Z`2NWYh0TY:B08n?S`1nOWh00P2?Shl0LP24Q8@0
T92@0861P@20P800T92@09fMW@1aLG40PH61096AT@2>SXh0W9bL09NGU`2ZZZX0VYZJ09JFUP2][Jd0
WinO09BDU02BTY80SXj>09BDU02IVIT0RXZ:09bLW02@T900[:b/08Z:RP2MWId0VIVI0:JVYP2HV9P0
R8R80:6QX@2NWYh0VYZJ08j>SP1^KVh0Ti>C08n?S`2LW9`0Shn?08N7Q`20P800LG5a08Z:RP1GEeL0
VYZJ07=cL`21PH40QHF5069RHP1gMgL0IfMW059BDP1bLW80M7Ad05iNGP1KFe/0RXZ:079bLP22PX80
HV9R07QhN01lO7`0GEeM07moO`1[Jf/0L71`06EUI@1dM7@0LG5a06e]K@1ZJVX0N7Qh07UiN@1bLW80
M7Ad06i^KP1aLG40M7Ad06m_K`1dM7@0PH6107UiN@1oOgl0QHF507MgM`2;Rh/0KVi^05]KF`1iNGT0
KVi^075aL@1WIfL0LW9b06IVIP1oOgl0HF5Q079bLP1GEeL0IFEU08B4Q01ZJVX0PX:208B4Q01SHf<0
E5AD07=cL`1_Kfl0H61P06e]K@1_Kfl0Lg=c07AdM080Ph>306H0PX:206EUI@1YJFT0MGEe06a/K01Q
HF40L71`065QH@1iNGT0GemO06ATI01ZJVX0FEUI04Q8B01kNg/0KVi^06QXJ01^KVh0Bd];06UYJ@0l
?3`0J6QX05]KF`13@d<0I6AT06EUI@1JFUX0CTi>03/k>`1KFe/0B4Q8055AD@1BDU80BTY:05YJFP1R
HV80F5QH065QH@1IFET0CDe=05EEE@1CDe<0GUiN069RHP0l?3`0BTY:04A4A01?Cdl0@41003Xj>P0c
<c<0BTY:05UIF@1:BTX0@d=303lo?`1FEUH0@D5103dm?@1TI6@0B4Q802XZ:P1PH600>SXj069RHP15
ADD0<S8b04i>CP0j>SX0?3`l03hn?P1SHf<0F5QH04];B`0n?Sh0:2PX03De=@0n?Sh0>CTi059BDP0n
?Sh0DE5A059BDP17AdL0:BTY03Lg=`0^;Rh0=3@d02h^;P0/;2`0:2PX02`/;00n?Sh030`<01XJ6P0S
8b<061PH01lO7`0;2`/05aLG02LW9`3oool40=WIf@<000000@3IfMT000050=WIf@000000fMWI0=WI
f@0000000P3IfMT010000000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI000000D0fMWI00<0
00000=WIf@3IfMT00`3IfMT0;@3oool0VIVI0:FUY@2ATI40ZZZZ08:2PP2CTi<0TI6A0:FUY@2KVi/0
Ti>C092@T02VYZH0UIFE096AT@2ZZZX0YJFU0:NWY`2MWId0W9bL0;2`/02SXj<0WinO092@T02PX:00
Ogmo09NGU`2KVi/0UiNG09ZJVP2PX:00WIfM09^KV`000000ZJVY09>CT`2?Shl0QXJ609FEU@2XZ:P0
WIfM08R8R02@T900Zj^[07emO@0207MgM`0o08^;R`2KVi/0WinO096AT@2LW9`0TY:B0:n_[`2MWId0
V9RH0:VYZ@2KVi/0YZJV09:BTP29RHT0X:2P09RHV027QhL0SHf=06][J`1bLW80UiNG08j>SP2BTY80
S8b<09:BTP1`L700Shn?08N7Q`1dM7@0IVIV07UiN@1_Kfl0O7al07IfMP1^KVh0FUYJ079bLP1OGel0
MWIf07MgM`1lO7`0Ogmo08J6QP2<S8`0U9BD08B4Q02?Shl0SHf=0:RXZ02EUID0T92@08Z:RP27QhL0
YJFU09nOW`2ATI40Ng]k09RHV027QhL0UiNG0;Zj^P2UYJD0TY:B0080YZJV0580TY:B08n?S`27QhL0
/K6a09bLW02GUiL0VIVI09:BTP2UYJD0XZ:R09VIV@2CTi<0X:2P09^KV`2FUYH0Y:BT0:FUY@2GUiL0
_;bl08V9R@1gMgL0SXj>08n?S`2GUiL0YZJV08j>SP2BTY80Ogmo08N7Q`2CTi<0Ph>308:2PP1iNGT0
M7Ad04Y:BP1FEUH0F5QH075aL@1eMGD0RXZ:06IVIP1ADE40K6a/06IVIP1hN7P0Jf][075aL@1oOgl0
LG5a07MgM`2?Shl0S8b<06YZJP1MGEd0RXZ:05iNGP1eMGD0Lg=c069RHP1kNg/0Ogmo07AdM01oOgl0
MgMg08n?S`1gMgL0Hf=S07moO`1_Kfl0MWIf08B4Q029RHT0Jf][075aL@1hN7P0LW9b06m_K`1ZJVX0
PX:207UiN@1oOgl0Jf][0P1IFET0MP1NGUh0Hf=S06QXJ01dM7@0HF5Q07EeM@1gMgL0Hf=S06UYJ@1^
KVh0P82008b<S01kNg/0KVi^06=SH`1bLW80MGEe07=cL`1`L700HF5Q06YZJP1hN7P0Lg=c07alO01S
Hf<0MGEe06QXJ01OGel0E5AD06MWI`1CDe<0F5QH069RHP1KFe/0EeMG03lo?`13@d<0B4Q805=CD`14
A4@0Hf=S04m?C`1@D500F5QH06ATI013@d<0ATI604a<C01MGEd0EUIF055AD@0m?Cd0Hf=S05YJFP1P
H600CDe=04i>CP1<C4`0H61P05EEE@0m?Cd0EEEE061PH017AdL0E5AD04i>CP0m?Cd0CTi>05ADE00`
<300ATI604a<C01RHV80EUIF04=3@`1BDU80A4A404I6AP0k>c/0DU9B03<c<`17AdL0=CDe04M7A`18
B4P0D51@03lo?`0m?Cd0BTY:04i>CP1GEeL0@D5103dm?@1;Bd/0<C4a04=3@`1>CTh05aLG03@d=00Z
:RX0@410038b<P0T92@08R8R03`l?00V9RH08B4Q030`<00Y:BT0820P018B4P0000008b<S01PH600C
4a<05QHF03Ti>@3oool60=WIf@4000000@3IfMT00080fMWI00<000000=WIf@0000000P3IfMT01000
0000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI000000D0fMWI00<000000=WIf@3IfMT00`3I
fMT02P3oool0[Jf]0:2PX02JVYX0MGEe07YjNP2UYJD0WYjN09FEU@2:RXX208N7Q`80UIFE00T0PX:2
07alO02JVYX0XZ:R09^KV`2JVYX0YZJV0:j^[P2TY:@00P2DU9@08`29RHT0W9bL09VIV@21PH40[Zj^
09JFUP2JVYX0[Zj^08F5Q@2NWYh0X:2P09nOW`2<S8`0VIVI09:BTP2ATI40ZJVY09NGU`26QXH0YZJV
09:BTP2VYZH0RXZ:09jNWP2[Zj/0XZ:R09>CT`29RHT0TI6A07]kN`2BTY80WinO08R8R02DU9@0UIFE
0080QhN704h0XJ6Q0::RXP1lO7`0J6QX07moO`1lO7`0PX:20820P028R8P0NWYj08f=S@1hN7P0VYZJ
08N7Q`26QXH0P82008>3P`1oOgl0JFUY08:2PP1`L700Jf][07MgM`1DE5@0OWin09BDU01TI6@0Lg=c
08f=S@2BTY80Shn?092@T02KVi/0Rh^;0:2PX02LW9`0OGem08V9R@2?Shl0TI6A0:>SX`2KVi/0TI6A
07MgM`2DU9@0VIVI0:ZZZP2ATI40X:2P09JFUP17AdL0YZJV0:>SX`2UYJD0Vi^K09VIV@2WYjL0ZZZZ
04I6AP2FUYH0_kno0:^[Z`2ATI40VYZJ09BDU02UYJD0WIfM0:6QX@2RXZ80PH6109VIV@2LW9`0UiNG
09bLW02<S8`0RXZ:075aL@1mOGd209jNWP2009>CT`1nOWh0Ph>307emO@1gMgL0Ogmo075aL@2@T900
J6QX06m_K`1[Jf/0HF5Q06MWI`1nOWh0MGEe06m_K`1>CTh0PX:208B4Q01aLG40Q8B4092@T01YJFT0
MGEe07emO@1aLG40KFe]07UiN@1^KVh0Kfm_05MGE`1NGUh0Lg=c0861P@1]KFd0NGUi07moO`27QhL0
MGEe07alO01/K6`0IVIV08f=S@1JFUX0G5aL0820P01jNWX0Q8B40861P@1_Kfl0OWin075aL@1eMGD0
Kfm_059BDP1SHf<0E5AD05YJFP1MGEd0GemO075aL@1QHF40MGEe07MgM`1bLW80MgMg079bLP2@T900
G5aL05MGE`22PX80KFe]07alO01/K6`0QhN706QXJ01?Cdl0IVIV06=SH`1TI6@0IFEU04e=C@1dM7@0
CDe=07UiN@1[Jf/0KFe]07QhN01UIFD0HF5Q05YJFP1[Jf/0?clo03Hf=P1FEUH0:RXZ0492@P1RHV80
ATI604A4A01=CDd0;bl_0451@@1MGEd0C4a<04];B`1TI6@0Cdm?04Y:BP1HF5P0?Shn05MGE`19BDT0
KFe]04Q8B015ADD0?Shn05iNGP1XJ6P0D51@028R8P0e=CD0<c<c061PH00k>c/0FEUI04];B`0a<C42
051@D00I02/[:`1TI6@0IfMW059BDP1>CTh0B4Q8030`<00j>SX0F5QH04A4A01<C4`0I6AT04M7A`1?
Cdl0AdM704U9B@1:BTX0?clo04i>CP1@D500@d=303`l?01<C4`0ATI601@D500203/k>`0?03dm?@0f
=SH0>c/k03Hf=P0e=CD0?clo02d];@0/;2`0>SXj01dM7@0];Bd0:b/[01lO7`0>3Ph0oooo00H0fMWI
0@0000010=WIf@000`3IfMT2000000<0fMWI0P0000040=WIf@8000001P3IfMT00`000000fMWI0=WI
f@030=WIf@0;0?ooo`2EUID0QXJ609>CT`2<S8`0Lg=c08J6QP2TY:@0WIfM09>CT`2BTY800P2SXj<0
7P2OWil0WIfM0:NWY`2RXZ80TY:B07EeM@28R8P0V9RH09JFUP2NWYh0[jn_08Z:RP24Q8@0W9bL0:2P
X02CTi<0WinO08V9R@2OWil0Vi^K0:VYZ@2][Jd0SHf=09:BTP1mOGd0QHF50:6QX@2MWId0V9RH09jN
WP80WinO00X0Ti>C09ZJVP2LW9`0[:b/09^KV`2HV9P0SHf=0:>SX`2IVIT0/[:b0P2WYjL0?`2][Jd0
VIVI07alO02JVYX0QhN708:2PP21PH40XZ:R08^;R`27QhL0T92@09>CT`2EUID0WIfM08V9R@23Ph<0
RXZ:09JFUP1dM7@0Ogmo079bLP1aLG40KVi^07AdM01cLg<0LG5a07YjNP20P800MgMg07IfMP1bLW80
NWYj08>3P`1kNg/0Ph>30820P02BTY80Ogmo06i^KP2@T900Ph>308J6QP2=SHd0WIfM08f=S@2EUID0
VIVI0;>c/`2RXZ80UiNG08^;R`2MWId0R8R809bLW02TY:@0MGEe08j>SP2SXj<0Z:RX09BDU02XZ:P0
UiNG0::RXP0209fMW@0F08n?S`2DU9@0TI6A0:RXZ02LW9`0ZJVY09>CT`2<S8`0UYJF08J6QP2HV9P0
RXZ:06UYJ@1nOWh0YjNW08J6QP2CTi<0O7al08R8R01iNGT0LW9b07=cL`80R8R805L0OWin07emO@1R
HV80P82006][J`23Ph<0KFe]07EeM@23Ph<0LW9b05mOG`1iNGT0IVIV07]kN`1SHf<0JFUY06YZJP1e
MGD0QXJ607QhN01iNGT0N7Qh07MgM`1_Kfl0Jf][05mOG`1oOgl0IVIV08R8R01aLG40L71`079bLP2<
S8`0MgMg08f=S@2?Shl0HF5Q08N7Q`21PH40PX:209fMW@1oOgl0Ng]k05MGE`1iNGT0LW9b06i^KP1e
MGD0GemO071`L01aLG40Kfm_08J6QP1`L700EUIF069RHP1NGUh0GemO04E5A@1_Kfl0EUIF05UIF@1H
F5P0N7Qh07IfMP1NGUh0LG5a07]kN`1[Jf/0JFUY075aL@1[Jf/0GEeM071`L01jNWX0OGem06MWI`1_
Kfl0GUiN05UIF@1GEeL0L71`05mOG`1HF5P0MWIf06EUI@1eMGD00P1@D5007`1NGUh0IVIV04U9B@0Z
:RX0@d=306a/K01QHF40EeMG05]KF`17AdL0EeMG06=SH`1>CTh0FEUI06UYJ@17AdL0Cdm?04U9B@1<
C4`0I6AT05IFEP1IFET0BTY:05mOG`0l?3`0De=C04I6AP19BDT0EUIF04];B`0f=SH00P10@4005`1A
DE40HV9R06=SH`0a<C40E5AD04Y:BP1OGel0?3`l05=CD`1DE5@0<c<c03De=@1DE5@0EEEE0451@@1B
DU80B4Q803dm?@1BDU80ATI605MGE`0X:2P0?3`l0080Cdm?00/0=cLg059BDP1DE5@0;bl_03Lg=`11
@D40=3@d02DU9@0W9bL0?Shn02`/;00302XZ:P07028R8P0/;2`0<S8b030`<00T92@020P80?ooo`06
0=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT07@3oool0[:b/0:VYZ@2CTi<0
T92@08>3P`1dM7@0VIVI09bLW02MWId0PH6107inOP2c/k<0TI6A08^;R`2IVIT0/K6a09bLW02;Rh/0
UYJF0:FUY@2RXZ80S8b<09>CT`2f][H0VIVI08R8R02@T900YZJV0080XZ:R00<0ZZZZ08V9R@2XZ:P0
0P2UYJD0402JVYX0R8R808N7Q`2?Shl0X:2P09>CT`1eMGD0U9BD08B4Q02;Rh/0RHV909nOW`2SXj<0
TY:B0:f][@2HV9P208^;R`1M09bLW02OWil0YjNW09>CT`2ZZZX0WinO08V9R@2<S8`0W9bL09ZJVP2F
UYH0XJ6Q08R8R01jNWX0S8b<09^KV`21PH40YJFU04Y:BP21PH40WinO08J6QP2?Shl0IVIV07MgM`1d
M7@0O7al08R8R02?Shl0TI6A08R8R01/K6`0PH6107=cL`20P800NWYj07UiN@24Q8@0S8b<09NGU`2A
TI40P820079bLP1hN7P0OGem08b<S01]KFd0WinO092@T02>SXh0Shn?09JFUP1eMGD0R8R80:n_[`2V
YZH0ZZZZ0:RXZ02NWYh0Xj>S0:VYZ@2?Shl0NWYj0::RXP2HV9P0Y:BT0:NWY`2PX:00YZJV096AT@2P
X:00RHV909bLW02KVi/0NGUi0:6QX@2TY:@0UiNG08V9R@2<S8`0PH6108B4Q029RHT0Ogmo09RHV02;
Rh/0L71`08^;R`1dM7@0Q8B4055AD@21PH40RXZ:0080N7Qh04/0LW9b096AT@1dM7@0FUYJ05aLG01n
OWh0Kfm_07YjNP1ZJVX0Lg=c06EUI@1lO7`0KFe]07YjNP1mOGd0J6QX06UYJ@1iNGT0OGem08J6QP1X
J6P0NWYj061PH02<S8`0PX:207YjNP1eMGD0KVi^05YJFP2>SXh0IfMW07EeM@1/K6`0PH6108f=S@1d
M7@0TY:B07IfMP1LG5`0GUiN08F5Q@1SHf<0MWIf06i^KP1FEUH0EeMG06][J`1ADE40CTi>06=SH`1;
Bd/0EUIF05iNGP1DE5@0@T9204I6AP0f=SH0FUYJ07moO`29RHT0H61P07UiN@1gMgL0K6a/06i^KP1e
MGD0NGUi05]KF`1TI6@0Kfm_06UYJ@1GEeL0RHV906a/K01hN7P00P1PH600F01XJ6P0Lg=c05YJFP1/
K6`0G5aL05QHF01IFET0Fe]K03Xj>P15ADD0=cLg05IFEP1>CTh0GEeM04m?C`15ADD0ATI603Lg=`10
@400G5aL05=CD`1ZJVX0L71`05QHF01KFe/0A4A405]KF`1=CDd0EUIF051@D01MGEd0BTY:03Lg=`1C
De<0?clo0410@00k>c/0ADE504e=C@1NGUh0IFEU02l_;`0k>c/0AdM704I6AP0h>3P0?Cdm03/k>`1>
CTh0ATI604i>CP0/;2`0CDe=03De=@1;Bd/0De=C0492@P1VIVH0>3Ph05IFEP16ATH0>c/k03Hf=P1A
DE40C4a<04E5A@0o?cl0=cLg04I6AP17AdL0<30`02/[:`0h>3P0?3`l034a<@0i>CT0=cLg02DU9@0`
<300@41004A4A00Z:RX0<C4a02d];@0:2PX09RHV00H61P3oool60=WIf@4000000@3IfMT001H0fMWI
00<000000=WIf@3IfMT00`3IfMT04@3oool0U9BD09ZJVP27QhL0SHf=09ZJVP2UYJD0QhN709JFUP2]
[Jd0ZZZZ09ZJVP24Q8@0UiNG09bLW01`L700SHf=0080W9bL00D0/k>c09BDU02MWId0XZ:R0:VYZ@02
0::RXP1h0:VYZ@2IVIT0/[:b09jNWP2<S8`0[:b/0:JVYP2c/k<0Vi^K0:f][@28R8P0ZJVY09>CT`2H
V9P0WIfM09BDU020P800WIfM07EeM@2>SXh0Rh^;08F5Q@2OWil0]KFe08Z:RP2HV9P0WinO08F5Q@2?
Shl0TY:B09NGU`2MWId0RHV909>CT`2ATI40UiNG09bLW024Q8@0Shn?08j>SP21PH40S8b<0::RXP1d
M7@0Rh^;08f=S@27QhL0Xj>S08J6QP28R8P0MgMg06][J`21PH40Hf=S08:2PP1bLW80U9BD07UiN@25
QHD0M7Ad08B4Q01nOWh0MGEe06m_K`2JVYX0M7Ad08j>SP2=SHd0S8b<08V9R@25QHD0YjNW09NGU`24
Q8@0VYZJ07EeM@1nOWh0QXJ607alO02;Rh/0QHF5092@T02GUiL0QhN709nOW`2QXJ40TY:B09fMW@2V
YZH0WIfM0:>SX`2?Shl0PX:20:2PX02?Shl0VIVI096AT@2UYJD0Rh^;0:VYZ@2c/k<0VIVI09jNWP26
QXH0XZ:R08V9R@2JVYX0QhN708n?S`1nOWh0Vi^K07MgM`2KVi/0UIFE08Z:RP1eMGD0RXZ:08V9R@26
QXH0Kfm_0P21PH40P01jNWX0PH6107IfMP1RHV80IVIV07EeM@1nOWh0HF5Q06i^KP1eMGD0NWYj06m_
K`1XJ6P0O7al08B4Q01hN7P0PH6107inOP1aLG40KFe]07]kN`22PX80P82006QXJ01gMgL0LG5a07Yj
NP26QXH0M7Ad08F5Q@2CTi<0J6QX08b<S02:RXX0NWYj07alO01cLg<0HF5Q0820P01eMGD0NGUi06e]
K@24Q8@0M7Ad06ATI01_Kfl0H61P05EEE@1NGUh0EeMG05aLG01aLG40@d=305ADE01>CTh0=CDe04=3
@`1VIVH0Hf=S061PH01KFe/0Hf=S06YZJP1aLG40PH6107UiN@1cLg<0LG5a079bLP1/K6`0JFUY06EU
I@1`L700N7Qh079bLP1]KFd0LG5a04m?C`1^KVh0HV9R04a<C00U9BD0D51@05QHF01RHV80JVYZ04m?
C`15ADD0?Shn05EEE@1?Cdl0A4A40492@P0c<c<08R8R03dm?@1TI6@0Fe]K05iNGP1OGel0B4Q8055A
D@1FEUH0BDU905ADE01?Cdl0F5QH04m?C`0k>c/0A4A403hn?P1ADE40A4A404Y:BP0^;Rh05QHF03Ti
>@1@D500Bd];02d];@12@T80>3Ph034a<@10@400ADE504a<C019BDT0B4Q80P17AdL0900U9BD0?3`l
05=CD`1HF5P0EUIF04E5A@1PH600A4A4061PH01GEeL0Bd];04a<C01EEED0=CDe02l_;`0d=3@0?Shn
03/k>`19BDT0?3`l030`<00o?cl05QHF030`<00W9bL06a/K02@T900j>SX0:BTY01hN7P0S8b<09bLW
02XZ:P0`<3008B4Q0?ooo`H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0l
0?ooo`2][Jd0QHF506m_K`2PX:00Z:RX09bLW02IVIT0Z:RX07QhN02VYZH0WYjN0:2PX02VYZH0/;2`
0:^[Z`22PX80QhN70:FUY@26QXH0TY:B0;2`/02DU9@0/;2`08f=S@2OWil0XJ6Q09jNWP2GUiL0SHf=
0:BTY02^[Zh0WYjN0:VYZ@2PX:00WinO08b<S02f][H0/K6a09BDU02`/;00U9BD0:2PX02DU9@0RHV9
08j>SP2:RXX0G5aL08b<S02?Shl0X:2P09BDU02KVi/0S8b<08B4Q027QhL0U9BD09^KV`2VYZH0RXZ:
0P2@T900L`2=SHd0VYZJ0:BTY02UYJD0SHf=08j>SP1eMGD0T92@07QhN01jNWX0TI6A09RHV02;Rh/0
Lg=c079bLP20P800R8R807YjNP23Ph<0QHF507moO`2?Shl0P82006m_K`1lO7`0L71`06ATI01[Jf/0
R8R808j>SP1dM7@0TI6A08F5Q@2?Shl0MGEe08F5Q@2EUID0SXj>096AT@1mOGd0Ti>C09BDU02GUiL0
V9RH09ZJVP2EUID0_Kfm09^KV`2<S8`0WinO0:VYZ@2KVi/0PX:209fMW@2FUYH0T92@09bLW02MWId0
V9RH07emO@2KVi/0Rh^;09:BTP1nOWh0U9BD09NGU`2LW9`0NWYj0;>c/`23Ph<0R8R80::RXP1mOGd0
X:2P071`L01gMgL0QhN709VIV@2<S8`0WYjN08>3P`1fMWH0Ng]k08N7Q`1aLG40S8b<08:2PP1oOgl0
LG5a07UiN@29RHT0NGUi06e]K@1SHf<0H61P07MgM`2@T900MgMg07inOP1_Kfl0MgMg075aL@29RHT0
M7Ad07MgM`1fMWH0L71`07emO@1]KFd0MGEe06QXJ01oOgl0OWin09VIV@1jNWX00P1fMWH05@24Q8@0
RXZ:08f=S@1mOGd0I6AT0861P@1bLW80SXj>08b<S02DU9@0LW9b069RHP1dM7@0JVYZ06MWI`1kNg/0
GEeM07AdM01PH600F5QH051@D002055AD@0:04];B`1ADE40E5AD03`l?016ATH0I6AT06i^KP25QHD0
Jf][05mOG`80Ng]k00d0QhN708n?S`1iNGT0LG5a07QhN01[Jf/0KVi^04m?C`1bLW80MgMg061PH01Q
HF40NWYj0080EEEE05D0HV9R06UYJ@1ZJVX0F5QH04e=C@1DE5@0?3`l05YJFP14A4@0D51@03Hf=P0j
>SX0@d=304];B`1DE5@0@d=305ADE01GEeL0?Shn0492@P15ADD0@D5103Ti>@10@400ADE505UIF@1W
IfL0GUiN04a<C017AdL0D51@04U9B@15ADD0Hf=S04I6AP1UIFD0C4a<051@D00];Bd0ADE503Ti>@17
AdL0=SHf0492@P14A4@0=cLg05ADE011@D40CTi>055AD@1NGUh0AdM706QXJ01;Bd/0F5QH03lo?`1U
IFD0?3`l04];B`0a<C40<30`02TY:@1EEED092@T02/[:`0i>CT0Bd];03lo?`15ADD0CTi>02<S8`18
B4P0>SXj02h^;P0A4A40?Cdm03Ti>@19BDT07alO01@D500H61P0;2`/01@D500U9BD0oooo00H0fMWI
0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0U0?ooo`2BTY80TY:B0;2`/01oOgl0
P82007QhN02LW9`0SXj>06QXJ02IVIT0P82009ZJVP2ZZZX0Ti>C0:6QX@2PX:00TY:B09>CT`2MWId0
VYZJ09nOW`2e]KD0XJ6Q0;bl_02LW9`0/k>c0:BTY02b/[80X:2P0:VYZ@2_[jl0XZ:R0:ZZZP1mOGd0
T92@08V9R@020:FUY@0I07EeM@23Ph<0Shn?09:BTP1nOWh0P82009>CT`2KVi/0UiNG09BDU02LW9`0
T92@08Z:RP29RHT0Shn?0:>SX`1cLg<0QHF507UiN@2EUID0QXJ608b<S026QXH0UiNG0:2PX0020:6Q
X@2507AdM01nOWh0QXJ609BDU029RHT0TY:B092@T01fMWH0RHV907MgM`1nOWh0EEEE07inOP1jNWX0
OGem07EeM@25QHD0M7Ad07QhN01kNg/0MgMg07AdM01GEeL0LG5a05QHF02BTY80YJFU08V9R@2IVIT0
WIfM0:RXZ02OWil0Rh^;092@T02HV9P0Ogmo09VIV@2;Rh/0R8R808b<S024Q8@0XJ6Q09:BTP2NWYh0
Zj^[0:NWY`2DU9@0Z:RX08n?S`26QXH0Shn?0:VYZ@2QXJ40QhN708j>SP2:RXX0VIVI0820P02FUYH0
TY:B08j>SP2EUID0RXZ:09fMW@2IVIT0V9RH08n?S`1kNg/0QhN708:2PP1_Kfl0U9BD09NGU`1_Kfl0
PH61096AT@1eMGD0PX:207MgM`1YJFT0Ph>308j>SP2GUiL0T92@07]kN`1_Kfl0H61P04];B`1nOWh0
JVYZ06m_K`1kNg/0Lg=c06EUI@1RHV80GEeM07moO`20P800LG5a07alO023Ph<0OGem075aL@22PX80
J6QX071`L01eMGD0LG5a05eMG@25QHD0Ph>306YZJP1UIFD0F5QH07EeM@1mOGd0IFEU06MWI`1hN7P0
PH6106e]K@1dM7@0HV9R06MWI`1kNg/0L71`07alO01RHV80E5AD06ATI01JFUX0Lg=c06a/K00206i^
KP0g06e]K@1WIfL0MgMg05EEE@1bLW80Hf=S05MGE`1DE5@0M7Ad05QHF01]KFd0NWYj06YZJP1?Cdl0
OGem079bLP1nOWh0Lg=c06EUI@1RHV80JVYZ07EeM@1VIVH0JVYZ05MGE`1RHV80I6AT05ADE01IFET0
IFEU04];B`1`L700I6AT051@D011@D40Bd];05EEE@0m?Cd0Cdm?034a<@000000CDe=03hn?P18B4P0
ATI605eMG@1ZJVX0BDU905ADE01BDU80E5AD04M7A`1=CDd0>c/k051@D00204];B`0803Xj>P0`<300
GUiN04I6AP11@D40DU9B04M7A`16ATH204A4A00M03`l?01>CTh0De=C03dm?@0i>CT0DU9B03hn?P1;
Bd/0I6AT04E5A@0k>c/0C4a<02XZ:P1?Cdl0>3Ph055AD@1OGel0C4a<06UYJ@0i>CT0Fe]K04];B`0n
?Sh0FEUI05IFEP16ATH0EEEE04=3@`0l?3`00P18B4P03`0e=CD0CDe=02PX:00Q8B40<S8b03dm?@0]
;Bd0=CDe020P800e=CD0=SHf04I6AP0_;bl08b<S0?ooo`060=WIf@4000000@3IfMT001H0fMWI00<0
00000=WIf@3IfMT00`3IfMT0>03oool0T92@0:FUY@2IVIT0YJFU0:BTY02>SXh0Y:BT096AT@2GUiL0
TY:B0:JVYP2XZ:P0Ti>C09VIV@2WYjL0UiNG07]kN`2^[Zh0XZ:R0:>SX`2m_Kd0];Bd09bLW02/[:`0
WIfM0:6QX@2MWId0aLG509jNWP2b/[80UIFE09NGU`2IVIT0WinO08>3P`2FUYH0Z:RX0:^[Z`2/[:`0
Shn?09JFUP2MWId0TI6A08f=S@2ZZZX0T92@07YjNP2UYJD0TI6A09>CT`2GUiL0QhN7096AT@2][Jd0
Q8B40P2FUYH0@P2YZJT0QhN709jNWP2/[:`0Y:BT09fMW@21PH40PX:207QhN01iNGT0WIfM08j>SP1g
MgL0VYZJ08N7Q`2SXj<0OGem07UiN@1oOgl0GUiN06UYJ@1IFET0LG5a08j>SP2IVIT0TI6A0861P@1c
Lg<0Kfm_075aL@1eMGD0QHF508N7Q`2BTY80V9RH0:VYZ@2<S8`0Q8B4096AT@27QhL0Y:BT09FEU@1h
N7P0Ti>C08N7Q`2ATI40M7Ad08R8R01RHV80YZJV08^;R`1oOgl0TY:B09bLW02YZJT0YZJV0:FUY@2>
SXh0RXZ:0820P02HV9P0QXJ60:2PX02@T900UiNG08V9R@80Ti>C00/0UiNG06IVIP2TY:@0TY:B07mo
O`2>SXh0QXJ608:2PP2FUYH0O7al096AT@0208Z:RP1?07UiN@2QXJ40QhN707moO`1jNWX0Rh^;08N7
Q`1^KVh0UYJF07QhN01eMGD0HF5Q05mOG`20P800O7al07]kN`1nOWh0O7al08R8R01_Kfl0L71`07Qh
N01mOGd0M7Ad07EeM@1[Jf/0QXJ608n?S`1ZJVX0Lg=c07YjNP1eMGD0L71`07AdM01ZJVX0NGUi0820
P01ZJVX0PX:206][J`1`L700Ng]k07EeM@1hN7P0TI6A06i^KP25QHD0NWYj08>3P`1kNg/0OWin08b<
S01lO7`0IFEU07]kN`1/K6`0EeMG06EUI@1WIfL0Lg=c07QhN01VIVH0Kfm_08J6QP1_Kfl0MgMg07Ui
N@1bLW80LG5a06a/K01UIFD0I6AT07moO`1WIfL0J6QX07QhN01FEUH0PH61051@D00207EeM@0306][
J`1cLg<0IfMW0080G5aL05T0HV9R06QXJ01ZJVX0KVi^06YZJP1^KVh0Jf][06MWI`1JFUX0CDe=05EE
E@19BDT0?3`l04e=C@1FEUH0CTi>03De=@1EEED0<S8b03Ti>@16ATH0?3`l069RHP16ATH0@d=306][
J`1BDU80ADE505UIF@0o?cl0De=C05iNGP0g=cL0Cdm?04U9B@0m?Cd0HF5Q04=3@`1@D5009bLW0451
@@1OGel0=SHf03hn?P12@T80?clo03`l?00V9RH0=SHf04e=C@1CDe<0@410051@D01GEeL0BTY:05YJ
FP0o?cl0@T9205aLG016ATH0EEEE04M7A`1PH600?3`l04Y:BP1>CTh0De=C059BDP0k>c/0A4A405=C
D`0g=cL0CDe=0410@00j>SX0;2`/03<c<`0a<C409BDU02l_;`0L71`0=cLg03Ti>@0P82006QXJ03@d
=00/;2`07alO0?ooo`060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0:`3o
ool0UIFE0;^k^`2DU9@0Ti>C08Z:RP2BTY80QXJ608R8R02SXj<0[jn_09fMW@2=SHd0VYZJ09RHV028
R8P0Ph>308^;R`26QXH0W9bL09jNWP2LW9`0[:b/0:f][@2?Shl0^;Rh0:FUY@2k^k/0Z:RX09bLW02h
^;P0/[:b08R8R02GUiL0NWYj08F5Q@2DU9@0SXj>08n?S`2[Zj/0UiNG08j>SP24Q8@00P2@T900M`29
RHT0WIfM0::RXP2JVYX0X:2P08B4Q025QHD0SHf=0:JVYP2FUYH0Ph>309^KV`2PX:00Zj^[092@T02C
Ti<0RXZ:08^;R`2FUYH0VYZJ08R8R02NWYh0RHV909nOW`24Q8@0O7al09>CT`26QXH0PX:208B4Q01c
Lg<0KVi^071`L01IFET0MGEe08F5Q@1oOgl0GEeM07QhN01^KVh0L71`07YjNP1]KFd0MgMg06e]K@1i
NGT0TY:B09NGU`28R8P0UIFE096AT@2MWId0NGUi08F5Q@2GUiL0QhN708f=S@24Q8@0UIFE0::RXP2J
VYX0OGem08f=S@2XZ:P0Shn?0::RXP2:RXX0YZJV09fMW@1lO7`0aLG50:6QX@2LW9`0SXj>08N7Q`2B
TY80YjNW09:BTP2@T900S8b<08f=S@1iNGT0QXJ608Z:RP2SXj<0TI6A08N7Q`23Ph<0QHF508j>SP23
Ph<0SXj>08b<S02JVYX0QHF508>3P`1nOWh0QXJ60451@@20P800JVYZ08^;R`27QhL0OWin08J6QP1c
Lg<0MWIf06=SH`1jNWX0Ogmo06][J`1MGEd0KFe]07emO@1OGel0IVIV071`L02?Shl0JFUY0080MWIf
0280H61P06e]K@1nOWh0J6QX06UYJ@1lO7`0Kfm_079bLP1PH600M7Ad069RHP1nOWh0P82006e]K@1K
Fe/0Lg=c06e]K@29RHT0L71`08j>SP1kNg/0K6a/07QhN01`L700JVYZ08>3P`1]KFd0GemO05QHF01Y
JFT0M7Ad06e]K@1WIfL0NWYj0P1[Jf/0C`1eMGD0L71`08:2PP1:BTX0FEUI05iNGP1MGEd0DE5A06MW
I`1PH600Ng]k07UiN@1PH600MgMg07]kN`20P800IVIV06a/K01ADE40N7Qh079bLP1HF5P0MgMg06YZ
JP1ADE40De=C06MWI`1KFe/0FUYJ065QH@1jNWX0C4a<04];B`1OGel0ADE506ATI01?Cdl0<S8b05IF
EP15ADD0D51@055AD@1CDe<0FEUI06EUI@1?Cdl0CDe=05eMG@1HF5P0>SXj055AD@0j>SX0@T9204M7
A`1KFe/0D51@03lo?`12@T80ATI605=CD`1:BTX0<30`04E5A@1GEeL0C4a<03Ph>00e=CD0=SHf04Q8
B012@T80EUIF04A4A01=CDd0C4a<03/k>`1PH600Cdm?05iNGP17AdL00P1:BTX07`1BDU80CDe=05]K
F`1CDe<0DU9B04I6AP1ADE40?clo04A4A01LG5`0>CTi05UIF@16ATH0?Shn04a<C017AdL09bLW03Ph
>00^;Rh04A4A03Lg=`0_;bl06a/K024Q8@0[:b/0?3`l0410@00Z:RX0<S8b02DU9@3oool01P3IfMT1
00000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI09L0oooo09^KV`2LW9`0TY:B0:NWY`2]
[Jd0UiNG08R8R02SXj<0PX:209ZJVP2^[Zh0000008Z:RP2BTY80WIfM096AT@2EUID0WYjN09^KV`2P
X:00PH610:b/[02HV9P0RHV90:6QX@29RHT0YJFU0:BTY02UYJD0Y:BT09nOW`2CTi<0YJFU0:6QX@2K
Vi/0WinO09VIV@2LW9`0Lg=c09VIV@2EUID0YJFU07inOP2TY:@0PX:208b<S022PX80TY:B08Z:RP1e
MGD0P82008B4Q02>SXh0Ph>308Z:RP2DU9@0SXj>08n?S`2:RXX0VYZJ08:2PP27QhL0P82009BDU01f
MWH0RXZ:09VIV@29RHT0TI6A08:2PP2:RXX0SHf=08j>SP23Ph<0OWin06UYJ@1oOgl0MWIf065QH@1D
E5@0N7Qh069RHP1^KVh0HV9R07inOP1lO7`0LG5a08j>SP25QHD0WinO0:2PX02<S8`0Rh^;0:BTY02;
Rh/0P82008R8R024Q8@0T92@08F5Q@2:RXX0Shn?08R8R02XZ:P0RXZ:09ZJVP2DU9@0Rh^;092@T023
Ph<0Ogmo096AT@2;Rh/0UIFE08j>SP2IVIT0X:2P09jNWP2:RXX0TY:B08^;R`2MWId0QXJ60:6QX@1i
NGT0Vi^K08f=S@2OWil0VIVI09fMW@2:RXX0TY:B09RHV02<S8`0UiNG08N7Q`1nOWh0VIVI0820P02=
SHd0WIfM092@T01mOGd0NWYj0410@023Ph<0KFe]06ATI022PX80Hf=S0080MgMg00l0M7Ad06=SH`1h
N7P0PX:207inOP1_Kfl0H61P06QXJ01]KFd0RXZ:08^;R`2=SHd0Kfm_06e]K@20P8000P1]KFd0801/
K6`0LG5a05eMG@1MGEd0M7Ad07inOP2?Shl0QhN7061PH01oOgl0Ng]k079bLP1dM7@0S8b<08F5Q@1m
OGd0PH6106m_K`1`L700PX:208F5Q@1VIVH0FEUI07=cL`1PH600Fe]K071`L01FEUH0MWIf06QXJ01S
Hf<0L71`0P1kNg/06@1fMWH0K6a/065QH@1/K6`0FUYJ06EUI@1>CTh0IFEU07IfMP1MGEd0LG5a05]K
F`1eMGD0NWYj05iNGP1LG5`0JVYZ06QXJ01fMWH0IVIV0861P@1^KVh0EUIF06i^KP1lO7`00P1LG5`0
>01QHF40GUiN08>3P`1WIfL0DE5A04M7A`1<C4`0EUIF04e=C@0a<C40BDU903dm?@1:BTX0Cdm?06MW
I`1ZJVX0HV9R055AD@12@T80Cdm?04e=C@1;Bd/0>CTi04U9B@0b<S80?clo05]KF`12@T80>c/k03hn
?P17AdL0F5QH03lo?`1ADE40>SXj04A4A015ADD0DU9B03Xj>P0d=3@0;Bd]02@T901=CDd0BDU904];
B`0`<300>CTi03Hf=P1QHF40Bd];05=CD`1BDU80FEUI055AD@19BDT0CTi>0P1?Cdl06@1UIFD0?Shn
04Q8B010@400C4a<03<c<`1=CDd0A4A403dm?@0F5QH0@41003Ti>@1>CTh0:RXZ02`/;00`<300820P
01TI6@0/;2`07QhN01lO7`0:2PX0820P01hN7P3oool01P3IfMT100000040fMWI000F0=WIf@030000
003IfMT0fMWI00<0fMWI00L0oooo0:JVYP1nOWh0P8200:b/[02QXJ40UiNG0080Shn?0140X:2P0:^[
Z`2RXZ80De=C08B4Q02EUID0U9BD08n?S`2SXj<0W9bL0:b/[02;Rh/0WYjN08N7Q`2NWYh0Shn?09fM
W@020:6QX@050:>SX`2OWil0YZJV08b<S02GUiL00P2:RXX0>`25QHD0X:2P0::RXP2OWil0T92@09bL
W02:RXX0VIVI08J6QP25QHD0RHV907emO@2:RXX0Ogmo08N7Q`1oOgl0MgMg0:FUY@2CTi<0UYJF09>C
T`2;Rh/0QXJ608j>SP28R8P0S8b<08:2PP2MWId0OGem09:BTP2FUYH0W9bL08Z:RP2PX:00QXJ60820
P02:RXX0P82008b<S02@T900R8R807moO`1eMGD0Lg=c051@D01]KFd0EUIF07IfMP1WIfL0Kfm_07If
MP1YJFT0OWin0:BTY029RHT0Shn?07moO`24Q8@0MWIf0080WYjN0=X0UiNG0:2PX02VYZH0SXj>09^K
V`25QHD0PH6108R8R01jNWX0S8b<07emO@28R8P0[:b/08N7Q`2?Shl0V9RH08b<S02@T900Vi^K09JF
UP2^[Zh0U9BD08J6QP2GUiL0S8b<09:BTP2?Shl0UYJF08b<S028R8P0WYjN09ZJVP1mOGd0S8b<07Mg
M`2GUiL0TY:B09RHV02LW9`0TI6A08J6QP1jNWX0Zj^[06a/K02>SXh0VIVI07YjNP2@T900MGEe07]k
N`1]KFd0PX:208R8R01mOGd0MGEe06a/K01fMWH0KVi^06IVIP1fMWH0OGem08F5Q@1`L700Kfm_071`
L01kNg/0SHf=07YjNP1RHV80QHF507QhN01fMWH0O7al06e]K@1dM7@0EeMG07emO@1PH600N7Qh07=c
L`20P800Q8B407alO01iNGT0N7Qh08V9R@1NGUh0MGEe06i^KP1oOgl0KFe]065QH@20P800MGEe07mo
O`1dM7@0H61P051@D01PH600EeMG05mOG`1aLG40H61P07alO020P800Q8B407EeM@23Ph<0P82008R8
R01GEeL0@T9205YJFP1^KVh0EeMG06UYJ@1OGel0JVYZ06IVIP1eMGD0LW9b069RHP1iNGT0PH6107Qh
N01SHf<0PX:206UYJ@1EEED0E5AD05mOG`1PH600LG5a05=CD`1NGUh0HV9R055AD@1MGEd0DU9B06e]
K@1MGEd0A4A405]KF`1=CDd0>c/k05=CD`1IFET0Cdm?04U9B@1UIFD0CTi>061PH01KFe/0@d=306a/
K00f=SH0GemO05UIF@17AdL0=SHf04M7A`18B4P0?Shn03Ti>@0o?cl0=SHf02`/;01:BTX0C4a<05IF
EP0a<C40@41005YJFP0];Bd0?clo03`l?00h>3P0?3`l03Ph>016ATH0=CDe04U9B@1?Cdl0G5aL04i>
CP1RHV80IFEU05QHF01CDe<0B4Q804M7A`11@D40De=C04A4A00n?Sh0=CDe04M7A`1=CDd0>3Ph03/k
>`1:BTX0=3@d02d];@0f=SH0>CTi030`<00T92@0:2PX01lO7`0U9BD0=3@d01TI6@0H61P08b<S00<3
0`0H61P0:RXZ0?ooo`H0fMWI0@0000010=WIf@005P3IfMT2000000@0fMWI01X0oooo0:^[Z`2IVIT0
WinO08V9R@2EUID0VIVI09JFUP2SXj<0[Jf]09fMW@2/[:`0OWin092@T02KVi/0U9BD08V9R@1nOWh0
Ti>C08j>SP2ATI40U9BD0;jn_P2;Rh/0WIfM09ZJVP80WinO00<0O7al0:f][@2JVYX00P2EUID0D`2Q
XJ40TI6A0:NWY`1oOgl0RHV909jNWP1oOgl0Ti>C08f=S@2TY:@0M7Ad0:^[Z`2DU9@0RXZ:0:ZZZP2I
VIT0V9RH096AT@22PX80RXZ:08V9R@24Q8@0QhN709:BTP28R8P0S8b<08J6QP27QhL0Lg=c08f=S@22
PX80L71`08b<S02b/[80RXZ:09bLW025QHD0YJFU0820P029RHT0N7Qh09jNWP2HV9P0S8b<07UiN@2;
Rh/0JFUY075aL@1FEUH0LW9b075aL@1PH600IfMW07UiN@2HV9P0Rh^;08n?S`26QXH0U9BD07alO025
QHD0Shn?0:6QX@2@T900Vi^K08Z:RP28R8P0VYZJ0861P@1lO7`0Ti>C09BDU027QhL0T92@08n?S`26
QXH0X:2P08b<S01mOGd0V9RH08J6QP2GUiL0U9BD0080ZJVY02H0TI6A09:BTP2NWYh0Rh^;09fMW@2P
X:00Rh^;09>CT`2SXj<0O7al09RHV02IVIT0WIfM0:FUY@25QHD0RHV908f=S@2CTi<0P82007EeM@1h
N7P0Vi^K09>CT`2:RXX0Q8B409VIV@1mOGd0IfMW08:2PP1[Jf/0HV9R07QhN01[Jf/0OGem07IfMP1Q
HF40Kfm_06i^KP80M7Ad00d0IfMW07AdM01jNWX0G5aL07QhN02=SHd0LG5a08b<S01kNg/0JFUY05YJ
FP1/K6`0Ogmo0080NWYj02<0MgMg06UYJ@1`L700Jf][07IfMP25QHD0MgMg06EUI@22PX80PH6107Ui
N@1eMGD0NWYj079bLP1lO7`0OGem06IVIP1RHV80HF5Q07IfMP1_Kfl0IfMW07=cL`1MGEd0FUYJ05]K
F`1LG5`0IFEU08F5Q@1QHF40OWin06IVIP1TI6@0Hf=S05QHF00207=cL`1906QXJ01UIFD0G5aL07Ad
M01hN7P0Ph>307=cL`1/K6`0KVi^071`L01fMWH0Ng]k06=SH`1WIfL0Jf][06a/K01[Jf/0I6AT06EU
I@18B4P0Jf][06QXJ01?Cdl0G5aL07YjNP00000061PH05YJFP1EEED0EeMG04a<C01;Bd/0AdM706i^
KP1GEeL0C4a<05mOG`1LG5`0De=C04e=C@12@T80ADE503Hf=P0e=CD092@T05MGE`14A4@0ADE504e=
C@1ADE40>SXj0410@011@D40;bl_02LW9`17AdL0=SHf04I6AP0b<S80Bd];02XZ:P11@D40AdM705EE
E@1GEeL0@41003Hf=P16ATH0F5QH05=CD`1TI6@0?Cdm04A4A00205aLG00M03hn?P1JFUX0ADE504Q8
B01:BTX0BDU903/k>`1?Cdl0=3@d04=3@`0h>3P0>CTi04Q8B00k>c/0@d=30492@P0c<c<0=3@d04Y:
BP0d=3@0;bl_03/k>`0>3Ph06QXJ020P800U9BD06a/K01hN7P3oool01@3IfMT200000040fMWI000F
0=WIf@030000003IfMT0fMWI00<0fMWI06@0oooo0;Bd]02<S8`0Kfm_0:VYZ@2RXZ80VYZJ08V9R@2=
SHd0UIFE0:j^[P2[Zj/0];Bd09VIV@2CTi<0XJ6Q0:>SX`25QHD0Ti>C09NGU`2@T900Q8B408>3P`2D
U9@0XZ:R08b<S02JVYX0XZ:R09NGU`2EUID0Rh^;0:2PX02NWYh0UYJF09NGU`2EUID0XJ6Q08Z:RP2;
Rh/0OGem09FEU@2SXj<0U9BD08:2PP2FUYH0MWIf0::RXP2ATI40OWin08:2PP2FUYH0W9bL08J6QP2N
WYh0R8R808j>SP2;Rh/0RHV907]kN`2HV9P0Ogmo08J6QP27QhL0PH6108B4Q025QHD0O7al0820P02J
VYX0Jf][08J6QP1mOGd0QhN708^;R`2>SXh0NGUi08>3P`2>SXh0OWin08N7Q`1eMGD0MWIf0861P@2@
T900QhN706m_K`22PX80SXj>0:NWY`2GUiL0WinO0:JVYP2IVIT0R8R808:2PP2;Rh/0TI6A09FEU@2:
RXX0TY:B0P2CTi<02@1fMWH0P82008b<S01dM7@0RXZ:09bLW02TY:@0VYZJ07UiN@0208b<S0030861
P@2BTY80S8b<0080Ti>C02<0Shn?0;2`/02GUiL0R8R80:2PX02BTY80SXj>09jNWP2EUID0UYJF08R8
R01hN7P0Vi^K09JFUP2KVi/0S8b<07emO@1lO7`0S8b<08f=S@1jNWX0OGem08V9R@21PH40QXJ609VI
V@22PX80P82008f=S@21PH40Q8B407YjNP2?Shl0JFUY0861P@0208J6QP21071`L01kNg/0Ogmo071`
L01hN7P0KFe]07emO@26QXH0N7Qh075aL@1bLW80M7Ad071`L027QhL0Ogmo08F5Q@1eMGD0Ph>306e]
K@1gMgL0QHF50861P@2<S8`0KVi^07=cL`2<S8`0Lg=c08n?S`1]KFd0QHF506m_K`1bLW80QXJ607Yj
NP1_Kfl0S8b<06a/K01gMgL0IFEU06UYJ@1kNg/0K6a/05IFEP1PH600?clo06MWI`1CDe<0ATI6065Q
H@1TI6@0IVIV0410@01PH600N7Qh05iNGP1YJFT0FEUI06a/K01NGUh0QXJ607YjNP25QHD0M7Ad075a
L@1^KVh0GUiN06MWI`1PH600Ng]k05eMG@1PH600B4Q805aLG01gMgL0IVIV05aLG01TI6@0DE5A05MG
E`1JFUX0@d=3061PH01EEED0?clo05iNGP1IFET0J6QX06ATI00_;bl0EUIF06m_K`16ATH0H61P05AD
E01@D500CTi>05EEE@1DE5@0IVIV05eMG@1<C4`0E5AD03De=@0k>c/0>SXj0451@@1?Cdl0ATI603De
=@17AdL0;bl_03lo?`1=CDd0ADE503hn?P0R8R80Cdm?04=3@`1QHF40ATI603lo?`0_;bl0B4Q805aL
G01dM7@0H61P075aL@1ADE40?Shn0080>SXj00H0GEeM03Ti>@16ATH0EUIF04e=C@0l?3`204Q8B00D
03`l?01;Bd/0<c<c028R8P14A4@0>3Ph04U9B@10@4008b<S034a<@0^;Rh00000024Q8@0000004Q8B
038b<P0T92@00@4101HF5P3oool60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3I
fMT07@3oool0U9BD08^;R`2][Jd0UiNG09>CT`2ZZZX0Shn?09NGU`2FUYH0V9RH09nOW`2@T900WYjN
09JFUP2PX:00V9RH0:f][@2UYJD0XZ:R0:VYZ@2UYJD0X:2P09fMW@2KVi/0ZJVY09bLW02EUID0UYJF
0080Vi^K02h0WIfM0:BTY02NWYh0TY:B08R8R01fMWH0PH610:^[Z`2DU9@0TI6A0861P@2BTY80QXJ6
08Z:RP2=SHd0VIVI0:>SX`24Q8@0RXZ:08^;R`2<S8`0N7Qh0:n_[`38b<P0Shn?08N7Q`1lO7`0U9BD
08b<S020P800L71`09>CT`26QXH0U9BD09FEU@2IVIT0R8R807MgM`2?Shl0LW9b08j>SP1_Kfl0R8R8
071`L022PX80Shn?0P23Ph<0OP29RHT0QHF507QhN02:RXX0Shn?09ZJVP1mOGd0Shn?09NGU`1lO7`0
Ph>309>CT`22PX80Shn?0:BTY02DU9@0S8b<09JFUP2BTY80QhN709ZJVP2BTY80QhN708b<S023Ph<0
MWIf07QhN02FUYH0S8b<08J6QP2e]KD0[Zj^09VIV@2>SXh0QHF509fMW@2;Rh/0Ti>C0:FUY@2DU9@0
X:2P08B4Q02DU9@0WinO09^KV`2/[:`0V9RH09>CT`27QhL0RXZ:08:2PP2=SHd0X:2P08>3P`26QXH0
MGEe06m_K`27QhL0U9BD08B4Q02MWId0Y:BT09nOW`1nOWh0Rh^;08n?S`23Ph<0KVi^06QXJ02FUYH0
RXZ:06][J`1kNg/0I6AT06i^KP1/K6`0MgMg08R8R01aLG40NWYj06IVIP28R8P0MGEe08f=S@1dM7@0
Rh^;06m_K`1GEeL0LW9b07MgM`1VIVH0Hf=S079bLP1RHV80Ogmo07=cL`1UIFD0N7Qh07MgM`1[Jf/0
NWYj07moO`1dM7@0O7al0861P@20P800TY:B08^;R`2MWId0IfMW07EeM@1nOWh0OGem09JFUP2=SHd0
MWIf05MGE`1TI6@0De=C03Ti>@1LG5`0?3`l04M7A`1NGUh0CDe=01lO7`80@T920200FEUI06i^KP1h
N7P0GUiN05UIF@1eMGD0GemO07EeM@23Ph<0OWin06=SH`1=CDd0HF5Q05IFEP1bLW80KVi^06ATI01J
FUX0C4a<05aLG01HF5P0GUiN06EUI@1[Jf/0LW9b071`L01WIfL0E5AD04a<C01?Cdl0GEeM06UYJ@80
G5aL04T0FEUI07AdM00[:b/0=CDe059BDP1_Kfl0DU9B04A4A01ADE40FEUI03Lg=`1BDU80JFUY04A4
A01KFe/0ATI604Y:BP1@D500AdM703Hf=P0j>SX0@d=302XZ:P1ADE40CDe=04Y:BP1BDU80DE5A05mO
G`16ATH0?clo0451@@1<C4`0EeMG0492@P15ADD0JVYZ05QHF00n?Sh0F5QH04a<C01RHV80?clo04A4
A01?Cdl0AdM704e=C@1@D500CDe=04A4A01>CTh0@d=30410@01ADE40>SXj0410@016ATH0ADE504M7
A`1GEeL0;Rh^04M7A`0j>SX061PH02@T900/;2`0000001`L700F5QH09BDU038b<P0f=SH0oooo00H0
fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@1;0?ooo`2LW9`0UiNG09BDU02L
W9`0/;2`09ZJVP2SXj<0Vi^K092@T02PX:00Vi^K08J6QP2GUiL0QhN708V9R@2IVIT0WYjN0::RXP1m
OGd0Shn?092@T02EUID0ZJVY0::RXP2CTi<0W9bL08>3P`2KVi/0Ti>C09jNWP2QXJ40/k>c07inOP25
QHD0KVi^08n?S`27QhL0UYJF0820P024Q8@0OWin06UYJ@1iNGT0Q8B408^;R`2@T900P82007]kN`2;
Rh/0ZJVY0:2PX026QXH0M7Ad08^;R`25QHD0V9RH07emO@1ZJVX0Q8B407YjNP2IVIT0OGem08>3P`1m
OGd0Shn?08B4Q01hN7P0JVYZ07IfMP1kNg/0@T9207QhN020P800S8b<0080QXJ601H0Lg=c07moO`2A
TI40Ogmo07QhN028R8P0SHf=0861P@25QHD0Ogmo07IfMP1/K6`0QHF5059BDP1^KVh0Rh^;05]KF`1o
Ogl0NWYj08J6QP2@T900RXZ:0P2@T900KP2KVi/0TI6A06QXJ02IVIT0Ti>C092@T02>SXh0WinO09VI
V@2EUID0ZZZZ09^KV`2ATI40WIfM0820P026QXH0^;Rh08f=S@2MWId0Xj>S08b<S01jNWX0T92@09VI
V@24Q8@0QHF509:BTP2;Rh/0TI6A09FEU@2:RXX0M7Ad08j>SP1hN7P0Shn?09ZJVP1mOGd0PX:207Ee
M@2RXZ80Vi^K08:2PP21PH40Rh^;09>CT`2IVIT0R8R806e]K@28R8P0RXZ:08j>SP1fMWH0HV9R06][
J`2GUiL0Lg=c09JFUP1ZJVX0K6a/0861P@2=SHd0G5aL065QH@29RHT0Rh^;06MWI`1dM7@0O7al06EU
I@1kNg/0L71`08n?S`1kNg/0Cdm?06MWI`21PH40M7Ad07IfMP1gMgL0OGem07alO027QhL0IFEU07al
O024Q8@0MgMg0820P01bLW80Rh^;08J6QP25QHD0PH6107YjNP1hN7P0MGEe079bLP1LG5`0Hf=S04Y:
BP1TI6@0EUIF06][J`1BDU80<c<c04=3@`1=CDd0FEUI05=CD`1]KFd0L71`0P1SHf<04028R8P0M7Ad
06][J`1bLW80Ogmo07MgM`1QHF40JVYZ08B4Q01LG5`0J6QX06YZJP1BDU80KFe]06YZJP1QHF4206AT
I00?06QXJ01WIfL0HF5Q05iNGP1HF5P0IVIV05IFEP1?Cdl0IfMW05YJFP1/K6`0GEeM05aLG01EEED0
@T920080Cdm?0480Fe]K04e=C@1:BTX0C4a<06ATI00h>3P0@D5105EEE@1IFET0>c/k04a<C00_;bl0
@4100451@@13@d<0DU9B05=CD`0d=3@0CDe=05eMG@1NGUh0DU9B04a<C01FEUH0FUYJ04m?C`18B4P0
G5aL05QHF01FEUH0Cdm?05EEE@12@T80Bd];051@D01DE5@0EUIF0410@01MGEd0G5aL05mOG`0k>c/0
A4A403Ph>01:BTX0@41004A4A00f=SH0DU9B03/k>`0^;Rh0?Shn034a<@12@T80<c<c0451@@0m?Cd0
820P01lO7`0T92@03Ph>00`<300Q8B40?3`l02TY:@3oool60=WIf@4000000@3IfMT001H0fMWI00<0
00000=WIf@3IfMT00`3IfMT0:`3oool0V9RH0;:b/P2UYJD0WIfM0:BTY02NWYh0T92@0;:b/P2IVIT0
[jn_0;Jf]P2PX:00V9RH09bLW02UYJD0[:b/09^KV`2DU9@0SHf=08Z:RP2d];@0VIVI09FEU@2<S8`0
VIVI09^KV`2BTY80WYjN08^;R`24Q8@0YjNW09nOW`25QHD0T92@09>CT`2LW9`0SXj>08B4Q027QhL0
QHF509fMW@2DU9@00P2BTY80801dM7@0OGem08Z:RP2GUiL0RHV908Z:RP1lO7`0Y:BT09NGU`26QXH0
VYZJ09NGU`27QhL0K6a/08B4Q01gMgL0SXj>07alO02MWId0NGUi07EeM@26QXH0P82008N7Q`21PH40
N7Qh07IfMP1BDU80N7Qh06i^KP1[Jf/0UYJF0P1`L700B`1SHf<0OWin07MgM`1lO7`0H61P05eMG@1a
LG40B4Q80492@P1DE5@0@T9205=CD`1<C4`0HF5Q05EEE@1VIVH0QHF508Z:RP2FUYH0Ogmo08N7Q`24
Q8@0VYZJ09VIV@25QHD0QXJ609>CT`2ATI40ZZZZ09fMW@2QXJ40T92@09RHV026QXH0SHf=09jNWP2C
Ti<0W9bL08F5Q@2MWId0R8R809FEU@2CTi<0OGem07inOP2>SXh0PX:208B4Q02;Rh/0WYjN08R8R02J
VYX0QHF507YjNP2PX:00UYJF09fMW@1mOGd0QHF506m_K`2CTi<0UiNG06a/K02EUID0R8R808N7Q`2G
UiL0S8b<08Z:RP2>SXh0R8R808N7Q`1bLW80SXj>07EeM@0207UiN@0508B4Q01eMGD0MGEe08b<S020
P8000P1]KFd01`1ZJVX0N7Qh07emO@1SHf<0N7Qh07alO027QhL00P21PH40Q01gMgL0MWIf07IfMP1Q
HF40LW9b08:2PP20P800QhN708Z:RP1cLg<0R8R809fMW@1fMWH0MgMg08F5Q@28R8P0OGem07QhN021
PH40SHf=08n?S`25QHD0KVi^071`L01oOgl0JVYZ07inOP1TI6@0Hf=S0492@P1JFUX0>c/k05]KF`1N
GUh0Hf=S061PH01YJFT0K6a/06EUI@1FEUH0Kfm_07MgM`1^KVh0Jf][06EUI@1VIVH0QHF506][J`22
PX80DE5A05eMG@1dM7@0FUYJ06ATI01QHF40IfMW0451@@1ZJVX0J6QX04A4A01;Bd/0GEeM05EEE@1J
FUX0I6AT069RHP1YJFT0HF5Q06QXJ01KFe/0CTi>04Y:BP1RHV80Fe]K04Q8B013@d<0ADE504I6AP1W
IfL0>c/k04a<C01BDU80GEeM05EEE@1?Cdl0EEEE02h^;P1JFUX0?3`l03Xj>P0m?Cd0EUIF04Y:BP12
@T80EUIF05ADE01=CDd0@D5105iNGP1CDe<0GUiN05YJFP1IFET0De=C06QXJ01EEED0OGem051@D01Q
HF40BTY:06ATI01<C4`0IFEU05]KF`1GEeL0>SXj04m?C`18B4P0<C4a055AD@1<C4`0?clo038b<P12
@T80?Cdm02d];@0d=3@0>3Ph02PX:01?Cdl0;Rh^02d];@807alO00@04a<C01dM7@0N7Qh0=SHf0P0k
>c/00`0/;2`0oooo0=WIf@050=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0
?03oool0VYZJ08Z:RP2DU9@0TY:B0:ZZZP2YZJT0Ti>C09^KV`2MWId0T92@08Z:RP2HV9P0];Bd0:RX
Z02FUYH0Ogmo0:6QX@25QHD0Xj>S08R8R023Ph<0W9bL0:VYZ@2MWId0MWIf09NGU`24Q8@0RXZ:08^;
R`2=SHd0S8b<0:FUY@2?Shl0P82008B4Q02@T900VIVI0:6QX@1cLg<0RXZ:08^;R`2JVYX0PX:207em
O@2MWId0MGEe08b<S027QhL0PH6108R8R02:RXX0WYjN06m_K`2<S8`0UYJF09ZJVP2LW9`0OGem079b
LP80N7Qh01H0Ph>308:2PP1gMgL0Q8B407inOP1`L700Ogmo061PH02;Rh/0Lg=c07emO@1oOgl0GemO
0861P@1bLW80HF5Q09BDU02:RXX0K6a/07EeM@1^KVh0F5QH0P1<C4`06`0S8b<0;Bd]01PH600L71`0
@41003Ph>00i>CT0DE5A069RHP1ZJVX0LW9b08j>SP2IVIT0R8R808>3P`29RHT0KFe]09BDU02MWId0
XZ:R08b<S02HV9P0RHV909^KV`2JVYX0QXJ609>CT`02096AT@0[0::RXP2MWId0QXJ60:ZZZP2b/[80
V9RH0:6QX@2>SXh0Rh^;0;2`/028R8P0RXZ:08V9R@21PH40QXJ607QhN024Q8@0WinO08^;R`2KVi/0
Ph>308V9R@1iNGT0MGEe08B4Q01mOGd0SHf=07UiN@1oOgl0M7Ad08b<S02>SXh0UiNG08f=S@2BTY80
Rh^;08f=S@2:RXX0Ph>306i^KP23Ph<0TI6A0861P@0207MgM`0S08f=S@1]KFd0Cdm?07IfMP1hN7P0
M7Ad06UYJ@25QHD0Ti>C07QhN01^KVh0MgMg07QhN01oOgl0Kfm_04i>CP1oOgl0EEEE06UYJ@1UIFD0
EUIF07YjNP1lO7`0QHF507inOP26QXH0MGEe06a/K024Q8@0SXj>07moO`28R8P0T92@09VIV@1kNg/0
0P1nOWh0@01fMWH0Ogmo06m_K`1PH600I6AT06IVIP1[Jf/0L71`05]KF`1IFET0MgMg069RHP1QHF40
JVYZ06=SH`1MGEd0IFEU07MgM`2ATI40Kfm_061PH01[Jf/0JFUY07=cL`1QHF40GEeM061PH01dM7@0
IFEU071`L01GEeL0Lg=c06=SH`1aLG40HV9R06EUI@1>CTh0Cdm?03hn?P12@T80GUiN05MGE`1TI6@0
EeMG05aLG01>CTh0G5aL05EEE@14A4@0=CDe06QXJ01YJFT0HF5Q04M7A`1;Bd/0F5QH05=CD`19BDT0
IFEU03lo?`1JFUX0@D5104Y:BP1CDe<203lo?`0F0492@P0c<c<0G5aL04I6AP1GEeL0@T9206ATI00o
?cl0GemO03dm?@1RHV80FEUI04i>CP13@d<0BTY:05ADE01IFET0H61P04I6AP1ADE40@d=305YJFP80
BTY:00T0D51@05=CD`1FEUH0>SXj03<c<`0h>3P0=CDe055AD@0f=SH00P0n?Sh0400J6QX092@T04i>
CP10@400<C4a02HV9P0X:2P071`L01PH600b<S809RHV01DE5@0X:2P0:BTY01PH603oool60=WIf@40
00000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0203oool0SHf=0:2PX02UYJD0U9BD096A
T@2:RXX0YZJV0P2OWil06P2GUiL0RXZ:08^;R`2@T900RHV908b<S02d];@0Ph>30:VYZ@2WYjL0Rh^;
096AT@24Q8@0WYjN08Z:RP2;Rh/0TI6A0:ZZZP1oOgl0RHV909:BTP2ATI40Ogmo06e]K@2?Shl0UIFE
0P29RHT0:@25QHD0M7Ad09VIV@1oOgl0TI6A08J6QP1nOWh0UYJF08:2PP2DU9@0O7al08f=S@1nOWh0
IVIV09VIV@1kNg/0OWin06m_K`2:RXX0P82007EeM@26QXH0RXZ:07emO@24Q8@0H61P07=cL`2:RXX0
LG5a09ZJVP1oOgl0Q8B407inOP20P800MgMg07YjNP27QhL0RHV907MgM`1_Kfl0L71`0080Hf=S00H0
HF5Q06QXJ01HF5P0=3@d01LG5`0T92@30000000S00410@000000000001HF5P0U9BD0C4a<055AD@1h
N7P0TY:B069RHP1/K6`0WinO0:^[Z`26QXH0Ph>309:BTP2ATI40Vi^K09VIV@2/[:`0UiNG07YjNP2F
UYH0TY:B0:j^[P2HV9P0WIfM09VIV@2:RXX0Z:RX08J6QP2GUiL0SXj>09NGU`2<S8`00P2=SHd01P2C
Ti<0VYZJ08Z:RP22PX80NWYj08F5Q@80P82000T0IFEU03`l?01]KFd0JFUY0861P@2SXj<0UiNG0:NW
Y`2NWYh00P2:RXX04@26QXH0WIfM08F5Q@2QXJ40LW9b08n?S`2[Zj/0NWYj08F5Q@1nOWh0K6a/06YZ
JP28R8P0Ng]k07emO@1;Bd/0Jf][0080LW9b05T0NGUi07inOP27QhL0PX:207EeM@1nOWh0KFe]0820
P02@T900MWIf08b<S01oOgl0Kfm_07emO@1RHV80O7al06UYJ@1[Jf/0E5AD07inOP1`L700QXJ6071`
L021PH40LW9b07=cL`2=SHd0KVi^06][J`1QHF40JVYZ07UiN@1oOgl0KFe]07MgM`1ZJVX0EeMG07Mg
M`1eMGD0NGUi07moO`1RHV80MgMg07AdM01YJFT0OGem061PH01gMgL0HF5Q07IfMP1IFET0HV9R06AT
I024Q8@0MGEe065QH@1lO7`0M7Ad07emO@1/K6`0Fe]K06QXJ01JFUX0EUIF06a/K01IFET0G5aL06EU
I@1VIVH0L71`03Lg=`1ZJVX0Fe]K06QXJ01KFe/0Bd];069RHP13@d<0EeMG04e=C@1OGel0;Bd]06][
J`1MGEd0CTi>04M7A`1NGUh0CTi>04A4A00204Q8B00j04I6AP15ADD0FUYJ03lo?`1OGel0Cdm?03Xj
>P1DE5@0?clo05ADE01:BTX0DU9B04e=C@1FEUH0ATI60451@@0X:2P0@T9204E5A@1:BTX0I6AT069R
HP1?Cdl0EEEE05MGE`1ADE40GemO03/k>`1PH600BDU906a/K01SHf<0?clo05eMG@1;Bd/0@D5104M7
A`1@D500>CTi038b<P0e=CD0<S8b03`l?00o?cl0;2`/030`<0092@T09bLW00d=3@0U9BD06QXJ02/[
:`0a<C409BDU03@d=00/;2`08R8R0?ooo`H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WI
f@030=WIf@0U0?ooo`2HV9P0YJFU092@T02ZZZX0UIFE09fMW@2BTY80UiNG0:f][@2PX:00^;Rh09fM
W@26QXH0TY:B08>3P`2ATI40Ogmo0:f][@21PH40R8R806m_K`21PH40PX:2096AT@27QhL0WYjN09RH
V02GUiL0YZJV0:VYZ@2IVIT0Xj>S08^;R`2JVYX0SHf=09:BTP02096AT@0H09:BTP27QhL0V9RH09bL
W026QXH0WIfM07alO02=SHd0PH6107QhN01`L700PX:2096AT@1hN7P0UIFE08>3P`1dM7@0V9RH09JF
UP28R8P0NGUi09jNWP22PX80P8200P1bLW805@1cLg<0S8b<08B4Q022PX80O7al07YjNP2;Rh/0LG5a
07inOP1`L700Q8B407inOP1aLG40Kfm_06ATI01KFe/0M7Ad04U9B@1@D500?3`l01DE5@070000000h
00@4100@410061PH04A4A01VIVH0L71`08F5Q@26QXH0UiNG07emO@2BTY80PX:209:BTP2:RXX0Vi^K
09:BTP29RHT0PX:209nOW`2WYjL0Shn?0820P02RXZ80YJFU0;Zj^P2TY:@0Xj>S096AT@2FUYH0QHF5
08R8R02=SHd0Ph>3092@T01mOGd0VIVI08R8R02OWil0S8b<08n?S`1bLW80OWin07moO`27QhL0KFe]
06i^KP1eMGD0Lg=c0820P025QHD0RXZ:08V9R@2DU9@0Vi^K08Z:RP2VYZH209fMW@0;08f=S@2:RXX0
JVYZ05YJFP1mOGd0TY:B06a/K02SXj<0R8R80820P01mOGd00P20P8002P27QhL0VYZJ06a/K027QhL0
MGEe07YjNP26QXH0Ti>C07inOP1cLg<206m_K`0J08Z:RP1QHF40QXJ607inOP27QhL0Lg=c08b<S01X
J6P0HF5Q07]kN`26QXH0GUiN07QhN01eMGD0K6a/079bLP1`L700TI6A08B4Q01]KFd0EUIF09>CT`1m
OGd0IFEU06ATI01/K6`207UiN@0805mOG`20P800KVi^05aLG01=CDd0Fe]K055AD@1>CTh2071`L00P
07=cL`29RHT0IFEU06e]K@1`L700NWYj07QhN01NGUh0JFUY06IVIP1eMGD0KVi^05ADE01XJ6P0Kfm_
06IVIP21PH40H61P051@D01QHF40CTi>05QHF01NGUh0KVi^05mOG`1ZJVX0>3Ph04];B`1LG5`0CDe=
069RHP1PH60205iNGP1205aLG01:BTX0G5aL03/k>`16ATH0IVIV061PH01>CTh0EeMG05=CD`1NGUh0
BTY:03@d=00k>c/0?3`l03lo?`13@d<0=cLg0451@@0f=SH0H61P04a<C01IFET0?clo04m?C`18B4P0
AdM705IFEP11@D40E5AD05mOG`1NGUh0CDe=06a/K01>CTh0Fe]K04m?C`1RHV80A4A403hn?P1JFUX0
IVIV055AD@14A4@0De=C03@d=016ATH0>c/k03<c<`0T92@09RHV01lO7`0g=cL0;Bd]00D51@0;2`/0
3@d=02HV9P0X:2P06QXJ02/[:`0c<c<0?Shn03dm?@0a<C40oooo1P3IfMT100000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI01/0oooo09bLW02VYZH0[Zj^09bLW02OWil0Rh^;08f=S@2@T900
W9bL0;Zj^P2YZJT0/;2`09JFUP2:RXX0QXJ609nOW`24Q8@0PX:2096AT@2DU9@0UYJF08R8R02NWYh0
TI6A06YZJP2:RXX00P2EUID0>02NWYh0UiNG08^;R`1/K6`0LW9b092@T02OWil0Ph>309:BTP29RHT0
OWin09JFUP1fMWH0QhN707alO02FUYH0TY:B071`L02DU9@0V9RH08^;R`1[Jf/0Ph>3061PH01oOgl0
Shn?079bLP1nOWh0PX:20820P023Ph<0QHF507YjNP1bLW80L71`06IVIP1bLW80MGEe07UiN@26QXH0
O7al07moO`1_Kfl0K6a/07UiN@25QHD0P82008:2PP1eMGD0LW9b07=cL`1eMGD0N7Qh06i^KP1TI6@0
<c<c2`0000004`0D51@0<S8b061PH02:RXX0T92@08V9R@1iNGT0J6QX09>CT`2OWil0[jn_09VIV@2@
T900WYjN08Z:RP1kNg/0[Jf]08B4Q02=SHd00P2OWil08@2a/K40TY:B07moO`2GUiL0QXJ609>CT`28
R8P0QHF509VIV@2<S8`0VYZJ09nOW`2@T900TI6A08:2PP23Ph<0NGUi06m_K`2<S8`0PX:2071`L01E
EED0MGEe07moO`1lO7`0RHV908N7Q`2>SXh0UiNG0::RXP2OWil0UIFE07inOP0207moO`0Z08N7Q`1U
IFD0SXj>07QhN01/K6`0Lg=c07UiN@1OGel0RXZ:07YjNP1nOWh0P82007=cL`1bLW806a/K08N7Q`24
Q8@0QHF507emO@1SHf<0LW9b08N7Q`1dM7@0IfMW08>3P`1cLg<0Ph>307AdM01SHf<0Lg=c07EeM@1o
Ogl0LG5a07MgM`1oOgl0N7Qh08Z:RP28R8P0MWIf08:2PP2;Rh/0IVIV0P1[Jf/03@1SHf<0KFe]06a/
K01]KFd0LW9b075aL@1WIfL0NWYj06i^KP21PH40QHF507]kN`1RHV800P1aLG408@1XJ6P0G5aL07em
O@1nOWh0Ogmo08>3P`1^KVh0MGEe06IVIP1:BTX0Hf=S06UYJ@1GEeL0MgMg07QhN01fMWH0L71`06EU
I@1OGel0JFUY04m?C`1XJ6P0MgMg079bLP1`L700DU9B05ADE01^KVh0GemO06EUI@1VIVH0O7al06i^
KP03055AD@0V06UYJ@1BDU80Fe]K04=3@`18B4P0@T9202/[:`1GEeL0?Cdm05mOG`1:BTX0EeMG03Ph
>01DE5@0DU9B0410@012@T80@41003<c<`11@D40D51@04];B`0n?Sh0?clo0410@01>CTh0H61P079b
LP14A4@0FUYJ04a<C01CDe<0EeMG03Lg=`1TI6@0FEUI05YJFP1;Bd/203Hf=P0K04Q8B017AdL0=CDe
03@d=00c<c<0Cdm?03Ti>@0`<300@d=304M7A`0O7al0>SXj03Hf=P0];Bd07AdM03Ph>00^;Rh07alO
02/[:`0;2`/09RHV01XJ6P000000=3@d01hN7P0M7Ad0oooo00H0fMWI0@0000010=WIf@005P3IfMT0
0`000000fMWI0=WIf@030=WIf@0E0?ooo`2=SHd0TI6A08Z:RP1iNGT0M7Ad07=cL`1dM7@0R8R808>3
P`2PX:00Ti>C08R8R02JVYX0[Zj^09nOW`1jNWX0Ogmo0:n_[`2GUiL0TY:B0080S8b<01L0R8R809:B
TP26QXH0Ti>C08:2PP20P800SHf=0820P029RHT0Xj>S07emO@2CTi<0Ogmo08^;R`24Q8@0NGUi08Z:
RP2<S8`0RHV9092@T02?Shl0SXj>08^;R`0209>CT`0U07alO02<S8`0Ogmo08R8R01oOgl0R8R807Ui
N@24Q8@0PH6107IfMP23Ph<0Q8B408:2PP1eMGD0MWIf08B4Q01lO7`0S8b<07EeM@1aLG40JFUY07mo
O`1nOWh0L71`08F5Q@1jNWX0OGem061PH01eMGD0MWIf0820P01XJ6P0NWYj07]kN`1BDU80?clo01XJ
6P050000000300820P0820P0000000<0000004P061PH01TI6@1RHV80V9RH09JFUP26QXH0NWYj09>C
T`2>SXh0WinO0:b/[02SXj<0ZJVY08:2PP2;Rh/0TI6A09VIV@1bLW80O7al09nOW`20P800Ti>C09FE
U@2PX:00Rh^;07alO02:RXX0Vi^K0::RXP2;Rh/0XZ:R09NGU`2ATI40O7al08n?S`23Ph<0LW9b06MW
I`1hN7P0Ogmo07UiN@20P800IfMW06a/K02>SXh0M7Ad09:BTP2<S8`0PH6107YjNP1iNGT0MGEe09RH
V01fMWH0Ph>308^;R`2:RXX0Ng]k07emO@1dM7@0PX:2069RHP26QXH0PX:208R8R01/K6`0Rh^;0861
P@2>SXh0MGEe05YJFP1eMGD206m_K`0F08^;R`28R8P0VIVI07]kN`1gMgL0MWIf05aLG01RHV80Ph>3
08F5Q@1eMGD0P82007AdM01UIFD0SHf=096AT@1mOGd0MGEe07]kN`2@T900HV9R06a/K080LG5a02H0
Ng]k07IfMP1_Kfl0LG5a05eMG@29RHT0NGUi07MgM`1WIfL0MgMg071`L01SHf<0J6QX07alO01bLW80
MWIf07inOP1NGUh0LG5a07emO@1XJ6P0GemO07MgM`1/K6`0GEeM05EEE@1RHV80NWYj06UYJ@1kNg/0
MGEe06i^KP1@D500Fe]K06UYJ@1XJ6P0LW9b07alO080IVIV0200DU9B05eMG@1RHV80IfMW05aLG01K
Fe/0HF5Q069RHP1WIfL0EeMG05iNGP1GEeL0:BTY065QH@13@d<0?3`l04Y:BP1IFET0K6a/04i>CP13
@d<0=CDe04i>CP12@T80<S8b04e=C@18B4P0L71`04I6AP12@T80ATI60492@P80ATI601H0AdM705MG
E`1DE5@04a<C05aLG01<C4`0GemO04m?C`1BDU80EEEE06EUI@1@D500MGEe04A4A01TI6@0?3`l03hn
?P1<C4`0?clo03Ti>@13@d<0D51@0P12@T805P18B4P0?Cdm02/[:`0o?cl0B4Q80451@@0h>3P0?Cdm
02XZ:P0a<C408R8R01dM7@0H61P07QhN010@400U9BD0=3@d0410@00S8b<0:2PX03Lg=`3oool60=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0303oool0WYjN06i^KP1cLg<0Jf][
06m_K`1gMgL0O7al06MWI`20P800TY:B08V9R@80WinO00H0W9bL08Z:RP2<S8`0Xj>S08V9R@2HV9P2
08f=S@0Y08R8R01mOGd0TI6A07emO@29RHT0PH6108R8R029RHT0Ti>C09bLW028R8P0J6QX08f=S@23
Ph<0T92@09BDU02GUiL0ZJVY08Z:RP2GUiL0[jn_09fMW@1iNGT0RXZ:07YjNP2:RXX0PH6109^KV`1k
Ng/0LW9b08V9R@2JVYX0O7al06YZJP2=SHd0Jf][08f=S@1jNWX0OWin06a/K026QXH00P1aLG404`1j
NWX0LG5a07emO@1fMWH0KFe]061PH01eMGD0RXZ:07MgM`2>SXh0I6AT07moO`24Q8@0L71`07EeM@1]
KFd0LG5a06ATI00R8R8010000000100A4A40000001DE5@092@T50000000O028R8P12@T80NGUi09jN
WP2@T900WYjN09^KV`2MWId0TI6A08J6QP1nOWh0Shn?096AT@1]KFd0WYjN08Z:RP2CTi<0OWin09:B
TP1jNWX0Q8B40:FUY@1oOgl0TI6A08^;R`26QXH0Ph>309JFUP2GUiL0RXZ:096AT@0208N7Q`0?07If
MP1kNg/0MGEe0820P02?Shl0PH6107emO@2JVYX0Q8B406e]K@2=SHd0QhN707emO@27QhL0U9BD0080
Shn?00X0MgMg08n?S`2ATI40UYJF08V9R@1hN7P0LG5a06UYJ@1fMWH0Ng]k0P1hN7P08028R8P0Lg=c
08:2PP1aLG40P82006IVIP2DU9@0OWin08B4Q01YJFT0IFEU071`L026QXH0KVi^0861P@1fMWH0OWin
07=cL`1lO7`0QXJ607inOP1fMWH0MgMg08b<S01cLg<0R8R807YjNP1eMGD0QXJ607]kN`2;Rh/0N7Qh
0P1cLg<0FP1XJ6P0JFUY09NGU`1TI6@0KFe]07QhN01<C4`0JVYZ08:2PP1^KVh0MWIf05UIF@1]KFd0
Ph>306YZJP1bLW80FUYJ06m_K`1bLW80EEEE07YjNP1WIfL0H61P06i^KP1GEeL0O7al07=cL`1/K6`0
F5QH069RHP1QHF40GUiN051@D01UIFD0GUiN06QXJ01GEeL0I6AT05aLG01>CTh0HV9R07QhN01aLG40
H61P06ATI01RHV80GUiN06YZJP1DE5@0GEeM05aLG01?Cdl0GemO04E5A@1?Cdl0Bd];04=3@`0l?3`0
BTY:059BDP0b<S80?Shn04Q8B012@T80Fe]K06UYJ@15ADD0E5AD03hn?P17AdL0;bl_0492@P1RHV80
B4Q803Ti>@1@D500FEUI05=CD`1IFET0I6AT05IFEP1CDe<0Cdm?04i>CP1=CDd0DE5A05]KF`1@D500
DU9B05QHF080EeMG01X0CDe=03dm?@0k>c/0CTi>04=3@`0a<C40ADE502h^;P1IFET061PH034a<@0e
=CD0>3Ph02/[:`0Y:BT0@T9203De=@0K6a/0:2PX00@4100M7Ad09RHV02d];@0=3@d07alO03De=@80
8R8R00<0oooo0=WIf@3IfMT0103IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI
00X0oooo09VIV@1LG5`0QhN707moO`23Ph<0M7Ad08R8R02IVIT0Shn?0P1cLg<01`24Q8@0OGem08b<
S02FUYH0YJFU07moO`20P8000P29RHT0?`27QhL0V9RH09ZJVP2WYjL0V9RH0820P02KVi/0MGEe07in
OP1_Kfl0QhN7096AT@2NWYh0P82009fMW@2@T900Ti>C0:FUY@2<S8`0X:2P0;:b/P23Ph<0QHF507in
OP2?Shl0UYJF06m_K`1iNGT0RXZ:0820P02;Rh/0PX:208R8R02>SXh0LG5a08j>SP1gMgL0RXZ:08N7
Q`2PX:00L71`07MgM`2;Rh/0PH6108N7Q`1mOGd0RHV908N7Q`29RHT0Ogmo06EUI@2FUYH0PH6109jN
WP21PH40O7al061PH01eMGD0LW9b05iNGP23Ph<0A4A401XJ6P040000000602@T900U9BD0?Cdm030`
<00c<c<01`L710000000C01DE5@0K6a/07inOP2OWil0Rh^;07YjNP2>SXh0Ti>C0:VYZ@25QHD0Shn?
09JFUP2?Shl0VYZJ08^;R`1nOWh0Ng]k08^;R`2BTY80KVi^09:BTP28R8P0VIVI0:BTY02:RXX0Y:BT
07moO`2DU9@0Shn?0:6QX@2JVYX0W9bL08F5Q@1jNWX0EeMG07alO026QXH0Kfm_08j>SP1nOWh0ZZZZ
0861P@22PX80JFUY07emO@1ZJVX0X:2P08F5Q@1fMWH0NGUi08:2PP1dM7@0YjNW08>3P`1^KVh0J6QX
07YjNP1EEED0N7Qh08Z:RP1eMGD0Ng]k08R8R01nOWh0KFe]08J6QP1_Kfl0QHF508j>SP2BTY80K6a/
07QhN02;Rh/0OWin07=cL`27QhL20861P@0Q0820P02?Shl0NWYj07UiN@23Ph<0JVYZ07YjNP1iNGT0
MWIf07QhN01aLG40Hf=S07QhN01eMGD0Jf][09BDU01kNg/0T92@07IfMP20P800Ng]k065QH@1nOWh0
L71`07alO01]KFd0J6QX07IfMP1/K6`0N7Qh04U9B@1PH600GEeM0080MWIf05T0I6AT06m_K`1ZJVX0
N7Qh05aLG01[Jf/0IfMW06a/K01aLG40FEUI071`L026QXH0HF5Q07]kN`1`L700HF5Q079bLP1JFUX0
DU9B06=SH`1lO7`0LG5a05UIF@1GEeL0M7Ad065QH@0b<S80JVYZ07emO@1TI6@0G5aL07UiN@1ADE40
KFe]07UiN@1SHf<0FEUI04Q8B01BDU80CTi>04E5A@1CDe<0<C4a04m?C`17AdL0Bd];04U9B@0j>SX0
ATI604A4A01>CTh0Cdm?0451@@18B4P0ATI605=CD`19BDT0K6a/034a<@1NGUh0@d=304m?C`0i>CT0
CTi>04e=C@1CDe<0FUYJ061PH016ATH09RHV04=3@`1?Cdl0BTY:04I6AP14A4@0>CTi03Hf=P0l?3`0
:b/[04U9B@0d=3@0=cLg0410@00o?cl0=CDe03Hf=P1=CDd0<S8b02h^;P0202TY:@0<0451@@15ADD0
61PH02<S8`0T92@051@D010@400C4a<092@T03Ti>@0N7Qh0oooo1P3IfMT100000040fMWI000F0=WI
f@800000103IfMT0503oool0O7al06=SH`1^KVh0OGem08J6QP23Ph<0R8R80:RXZ02=SHd0IfMW06e]
K@1lO7`0UiNG09nOW`1mOGd0S8b<079bLP2GUiL0PH610P1jNWX0?P1`L700KFe]05aLG026QXH0O7al
07]kN`22PX80X:2P08j>SP23Ph<0UYJF08^;R`2XZ:P0QhN70:2PX02CTi<0V9RH09bLW02TY:@0UIFE
08R8R02QXJ40RHV908>3P`2:RXX0QhN707AdM028R8P0K6a/08>3P`20P800RHV908J6QP1nOWh0N7Qh
08^;R`2EUID0R8R807MgM`1bLW80PX:207YjNP1aLG40TY:B08Z:RP1eMGD0KVi^06YZJP1cLg<0OGem
06QXJ01fMWH0P820079bLP1lO7`0P82006UYJ@23Ph<0RXZ:06IVIP0e=CD02@T9100000001P0Z:RX0
?Shn05=CD`1HF5P0Cdm?01PH60@0000001D0=3@d08:2PP2:RXX0P82009BDU023Ph<0PH6108j>SP29
RHT0Ph>309VIV@2;Rh/0WYjN0:2PX024Q8@0T92@09VIV@2PX:00Ph>307emO@1nOWh00P2?Shl0502D
U9@0VIVI09NGU`2GUiL0R8R80:RXZ02JVYX0X:2P09bLW02:RXX0HV9R07QhN01TI6@0N7Qh09fMW@27
QhL0PH6107emO@1kNg/0O7al0P1hN7P0>P2<S8`0NGUi08^;R`1_Kfl0MWIf08B4Q01bLW80Ogmo08f=
S@1mOGd0MgMg06MWI`2>SXh0JVYZ07moO`1]KFd0X:2P06e]K@1jNWX0TI6A08:2PP1`L700P82007If
MP1lO7`0Kfm_079bLP28R8P0QHF507UiN@1mOGd0O7al08Z:RP2?Shl0PX:207UiN@1lO7`0Q8B407If
MP1dM7@0K6a/06UYJ@1nOWh0L71`07UiN@1eMGD0S8b<08N7Q`24Q8@0NGUi06e]K@1ZJVX0T92@08>3
P`1kNg/0JVYZ06EUI@1IFET2079bLP0M07EeM@2BTY80IVIV07MgM`1SHf<0NWYj05mOG`1^KVh0JFUY
06e]K@1bLW80KVi^06m_K`1JFUX0MGEe08f=S@1_Kfl0E5AD055AD@13@d<0De=C04M7A`1HF5P0D51@
05ADE01YJFT0IFEU06i^KP1JFUX00P1TI6@05@1OGel0MWIf06ATI01IFET0Fe]K051@D01RHV80G5aL
04e=C@11@D40EUIF059BDP1]KFd0H61P0451@@1CDe<0GEeM05EEE@1IFET0De=C059BDP0203/k>`0K
03@d=016ATH0?Cdm05]KF`0f=SH0>3Ph04I6AP0c<c<0?Shn03Ti>@1UIFD0F5QH04Q8B01SHf<0D51@
04m?C`14A4@0EUIF06e]K@1=CDd0H61P04A4A01KFe/0>c/k05IFEP1<C4`0A4A40080B4Q801`0ATI6
03Ti>@0[:b/0<C4a04Y:BP0_;bl0;Rh^03Lg=`18B4P0:BTY01<C4`0`<300C4a<01lO7`0d=3@0>c/k
02/[:`0X:2P0ATI6034a<@0G5aL0:RXZ02LW9`0R8R804Q8B014A4@0W9bL0oooo1@3IfMT200000040
fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI05<0oooo07IfMP28R8P0O7al0:>SX`2JVYX0VIVI
0:FUY@2KVi/0UYJF07EeM@25QHD0Ng]k06m_K`23Ph<0YZJV09FEU@2@T900LW9b0820P024Q8@0GEeM
07IfMP1ZJVX0OGem04I6AP23Ph<0P8200:2PX02SXj<0RXZ:08V9R@27QhL0U9BD09:BTP2EUID0UYJF
07]kN`2;Rh/0O7al08N7Q`1mOGd0T92@08Z:RP1gMgL0WIfM07emO@2MWId0RXZ:07UiN@25QHD0Ti>C
0861P@1iNGT0M7Ad07=cL`2;Rh/0TY:B08F5Q@2;Rh/0Ti>C05=CD`1oOgl0A4A407alO027QhL0PX:2
08f=S@22PX80M7Ad071`L020P800O7al07YjNP1kNg/0NWYj07MgM`1iNGT0JVYZ05eMG@1SHf<0MgMg
02h^;P050000000603lo?`1MGEd0CTi>05MGE`12@T802`/;10000000RP0i>CT0GEeM08F5Q@2HV9P0
Shn?0:2PX026QXH0Vi^K08^;R`21PH40VIVI0:6QX@24Q8@0PH6105MGE`2@T900W9bL07UiN@2:RXX0
Q8B408>3P`2BTY80Y:BT07inOP2CTi<0Xj>S08^;R`2VYZH0RXZ:07inOP2>SXh0R8R808V9R@1XJ6P0
Ng]k061PH01nOWh0K6a/09jNWP1eMGD0Ph>308V9R@2:RXX0VIVI08j>SP1nOWh0VYZJ07AdM02=SHd0
MWIf06UYJ@1hN7P0KVi^08^;R`1oOgl0S8b<09FEU@1iNGT0OGem06UYJ@1fMWH0NWYj06a/K01iNGT0
MGEe08b<S02;Rh/0LW9b08Z:RP2<S8`0SHf=0451@@1XJ6P0IFEU071`L01oOgl0E5AD07UiN@27QhL0
MgMg07=cL`1`L700Lg=c07YjNP20P800LW9b07]kN`1aLG40M7Ad0820P01jNWX0J6QX06=SH`1eMGD0
Ph>306i^KP27QhL0MGEe06e]K@1aLG40NGUi07MgM`1VIVH0Lg=c06][J`1aLG40OWin07UiN@1_Kfl0
GemO06i^KP26QXH0Kfm_06ATI01CDe<0LW9b06=SH`1LG5`0JFUY06i^KP1gMgL0KFe]06a/K01XJ6P0
QhN705YJFP1ADE40I6AT05YJFP1HF5P0IfMW06m_K`1iNGT0IfMW06EUI@1WIfL0GemO05EEE@80EUIF
0240JVYZ04a<C01?Cdl0?Cdm05=CD`17AdL0C4a<05eMG@1@D500CDe=04];B`1LG5`0C4a<05ADE012
@T80H61P051@D015ADD0C4a<05YJFP0h>3P0DU9B065QH@1>CTh0D51@04Q8B01HF5P0?Shn03Lg=`1>
CTh0FUYJ05]KF`1CDe<00P1OGel0:@1RHV80?clo06QXJ01NGUh0Bd];04a<C012@T80Bd];04I6AP1?
Cdl0H61P05]KF`1CDe<0;bl_02XZ:P1=CDd0;2`/03lo?`1=CDd0@D5104M7A`0o?cl0<C4a03De=@1C
De<0<c<c03De=@0J6QX0=SHf030`<00S8b<0;Rh^02d];@0J6QX06ATI02l_;`0T92@02`/;00h>3P07
1`L0oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0U0?ooo`1VIVH0
NGUi07EeM@2FUYH0U9BD0:VYZ@2`/;00V9RH0:BTY01iNGT0G5aL07EeM@1gMgL0SXj>096AT@2;Rh/0
Vi^K09ZJVP21PH40JVYZ05eMG@1PH600IVIV06a/K020P800OGem075aL@1mOGd0K6a/07]kN`2@T900
PH6107=cL`29RHT0V9RH08f=S@0206e]K@0/09NGU`28R8P0S8b<08J6QP2CTi<0QXJ6075aL@2FUYH0
Ng]k07=cL`20P800Ogmo08F5Q@2FUYH0MgMg06e]K@1PH600JFUY07IfMP25QHD0Lg=c0861P@1nOWh0
PX:205=CD`29RHT0QHF507emO@1WIfL0HV9R07MgM`1nOWh0QHF507=cL`1hN7P0J6QX08V9R@1kNg/0
J6QX06UYJ@1KFe/0Ogmo05IFEP0[:b/50000000600d=3@10@400>3Ph03Ph>016ATH030`<10000000
1P0[:b/0KVi^06i^KP2GUiL0QHF508^;R`80WIfM0200PH6108b<S01hN7P0OGem0:NWY`2HV9P0Rh^;
09FEU@2DU9@0TY:B08V9R@2=SHd0T92@08R8R01nOWh0MWIf09FEU@2NWYh0P82008:2PP2LW9`0RXZ:
08J6QP20P800SHf=07alO02:RXX0Jf][071`L01fMWH0KFe]0820P080LG5a04`0Ng]k075aL@2;Rh/0
QXJ60:6QX@25QHD0SHf=075aL@1_Kfl0IFEU07inOP1WIfL0RXZ:08f=S@2CTi<0NGUi06YZJP1KFe/0
OWin08:2PP1lO7`0RXZ:08B4Q01dM7@0MWIf06][J`1PH600Ph>3092@T01eMGD0P82007UiN@1dM7@0
K6a/05mOG`2;Rh/0Lg=c08f=S@2>SXh0QhN706][J`28R8P0O7al06a/K01dM7@0MGEe08Z:RP1YJFT0
QHF508^;R`2EUID0LG5a06UYJ@24Q8@0JVYZ07inOP1/K6`0MgMg06YZJP24Q8@0L71`06][J`23Ph<0
IFEU08^;R`1OGel0FUYJ08V9R@1FEUH0JFUY061PH01HF5P0GemO06ATI01mOGd0L71`0P1HF5P0501F
EUH0HV9R08V9R@1EEED0G5aL07MgM`1QHF40IFEU071`L01[Jf/0J6QX05UIF@1MGEd0EeMG055AD@1b
LW80Jf][04m?C`1IFET0IVIV0P1SHf<0501MGEd0@D5105]KF`1KFe/0IVIV0410@01:BTX0?3`l04e=
C@1WIfL0DE5A04A4A01?Cdl0FUYJ055AD@16ATH0EeMG04m?C`16ATH0CTi>0P1OGel0=01GEeL0C4a<
04M7A`1;Bd/0>SXj05iNGP1?Cdl0CDe=06UYJ@1@D500H61P0492@P0h>3P0KFe]04Q8B01NGUh0Fe]K
059BDP1ADE40A4A404M7A`0_;bl0@T9205ADE00b<S80@D5102d];@12@T80Bd];04E5A@0i>CT0?clo
02d];@14A4@0<c<c04];B`0o?cl0ATI602<S8`18B4P0<30`03De=@0i>CT0>3Ph03De=@0f=SH092@T
038b<P0L71`08R8R018B4P3oool60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3I
fMT0D03oool0IVIV0820P01OGel0Q8B409:BTP2GUiL0W9bL09NGU`2@T900O7al061PH01eMGD0Ph>3
09>CT`2LW9`0Ogmo09RHV01oOgl0O7al07EeM@1OGel0OWin07IfMP1SHf<0P820061PH01XJ6P0M7Ad
075aL@26QXH0QhN708Z:RP1hN7P0QhN708>3P`2<S8`0YZJV07UiN@1dM7@0Ogmo08^;R`2:RXX0Q8B4
08b<S01jNWX0PH6108^;R`26QXH0RHV9096AT@1lO7`0Ng]k07UiN@1kNg/0HV9R07IfMP2@T900O7al
07emO@2<S8`0PH61096AT@1nOWh0QHF507]kN`1_Kfl0PX:208J6QP1jNWX0Hf=S08:2PP23Ph<0OWin
08Z:RP1bLW80Q8B408J6QP1^KVh0I6AT0P1VIVH00`0X:2P00000000000030000000502LW9`0^;Rh0
EUIF03<c<`0i>CT0100000007@0=3@d0CDe=08F5Q@2JVYX0WIfM09RHV02@T900Lg=c09RHV02WYjL0
O7al07emO@21PH40RXZ:07inOP2=SHd0Shn?09RHV02KVi/0WYjN08N7Q`2:RXX0U9BD06QXJ029RHT0
O7al07emO@20P800R8R80080PH6102<0UiNG0:6QX@2TY:@0OGem07MgM`1lO7`0MGEe06i^KP1jNWX0
K6a/06m_K`1mOGd0P82006e]K@2LW9`0UIFE0:>SX`1cLg<0M7Ad09FEU@1eMGD0Lg=c08Z:RP2GUiL0
Vi^K08Z:RP2CTi<0OWin05iNGP1eMGD0NWYj07UiN@2>SXh0Lg=c08:2PP0208V9R@1408F5Q@1fMWH0
NWYj07QhN02HV9P0RXZ:07moO`23Ph<0JVYZ08B4Q01cLg<0NGUi08F5Q@1VIVH0JVYZ06m_K`1`L700
Fe]K06e]K@1jNWX0QhN709FEU@1iNGT0KFe]08F5Q@1jNWX0M7Ad065QH@1ZJVX0JFUY08^;R`1`L700
Hf=S06e]K@1ZJVX0N7Qh08F5Q@1eMGD0O7al07inOP1QHF40MGEe06e]K@1VIVH0NWYj05UIF@17AdL0
Cdm?0820P01hN7P0IfMW06YZJP1JFUX0G5aL06m_K`21PH40LW9b06i^KP1]KFd0MgMg05]KF`1IFET0
G5aL05QHF01TI6@0De=C06=SH`1hN7P205mOG`1?0451@@1VIVH0LG5a06m_K`1aLG40B4Q805iNGP1J
FUX0ADE504=3@`1;Bd/0DU9B05YJFP1GEeL0BDU905mOG`1HF5P0EUIF05iNGP13@d<0E5AD04i>CP15
ADD0GUiN07AdM01PH600FEUI06UYJ@1BDU80GEeM04Y:BP0j>SX0EeMG04M7A`1SHf<0B4Q8059BDP1;
Bd/0DE5A05]KF`1MGEd0D51@05ADE017AdL0M7Ad05MGE`19BDT0@41004a<C017AdL0GEeM03Ph>018
B4P0D51@0451@@0j>SX0<30`02TY:@15ADD0=cLg03De=@0g=cL0Bd];02l_;`0U9BD0@T9202XZ:P11
@D409bLW03<c<`0[:b/07AdM02d];@0M7Ad0;Rh^02PX:00f=SH09bLW0?ooo`060=WIf@4000000@3I
fMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT01P3oool0QhN706e]K@1`L700MGEe08b<S080O7al
02D0WIfM06IVIP24Q8@0MgMg06i^KP2YZJT0VYZJ08B4Q021PH40RXZ:06m_K`23Ph<0Q8B407alO01_
Kfl0LW9b07AdM021PH40I6AT06][J`1dM7@0IVIV07IfMP27QhL0Q8B408V9R@1nOWh0UYJF07alO02?
Shl0Y:BT07IfMP1KFe/0JFUY08^;R`28R8P0VYZJ0080UYJF02@0KVi^07QhN023Ph<0Ti>C08>3P`2D
U9@0M7Ad07YjNP1eMGD0KVi^079bLP1`L700SHf=07UiN@21PH40H61P05iNGP1QHF40Jf][08V9R@1l
O7`0OGem09:BTP2=SHd0KFe]05mOG`27QhL0Z:RX08n?S`24Q8@0IfMW08:2PP1[Jf/0820P05=CD`0l
?3`60000000300L71`0P8200000000D0000002H02`/;061PH02;Rh/0MGEe096AT@1lO7`0QhN708b<
S02LW9`0SXj>08>3P`20P800NWYj09NGU`28R8P0Ogmo07YjNP1eMGD0RXZ:08N7Q`20P800VIVI08n?
S`1fMWH0Ti>C0861P@1cLg<0R8R80::RXP2@T900Rh^;07MgM`25QHD0N7Qh09JFUP2?Shl0OGem06e]
K@80K6a/00D0LG5a06e]K@22PX80RXZ:0861P@0208F5Q@0=092@T02:RXX0WYjN08J6QP2OWil0QHF5
09ZJVP1bLW80J6QX07MgM`24Q8@0T92@08j>SP0208N7Q`0508Z:RP2@T900OGem08f=S@1aLG400P1T
I6@0U02;Rh/0PH6107alO01dM7@0Lg=c07moO`1DE5@0O7al07EeM@2GUiL0PH6107AdM01`L700RXZ:
06EUI@1/K6`0Ogmo08b<S01^KVh0MGEe08F5Q@2;Rh/0LG5a07]kN`1dM7@0Ng]k07EeM@1oOgl0HF5Q
06YZJP1QHF40NGUi07=cL`1<C4`0Lg=c071`L01iNGT0LW9b061PH02ATI40NWYj06a/K01DE5@0JFUY
06a/K01fMWH0M7Ad05EEE@1VIVH0Ph>307EeM@1/K6`0LW9b06e]K@1^KVh0@T9205iNGP1^KVh0M7Ad
04e=C@1MGEd0Lg=c06EUI@1<C4`0MgMg079bLP1ZJVX0RXZ:06UYJ@1lO7`0HF5Q05mOG`1TI6@0FUYJ
05IFEP1dM7@0000006UYJ@1MGEd0Jf][03Ph>011@D40>3Ph04A4A01[Jf/0AdM706ATI01CDe<0H61P
065QH@1GEeL0AdM705mOG`1BDU80DE5A04Q8B01?Cdl0DU9B04=3@`0k>c/0FUYJ04Y:BP16ATH0IVIV
05QHF01KFe/0EUIF055AD@1LG5`0GUiN05EEE@1PH600CDe=04i>CP1=CDd0FEUI04Y:BP15ADD0A4A4
03`l?01;Bd/0BDU90451@@1IFET0Hf=S01dM7@0m?Cd0>3Ph03@d=018B4P0=3@d03/k>`15ADD0820P
03Lg=`0/;2`08R8R0410@00W9bL0@41002l_;`0W9bL0=SHf0492@P0j>SX092@T02PX:03oool60=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0>03oool0OWin06YZJP1/K6`0JVYZ
061PH01ZJVX0LW9b07YjNP1]KFd0JVYZ075aL@2ATI40Shn?09NGU`2RXZ80TY:B07moO`1XJ6P0GUiN
06=SH`1dM7@0KFe]08:2PP2ATI40SXj>07moO`20P800IfMW07MgM`1PH600KFe]07emO@29RHT0P820
07emO@2UYJD0Q8B408b<S01jNWX0P82009ZJVP2CTi<0R8R807inOP28R8P0OGem09fMW@1`L700SXj>
07=cL`1nOWh0T92@08R8R01aLG40LW9b0P1jNWX06@2HV9P0LG5a07MgM`21PH40Hf=S06UYJ@1/K6`0
KVi^08F5Q@21PH40QhN706][J`25QHD0JVYZ07IfMP1nOWh0Vi^K09FEU@29RHT0U9BD07IfMP1iNGT0
OGem07EeM@0g=cL03@000000O00F5QH0=3@d07IfMP1aLG40HF5Q08B4Q02CTi<0QhN709:BTP24Q8@0
SHf=08>3P`24Q8@0RHV909ZJVP2=SHd0Vi^K07MgM`1lO7`0Ogmo07alO02LW9`0Ti>C08^;R`2?Shl0
SXj>08:2PP1kNg/0N7Qh09jNWP20P800X:2P09NGU`1^KVh0Shn?08F5Q@2@T900UYJF09ZJVP21PH40
WYjN07MgM`2EUID0UYJF08J6QP1dM7@0UIFE09VIV@2LW9`0UIFE07alO01mOGd0U9BD07]kN`22PX80
MWIf07alO01oOgl0Q8B407QhN01iNGT0LW9b07moO`1iNGT0WinO08B4Q01mOGd0O7al08J6QP24Q8@0
HF5Q06][J`1jNWX0R8R807=cL`1gMgL0UIFE09BDU01`L700GemO05MGE`1[Jf/0OWin07EeM@1fMWH0
LW9b075aL@20P800M7Ad07alO02?Shl0O7al07emO@1IFET0MWIf07emO@1eMGD0JVYZ065QH@1<C4`0
KVi^07UiN@1/K6`0IfMW06][J`1cLg<0MGEe0820P01]KFd0SHf=07UiN@1=CDd0IVIV07QhN01QHF40
EUIF05MGE`26QXH0NWYj071`L01VIVH0Kfm_05]KF`1NGUh206MWI`0706e]K@1KFe/0E5AD07AdM01N
GUh0LW9b05eMG@0306QXJ00_069RHP1SHf<0F5QH05IFEP1JFUX0KFe]07IfMP1aLG40GEeM05MGE`1>
CTh0GUiN04=3@`1JFUX0KFe]075aL@1/K6`0Cdm?05]KF`1XJ6P0K6a/07AdM01oOgl0FEUI05IFEP18
B4P0HV9R03Ti>@0g=cL0<C4a04Y:BP1ADE40?Cdm038b<P13@d<0E5AD05aLG01MGEd0HV9R05UIF@11
@D40DU9B03Ti>@19BDT0:2PX05MGE`1QHF400P1PH6008@1?Cdl0B4Q802l_;`0^;Rh0?Shn03dm?@18
B4P0BTY:05=CD`16ATH0ADE504U9B@0a<C402`/;01XJ6P0o?cl06QXJ04I6AP0S8b<0=CDe04M7A`19
BDT0:b/[02h^;P0V9RH0;2`/030`<00i>CT0:b/[03Ti>@0N7Qh03`l?0?ooo`060=WIf@4000000@3I
fMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT07@3oool0P82005eMG@1^KVh0LW9b06UYJ@23Ph<0
GUiN06YZJP1`L700Jf][08B4Q01jNWX0Vi^K09RHV02QXJ40Q8B408^;R`1iNGT0E5AD06QXJ028R8P0
MgMg0861P@2GUiL0Q8B408Z:RP1cLg<0PX:20080JFUY03H0S8b<08R8R02?Shl0RHV909^KV`2?Shl0
Rh^;08R8R021PH40RHV908:2PP1jNWX0L71`08J6QP28R8P0Ti>C08V9R@21PH40L71`0820P01fMWH0
R8R808N7Q`1nOWh0SXj>06i^KP1;Bd/0LW9b07IfMP1^KVh0PX:2065QH@2;Rh/0PX:206EUI@1bLW80
Lg=c06i^KP1TI6@0Ogmo07IfMP21PH40OGem07MgM`1^KVh0N7Qh09:BTP1HF5P0Rh^;08F5Q@22PX80
GemO01dM7@010@4:0000000400@4100Q8B40CDe=06MWI`80Shn?0580OWin08:2PP1QHF40N7Qh07Mg
M`1mOGd0V9RH07IfMP2@T900LG5a08V9R@2ATI40Ti>C09BDU028R8P0M7Ad08b<S025QHD0VYZJ09:B
TP2?Shl0QXJ608j>SP1dM7@0U9BD0861P@2:RXX0Ogmo09:BTP1nOWh0S8b<08>3P`22PX80V9RH08f=
S@1kNg/0Vi^K07EeM@2DU9@0Y:BT09^KV`28R8P0P82008:2PP1fMWH0NGUi09:BTP27QhL0KVi^06m_
K`23Ph<0Ng]k08^;R`2KVi/0KFe]09:BTP25QHD0N7Qh07YjNP1]KFd0P82008Z:RP1WIfL0Shn?07mo
O`25QHD0R8R8071`L026QXH0PX:207UiN@26QXH0KVi^07EeM@1[Jf/0K6a/061PH01iNGT0Ph>307=c
L`1[Jf/0QHF50P23Ph<0:P1eMGD0Ogmo07AdM01cLg<0Jf][07EeM@1kNg/0JVYZ07AdM01PH600MWIf
065QH@25QHD0F5QH08F5Q@1[Jf/0P82006a/K01_Kfl0P82006QXJ01iNGT0OGem06m_K`1WIfL0M7Ad
07UiN@1dM7@0BTY:06e]K@1YJFT0IFEU05EEE@1WIfL0EEEE07IfMP1eMGD0De=C07QhN01mOGd0NWYj
05eMG@80I6AT00L0JFUY06YZJP1ADE40E5AD061PH01XJ6P0IVIV0080GEeM0380HF5Q05EEE@1BDU80
LG5a06QXJ01=CDd0GEeM05ADE01HF5P0CDe=05mOG`1/K6`0G5aL05]KF`1ZJVX0J6QX07alO01LG5`0
DE5A03De=@11@D40HF5Q03lo?`15ADD0DE5A03Ph>010@400F5QH04];B`1aLG40De=C04i>CP1FEUH0
DE5A061PH01SHf<0EEEE05]KF`1JFUX0EEEE05QHF01MGEd0EeMG03Xj>P12@T80ATI605aLG00];Bd0
BTY:03Hf=P80@d=301P0ATI60492@P0W9bL0<30`03@d=01;Bd/0<c<c0410@00[:b/0@T9204I6AP0a
<C40?Cdm03Ph>00e=CD0<C4a02<S8`0b<S8092@T02TY:@0j>SX0>CTi038b<P3oool60=WIf@400000
0@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT00`3oool0OGem07EeM@0207IfMP0507=cL`1U
IFD0FEUI07MgM`1hN7P00P23Ph<0801iNGT0LG5a0861P@2;Rh/0Kfm_05mOG`1oOgl0Ng]k07QhN021
PH40R8R806IVIP23Ph<0OWin08V9R@1[Jf/0Fe]K05QHF01>CTh0L71`07MgM`0V9RH0Ti>C07AdM01i
NGT0Ogmo08Z:RP1aLG40SHf=08J6QP2;Rh/0S8b<0P2?Shl0201VIVH0L71`07MgM`1mOGd0PX:2069R
HP2GUiL0NWYj0P1mOGd01P1nOWh0S8b<08F5Q@1nOWh0NWYj08R8R080QHF501L0MGEe07MgM`1OGel0
O7al07EeM@1hN7P0Jf][07IfMP1`L700QhN706i^KP27QhL0Jf][07IfMP26QXH0Lg=c07MgM`1[Jf/0
T92@06a/K019BDT07AdM00/;2`050000000500d=3@0@41003@d=01lO7`15ADD00P1VIVH0[026QXH0
N7Qh08J6QP25QHD0Ng]k07MgM`29RHT0Ph>307=cL`25QHD0SXj>09ZJVP20P800LG5a06][J`1eMGD0
M7Ad07emO@2QXJ40SHf=08R8R021PH40O7al07inOP2ATI40PX:209NGU`25QHD0RHV907alO029RHT0
W9bL08Z:RP1aLG40TY:B09FEU@23Ph<0R8R80820P02@T900UiNG08F5Q@28R8P0PH6108V9R@1jNWX0
MgMg09BDU02:RXX0Kfm_07]kN`2;Rh/0MGEe07inOP1lO7`0OWin07emO@1jNWX0Ph>304Y:BP27QhL0
LG5a07alO01]KFd0L71`08^;R`1oOgl0IfMW07MgM`1bLW80Lg=c06a/K01XJ6P0LG5a08>3P`1^KVh0
Q8B406IVIP1TI6@0NWYj07=cL`1RHV80Cdm?07AdM01WIfL0JFUY06MWI`1mOGd0LW9b071`L01WIfL0
HV9R07UiN@1bLW80S8b<07IfMP1oOgl0D51@075aL@1dM7@0Ogmo07]kN`1UIFD0OGem07AdM01cLg<0
HV9R04A4A01SHf<0Lg=c06a/K01_Kfl0IFEU07alO01RHV80Ogmo07EeM@1FEUH0HV9R061PH01ZJVX0
IFEU05QHF01`L700LW9b06m_K`1VIVH0Cdm?06a/K01eMGD0ATI6069RHP23Ph<0GemO06a/K017AdL0
MgMg06m_K`1QHF40Lg=c0492@P1DE5@0IVIV06EUI@1GEeL0DU9B05QHF01;Bd/0<30`04];B`19BDT0
MgMg07alO01NGUh0NWYj08R8R01UIFD0G5aL04Y:BP1;Bd/0HF5Q03`l?019BDT0?Cdm03hn?P0k>c/0
Bd];04I6AP12@T80EEEE061PH015ADD205MGE`03061PH01=CDd0DU9B0080C4a<00@0HV9R04];B`0i
>CT0Bd];0P1ADE402@1>CTh0@D5102LW9`0Z:RX0?3`l02d];@0b<S80?clo02HV9P0202d];@0402/[
:`0Q8B40<S8b02<S8`80=SHf00d0>CTi03Xj>P0X:2P0?clo04M7A`0o?cl0=CDe034a<@0C4a<0;Bd]
01dM7@0[:b/0oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0F0?oo
o`25QHD0WIfM092@T02<S8`0RHV90820P029RHT0QHF509BDU025QHD0QhN708^;R`1oOgl0I6AT09:B
TP2JVYX0JFUY07alO01aLG40Lg=c07emO@80MGEe02@0PX:207AdM01TI6@0OWin07UiN@1RHV80NWYj
0820P02;Rh/0MWIf08R8R02NWYh0P8200:BTY02DU9@0SHf=08J6QP27QhL0QXJ608B4Q01cLg<0MGEe
07=cL`27QhL0P82007MgM`2ATI40P82009BDU023Ph<0P82007alO01^KVh0Ng]k08F5Q@2@T90208R8
R00508:2PP2ATI40P820071`L022PX800P1gMgL02@1jNWX0SHf=07IfMP26QXH0O7al075aL@1YJFT0
Kfm_06][J`020820P00V08F5Q@2:RXX0U9BD08J6QP1oOgl0Cdm?03Ti>@0f=SH0<C4a028R8P0T92@0
000002h^;P0k>c/0:BTY055AD@1mOGd0O7al09ZJVP26QXH0TY:B09>CT`1dM7@0MWIf075aL@1iNGT0
R8R809RHV01gMgL0Q8B409^KV`1nOWh0QXJ607MgM`2;Rh/0IVIV075aL@2BTY8208F5Q@0j09FEU@28
R8P0Shn?0861P@2@T900R8R809:BTP26QXH0PH6108b<S01hN7P0Ti>C07inOP1YJFT0TY:B092@T02Q
XJ40Ng]k08>3P`1mOGd0QXJ607alO01mOGd0SHf=07QhN02:RXX0NWYj08n?S`24Q8@0WinO09FEU@1i
NGT0Ogmo07=cL`1nOWh0QhN707emO@20P800Ogmo06m_K`1cLg<0Rh^;07QhN02>SXh0Ogmo07AdM01^
KVh0TI6A079bLP24Q8@0S8b<07=cL`24Q8@0PH6106YZJP1cLg<0NWYj06a/K080Q8B401d0Lg=c0861
P@1iNGT0OGem07MgM`1ZJVX0RHV907EeM@22PX80OGem071`L026QXH0KVi^08F5Q@1dM7@0Lg=c07Ee
M@2FUYH0Jf][07moO`1gMgL0Ng]k06=SH`1_Kfl0JFUY07emO@1cLg<0MWIf08f=S@0207IfMP0807Ui
N@28R8P0R8R806i^KP1XJ6P0Lg=c07MgM`1dM7@2071`L01M04Y:BP1eMGD0JFUY07EeM@1@D500RXZ:
07]kN`1`L700Lg=c07AdM01?Cdl0Jf][05IFEP1YJFT0Kfm_06e]K@1SHf<0GEeM06ATI01VIVH0Lg=c
075aL@13@d<0AdM705=CD`1ADE40BDU905MGE`1SHf<0GUiN06=SH`1PH600JFUY04Y:BP1cLg<0F5QH
05EEE@1>CTh0A4A40410@01EEED0A4A4059BDP18B4P0D51@06e]K@1<C4`0F5QH05mOG`1>CTh0EEEE
069RHP1ADE40FEUI06UYJ@1MGEd0KFe]05eMG@1>CTh0EUIF02h^;P0j>SX0@41004=3@`16ATH0?Cdm
02`/;00R8R809RHV03hn?P0W9bL0=SHf04A4A00m?Cd0=3@d0451@@0a<C40@D5104A4A012@T80?Shn
02XZ:P0^;Rh0?Shn034a<@0d=3@0<c<c03dm?@0c<c<0GEeM03Lg=`0b<S80oooo00H0fMWI0@000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0O0?ooo`1ZJVX0S8b<07alO02CTi<0Vi^K08B4
Q01jNWX0QHF507IfMP1gMgL0M7Ad08Z:RP1]KFd0MgMg08V9R@1jNWX0MGEe07UiN@1mOGd0MWIf07Qh
N021PH40SHf=0861P@1iNGT0Kfm_06i^KP1XJ6P0LG5a05eMG@0208:2PP0E08B4Q02@T900XZ:R08N7
Q`23Ph<0T92@07]kN`1mOGd0Ng]k09RHV02;Rh/0Q8B408Z:RP1iNGT0Ng]k07EeM@29RHT0LW9b071`
L020P800OWin0080OGem00l0Kfm_0820P01lO7`0P82008V9R@2;Rh/0MgMg079bLP20P800OGem061P
H02GUiL0NGUi08N7Q`1jNWX00P1lO7`0KP1]KFd0NGUi06e]K@2:RXX0MgMg08F5Q@24Q8@0R8R808f=
S@1oOgl0KVi^06MWI`1^KVh0C4a<05YJFP0o?cl0CDe=04i>CP0X:2P0?Cdm03hn?P13@d<0AdM708>3
P`1SHf<0S8b<07emO@1ZJVX0V9RH09>CT`24Q8@0Vi^K09ZJVP2CTi<0TY:B08F5Q@2DU9@0QHF507em
O@26QXH0NWYj08n?S`2GUiL0QhN709JFUP29RHT0U9BD07inOP2@T900JFUY07inOP2<S8`0Ng]k09:B
TP2@T900SXj>08F5Q@22PX80Ng]k065QH@1jNWX0UYJF07YjNP2LW9`0PH6108Z:RP1nOWh0QhN707Qh
N02IVIT0OGem0820P024Q8@0Rh^;07inOP2:RXX0O7al06a/K022PX80SHf=0::RXP2BTY80QHF5071`
L01^KVh0RHV908B4Q02ATI40MWIf07inOP1fMWH0Rh^;07alO028R8P0OWin08J6QP1mOGd0R8R807Ad
M01lO7`0OWin07AdM01[Jf/0HF5Q08N7Q`1TI6@0OWin06i^KP26QXH0MWIf0P1/K6`0A`1WIfL0Kfm_
06UYJ@1`L700K6a/07=cL`1ZJVX0I6AT075aL@1bLW80IfMW069RHP1mOGd0QhN707UiN@21PH40NGUi
08>3P`1lO7`0MWIf08f=S@1gMgL0Fe]K06EUI@1aLG40M7Ad06i^KP1[Jf/0NWYj06a/K01>CTh0Hf=S
06a/K01kNg/0K6a/05EEE@1aLG40JFUY05IFEP1VIVH0MGEe07QhN01dM7@0NGUi06QXJ01aLG40Cdm?
05eMG@1lO7`0GUiN05UIF@1SHf<0L71`06][J`1UIFD0IVIV04M7A`1@D500Fe]K0451@@1CDe<0?Cdm
06=SH`1<C4`0ATI605iNGP1CDe<0Bd];05aLG01TI6@0A4A400<0EUIF03L0Bd];05QHF00d=3@0;Bd]
05=CD`1`L700KFe]05IFEP1LG5`0IfMW05mOG`1IFET0H61P06IVIP1PH600D51@03lo?`1;Bd/0I6AT
05=CD`1LG5`0GemO04Q8B01=CDd0@D51059BDP1HF5P0?Cdm03Ph>00U9BD0<30`02PX:00e=CD05aLG
04Y:BP10@400BTY:02/[:`1BDU80<c<c0451@@0W9bL0?clo02PX:018B4P0>CTi03dm?@12@T80;Rh^
030`<00b<S80;Bd]02@T900k>c/0oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WI
f@030=WIf@0V0?ooo`2;Rh/0R8R808b<S01bLW80V9RH07]kN`1dM7@0Ng]k09JFUP1jNWX0V9RH08f=
S@1nOWh0QHF508:2PP28R8P0Ph>3071`L01bLW80GemO06a/K022PX80IVIV065QH@1fMWH0F5QH06YZ
JP1OGel0MgMg06m_K`1VIVH0N7Qh0861P@25QHD0UYJF07YjNP24Q8@209fMW@070861P@2;Rh/0QXJ6
08V9R@2<S8`0PH6108Z:RP0207emO@05092@T01jNWX0PX:207]kN`2GUiL00P1oOgl08@1eMGD0Rh^;
06EUI@28R8P0HV9R06YZJP1iNGT0KVi^07UiN@1eMGD0Q8B408n?S`1lO7`0PH61079bLP2:RXX0Jf][
06=SH`2BTY80NGUi08V9R@1NGUh0Rh^;08j>SP28R8P0Ti>C075aL@2LW9`0Ti>C06][J`1`L700JFUY
03lo?`0205EEE@0C04Q8B01HF5P0KVi^07EeM@1QHF40O7al08V9R@1fMWH0Ph>308V9R@2=SHd0UIFE
08b<S023Ph<0OGem09NGU`1eMGD0UIFE09JFUP0209BDU01B08R8R020P800W9bL08^;R`2JVYX0ZJVY
0820P02@T900Q8B408>3P`2>SXh0Ph>307inOP2=SHd0UYJF08Z:RP2PX:00V9RH06MWI`2@T900Y:BT
09VIV@2@T900OWin079bLP27QhL0Q8B407moO`20P800Q8B406i^KP24Q8@0TI6A08f=S@22PX80R8R8
07]kN`1VIVH0Ti>C09:BTP1nOWh0R8R807emO@26QXH0Ph>308B4Q02=SHd0M7Ad08V9R@1`L700O7al
08N7Q`1kNg/0TY:B07AdM01ZJVX0NGUi06][J`1jNWX0R8R80861P@27QhL0Ng]k09>CT`1kNg/0JFUY
0820P01YJFT0TI6A0861P@1fMWH0O7al0820P01aLG40MgMg07QhN01bLW80MWIf06e]K@1gMgL0M7Ad
075aL@80MWIf01d0L71`07MgM`1]KFd0O7al07]kN`26QXH0KVi^07moO`1WIfL0LW9b06i^KP1RHV80
F5QH05iNGP24Q8@0MGEe07]kN`1[Jf/0Ng]k061PH01TI6@0EUIF06e]K@1DE5@0IfMW075aL@1@D500
OGem06YZJP0206IVIP14069RHP1^KVh0IfMW07MgM`1eMGD0DU9B03lo?`1YJFT0IfMW069RHP1SHf<0
Jf][059BDP1@D500>CTi04a<C01GEeL0JVYZ0410@01;Bd/0FEUI04A4A01>CTh0IVIV04Y:BP1/K6`0
JVYZ06m_K`1>CTh0EEEE04];B`17AdL0De=C02XZ:P1QHF40JFUY069RHP1GEeL0IFEU05MGE`1EEED0
KVi^05IFEP1@D500GUiN06QXJ01PH600ADE506a/K01<C4`0GEeM05IFEP18B4P0@T9204i>CP0d=3@0
B4Q803Hf=P10@4009RHV04m?C`13@d<07alO024Q8@19BDT0@41004];B`1:BTX2055AD@0A04i>CP0c
<c<0@d=304E5A@0l?3`0<c<c030`<018B4P0?Shn04A4A00o?cl09BDU03Lg=`1:BTX0=cLg02TY:@3o
ool01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0280oooo07IfMP2>SXh0
TY:B07inOP1gMgL0R8R806][J`1gMgL0T92@0861P@2GUiL0Ogmo07QhN027QhL0UYJF09VIV@1`L700
EeMG04];B`25QHD0O7al079bLP21PH40Kfm_07IfMP1eMGD0LW9b07MgM`19BDT0FEUI08F5Q@2BTY80
LW9b0P1jNWX0;@2<S8`0Zj^[09^KV`25QHD0W9bL07moO`20P800QhN708Z:RP2SXj<0Lg=c08B4Q02:
RXX0O7al06e]K@23Ph<0DU9B07AdM01lO7`0PH610820P028R8P0BTY:07=cL`2;Rh/0JFUY06MWI`1Y
JFT0Ogmo07UiN@1XJ6P0JFUY07YjNP24Q8@0Kfm_096AT@1/K6`0Q8B408J6QP22PX80Ogmo09JFUP22
PX80RXZ:0:NWY`0208J6QP0Z07alO01iNGT0QHF5065QH@1mOGd0KVi^079bLP1;Bd/0IfMW06=SH`1Z
JVX0SXj>09>CT`2?Shl0OGem0820P01oOgl0UiNG09FEU@1cLg<0S8b<09>CT`2FUYH0RXZ:0820P02;
Rh/0RHV909:BTP1jNWX0VYZJ07]kN`22PX80T92@08N7Q`23Ph<0MWIf09BDU02;Rh/0O7al08B4Q026
QXH0Ogmo0P24Q8@0^`26QXH0U9BD07emO@1nOWh0Rh^;0:2PX02IVIT0U9BD0820P01eMGD0OWin08:2
PP25QHD0R8R809>CT`2BTY80Rh^;08b<S022PX80PH6107inOP1fMWH0QXJ608n?S`1lO7`0QHF506UY
J@2>SXh0VYZJ07UiN@2;Rh/0NWYj08R8R025QHD0RXZ:09RHV01dM7@0U9BD07alO01hN7P0P82007If
MP21PH40QHF507emO@1dM7@0NWYj08>3P`1RHV80IfMW07alO01ZJVX0IfMW07QhN025QHD0U9BD0861
P@1bLW80O7al07emO@1`L700NWYj07alO02:RXX0I6AT0820P01nOWh0I6AT04a<C01jNWX0Fe]K075a
L@1`L700IVIV06i^KP1cLg<0Ogmo09>CT`1ZJVX0JFUY07YjNP1mOGd0Jf][06EUI@1eMGD0NWYj06EU
I@1^KVh0Ng]k08:2PP26QXH0NGUi05aLG01XJ6P0KFe]069RHP1VIVH0Lg=c05MGE`1NGUh0Jf][05AD
E01]KFd0FEUI055AD@1KFe/0EUIF05QHF01=CDd0E5AD069RHP1aLG40F5QH065QH@15ADD0EUIF05AD
E01ADE40GEeM04Q8B00f=SH0HV9R03hn?P0o?cl0E5AD04=3@`1KFe/0C4a<05iNGP1OGel0Lg=c03lo
?`0g=cL0EUIF0451@@16ATH0EUIF04];B`1PH600DE5A05ADE01KFe/0HV9R051@D01hN7P0Hf=S05]K
F`14A4@0@d=3069RHP18B4P0HV9R0410@01;Bd/0E5AD02PX:00h>3P0A4A403dm?@1GEeL0;bl_02XZ
:P0K6a/0=SHf04=3@`0T92@0ATI603Lg=`0d=3@0?clo04=3@`0`<300?Shn0451@@19BDT0BTY:0492
@P0g=cL071`L03dm?@0l?3`0;bl_04A4A00];Bd0=3@d02@T903oool01P3IfMT100000040fMWI000F
0=WIf@030000003IfMT0fMWI00<0fMWI02`0oooo07IfMP1gMgL0O7al0820P02?Shl0Ng]k0861P@2@
T900LG5a06EUI@1eMGD0SXj>08:2PP1jNWX0RHV909FEU@1aLG40JVYZ07AdM026QXH0JVYZ07moO`1Q
HF40FEUI06YZJP1OGel0M7Ad07]kN`20P800N7Qh08J6QP2DU9@0KVi^07YjNP2EUID0OGem08J6QP29
RHT0QHF508f=S@2GUiL0RHV908R8R080OGem0140SHf=09>CT`1cLg<0S8b<07AdM021PH40Ng]k06m_
K`1`L700FEUI06=SH`1cLg<0LW9b07emO@1ZJVX0PX:2061PH0020820P01M09FEU@1gMgL0LW9b08:2
PP29RHT0NGUi05mOG`1_Kfl0QXJ608>3P`1lO7`0PX:207UiN@1lO7`0N7Qh08>3P`2IVIT0U9BD07mo
O`1aLG40M7Ad07moO`26QXH0O7al092@T01kNg/0Jf][079bLP1ZJVX0MgMg08>3P`1gMgL0P82008N7
Q`2OWil0MGEe07emO@2CTi<0SHf=08j>SP2ATI40Y:BT09>CT`2`/;00SXj>09:BTP2?Shl0R8R808F5
Q@22PX80UIFE08R8R01oOgl0MWIf07]kN`2CTi<0SXj>08>3P`1mOGd0LG5a08^;R`27QhL0RHV908N7
Q`2NWYh0MWIf09VIV@2GUiL0QXJ608j>SP2LW9`0SHf=08F5Q@22PX80L71`07MgM`2ATI40Rh^;07Ui
N@2YZJT0PH6109VIV@2ATI40LG5a08>3P`25QHD0PX:207emO@1cLg<0QhN70::RXP24Q8@0R8R80080
PH6109X0O7al08b<S01^KVh0QhN708b<S01mOGd0Jf][07YjNP26QXH0PH6107IfMP1`L700Kfm_07]k
N`1^KVh0OWin07emO@1bLW80Lg=c079bLP1YJFT0IFEU08J6QP1dM7@0HF5Q08^;R`21PH40OWin06YZ
JP1GEeL0LG5a051@D01]KFd0MGEe07=cL`1aLG40JFUY05]KF`1VIVH0OGem07UiN@2FUYH0Lg=c08:2
PP1nOWh0LW9b07YjNP28R8P0O7al08F5Q@1MGEd0IVIV07MgM`1iNGT0PX:20820P01eMGD0MWIf05QH
F01XJ6P0L71`05QHF01PH600LG5a05UIF@1nOWh0IVIV06e]K@1NGUh0Hf=S06a/K01CDe<0EeMG06IV
IP1SHf<0Bd];06m_K`1IFET0@D5105YJFP1GEeL0FEUI05aLG01;Bd/0Jf][04U9B@1ZJVX0?Cdm05=C
D`12@T80I6AT05ADE01;Bd/0HF5Q05=CD`1LG5`0J6QX06][J`1YJFT0GemO04i>CP1SHf<0HV9R05YJ
FP1RHV80EEEE06MWI`1NGUh0Kfm_06EUI@1LG5`0Fe]K05mOG`1IFET0EEEE05mOG`1SHf<0>SXj055A
D@1aLG40Hf=S04Q8B01=CDd0Bd];03/k>`0`<300=3@d02PX:012@T80=cLg02XZ:P12@T80?Cdm02@T
901BDU80Bd];03Xj>P0l?3`0>SXj0451@@0f=SH0A4A403dm?@0`<300@T920410@00j>SX0A4A403<c
<`0l?3`0ATI602d];@0P8200oooo1P3IfMT100000040fMWI000F0=WIf@800000103IfMT0>P3oool0
PH6107]kN`1iNGT0Ti>C092@T01`L700NWYj09FEU@20P800O7al08N7Q`1dM7@0PH6106e]K@1nOWh0
PH6109BDU02<S8`0P82007MgM`1EEED0HF5Q0:JVYP2j^[X0IVIV07MgM`1cLg<0FEUI08Z:RP1mOGd0
RHV908>3P`27QhL0NGUi07emO@1_Kfl0T92@07emO@1iNGT0QHF506a/K01kNg/0SXj>08B4Q01gMgL0
KVi^0820P01eMGD0K6a/07alO023Ph<0SXj>07UiN@1lO7`0J6QX08N7Q`1YJFT207moO`0`07]kN`1o
Ogl0NGUi08>3P`1]KFd0P82009>CT`24Q8@0MWIf06IVIP1YJFT0MgMg08>3P`1kNg/0TI6A08R8R01g
MgL0UiNG07inOP23Ph<0SXj>07inOP2;Rh/0R8R806EUI@2a/K40VYZJ096AT@22PX80QXJ608:2PP2A
TI40T92@06m_K`1XJ6P0Q8B407inOP24Q8@0Ph>309JFUP2NWYh0S8b<07inOP22PX80ZZZZ096AT@2H
V9P0Kfm_0P24Q8@208b<S01R09^KV`27QhL0VYZJ08Z:RP2@T900R8R80820P02QXJ40TY:B07inOP1j
NWX0SHf=0;6a/@27QhL0JFUY0820P01lO7`0UIFE08Z:RP2CTi<0PH61092@T022PX80LG5a07]kN`2D
U9@0OWin08Z:RP29RHT0SXj>09:BTP2;Rh/0Kfm_08Z:RP1hN7P0OGem07AdM02CTi<0QXJ6071`L02Y
ZJT0H61P08^;R`2EUID0Rh^;07emO@1jNWX0OWin08:2PP2<S8`0SXj>07AdM026QXH0PH6106e]K@2J
VYX0R8R807YjNP1mOGd0GEeM07EeM@20P800JFUY07alO022PX80Ph>307EeM@28R8P0IFEU06][J`2:
RXX0KFe]075aL@24Q8@0OGem08V9R@23Ph<0JFUY07EeM@1PH600Kfm_07=cL`1^KVh0IVIV06=SH`1j
NWX0PH6107IfMP1kNg/0H61P07]kN`1OGel0MgMg07UiN@1^KVh0OGem07EeM@1cLg<307emO@1U092@
T01fMWH0GEeM07MgM`1DE5@0OGem06i^KP1eMGD0JFUY05EEE@1ZJVX0MgMg04Q8B01lO7`0M7Ad06][
J`0o?cl0IVIV05mOG`1UIFD0EeMG06i^KP1HF5P0HV9R055AD@1>CTh0CDe=05=CD`1?Cdl0HF5Q051@
D01OGel0CTi>04];B`1QHF40EeMG055AD@1DE5@0EUIF04I6AP1?Cdl0EeMG05ADE01<C4`0LW9b05]K
F`14A4@0DU9B04M7A`1EEED0I6AT061PH01cLg<0IFEU05MGE`1HF5P0MGEe05UIF@1XJ6P0GEeM05mO
G`1EEED0KFe]06i^KP1UIFD0EeMG0410@00/;2`0?3`l051@D01OGel0D51@03Lg=`10@4006ATI03`l
?00g=cL0@D5104Q8B01;Bd/0AdM703hn?P0c<c<0?3`l02DU9@13@d<0>c/k04E5A@0h>3P0GUiN03Xj
>P16ATH0:b/[04m?C`0g=cL09BDU04a<C00g=cL092@T03`l?03oool01@3IfMT200000040fMWI000F
0=WIf@030000003IfMT0fMWI00<0fMWI0280oooo07IfMP1^KVh0OGem0861P@28R8P0Ph>307moO`2>
SXh0Ogmo071`L01UIFD0Ng]k09BDU02:RXX0QHF508j>SP1dM7@0PX:209BDU01gMgL0GEeM08:2PP2:
RXX0SHf=065QH@1cLg<0NGUi071`L024Q8@0Ph>308V9R@2GUiL0OWin0P2?Shl08`2:RXX0Ti>C07mo
O`2=SHd0MGEe09BDU02=SHd0RHV907]kN`1lO7`0P82007YjNP20P800KFe]08R8R01jNWX0MWIf08b<
S02=SHd0P82006m_K`1bLW80KVi^06e]K@1/K6`0PH6107QhN01QHF40Jf][05]KF`1jNWX0N7Qh071`
L01aLG40M7Ad0080Lg=c03l0T92@09>CT`1[Jf/0PH6108n?S`27QhL0R8R809VIV@25QHD0N7Qh08^;
R`2ATI40J6QX08F5Q@22PX80SHf=0:JVYP25QHD0VYZJ08:2PP2LW9`0KVi^09NGU`26QXH0SXj>0861
P@2DU9@0Kfm_08J6QP23Ph<0PH610:BTY02HV9P0RXZ:09JFUP2DU9@0Rh^;08f=S@2>SXh0PX:207]k
N`24Q8@0P82006QXJ02;Rh/0QHF508^;R`1dM7@0QHF508:2PP29RHT0Shn?092@T01_Kfl0R8R807al
O02BTY80Rh^;092@T021PH40MGEe07UiN@2JVYX00P2@T900K@27QhL0Shn?09RHV02HV9P0M7Ad09:B
TP1^KVh0PX:208f=S@1VIVH0NWYj06UYJ@2DU9@0RXZ:079bLP25QHD0MGEe08j>SP1jNWX0M7Ad08>3
P`28R8P0NWYj09NGU`1gMgL0QXJ607moO`1fMWH0GEeM08^;R`22PX80LW9b08n?S`27QhL0JVYZ06AT
I01fMWH0LG5a07QhN01jNWX0OWin09:BTP1LG5`0QHF506i^KP2DU9@0R8R807QhN01gMgL0O7al075a
L@22PX80I6AT08j>SP21PH40QXJ607moO`1`L700FEUI07IfMP1VIVH0Lg=c065QH@1]KFd0MGEe07al
O01XJ6P0Ogmo07inOP1/K6`0MWIf07=cL`1`L700M7Ad07]kN`1eMGD0NWYj06i^KP1kNg/0P82008R8
R01`L700NWYj07=cL`1bLW80GUiN05mOG`1aLG40NGUi08B4Q01GEeL0?Shn06YZJP1KFe/0JFUY07=c
L`1]KFd0F5QH06ATI01DE5@0C4a<05aLG01/K6`0G5aL05eMG@1>CTh0C4a<071`L01BDU800P1JFUX0
5`1NGUh0F5QH03hn?P0o?cl0BTY:055AD@1MGEd0J6QX05UIF@1?Cdl0BTY:069RHP18B4P0EUIF04];
B`1UIFD0I6AT05]KF`1SHf<0M7Ad05aLG01ZJVX0HV9R0080AdM700P0J6QX069RHP1GEeL0HF5Q04e=
C@1RHV80Cdm?02`/;080BTY:0P14A4@07010@400F5QH04=3@`10@400@T92055AD@1:BTX0AdM704Q8
B015ADD0;bl_05IFEP0l?3`0Cdm?04];B`18B4P0@d=304i>CP1=CDd0@41004Y:BP0L71`09RHV01dM
7@0m?Cd0Cdm?03Ph>03oool60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0
V@3oool0PX:207]kN`1aLG40P82009BDU01`L700PX:207moO`1PH600Lg=c08f=S@2:RXX0MGEe07]k
N`1gMgL0MGEe07MgM`26QXH0UiNG0861P@1QHF40IVIV07QhN027QhL0SHf=06a/K01eMGD0U9BD08^;
R`2IVIT0T92@07moO`2EUID0SHf=07=cL`23Ph<0R8R80:>SX`2?Shl0T92@08N7Q`1bLW80Ph>307in
OP2FUYH0V9RH07alO01bLW80Ogmo08:2PP2EUID0SHf=08:2PP2@T900Ph>306a/K01eMGD0MWIf075a
L@1WIfL0Hf=S06][J`2;Rh/0P82007UiN@1TI6@0RHV908:2PP2<S8`0RXZ:06a/K02?Shl0UYJF07mo
O`2;Rh/0VIVI08f=S@2BTY80VYZJ08V9R@1fMWH0Ogmo08V9R@1]KFd0Kfm_08Z:RP2LW9`0VYZJ07in
OP2DU9@0W9bL07UiN@26QXH0TI6A07alO022PX80OWin07AdM02>SXh0U9BD07emO@2CTi<0X:2P08f=
S@2?Shl0LW9b09BDU01gMgL0NWYj07AdM02MWId0Ti>C0861P@2IVIT0QHF509:BTP1gMgL0Ogmo08:2
PP2QXJ40RXZ:06a/K02>SXh0MGEe092@T02JVYX0WYjN08F5Q@1dM7@0TI6A08N7Q`25QHD0T92@07Mg
M`25QHD0OWin07QhN02;Rh/0O7al0:6QX@2FUYH0N7Qh07emO@2BTY80PH6109BDU02@T900Ng]k08F5
Q@2<S8`0MWIf07alO00207UiN@0T08N7Q`2FUYH0TY:B08f=S@1eMGD0RHV908N7Q`1iNGT0TY:B09RH
V01eMGD0M7Ad07=cL`1mOGd0Ogmo06a/K01_Kfl0OWin08Z:RP26QXH0Ng]k06UYJ@26QXH0KVi^07]k
N`1MGEd0R8R807emO@25QHD0LW9b06m_K`27QhL0LG5a092@T029RHT0PH610P1mOGd0A@1]KFd0Lg=c
08J6QP1YJFT0JVYZ06QXJ01QHF40LW9b07]kN`2?Shl0JVYZ07MgM`1iNGT0M7Ad07EeM@1oOgl0IFEU
071`L01aLG40Jf][05eMG@1hN7P0MGEe05UIF@1[Jf/0JVYZ06ATI01fMWH0R8R805eMG@1>CTh0GUiN
06QXJ01gMgL0R8R806][J`1RHV80GUiN06ATI01^KVh0LG5a07MgM`1^KVh0FUYJ03dm?@1KFe/0H61P
04M7A`1JFUX0HV9R05iNGP1PH600HF5Q04I6AP13@d<0HV9R05aLG01MGEd0?clo05QHF01bLW80I6AT
069RHP1KFe/0I6AT05EEE@1_Kfl0FEUI06EUI@0206QXJ00805MGE`1DE5@0HF5Q06UYJ@15ADD0FUYJ
06ATI01aLG4206EUI@0X05mOG`1IFET0?Shn06IVIP1WIfL0FEUI0451@@1<C4`0ADE504M7A`0b<S80
Bd];04Q8B01;Bd/0B4Q804U9B@1?Cdl0?3`l04M7A`18B4P0@d=303Ph>01>CTh0De=C03/k>`1;Bd/0
A4A406=SH`0h>3P0?3`l03Ph>013@d<0;bl_02PX:018B4P0EUIF04U9B@0j>SX0=3@d0?ooo`H0fMWI
0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0D0?ooo`1hN7P0Rh^;08V9R@1eMGD0
OWin08^;R`1fMWH0MgMg08b<S01LG5`0RXZ:07UiN@1bLW80Ng]k07inOP2LW9`0K6a/08^;R`28R8P2
08J6QP1C07emO@24Q8@0UiNG09jNWP22PX80MWIf06YZJP1`L700LW9b06ATI02>SXh0N7Qh07inOP2<
S8`0TY:B0861P@2SXj<0RXZ:09>CT`27QhL0PX:208B4Q01`L700UiNG0:2PX027QhL0PH6105iNGP22
PX80Q8B407emO@24Q8@0MGEe07=cL`1nOWh0Ti>C07inOP1jNWX0N7Qh05QHF01cLg<0Ng]k06][J`2B
TY80MgMg08b<S01iNGT0SHf=08^;R`1mOGd0MWIf09BDU02ATI40OGem08J6QP2GUiL0SHf=092@T01l
O7`0Ti>C0861P@25QHD0MWIf09^KV`21PH40OWin08R8R01`L700JFUY08F5Q@1MGEd0W9bL08Z:RP22
PX80Ti>C08F5Q@2;Rh/0Ogmo08F5Q@1jNWX0PH6108Z:RP23Ph<00P27QhL04`28R8P0RXZ:092@T01m
OGd0R8R808J6QP1mOGd0Ph>307=cL`2CTi<0Ph>3096AT@2[Zj/0D51@0:VYZ@2FUYH0MGEe08n?S`2=
SHd00P25QHD08@27QhL0PX:209>CT`1hN7P0MgMg0861P@1cLg<0OGem09ZJVP22PX80TI6A08N7Q`2>
SXh0Ph>30861P@27QhL0QXJ6096AT@2<S8`0Vi^K07=cL`2ATI40RHV907emO@1oOgl0KVi^079bLP1c
Lg<0Ti>C071`L02:RXX0R8R808j>SP020861P@1C0820P01mOGd0TI6A05YJFP1fMWH0OGem08:2PP1`
L700SHf=08J6QP1oOgl0P82008>3P`1fMWH0TY:B08J6QP2<S8`0Ng]k07YjNP20P800L71`07emO@27
QhL0PH6107=cL`21PH40Hf=S09NGU`1oOgl0MGEe07=cL`1jNWX0O7al08>3P`1oOgl0PH6106QXJ01h
N7P0F5QH07MgM`22PX80K6a/07=cL`1nOWh0GemO06IVIP1UIFD0Ph>306QXJ01[Jf/0Ogmo07IfMP1X
J6P0Lg=c06QXJ01VIVH0O7al06i^KP1kNg/0MWIf07AdM01jNWX0JFUY07UiN@20P800Jf][05eMG@1W
IfL0KVi^07QhN01XJ6P0MWIf06=SH`1OGel0Kfm_05YJFP1<C4`0DU9B06i^KP1`L700LW9b059BDP1S
Hf<00P1LG5`0@P0m?Cd0GemO059BDP16ATH0DU9B06EUI@1LG5`0JFUY05ADE01MGEd0HV9R03Ti>@1;
Bd/0I6AT059BDP1OGel0@D51061PH01nOWh0EUIF04];B`1UIFD0HV9R05EEE@1>CTh0GemO06IVIP0o
?cl0GemO05IFEP0n?Sh0GUiN05]KF`1DE5@0EeMG055AD@1NGUh0A4A4061PH00b<S80@41003Ph>010
@400>3Ph04Q8B011@D40D51@03/k>`0c<c<0?3`l04M7A`0m?Cd0=cLg02d];@10@4009RHV04E5A@10
@400A4A402PX:00V9RH0A4A403<c<`0j>SX0<c<c0?ooo`H0fMWI0@0000010=WIf@005P3IfMT00`00
0000fMWI0=WIf@030=WIf@0T0?ooo`1nOWh0QhN70861P@1_Kfl0Ng]k06QXJ01_Kfl0Lg=c07inOP1J
FUX0IFEU07UiN@1RHV80Jf][079bLP1cLg<0TI6A08V9R@1jNWX0P82008B4Q027QhL0S8b<09FEU@1/
K6`0OWin06e]K@2?Shl0Rh^;08f=S@1XJ6P0QhN70861P@2ATI40SXj>0P22PX80;P2;Rh/0VIVI09RH
V02@T900Ph>308f=S@2UYJD0MWIf07YjNP24Q8@0SHf=0861P@2KVi/0IVIV07AdM02EUID0Ph>307Ui
N@1jNWX0UiNG071`L020P800Q8B407AdM01hN7P0QhN707EeM@1iNGT0NWYj08n?S`1oOgl0OGem07in
OP24Q8@0UIFE06YZJP2JVYX0PX:208R8R02PX:00MWIf09FEU@1mOGd0QhN709RHV01kNg/20861P@0l
08j>SP29RHT0Ogmo0820P02:RXX0Ti>C08f=S@1jNWX0H61P06][J`1mOGd0QhN709nOW`28R8P0Vi^K
075aL@1hN7P0Rh^;09^KV`2@T900SHf=08Z:RP1hN7P0P82008F5Q@21PH40SHf=06a/K020P800Shn?
08:2PP1lO7`0Xj>S08b<S027QhL0Ng]k08Z:RP25QHD0LW9b07EeM@1oOgl0R8R808n?S`2@T900OWin
08>3P`2;Rh/0XZ:R09jNWP1nOWh0Ogmo09>CT`2:RXX0Ti>C0820P02NWYh0Ti>C08R8R01jNWX0WinO
0P22PX80YP1bLW80[:b/07moO`1QHF40IFEU07YjNP2?Shl0PX:208N7Q`22PX80M7Ad08f=S@2HV9P0
J6QX07EeM@25QHD0MgMg07]kN`2[Zj/0TI6A07AdM02;Rh/0MGEe06m_K`1hN7P0MGEe09RHV01cLg<0
K6a/07inOP2PX:00Q8B409bLW01/K6`0NWYj07inOP24Q8@0PX:2069RHP1ZJVX0LG5a07EeM@1dM7@0
OWin075aL@2ATI40NWYj07IfMP1aLG40KVi^07UiN@1CDe<0EUIF079bLP1iNGT0LW9b06QXJ01mOGd0
JVYZ07YjNP1eMGD0KVi^06QXJ01dM7@0MWIf069RHP1`L700OWin06ATI01RHV80OWin04U9B@1QHF40
Ogmo07UiN@1eMGD0KVi^07UiN@1HF5P0G5aL071`L01?Cdl0HV9R06a/K01mOGd0J6QX06e]K@1`L700
MgMg05QHF01TI6@0D51@075aL@19BDT0E5AD04a<C01^KVh0CDe=06EUI@1IFET0DE5A05IFEP0m?Cd0
G5aL06=SH`1IFET0DE5A061PH01LG5`0Lg=c05YJFP1CDe<0D51@05MGE`1OGel0M7Ad06MWI`1ZJVX0
EUIF04Y:BP1KFe/0DE5A05iNGP1RHV80GUiN05EEE@1eMGD0CTi>06YZJP1LG5`0JVYZ05IFEP12@T80
CDe=05aLG01GEeL0FUYJ051@D016ATH0ADE504M7A`1?Cdl0B4Q804U9B@1HF5P0B4Q805aLG01EEED0
?clo05QHF012@T80De=C04Y:BP1>CTh0?3`l04U9B@0k>c/0@41004i>CP11@D40:b/[02DU9@0_;bl0
DE5A02l_;`3oool60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0:@3oool0
QhN708b<S01aLG40KVi^08N7Q`2<S8`0NWYj06QXJ01[Jf/0PH6107YjNP1_Kfl0PH6106IVIP1mOGd0
Ogmo08>3P`1XJ6P0QXJ606IVIP1[Jf/0OGem08V9R@1XJ6P0Ogmo08F5Q@1kNg/0MWIf08J6QP2CTi<0
U9BD0861P@22PX80QhN707AdM01iNGT0SXj>09^KV`1dM7@0SXj>0080RHV902D0Shn?0:2PX026QXH0
QXJ609JFUP21PH40NWYj08Z:RP21PH40Shn?07IfMP1bLW80M7Ad07MgM`23Ph<0QHF507QhN026QXH0
OWin07MgM`21PH40O7al06YZJP1oOgl0PX:208Z:RP2<S8`0Rh^;07emO@1gMgL0QHF5075aL@1nOWh0
Ti>C06e]K@28R8P0QHF50080TY:B00H0N7Qh07alO01dM7@0N7Qh09BDU02BTY8208V9R@0708^;R`20
P800QHF507emO@27QhL0RHV908R8R00208F5Q@0G092@T02NWYh0O7al09RHV02EUID0SXj>08N7Q`28
R8P0SHf=09:BTP2ATI40S8b<08n?S`20P800N7Qh0820P02:RXX0N7Qh08N7Q`24Q8@0YJFU09>CT`25
QHD00P21PH40A@2CTi<0NWYj079bLP2BTY80QXJ609:BTP2HV9P0P82007]kN`1eMGD0SHf=09VIV@22
PX80TY:B096AT@2@T900O7al09JFUP1lO7`0QHF507QhN01jNWX0Rh^;0820P026QXH0Lg=c08f=S@29
RHT0L71`0820P01gMgL0NGUi07IfMP25QHD0Ogmo07]kN`1aLG40Shn?06YZJP24Q8@0U9BD08^;R`1i
NGT0PX:208V9R@1WIfL0OGem08B4Q01lO7`0M7Ad07emO@1PH600G5aL08>3P`1lO7`0SHf=08B4Q01n
OWh0P82006a/K01oOgl0IfMW07UiN@1VIVH0L71`07EeM@1oOgl0OGem07=cL`0208J6QP1g08N7Q`1i
NGT0IfMW069RHP1WIfL0Kfm_07alO01ADE40MWIf05iNGP1[Jf/0NGUi06EUI@1nOWh0MgMg08^;R`1a
LG40IfMW06a/K01LG5`0Lg=c06EUI@1[Jf/0GEeM06IVIP1LG5`0Ng]k07IfMP1NGUh0J6QX069RHP1V
IVH0GemO06i^KP1RHV80IVIV061PH01aLG40H61P065QH@1XJ6P0QXJ607]kN`1YJFT0HV9R07QhN01n
OWh0HF5Q05YJFP1QHF40GEeM051@D01<C4`0EUIF0492@P1IFET0J6QX069RHP1jNWX0K6a/05UIF@1G
EeL0JVYZ06QXJ01GEeL0DU9B05ADE01BDU80ATI6061PH01[Jf/0FUYJ05ADE01QHF40GUiN06UYJ@1G
EeL0IVIV04i>CP1OGel0ATI6059BDP1EEED0E5AD04i>CP1?Cdl0DE5A04Y:BP1BDU80A4A4059BDP1O
Gel0EeMG04Q8B00e=CD0AdM706ATI01HF5P0@D5104e=C@16ATH0>3Ph04=3@`1DE5@0JFUY03Ph>019
BDT0A4A4038b<P0k>c/0CDe=04M7A`14A4@0?3`l03dm?@0];Bd0=cLg0410@03oool01P3IfMT10000
0040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI01@0oooo07inOP1aLG40PX:207QhN01[Jf/0
KVi^06UYJ@1[Jf/0LW9b07alO021PH40Kfm_07=cL`1dM7@0NGUi05iNGP24Q8@0H61P07IfMP80JVYZ
00T0UYJF08N7Q`1bLW80RXZ:09BDU02BTY80RXZ:08f=S@2BTY800`1lO7`0=025QHD0R8R808V9R@2Z
ZZX0UIFE0:6QX@23Ph<0SXj>09ZJVP1^KVh0TI6A08V9R@2IVIT0Ti>C09:BTP2CTi<0QXJ607AdM01i
NGT0QXJ607AdM02@T900OWin07MgM`1SHf<0PH6108B4Q01mOGd0VIVI07QhN01jNWX0Ph>309:BTP26
QXH0Kfm_08^;R`1lO7`0OGem08B4Q01jNWX0RHV909:BTP2@T900Q8B4079bLP1RHV80LW9b08^;R`20
P800R8R806i^KP28R8P208B4Q00V08>3P`25QHD0RXZ:07EeM@1]KFd0TI6A08b<S023Ph<0P82008F5
Q@1oOgl0Q8B408^;R`1oOgl0MgMg09JFUP1fMWH0UYJF07]kN`2KVi/0Kfm_09nOW`1oOgl0RXZ:07Yj
NP1iNGT0SHf=096AT@1lO7`0OWin079bLP1jNWX0X:2P092@T02;Rh/0NWYj06UYJ@24Q8@207MgM`0C
08^;R`28R8P0PX:207moO`27QhL0Ti>C08N7Q`24Q8@0RHV909RHV023Ph<0TI6A07inOP2CTi<0N7Qh
0861P@1_Kfl0SHf=08B4Q00208V9R@0708Z:RP2HV9P0Ogmo0820P02BTY80Ph>306][J`0208N7Q`17
08j>SP22PX80R8R808B4Q01lO7`0JVYZ07moO`2;Rh/0K6a/0820P01ZJVX0Ng]k08F5Q@2@T900Q8B4
075aL@1oOgl0Ph>3075aL@1gMgL0OGem0861P@29RHT0NGUi07moO`2<S8`0KVi^07]kN`2BTY80RHV9
06QXJ01SHf<0J6QX075aL@1LG5`0JFUY07EeM@1jNWX0PH6107=cL`1/K6`0Fe]K06][J`1@D500L71`
08f=S@1cLg<0NWYj07inOP1OGel0KFe]08F5Q@1eMGD0TI6A06IVIP1YJFT0IFEU07MgM`1hN7P0Jf][
07]kN`1bLW80Ogmo06UYJ@1kNg/0NGUi06QXJ01/K6`0Ph>3065QH@22PX800P1iNGT01P1hN7P0IfMW
05aLG01UIFD0GEeM079bLP80GUiN03d0KFe]06QXJ01[Jf/0H61P05MGE`1QHF40F5QH05]KF`1FEUH0
>SXj05IFEP0l?3`0G5aL061PH01FEUH0MGEe05YJFP1FEUH0H61P05iNGP1IFET0JFUY065QH@1LG5`0
Bd];061PH01>CTh0LW9b05QHF01GEeL0DU9B06i^KP1RHV80F5QH04];B`1LG5`0FEUI075aL@1_Kfl0
GEeM055AD@1?Cdl0FEUI04M7A`1GEeL0ADE504M7A`16ATH0BDU903Ph>01:BTX0=cLg03/k>`1=CDd0
DE5A02/[:`1aLG40ATI604E5A@17AdL0?Cdm0080AdM700`0EEEE05IFEP0g=cL0@T9203dm?@0j>SX0
?Cdm03Ph>00_;bl0820P030`<03oool60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT0
0`3IfMT0:03oool0KVi^079bLP1cLg<0L71`07alO01eMGD0MWIf07=cL`1lO7`0Rh^;08j>SP29RHT0
Ng]k06MWI`1cLg<0Ph>306YZJP1]KFd0OWin08:2PP1YJFT0OWin08R8R021PH40J6QX08N7Q`1oOgl0
JFUY08b<S028R8P0SXj>08J6QP2;Rh/0S8b<09NGU`2OWil0J6QX08>3P`2ATI4209:BTP0S09FEU@2?
Shl0R8R806i^KP2EUID0MGEe07IfMP1eMGD0SXj>096AT@23Ph<0M7Ad07EeM@2IVIT0Hf=S09FEU@1j
NWX0Ogmo08J6QP1eMGD0QhN707UiN@2?Shl0PX:208>3P`27QhL0OWin07UiN@1gMgL0VYZJ075aL@1n
OWh0Ti>C08Z:RP2<S8`00P29RHT0701nOWh0QHF507moO`24Q8@0O7al08N7Q`2?Shl0OGem08b<S01>
CTh0H61P07YjNP1mOGd0V9RH08V9R@1gMgL0L71`08N7Q`1`L700OWin07]kN`2;Rh/0QHF5092@T021
PH40LW9b09JFUP1bLW8208n?S`0606i^KP27QhL0UYJF08F5Q@2HV9P0OWin0P28R8P04`2>SXh0WIfM
07YjNP26QXH0L71`06YZJP1iNGT0RXZ:08f=S@2:RXX0OGem07UiN@25QHD0TY:B0861P@2<S8`0Ng]k
08J6QP2:RXX00P1mOGd05P25QHD0TY:B096AT@1fMWH0JVYZ06IVIP24Q8@0Hf=S07emO@22PX80QHF5
08Z:RP1hN7P0J6QX079bLP1nOWh0QhN706YZJP21PH40Kfm_06QXJ01eMGD207UiN@080820P025QHD0
S8b<09FEU@1eMGD0PH61075aL@24Q8@208F5Q@0I08B4Q01QHF40PH61096AT@1`L700N7Qh09NGU`2:
RXX0NWYj08J6QP1nOWh0MgMg08>3P`1oOgl0M7Ad09>CT`1cLg<0Ogmo07alO01oOgl0Q8B407alO01M
GEd0HV9R08N7Q`0206UYJ@0n07QhN01lO7`0FEUI07AdM01YJFT0Fe]K07MgM`1bLW80QhN708f=S@1f
MWH0FUYJ06UYJ@27QhL0Fe]K07=cL`1_Kfl0IVIV05=CD`1[Jf/0Ph>305iNGP21PH40PX:208F5Q@1k
Ng/0Kfm_08J6QP2>SXh0LW9b06a/K01nOWh0Jf][06i^KP1XJ6P0Lg=c06e]K@23Ph<0M7Ad065QH@1f
MWH0NGUi06a/K01NGUh0Hf=S069RHP1QHF40DU9B05EEE@1PH600@d=304M7A`1WIfL0Bd];06UYJ@13
@d<0FEUI06IVIP1UIFD0IVIV05]KF`1UIFD205aLG00G05MGE`1SHf<0MWIf07UiN@1fMWH0D51@05eM
G@1EEED0E5AD05mOG`1PH600DE5A065QH@1NGUh0MWIf06i^KP1UIFD0IfMW04i>CP19BDT0E5AD06IV
IP1FEUH00P1CDe<06P14A4@0DE5A06][J`1ZJVX0D51@04A4A00k>c/0@4100451@@19BDT0G5aL04=3
@`1:BTX0BDU903dm?@0k>c/0>3Ph03`l?01NGUh0>CTi05YJFP1:BTX0<S8b02d];@0m?Cd0oooo1P3I
fMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI01<0oooo079bLP1KFe/0Lg=c07Qh
N01MGEd0MGEe07emO@1hN7P0CTi>06e]K@1nOWh0MWIf08R8R01RHV80EUIF07QhN01`L700RHV90080
MWIf00L0MgMg071`L01`L700Q8B40861P@20P800SXj>0080RHV906X0Ogmo09ZJVP2EUID0TY:B07Ui
N@27QhL0VIVI09ZJVP25QHD0Ph>308R8R02MWId0Xj>S07moO`2>SXh0Lg=c05iNGP20P800PX:207=c
L`1aLG40Kfm_0820P01mOGd0TY:B08^;R`1nOWh0IfMW0::RXP1iNGT0K6a/07AdM01bLW80KFe]08B4
Q02ATI40OWin0820P01XJ6P0S8b<071`L01hN7P0T92@09BDU025QHD0RXZ:07MgM`22PX80QHF508Z:
RP2OWil0N7Qh07emO@24Q8@0L71`09ZJVP1bLW80TY:B07EeM@1jNWX0MWIf05iNGP1YJFT0R8R809bL
W02=SHd0Ogmo08:2PP2>SXh0MGEe08Z:RP1/K6`0L71`09FEU@25QHD0TY:B08b<S01kNg/0S8b<07Ad
M01jNWX0V9RH08B4Q02FUYH0Shn?08B4Q02;Rh/0RXZ:07AdM01kNg/0QHF508:2PP2MWId0UiNG096A
T@2<S8`0UYJF08V9R@2:RXX0Ogmo08B4Q022PX80SHf=07]kN`24Q8@0UiNG0P2>SXh0>02=SHd0XJ6Q
06MWI`2<S8`0PH6108b<S026QXH0J6QX08V9R@2BTY80Ti>C0861P@1kNg/0JVYZ08j>SP1nOWh0Ng]k
07inOP1fMWH0NGUi08V9R@2CTi<0K6a/08>3P`2;Rh/0NWYj07MgM`2=SHd0RHV907=cL`1`L700QXJ6
07alO026QXH0S8b<0;Zj^P1kNg/0QXJ607IfMP2;Rh/0MGEe08>3P`1jNWX0RXZ:07inOP1aLG40NWYj
07QhN01kNg/0IFEU08B4Q023Ph<0MgMg07QhN01cLg<0H61P0P1/K6`0401QHF40MGEe06EUI@1EEED0
F5QH05aLG01XJ6P0MGEe08:2PP1eMGD0N7Qh071`L01mOGd0LG5a04Q8B01/K6`206QXJ00]06EUI@1[
Jf/0GemO08:2PP18B4P0PX:2061PH01fMWH0GemO075aL@1mOGd0L71`08>3P`2;Rh/0K6a/06i^KP1e
MGD0IfMW07=cL`1VIVH0GemO07QhN01mOGd0MWIf06UYJ@1ZJVX0Ph>306EUI@1dM7@0Kfm_06a/K01V
IVH0H61P06i^KP1aLG40EeMG05QHF01VIVH0JVYZ05]KF`1kNg/0K6a/05UIF@1]KFd0Hf=S0080IfMW
03D0AdM706][J`1QHF40LG5a051@D01HF5P0LW9b04e=C@1:BTX0EEEE05IFEP1EEED0J6QX04U9B@1@
D500EeMG061PH01JFUX0Bd];05YJFP1KFe/0C4a<069RHP1UIFD0<S8b03dm?@1:BTX0EEEE04Y:BP0n
?Sh0?clo05EEE@1:BTX0?clo04M7A`1IFET0?clo03`l?00f=SH0=cLg0451@@1:BTX0FEUI03/k>`0[
:b/0=SHf03Ph>00l?3`0=cLg02/[:`15ADD0ATI60?ooo`060=WIf@4000000@3IfMT001H0fMWI00<0
00000=WIf@3IfMT00`3IfMT08P3oool0MgMg08:2PP25QHD0L71`07moO`1hN7P0O7al06QXJ02<S8`0
PX:207emO@1/K6`0LG5a07YjNP1eMGD0Lg=c07alO02>SXh0Ng]k09ZJVP21PH40MgMg07inOP2JVYX0
MGEe092@T02:RXX0QHF508^;R`2?Shl0SHf=07inOP21PH4209BDU00/06MWI`1mOGd0Rh^;08f=S@26
QXH0TI6A08J6QP23Ph<0L71`06QXJ01`L700FEUI06IVIP1ZJVX0H61P06e]K@1cLg<0SXj>08f=S@1l
O7`0R8R809ZJVP2?Shl0M7Ad07]kN`1nOWh0VIVI08R8R022PX80N7Qh06][J`1lO7`0NGUi08^;R`2E
UID0M7Ad07EeM@2@T900Rh^;08F5Q@2UYJD0VYZJ07emO@1dM7@207]kN`80Rh^;00L0TY:B07inOP23
Ph<0OGem08Z:RP25QHD0Rh^;0080QHF501@0SHf=08b<S02KVi/0NWYj06QXJ02HV9P0OGem08R8R01S
Hf<0RXZ:09bLW025QHD0PX:207MgM`1YJFT0RXZ:09NGU`2@T900TY:B06e]K@80U9BD04h0NGUi08^;
R`2@T900RHV9092@T01iNGT0PX:207moO`2OWil0Ti>C09nOW`1oOgl0TI6A08F5Q@2GUiL0Shn?08R8
R026QXH0SHf=07emO@2EUID0RHV908B4Q01lO7`0PH6107moO`1iNGT0Jf][07YjNP1XJ6P0PX:20820
P01^KVh0SXj>06m_K`1`L700P82007]kN`1lO7`0V9RH08Z:RP24Q8@0QhN708b<S024Q8@0RXZ:07Yj
NP2EUID0R8R808N7Q`29RHT0Ph>308^;R`26QXH0O7al08J6QP1nOWh0NGUi07]kN`2=SHd0P82008J6
QP2EUID0Q8B408F5Q@2:RXX0N7Qh08:2PP1gMgL0PX:20861P@1oOgl0NWYj065QH@1/K6`0CTi>05mO
G`1QHF4205]KF`0@05EEE@1NGUh0IFEU05QHF01RHV80GEeM07MgM`22PX80IFEU05]KF`1dM7@0JVYZ
07EeM@18B4P0Ng]k06QXJ080KFe]00T0JFUY07YjNP1QHF40FEUI0820P01mOGd0H61P071`L01XJ6P0
0P1QHF403`1^KVh0Lg=c071`L01VIVH0NWYj08B4Q02?Shl0EUIF079bLP1iNGT0NWYj0820P01mOGd0
NGUi06IVIP0205mOG`19051@D01`L700D51@071`L01CDe<0IVIV05UIF@1hN7P0Kfm_05aLG01CDe<0
HF5Q04Y:BP11@D40L71`06IVIP1`L700IFEU04E5A@1:BTX0E5AD06QXJ01SHf<0JFUY0861P@1LG5`0
H61P05]KF`1FEUH0IVIV06a/K012@T80EUIF04U9B@1VIVH0M7Ad05YJFP1WIfL0IFEU05iNGP1VIVH0
?Shn06i^KP1IFET0Fe]K055AD@1CDe<0E5AD05IFEP1ADE40=3@d03Xj>P18B4P0@D5104];B`0i>CT0
H61P04A4A01@D500BTY:03Xj>P1?Cdl0@T9203`l?01>CTh0D51@03De=@0`<300Cdm?038b<P15ADD0
>SXj0?ooo`060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0203oool0N7Qh
08>3P`1fMWH0IVIV08V9R@1_Kfl0KFe]0P1kNg/0B020P800Ogmo08V9R@26QXH0MWIf07emO@1gMgL0
LG5a06e]K@1jNWX0H61P07IfMP25QHD0OGem0820P01`L700QhN708>3P`26QXH0J6QX06m_K`23Ph<0
UiNG07]kN`21PH40N7Qh08N7Q`1dM7@0Q8B409jNWP2IVIT0T92@08n?S`28R8P0IfMW06IVIP1bLW80
>CTi079bLP1QHF40IFEU05QHF01hN7P0R8R808>3P`1kNg/0IVIV07inOP29RHT0LG5a0861P@1YJFT0
P82007inOP1fMWH0NWYj08R8R021PH40R8R808j>SP2DU9@0P8200:RXZ02FUYH0TY:B08R8R020P800
QHF508j>SP1mOGd0Ti>C08F5Q@80OGem00@0[Zj^08j>SP2ATI40T92@0P1aLG409@28R8P0JVYZ07mo
O`28R8P0QHF508:2PP1kNg/0Lg=c09RHV01TI6@0MGEe08N7Q`1jNWX0Kfm_0:JVYP2@T900UiNG07Yj
NP1WIfL0OWin08Z:RP1`L700U9BD07IfMP23Ph<0QHF509RHV01iNGT0PX:208>3P`1_Kfl0Shn?096A
T@2IVIT0UYJF08j>SP1lO7`00P2;Rh/07P1aLG40OWin09>CT`2ATI40Ti>C08f=S@2GUiL0IVIV07Mg
M`2=SHd0PX:207moO`21PH40RHV90820P028R8P0OWin07UiN@1cLg<0MGEe08N7Q`1nOWh0QXJ607mo
O`2>SXh0OWin09^KV`1oOgl0UIFE07alO080M7Ad0100T92@09NGU`1mOGd0MWIf08V9R@1oOgl0MgMg
071`L02<S8`0T92@07emO@2KVi/0NWYj06m_K`1gMgL0K6a/0P2ATI40>@2OWil0Kfm_07UiN@24Q8@0
S8b<08V9R@1WIfL0RXZ:08R8R01`L700IfMW06YZJP1eMGD0KVi^07inOP1oOgl0J6QX06a/K01gMgL0
FUYJ06e]K@1SHf<0LG5a04Y:BP1fMWH0LG5a06i^KP1mOGd0LG5a06ATI02DU9@0Ph>307UiN@1JFUX0
JFUY06=SH`1[Jf/0KFe]08F5Q@27QhL0RXZ:07MgM`1WIfL0LG5a06YZJP1bLW80H61P07EeM@1lO7`0
MGEe07UiN@1bLW80J6QX09BDU01`L700OGem07inOP0207YjNP0G092@T01jNWX0NWYj07emO@2ATI40
Q8B4065QH@1bLW80J6QX06YZJP1[Jf/0LG5a06QXJ01OGel0FUYJ06EUI@19BDT0L71`06MWI`1KFe/0
GUiN06e]K@1TI6@00P1OGel0<`1CDe<0DE5A055AD@1:BTX0C4a<05EEE@1NGUh0Fe]K04e=C@1JFUX0
GemO04];B`1IFET0EUIF069RHP1;Bd/0DE5A04m?C`1TI6@0De=C03<c<`1ADE40JVYZ05YJFP1GEeL0
C4a<04M7A`1SHf<0>c/k04M7A`1>CTh0IFEU055AD@0m?Cd0CDe=04I6AP0o?cl0B4Q804m?C`0m?Cd0
:RXZ02TY:@1GEeL0ATI603`l?00a<C40B4Q803Ti>@12@T80>CTi0?ooo`060=WIf@4000000@3IfMT0
01H0fMWI00<000000=WIf@3IfMT00`3IfMT0103oool0Jf][07UiN@1bLW8206e]K@0O07moO`1VIVH0
KVi^071`L01]KFd0JVYZ06][J`1OGel0MGEe07inOP28R8P0PX:206a/K01jNWX0R8R807MgM`2@T900
Q8B407]kN`27QhL0Shn?09:BTP29RHT0XZ:R09FEU@23Ph<0M7Ad08f=S@2DU9@0LW9b0861P@02092@
T01<08J6QP23Ph<0K6a/06][J`1MGEd0De=C05aLG01RHV80G5aL06MWI`1/K6`0IFEU071`L01eMGD0
RXZ:079bLP1aLG40OWin07]kN`1bLW80Q8B408R8R01UIFD0Q8B408^;R`2FUYH0IFEU08F5Q@23Ph<0
MWIf08^;R`29RHT0NWYj08n?S`23Ph<0Ng]k09fMW@2<S8`0XJ6Q09FEU@20P800LW9b07inOP2CTi<0
UYJF08^;R`2<S8`0PX:208^;R`28R8P0O7al06UYJ@1_Kfl0NGUi07]kN`1gMgL0QhN707AdM01ZJVX0
Q8B407UiN@2<S8`0P82006a/K02>SXh0O7al08N7Q`20P800Hf=S08>3P`22PX80NWYj08f=S@2IVIT0
Vi^K0:2PX080OWin02`0W9bL06][J`1]KFd0R8R809FEU@2HV9P0R8R807]kN`2ATI40Vi^K09JFUP2:
RXX0SHf=096AT@2FUYH0TI6A08j>SP2GUiL0Rh^;09BDU020P800MGEe08J6QP1jNWX0KFe]09NGU`1f
MWH0SHf=06UYJ@21PH40OWin08V9R@1dM7@0OWin09:BTP1iNGT0O7al07=cL`2NWYh0RXZ:09JFUP2;
Rh/0RXZ:06e]K@80PX:200d0Ti>C08j>SP1cLg<0S8b<07alO01iNGT0MGEe08N7Q`24Q8@0LW9b08j>
SP1SHf<0Ogmo0080PH6100T0Shn?07MgM`23Ph<0PH6106QXJ01/K6`0L71`07emO@21PH400P27QhL0
1@1bLW80P820075aL@1TI6@0IVIV0080NWYj03L0GEeM06a/K01]KFd0KFe]06IVIP1`L700KVi^06][
J`1/K6`0NGUi07AdM022PX80R8R808n?S`1^KVh0N7Qh06a/K024Q8@0H61P05mOG`1oOgl0MWIf08>3
P`1ZJVX0J6QX07AdM023Ph<0P82007QhN01gMgL0PX:2069RHP1oOgl0NGUi08R8R020P800MWIf07Ui
N@1jNWX0JVYZ07AdM01NGUh0KVi^07YjNP24Q8@0MGEe061PH01XJ6P0O7al07UiN@1oOgl0H61P05UI
F@1YJFT0JVYZ0080EUIF01@0PX:205]KF`1PH600Kfm_06UYJ@11@D40DU9B05UIF@1JFUX0EEEE061P
H01WIfL0HV9R06=SH`1RHV80JFUY05EEE@1HF5P0GUiN06=SH`80FEUI01@0>SXj04i>CP1FEUH0EeMG
04Q8B01KFe/0EeMG03/k>`18B4P0Kfm_051@D011@D40Fe]K05aLG01>CTh0ADE505QHF017AdL0Cdm?
02`/;080@d=30140C4a<03Hf=P10@400Cdm?05UIF@1QHF40E5AD0492@P0C4a<0@41003De=@13@d<0
Cdm?04a<C017AdL0;bl_0?ooo`060=WIf@4000000@3IfMT001H0fMWI0P0000040=WIf@0<0?ooo`1^
KVh0EUIF05QHF01jNWX0JVYZ07inOP1hN7P0MgMg06MWI`1eMGD0R8R80P1fMWH0<@1cLg<0QhN709FE
U@28R8P0MgMg07AdM02:RXX0R8R808J6QP2<S8`0Q8B405eMG@1jNWX0V9RH07alO01eMGD0IfMW08B4
Q01oOgl0NWYj09:BTP2CTi<0P82008R8R01lO7`0YZJV06YZJP1aLG40Jf][06ATI01NGUh0IFEU06IV
IP1JFUX0O7al07MgM`1`L700?clo0820P01TI6@0MGEe08R8R02KVi/0Ogmo08^;R`21PH40SHf=07em
O@1bLW800P2;Rh/07`2<S8`0Ph>30:2PX02?Shl0VYZJ07IfMP2EUID0SHf=08N7Q`2VYZH0Ogmo09jN
WP20P800OWin07QhN02JVYX0WIfM09:BTP1jNWX0P82007QhN01oOgl0MWIf08J6QP1fMWH0L71`06m_
K`1nOWh0Ogmo08^;R`1jNWX00P2>SXh02`2<S8`0PH6108R8R02BTY80Q8B406a/K02;Rh/0PX:207Yj
NP24Q8@0OWin0080O7al0380PH6107UiN@1oOgl0MgMg07IfMP28R8P0YjNW0820P01TI6@0Shn?07Ui
N@2MWId0MWIf08:2PP1iNGT0R8R808>3P`1WIfL0QXJ608^;R`27QhL0LG5a09ZJVP2>SXh0SHf=09^K
V`2=SHd0KVi^08N7Q`28R8P0QXJ609RHV022PX80Kfm_07alO02BTY80JVYZ08F5Q@2DU9@0NGUi08J6
QP2JVYX0W9bL08N7Q`1oOgl0RXZ:06m_K`1oOgl0TI6A0:f][@80RHV90400TY:B08^;R`23Ph<0TY:B
08:2PP1mOGd0MgMg07=cL`2EUID0Hf=S08j>SP2@T900VIVI09BDU01`L700Ng]k08N7Q`1eMGD0J6QX
08^;R`1kNg/0PH6107emO@1/K6`0PH6107IfMP25QHD0LW9b08Z:RP1gMgL0Hf=S06a/K01jNWX0=cLg
06UYJ@1_Kfl0PX:207alO020P800Kfm_06i^KP1VIVH0P82007YjNP1gMgL0G5aL07emO@1fMWH0KVi^
08N7Q`1cLg<0Hf=S06YZJP1UIFD0MWIf06IVIP1mOGd0LW9b07=cL`1TI6@0Q8B4065QH@1lO7`0Ng]k
0P1eMGD0<@1WIfL0MWIf07YjNP2>SXh0R8R806m_K`1gMgL0Ogmo0820P01`L700Lg=c06QXJ01aLG40
Jf][07AdM01QHF40NGUi05QHF01aLG40LW9b06QXJ01fMWH0LG5a07emO@1HF5P0IfMW079bLP1ADE40
H61P065QH@1MGEd0IFEU04A4A01OGel0Jf][04i>CP1dM7@0GemO06m_K`1<C4`0GUiN065QH@1SHf<0
IfMW069RHP1<C4`0DU9B05aLG01PH6000P1BDU80101DE5@0Fe]K069RHP1IFET204e=C@0L06YZJP1;
Bd/0<c<c04Y:BP19BDT0A4A4051@D018B4P0DU9B04];B`0P8200D51@04E5A@16ATH0D51@04i>CP1H
F5P0FUYJ05aLG010@400>c/k04];B`19BDT0>c/k0492@P1?Cdl0?Shn0?ooo`D0fMWI0P0000010=WI
f@005P3IfMT00`000000fMWI0=WIf@030=WIf@0K0?ooo`1[Jf/0NWYj06i^KP1/K6`0O7al07MgM`2>
SXh0Ng]k06a/K01gMgL0Hf=S07YjNP1ZJVX0Lg=c07UiN@1mOGd0KVi^0820P027QhL0P82008f=S@1X
J6P0R8R808j>SP21PH40P8200080RHV90140MgMg07AdM02HV9P0M7Ad08V9R@1jNWX0Shn?08F5Q@2?
Shl0QhN708B4Q01nOWh0L71`06EUI@1_Kfl0Fe]K07EeM@020820P00P07AdM01oOgl0Fe]K071`L01f
MWH0Ogmo07YjNP1_Kfl0IFEU07UiN@20P800QXJ607UiN@1gMgL0QhN7075aL@1iNGT0O7al08F5Q@1i
NGT0N7Qh08Z:RP2<S8`0T92@08n?S`2:RXX0Ogmo08>3P`1mOGd0SXj>0:2PX025QHD208>3P`0D08F5
Q@1kNg/0Kfm_06UYJ@1oOgl0MgMg08Z:RP1KFe/0P82006a/K01[Jf/0U9BD08^;R`1`L700V9RH06QX
J01jNWX0R8R80000002?Shl20820P00<07inOP1kNg/0LW9b07IfMP2IVIT0Ti>C07MgM`1lO7`0GEeM
07AdM02RXZ80N7Qh0P29RHT06@23Ph<0R8R809VIV@21PH40MGEe08J6QP29RHT0PH6107]kN`20P800
Hf=S08B4Q02GUiL0Ogmo08b<S01eMGD0PH6108j>SP1lO7`0Shn?09^KV`1lO7`0Ti>C08Z:RP1nOWh0
0P2;Rh/09@20P800Ti>C09VIV@2BTY80WYjN08N7Q`2TY:@0QhN708B4Q027QhL0WIfM096AT@25QHD0
NWYj09nOW`1kNg/0T92@08b<S01jNWX0RHV909:BTP23Ph<0OWin092@T02ATI40OWin06m_K`21PH40
Q8B408N7Q`1gMgL0Rh^;08j>SP29RHT0MgMg06ATI027QhL00P1_Kfl08P1NGUh0MWIf07YjNP1bLW80
NGUi08B4Q01oOgl0RHV909BDU021PH40QhN707moO`20P800JVYZ06][J`26QXH0I6AT06QXJ026QXH0
IfMW061PH01YJFT0NWYj06m_K`1gMgL0D51@096AT@20P800IVIV08N7Q`1eMGD0OWin079bLP1fMWH2
06e]K@0l07YjNP1kNg/0O7al06e]K@1bLW80NGUi06a/K01`L700Kfm_08f=S@2GUiL0M7Ad08F5Q@22
PX80J6QX0861P@1iNGT0NWYj09:BTP1gMgL0GUiN09BDU02EUID0L71`075aL@1_Kfl0M7Ad06e]K@22
PX80OWin05mOG`1dM7@0P82006][J`1/K6`0FEUI05QHF01jNWX0Kfm_0820P01gMgL0GUiN06ATI01[
Jf/0A4A405QHF01hN7P0CTi>069RHP1ZJVX0Cdm?06MWI`1VIVH0EUIF05QHF00Y:BT0000006QXJ01/
K6`0G5aL0P1JFUX04@1TI6@0IfMW05]KF`1FEUH0C4a<05IFEP13@d<0BDU905]KF`19BDT0De=C04m?
C`1:BTX0F5QH055AD@1:BTX0EeMG0080H61P00H0BTY:04E5A@1LG5`0ADE503@d=01:BTX203De=@05
04I6AP15ADD0E5AD051@D03oool01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0
fMWI01T0oooo06EUI@1UIFD0NWYj08F5Q@1]KFd0IfMW07]kN`1^KVh0F5QH07moO`1RHV80Q8B407em
O@1bLW80VIVI07moO`27QhL0Ti>C07YjNP2@T900KVi^09RHV01fMWH0OWin0080RXZ:01l0]kNg0861
P@1kNg/0LG5a07AdM027QhL0PH61092@T02RXZ80Lg=c08j>SP2<S8`0TI6A07moO`1kNg/0P82005aL
G01PH600Ng]k075aL@24Q8@0OGem07YjNP1_Kfl0E5AD06EUI@1aLG40EeMG07MgM`1/K6`0T92@0080
MgMg04D0PH6108B4Q022PX80Ng]k08B4Q029RHT0Lg=c08n?S`22PX80QXJ607moO`2?Shl0R8R8092@
T02EUID0V9RH08>3P`2GUiL0LG5a09:BTP2KVi/0Rh^;09FEU@1jNWX0M7Ad07IfMP1_Kfl0OGem06e]
K@2FUYH0WIfM06e]K@22PX80K6a/07moO`1iNGT0MGEe06=SH`21PH40MGEe092@T01gMgL0OGem06e]
K@2>SXh0IfMW07]kN`1cLg<0KVi^07moO`21PH40RXZ:07alO02>SXh0PH6106=SH`1VIVH0HF5Q08^;
R`2<S8`0MWIf07AdM01gMgL0SXj>08Z:RP27QhL0MWIf06UYJ@1cLg<00P1nOWh208^;R`1808b<S021
PH40R8R808B4Q02?Shl0RHV908b<S02?Shl0UiNG08R8R02@T900Vi^K08^;R`2=SHd0S8b<08B4Q020
P800VYZJ07inOP2;Rh/0N7Qh08J6QP29RHT0UiNG09^KV`2MWId0U9BD09>CT`2FUYH0PH6108f=S@2G
UiL0PX:209>CT`28R8P0T92@075aL@2GUiL0T92@08N7Q`1dM7@0Ph>306][J`22PX80T92@06m_K`25
QHD0Q8B407moO`1dM7@0GEeM06][J`1/K6`0V9RH09bLW02ATI40LG5a06QXJ01/K6`0Ogmo08Z:RP24
Q8@0O7al05aLG01iNGT0N7Qh08>3P`1kNg/0MWIf06m_K`16ATH0Hf=S0P1kNg/01025QHD0PX:206a/
K01iNGT206m_K`0o061PH01mOGd0J6QX06IVIP21PH40KVi^079bLP1[Jf/0LG5a079bLP1gMgL0De=C
06ATI01`L700O7al06a/K02@T900O7al07inOP1^KVh0O7al07AdM01gMgL0PX:20861P@1SHf<0NWYj
06UYJ@1cLg<0GEeM08^;R`1bLW80QhN707=cL`1=CDd0L71`06i^KP21PH40GEeM06EUI@1RHV80FEUI
06=SH`1bLW80JFUY04];B`1IFET0EeMG06ATI01SHf<0BTY:04E5A@1BDU80H61P04i>CP11@D40K6a/
079bLP1UIFD0IVIV06YZJP1ADE40FEUI0080G5aL02@0J6QX06EUI@1_Kfl0FUYJ079bLP1>CTh0FUYJ
065QH@1[Jf/0FEUI04e=C@16ATH0Bd];0492@P14A4@0LG5a04Q8B013@d<0BTY:0410@01@D500F5QH
05IFEP1QHF40Fe]K04a<C00g=cL0DE5A065QH@0k>c/0=cLg05UIF@0/;2`0<c<c04M7A`3oool60=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0?P3oool0Ph>3079bLP1OGel0N7Qh
075aL@1lO7`0P82008B4Q01lO7`0Ph>308F5Q@1gMgL0KVi^06e]K@26QXH0RXZ:071`L02:RXX0QXJ6
096AT@27QhL0R8R808:2PP23Ph<0O7al08f=S@2:RXX0M7Ad07alO01oOgl0O7al0861P@2=SHd0Ogmo
08b<S01jNWX0U9BD0820P01hN7P0K6a/08J6QP1NGUh0LW9b08b<S023Ph<0P82009>CT`1hN7P0RHV9
07inOP29RHT0EEEE06e]K@1mOGd0OWin092@T028R8P0O7al06MWI`2:RXX0P8200P1kNg/02`1gMgL0
SHf=09^KV`21PH40QHF507moO`20P800TI6A07emO@2FUYH0V9RH0080LG5a01<0TY:B09VIV@1XJ6P0
Kfm_08R8R01gMgL0OGem08Z:RP1]KFd0Kfm_07EeM@1LG5`0EeMG07moO`1jNWX0OGem08J6QP28R8P0
O7al0080NGUi00P0QXJ608N7Q`2ATI40Rh^;06e]K@1PH600MGEe07QhN080OWin0480OGem06IVIP2U
YJD0O7al08R8R01oOgl0KVi^08Z:RP27QhL0RHV908Z:RP2HV9P0UYJF07moO`2=SHd0NWYj06IVIP1`
L700QXJ607EeM@21PH40SHf=09BDU027QhL0QHF507alO02BTY80VIVI075aL@29RHT0OWin07AdM01V
IVH0MWIf07AdM02=SHd0UIFE07IfMP2=SHd0QhN70861P@2[Zj/0W9bL08F5Q@20P800S8b<0:n_[`2A
TI40VIVI08F5Q@1gMgL0Shn?08J6QP27QhL0Q8B408Z:RP1^KVh0VYZJ09RHV024Q8@0QXJ608Z:RP23
Ph<0L71`07MgM`2>SXh207moO`0407YjNP1hN7P0Shn?0820P080PX:205D0IVIV07QhN01eMGD0IFEU
07inOP1UIFD0RHV906i^KP1fMWH0Kfm_07moO`29RHT0Rh^;07EeM@1jNWX0G5aL06MWI`1fMWH0LG5a
07moO`2:RXX0GemO07AdM01PH600QHF507=cL`1[Jf/0OWin08:2PP1]KFd0O7al075aL@1TI6@0LW9b
07=cL`28R8P0Ng]k06YZJP1bLW80K6a/071`L01KFe/0NGUi05iNGP1mOGd0JFUY07UiN@1nOWh0WinO
06m_K`23Ph<0NGUi07QhN01jNWX0R8R80820P023Ph<0Ogmo04Y:BP1^KVh0RXZ:07MgM`1LG5`0NGUi
07YjNP1DE5@0QhN70820P01kNg/0K6a/06m_K`1gMgL0O7al07IfMP1jNWX0Lg=c04U9B@1MGEd0De=C
04i>CP1VIVH0DU9B04m?C`1PH600KFe]0080C4a<0100HV9R06ATI01kNg/0H61P05EEE@1MGEd0I6AT
06EUI@1NGUh0HV9R05UIF@1XJ6P0H61P05mOG`1JFUX0CDe=0P1EEED0501DE5@0?3`l04E5A@0j>SX0
D51@03`l?01EEED0HF5Q04U9B@18B4P0F5QH03Ti>@1IFET0EeMG05ADE01ADE40Hf=S03Ti>@11@D40
9bLW0P0n?Sh01@1ADE40GUiN05=CD`1;Bd/0oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000
fMWI0=WIf@030=WIf@0Y0?ooo`23Ph<0OGem07AdM01cLg<0Rh^;07alO01WIfL0RXZ:07moO`21PH40
MWIf06ATI01cLg<0QhN706YZJP20P800Ng]k08B4Q01^KVh0Q8B409NGU`1dM7@0OWin07QhN02@T900
PH6107emO@2:RXX0LW9b08Z:RP1hN7P0OGem092@T02ATI40RHV907EeM@1kNg/0RHV908:2PP1HF5P0
0P1WIfL08P26QXH0Ogmo09jNWP1oOgl0MgMg08V9R@1oOgl0O7al08>3P`18B4P0HV9R065QH@1kNg/0
M7Ad07IfMP1PH600L71`06YZJP2:RXX0R8R808V9R@22PX80P82007UiN@20P800N7Qh08J6QP1QHF40
P82008J6QP1oOgl0OWin08F5Q@2TY:@208F5Q@0=03lo?`2;Rh/0NGUi075aL@1XJ6P0IVIV071`L01c
Lg<0OGem0820P024Q8@0I6AT08J6QP020820P00S0861P@1lO7`0IFEU08B4Q01_Kfl0Rh^;07inOP1c
Lg<0Jf][07EeM@1gMgL0Ph>308B4Q01iNGT0UiNG079bLP2MWId0R8R809FEU@1lO7`0QHF507IfMP1o
Ogl0QXJ609RHV01fMWH0UYJF08n?S`2=SHd0MgMg07alO01mOGd0P82008J6QP1mOGd00P2FUYH00`26
QXH0V9RH08n?S`0208b<S01J09:BTP21PH40M7Ad07inOP2?Shl0OGem09VIV@21PH40RHV908Z:RP1`
L700KFe]09:BTP2NWYh0SXj>07emO@2DU9@0IFEU07YjNP2EUID0U9BD09>CT`1oOgl0Ti>C09RHV022
PX80Ogmo0:b/[02?Shl0Vi^K09FEU@22PX80YjNW08b<S026QXH0Ogmo08J6QP1fMWH0RHV908b<S02F
UYH0RHV908Z:RP1nOWh0Q8B409>CT`1eMGD0Lg=c07]kN`1cLg<0Hf=S071`L02MWId0Q8B407EeM@1g
MgL0O7al065QH@1JFUX0MWIf07EeM@1`L700MgMg08b<S026QXH0QHF50861P@2DU9@0Ng]k07UiN@2:
RXX0M7Ad061PH01CDe<0J6QX0820P01kNg/0MgMg07EeM@1GEeL0IVIV06m_K`1SHf<0HV9R06IVIP1Z
JVX0L71`06UYJ@1MGEd0MGEe0P1_Kfl0>`1dM7@0MgMg08J6QP23Ph<0PH6108^;R`25QHD0Shn?06a/
K01MGEd0N7Qh08B4Q01^KVh0QHF5075aL@20P800S8b<07QhN01GEeL0QhN7061PH01lO7`0Ng]k05iN
GP1IFET0Jf][06i^KP1hN7P0Ph>306a/K012@T80Hf=S06m_K`1@D500J6QX05aLG021PH40De=C06YZ
JP1;Bd/0EEEE0410@01UIFD0Bd];061PH01eMGD0FEUI05]KF`1^KVh0GUiN06a/K01@D500HV9R0492
@P14A4@0I6AT059BDP0b<S80Hf=S0080Cdm?01T0BTY:04];B`19BDT0@41005MGE`1MGEd0EEEE03Lg
=`15ADD0G5aL05]KF`1NGUh0B4Q805IFEP0n?Sh0C4a<05QHF01OGel0AdM704i>CP1JFUX0@T9206MW
I`0g=cL0oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@1@0?ooo`1c
Lg<0Ng]k07]kN`20P800HV9R06m_K`1iNGT0QHF5065QH@23Ph<0Ogmo09>CT`1bLW80N7Qh09BDU02:
RXX0OWin08J6QP21PH40U9BD08b<S01nOWh0JFUY096AT@1YJFT0QhN708Z:RP22PX80T92@09FEU@2<
S8`0TY:B07QhN02:RXX0LW9b09:BTP2>SXh0RXZ:07moO`1fMWH0IfMW06IVIP1IFET0OWin09NGU`2V
YZH0KVi^092@T02OWil0GUiN05YJFP1WIfL0HV9R06ATI01eMGD0Ng]k07YjNP23Ph<0P82008J6QP28
R8P0OGem08N7Q`1MGEd0TI6A0861P@2:RXX0N7Qh0861P@1nOWh0RHV909FEU@1iNGT0Q8B409fMW@1W
IfL0OWin08^;R`20P80208J6QP0Y07EeM@2<S8`0QHF50820P01nOWh0RXZ:08>3P`1eMGD0RHV906i^
KP1/K6`0R8R807EeM@1gMgL0QhN707MgM`1lO7`0FEUI08:2PP20P800MgMg07YjNP29RHT0PH6108b<
S029RHT0MGEe07alO01`L700PX:207inOP24Q8@0QHF508n?S`2ATI40QhN707]kN`1eMGD0QhN707Qh
N01nOWh00P2<S8`06@2PX:00Ogmo06e]K@2?Shl0TY:B09>CT`1SHf<0P82009jNWP2<S8`0R8R808F5
Q@1nOWh0UiNG08N7Q`2QXJ40TI6A07=cL`27QhL0PH6109JFUP2RXZ80TI6A08B4Q028R8P00P24Q8@0
7@2=SHd0UYJF06=SH`1kNg/0NWYj07QhN029RHT0U9BD08^;R`1oOgl0MgMg09BDU02UYJD0VIVI08B4
Q02:RXX0T92@08b<S01hN7P0IVIV0861P@29RHT0OWin07QhN01dM7@0N7Qh08f=S@1gMgL0SXj>0080
K6a/03<0MWIf07MgM`1lO7`0QHF508:2PP1cLg<0GEeM07AdM01ZJVX0OGem05]KF`1HF5P0MWIf08:2
PP1cLg<0Q8B4071`L023Ph<0OGem07]kN`1hN7P0Ng]k07UiN@1eMGD0MWIf06a/K01kNg/0NGUi07in
OP1XJ6P0L71`05mOG`1VIVH0Fe]K055AD@27QhL0F5QH06a/K01[Jf/0O7al05aLG01nOWh0GUiN06QX
J01cLg<0J6QX079bLP1hN7P0OWin07QhN025QHD00P1mOGd0?@28R8P0QXJ607EeM@1/K6`0MWIf071`
L02>SXh0GEeM05UIF@1nOWh0PX:206IVIP1/K6`0IVIV08b<S01jNWX0Fe]K05eMG@1lO7`0N7Qh06a/
K01cLg<0HF5Q07EeM@1CDe<0Jf][055AD@1CDe<0IVIV06UYJ@1OGel0H61P055AD@1TI6@0KFe]06MW
I`1_Kfl0FUYJ06YZJP1OGel0F5QH06QXJ01DE5@0EEEE04Y:BP10@400AdM705QHF01>CTh0@41005]K
F`1IFET0@d=304m?C`0n?Sh0;bl_03<c<`16ATH0Fe]K04E5A@17AdL00P16ATH03`1ADE40CDe=05MG
E`1;Bd/0ADE504Y:BP1<C4`0>CTi03hn?P18B4P0D51@05EEE@0e=CD0?clo0?ooo`060=WIf@400000
0@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT03`3oool0U9BD08R8R020P800Lg=c061PH01Y
JFT0MgMg06e]K@20P800U9BD08F5Q@2MWId0Q8B407]kN`0207UiN@0B08F5Q@2:RXX0MgMg07UiN@26
QXH0MgMg07]kN`1aLG40QXJ6092@T02?Shl0LW9b0:ZZZP2JVYX0O7al07inOP24Q8@0SHf=0P2>SXh0
<@27QhL0PX:207moO`1iNGT0Kfm_06a/K01bLW80JFUY05]KF`1mOGd0XZ:R09VIV@1kNg/0MgMg069R
HP1]KFd0JFUY04i>CP22PX80Ogmo08b<S01cLg<0Ph>308j>SP1dM7@0QhN707inOP1eMGD0UYJF07If
MP1nOWh0IFEU07emO@22PX80Shn?07moO`2<S8`0N7Qh08N7Q`2?Shl0MGEe08F5Q@2?Shl0PX:208n?
S`1mOGd0Ph>307inOP27QhL00P1`L7004`1hN7P0LG5a07inOP1cLg<0P820079bLP1gMgL0Ogmo071`
L020P800PH6108n?S`1gMgL0P82007inOP26QXH0NGUi07QhN01VIVH00P1eMGD09@28R8P0Q8B4075a
L@2;Rh/0TI6A08n?S`23Ph<0M7Ad09FEU@2:RXX0Ti>C075aL@2:RXX0U9BD08>3P`29RHT0O7al0861
P@2=SHd0PX:209NGU`1mOGd0TI6A09JFUP2:RXX0Rh^;08f=S@2BTY80OGem08V9R@2IVIT0Ng]k08R8
R01fMWH0SHf=07]kN`21PH400P2KVi/05025QHD0RXZ:09JFUP2OWil0UYJF092@T024Q8@0UiNG08:2
PP2IVIT0SHf=0:JVYP2=SHd0R8R809nOW`1oOgl0YJFU08N7Q`1oOgl0V9RH0P2ATI409@1hN7P0QHF5
0;:b/P2GUiL0RXZ:07AdM01nOWh0I6AT07AdM01oOgl0Ti>C07IfMP1jNWX0SXj>08b<S01kNg/0Q8B4
09:BTP1iNGT0KVi^07IfMP1mOGd0FUYJ06ATI01RHV80IFEU069RHP2CTi<0Ng]k07YjNP1gMgL0XZ:R
07UiN@1oOgl0GemO07EeM@1_Kfl00P0000003P1LG5`0LW9b07UiN@1[Jf/0N7Qh069RHP1YJFT0FEUI
06=SH`1HF5P0H61P065QH@12@T80FEUI0P1ZJVX0F@1`L700Kfm_08^;R`1hN7P0QHF507]kN`1dM7@0
R8R809>CT`1/K6`0SHf=07MgM`23Ph<0Q8B408>3P`26QXH0MgMg075aL@1iNGT0R8R807QhN02<S8`0
Ph>3075aL@20P800KVi^08b<S026QXH0KFe]07=cL`26QXH0TI6A06QXJ01bLW80Hf=S06YZJP1]KFd0
GemO06i^KP1RHV80Cdm?06ATI01YJFT0FUYJ059BDP1YJFT0IFEU05EEE@1mOGd0HV9R06a/K01RHV80
@d=307QhN01FEUH0FEUI051@D01ZJVX0GEeM04M7A`1HF5P0H61P04m?C`1^KVh0C4a<02h^;P1EEED0
EUIF04U9B@1ADE40Fe]K051@D01<C4`0K6a/05aLG01GEeL0Fe]K05EEE@1<C4`0E5AD04];B`0k>c/0
FEUI05MGE`1:BTX0Bd];04I6AP1@D500oooo00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI
0=WIf@030=WIf@0]0?ooo`2:RXX0N7Qh07alO027QhL0JVYZ071`L01JFUX0MgMg06m_K`1jNWX0IVIV
08V9R@1gMgL0U9BD09^KV`2:RXX0NGUi08j>SP1nOWh0V9RH08R8R01mOGd0LW9b07YjNP2=SHd0OGem
08J6QP1nOWh0QhN709NGU`1lO7`0R8R808N7Q`28R8P0PX:207IfMP23Ph<0Ogmo08n?S`21PH40LW9b
06ATI01aLG40PH610080Ph>301d0MGEe0861P@1KFe/0>c/k071`L01DE5@0KVi^075aL@2EUID0LG5a
08J6QP23Ph<0WIfM08F5Q@1^KVh0NGUi07YjNP1_Kfl0O7al05aLG024Q8@0RHV908>3P`2?Shl0O7al
08f=S@2WYjL0OGem06MWI`020861P@0/09ZJVP25QHD0Ogmo08j>SP23Ph<0XJ6Q07QhN02ATI40LG5a
06YZJP28R8P0NWYj075aL@1VIVH0Lg=c07IfMP1[Jf/0NWYj05MGE`1jNWX0IfMW08N7Q`2;Rh/0Jf][
06YZJP1kNg/0QhN707alO01jNWX0NGUi08>3P`20P800U9BD09ZJVP25QHD0Q8B408R8R02BTY80Ti>C
08j>SP28R8P0UiNG08B4Q01eMGD207YjNP0C0861P@1lO7`0RXZ:08F5Q@26QXH0U9BD08>3P`21PH40
SXj>092@T01kNg/0RHV907MgM`2@T900QXJ608^;R`1hN7P0QHF508f=S@0207UiN@0j092@T02IVIT0
Ti>C08j>SP20P800U9BD0861P@1iNGT0QXJ608F5Q@2CTi<0Vi^K079bLP2@T900NGUi04I6AP2GUiL0
RXZ:0820P01lO7`0Shn?09ZJVP2MWId0WinO09NGU`2MWId0YJFU08F5Q@2>SXh0Ng]k09:BTP1kNg/0
NGUi07moO`1SHf<0QhN707alO01dM7@0TY:B0861P@2ATI40NGUi07=cL`1XJ6P0EUIF059BDP1VIVH0
GemO06EUI@1<C4`0L71`06i^KP24Q8@0Jf][07]kN`2>SXh0QHF508:2PP80R8R80100NGUi07EeM@0k
>c/0=SHf06IVIP1IFET0Fe]K06IVIP1NGUh0OWin06ATI01LG5`0BTY:07AdM01CDe<07QhN0P000000
8@1@D500IfMW06EUI@1dM7@0L71`05]KF`21PH40PX:207=cL`21PH40RHV90861P@1nOWh0O7al07=c
L`2<S8`0OWin08F5Q@2?Shl0Ogmo08^;R`20P800Ogmo07AdM01/K6`0N7Qh08V9R@2;Rh/0MGEe06MW
I`1/K6`0LG5a069RHP0207MgM`0h07IfMP1kNg/0Lg=c06MWI`1LG5`0DU9B07QhN01WIfL0GEeM05IF
EP1OGel0OWin071`L01^KVh0G5aL075aL@26QXH0D51@065QH@1aLG40HF5Q05YJFP0k>c/0CDe=04m?
C`11@D40Fe]K05EEE@16ATH0G5aL04];B`13@d<0EUIF04A4A01RHV80AdM705IFEP1=CDd0D51@069R
HP1GEeL0E5AD03dm?@1>CTh0GemO06EUI@18B4P0CDe=05EEE@1MGEd0F5QH04U9B@1?Cdl0=3@d03Lg
=`3oool60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT08@3oool0NWYj079b
LP1dM7@0RHV907emO@1iNGT0OWin05iNGP1eMGD0U9BD08R8R01oOgl0MgMg07YjNP21PH40QXJ608f=
S@1lO7`0Ph>308N7Q`25QHD0Q8B408F5Q@2;Rh/0P82007=cL`23Ph<0VYZJ07inOP1hN7P0RHV908>3
P`0208J6QP0@096AT@27QhL0S8b<09RHV01TI6@0T92@075aL@1^KVh0HV9R07EeM@1jNWX0Fe]K06e]
K@1CDe<0JVYZ05MGE`80H61P00H0PH6107AdM02;Rh/0Rh^;07moO`2BTY8208J6QP0@07MgM`2ZZZX0
RHV909FEU@28R8P0MgMg08R8R02?Shl0VYZJ08N7Q`2=SHd0PH6106e]K@1`L700QHF5096AT@80OGem
00@0JVYZ07alO02@T900TI6A0P1kNg/0C023Ph<0LG5a08F5Q@1]KFd0GemO071`L01aLG40KVi^07Ee
M@1lO7`0Lg=c07MgM`1JFUX0LW9b07UiN@1XJ6P0RHV907=cL`1eMGD0M7Ad06m_K`2?Shl0RXZ:07em
O@1aLG40P82007emO@2ATI40S8b<08n?S`2EUID0UiNG08:2PP1iNGT0OWin07IfMP29RHT0Shn?08f=
S@1oOgl0OWin08>3P`1hN7P0PX:209nOW`22PX80RXZ:0861P@1mOGd0T92@07=cL`2=SHd0UIFE08^;
R`1cLg<0RHV90861P@22PX80UIFE07moO`2ATI40SHf=08b<S02FUYH0RXZ:08j>SP2@T900Lg=c08N7
Q`2CTi<0S8b<09^KV`2NWYh0P82009:BTP1gMgL2092@T00i09VIV@2?Shl0/;2`096AT@24Q8@0NWYj
09fMW@23Ph<0UIFE092@T024Q8@0Ogmo08j>SP2:RXX0LW9b08R8R024Q8@0R8R808F5Q@2<S8`0MGEe
0861P@2@T900N7Qh06IVIP1NGUh0Lg=c05UIF@1@D500EEEE04i>CP1PH600F5QH055AD@1aLG40GUiN
08J6QP2ATI40R8R80861P@1kNg/0N7Qh07=cL`1KFe/0O7al06EUI@24Q8@0JVYZ06m_K`1gMgL0QXJ6
06][J`1SHf<0MGEe075aL@1<C4`0B4Q800<0000004H0@D51059BDP1[Jf/0I6AT07]kN`1aLG40MWIf
07AdM01kNg/0Jf][06UYJ@1fMWH0GUiN08R8R01ZJVX0Ti>C075aL@1gMgL0MGEe08:2PP1kNg/0N7Qh
08N7Q`1gMgL0Q8B407AdM01lO7`0LW9b06UYJ@2=SHd0NGUi08B4Q01`L700MGEe065QH@1PH600De=C
061PH01gMgL0K6a/05EEE@1LG5`0GUiN06a/K01ZJVX0L71`05aLG01=CDd0Fe]K06QXJ01gMgL0Cdm?
05aLG01`L700GemO06m_K`1@D500IfMW05UIF@1UIFD0BDU9055AD@15ADD0D51@0410@01KFe/0De=C
05YJFP19BDT0G5aL0P1GEeL04`19BDT0E5AD07=cL`1GEeL0>c/k055AD@0m?Cd0Fe]K06MWI`1LG5`0
EEEE061PH011@D40>c/k05]KF`18B4P0HF5Q04a<C03oool01P3IfMT100000040fMWI000F0=WIf@03
0000003IfMT0fMWI00<0fMWI02d0oooo09nOW`1nOWh0MGEe07UiN@1dM7@0N7Qh07alO01/K6`0Ph>3
07IfMP1WIfL0M7Ad06a/K01oOgl0OWin08b<S01aLG40T92@07]kN`1oOgl0K6a/0820P028R8P0OWin
07UiN@29RHT0Rh^;08Z:RP1nOWh0VYZJ07alO01eMGD0SHf=0820P01jNWX0WinO092@T02MWId0O7al
08V9R@26QXH0JVYZ07inOP1TI6@00P1RHV80B`1SHf<0Cdm?06a/K01/K6`0LG5a092@T01nOWh0LW9b
08B4Q02LW9`0WIfM07inOP1kNg/0WYjN07emO@2;Rh/0UIFE08f=S@1nOWh0NGUi08N7Q`2;Rh/0NWYj
0820P025QHD0TI6A08R8R02:RXX0N7Qh09:BTP1kNg/0RXZ:08n?S`24Q8@0SXj>06ATI01fMWH0Shn?
07alO02:RXX0Q8B407]kN`1nOWh0MgMg07IfMP1nOWh0Jf][07emO@1/K6`0RXZ:05mOG`1^KVh0MGEe
071`L01XJ6P0Ng]k08>3P`1/K6`0PH6108B4Q01]KFd0NGUi0::RXP1hN7P0S8b<08n?S`2IVIT0TY:B
0:2PX02@T900R8R807alO02JVYX0VIVI08>3P`0207inOP0K07emO@1`L700Rh^;09JFUP26QXH0OGem
08V9R@1eMGD0QHF508n?S`1VIVH0Jf][08B4Q02>SXh0Rh^;08:2PP1mOGd0OWin09>CT`2:RXX0X:2P
096AT@2TY:@0Vi^K08^;R`2DU9@0Shn?0080Lg=c02P0R8R808Z:RP2EUID0Shn?09:BTP2@T900Rh^;
09ZJVP2;Rh/0PX:207inOP1hN7P0U9BD092@T02BTY80YJFU07inOP23Ph<0NGUi08B4Q02LW9`0UYJF
07AdM024Q8@0RXZ:07emO@2OWil0P820065QH@1jNWX0N7Qh07emO@1jNWX0QhN707alO01kNg/0IFEU
04m?C`1aLG40GEeM0P1TI6@05@1WIfL0Hf=S05=CD`1FEUH0L71`06m_K`1[Jf/0Rh^;09bLW02;Rh/0
KFe]08:2PP29RHT0PX:209FEU@2;Rh/0PX:207emO@25QHD0N7Qh07]kN`0206ATI0030410@01FEUH0
000000<0000001<0RHV906=SH`1aLG40O7al075aL@2;Rh/0M7Ad09RHV02?Shl0TY:B0861P@2<S8`0
V9RH08>3P`22PX80Ph>307IfMP2IVIT0PH610080O7al01D0N7Qh06m_K`1hN7P0N7Qh06][J`20P800
MGEe061PH01?Cdl0Lg=c08:2PP1cLg<0JFUY06i^KP20P800IVIV079bLP1QHF40EEEE06IVIP1LG5`0
0P1WIfL06@1TI6@0G5aL05UIF@1dM7@0EeMG06m_K`1hN7P0AdM706a/K01BDU80BDU906YZJP24Q8@0
MGEe06m_K`1OGel0HF5Q05IFEP1GEeL0FEUI051@D015ADD0F5QH04M7A`1PH6000P1CDe<04`1PH600
J6QX069RHP1KFe/0@d=303Ph>01WIfL0>3Ph04i>CP1NGUh0DU9B05YJFP1EEED0?clo05IFEP1LG5`0
?Cdm05eMG@3oool01P3IfMT100000040fMWI00020=WIf@800000103IfMT2000000@0fMWI0P000006
0=WIf@030000003IfMT0fMWI00<0fMWI0240oooo06QXJ021PH40Ogmo06EUI@28R8P0T92@0820P026
QXH0T92@07AdM01RHV80O7al07inOP20P800N7Qh07IfMP1bLW80M7Ad0861P@1iNGT0Ng]k06UYJ@2:
RXX0U9BD06e]K@1fMWH0X:2P08^;R`2:RXX0QhN70861P@2:RXX00P23Ph<0?01kNg/0SHf=09RHV02D
U9@0SXj>09ZJVP2DU9@0PX:207]kN`1eMGD0BTY:05eMG@1NGUh0HF5Q04i>CP1SHf<0OGem06i^KP2=
SHd0TY:B07moO`2ATI40TY:B07]kN`2@T900LW9b09ZJVP2EUID0TY:B09^KV`2QXJ40TI6A07emO@2?
Shl0RXZ:09:BTP1kNg/0MgMg08V9R@20P800NWYj09:BTP1bLW80Shn?08:2PP2@T900Fe]K07emO@1`
L700Hf=S07MgM`1fMWH0MgMg075aL@1hN7P0Ph>305eMG@2GUiL0KFe]08J6QP80O7al00`0Ng]k08>3
P`1kNg/0OGem07QhN01]KFd0Ph>308R8R02:RXX0NWYj07AdM027QhL208j>SP1407emO@2>SXh0NWYj
09VIV@2DU9@0Shn?08R8R027QhL0UiNG09JFUP1mOGd0NWYj06m_K`29RHT0RXZ:08j>SP2DU9@0RHV9
0:>SX`29RHT0RXZ:0:>SX`2ATI40Ng]k09VIV@1lO7`0RHV90:6QX@29RHT0Ti>C09bLW01mOGd0QXJ6
0861P@2=SHd0QXJ608^;R`2FUYH0XZ:R08j>SP2LW9`0WinO08b<S022PX80P82008^;R`26QXH0X:2P
07moO`2PX:00SHf=09NGU`29RHT0XZ:R0:FUY@2MWId0Vi^K0::RXP2UYJD0SHf=09JFUP2@T900S8b<
0820P02GUiL0QHF508b<S022PX8207MgM`0;08V9R@23Ph<0SHf=0:6QX@1mOGd0Jf][06QXJ01mOGd0
MgMg04A4A01LG5`00P1/K6`03@1BDU80FEUI06m_K`1UIFD0De=C06EUI@22PX80S8b<08>3P`1UIFD0
X:2P08N7Q`1PH6000P1iNGT02`29RHT0UIFE08f=S@22PX80SXj>0861P@1_Kfl0MGEe06=SH`1WIfL0
DE5A00@0000000L0J6QX07YjNP2:RXX0JVYZ07inOP2ATI40OGem00<0Ogmo0P2=SHd03`1]KFd0Rh^;
07]kN`2:RXX0Q8B40820P01_Kfl0OGem096AT@1gMgL0S8b<07emO@1bLW80IFEU06m_K`0207]kN`0U
071`L01]KFd0Bd];06YZJP1_Kfl0M7Ad075aL@1cLg<0E5AD05=CD`1`L700GemO05aLG01SHf<0E5AD
07UiN@1SHf<0H61P06EUI@1ZJVX0L71`059BDP1PH600ATI605eMG@1OGel0BDU9065QH@1ZJVX0IFEU
06UYJ@1>CTh0H61P05ADE01ZJVX0Fe]K06e]K@0304e=C@0E06QXJ01[Jf/0GEeM03Lg=`1TI6@0?Shn
04Q8B01DE5@0BDU905iNGP1EEED0De=C03@d=017AdL0IfMW05=CD`1EEED0=cLg03`l?00j>SX0oooo
00H0fMWI0@0000010=WIf@0000D0fMWI0000003IfMT0fMWI000000020=WIf@040000003IfMT0fMWI
00000080fMWI00@000000=WIf@3IfMT000001@3IfMT00`000000fMWI0=WIf@030=WIf@1^0?ooo`1]
KFd0KVi^07EeM@2FUYH0W9bL07UiN@28R8P0P82007EeM@29RHT0J6QX07QhN01mOGd0KVi^06UYJ@1X
J6P0MGEe06a/K024Q8@0PH6108^;R`21PH40KFe]08:2PP28R8P0Shn?0:2PX02DU9@0TY:B08N7Q`2F
UYH0TY:B09^KV`1XJ6P0ZZZZ08n?S`24Q8@0PX:2092@T02=SHd0Ti>C07EeM@1YJFT0MgMg071`L01T
I6@0QXJ6079bLP1_Kfl0Ng]k07AdM023Ph<0TI6A07IfMP22PX80T92@0861P@2>SXh0OGem08F5Q@22
PX80R8R807emO@2BTY80UiNG09BDU026QXH0PX:2096AT@1hN7P0Q8B407UiN@2DU9@0RHV907UiN@26
QXH0Ti>C08V9R@2?Shl0U9BD08:2PP1`L700PH6106MWI`1iNGT0Q8B40820P01[Jf/0QhN707]kN`27
QhL0N7Qh07alO02EUID0O7al05]KF`1VIVH0M7Ad0861P@23Ph<0KVi^08B4Q01gMgL0PH6108>3P`1i
NGT0QXJ609VIV@1oOgl208B4Q00c09JFUP1oOgl0PX:208^;R`2PX:00QhN709VIV@2EUID0T92@09ZJ
VP25QHD0UYJF07]kN`2HV9P0SHf=09FEU@1lO7`0TI6A09>CT`2NWYh0P82008n?S`1lO7`0RHV907Ee
M@27QhL0W9bL07]kN`1nOWh0R8R8096AT@2=SHd0R8R8092@T02HV9P0NWYj09RHV02TY:@0RXZ:09NG
U`2XZ:P0Rh^;09NGU`2DU9@0Y:BT09bLW02SXj<0Rh^;07EeM@20P800RHV90080VIVI0200XJ6Q0:VY
Z@2GUiL0V9RH09FEU@21PH40WIfM0:2PX029RHT0TY:B07inOP2:RXX0R8R809fMW@2DU9@0S8b<07Ui
N@2:RXX0R8R808n?S`1oOgl0Lg=c05ADE01YJFT0GEeM071`L01cLg<0IVIV06UYJ@1fMWH0KFe]05YJ
FP80EUIF03L0JVYZ07MgM`2;Rh/0VIVI09BDU02ATI40Ph>307alO02ATI40LW9b08F5Q@1gMgL0Ph>3
08N7Q`2ATI40PH6107MgM`2:RXX0Rh^;075aL@1QHF40LG5a0451@@1:BTX0Jf][06IVIP23Ph<0JFUY
08:2PP2KVi/0PX:206i^KP2IVIT0YZJV096AT@25QHD0Ng]k09BDU025QHD0Rh^;096AT@1/K6`0TI6A
08j>SP20P800O7al075aL@21PH40L71`07YjNP2@T900TY:B06][J`1gMgL0L71`0080M7Ad03X0I6AT
06IVIP1aLG40KVi^06YZJP1JFUX0KVi^069RHP1ADE40K6a/06ATI021PH40L71`06=SH`1/K6`0FUYJ
05iNGP1dM7@0Jf][04Y:BP1NGUh0HV9R06EUI@1CDe<0GEeM079bLP1YJFT0E5AD06UYJ@1PH600E5AD
05QHF01IFET0JVYZ05MGE`1HF5P0De=C03`l?01_Kfl0GEeM07]kN`1SHf<0ATI604Y:BP1EEED0DE5A
05ADE01ADE40?Shn0492@P1FEUH0IVIV04m?C`1;Bd/0AdM705MGE`1NGUh0oooo1P3IfMT100000040
fMWI00040=WIf@040000003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT000000P3IfMT00`00
0000fMWI0=WIf@030=WIf@<000000`3IfMT03@3oool0X:2P07inOP1iNGT0M7Ad07=cL`2>SXh0QXJ6
08B4Q01RHV80M7Ad09>CT`2:RXX00P21PH40KP29RHT0MGEe0820P01YJFT0SXj>08n?S`24Q8@0UYJF
07alO01nOWh0UiNG07QhN02ATI40SXj>08f=S@2JVYX0QhN709>CT`21PH40U9BD0:2PX01jNWX0QXJ6
08>3P`1oOgl0RXZ:07AdM02ATI40U9BD07]kN`2;Rh/0OGem08F5Q@2ATI40Ph>307emO@2@T900Shn?
096AT@2GUiL0Rh^;09fMW@25QHD0TI6A08>3P`29RHT0X:2P08R8R01lO7`0SHf=065QH@2FUYH0UiNG
07alO025QHD0NWYj071`L029RHT0UIFE07moO`1]KFd0TI6A07EeM@22PX80RHV907emO@25QHD0KVi^
07UiN@2<S8`0Q8B407AdM01gMgL0OWin07MgM`1hN7P0O7al06m_K`28R8P0L71`06=SH`1ZJVX0Ogmo
0820P02:RXX0Ti>C08>3P`27QhL0R8R808N7Q`24Q8@0R8R808b<S02?Shl0W9bL07moO`2PX:00WinO
0:b/[02DU9@0WIfM09FEU@2IVIT0W9bL09JFUP2KVi/0S8b<0:2PX01fMWH0RHV90P2NWYh209FEU@0V
0:2PX02?Shl0OWin07moO`26QXH0Vi^K079bLP2HV9P0UIFE0861P@1hN7P0PH61092@T02:RXX0PX:2
08>3P`2JVYX0T92@0:2PX02?Shl0T92@09:BTP2KVi/0UIFE07]kN`2GUiL0U9BD08J6QP2TY:@0VIVI
07QhN02>SXh0Vi^K08f=S@2TY:@0ZJVY0:JVYP2JVYX209JFUP0L07]kN`24Q8@0VIVI07QhN02DU9@0
T92@07QhN02;Rh/0Ng]k08>3P`2MWId0Ti>C0:FUY@1iNGT0Jf][08B4Q023Ph<0IfMW065QH@1LG5`0
M7Ad05mOG`1mOGd0Hf=S096AT@2CTi<0QHF5061PH080IVIV0700J6QX071`L01jNWX0RXZ:08f=S@2B
TY80UYJF08^;R`2PX:00Shn?09^KV`2FUYH0SHf=08N7Q`1YJFT0VYZJ0820P01bLW80IFEU08j>SP1X
J6P0QHF50820P01cLg<0K6a/08F5Q@26QXH0SXj>08N7Q`2=SHd0Ogmo09ZJVP2:RXX0PH6108f=S@1o
Ogl0T92@07EeM@24Q8@0S8b<07]kN`1mOGd0RXZ:08F5Q@1hN7P0Shn?08R8R01OGel0NGUi07MgM`1U
IFD0N7Qh079bLP1jNWX0JFUY06m_K`1hN7P0OWin05ADE01[Jf/0Ogmo065QH@1:BTX0Jf][06a/K01g
MgL0IfMW069RHP1CDe<0FUYJ06e]K@1TI6@0H61P0861P@1hN7P0DU9B07AdM01_Kfl0GUiN05aLG01U
IFD0C4a<05aLG01OGel0EUIF065QH@1jNWX0De=C06ATI01DE5@0H61P06QXJ01WIfL0DE5A06a/K01]
KFd0D51@05YJFP1KFe/0HV9R05IFEP1QHF40FEUI05EEE@1IFET0DE5A04A4A019BDT0BTY:065QH@1C
De<0ATI60P1FEUH00`3oool0fMWI0=WIf@020=WIf@<000000@3IfMT00080fMWI0P0000030=WIf@04
0000003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT000001@3IfMT00`000000fMWI0=WIf@03
0=WIf@0k0?ooo`22PX80V9RH09:BTP1cLg<0UYJF06QXJ025QHD0QXJ6075aL@1cLg<0Q8B4092@T01Y
JFT0N7Qh06YZJP1fMWH0Lg=c08V9R@1nOWh0UYJF06e]K@22PX80Ogmo07inOP2CTi<0VYZJ08^;R`2I
VIT0UIFE06i^KP2BTY80QhN708b<S02MWId0U9BD09RHV02XZ:P0T92@08J6QP21PH40Kfm_0:f][@2@
T900Shn?08^;R`22PX80WYjN07emO@2;Rh/0TY:B08F5Q@2DU9@0TY:B07EeM@2>SXh0OGem08B4Q01i
NGT00P2?Shl0;02JVYX0Q8B408j>SP2;Rh/0QXJ6092@T01mOGd0Rh^;07inOP29RHT0MWIf09VIV@2B
TY80Ng]k08B4Q01_Kfl0U9BD09:BTP24Q8@0SHf=09>CT`23Ph<0QHF507inOP1`L700UIFE075aL@21
PH40TI6A08N7Q`23Ph<0Lg=c08f=S@2?Shl0OGem06][J`1`L700MWIf0820P024Q8@0OGem06i^KP1m
OGd0SXj>0P2:RXX09027QhL0S8b<08j>SP25QHD0Ti>C09VIV@2PX:00WIfM07emO@2KVi/0VYZJ09fM
W@2IVIT0U9BD07emO@2DU9@0T92@07alO01fMWH0NWYj09:BTP2VYZH0QhN708^;R`2ATI40SHf=08n?
S`1bLW80SXj>09BDU028R8P0SHf=08Z:RP1nOWh0VYZJ09BDU080SXj>02T0MGEe09BDU02GUiL0NWYj
09ZJVP1jNWX0R8R80:FUY@2BTY80YZJV08B4Q02IVIT0WIfM08n?S`28R8P0[Zj^0:FUY@2FUYH0Xj>S
0:VYZ@2SXj<0X:2P09^KV`2JVYX0X:2P09ZJVP2CTi<0R8R809BDU02:RXX0MWIf08f=S@2@T900VYZJ
08Z:RP2<S8`0TI6A0820P02NWYh0T92@08Z:RP0206a/K01f05iNGP1TI6@0JFUY07]kN`26QXH0Ti>C
08f=S@2CTi<0OGem05ADE00f=SH0G5aL079bLP1^KVh0RXZ:0861P@26QXH0Vi^K071`L02RXZ80TY:B
06i^KP1lO7`0OWin08F5Q@1_Kfl0Ogmo075aL@2ATI40Kfm_07IfMP2=SHd0P82007EeM@1lO7`0Jf][
06MWI`20P800R8R808B4Q027QhL0R8R807]kN`1lO7`0UIFE06m_K`2NWYh0M7Ad07IfMP1mOGd0JVYZ
08b<S01mOGd0UYJF08^;R`2>SXh0Ng]k07alO029RHT0KFe]08B4Q01dM7@0N7Qh06YZJP1_Kfl0IVIV
06m_K`1ZJVX0Jf][08^;R`1_Kfl0IVIV07emO@1GEeL0FUYJ05IFEP1=CDd0JFUY07emO@0m?Cd0ADE5
07UiN@1EEED0FEUI06EUI@1dM7@0Ng]k06MWI`1LG5`0JFUY05iNGP1SHf<0GUiN061PH01fMWH0GemO
05iNGP1QHF40ADE504=3@`1OGel0HF5Q059BDP1>CTh0GUiN055AD@1MGEd0FEUI04e=C@1WIfL0EUIF
06m_K`1MGEd0BDU905YJFP1>CTh0@T92055AD@80GemO00H0HV9R05YJFP1VIVH0CDe=05eMG@3oool6
0=WIf@4000000@3IfMT00080fMWI00<000000=WIf@3IfMT00P3IfMT010000000fMWI0=WIf@000002
0=WIf@040000003IfMT0fMWI000000D0fMWI00<000000=WIf@3IfMT00`3IfMT00`3oool0RXZ:0861
P@0208j>SP0T09BDU01nOWh0K6a/0861P@1jNWX0QHF50820P029RHT0NGUi07emO@1jNWX0SHf=08b<
S027QhL0RXZ:08b<S02FUYH0Vi^K08>3P`2=SHd0K6a/09JFUP2BTY80YJFU08R8R02DU9@0UiNG08B4
Q02PX:00SHf=092@T02>SXh0Ph>309FEU@25QHD0UiNG0P2BTY801P1oOgl0Ph>307alO02LW9`0Ng]k
09VIV@80NWYj03P0Jf][08N7Q`23Ph<0W9bL075aL@1iNGT0Ogmo092@T01oOgl0PX:207AdM02HV9P0
QXJ608f=S@2:RXX0QXJ60861P@1OGel0KFe]06i^KP2NWYh0VIVI09^KV`2ATI40Xj>S08Z:RP2>SXh0
OWin09>CT`2>SXh0N7Qh09JFUP24Q8@0MgMg07alO01eMGD0QHF507alO01mOGd0N7Qh07EeM@2@T900
N7Qh08Z:RP1jNWX0Ng]k07UiN@1jNWX0QhN70820P02<S8`0PX:208F5Q@2PX:00MgMg07EeM@80Rh^;
00@0VYZJ09RHV02:RXX0T92@0P2EUID0N029RHT0UIFE092@T02OWil0XJ6Q08f=S@2UYJD0Shn?08V9
R@1lO7`0P82008^;R`29RHT0TY:B07inOP1[Jf/0T92@09^KV`22PX80T92@08Z:RP2FUYH0SXj>09VI
V@24Q8@0RXZ:08:2PP2OWil0U9BD08>3P`22PX80SXj>08R8R02=SHd0R8R809fMW@2PX:00T92@09^K
V`2GUiL0R8R807emO@2KVi/0Shn?09^KV`2OWil0/K6a08^;R`2IVIT0W9bL09ZJVP2^[Zh0OWin08F5
Q@2CTi<0UIFE0:2PX02@T900Y:BT09jNWP23Ph<0MgMg096AT@28R8P0Shn?0820P01oOgl0UYJF09FE
U@1mOGd0Ng]k06YZJP1NGUh0HF5Q06i^KP1ZJVX0SXj>08b<S01lO7`0XZ:R09jNWP1kNg/0NGUi07Yj
NP1@D500K6a/08b<S02:RXX0RHV90:VYZ@2ATI40QHF508B4Q02CTi<0XJ6Q09JFUP2XZ:P0PX:209NG
U`1eMGD0R8R806UYJ@28R8P0L71`06QXJ01VIVH0UIFE06MWI`1nOWh0Jf][09BDU025QHD0PH6108F5
Q@1lO7`0MgMg07inOP2EUID0MgMg07moO`80SXj>04d0W9bL07inOP2;Rh/0P82008:2PP2:RXX0R8R8
0861P@26QXH0MGEe07MgM`29RHT0NGUi06a/K01`L700K6a/06i^KP1VIVH0L71`06UYJ@1_Kfl0KVi^
06ATI01eMGD0Lg=c06e]K@1WIfL0F5QH061PH01^KVh0IVIV06UYJ@1OGel0J6QX06ATI01JFUX0H61P
07AdM01XJ6P0GemO079bLP1lO7`0Hf=S055AD@1ZJVX0IFEU05iNGP1ZJVX0BDU905]KF`1NGUh0E5AD
05UIF@1/K6`0E5AD0492@P1EEED0Fe]K059BDP1?Cdl0GUiN04E5A@1IFET0KVi^05eMG@1SHf<0IFEU
03hn?P1=CDd0AdM705eMG@1?Cdl0GEeM07YjNP1/K6`0E5AD0?ooo`060=WIf@4000000@3IfMT00080
fMWI0`0000030=WIf@800000103IfMT2000000H0fMWI00<000000=WIf@3IfMT00`3IfMT0<P3oool0
PX:209>CT`2:RXX0N7Qh08^;R`1eMGD0L71`06YZJP1gMgL0R8R808F5Q@2/[:`0O7al08n?S`1kNg/0
Jf][061PH02@T900R8R80861P@2EUID0XJ6Q08B4Q02=SHd0ZZZZ0:>SX`2=SHd0SXj>0820P02RXZ80
QhN707AdM02OWil0UYJF096AT@2:RXX0RHV908B4Q028R8P0U9BD07]kN`22PX80P82007moO`2:RXX0
Ti>C07EeM@2JVYX0H61P0P23Ph<0>02>SXh0L71`07inOP1fMWH0Ogmo08N7Q`1iNGT0][Jf08N7Q`2>
SXh0Ph>308J6QP1fMWH0Ogmo08N7Q`2FUYH0U9BD0861P@2;Rh/0TY:B09RHV028R8P0S8b<08>3P`2<
S8`0RXZ:0820P023Ph<0Shn?09fMW@2>SXh0RHV908n?S`1dM7@0MGEe06e]K@2DU9@0L71`07EeM@26
QXH0L71`08R8R01`L700OWin0820P02>SXh0MGEe07]kN`1aLG40R8R807emO@1bLW80TI6A08Z:RP2E
UID0Vi^K0P2HV9P0102PX:00YZJV07alO02HV9P208^;R`280:^[Z`2ZZZX0Rh^;0:^[Z`2BTY80XZ:R
06a/K02KVi/0KFe]08^;R`1WIfL0WinO09^KV`27QhL0TY:B07moO`1kNg/0Ti>C09JFUP2VYZH0QhN7
08B4Q02GUiL0ZJVY08f=S@2IVIT0WIfM092@T02QXJ40TY:B08B4Q02?Shl0UYJF09ZJVP2HV9P0VYZJ
09:BTP27QhL0UYJF09VIV@2PX:00XJ6Q0:RXZ02f][H0WYjN08j>SP2m_Kd0VIVI0:RXZ03<c<`0UYJF
0:FUY@2LW9`0Z:RX092@T02KVi/0TI6A0:FUY@2:RXX0Shn?09fMW@2UYJD0R8R8079bLP2@T900W9bL
09fMW@22PX80QhN709RHV01QHF40FUYJ065QH@1bLW80JVYZ06e]K@2MWId0OGem08Z:RP23Ph<0QhN7
06e]K@1iNGT0LW9b069RHP26QXH0TI6A09bLW02@T900SXj>09>CT`26QXH0QHF508B4Q026QXH0X:2P
0:>SX`1iNGT0YjNW08Z:RP2?Shl0RHV907QhN022PX80RXZ:07moO`2BTY80Shn?07emO@1_Kfl0NWYj
08j>SP1jNWX0OGem092@T01cLg<0QhN708^;R`27QhL0U9BD0:6QX@1mOGd0NGUi09BDU020P800SXj>
079bLP26QXH0Q8B407emO@1[Jf/0O7al07]kN`1gMgL0NGUi06i^KP80IfMW00h0FEUI06][J`1aLG40
M7Ad065QH@1`L700H61P06UYJ@1_Kfl0Lg=c0820P01WIfL0Fe]K05aLG080Kfm_00`0J6QX075aL@1a
LG40LG5a079bLP1TI6@0J6QX07EeM@1YJFT0NWYj06IVIP1IFET205eMG@0N05MGE`1WIfL0Jf][05AD
E01YJFT0N7Qh04e=C@1_Kfl0IfMW06][J`1XJ6P0IfMW03De=@1aLG40J6QX06][J`1NGUh0GemO06UY
J@1`L700EeMG069RHP1KFe/0IVIV04];B`1KFe/0F5QH065QH@1SHf<0oooo1P3IfMT100000040fMWI
000F0=WIf@030000003IfMT0fMWI00<0fMWI04h0oooo0861P@1mOGd0M7Ad09JFUP23Ph<0Ng]k07em
O@1iNGT0IFEU07=cL`1fMWH0QXJ60:BTY02ATI40SHf=08J6QP2FUYH0NGUi08n?S`2[Zj/0UYJF08j>
SP2EUID0RXZ:08J6QP1_Kfl0VYZJ08f=S@2:RXX0VYZJ09RHV02@T900UYJF08V9R@2:RXX0W9bL07al
O02?Shl0Ti>C06e]K@1nOWh0Q8B40861P@1lO7`0NGUi08>3P`21PH40R8R807emO@25QHD0T92@06e]
K@1mOGd0SXj>09FEU@2<S8`0PH61079bLP1[Jf/0Shn?09>CT`27QhL0Ti>C08R8R01lO7`0RHV90820
P02CTi<0O7al08N7Q`2QXJ40SHf=09FEU@27QhL0X:2P08Z:RP2GUiL308>3P`0H07QhN01mOGd0TI6A
08F5Q@28R8P0M7Ad08j>SP1kNg/0PX:207IfMP2BTY80RHV908:2PP1mOGd0Ng]k06m_K`1XJ6P0P820
08b<S02EUID0QXJ609BDU01hN7P0SXj>0P29RHT05`2CTi<0ZZZZ09ZJVP2PX:00^KVi0:VYZ@2QXJ40
OWin0:6QX@2KVi/0X:2P092@T025QHD0TI6A08J6QP2MWId0V9RH09fMW@1nOWh0PX:208V9R@2=SHd0
S8b<0080Q8B40;H0XJ6Q09NGU`2SXj<0Vi^K0:2PX02WYjL0SHf=0861P@2YZJT0Shn?08N7Q`2SXj<0
WIfM08b<S02XZ:P0MWIf0:>SX`2ATI40S8b<09NGU`2JVYX0TY:B09NGU`2b/[80VYZJ09fMW@2JVYX0
Ti>C0:b/[02OWil0UiNG0:j^[P2a/K40R8R808V9R@2HV9P0Ogmo09:BTP28R8P0SXj>0:RXZ02MWId0
WinO09RHV02KVi/0TI6A09NGU`26QXH0VIVI0:2PX02CTi<0Y:BT09BDU01iNGT0JFUY05eMG@1CDe<0
Cdm?06=SH`1dM7@0QhN707YjNP1bLW80PH6108>3P`21PH40OGem06UYJ@28R8P0UYJF09RHV025QHD0
SXj>08n?S`1oOgl0PH61092@T02<S8`0Rh^;08V9R@2@T900YZJV09FEU@25QHD0U9BD08f=S@2DU9@0
TY:B08Z:RP27QhL0PH6109:BTP2ATI40Ng]k0861P@2=SHd0PH6109bLW026QXH0PH6109VIV@2;Rh/0
SXj>09>CT`2e]KD0WYjN08f=S@1jNWX0Ph>307alO027QhL0O7al0820P02@T900SXj>079bLP1UIFD0
Q8B408^;R`1VIVH0QhN708>3P`1gMgL0QXJ606a/K01`L700M7Ad07MgM`1/K6`0HF5Q06][J`1cLg<0
Hf=S05eMG@1WIfL0IVIV05iNGP1QHF40J6QX05aLG01aLG40MWIf06e]K@1[Jf/0LW9b07alO01cLg<0
J6QX06e]K@1bLW80Jf][06MWI`1`L700FUYJ07UiN@1aLG40JVYZ06ATI01SHf<0Kfm_069RHP1YJFT0
E5AD05]KF`1CDe<0BDU905aLG01MGEd0EUIF05MGE`1[Jf/0I6AT06i^KP1CDe<0K6a/03Lg=`1WIfL0
HF5Q069RHP1NGUh0DE5A0?ooo`H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WI
f@2D0?ooo`2GUiL0T92@09:BTP2;Rh/0QXJ608F5Q@24Q8@0QHF507EeM@2@T900MGEe07YjNP1oOgl0
P82008B4Q021PH40QhN709JFUP2BTY80RXZ:09>CT`2?Shl0Ph>305UIF@1mOGd0S8b<09jNWP2OWil0
S8b<08Z:RP2GUiL0ZJVY09fMW@2GUiL0Ti>C08f=S@1XJ6P0SHf=09bLW01oOgl0SHf=0820P01mOGd0
RXZ:09BDU02OWil0TI6A08>3P`2QXJ40UIFE08J6QP24Q8@0Ph>308f=S@2ATI40QhN708f=S@1iNGT0
V9RH09VIV@23Ph<0TY:B0:>SX`2ATI40Lg=c08:2PP2<S8`0PX:208n?S`29RHT0P82009fMW@2IVIT0
TI6A09ZJVP2:RXX0OWin09VIV@2LW9`0S8b<07emO@29RHT0K6a/07YjNP2BTY80Ph>307alO01oOgl0
N7Qh07]kN`23Ph<0OGem07MgM`1]KFd0OWin071`L01fMWH0RXZ:09>CT`2BTY80PH610:>SX`2:RXX0
Y:BT09nOW`2?Shl0Z:RX09RHV02<S8`0U9BD0:BTY02LW9`0UYJF09VIV@2RXZ80Y:BT0:FUY@2FUYH0
QhN709ZJVP2KVi/0RHV909ZJVP2SXj<0Ti>C07YjNP2BTY80SHf=0:FUY@2FUYH0Vi^K09JFUP2@T900
OWin08f=S@2MWId0[:b/0:JVYP2<S8`0PH6108f=S@2<S8`0YZJV09bLW02?Shl0VYZJ08V9R@80RXZ:
00<0Ti>C0:JVYP2NWYh00P2a/K405P2LW9`0Ti>C0820P02IVIT0^[Zj0:ZZZP2GUiL0ZJVY0<30`023
Ph<0Rh^;09nOW`2KVi/0Xj>S09:BTP2OWil0WYjN0:6QX@2IVIT0VYZJ09^KV`2/[:`209FEU@180:>S
X`2VYZH0SXj>0:BTY01jNWX0UiNG08^;R`1?Cdl0GemO04i>CP1:BTX0HV9R06YZJP1nOWh0NWYj07Mg
M`1dM7@0PX:207moO`1WIfL0TI6A08N7Q`2IVIT0W9bL0820P02DU9@0MGEe08J6QP2HV9P0Rh^;092@
T02DU9@0TI6A09:BTP24Q8@0Ph>3096AT@1dM7@0PH6108^;R`2VYZH0U9BD08n?S`2>SXh0X:2P09NG
U`1YJFT0RHV908B4Q028R8P0SHf=08N7Q`22PX80MgMg08F5Q@27QhL0PX:20:FUY@28R8P0S8b<08j>
SP1oOgl0S8b<08j>SP1iNGT0PH6107YjNP1eMGD0MWIf07=cL`1VIVH0OGem0P1WIfL0:P1GEeL0Jf][
07inOP1bLW80M7Ad06ATI01kNg/0MGEe07MgM`1^KVh0KFe]08F5Q@1RHV80Fe]K06EUI@1bLW80IFEU
07UiN@1jNWX0J6QX07QhN01^KVh0QXJ606YZJP1_Kfl0MWIf06i^KP1]KFd0GEeM06a/K01VIVH0GemO
0861P@1ADE40EUIF06UYJ@1XJ6P0H61P07YjNP1XJ6P0JFUY08:2PP80Hf=S0140MgMg06e]K@1GEeL0
FEUI055AD@1?Cdl0EeMG04i>CP1LG5`0EeMG04I6AP1<C4`0H61P05MGE`1KFe/0?Cdm0?ooo`060=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT00`3oool0OGem092@T00208j>SP1j
07alO020P800Ogmo08b<S01[Jf/0T92@08J6QP1lO7`0MGEe07YjNP1dM7@0P820096AT@2CTi<0YJFU
08>3P`2FUYH0WinO096AT@2GUiL0Ti>C09ZJVP2<S8`0RHV908>3P`2=SHd0U9BD08F5Q@2_[jl0S8b<
0:6QX@23Ph<0YJFU07]kN`2DU9@0Rh^;07emO@1oOgl0N7Qh08N7Q`2NWYh0SHf=09:BTP2ATI40Q8B4
09BDU02HV9P0PX:208R8R01eMGD0OGem09BDU02CTi<0VYZJ09FEU@1mOGd0V9RH08^;R`25QHD0UIFE
08V9R@1nOWh0Ogmo0:^[Z`1fMWH0WIfM08N7Q`2ATI40WIfM08F5Q@2NWYh0TY:B09nOW`1_Kfl0OWin
08:2PP2EUID0Rh^;079bLP25QHD0MgMg06YZJP1eMGD0UiNG08^;R`2ATI40T92@07alO01kNg/0OWin
07MgM`2@T900Shn?08b<S01_Kfl0UIFE09^KV`2ATI40UIFE09RHV02SXj<0UIFE092@T02ATI40XJ6Q
07moO`2>SXh0Z:RX0;Jf]P2NWYh0^;Rh09^KV`2LW9`0PH6109fMW@2OWil0U9BD09VIV@1mOGd0S8b<
09FEU@2>SXh208N7Q`0?092@T02OWil0RXZ:09fMW@2ATI40VYZJ092@T02BTY80QHF508f=S@2ATI40
TY:B0:>SX`2FUYH0RHV90080TI6A02<0XJ6Q09^KV`25QHD0UiNG09ZJVP2KVi/0W9bL0:VYZ@2BTY80
YjNW0:ZZZP2SXj<0WinO0::RXP2_[jl0Y:BT0:b/[02l_;`0]KFe0;Rh^02BTY80[Zj^0:2PX02NWYh0
Zj^[09NGU`2FUYH0[Jf]08f=S@2TY:@0ZJVY0:ZZZP2RXZ80QHF508n?S`0209JFUP0K096AT@20P800
Ogmo07MgM`1=CDd0GEeM06UYJ@1NGUh0Kfm_06QXJ01_Kfl0O7al07]kN`1_Kfl0MWIf06ATI01`L700
NGUi096AT@2RXZ80U9BD09VIV@1^KVh0QhN709JFUP2NWYh0VYZJ0080U9BD01T0S8b<09RHV02VYZH0
X:2P092@T028R8P0SHf=08F5Q@2<S8`0Rh^;09nOW`1lO7`0Ti>C08F5Q@2@T900TI6A08Z:RP1oOgl0
Ti>C0::RXP25QHD0JVYZ08j>SP2@T900SXj>0080WYjN04/0Shn?08>3P`23Ph<0TY:B08B4Q029RHT0
Hf=S07YjNP1eMGD0PH6108^;R`1gMgL0SHf=08>3P`1XJ6P0CDe=08^;R`25QHD0Ph>307AdM023Ph<0
OGem05eMG@1fMWH0JVYZ07moO`1iNGT0MWIf06QXJ01gMgL0Jf][07IfMP1EEED0EeMG069RHP1dM7@0
K6a/07MgM`1`L700CDe=06MWI`1[Jf/0NWYj07=cL`24Q8@0JFUY065QH@1VIVH0Lg=c065QH@1KFe/0
HV9R05ADE023Ph<0J6QX06IVIP1YJFT0J6QX04i>CP1GEeL0GUiN065QH@1YJFT0IfMW05iNGP1SHf<0
IFEU05UIF@1OGel0Kfm_05iNGP1MGEd0LG5a05IFEP3oool01P3IfMT100000040fMWI000F0=WIf@03
0000003IfMT0fMWI00<0fMWI00<0oooo08f=S@2KVi/00P2BTY806@29RHT0NWYj09JFUP1MGEd0Ph>3
09>CT`2DU9@0P82009FEU@20P800OWin08B4Q02FUYH0S8b<09RHV02JVYX0Ogmo0820P021PH40RXZ:
07EeM@27QhL0R8R809:BTP1gMgL00P2HV9P0302KVi/0WinO07inOP29RHT0Vi^K0861P@2EUID0MWIf
07YjNP2;Rh/0Jf][08V9R@80QHF501D0TY:B09JFUP2NWYh0QXJ60861P@2?Shl0P82008n?S`2JVYX0
T92@08Z:RP29RHT0N7Qh07emO@2<S8`0WYjN09bLW02/[:`0UYJF07emO@2=SHd00P23Ph<0=02b/[80
U9BD08V9R@2;Rh/0TY:B08B4Q02KVi/0UiNG09bLW02?Shl0[Jf]07alO02CTi<0RXZ:09ZJVP28R8P0
Rh^;0820P02RXZ80O7al08V9R@2?Shl0Kfm_09NGU`2;Rh/0Shn?07MgM`1hN7P0X:2P092@T02>SXh0
XZ:R09BDU02RXZ80RXZ:09BDU02UYJD0R8R80:FUY@2[Zj/0UYJF09fMW@2TY:@0Xj>S0;Fe]@2DU9@0
QhN70:NWY`2NWYh0XJ6Q0::RXP2LW9`209^KV`0T07alO02LW9`0VIVI0:VYZ@2SXj<0];Bd08j>SP2Q
XJ40U9BD08Z:RP2EUID0VIVI09jNWP37alL0TI6A09:BTP2CTi<0SHf=08R8R02YZJT0Shn?08R8R02P
X:00ZJVY0;2`/02FUYH0Z:RX0:6QX@2BTY80YZJV0::RXP2[Zj/0UiNG09BDU02QXJ40^;Rh0P2WYjL0
202[Zj/0ZJVY08^;R`2WYjL0][Jf08>3P`2KVi/0_;bl0P2JVYX03@2NWYh0U9BD0:VYZ@20P800OGem
07]kN`2SXj<0UIFE08j>SP2^[Zh0RHV909:BTP2EUID00P2DU9@0P025QHD0Fe]K0820P01BDU80CTi>
061PH01RHV80FUYJ05QHF01dM7@0HF5Q07]kN`2FUYH0RXZ:0:JVYP2RXZ80V9RH0:BTY02NWYh0S8b<
0:6QX@24Q8@0Ti>C0;>c/`2NWYh0Rh^;09fMW@1iNGT0UiNG08J6QP1mOGd0RHV908F5Q@1jNWX0M7Ad
075aL@27QhL0QXJ607inOP1oOgl0RXZ:06e]K@2VYZH0QXJ607MgM`2<S8`0SHf=09FEU@1gMgL0U9BD
09^KV`2TY:@0/[:b09ZJVP2=SHd0NGUi08>3P`2@T900Ng]k06][J`2FUYH0PH6107alO01hN7P0Ng]k
08j>SP24Q8@0MGEe06YZJP22PX80QXJ608^;R`1WIfL0LW9b0861P@1oOgl0MWIf06YZJP1RHV80LG5a
07QhN01DE5@0IVIV08>3P`1]KFd0K6a/079bLP1^KVh0MGEe08f=S@1nOWh0K6a/06YZJP1?Cdl0IfMW
071`L01VIVH0IFEU05eMG@26QXH0Fe]K05UIF@1bLW80IfMW06IVIP1?Cdl0Jf][04m?C`1OGel0IFEU
07EeM@1KFe/0Hf=S065QH@1OGel0BTY:04m?C`1GEeL0Fe]K05iNGP1YJFT0G5aL055AD@1mOGd0EUIF
04a<C01IFET0oooo1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00<0oooo
000000000000o`00000g000000030?ooo`3IfMT0fMWI00@0fMWI0@0000010=WIf@005P3IfMT00`00
0000fMWI0=WIf@3o0=WIfD@0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WIfD@0
fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WIfD@0fMWI0@0000010=WIf@005P3I
fMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI03X0fMWI00<000000=WIf@3IfMT0>`3I
fMT00`000000fMWI0=WIf@0j0=WIf@030000003IfMT0fMWI03X0fMWI00<000000=WIf@3IfMT0>`3I
fMT00`000000fMWI0=WIf@0:0=WIf@4000000@3IfMT001H0fMWI0P0000040=WIf@030000003IfMT0
fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0
fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0
fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0
fMWI00T0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0
fMWI00T0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0
fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0
fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT02@3IfMT200000040fMWI000F0=WIfOl00000B00000010=WI
f@00o`3IfMUO0=WIf@00o`3IfMUO0=WIf@00o`3IfMUO0=WIf@00o`3IfMUO0=WIf@00\
\>"],
  ImageRangeCache->{{{0, 349}, {349, 0}} -> {-46.2288, -38.9981, 1.62945, \
1.62945}}]
}, Open  ]],

Cell["\<\
The dark frame is a measure of the thermal noise produced by thermally \
excited electrons. In this case, the CCD chip was cooled with liquid \
nitrogen, so there was no appreciable thermal count. The dark frame was \
therefore omitted.\
\>", "Text"],

Cell["\<\
The image frame is an image of the giant elliptical galaxy M87.  The raw \
image contains an overscan region that is 50 pixels wide on the right side. \
This region will be removed later.  Plotting of the image frame is discussed \
in the next section.\
\>", "Text"],

Cell[BoxData[
    \(\(image = 
        Import["\<May08_0132.fit\>", 
          ConversionOptions \[Rule] {"\<Verbose\>" \[Rule] 
                True}];\)\)], "Input"],

Cell["\<\
We can also view the header which contains important information such as the \
image type and the filter that was used.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[{"\<OBJECT\>", "\<BITPIX\>", "\<EXPTIME\>", "\<DATE-OBS\>", "\
\<OBSERVAT\>"} /. image[\([1, 1]\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\("Value" \[Rule] 
              "'M87     '"\), \("Comment" \[Rule] \*"\<\"\"\>"\)},
          {\("Value" \[Rule] 16.`\), \("Comment" \[Rule] 
              "FITS BITS/PIXEL"\)},
          {\("Value" \[Rule] 300.`\), \("Comment" \[Rule] 
              "actual integration time, seconds"\)},
          {\("Value" \[Rule] "'09/05/00          '"\), \("Comment" \[Rule] 
              "UT date (dd/mm/yy) of observation"\)},
          {\("Value" \[Rule] "'lowell            '"\), \("Comment" \[Rule] 
              "observatory"\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reducing the Image", "Section"],

Cell["\<\
Reduction of an image is a process that processes a raw-image frame so that \
it is ready for useful analysis. In this case, the process involves \
subtracting a bias frame from all images and dividing the corrected image \
frame by a normalized flat-field frame.  \
\>", "Text"],

Cell["\<\
We need to preserve the original header so that we can modify it to reflect \
the fact that pixels will be removed when the overscan region is removed.\
\>", "Text"],

Cell[BoxData[
    \(\(oldheader = image[\([1, 1]\)];\)\)], "Input"],

Cell["\<\
Since we will be removing the overscan region, we need to modify the header \
to indicate the reduction of the number of pixels.\
\>", "Text"],

Cell[BoxData[
    \(\(newheader = 
        oldheader /. \(("\<NAXIS1\>" \[Rule] _)\) \[Rule] \(("\<NAXIS1\>" \
\[Rule] {"\<Value\>" \[Rule] 512. , "\<Comment\>" -> "\<\>"})\);\)\)], "Input"],

Cell["\<\
We need to remove the overscan region from the flat-field frame and subtract \
the bias frame from it as well.\
\>", "Text"],

Cell[BoxData[
    \(\(flatfielddata = 
        Transpose[Take[Transpose[avgvflat[\([1, 2]\)]], 512]] - 
          avgbias[\([1, 2]\)];\)\)], "Input"],

Cell["\<\
Similarly, we need to remove the overscan region from the raw-image frame. \
\>", "Text"],

Cell[BoxData[
    \(\(olddata = 
        Transpose[Take[Transpose[image[\([1, 2]\)]], 512]];\)\)], "Input"],

Cell["\<\
To normalize the flat-field frame, we simply divide every pixel by the \
average pixel value of the entire frame.\
\>", "Text"],

Cell[BoxData[
    \(\(normalizedflatfield = 
        flatfielddata/\((\((Plus @@ 
                  Flatten@flatfielddata)\)/\((512*512. )\))\);\)\)], "Input"],

Cell["\<\
Now, we actually perform the reduction process on the image by subtracting \
the bias frame and then dividing by the normalized flat-field frame.\
\>", "Text"],

Cell[BoxData[
    \(\(newdata = \((olddata - avgbias[\([1, 2]\)])\)/
          normalizedflatfield;\)\)], "Input"],

Cell["\<\
We finish by reconstructing the data into a header section and a data \
section. This is useful later if we wish to export the image to a new FITS \
image.\
\>", "Text"],

Cell[BoxData[
    \(\(workingimage = {{newheader, newdata}};\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plotting the Results", "Section"],

Cell["\<\
   Now that the calculations have all been completed, we can see the results. \
First, we can view the raw-image frame. As the image shows, there are \
numerous \"doughnuts\" in the image plane that represent unfocused dust \
grains sitting in the light path. Also, the overscan region is visible on the \
right side of the image. Since the overscan region contains no image data, we \
removed it in the previous section.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListDensityPlot[image[\([1, 2]\)], Mesh \[Rule] False, 
        ImageSize \[Rule] 350, AspectRatio \[Rule] Automatic];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92754 
%%ImageSize: 350 324.638 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00174192 0.0178372 0.00174192 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.19342 -0.0125 -9 -9 ]
[.19342 -0.0125 9 0 ]
[.36761 -0.0125 -9 -9 ]
[.36761 -0.0125 9 0 ]
[.54181 -0.0125 -9 -9 ]
[.54181 -0.0125 9 0 ]
[.716 -0.0125 -9 -9 ]
[.716 -0.0125 9 0 ]
[.89019 -0.0125 -9 -9 ]
[.89019 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01784 -6 -4.5 ]
[-0.0125 .01784 0 4.5 ]
[-0.0125 .19203 -18 -4.5 ]
[-0.0125 .19203 0 4.5 ]
[-0.0125 .36622 -18 -4.5 ]
[-0.0125 .36622 0 4.5 ]
[-0.0125 .54041 -18 -4.5 ]
[-0.0125 .54041 0 4.5 ]
[-0.0125 .7146 -18 -4.5 ]
[-0.0125 .7146 0 4.5 ]
[-0.0125 .8888 -18 -4.5 ]
[-0.0125 .8888 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .92754 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .92754 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.19342 0 m
.19342 .00625 L
s
[(100)] .19342 -0.0125 0 1 Mshowa
.36761 0 m
.36761 .00625 L
s
[(200)] .36761 -0.0125 0 1 Mshowa
.54181 0 m
.54181 .00625 L
s
[(300)] .54181 -0.0125 0 1 Mshowa
.716 0 m
.716 .00625 L
s
[(400)] .716 -0.0125 0 1 Mshowa
.89019 0 m
.89019 .00625 L
s
[(500)] .89019 -0.0125 0 1 Mshowa
.125 Mabswid
.05407 0 m
.05407 .00375 L
s
.08891 0 m
.08891 .00375 L
s
.12375 0 m
.12375 .00375 L
s
.15858 0 m
.15858 .00375 L
s
.22826 0 m
.22826 .00375 L
s
.2631 0 m
.2631 .00375 L
s
.29794 0 m
.29794 .00375 L
s
.33278 0 m
.33278 .00375 L
s
.40245 0 m
.40245 .00375 L
s
.43729 0 m
.43729 .00375 L
s
.47213 0 m
.47213 .00375 L
s
.50697 0 m
.50697 .00375 L
s
.57664 0 m
.57664 .00375 L
s
.61148 0 m
.61148 .00375 L
s
.64632 0 m
.64632 .00375 L
s
.68116 0 m
.68116 .00375 L
s
.75084 0 m
.75084 .00375 L
s
.78567 0 m
.78567 .00375 L
s
.82051 0 m
.82051 .00375 L
s
.85535 0 m
.85535 .00375 L
s
.92503 0 m
.92503 .00375 L
s
.95987 0 m
.95987 .00375 L
s
.9947 0 m
.9947 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01784 m
.00625 .01784 L
s
[(0)] -0.0125 .01784 1 0 Mshowa
0 .19203 m
.00625 .19203 L
s
[(100)] -0.0125 .19203 1 0 Mshowa
0 .36622 m
.00625 .36622 L
s
[(200)] -0.0125 .36622 1 0 Mshowa
0 .54041 m
.00625 .54041 L
s
[(300)] -0.0125 .54041 1 0 Mshowa
0 .7146 m
.00625 .7146 L
s
[(400)] -0.0125 .7146 1 0 Mshowa
0 .8888 m
.00625 .8888 L
s
[(500)] -0.0125 .8888 1 0 Mshowa
.125 Mabswid
0 .05268 m
.00375 .05268 L
s
0 .08751 m
.00375 .08751 L
s
0 .12235 m
.00375 .12235 L
s
0 .15719 m
.00375 .15719 L
s
0 .22687 m
.00375 .22687 L
s
0 .26171 m
.00375 .26171 L
s
0 .29654 m
.00375 .29654 L
s
0 .33138 m
.00375 .33138 L
s
0 .40106 m
.00375 .40106 L
s
0 .4359 m
.00375 .4359 L
s
0 .47074 m
.00375 .47074 L
s
0 .50557 m
.00375 .50557 L
s
0 .57525 m
.00375 .57525 L
s
0 .61009 m
.00375 .61009 L
s
0 .64493 m
.00375 .64493 L
s
0 .67977 m
.00375 .67977 L
s
0 .74944 m
.00375 .74944 L
s
0 .78428 m
.00375 .78428 L
s
0 .81912 m
.00375 .81912 L
s
0 .85396 m
.00375 .85396 L
s
0 .92363 m
.00375 .92363 L
s
.25 Mabswid
0 0 m
0 .92754 L
s
.01923 .92129 m
.01923 .92754 L
s
.19342 .92129 m
.19342 .92754 L
s
.36761 .92129 m
.36761 .92754 L
s
.54181 .92129 m
.54181 .92754 L
s
.716 .92129 m
.716 .92754 L
s
.89019 .92129 m
.89019 .92754 L
s
.125 Mabswid
.05407 .92379 m
.05407 .92754 L
s
.08891 .92379 m
.08891 .92754 L
s
.12375 .92379 m
.12375 .92754 L
s
.15858 .92379 m
.15858 .92754 L
s
.22826 .92379 m
.22826 .92754 L
s
.2631 .92379 m
.2631 .92754 L
s
.29794 .92379 m
.29794 .92754 L
s
.33278 .92379 m
.33278 .92754 L
s
.40245 .92379 m
.40245 .92754 L
s
.43729 .92379 m
.43729 .92754 L
s
.47213 .92379 m
.47213 .92754 L
s
.50697 .92379 m
.50697 .92754 L
s
.57664 .92379 m
.57664 .92754 L
s
.61148 .92379 m
.61148 .92754 L
s
.64632 .92379 m
.64632 .92754 L
s
.68116 .92379 m
.68116 .92754 L
s
.75084 .92379 m
.75084 .92754 L
s
.78567 .92379 m
.78567 .92754 L
s
.82051 .92379 m
.82051 .92754 L
s
.85535 .92379 m
.85535 .92754 L
s
.92503 .92379 m
.92503 .92754 L
s
.95987 .92379 m
.95987 .92754 L
s
.9947 .92379 m
.9947 .92754 L
s
.25 Mabswid
0 .92754 m
1 .92754 L
s
.99375 .01784 m
1 .01784 L
s
.99375 .19203 m
1 .19203 L
s
.99375 .36622 m
1 .36622 L
s
.99375 .54041 m
1 .54041 L
s
.99375 .7146 m
1 .7146 L
s
.99375 .8888 m
1 .8888 L
s
.125 Mabswid
.99625 .05268 m
1 .05268 L
s
.99625 .08751 m
1 .08751 L
s
.99625 .12235 m
1 .12235 L
s
.99625 .15719 m
1 .15719 L
s
.99625 .22687 m
1 .22687 L
s
.99625 .26171 m
1 .26171 L
s
.99625 .29654 m
1 .29654 L
s
.99625 .33138 m
1 .33138 L
s
.99625 .40106 m
1 .40106 L
s
.99625 .4359 m
1 .4359 L
s
.99625 .47074 m
1 .47074 L
s
.99625 .50557 m
1 .50557 L
s
.99625 .57525 m
1 .57525 L
s
.99625 .61009 m
1 .61009 L
s
.99625 .64493 m
1 .64493 L
s
.99625 .67977 m
1 .67977 L
s
.99625 .74944 m
1 .74944 L
s
.99625 .78428 m
1 .78428 L
s
.99625 .81912 m
1 .81912 L
s
.99625 .85396 m
1 .85396 L
s
.99625 .92363 m
1 .92363 L
s
.25 Mabswid
1 0 m
1 .92754 L
s
0 0 m
1 0 L
1 .92754 L
0 .92754 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01784 translate
.96154 .89186 scale
552 string
552 512 8 [552 0 0 512 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
AE544C52525352565050564E565652505851565550545850545850585655585452585658
5B5858565956585651585560595D5659535653615D555B5A565A5C575756585B555D5555
525B5B5E58585654585958595A56565D5358545B57605C62585F5E59595B59615E616365
5C5E5F63636061595E5D5E5C5B56605E5C5D5E5D61635C5B605D5A575C5B5C5D5D615E5B
5E5C5E61635E5E5B64665B5B5E5A676258616461636463605C5D6061605D636461635965
645D5E605D5F615C5E636864606C626168636665606464616869696170656E66696B6061
6B6E69606B6B6F686768686A6D6C6C6E6A6868696C636A6C6A6B68746F6E6C636C68726C
696C726F76736E7775757372716B69706E72737073706C7076686C70736A706E6E666870
7A6C6E736B716F6B66686F6C6C6B6C6F6E686F71766B6C706E6C656B6E6B6E6A6662696B
736E6A616A71696863696369676D726E666A68656167636566676D6B6166636B66656768
6E64686C696B6B6D6961666C676F6C60606166636664636360625E606164615D6164645C
5E58615C595D60605B5D625F595C5F5B585B5E61605B5E546060585C535D545B5D605B54
595A50595952534E505752515B545E515654535852515452545453585D5B615459515A4D
5956565359595458515653545052544A585C575759515651535151545756565051505154
59534C55545351AC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
BC534F5557525D585456565456565A5E5B5E5B565A575A5E585E5A5C595C5E565859595A
5954595C6159585B5E5F5D5A615B5A61626661615D5B5E605F6161625F5C5E5E5C605E5E
61545E5C595C605D5C59625C58625C5E5C5D675C5E5E625C66605E655E60606863616464
636361615B5F5E696768656860665D60675F626A676A625B66675C616466616365655B60
64665C67606466635E61626B6061646969616764636463666463675D666766616E676868
6A6765636865646A6868666A666D65666B6B686A6969666C70696E6E6B7070706E716B70
6B6D68716D706A6E6F706A72716D7073716E706C717271766F757970797173756C717474
76726F7371777B797F767D747974747C7C7375787376717D737674787A716E6D74766F76
7176706E6F6D6974716A7073717E6C76736E7671707675707B76756D71766F6F766E6B72
7072696D6E6B6F6C6F6F6B6A71686C6C6D6F72686C686D686E6C6B706B67716D6B646D66
6868726B716E6D756D6E666C6666656665626361646B6468626464656966616A686B5C68
5F5B64615B6063636A635D5B645F6459646260635E5D63666265636463636061595B5764
595C5C5A545258565158565D5B59615A5C584E5B595556515C56585A60625E5E58515460
5754565C5855565F595E5359545A5858545B53585957565C5B5B50585056535751565052
574C595B584F58B400000000000000000000000000000000000000000000000000000000
000000000000000000000000
C15A5E5B63615C5C556055565C5F5B595B5B5D5E5D615C60626066606062625E5B5F6461
5D64605E5A60605F5B615B595E6763605F5E60605F68635E63625E66676261595D5C6159
685F5E64686060616161645C656160646A6766655C6469625E6265656A63616C68666969
686761696866646960676B6666686960676961666B635F66676868706168676963605F62
676663636D6170636C6A66646C6D686B6D6E6C6C656D6E636E6068696C6E6C6A7164686F
6D6B69636E6F686C69686D6C6B687169706F6C716C6B6B6E726D7172737871776D797570
717376717071706C6C747973757174757872787B7B756977767174797B747D7B6D777974
7578717C7C737C7B807E7C7C7B7C7D757D7A7A7878787A7A6D7479807B797B797A74777A
7378757C78797174747466787979747F767B75767775777B7B786E767B76747C70747776
6C6F79726E736D776F7674727176736E746E7169736D7474746A707070716A6E66736E6F
736C7073787375747168706E716B696D6A6869706D696D6C68626E6166646B6966676764
666666656A65646B646768695E6469606064645E646168625E666165635C5F5E65625F5E
5E5D605B5C5A585C5E62605B5E575C5C5C5D555E6362605D5B616365645F6162605B595E
58605E5A5E5D605961595C605A5A5653605E5C605855545C5B53565C595A56505554525E
5C5C595E5A595AB600000000000000000000000000000000000000000000000000000000
000000000000000000000000
C953565C595E5963615B5F645159615C5A5C615D5F5E6062606861635D6661645E635F5F
606061635C6064646760606362655E626161656D6968616863636363695E6B6569656260
64606A635E636866645E616266666D646761686E6666616C6F6265696C64666C6B6C6871
716B61686C69696B6D6A666C6B6C6E6E6B6968666E646C6B666361606963606068686C68
686F6669697064666B7066666E71696B716E76736E676E656A64706E646D716C6A6D716E
736D6A716C6E6C6B716B706D6C726F7173716E767174706E77716D6F7775777078757174
796F707079747570777977737875746E7977737978717E797E7D79786F7D79737D7C7C78
777D7F827B8680817A837B7F847C717E78767C7C77787B767F7B767A787D797978767971
77777D717C727975767B73787A797C7B808376807B797F7573727D7E7A76727B78757B7A
7B72727178747976797270737474786E716B6D7079766E79747873736E77717170787372
746F67787074716E6C746D736E6A6E6E6E6C726F6C6B706B6C646C6764706B6B6C736564
6869686568656B65606569696B626968666C63646861645E64606766606E67696C676567
5961585E5D585A645D64646666676662655F5B5E555561595E5963635F645B645C605A59
605D5F5C625F595C586162615E60605D605E56595C5B605C535357565B595E60605C5C59
5E5E5856585558BA00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D3625F5E6060606059636064686463615B646460636360645C5E6D6865685B6161686568
6263686364646866616761636E676C686768666961676669636D69686661686660636C60
64626364666366656065607068686566696F706E696E6A696366687067686B6E6C716C67
6E6C686B676C71636B6667696B716B6B706D736E706B6D6D686A69686C696B6C68696570
6B686C6E696D6A6C666A6B696B6B6E6D7371707571736B6B6F726B6E6E7271726B76756E
7376756C6F6B6C76737071736F6970726B6F7976707873716C7A7C7476746F717178787B
7773777678787B7E7A7678707F767579787C7C7B7A767C78737C7F7B7B79777F7879807B
787B7A7880807C7B84787983797C8174837D78797A83767B827C837D7B767F7C7B7A787B
7474797C797C7B7D7679827D78817683807C817D7B7C7E787879797F787578787E767879
787870787776757174787276787A7970747374757078757B767372737379737677786E76
6D737079717678746D6E716E736E69686D74716F6B68696E6B6E726A6C6A75646E65706C
6866706867686B6D68666A686B6C64636868666968656464686564616B68696469645F68
64615F625B5D655B6764686465605E605D60605A5D5856535E646B5E5E6363645E5C5A68
5F5F635B64605B5C65635D5E5A5C5F5E5A5D5A59615D555C60545C625C555B636064585A
645E5D595B5657B900000000000000000000000000000000000000000000000000000000
000000000000000000000000
C86361605E645C65636165666463696363605F6B6363645C636E69646D69696266666460
69706067666C5E68646A656863666666706164626069686366616A666A6C6569606B616B
62686669686C686B67706E6A6C66696C686B5E646C7067636C7064666E6870646B736C73
676C71696B706C7071666C66666A6E776E726B696C6E6A67716D69696A6B716E71616D69
6C6C706E6E6E696E6969706C6E6B706E6E6F716972696B6E65696E687173707070747671
6E7374707272756970707171747973737473737A7674757A73797B7975737A7976787C7E
747B797C777A6F74797C79737D7578787B807A8480787E7E7C78857384797B7778807B87
7C8080837D8180807C8083897F7D7C7C7879817E7E818378868188797E7F7C81837E7C7C
7F818282807C7B7E7C7D7B7B7C7E7D8180807C7B827979787C7C7F817C7A817A7B7D7B76
7C7878787C6B7974767C7B78717879737879777A767B6E756E78796E71787375716E7877
7B7875766F70737070797870746F6D716B6B6974706F756C6B6C70746F7368706C686E6E
68726C6B6569676868706B6A666E666E60686D6561696A6E646B686C6A616760636B636B
66625E605C685C646863636660616560605B5F5B5D61585E5F61615E6C61665F60656662
606160605D5D67585B615E635E5E565C64615E68615C595E5B5B595E635E5E5D5A595B58
6360545A5E595ABF00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D6666368635E6461615E6461686266636761606B5C64625E666B666C66696B68636B6964
6763646865656666666568646C68646A6C68696965686166676866686B71666B676D6269
666A686960686B6369686667696C686B62666B636D69696C6E6E6B6C686E706871726C6A
6C6E6C6F706A6C71686870706C73636A6D6F726E6B6D6D6769726D6B656D6D7565716E6B
716E6C68666E6E666E6A6C686E6E6E76706D6E6C76706D6E717070736C707676726E7171
717376717B787277707B76736B727472747575727F777776737478787076787B737E7878
7C78767D85728079777B7F787A7B7B7881817B837C827A807E7F7B7C7C807F77847D8080
7E7C7B7F7C817D837A837B828182857E81837A85807A7D86858181817E84807A817C7E7B
7B7383787C807C7E7C7D7E7C7E797E837D80757680827B7C7D807C75747E797F837E7D7C
807E767D7A787E78767874797D6E7C797A78757378737A71737177717476797C7A717378
7B777C737B767574737277717073706E706D6E706E6B6E71707770716E6E706D726F6C68
6E6F6C64706F706F666F66766C6D6669696B686A726A666B6A6863676D61666B69646666
615E615B625C635E636C636F615D615E5B61675B6059595D596164635F68665E60626660
5E66605C5D5F636061665C6B595E5A615E5C5F5B61585B615D5B5E565C59575A5A605E5D
655758545E5A5BC300000000000000000000000000000000000000000000000000000000
000000000000000000000000
D065696060615B6863606B695E666064646662606566636A6967696A6A6767646763636A
6C6C666B666368666B66666767646D64696964646C6669686D6B5F665D6663636C636460
66666A68676863696C69676B6A6B6B6C6B6E6C67666D766A6E6B6F74666B6E72716C6F74
70666B6F6D6D6E716F726F6B6C6D65736E6B6B706C6F74706E746F6D6B6D6E6A736E6F6F
706F706E6C6E6E706974727077756F6F7771716F706C6B786B71756F726E6D74756F7779
736F76707373777875777978797B787C6F7679797679787E7D797B797C767B797B757377
787A79707E737C7E7980737B7E7B81837E7F78807E7B7E818384778583817B7E807A8186
80838584848386807A848583818986817E83857F8487898B8884808385878184817A8276
827F7E807F7C78807B7D807E7E837D7E7C807A7C777E81747F797E7678837E808A81837B
817E797B737D74757479747A777873767C7B787C7A7E757B7A7976767570777371777273
7174716F766D6F787274717D7071737C70747B7174767A6C706C706E736C76716E6C6E77
71676E6F71706B6B6C6E7471706E6E626768696668666B6B69686C6E6469696468696965
635E64645B616167625D6463636760606268605B5E636260655E5F6167635B685A636663
5D5E5E5D6366616560696665655B5C5A626560595B605F62645B605F5B61605F585E6159
5C5760585C5A53C400000000000000000000000000000000000000000000000000000000
000000000000000000000000
D56460676B645E6862616960656B5C695B62665C616769666466656B6C636C6961656464
65676B6663666C6C67686768666B656A666A656E7167656A6466666868666263686E6462
6A65676966666D696A6969696C6B6F6C6A68676C6971686D63686A636F716F6B6B6C6B6D
68736D6D69706C6F6B697170706F6870746969746C6D6C70686D766B686F7B6F6C6D7269
746C6E6C6E6C7674696B6C70766E6D73687476706F7673737B736E706C72756D76737273
727471717870786E7574737B75737C717C737A78737C7272787677817975777C7E78787B
717979797678787C7377817F7C81807C76767D7F867F8281787C7F867A7E707E87817E81
81817B7D837C7C8B7A8984837C80848483847D7E81767E7F838786817D808880867C7E82
837675807E7C7F8374827A847F8278787D79817B79767F83807B80787D82847F7F868281
7F807D787477767781767F7B7C767B7A7C7F74797E777578747B7079707D777C777A7376
7376747079737072716E717376726F7279746F7072746B76716B726B7873716C696E6D6F
6C72716C6F6B6E6F6B6A6E6B696D6B6B6A6B66786868646E716B6665666C6C61686D6B61
6E646068605E6B6567636766635F656964606359615C616163646166666464645E636163
665F645E5E5F67616460636358645E625962595C615F616061635E5F62605B545B615B5C
5661585961645CC500000000000000000000000000000000000000000000000000000000
000000000000000000000000
DC676561616A63616465605E6665666B656C666466606D686B676E666765696F686A6468
68636664626A68686C706D64626D6B69656F6E6B67666766666566686867696D68696969
64616B6E666C6B6669696269696969736C6C6C67666C686F706E6C6B73656B66686B686E
6F677371746C746C68696C716C706D6C6B73686C6C766E747C706C726E74636C706A6B74
7370786E70726F766E71706F6D6E7373746D746D6F6E72736F737274707A6D6B75747574
77747876756F7479777E78767176747277807B7D70777A7E7E777C7C7B7C787C727E7C7D
76796E807A857E76847B7683787A79807D827C8079837D817B84817E7C8179837D7E7E86
7A83808484798484818B828686847D847F888382837D8683808182817D807B83867A8080
8083887778807B817B837E8384827B7C777C7D7879797F7E7981837D7C84818382847E85
857A7C75767E7D7B797C7B787C797A767379817B7975727A7779767876787B7D76707874
757774737371807B7B7876737476746A7478746E7370747076736C6B6C70746D77726E6E
6E716D6B716F736E747173716E716C7164636E666B666C6969687069696E6869666C6869
666360645E615C60606761646568616068625D62615E606266646360635E6461605B6069
5C5F646068675C6466646269615C5C626D6C615C605B5B5959625B5E5E616156575C5C5B
5C595D615A5F60C700000000000000000000000000000000000000000000000000000000
000000000000000000000000
DB636662626A675F696564646960615E655C5E64636B68616666666B64696661695E6664
68616A6667686B6A676B66646E696069616566656B67606164666E697069686664706968
6164616B68696964666C6766696B6B69716E6A6E696B6D74696770726C696A6A69666B6D
65726E706C6E6B6F69736C6D756F6C6A6E686E696D716E676C746E71736C6D6F68717072
6D716E746C716C716F737374736A6E7474787C7676706E706B707577737979717D687078
7C7376737B74737574767A7C7578797A797479767E787C7B767D7A7981777B7C79757A78
777C7A7E7B7B8380708376757B7C837E7A827E7B7E847E7A84827B7E817E827C81807583
808083877C86848081867C787B7C7E7B817E858480857C7B7B8580838480868380828286
7D80817E82817D817C8184827C797D818083847B73787583887C7D7C7C878483817F847F
817C798379768384797C77717F797D747C797A7C7B7F7578767C73737D79787B71757C7B
7375717073716E7977727573747372716B76776B7467717369696C6D6E7070706E6E7176
7273696B6E696E737362736E6E656C736868656C6A6F6E6E6C686869696C70666E635E66
6665675E6063645E6063646461606360635D65635C685E5E615E65696366646360656662
636262605C675E5E5F5960605F5B616462645C6161636160615D5B5C60575A58615A5A5B
5B6258595D565ABB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
DB5F635C6266606162636966635F646766666A646068686966676A6C6163666E66676969
66666B6567696A6B696A6468666A636E68646A666164656A646869666865676864636A6D
616C676C6969656D696B716B666E6E6B6A6A6D64646E6B68706E66726F6968646872656E
6C6C6D696B716F6E786D6B6A7270736C736E6B6B6D6C7670776E717668717373676E696B
6E6973697170776B72736C6A726E726E7370717078716B70747B746E6A6C7574736E7974
747476757573747876737C716E757179746E7B7B777B707A7D7278797B75797379798077
757B7F827E797A7E787678817B7F7E84858476847C7D837B7B817E887F80817C82808880
8183807E888588897C82817C8181807F8480837F7A7D8A838486818084838581817D8383
7980787B807E777A8783837B7E7E80817E7E8179847B848983817D7B7E7C818480857D82
7C7E797A7D7D71797D7B747A797B80787C7C797E7E7875797C787A797679747678777774
7E73717B767074766E797074736F71716C6B746A696E6A6E706E6A6B7669717A736E7270
73796C67737070756A6C726F686E69666468696972716A6C6866686B6B6E69696B676E67
6B676163635D5E6867665B676968665F635A61615C5C635E615F69636063656464615F5F
6D5F5E66655C63655E5E64605E60665B6053625C655E5E5F5F605B5860605D5E5C605C5C
5961635E595F5EBC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D36263626467595E616B69686F646366656467636F646164656B6E646B63676966646673
686A6568686B6A6667616B6A6B606B646666606C68636869696868696D64686B6C686766
6A68696C686C646863706E6D6B70616673696F66646F6B6168636C6B6B6E736C6E6E6A71
696B6C6F6970666B6E726B67706C6E6D736B74736E726A6B707270747475717C6A70686F
74736B77797076746F6D706F71737476787574736E7079746C7B7271747C6C6E797A7975
797873767679787F7A7D817672787B7C76737C787A7876797B797C7C7C7E7B7E7D7C7782
79787B797C7D7E777E8182808380837C7C7B8181897C8587798C897B837C858681838788
767B7C7B8980817F7E7E868C837E7C7A7B7B7E83878086838B7C8985838A86877D83807D
8383817D81828783887A7E8380867D7B818180867C8182807C8080877B84837F81887E7C
787C817F7E7A77777483797779797E7D79767B777F787E7D7E7B7C7E7277787870747A72
7B7E777274707B797474716B78707E716E6C6C726D686B6B676E6C6C6F746F786B6E6E75
716F6A6D6B6D7071767468666C63706E69686C6A696C696D686B6368676B666362686B6B
61665E635F5F5C5E5C62616362636664625F5D59615E645E6061636A60616B6368616466
5E5F6461615E6469615C635E60635F5C595C595F5D5E5B5D5C5F5E5F585E66605C5E5E61
63605B5E645F59C900000000000000000000000000000000000000000000000000000000
000000000000000000000000
E3645B6361666663666362666160696B64635D62665E686E67676B686761666766636962
666B68646966656E69686A69636A63686966666A6E625E69646B66686970606768636E6B
65636B6666686A6A686A69636A6A766E66656F6C736E7069666E6E726567686E71716E70
7070706C676A76716E6E6D736A6D6F6D6F6E696A706E71756C6E6F76727269747272706E
6D72717273717374716F70716C7576707377716C757971767A706973707A76786F727879
747879737678767B7982787E80797B777C7C797881837685888077817E83847D77797D78
7B807B787C75817975817683837D7B83817C807F7A7F82817E83887B817F818380848483
84868283797F7D8B84888089837E808088847B817F8383867D83867F7B84868085827E80
7E82828387847F84818081847C8681827E7B807B88888B7F7A7C7D7F847F837D7E7D7C80
7B787B797C797F7E7B767B767B7876767B7B727C7680767E7C7975777374787B7877777C
757578776F7273736F7774796D767073717876746E746D6D6F696D6D6C6C686D73706C6F
70676B6D696C6975696E6C686B6F68646F6F6265716B6C686B69646D6B626970676B6867
616466676461615E6066676263635D5E596464606263615F5F6461655C616B695D646963
635E5E5E655E5A5D6759606060685C645E5D60635E6064565B5C56605B605D635D575B58
605C5B5E625D5BBC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D3625F67635966646063695F62616C63666B6364646467656164666E6864636B6B66636B
67616363626E6F666B686166646967696064636B5F6B6569696767656B6B60686A645E61
626C6B6B62676B6B60646B6E70696A6C6B6B706D686D6E6370716C706C6D736870696F70
6B6D72736E686A6E70666D6F7073707876696C6B697679697373766E70717773746F7870
7174747874707371756E77757476756E726D747E78797368737376717D6E757870757276
7174797480767C7679737A757C758080747A70807B788073777C7C7A797779857C7C737A
7C79877C8076767F807D7D797B7C7C7B7E777A81827E80848383838386817E7D837B807A
858583897B848184868387818284848C837F8686888A8A818984868780867E818480837E
8680867C8286887C80798781818089897F7E8983817F837B7E7F817E7E7B867B827D817E
7E7F7C83807E7A817C867E8276787B7B7A797B7C7D7B797B7B767C7B7B847F776B7E797E
7E797B787B7972787578756C776E7B75726E6E6A74717271786872676D6D73697273716F
6571746E6B6E6B716E6E696B6D68696B696C6D6B6D6B6C6E6B686C686B67666B63666666
6962686C6267616163675D6466615B6163636664625F685B6865645F6664666E63636467
61616061656261645D6661625D61656155606465615B645E635C6958605D5B5D615B5C63
595E5F6160564DBA00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E2666156666964615E6666625F6969686A5C60646B686461696969696A6569686B5E6865
636362695E6469656265686C6A6463646368655F646970656364646A6461686B62666268
6464696D6B65656A63606B68686A6A716B697368696F68666C696E65716E696C6A706A6A
7068766A6F726E6E6F706F6D6E6A636D71706C6E6E716B746C6F6B717064726D716C7376
70716E6B7073777878716E76727176767A6E756C767075726F7672727C7974757875767C
73797471727C7672847E7A817F72787683798178727777767475787B7B797B837B7C8081
8175857E7A7B7E7C7C7B7C7A7D79808684888087817E898483807E797C7E837B83867987
86847B8083827F7B84808489817F7A8C7D8C7F848489898C7C8E88897E80827F80848383
848383868B887E808083887E89848181818B7E7A7B8380887F7F80838788817D7D847980
7C85847E7482867980857A7A7D7C807E747B7178767B7E79797B78747B777C7980797A73
757B737C786F7C74757B73726F71756E746B7078707073706B716F6D7373716B696E7073
6B716B6B68666E68726C6B6E686A6C6B6A64656E676C6B6E6C6E6B6B6C6C696D6E687161
6B686566675F6162645F6166686863655E63645B646B6864596461665E6164696661635B
685C64615E666462645E5D5E61635C5E5D66635F615A63595D615E595D5D59585D605C5F
606059625E5A5BAC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
C9665C67616163645E6766676269626166636066646E6166696569696166686460656D65
64646469666868616B6660666C6F65636C686661696261656860616367636C6C66636867
606466626B706B686963696A676E69646570666468666B6B6364736D706C6E6E6B6C706E
686C686E696C666C6A6F6D6D6870666D717168767670756D77716E7070797869746F6E73
6A736E746E756F796C726D73697A70717676757C747470777579716F736E767A75757A76
7C7C78737B7483787A6E797B797C777D7A7B767B7B817C7E7C817B7B77777E80797B7B7A
7979807D817B797875777D817881807C7F818484807C8479868080827C828380847E7C7C
7F858287808683828683888484848B84808C838B828683858884807C838183857C878187
81837C888480868381817E7D8486877D8382808A83807B7C8680847E84808184827B8379
7C79807C7B8280797B787D807E73807B767D7F7B787B797B7276767476707F776F727778
797474717273766D7871797870736D6E70746F70736D796E70696E656D6B6B6E6D79726E
7370666C6E736C6B6871666E73666D6A6E696C716C686866686769636963697166656867
6A6963686665676B636061606062605C605B606264636764646D666360616060605E5E61
635D5C5C61636163605E5F635E61615D5E616458615C615C5E605E5E60615462595E625A
635F5E5C5B5858BA00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D461636A675D6966656666616760626463686360656664656B696E636566666665676460
6764656868606E6B676B6668686B6069636664636664686567625E685B61616661676166
61676666676969646B71696C6868676F69716872706A686C726B686E6F6E6E666E706873
6C716C6F706E6C716B72706C6D7872737174696C6B706D726F756D71707471776E737778
6E7478717170716F6D7C737A7B6E7176736B6D7A797475707576797C7979708078807570
7C79797874798278797378757C7677787B717B7981797C78817C7A817D797B7B7E7E7A7B
7C7B7E827C797A78837E8181807F7E7C7E8180848885837F8081837C8385897B7D838A85
897B807E89877D86818A8485828483888783838382858F8E8481838E898684837E8B8186
85848B868A7D8487808080887E858A8786838B817C82837C80808383807E80877E858A7E
8486817D787B737C8077767C7878767C7E7C78767C7C7B78767C7E78737681787E7F7C7F
767877747B74797473747B6F7478717470706F6C74716E766E716B73686A6C696F6B666D
6B736B6E716A6871697072657470666C6F6D697076656A646C6A666A60686B646A686B64
67686A636862646B6665676662637060635C60655C5E6663606A69646760665C675F6458
5E646560695B5E5E5C64625F55605B6163635C656158615D665E5C635A5E605C61625A65
5D65625A5E5454B900000000000000000000000000000000000000000000000000000000
000000000000000000000000
D064616268656B696068616266696C636466656366636868636669686C626A6669696864
60696867646A646869636067696464636B6067646264605E675863656460615D66686963
685E5F696C686768736B71646A63676C6A69706D706E6D666F6C6E786A6C6C6C6C736B69
66716B686C6D756A6E6B6C7070697476747B71796F77716875766D7366726F72716D6F78
76747368706F72767075717468717B76707979717576767A797477787678797280787D79
81797472787A78767679757876757B7B7A817673757B7A837E777C7E7A7C837C787A7E7E
7B7F83807E7F837E8481857B797C8086847E857C81848880887E8781828B7E788184867C
84848A808184847D8489838488848081888387848980888188897E8189867E8083868683
8689888886838B807A7E808B87868B8881867E8183837E837C7A847E8C7E81847F7B7B7E
8380838183817F7F7C7B7C797A7980757B7B7B7D8579757380797479737876787676767C
7171777679747578707B716E7372746D7173716E716B6D68737176616A706C686864716D
68686F72696B6D6E71727370716B6B6F6B6E6E6C6B6C6F64686D696E686E6D696B686C63
6A626066636B6767636066686065626767665E615D6460636368605C5B6660625E646663
615B63636866645E62596661625C645E615C62605E685B5F5D61535E5C5F5C605F615E5D
59605E5E545B56AF00000000000000000000000000000000000000000000000000000000
000000000000000000000000
DE6066616664666062696B5D606467635E66676967666D61646563696466696661656061
676166656567606F6960686B69646B6C6864615E645E62646661615E5F6A646360616366
69666B6B636A63636C70606665676F6A67616C716D6D696B6C64686A6C6C6C6D7074736B
6E736B686A6A6E766D6C6B6E6D7472756F7070787371726F6E6C766B717171706B707274
7373787173727171707E7670746A6F746F717673767C787479717B757B79708073777874
7677777978797A7C74767C797A7B7D7F7F7A797B7B787F7D77847D777C807E797B7D7D7E
79797E7F78847B747B767C7E828182817C8388808280877D838981818B8781878B818487
7E8A7C8180898E86818B84857E88888589808C8481838986828483818483838D7D818689
847C89838284867D887F8086878288848584898084837D84807C82817D80837C7B7F8188
8483817B7F7E797B7B7B757A8076777E7C73787C8081807B8278807E7F7C7C7B6D737B79
767C7878797D787A7C72706E707773716B7178796B727170676D716E67696E696073736E
73706B706E6B6E6C736C73696E6E68726A6773706B6C6E6C6B68696A646065666B6F6867
6A6869676B686867616463616362666660675D5F60606B636161676B5D64616263676061
5D625F646963665F635E6B66645C5C606065596060616460606154605E5C5F59595E5C61
635B5D5C5F5653AE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D4636764646365646169695C636668646C66616063606A696366635B6168636469666369
6366667069656F68626B676B6C685F606461605C625E636366646761675F656766646166
6860666568696468666B6D6B646C69696B6B6E6D6B6C64676E6C696D6F706B68706D6866
726F766C6B746E66716C696970796E7872726C707170736D6F736D74757172716B6E6F71
6A7179767875707A786E787777767174797D786F77797C6F767C797B717971747F797A78
7079807D7F7479737A8078797A7C837B7F807D717483837E74817C818079817F79768173
817B7B807F83838182797E807E8080808387838883868483837F7F818784817F81858383
7B84888689858C84888486848686808E877C8184868A8588878C868C86808B868C818C82
7C84848483888686868688838283898689808C817E88848383828B7A847D7F8283828878
827D7E7F7F7E80807C7E73757E7D787F7E7681747A797D787E7776807C7B7A7C73717179
797976767979777873747B716E70747077747371736F737677746F67696B716A6B6C686C
747371726E717368687472737276717267696B69676C6C68666B6B6569666868676C6868
6A6B6464686572676066616468616666636166625F6064686666616063635E6564626266
62655F5F625C6064615C5D616461605E5E65615F605B61615D615E6161605E61645C5F60
66625E5B5B5B55B700000000000000000000000000000000000000000000000000000000
000000000000000000000000
D85E666766615B6864635E5F5E646061695D6C66635C62636666666E6B60646A6C696168
5F6661656166616860686B686A62626A5B6163606359645E5C60696C606466626564646D
665F61635E64696A666E6B6961686E696B6B686C6A676D6968736F67736770656C736A69
6F6C6F746E6F7374667471716969706C6F716B706E73717273707872766B686B746F7274
72716B717873767875757678767874787372707A717A75707879787679787E747876767D
757A7C7B7B79767D767B817688847A8181877E7B867B7B7C817E7A827E847E7D787D7580
7C837B7D76807E837D7E7D81887E817C7E8083867B83858984867F7F87828C8382848480
868388858883828980898682838C82808E7E88848B838B8089868083818B7F8485888C80
7E7E81887B7E8681857C86817E88838383827F8783867C8483817C85818384848481837E
8484807F817F7B7F817E7B7C7B747A787E7C7C7E8082777B807A797C747F7876797B7876
78757B78787971757A746E6C72706E6E686D726E78717371696E6F6F6D67646869636B6B
7476746E6E60566F696E736D796E70726F6E686C676B6D686870666B686C6D5C69646961
67656C685C68646760686668606A616A616060656067656060686460645F606B60635D64
636466625B5E5C605E5C5D5B5E5F606366605E5C606163605D5D615C5E625D6460595B62
605F6060575A51B300000000000000000000000000000000000000000000000000000000
000000000000000000000000
CF6164645F696667646B6066656663616E6A646665696266646461646A645F5C6163686C
5D6C6C6861686968676C606468635E625E5E5B5C60585B606260615F645F637169686665
6368676562646764656C6E676B6E686B696C686C6D6D6B686C6B7373736C71716D6D6C64
6D736A6A71686B68736C70696F6C727076716E6870726D7074796C7875746D7774767470
72746B6F777974706D75797978797B756F797076767B797975777B7D79817B807C7B797C
7E7A73787F7C797C7D747B817E7B75817D807E7E7C807B737D8081787A798078807F7C89
74817D8080838080797E877E80847D7D7D86888681848683878186878888808384897980
89837D868C8C8A8790838881868A8387838986838586858688817D8187847D838B848388
8981818681848B868189888B8F8C8C81837F84847E84838684838483837B838784848081
817F7F787881887C8486797B807B7B7C7E7D7E7C787278727A79787784807C78767E7E7E
73747B7B7878797981797B73786C6F6E7164686C6975766E716A73696769626869697069
707070716E686B6D6E6E7073746B6E67697070686E6C69706770686B6F656B696667696E
6A6469625F696967646B69666B615C6A645D646068646364646C6663666164666469695F
605E5C635F5B60605E66656365615C5E63616158615B5F5C65615B5B6066615E65635C61
59625E5C595657BB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D064615F6B63606266666567646E6661686B6961625C6461646766636168636C6A616565
66646C63696B6664656961625E62605E58615B645F5D605C5C6165606B64606163636469
616265636662685D6C6A6C6367696966666965696C73656870626B69726F6F74696E6D6B
6C736C65756F6F68717076707372737071706D777075717473766E7379707A777571746D
6E7173736E7B7C777B79707071747178757C78747779777272797E7880807C7980797C80
777C7C7E777A7E7B77768081877E7C83787C7F8084787C7D7B7E7E837E7F7E7E7E817E81
7B7C7F7980838286847C7E76827B818E818A8887847C868582848A8388838489846E7E79
81838386818486827F8883848681818D868E8B8A888D898B898B8B838F8583898A848382
828188848388848986818686887C84868B858687818684848881868481847D837E7B817D
81787782888181787F817F7C7E79807C797E72737B7E7E797F7978767E7B78797A767378
767D72787B7674797B7A7774797876736E72687A6F6C72706D71736C6C63676D656B6770
64706C6F706870716A746A6D70696E6871746B6E6C6B6F686B70676F6A666A6D68706366
6C6763696B5C6B66675E626C645F666A676369646B6264606064625C6561625B63636960
626363645A655E5D606056585F666463635A5E5C655C605B636160645E62615E5A5E5E5E
665E5D5E5B574FB800000000000000000000000000000000000000000000000000000000
000000000000000000000000
D56663696960686264695C6866636663625E68666166675E686564685D6868685E656667
636462616062676362655B66615C6060535E585E605E61635F6A6361616164615C646B63
696667646C5C66676C64686A6C656A677164696E6C676669676968636D726C656C707469
69696D716C6A6D736873686E6E6B657073737C72707070727674716C716E6E6C73757373
6F736F76767B7B72757676787D7A79737174727879797176797B797E79797877797A807B
8080817F7C7F83797C7B767C7B7A7B7C7B847B8181787E878181817E81817E808381807E
7B7D8B817C848282867C7C847D8084808C80827E8A8882808780847C85888183846B7688
86867B8A8682887E83818884868584868B84818786818A89888688898D7C84877E828187
7F8685898682838581868C838C8B85818882898488847B867F86888484847E8088807C7F
837B7D848484767E7F7D7D7E787B757C7B7B7E7C817D7F7C7E807E797978767D7477797C
78797D747B837C7E807D717E6B6D6C6A707074787171776E777972716B71666769666369
716E6D75717171706F71727178736E6D646A65666A6F6B696C666B6B6B6C6E6668686A69
64636971686560676B6361636B6366646861676C665E616661616164616960625C635C63
605B5B5F6459605C6B605E615B6363645A615F59605C62646364655D66615E6463685D5E
5D60616059575BC100000000000000000000000000000000000000000000000000000000
000000000000000000000000
CC6261605A63686C6367696363665F6B666B606567685D6166666367675F5D68665F6162
5E676861635B676468685F5F63625B56585C5E635C5E6262636065646863615D60666A63
696961646365666B676F6B676F6B64697167686B6E636C6561666B6E6F6568706C69706E
716965706F686D6F6C7470746F76727777716D71716E7875716B70746F7474766F776978
7670747278717B7779737471796E7873736E767A767680727C718076787D767E7D768182
7A817D7E797C7A7A7D787B7F7B7C7D837C7D787E8380807A7B7B787F7D807C7E81847C7B
7C817E807E7C80827F7E7C8181897C7C848C848183867F82878688898284868782848088
83838B83848F84827F86848C8C8C8C8586898B84898888888A89818488868F86838B8483
8588848183888C84897C888489848586838486897D8A858679818485818386808A7E8381
7F7D82797C74807B737F887C777F767F7E80787E7B7E7D73797A8080778078787A747676
7B83767C82857D847D7E806E766E6B6D6F6E74757476706E686B746F6D6469686E686668
686E6C6C6C7473747075776F706D716E70676A686B6C6963696A6471616C6C686E686660
6468606E6B636866666268656161636661605F5F6663606463646465636170616465635C
5C615F606664666663636568656866565B645F5B665E5B665D5E5B535C5F575B5F5D615E
6B5A585B5B5658B600000000000000000000000000000000000000000000000000000000
000000000000000000000000
D4636264635F6461605E696668636869656366636768615F5C655F685E5E60665E6A6064
6467655F6368666561605E665A5B5C5A605D5C625D5D56655F5E646761666464645E6466
686A6464636368636A63676B64646C6865686F633B000A5B6F6F706B6E6E716E6D6B6D71
71716E726B6C6F6C6C6D6F6C6F6C707B70796D6E76696E74706C746C7579746C6C737370
7474736E7475737A727873767476747375747872717B75787D747E7C7E80797F7575837E
8181797D807975797B7C7B8288817C7B79767C7A73797985817B7A7E82887C7B8983847F
7F79847E7C80847C7E7E828B8088838486868B8784848182868884888587837F9281817F
7C8785848E8683898980848A8382868C8B86868185818888818488858A8C91808A898688
85897F8D868084898B868484888A848B7B838384867E80847C8084857F7D847E867C7E8A
807D797B7F83807F8286807E7E707E8483817E807679857E79857B80757A7C7A7A7D8078
787E808B818C87898D807D7977767068736D69737A74736E716B74716E6C706E6D666168
6B6C696F6E736D7171716C72686C726E6A6B6A70676F6867666F69636C686666666E6C68
6C6464616467606661656B6A5E6966676660615C5F646163686661646568615A60666563
61575E64645E605E66656264645F6360645F585B605B6361635D605C606164615C625C66
5D5C5B5F5B5155B200000000000000000000000000000000000000000000000000000000
000000000000000000000000
D161666164636063615F68636669666764636A6568666966616666636363606465666563
67666668666562605C6358575E5A5E5C665D5C61625D62685B5C66686061616169606063
5F6864626468616B666D6E6E67746B636B70643E004E50646F67666C7070736A6B676573
6A64716C6B6E706E746973736C6E746D747274767572707C687176766E73717976756C6F
79737175757377766D8071767B7977796F777980797A7B757383777A807D7C797A7B7D7C
7B86868080807B8688757873837C7B7A7E7C8386818183798082887D8180817B86867E7B
8083897C828381887F8282837E8A827E838785878B89887F7F8384838488848886838A81
88888089858B818884838482818E86888E86868C85838A8687848C849083848A8C878A81
83838C8A84878B88858E8A8B8887858E88828C808A7C8984848491867B86838881868E7E
81808580777F7C797A808183867C7E7D807E7A7D7C7C817A83797A848374798079787E7C
7D838E878C8F918A8E867E7B777671666E6C6C756B6B716F6B7173776C6B666C6A6C6A69
73686E716C687670747670736D75706C6C68716C6E6E6E646A6E6D6B6F6C6F6C66736E64
68656A6762606166636E665D6C696468605C646A6161616964645D605B5D5F646B646068
6364665E636065615B6063665B605E5B645D66635E6059605F61525C606461615D5B6060
675F5D68585954B800000000000000000000000000000000000000000000000000000000
000000000000000000000000
D36C61666661616668666463665E646A66656A6463675F6963676062635E5F6761646164
60696666636B60635E65615B625E5F605D63646061685E63635E5B61636A636163615D66
5E686363666A6269686C6E6E6C697064646C6E2E3A616D706E696B716F6E6C72736D696C
6C6A6B6B76706F6C73786E72697374747071696E696F79756C7172747976767574767371
7173777C7C7079786E7676787178787D7675767C74737C79797980737E797C7379817E80
86847E807B877D7E807C7E7D7775797780787A868380807F7E7D81807F8079808184807D
808583797E8381768284868384818682887E8482858B7E868680858284848E848A818387
898783918B8E86878C8E8E8884818E8A8A848E87868A8988888B89868B908D838E848483
8B8C8B838888838C8989878C828487847D8085818786858482898384847E837E80847B88
7D7D7B83868388827C81827C8379817B807E7C78807E7886807F797878787B7A7B787B7E
8082899691A09C9B978F817E7C6C73746871696C6E786E7673786D6F7664646A69686862
736C6A6B717168706C6A71776E6D74646F6C6B706E6C716266666966686A67696868656B
6A666C6364666266686869636D5C6665636B616360696A60696161606064645F66605E5E
63645E6463626063695C6366625E6861615C615C5D605C5E615E65625F565C5F5C5F5D5B
60645E575C545BC300000000000000000000000000000000000000000000000000000000
000000000000000000000000
DC63615E62676867696161696869606766636958666960676668646A67676366615F6463
6166616061676560645B695D666A5F6360605C5E626764605D61645E666160625B64696C
69695F68636B616C6C6A686E716C6B6B6C6C6A6668696E6D7470696767706D6C6E6E6970
716C666E6E6D6C6F7074737971706C706F6F78737C72796E707771747873737971747076
71767775767B757973747178757C7C747B74747F71797C767A7B737473737E807C7C7A77
7C7B7980827F8379807E79797E737C80778085807E7C7E7E7E7D82868079848179837981
808683817E838679828486847E87848088868380857E8C8684898989898888907C89808A
88898C9386838C8C868B89888B868B82908E8A9488908E868C8E898B918B7C8684858A8C
849085838689868589848B8685828D86857982827E858B7F8388868E8186818382868181
7F7C83807E838180877C7D7E807B84867E807983837E807E7B80867A807A7C7883797677
7F7F8C9699A6A09E8C82797871786E6E736A6F6D706F7373756B716C706C786E69656364
676C70716B737D6D6E6D736C696D716B6B6E6B6E6A6A66666A6B686B6E6A6C66676A6065
676A6867675D656367646A6D6267646C666B606367666361625C5E666C61696161645D63
61675B685A605C646466605E665C5E63625866615C605A6566615C595C625E695E5B625E
645E5D5A5B5C54C100000000000000000000000000000000000000000000000000000000
000000000000000000000000
D561615C61665D685F6A5F686663666B675F606062646A5F65685D6568696166665C6363
6865615F6465606F63636B65666662636969646260636261605C5E5E625D61635C5F6463
655F62716A647267696F706B70706B6E6C6E6D6C676D6B7169716E69686B666F6F677473
6F716A6F6A6B706E78706E6C69756A716B6C6C6C75716D79707874747C6C707779787372
7772736A7D7B7874727673767375737675727C737977727C7A767C7A7E787C7580757E7E
8780847C807B767877807B817B807B7D7B7E788084807F8381837B7A7E84797E79857E7D
7F7C7A7A7C857B7B8184877B86897E80878487808C898484877E8A8D8C828B868882898B
898283908C84848B908A81868B808F91858B888E818E8B878B8B8B8587828D8889888994
848C89869085868395868B84818187887C8784848A88888C8786867E8C847F7F8B7E807F
7F88827C7979808075837B808184868878868381817A7E787B80837D7A8282767A7C7880
84888D99A5A6A1978E837D7A7574706E7475716C6F74746E716F73786B716F726C696B6F
686C6C696D6E6F73686E717571666D6C73746F6D6C706F6B686C676A6968686965676060
68666466676064686B646963635F6468626C616461686862645E6562636364636D636164
5B5C5B5D625C5E5F60606261585F605D5F64616163646361685E5A58615C5D6661625E62
646359645F5E54BE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D35F596864636861646962656E64645D61626A6B63636A69616960606863686667636B5C
6168686A6060616464666B6A6F6464696B6E68626768646163636466615E595D615E615C
6B6160686B6967646B6B6E687371656F6D6B6668736B6466656C666A6E6D637370726C6F
70736F70716B696B726A72746D6F706B6B70717076786B7C78726E79767B6E737F7B726C
6F767877767377706E7B797479737476757B767E71747C78757B7C7B797E747582807E7C
74807F79807D81797C7C837983817B7C7E83867B8181847C827A86848C848A80757F7C82
7C807C848780837D818081847B80818385888386847F848883808384858E888784868F83
8485858C868B8183808C89898E86898389868992898B868688888886888E8B8689879185
8C85828B88868787838A83868C838484898B7E84857A8D838481868B847E857E7E83847F
81818080887E807B7C7D7C7A86817D79887C7E7A83838C7C807D7B7C7B7C76807E7B7F82
7B828D9B9EB29C8C8978807C757774747072696C64706C736E736A707469736E6E706B6B
666668737276717B707171716E706E6D707067746A76706E66676F6C6A696C61636C636B
6B636B6A6863646C666166636265666463685B5862635C6566666A625E69646460645F63
67615E63615C6364616366636166645B62605E5B60615E59685B5C5C616163625C616264
5E605E5B60585FBC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
DB615E625E63626666615F696066686463665F6666686465666868696561615F68646368
63625C61666761706A6A6B71746F6C636167636970655C616563635B615E5C615F5F5B63
68676160616B696A6E6A696D617069736A7164606F69646F6D6F726B70716F6E706E6C6B
6A666C717772737170766D72716F6C6F7073746876727575716E6C6F6D747771747C7478
7374717273727575777C7B707171797B777670737C767D7C798279807D7974837C797B7F
7B7E80807B7E7F837E807C797F797E837A827A8382817E80847B8682877A7E887A807F86
8483817B7E7D838883848785848482817F8686828B848B848E87858B8E8989858786898A
8883848889848E818487888684897E8D92888B89868C868E848B8E8B898E8C89878F908E
8C888B908F938D90879289878A8683848086878A8585837E88818889888C878083817E8C
837E867B7C847C837B847785777D7E767C74868384828283837F857C88807B818281787E
828889989BA68A948580797B7B71726F6E6B706F70767171726A707271716E6E79736968
6B706B6C6669736F7174736B6E696979746E6B70726770676B6C696B6B666F6E62696266
676B6663676368696B686360646C5E646867626263675D676168666161636866645E665C
64565C625C6B5361615F5E6261606964636463635B5F6066636460625D5E625A5B635B5B
5F5C5A655F6057B300000000000000000000000000000000000000000000000000000000
000000000000000000000000
D45E606C62616164656164646661606963616468686B6869666A69666961686A68616861
626258666568686E6E70786D776B7363696565646866645E615E5E5A5D5B595D5F61615F
666764666D736C6B69696F6C6768706F736C706D706E6B6D6B6E71747674696970746B6C
6E726C70696F687871746C6E6F716B79726E7374777879727373766C6D74817674767A74
74787179727C737273707C717A7E7B747B786F737B8375778079738170787C7C7A818481
807E82747B807B767C7B7B7E82818381788483847D8386857D7C807F8083838181808081
838481847C80817C848689888889848184858B8B8B868A89848B888C8B93868C898B8B8D
8A8287878C888E888C84898B8C8B858A8E9083878B8E8F8F898584828E88878C90828B92
8C938A908B8B8786898C918A888C8981898685898182888A848B848B8A85877E8B83818B
8C80818185887E818484838387827C7E7C827E7E877D76827B7C7D80807C827E7B7E8184
8687848A8B8C96817E7683767D787F72726B716C666C6E6C71717273787470756E6E6F6F
787079707477706E6B6D726C7062706C696A686C706B716D66646A676868686466666B69
6468656469676C765E5F5E646864616566676169646161656266636B62635E5D63635E60
6666635F6665685E6261645D636263635A605C635F62595E69615E5F6060656059606161
626161605E5C5ABE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D66261636E6364656362646464646966616E646A66686468656970706E6A646166606866
666064656C6C68686A7976777574706A6D666364666564645E695E615B595E5B64646268
6B6A686F666E66636B6B6B68696571716E74686D6E736E66717071726E6869706C686A6D
6B746C696B6B736F72706D6F70716C676F70736C767377717476767D75776F726E787175
7375787476778171767577787773767B717E7E787B7C7B767F7D797379787F777B7D7980
82867B857E7E7E767E827E7E7D7B808387847E8680897E817F818189837C83868187867E
8C7E83878086798189858D888C898788888E87828888888482888B8B868E83868E86848B
8C8B88878A898B8686838C8F908E8F8D8E849189898C88958494958D98888C84878C8E8D
8E918E8B8A8A8A918986818C888A938B838A8183898B84818488868883858B83837E8980
84888C7D7C7C8483897B7A7A84787C80827F767F7E837D7B7D7E7B807B81847E817C7682
7A8483818F868883787B7E79837B7C73736D73666E6C7370747173746E7772766D706D71
6B706E706C6C68776C736D6D6C706F67726E6B726F736A7069706A6567636C6F5F67656A
666F666E6A63685F6768686464636B666E616664696A68626961626660635E6063645C5E
5E605E60596666645C5F5B5E60685D63615F66615D646260646462646463635D665F5E64
5E666064565B54BB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D064645F665F6661696664615F64626060616365636A5F68686564636E636960616A645F
6868635D63646767696F7D72736C6E636660655E68616361645C5D5B615E615E60666464
6961686B686C67706C6F676E6C696A6B6A6B6F6E6C736B69726E676E776B6A716A6A736C
64757263726C766B6E70746C6D786D737474757673757674767372747175777974727376
797C797B79767B7A777D7A7E777B797C757B83787C7D7B7C7C7B7E737B7B76777B837B7C
7F7C7C79807B7C837E7C7E7E8275767B7E7F85838081817988887B79838081807E7B817D
81797E8682838382857D84848986838C868888808E8E8B92888A8C8B8B898E83838C8B8C
8B8A86878B9084838F888C908C858A918E918C8C888B938E8A86888C8690888C8C918D8B
8F888C8D8692848A8984898B8C8C8B8B84888D838B888A888681898D80858088847D838E
8489798183867B8381867E82838484807E817B8080808081847B847B7C7D827C7E7B847C
817E83808B837C7C7A7A747978807A787A716E726B6F6F71766C6F747C6E6C6E73706E73
6C686F6F6F6B6E726F71716D6D706C707370726E736D666D686F6D6F7069666B6568666C
676B6E686B6A66676B6B686763636C6C6669696864686963615C6961665C6A5C645D645E
685D64655E61646367605C6061686061646868635966635B62605B635D635C5F5D635E65
615F5B60586058BA00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D1605F6B5C5F63675D616360606865696265626B69646666696E6C5B646E5D6765646766
5E646163636B656C6C726B706C69656468665C675F6660595F645E64595C5C5B62616366
6B6C6D666E706769706C6F706F6E6C6B636C6E6D6C7073706B6D6C676F747172746F6E6B
67726E6C6C716D736B7178706F706F716E717773717C7A7C75787178776E717579747D76
7479797A767A7871787B777C7C847C7B777E787C7C7C787B7874747577747974757C7C77
7A7B7C8587797F7E818983858189838183877F887D858081827C837F838B82818086877B
7E8A808083818086848C868987868586828786898B858681898587868686888A8A8B8887
8C8686918F84848F8E868A9192898D8D908B8E8C8B8F8C898F928C8A8E8E9090868A8B8C
8D908C91928D888B8A8C96928B85848C8A8383857F8C878686848184858C868484818584
897D837E817B8982807C888283898B88838682857D837C818281807C8081827D7F847C81
8280827E837E7B7D787A767B777E796F71727173716C70786D74736E7574717073707169
6D7071716B6B7371736E6E706F6B7169696B6B6A706966706E696E6D6D636B6B696C6B71
676B6B666D676D657160696A696B6866676A6C636564605E5F5C665B63645E62685C625E
60656363676264625D6663615C65666061615D5C5E5D5B5B605F6160636067645B586064
6463635958565BC100000000000000000000000000000000000000000000000000000000
000000000000000000000000
D0605A636161646161666E5F686E6B656169646469626468656666696A70646160646068
6360636166636F6C696C696D6B64676460666063615B665860615C5E5C645D656561695E
6B6B686462646A6C68646F6C696A6C686F646A616D6D6E686B707567686E6D6B6F736E70
7169696C716C736E6D70707B7578747074787474737A7274766E747371747A7878747C6C
78737375727C727977777B7B78797982828081777478787C74757B78757076767678777B
7C797C7B80807E7E817B76807E817D7E7E7E8183817F89838B847B81848A838B827F8981
8B878C89838A89838D8486848B898C8C93848C888A8588898C868B91888E86918B8A8889
868B8B8888898D819087878B96908C8A9089888C8893868E8E91898E8C8D8E8D8E8A9292
938F958E888D868D84898B8C8C9086848C8E8F89908683877C8D838B8A8B898A8581798E
87807F958C8F8184858989807F7E84837B8184837C7E7E7D7B7E7C7F83867B7C7F7A887E
837A807A79867C7C6B7E7F77787E7C706E6F736A6C716E6F6F717273766F746F6E777073
6E6C6E6C6C766E6C6E746C716E69747473736D756C6C6E706B6A736B696C6B68686C6C6A
6870656B62696A606D676C6166686B6C6C6C6560636661625B5E605F6664606068686063
5D66606368615D6461666162615F63665B636466635C6360605F656A636066625F63615C
605E5C5D5C5C65C300000000000000000000000000000000000000000000000000000000
000000000000000000000000
D46763626161635C686763685E656063686167645E665E665D5E616B68676A6A64685C66
6461606065696571666A63666362635F60636162595E63615C6160636163606564636B64
68766A69656D656E6570716E71716C6964666A716E6D706969666F756E6B6C70746E6E6C
7269706B6B72706F6A72727271716A6D707370737570757779787B756C71737C6F707D76
73737378767679767779817A7C837A7C7977767B7C797F737176797176767379747C7379
807B787E7C827D7D7E8185807A798180868784838288847F87818C7E83848483897E8589
85888281837E8885878389858587878380848484898C8F917B81868D89858F938C8E8B88
868E808D908D888B9489898E8C888A94898F8C8B8D9891908C9187918F8E898D8A90888F
818F868E878D94898F8E8B8D8684868489838A89848E8C8F888A898D8884848085838881
83838C898C7E86828182837C80797E887A807E7E808183867C818680797C7D88867B8073
7F767B7E847B737876797A76797C7E777777766E6E736E7174706C7171706E6E68736974
786A6E736E6B6F737376776D7178767176746E6B6D69716B6670667166706E68696C6B70
6C6B6263666666636862686467686E6C686961636361615C65686C6464636B625F6C655F
5F5F60635C5B6460615E60615D5E6369636363686461615E606863635F5E676264685E61
5D6057585D5961C500000000000000000000000000000000000000000000000000000000
000000000000000000000000
C9656464646160695F5C5C656861696665626361646F6966696066696D61656865606261
615C6161666969646168726660636765615F635C595D5B59655F596865636C6D676A6B6B
68686465676470696E69686E6F6D68636A696B6B6E6F6B6A6B6B726F718971746E6C6C6B
786E706E69776B7864736F67706C7B706E777378787276747D76787971786E7872746E72
7E707376727776767877797B7D807F7C80807773797477757473736E7374727671717275
7C7C7C7B7D7F817E837D868884808386897E817C87838982847F86888789808989898A89
8A898688868B848B868C838C888A8C8B8684898387888B8D8D868C918A8C8B8487858E8F
968E8B8986898D8E8986928D9889898D918F8C8D8F938B8B988F938C8E8F8E8889998E91
93928D868C938E8A8E9186898A93868984898A8C8F88918A86868183818988888C898583
898486868A867F8084858C847E888186807F8786858585808178807E7D7D7D7B7B797B81
7C7E7E84797C7F7B787083757A747377797574716E697171716B6E6E7671747170727372
6B6E7968726D696F746E736C6F70726D6A776C6E71616B686C707369706F6C70706A6B62
6961616966666B686963696A686B6C66666F5C61606267615B6963625E5F656866686165
6961615D5E686763695964615E66636364616763606168606462635B636361626464595E
6161605E595A56C400000000000000000000000000000000000000000000000000000000
000000000000000000000000
D6686761615C606663606C696664626161615B6C6369666462656365666960635E6C605C
636B616365626A666C66686661605B615E5A5F5E62635C635F615B5F5E6668666E68696C
6C686A6D686766716E6B6F6E6F76746C6A65706B6F677068706C6D746FC56C71696C666E
6E706870726E79716B73697070747079706D6C6F73747678707774747774747679717571
76787A6F7674767B7673747D7C7C817A8076736D7C706B6D697071706B70706F71796E78
7679788080807E838183877B85807B7C7C7C837F7A7E817A81857F897D828E8C7C81838C
818F89848D898B87848784889383898A8A868A8B888D888C8C9089878E918C8C9190888E
8D8E8A888D908990908B8B8B8F88909390888E908D8C9491918A98908C98949B8B8C8E8B
9889868E978D8B918E9188978E868E9187908B888B878089818683888488838884848691
84898388808789838384848380838386848183837C8384817E8783867E837B808480807F
86807B80817E7676707B767880787E7F797B757075736C71796C727376726C6E6A747278
766F716C746E7474746A7572716E68747071736D6A6F6C736C6B6A6F6676706C6C686B61
706668676669686670696B686973716B6868636966656766696663615E63646462616363
616461605E5C60636164625D615B5F5C5F5E605C63666161605E6960645E6060625D615C
5B5F5B5D565D66CE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D45E606366605B6D636663635F66635E60666A5C6661666068665E646469686561616865
6A636A666168666C6160646061635E5E64615E63605D61615F636463646862696E696464
676B636C696E696C6E6C6E706B73686A6C6E706D6B6B6D706E71707170656E6E696B7070
717B6E716B69737371736E736B6F707B6E75727476787076787A6C737D7A75717A797470
6E79717381747479837580777B7584717375746F6F6F666B70675962786B6B6974797576
6F7478767978848488857E837D877B797F80817D81808181898083838386898B88838A8A
8B848E8580838088918C8A858889878D8989888A8F8B8C888787938C8987868E928B8B85
918F9496918F949394909689898E9091918E8C8889929193918C8C888E8F9A938E8D8390
8B9090898E8C8B9189838B908E8989938D8A8B8C8C8C83968984878B8E8984848B888284
8988898683888B7E86887F838581818688837D86848182808980897B80837D788181837A
747B838181797C7B7C807A7E7B797974767B7474727572746F6D716F6E74707274716E78
70726F77717075726D6A6E71736D6E7871706E6A73666D7370656F686C66696E686D706B
6E6566646568676E6B7064686F70696B696C65696E6269636666656563605E6860636A65
646361646369665D625D6563676064656062665F64626967616067635D66696061635C66
635E5E5D64625EC700000000000000000000000000000000000000000000000000000000
000000000000000000000000
D162685E665E616162615E6866686D68606461685D64686A61685E6B6861605E5B666A65
656367666167606567645E64626066605E636562606367616161616F6168606E72636C6E
6E68746C6C676969736E68746E696D716C736B6C6E7170676D6C696B696D6D706F696E6E
6E686B78716B736D7074756F6E72747472797670777476737871747075737C7B74707871
7B6C7B787179747F79807D7C817E757072736F6964676661656068666A67766B716C7378
816C797B7D7F7C8086818080827E7B817C7F777C837A847E7E7D7C7B7D8D84828A898787
8786878B8C8786818B89888C89899287818F89858D8990899093868B8A89898B83898B91
8E8E888B8C918D888B8D8F8A8C88929398998F8E8C9C9494978B8B908894908C94919697
948B918C8E8C918893928892888F8E8B848B8C88908E8C8E8B908688868E838287818883
8C88887E8484888B848C7A838485818787848180817E8382817C7884827C837D82817B84
847C8A7C767E7C7E7D74787E79787A79767773747E7C6F78727B6C777578787073787170
6E71717773717172796D6C6F6E706C706A6F7369707070677A6B6B6B6C71696E70656465
6E686469656C6B616E6B6C6866716C6B6864615D6164616B646567676461645F616A5F6A
64615E5B5E60646D6B61605C5F62625A65615E65695E6363616867676163656B645C6361
5B5F5C58666960D000000000000000000000000000000000000000000000000000000000
000000000000000000000000
D1645D5E64626966666C5E63636061656C63666366666664606B6561646A6468626A6963
606861676C6668666967605F63676860645E605D626463666261606869636B706E65766B
6E6F7068716A6C686D6B69756C6F6E726E6E7068746D6D706E736E6F6A7070736F6D7373
756E71717174736F7674747069716F767668787473736E77746F71757A797474767B7073
7579767875767C78797873737C7B7072717669646460605758675D696966696E6D757571
727B73807B7E8478827C807A767E79827E80817F7E77718074797C868385838984868489
838E90808C8C8586868689898B8B86838B94878B8689908A888D8C928E9596918E88908B
968B938D918F8C93948591948E8C9390919390959090938D908D90939D86949095949891
90969089908E938E8F8E938E929293868D868E848C8589868E868B878784838687898381
848887858C8584848285897E877F8381818481637F82897D7A83837D868181827E7D827A
777B7E757F79817774817C7D79767B7D79767C787C73717374767475787570776F6C7673
6C746E73727679756C6E6670746F727276766F6A6F726B6771656B6B6E6970706C6B666B
6969686B6669676D666662696766656E656B65686865686868676765606962695E635F63
655E615E60636466636563615D675F5C5E65626061665C68656369696463606068635B59
62655A5A5E605BD600000000000000000000000000000000000000000000000000000000
000000000000000000000000
D15E60606561625B695E606A61616366606263686A5B66646765656163615E6664646066
6667646867695F626862606062606163615F636166616861686165666B6066636E636E73
6E656E70707070736F706E706E6F786A6C706F6672716D6C726D7171706C6C6C6B6F6F6C
6E72707476797478786E7472736E786B74767970747177757178717C7678767673757674
6D7776737477767B747B837B807B75716B6D6C63565556545B5E5C6163686C71686D6A74
7075707E7C7E7C807C847F7E7878797E79787B777E867882787C7C818582808784898C88
8884868588838E898388848E8C87898C8E82898F8E8D8B8B878792908C8D9292938E968F
88948F918E9293918E94928F8E908D938E8B928B91979691968E98918F988B8D8C96918F
9492918E94938B98918C9294918D908A898C938E8D8E84898E8B868C88888A8988868E85
8D928B878B898487848489848689847E84808182838181887F7B817B81847B7E7E847F79
7B7E7C7A7F79797E7D73767F79768879797D77776F797C727A767C797179796E6F7A716E
7372767074746C6F6D6B6E73726C6D706E6E716E736B6E6B686C72736A796A696A6C6A70
6B616A6B6C646C6C6B6961636C6B696461686861636F6B61666466646461665E62636165
636861656966666764636663655C5F5F6369616C6866686565686E6A65615E6166656665
5D5E615A635E60C400000000000000000000000000000000000000000000000000000000
000000000000000000000000
CC63686360665D635D6168626060665D606365606361706364616662646361636C696864
66646469645E6460626363606065656861646E61646A6764686670706E706B6F676F6669
736E70636E6C68737371696C716F686E6970686F696B7270786B6B666D6F6B7670697179
6E7075687476707478776E6E7476737674707D7679777274797478737675747176707771
727472737277838079758375737870696C61615B5B585658545D5E64626069686E686E6E
6E7D736E7B8083827B7F737E7C7C78817D7B7C7B7B7F7C7C80837B7B84847C7F81868691
908B8D828B8A86918090948C8E878B868884878B9089869093968D919689968C8B889192
919095928D8F8D938C988E9197908F89919090939493938C988C98898F8D9493988D8E96
9890898E93969193908F908A8D948C939389868C938E8A93868F928C918C888D8C8C8983
7F8886888C8385848286838586858E8E86848586867F807C7F7D7E818279797C7E817F7A
7C7D7B8084757D7E7C7B8079747B747C737876747579707876747D71786E747575797B75
726F707374726C7673786B6C766F706F717371746C73747368676B6E6B6A6F6B6E6B6D6A
696F6968686E6868636B6169686C666669616B68676A6968686E63676067666060616361
63666465625C646464645E675C6463665D656761585D5D686F6A6466636D5E626263675D
5861635F5C5E5AC600000000000000000000000000000000000000000000000000000000
000000000000000000000000
D06469606567666C5B5F635C58655E68686568656468616669686365686A66665E646567
656A6663626061616169685C5B606A6564626A69646B66636B6D6F696A696B6F6B6C6C69
6870736E716D6E6E6C69707073796E68706B726E70736E6E6E7073706C6E77706F736973
7877766A6B747872776E777674716579736E7676747273767175767C76797B767B757879
7C79797D7A7779737D7C79756E766E6B696461555C5753585B5B635E6369706B73736A75
6A736D75787E787C7A7E7B7E7A7B77797F7B7C7C8084877B7B84817B7E7F8888808A8B89
84898E8B8B888690898B8A8C89968B8D889386948990898890948F8E949290989788908F
8B918B92948C938A8F929188918D919089928C9193968D9193898B929196888F908C8C94
8E91919696939489978C899196918B898A908B8C8E8696858B8F87908E8A838C91828886
8C8386878A8E8B83848E8A82838586848184838B82897E8382787F828279837E7C828280
8180877D8080777C7878797B7D827B73797A7B76797C7779807674777677787B7E737476
7C79757370746D7970746C716B74747B706F746E746871666C70716C6E6A72706F68686F
73666B6668646B6468666C656969616B646C6969696664697063686462665E6360646864
60646D5F6161625E6568646064636063606061645C696666646E5E686662695D5E62605E
63675C645E5D5AC000000000000000000000000000000000000000000000000000000000
000000000000000000000000
D2605D6061686062606364686163666363656D6A60675F606764656C6C68656666606A68
69686762636C677062656369636161696B646270616E6E70646763706B6B657463667067
676A6B686E6B6E6C6E717476766A6E6B6E72756B636D6C6877716F73716F6E6768726E6D
73706F76787678766E787773787678756D796C7674747179738073717879777C77717876
757D7C807D787B7E797C7F7276736C6965665F5B565C646361625B65636E746B70736F72
736F736E717B777A7B797E79737C7878727B778380818379808480788380818987898686
8D9389868B8689878C8B8F8C938C8F93898D8C898C99928D93908F898C8E98898F908890
8F908E8D88918F8D918F908C8F8691948D959793988E9C8E94958B8C9292969898969394
969B9390978F919A8B949792919696948890918C908A8D918B868889878E888B88888C86
8E8F868C848B84848A8C90818484838684828883858B89838A80818B83868381877D887B
7F7B8279847480797688827B76797B807C7874777978797E7673777C6F7C7472777A7770
6E77756E78776B7471716E6D78706971716B6871656E72696B71766A6166696A6B69736B
696A6A6C646C6A636667666B6B6D646368636468666667686A646B666562675D6066615D
6161636363635F64636466605B6367656164645E616466656264656465635D5F67626063
6961605C565B5EBC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
CD5A6565605C6664605E626A64636068646963636961686468675E645E665E646B656662
666267686C616C6964666E646E616B686F6A6B686E67666C6A6B6B676E6970696C656B6C
696B6C6474647071717171736C6E6D696A7467636B716B70726B736B6D7070706C706E71
726F73717973747074736E6F76737A6F75777876766E797876787D7878717376737C6C76
7875797475707B73767274756E6E695E6C605E5B60615D686952676A6C6A6F6B72717071
70746F747E797B767D7D757E7A72737E767D847B80818A8C89908988807E868286818489
89908A9487878992918E868E8D8E948D8A8F8C908E8E918C999197968C88959094938F90
949B8A939592938E8A999791999495919996988D97909893949395908F8C94948F918C8C
9393949694939693978F8F918B92908F8C8E92868C87928F988D8686908E858B8B8B908E
808987847D868A87898681858584848E898689838480907E8986848C7E7E817F82848283
7C827E7C788381787B797C817B7C7479767B73766F7E737276787976746E767A75817679
707C76787376736C7272767972706B7170746E736E716D76716C6D6E736A6E70726E6D68
74706B71686D6B6867666B696466696A676464686B636B6669696368666563666E5D5F60
62665D635C665C616863646163636466626664685E63656261666861626661635C646964
6361625C5E5A52B800000000000000000000000000000000000000000000000000000000
000000000000000000000000
CC685C5E646061615C5E5C616361646965676464656864666D696B625C66606461666065
6C64666469616165666A6B656C626667666B6B6367706E6868686167716E6B6D6B686369
6B6C6B6B636C6E6E6B7473696F6C6A6D7570696F6C6C6B6E716F716E737070727177766E
6C777071696F79737075736B7B797378756C7B74757C767978757778796C76767676727E
8079767C7A7C7A7B757874736A6E6F5E66645F54605F61666853627571706E7969747469
7170787673737E8373817C80747C79787D797E7F838887858986868583818180898D8684
8B8F89898E91908F8A89898D848C888E9396918D9290938D8A919593978B959B8E9A9694
968B9090968D8B8E8C998E8D93929690919391969495939C8D95969A90999D948F909590
A09799939A8F949191949397998C8F908F91958D92938F8987888E8E898A8B918B8E8F89
908D8B89868388898B878884838B878880878B8288897D8583868083857E808683808081
8080817C7D787B80757B7B777A7D797A727B7474787C787778767478727C79797871717E
757678737776736D6C70736D6E71736E6F74737374736F70696469716D73726E6C697368
636B6B6C6A66666D6C6C64616C6669616C63646C66666068646A646261636965636C636C
65646363646B63646061636461615E6466635D676068655E61686666656663656163625F
6262605F585B59B400000000000000000000000000000000000000000000000000000000
000000000000000000000000
C95F5C615E5B6A635E6864635F64636C61616B61666963656B666C666964686267646562
636A636663706C6C68716963615D66686E6B67676967696C6C69696A6B6C6C6B6B6C6E71
6E696E6E6E697070796A6E6968696C7269776B67666B6C6E68736F6E6E74746B70706C71
717679777171707874767B7374767776767A74757471767C7574707B7777767776747478
7E787F79737B7E797D717D756F6D7072686469666368706B726E71707570686A706D6972
6B72726C7276817C857B797B7A8081787B807B8479888386848C8D888481848889858684
8B92908E908E868B8B88908E8C8C8E99918B87988E96948F9596968C9B9896909891948F
8F8C9898989B9390978F8C98938A988B91909594919498999494939696998C94969B9298
9A9999989B909894918C98909394908C8F96958E898C9491898E888E8B8C8E948C8B888C
8D868B89908892877F88888889838885878689837E7E7D84838188818386878186867C7D
7E837678817B7E817D7F76807A8070797C797D717877797B7E7973767979717B7D767373
7B7E77747D75737B72746F696F6F6E7473746A70706C666C6B69766C6B72627168666B6C
687068646B686F686965676A606763655E615E696663666B686363696664636563615F63
636068655F5E626B67636067615F686164616A6566645C64596B63636563635862606060
616C5F5C5A605DBC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D36463605B6366675D6764686464665E6061696465635F64646B66666664686864666661
5E68656B6C666969636B6468686C6B6465646B66606C686A6970696B6B6E696B696B6C6B
64666670736B6B776F726B6C7170696E7164676B6F6B68696370706B6E70737376776C72
707677707B7B7378787175737B797E767971716E796F74797B7B7C7C81767B7777767A71
717B777D7B798177787571706B6368696666636764666C70737B707C74716F736D706867
6E6B6D6E737B807C7A837A807C7C808384818280868384868B808483848781828B898B8A
8B8E8C8E8D938C8B858E8C8E919788908F8B8E88909695988C948E949990928E938E8C96
959691909B8C98949396949092999997949491929B999A91919791978E99949897919491
9998989A9694979C9894918A90928A96949390948E9896889297898D908C8B8B9C8A8B8C
8C898789918E848B87897E8785817E8C86878B838A8B85837C83867E868180897F828483
79838384847E7F797E7C7976788978737C73797B787475707A7C79797C767B7277787479
797479706C716F71737F7471716E73716F6C7271756A6B6C73726E6E6A6B706B6F6B666C
6F6D6E63696C6765676469696769636D686A6661636363696A5C6364636B616363636064
6263616561636069655E6363656361645E646465646167645F5F655B6A646866645F6364
60615E62596059BE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
C9635C5E5E6063696069656063675A6861676664686663696762665D686364665F656769
616B676769686D686C70646B67666B6867696B6666666A6E6865706D6E6970696A6C6A6E
6969706A66716D706E6C7363766D66746E696A796E6B716D6A6B6F6E6668696E746E7474
776E6E78707273756C73786E766E747377787375737270747479767971747876727E7379
7977787C7C74767B7479716E686B67606B6868656A6669756F77797C7171736E6F667064
686B7372747A837C7E807D7A84837C848A8687878089867C888C878B8186838286898A8A
938E8A908893909190939494908D8E949394958C8998918E8E9F99989391999696999096
9290949A988D8E94938F9598919A9994949395939A9E9D9B919992919A91999690969695
989099969796938E928E8E8794848E848D969091908A949194888C8E8A87888D90918C95
8B8E8C8686858D888C888882858689848588898C84877E8689888881838485807E768480
807F848681867D797C7F788680787C7D74817977797974807E7E74797679787288817E7C
777473747879776D716D74747170747172787673696F6E6D70726A706C6D7067696B6C6D
6C6E7169646868676C6B706C6C686C6B6569646467666663636264676165616460656160
606162636659636864666A636663626065665C69655E615E6262696065666561655D665E
615C5558595854BB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
C95760605961615E60655C6A606062606361616164666169666766636B6562696A666767
6B66686B696C6B706A69676B676A6070676464696D6A686E6F6F6A6F6B6B696C69686C6C
6D6870676E6F696A6C6D716B6B6E7470696D68706E726E7071706B6B727373726E706E71
716E7373717974706E7670747671757D727A7C7471787970747478767B78797C76787677
8182787E6D778373787370716E706C6E696F6A6B6D6D6D75717B787E71736B6869666B68
63686F6E767B7D79857E80827F7D7984838B7E8A828A848A8B8481878188818B82848792
90888E908A8F899094978D9798918D929996968E94919C949698998E93989796939C9398
8E9797969690988C9C90919896988C96909B989D949C969A949C96909B94959693969594
968E93A098989C9B98968D9093909A9591998E969B95908C8C9792898C9588928C908986
8B838E90898F8E84888F85898C847C8089808988828689878284847E8185838081837D7C
7F8680807C7E81837D81837D807C78837B79787C797D7A73797D7A73737C79767B7C7C7B
7C807777756C716F77726E6C72766E7A71717471726E70666C6E69706A6B6C696A716E61
6C686569736B6468696C6B60686B696566656A6B686D66646364666C625F626164645E67
6264675E5E64636C62635F636668626B60646068625F63646561626764636761656A6362
5F5E595D59595CC100000000000000000000000000000000000000000000000000000000
000000000000000000000000
CD615B645D63645C6765616C655F6868615F62616061676163606663696166665E665E65
60646968696B6F69656566696C656B6A666B6469626C70686A706F6A6968696C6966686E
676E6D6D716F746C6E74716F70717073716C706E6F706F716B6C6C6C686C72707473786E
726F7774777473717B777978767B7479717870747A747E7E767C7C817E747B7876767C7B
7479787E707878717370746C6E6E6969656D6D6C6C6C71747F7E7D796D706E6A656B6968
686A6D6A79738080837F7E81838886827B7E868889888586858688818686858B5C7B8E8B
8F9391909590909591909596969097919991988A9091949696969699949B96919B9C9095
9B99989C949C978E948E959C929895989C939390919B96959EA397969696949898988F94
9C98909693999993969D9A93949094959898949091969C969995949191908A908B968D8C
858C948C8F8A88868D84888F899084888C8488898688898884857F85898486857C898384
80868880848385817C84837E807A79767E7E7E77747C6E7C7E727B7C727B79827E7C817B
7E7A767A747073747C7C717A706F766E756E707C73716C7670746F6F696E736B6C6D6570
646B686F64686D686D636D7169626B63686A66646664696E6860616465635D65695C6263
66686561656662615E60665B676661666563696162636162636064665E666666605D6461
615F6458604E58BD00000000000000000000000000000000000000000000000000000000
000000000000000000000000
CC63656361605D5962646664606163676B636B645C6565686660645F6A67615E68696765
6E666862696A646573646B646C696C686A6B716E676C696B6C6E6F636C6B686A6C6C706B
666C6D6E6B697365716B6B6B68637167707376786E7E6D69716F6071766B707474716D72
78747468756C797473767375797D7378707A7274797D78807F79717C777E7E827B727D77
787F7D7B787B807A7770736A706764716A6B6E6D7870747A767A79736F696C6262646361
6C686A70728181807E7D84898481868A86868488878B8C868B89898B8B87888E65758E90
8D909390939094898D919B908F91948A9194909898959893949490989197959698909B98
97979C9A969994969890998C90918E92968E9E9B989797949398979B9894999797939794
A08F9A92919A8E9C8D94949891949095938F92919491918E8C9194958F8E8E8988919190
8E888D8B8C958B8B9083888C93817C8E84898880888F858B8286878583878782867B7D88
8D83897C84828387837E847C7E7C82767C867B7477787F7F7F78797C6F7A7E798079817E
787C77717674737378766F707172706E746F707075746E6C717477706B6E66736D69706E
6E6C636B6969666E6F6F6E6B6C6C69656E676D6864656668666167695F6060666A675C66
686069645C65646C6A665C645E69625E635C6165645E686368675D605D61666566626C63
5B68625B61595FC200000000000000000000000000000000000000000000000000000000
000000000000000000000000
CA5E63646A61665F61645A605F695E646369695E666460695E66646367606666635E6667
66666D6B64676D6B6667716F66657168706E6D686C6B6C706C6B7371726C6C656A666768
6669676C6C6F746C6F6C6A6C6C6D6C716C766C6E6968646D706968686C6D7373756E7378
7C6F6F7271736E7274747174807675818079787778787B7B777878777E79787980766C79
74797A82797C77777979706E746C6B6F666F6D766F797876716E7368736B6D6B64625F65
676C78747E7E868880848180847D878184867D8381848B86868086897E848A84908E8C94
89918B9087908E9099968E9A919096959B9398959499919892949291989A979693999890
9C91969B9E9C9996969494919A959B959B9C92979F99939DA1969B8C9B9493939A949A9D
9694A49E97969691989891938C99999590948C8F919696968E948E9896948B9291948C86
8C918B9692918880878C8984868B8386888D86808786887B8383888488888B84888B827E
838288807F81867F7E7C7679727E7C7C7D78817C797A7E77807C7B7C797D747C7A787878
7F717172727874747275776A767371736D737373726C6C706C6F6C646A7471706B736669
6C69696A6C696067676C6C6660666E68696A6565706E6A6A616860606363666966606261
6960606867655C65636664595C59675F6361605F6B616069635E68695D606266636A6161
665E5D5B5F615DC400000000000000000000000000000000000000000000000000000000
000000000000000000000000
D3655C625B5D5E67616465635D61656B626663646064605E64686368616C636468706663
62686A646569616B63716968666A71686E6962676E6D6D6C6C6E666F686C6E706E696B66
686E6A747061686E6C6F6C68686F666E6F687370687670716B7069736E6E6D7373647370
7879756C7C6E71757472746F7B7372737B767F747E6E7C7D7E7E81797F7F7C767C7C7A76
79767C7B757A7B76837977706A72766F6C686B716B6B6B716E6E706A6C6869646B5E656B
6C6B73767B82807B85828B8583808A868183838884818988838C8A818389818A898D8E83
95948E8A8E8C929B92969999999A90959590969392969996919398919B9891969C999C99
96989B94909C8E91A1959E91999892988E97999C9E9A99979A9A99949A979D978F959495
A199968E96A091959A94989996969293949C979699989496949190939395958D94929396
8C93898C888E8D928A8B8A868E8E8988808B8C86818383898B84838289838E8685868381
83908B868C828183807E7D797B7E7D7C797D7E7E7B78767E7C837C807D7D7A787C797986
737676707475776D747B71726D6C7171746E6F767174706C6A716B71647167746B6B676A
6670696F68686B69656A686C6A6970686D6464636669636B6963636E63675D6865616666
6164666969626C636864636366665E67635D65615E5F605F636360696666636361615F5C
615F6361605E5AC400000000000000000000000000000000000000000000000000000000
000000000000000000000000
D165635E615E615D6560685E635E5E62636B5E6865616666636865636862685E6469646C
6466686664666968656B686E5F6D706E696E6B6B6768696768606B6E707473666B686371
6E63716E6F6E706A686F6C696F6B706B6C6D6C767076716C726E756B6E76716F7A797176
7870717076717074717E7A77737B777576777B747B7979787676787B7F797C78787B7879
797A73787E7D76787975736C716F726C726E75696E6971706F6B706A646261616B646C60
707673738080848084888788807B7B878489868683898083838B818884838984928C858B
8D99899394969A8C91949697999896959098969B9F93989D9A9D969B98979B949C9C9799
9C9C9893999996A39294969F999C94979494909A97A09C9D9E9696A29C969F97A0989B9B
998F99989991979A99989694999299989F919798949B8E8B98909A919690918F918E9096
8B908E90918B898C908C8C8A87868E908789878C868A8681868985848584838C7E888588
86868484827C807C82787883807D8080817F7C7D807B7B7C787B7979807B807B7E7F767A
787C7E787D76767B6F737778787772787273706F726F747073676D69686C6D6B6E706E6C
70666E70666B6F6C74706C786A6D67686E6863666260675F606871696060686863666061
5D605E686B64646661655E686762676169636660676661646068666460645E5E62615E5E
60615B5B635E61C000000000000000000000000000000000000000000000000000000000
000000000000000000000000
C66563636161635D635D5C636161656463676367675E5E635E6365646562696B666C605F
6B69646B646467636C666C6C6B6E6D70736C6C6B68696966686C64686B6968686F6E6C67
666B6B6D70667067656A6B71686E726C706C706E717374767073726A6F7A707871717471
797E787971707472757671757A757E8078717C707B79877C797B747C797C7D74777B7B78
737F7D7B80777F797B7371776F726C6F6E6B70716C7169716B6E6A5C645C6666686A6473
70797B7B83838484848687878289838081817E84818981848486868783888B8E8D8E8A91
978B94959893909C9D9E94968E949491989891979599999896959993979C9A9991999296
9C99989C94949EA0989691969A949B9B9A9892A2958FA298A89C988CA6999794999C9C9B
9B98979998989893998F95A09196949C8D9794939B99999E919D919397939498908F928E
8C8E8E998E938E8A8C888987898E8E8F85878C85928F7D8888848F8B878690868B818187
8684898B80857E8A83817D847E7B7E7B7C807D7E7D7B7B747E7A7B7E7D7E7C8178797D73
6F7C74707B72776E717C70766F706D746E767271737271736C736A6B6E6B676B6F6A6C6E
6B6C666E6B716F696A687065716869696C6663686861616C6B6E64676C68666C6960686D
61645B64646864666166686761616266656166675F5C685F5C67565C60615E615B605C66
5E5B58595F5B5EB800000000000000000000000000000000000000000000000000000000
000000000000000000000000
CE645C5E616163665B60606A6066666863675A63636465636866675F606D645E67646363
616668606664696B6969696B6E6C706C6F6F686869646D716B6B6D6B6C6C6D706A726E71
6B716E6C6B66706D6A696E686D696A707C6C6C7173767370716F6E736F7B707377717079
7A7474797676787376717C767C7A7A787A7A7A7C807C7E827C7980807C7C7B7B7C7A787C
797F79787C7B717E797B7E7B74736C6C696D686968706F6C6B63636B6969666866687973
7B767F818884867E84868881827E7E80808383838383838B8183868383808B8995929891
96898B98919696989899999C9B9895939192948E9C919B96949D9E9B989C919E949C9D94
9B999D9C979991989A9B99989492A09A9D96A59B989E9898969C999D9E9EA09E9E9B989C
99999EA09A9C9A9B99969D989C9B9B93969B99919F979B9C9C9C979A9A90988C8B918F8E
94918E908E958B8C898B9089879384869286818C868C868D88848086898B8E818B828181
84858180828284837E81817E7E85797E7C84767B7980767C7B7A7D81827E7C767C7A7874
7C79777B787776746F72706E71767777757274716C70696C6D6E74706F73736A6F6D6C72
6E6B6C65606868626E66636D696B6C6F746D696A6C6B6664606E6E636166686064666465
616864645E666369646865636561635D65605E5E666162625C6661645B6461616365645E
63645D56595B5CC700000000000000000000000000000000000000000000000000000000
000000000000000000000000
C16662645C606161605F5C5D686060635F616168665D5F646261676D635F6A6261666971
69686964696E6B6D69696669716E6C6B686D666869676C6D66686C7068736C6E70656869
6A6B69696C6B676566636B6A706E6D6F7473746F6D706D706D6E6E777676717276777879
737978847173717B747879717E78767A7D717D807B7A7873787A747484837A7C7C807677
797B808879797B7B7B7C7E797973796E6D6B686A6969706363666C6B6663606A6C727B7B
7C828083818283808A848588888B88888187837E7D7F86817E8384898C878C978D949091
8C939895989496939B98999B93989797949C9D979FA190A09B97969B9896969E939A9C9C
9C9B9A9C9D999B90999699A1989C93A09A9995979A9894A19F98999D98A1959C96A09D9B
A392939B9C99A2969F8F9F9B989BA09895979E999F99969B9F97949692919198878F9296
94938D8B8D918C8F8891888E8C86868E8B8486838A8980857F838989857E8B8A87858386
86848085817E867C7E7B787B7C7D817381787B887C7F84818481797B757B7E7B78797A7B
787C74767178787A70767A6E7670746D6D6A70707666696B6D666F76717074706A70726C
61716C69716C6F6D716A69656B6C67686B6F6061696E6B6866766E676B6A646C686B646A
626160686B6B6A606B616469606864666968656668605F62686060605E615E625F685E5D
5F625E60615E5EBE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
CF5D5B5E60645B6661615B5B6064615F61625E606361676563636069636163686561595E
6A676B666A66666770656F696B6A6A6B70706D736C6C666A6E666D6D69706D686B686A68
6C6E6A626A6B6B7466666C696B6B6E736C78706C74736C6F706C7471796E767570727673
74777971747E767373767674787579767B757C74787C777B79807D7A747E797B8179767C
7D7C7C78817D7B8283827C767676746F6E6C7171686B6D706B67676067666E6F71747982
807B84838A8487898B8A8B8B868188807C8680817A83847F8886888B83918C9092959598
909397969290939B99919B999E97999D919991919993959E979E9797919BA09A9BA09896
98A1A1949E9D9C9B989F9C9993A69F9896999B94959E9D9BA09B9B969B999C94A09E969B
9D949291919899A3999C9E9FA8A0A1A49B9B9E90969BA4989F9B99989E98909C97939695
958A8F8E8F928D8E89938D86928F8E8F85858C89837E8C8B8189848E8089838383868081
8E8481818482847F807D807F807A7C85837E787B7E7E837B7C7F767B7C7D7877777C7E7B
747873797676747673737474716B6F6F6E7073716C6F6A6F74706C6E706D72736F6E6C69
746C6E6968706E6A6F6D68706970676B6C6B6C6C686A69656C6B69696667686365616864
6968695E66646461606367695C65616662636B636064625B606464665C5C685C66635E64
6163585D5B605ABE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D0645F5C62666160656664636561635B6462676160676262646063636869676A6B5E6869
61686D6B666B6B636C706C676A6D6B6E696B6B6B6F6A6C6B6A696C6C6E6869726E6D6871
6E746D6C6A6B6C6A68616B746E6C736B6C6E716F6C6C6E6A7279767075777673797B746F
6C76717473746C7E7B7B74757B77757E83777784737A7E7A788179797C817E797D7C8180
7F7E737B7E7C81798281807C747D7C7172786C706C6B74696C6C73686D7071797A7E7C7E
868B8490879184938A898988818383848881828385828489898B938C8C8793998F959094
94989091959698979890999F8F909E969B999F9C969E9E99A19F98A096949A9D9C9AA499
98A29B989B9E9593A59A9FA2A39B999C9B979C9E9E9F97959D9C9CA39CA093999B9C9C9A
9C9B99A09F999B9A9DA19E989D959F9BA3989EA6A1A09DA8A2A49E9E9EA09B9991938F96
949694988D91889096918F9093928C8C8B89858B8B8483868C85918B868788817C888984
80868484858480797F8586857A7D7B807A7B7D8281807B7E85807878797C7A807D757A78
7B7B7B78737576747475786E7376727170706C787876706B6E70736C7176706D706F7471
676A706C7870686C6F6D68746F696E636F6A68676E6969696461696466666663666E6965
686563636962686866666764626664696364636561665C5B5E62636163605E6361605E5B
635E5A6560595CC700000000000000000000000000000000000000000000000000000000
000000000000000000000000
C764635E656B6262615B636063605C6760636868625E63695C64646C615C5B5E63686668
63676464666867606E637066666B6F6B6969696669686C7069686C686B6D6C716B716871
66666B69706A6B6B6C686B6968726F6F7468767271736C7374746E78767A6F737677747C
736F7F7170787675767C73797B7679756C767E737C80797B7D7A787E787E76807B817C7B
83797B7A80818378837A7D80797980797876736E6875766A746E6D77717272768181838C
908E9291888B938D89908A858388868186848B86818A84868E8A93918C8E948C90939389
959293968F8C9D969696969298959C9A9D98A19C9D989FA19F9E9C9D9FA19BA1969C9DA3
9CA49E9BA1A19C9D949C98979D98969C98A19B9C9999A0979D9C9C959B9C999F9B9D979D
A5989B9798989F9B969A9B9CA0A2A9A69D9CA29E9C9B9CA8A2ABA4A69996999B9196918D
989192978993989591908E89898F8A8B8D8B849189918B827E8A878889858B897C8B8181
83897F7D8E848181887C847F86817E7F7B7B7C7F797C837B8477847C7A71737582797C79
797C777C797B767779727B7B716E71686D7376766F736B706E74686B6C716B6E7174736B
6B69706B666770686B64696C745F70686C71646468666371666768656F696B6761646966
5C6A63685E6B646C6666646065645E686960656261685C665D6063695D5E605C62666163
5E61615E5B5E60BD00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D0625F5B5C65636859646761646660686364606460606C63695C645F646B6767645E6164
6169646468616B6B616E6C6A6E68686E6C6D6C6B6D6C6C726B6D716F756D70706C6D6A6C
696E6E696C696B6B6D6F736C6F6E6F7273726C726B6D7174726E74746E74756D77797873
7C757B707B7B7076747675787D7B76787C7978747C7C747C828384817E7D7C7F7E7D7E83
7874828778807E7C8081818C7B807D807E817C7874786F726E6E76747A777D7F84818B8B
8C94908F8C8989888D8A8C8885888D8989878D938B898B8E8B8C8B949690909396979596
90939698999B9A98999B9B949D9B99A1A196969C999BA498999A9D93A29F9E9CA19BA39C
A0A2969B9791999B9C9B9A9CA0999E9A9C9DA6A497959E9C9EA69BA09C9C9A99A2999C9D
A0A09EA59D999C9B9F999CA398A4A39F9BA3A3A69BA6A3A6A4A4A0A4A79EA89993999896
929391959693918D8E8C8C888B8C86898C8988818E8C8B89828B8386848C7B8887858880
81838B897E868885827D81817D837E8481868181847C807C81837B797F7C7B7C7E73787B
787875797B767A766D7B78767C7172756C6C71707369736F6E6A686F73736E6D7369736B
6C6F6D6F6E6A6E6C6B6F6E66666966676D6F69646A61696C716C666A686D62786A6A6168
67676D676564686B66656461676A5E5D616766636465666367685E6164646A64625F5E64
5D645F635B5A5CBC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
CB636166636160616264675F66615C685E6961685D685D626464676666656A6363686462
60636167686B6667606A6A636B666B6B6F666C7068686C71746E6E6B726B6C6C66676673
6A6E6E6D6F796C716B766C6B6C69716F6A6C6C696B70716C76746C717179767671797D79
71797376767A767E737B7A7A707678767D817F7376737D7B7A7E7B7777747E807882887C
807C7E82858488837B8A7B8C8587807C808281797D747974737B7E79817B7C8784838A86
8C8E8C9193909C8E8E96848B848789818B9187868B958E90908C91908D929C979393939B
95909890999399929C989694A19C999D909A9B99A3A6A09EA19B9CA4A19CA3A09EA499A5
9EA6A3A69D9A989CA0989EA29C9EA092A09E9D9C9DA19FA4A8A69C9E9C9B9CA4A6A99EA7
A49C99A0969AA0999C98A0A39BAE9E9BA4959C98A3A0A6A6A6B0ABA5A3A094999998989A
8E9990948E99909391929194948D8C868B8E888C888B8996918088808889848E85838E88
83808783887C808180817E837E81797E818082817C7C7B80817C8376857E7483796E747F
6E797D787E7E7277787B74717274797A75796E6C726E716C766B7077706E73686C706E6E
75736B716B70686C697171656B67716B6C6C64696C6369686C68646C66666C6471686B6B
6970656B606766696A60606466676464676461666A636366655C6460636461635B5B6160
5D5E645E635B59BB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D86565615D635F66636160636661616B666461635E5A606964696269616363685E636566
6163666C63686C696B6E70646B686C696B6C6E65746C7171756F71736D6D6B69696A7070
766D6C7274747673747770707071666B706F6B716C736C73736C76727079736E78737374
777474778074717B767B75777A7876767B7C887E79787C7A788177807F807780767E7A83
838285818488877E8083828484837986847F8085817F80807E7389838488838887908C8A
878C9395949596989B91948F847E848E868C909092928D949193938F98999494989A9499
938D9B9499959A969A9C9C96949E9A9897A1A0A198A3A5A1A0A69CA1A4A0A0A4A0A09EA4
9A9DA0A2A19B9B9BA3A0A19F9C9E9B86A29C9BA1A1A3A8B1A5A4A09CA4999E9EA9A0A4A0
999C9CA29C9F9EA0A1A79E9F999B99A396A1A597A2A3A4B2AAACA0A4A1999B96989B9B91
939B988C9493908A949692938B8B8E8E8C868D84898B8981808B8A898684828486827E77
798184848386837E85817E8481837F7B807D7D80827F7C81888383817A7F807E76767E78
78747B7E7879777B786E757C6F6F7A7675736F6E76786F6C7378696C696E6F6969717074
726C6773746E6E686C6B696E696C6E6970696866646C6E686766666064686E676965616A
6269665E6C5C635E6168666662635B6964646464636166636663626166666962605C5B60
60635C62635B59C600000000000000000000000000000000000000000000000000000000
000000000000000000000000
D46363616664666264615D64636165626168665863676361645E6066666B65666865646C
6862656866685C6C686C63676C606D706B6B7468696C706F7274716E6D746E697075746B
706B7371787874756E6E7070766B69707370706F6C6F727773787C706C767476707E7776
7676757A79737C7C7571787372787B7679767F7C79807B80807C7F797B807E808486827E
7E7B84847C807E8C85807D847E8885838584838B887C7C847F83898481888D8F8F908E8B
8E91958F919893989A8C908E888C8B8E9094929195968E93939892909189938E90A09693
969B9A969F9C989C969B919C979A9E9FA09BA1A09AA3A49DA69EA8A09E9B9F9B9FA29EA1
9BA1989FA5A099A8A49EA4A39E9C9EA89FA396A298A3A1A5A09F9CA09CA39E9FA7A0A1A3
9C9EA19899A2A19FA0A19CA89B9BA4A5A1A19BA39CA5A2A9A9A79F99A1A1999898999994
9895939C98909893998E8D8E8C908896848A8888848A86838585838783898C8887837673
747E7D848483787C80848888807E7F8388827C807E7B807B7681847C7E7D6F807983747A
7B75767D807C7A7B706D78787678727573757077717172736B7868706B63716C6E696C74
68757F73696B6A6B6B69686E68666E646E696C6B70656B65626C6E6B63646962616B6868
67646867666161696567636B63656364636C686465685C606260635C695C58656060585C
606368545E5F62C400000000000000000000000000000000000000000000000000000000
000000000000000000000000
CD5F6463645E606762676061656267646168686466626664626866686461686E6464636E
646C616E706E626864677069686D6C65726C6E6C676D6F6E6C7074716F736F6B666E7070
737170706B6C70746E686D726C756E6D6F746F746B6E6D73706D7476727A7379777C7575
7D7B7F7A737177797778767881777C7B7C7B797E7C807978767E827C817B837C7F78797E
847B7F807B7E7C7F857C8382848687838585838384877C7C838A838E858A808983889088
8E8D948A9B999A998B8A938D918B888F9088948B90969999909790929B9D949B8E979397
999D9A9B94A29A9C98969DA29394A0A199A09A9E9B99A49E9EA29BA09CA0A6A29B9F9C9A
9BA399A1A9A4A09F989FA4A0A1A69EAA9FA1A2999C9B9BA8A49FA7A3999DA4A5A499A09C
9C9DA59FA3A8A3A39BA39394A59CA0A3A09B9CA0A399A1ACA4A1A2A0909C949597939794
98918F8E989392999290928D928A94948B918D848D83898890857F868D8480808788808C
8381848989847E869086827D808289817E7B82817B7E817B7889847E7B7982798078787E
817C78717978747474767578766F716C787273736B74716C746A6874706D757271696C66
6F7173736E6F69686D6B6B6C6A71696F6368696C676A616964685B62686B6E6369666865
6268696363626860606264695D625E665F696661625E6266605A5B5C615E635C605A6661
5C61596366645BB800000000000000000000000000000000000000000000000000000000
000000000000000000000000
CB616366615E5D63626162625C60635F68665E61636864675F6A666667686B6663656865
62666B636A6C656A6266676D6A68686E6C6C70657168716B6B746B7470716E636B707069
6C7175726E706E737171746A76757073747370716E6D6977747B7674737C73747975727E
76747B76767B797D7B74787B7079797A7C74777981857B7B76758186767B80767A808583
85817A8184838680808082808B8583868689868784868586898984868C8C88868E909091
8C8D8A92969E9C92999088938A8E8E8A8C8E94919599939690938C9B9B988F9993949795
9693909C9E9C9C9B949496999EA59BA5A1A1A39FA1A69B9DA29BABA3A0A69DABA2A4A4A2
9EA49CA3A3A8A79E9FA3A9A29E9EA19DA19BA3A9A59EABA29EA3ACA19F9BA1A6A3A2A3A6
A39F9CA39EA3A09F9DA7A499989FA0A6A39D999B99A1A0A69CA0A69D97A09E9E9B988F9B
9C9799969B9C97949B8B93968B919489948F8C8C898B8B888A8689918B84918386808680
838C86887D8A8083877E817F817C858E8180827B80808079807B768184837B7E7F7D7379
7D7B7C7B777681797779767472736F707471716B6E737375716D746E6C6C6F7369756D74
7374757375666E71646B6B696E6D686E6B6B6966666C66686161696B666B656C68626369
6469636D61626C6B60616367636A6B63606265665D646066686063625E61605A5E606062
5F595E5B626263CB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D388705C6463686B635F5C6364666B5F64636B686566625B675E605F6C60666567607067
686E6A69666A636B6A646B6B68696A6A6A71616C6D6E6870736E6E6C6C686F6864696768
70786B76706E6F757373766E7471707479746A6E736D717A70737471737478797B6E7473
7877797C7A737D7D787E787B9C877A7D797C71777B83807F7B7C797F7E78807B827A7E80
7E7A887F838E847C877F7E83808188807E898B838C8E888180868685888B8B948B8C9288
908A98939494988B9B91988C969693988C99959E92939495999B9A9696969399969E9B94
9899979D9F9DA09999A498A1A1A198A19D9B9CAEA49CA0A0A0A0A6A49F9EAAA09D9FA8A4
ADA79DA89FA4A0A1A3A2A5A1A9A1A3A0A1ABA4A2A1A0A3A3A0A7A0A3A0A7A59BA69CA4A3
9BA0A6A9A69E9FA19CA0A0989C9DAAA19BA99B9FA398A3A09C9E9B9F98989C9393939996
9B988F9199989A8B8A9C918D90928E9291918E8C8D8E8C8A88898F938D8B7E8889868184
7A847E8A8A88868084848080838079877F817D8679817D80777E83877E80837D7F76807C
7D7B797E7C767C786E786D787978787674707778737473706B676E74746C737076717268
6E666D747E68676D7470656C69636B71696D66646F696366667069666B6C6A706D686966
6D60686B66636C6864635F626060636666656866626464665F635C63645B5A6363606159
60595F61605C5EC600000000000000000000000000000000000000000000000000000000
000000000000000000000000
D27D666761656668625E66605E65666C6C615F626360666463646466656B686B67616666
696D666C676969636865696E746F636D68666B6C747B73686C746869736D73696B696B6B
6C7171706E777673746E717175737B767573777873757172707074797679797479817378
767B79737E7B7B7B807C7B7A897B8483787E83798182787E7C797E73807A8086807D808C
83838789838689827F888087867E8485888B89898286887E908A858B908A91868E918E8C
8B8F90959092979B8E9691939397909C9B919395959694999C9A979998979994998F9495
98A399A3979699999BA0A2A7A5A3B1A49EA99DA19FABA2A9A9A1A9ABA4A6A6ADA8A4A6A6
ABA1A3A5A3A1A9A5A6AAABABA4A5A6A0A1A4A8A69EA7A2A6A6A89BA69BA3A7A9A3A79FA2
A2A6A3A4AAA8A49FA69EA3A0A0999C98A1A3A1A39A9DA0999A999B9DA29D9F9AA29C9A97
9797939A9D9C9A8E91928C9894978D8C90968B90A4A28B90858F87898B878688888D8984
88848281838185897A83898B81827B818380838383888181877E7C7D78807C8682777F80
7C787974737B80767B7979796E6E77736B75756D6F7371717973797771706B6C70706B7B
71736D717168696C68696C71706B706C6E73666B686C6B6C656A6466666B6A6961665F68
69636B6068696B656562646862646B6960646363645C60635B60625D5E615B5A64606360
63595E66586163C600000000000000000000000000000000000000000000000000000000
000000000000000000000000
DE6463616461636A676C6868636160605C60685B6B5E606666656666646E6A616B68686B
6066636B71656C686465686D676F6B696A66686676686B62716A6B6C6B6B6664686F746C
6B6873716F6F707176747174707971776E717678717873787B7375737079797B72737976
77737377778080797E7979787B76777A74847F7A808379797D798381847F807E88818180
858383807D888882838887827C87838C868984888983888D8F838B888D878E8E8A868C8E
8F998C908E968D9697918A9894979594A49799949A9098919E94949A9C9794989C9C999B
A39899A0A1A4979E9BA1A4A69AA59EA69DA8A3A19EA3A7A6ACA1A0999BA3AAA4AD9F9EA5
A7A5A9A4A5A6A9A9A4A3A49EA6A8A0A2A1A19EA5A6A3A0A6A0A2A1A9A6A19BA2A6A6A9A5
A0A6A1A8A0A3A39BA9A6A4A0A2A1A4A5A99EA19FA195A59BA3A1989C949B9F979B989B9B
96988D9C96999B9390909A9B8F939094918D8B8CFFFFF38B8A888E9187868A888689868E
8E8682848480887B83898B83868784838679847F7F7C7F80888189838680838078807B79
7E7D767C75807E79737976737573796B73706E706E706E7470716C6E6F6F6E6E73716D6C
6F6C70736868686C736A6B6D6B686E68696C64666B686C6B6C6D666B666866646C6A6764
656C6568656663635C66625E67676564686561636461695C616A6366615D5F695C5C5E64
5E615E60645E5BC000000000000000000000000000000000000000000000000000000000
000000000000000000000000
D35F636C686369666361686B6461645E6865676464636169616467685E69646861646868
6769696B676466666769696670646A6F666B6C6B726B646672726D736569656E69687062
6B736F716B7371736D746D73736A7071787D777B7171777B7974787776787B72727E767E
787B767E7A7E7E827E7C777B7D7C777B7A7876837C7C7D8183827F7C7B83787984827E80
877E80838883868882837F9086848388838986898F80848B868989918A8B888D8A918C8E
8F8F96968C90968E9B949190948E98919899979594949A949692A0969897999F989E9E9E
9C9C98A1999C9F9A9FA19EA0A99EA6A0ABA1A7A1A6A4A4A9A9ABA4ABADA1ABA1A3A9A8A5
A1A7ABA3A89BA6A9B0A6A0ADA1A3A19FA6A9A4A0A1A0A1A2A3A4A8ABA4A3A2A6A0A5A3A4
AFACACA49BA89FA3A5A699A298ACA0A3A79FA69C9CA69D9E9EA1A59EA49F9B97A1969699
989B9C9894979B91909E8B8B9497928E89869191A3FFAD8B9189848A8A8D8F888F8B8490
7F838B88897C8B8488837E848682848884837A817B868A8A837D8089818485817D75797C
7979797A7879747A7A777B7A787B746E78797878736C68797C7872706F69726C72737074
6B70707470706D6C68676F6F63696E626A6D696866646862666A6B6D676B6964646B6669
68626963686B686367615B6664666066616663636C685E6161665E6260645E595B63625C
5D615C5C605D5BC100000000000000000000000000000000000000000000000000000000
000000000000000000000000
D8646466686A64685F6468636665616868696568616166616566606668675C6B60636969
646B666965646A6B6F686668686C6C666665646B6F6C69686B7166636B646E6669686768
6C6C6F6E716B69716F747273777B796E6E7176787F797171717878747775757A75717375
7582737E757A7D7E83797072827C7A85807C7C80797F7E7C837B81787B7D7E7E83838181
838485838484858483878985898888818A8B888B8B808488868C8B8C8C91898D908E8B8B
88938894949391919599968E969891969E91929597919B9E969492969BA0989698989EA1
9A99A09BA098A29FA494A1A1A1A4A1A3A3A3A9A6A6A2A1AAABA0ACA2A6A4A4AFA6A4A1A1
A7A69BA49EA1A7A7B4A9A0A3A4A9A4A1A4A2A8A9ACAAA4A5B0A6AAA9A6A99DA9A0A8A2A4
ACA6A7A8A9A6A79DA5A5A8A8A19EA19EA6A19B9EA49EA0A0AAA19CA3999B9CA39E999C9C
9E9E92989D99919894999E999196938F9192908C8B8C8D888E868C898E84828C8D8E8A8C
8985888286888A8381847D807B81837C818885888380898180878B807F85847C7D787B88
7F78807C797A79767E74787E7873A988747776716C6E76746C787375766B666C73766D76
69747266726B6A67686F6369656B6E706B70686B6B6B66626664695E6C65646B68696064
6F66626E67666B606468626862646B686A61616466626560696860686464596463636861
635C6362606261CB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D9616868686E6766686364656B67666D606964675C66636669606C6A686661606962695C
6C66626868696B666B69686868655E6B64696B656B6C6968676E6E6970606B66676D6A70
6665686D726C6E6D71737276766E7570787873696C7378797D76797375707A767B70787B
7B7C7B83847E80887B737E7B7E76797B797E7E7B808385868582808B807C7D81867C7B85
897F8786827E8583878C90848983838B8F80888D8C8A8C8D8A878D8B8A8D908B88938391
8C8C918C939693969897918F8DA090A296999D96949D9A999698999F9A9998A099A0A19B
A4A3A3A4A1A8A1A0A4A6A0A1A2A5A8A6A6A2A9A1A4AAAAA8A6AAA6A4A6ABA4B0ACA4A4A8
AAA4A7A8A89EA2A1A7A8ACA7AAAAA5ABA1A2A5A8A8ACA9A4A9A1A6A8ABACA5A4A6ABB0A1
ABADABA8A4A6A6A6A1A2A0A6ACA69E9EA1A1A09EA1A2A398A1A3A09CAB9E9B9E9F9FA09A
9BA096A09B9A9B92988E97919691989A8696947E968B949094928C8491909286868A918B
8D87868683817E8688848684847F80898B868489818485848885868485808180797D7C79
767B7679807B7D7684797D747E778B7E7574796D736D75747371766D6E72716B756F776E
73786E6E6B6C70746E6A686E6B70706A6A6D70686D65646E706A736A6E64666C6C66696B
6966646E626E64645F60665E6066666B69696468676160615E686061616766646364665D
6060655E5E605CC400000000000000000000000000000000000000000000000000000000
000000000000000000000000
D36B666D64696D64666761646861636665656669686168666671676369686F6E68696163
646C6B646870686D71686A696966696E6B63666C5E69706D6E6C6C6D696663646E696E6A
6C69666C6B6C686A71706B716D75757576787471787174766E75757C7479737A79737B7F
78767B767D7E847C78867A7C7B7F7E797383797F807B82787B787F867E7D808680828188
817F8C84898C808383878C83868A8987838C838C8B83839189898B8D898B8B938D939292
8C908F939392939D979694959B9E999B9B9C969CA196999998949D9C949699A09CA69BA8
9AA2A7A49E9C9BA0A2A3A6A0AEA0A6A9A4ACAAA0ACA3A9A6A5A6ABA9ABABA1A8A4A6A6A9
A1A2A9ACAEA3A4B0ABA4ABA3A8B1A89DA9A4ACA7AAA7B1A8A4A7A6A5A8ACA0A8B0A5A4AA
AAA7A4A7B1ABAEA4AC9EA6A3A6A0A0A69CA5A9A3A0A59B989EA4A7A0A8A09BA19A999F96
9C989C9EA394969B9E9696929A999694909194998E9291928A8E8E888D8C8B8F8D9F8B8B
8C8E868784847E8283887F8C7C8388838E8C7B837F808A8688818B86858783807E7D7979
7A7A777C7C727C7C807976767674757179767877737470756D766A776975747171686C6E
6F7171756C726E6E67686970706F69726D69686B666A6C696B65686A6C5E6A616B616867
6765706B69666A646A65606663696160636666655E5E6B646266646166605E6557626963
605F595E5B5E61CC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E16D6E67666D6C616766607161666169646864665E66606469686E6567666A6568676461
616964606A6C69636861646C686C696B6A706A65666B6B706C646B6B6B6668666B73686A
6C73716C6C73726E76696F7177707B6E7877767977797B78787774788176797774707772
7876807C76817979787883797C767877777379817C78868080747E808081787D82818180
80848185898C817F8281868E84858E8B8B8B8D8B908B90848C8C8C8D8F8D8890938B8890
91909091928C989B9496999996988F9898A09F939EA197999C9D97A29C9D9AA09EAAABA8
A2A7A4989FA4AC9FA0A1A7A0A1AB9FA1AAA3A4ABA3ADACABA8ACAFAEABA6A8ACAEA4A8AB
AEACB0AAA9A7A6A0ABA7A5A4A9AEAEABA4A5A9A9A8A9A9A8A9ACA5AAA6A7A8B1AAAAAFAA
A4AEAEA0A3A4A1A8A1A4ACA3A99FA8A3A2A99EA49FA0A09AA0A2A1A49FADA791A6A5969E
9C9999999693969C939A9696999396949A909B99979190948D8D938390938C918B93938E
8E8B8E8C84888B818B848A87817E7E81858C8687818B817E888487877C807B7D797C7C80
78797E807E7B807F767F7A7B77757C7B79747B757A71736D7071746F786E6C726B717172
706C6E666E696B6A6B6E6E706F5E706F696F686D6A6D69696D696C636B67676C66686364
69646069676666636868616462636568696667686460646963636066606B5F61625D5C66
5E63615D5E6764C200000000000000000000000000000000000000000000000000000000
000000000000000000000000
D9676E73696466676B61646661686A65676C6A636B62646D6667676D63736D686B646C64
646369626869686B6C736C6B656B6D6E6B6B696C67666569686C68646D64636C69666869
6F686C676E706E756C6D706F6C6E7473756D7770787B74797E767C737179797D78747675
78807B767C7D79807B757B817C807C7C7E7B8188847A8981807C797F7D887E7F82808385
87878184818B89888188888C83888B8D8F878C908C84868C8B88858B94988E9389928E8D
958F9B8B8E969894A09B91949999989BA29795A1A0989C9B9B999DA1A2999CA1A5A2A4A0
A6A7A0AAAAA4A9A49EA1A9A9A3A1A5A3AFABA9A7A8A9B1ACA6ABB2ACA9A3AEA9A6A9AAA7
A4AFA6ADA2A8A9ABABACA6ACA6B3A4B0B3A9B1B0B3ACAAACACA3ABACB1ABA6B1A9A9ACA9
A8B1AEAB9EA7A8A5A2A2A9A8A6A2ABA0A3A1A1A49DA89FA1AC9DA8A4989BA4A4ABA7A3A0
A4A296A0949C9EA0969B9999929A9A8F94948E9191909896908A8D908A8B8B8F93928D93
97938C8687888386838E89877E877D827F878784888187818B84847D867983817A797E7E
7D757A7C7B7C7C7C7C777271787776757676747B74737876706E6E6F7170746B6870716A
70766E706C6D6E68696B70736D786D6C6C6B706C6E6967686A6B6A6A6C6971717368666B
6661666864646669656B6B666A62636066605E646163646563606163646660605B56605E
5E5E6165615B60C100000000000000000000000000000000000000000000000000000000
000000000000000000000000
E0636A666365645E695F6063646363686B6165646967696960606C61696967696564696A
7166646566656B616C65686C6F726E66656B6B6C6C71686563666465686266636E6A676A
66696F736565736C717172746B787A7B7372786C7471787B7C7677806E78797679797972
7073767C80798583777F847980837A7E7B787C837E80847F79828080847A8181858C877E
8383858485878990908E91818E8C948F978E9A94948C8B8F8B86908D8B8D939595968C94
93979699989E96A1998E9C9B9D969D9B999CA39CA093979FA09B98989C9CA6A3A0A0A4A4
A6A5A0A2AAABA4A3A0A4A9A8ACA9ACB8A4A7B0A8A9A6ACA9ACADAEABABAEB2A8A8A3A5A6
A4A5A9A6AFA7AAB4ADB1A8A3A7A4B0AAB0A5A6AEB1A4A9A1AAABAEA8B0A1ABABA9A4A9AC
ADB1ACA3ACA8ADADA4ABA8A9A6A6A49EA1A6A1A5ABA8A1ABA9A7A5A3A3A1A1A19EAA979D
9E999EA0949B9995989D919D9B948C9A92939398919295959992948C938B8A968E959793
8E909388848681867E8B808A89858E838388828583858A8781817E85777A81807F7E7987
7D7A7B797E7E7D787D7979777E7B797979767B7673767178786E7476706E766A6E76736D
736C706C6D73686C6E726D6E69786C686D6C6C6E686D646F68716B6D6A6B6C686368676A
65646B6A66676866716566666467615F6661626365686368635C6166615F635866666560
5E5C5C5E635D5EBE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E56763635E66686368646669676363616961696463696566686B6D616965696667686B68
6D696B6B6C68736F6A6A7168726E646D6C69656E71706C686A6864666969666C6C6A7071
71686C6C73666B746C7371717070736F73746F7378767674788378718076797C727A767B
7A797C837B817E7E807C79807A7C6F797C7E7986797E8082838787807C877D8384818587
8B898799868C84878F898A878B8C94958693919688868D898E8A8E878796909389918E9A
9B909B988C949D9197999B9899A19AA1A39B9992A097999E9699959C9E96A89BADA99EA9
9DA49E9DA7A6A09EA5AEABA9A5B1ADA6A7A5A6AEACACAAAAADB2A7AEAFAAAAAEA8A6AAAC
ACB0A9AFA6B0B0A9ACB0ABADACABA9B6AFA9A7B0ADB7ABABACB4A7B1A7A6ACACB1AAAAAA
ACB3B5A9AFA1AAB0A3ABA8A4A1A29FA8AEACA2A0A5A9A6A49B9FA8A1ACA7A1A1A89CA0A3
9EA19E9E9DA09B979E98949E979B98989BA5929094969C90948E8E8B8B928B8992989296
8B8C87868989868087858B83858989858B81898A808586877F7F867F887E808683897E7B
7E7C7B7A7E857B74807E79777676797478797371717A7C737470706F706D6C716F736E70
6C6C706D6C6B747271696E71726C6E6E6C6B6E686B6C6A6472696A646E696864666E6468
706B64676B6C656864676564695F67646A61656662626C62636461605F5E626161686362
655D5C665D5C5AC400000000000000000000000000000000000000000000000000000000
000000000000000000000000
DB6C6468646167696C65666465696B64616B666F6B686B6369666E676768726A68695F71
68636D686B686967736C6C666A6E686B6A6D6D6B756E6F7069626863636A5D637174686E
6F7170626760706E6D726C7372717675797471747674786C7C79797D747C7476787A797B
7473717371797F7A7E7C7C7C767E7B7A827A847B8080847D808385858084808C85868789
877A84818C868C878B8C898B92908E948B9A9196948B858E8C8C938C948A898F91909194
918C9796969B929C9E9896A1A19BA59A9998999B969598969C9CA09CA29D9EA2A4A2A0A8
A7A398A7A3ABA69CABA6ACABA3A8AEACA4A9A9B2B2AAAEB0AFA3ACACA9B1AFA9A9B6B0AC
ACACAAB3B0B6A6AEBBB2A6ABA7ADAEB3ACB1AEB7ADAEA9ADB0AEB6B1AEB0ADABA7A5ABA9
A6B1B7A6AEA8AFACABA6A9AEACA7A4A8B0A7ACA29FA69EA4A5ADB0A8A8A3A093A4AAA49E
949C9F9BA0A39D9499A0989D97999D989B96A39B9994969699918E908C8B9093929D938D
98929384808886868E88858D89857C888381848083868381807F878483817A81827C8176
7C7C7E867F7D80787C7974747D76777A747A777672716C79746F74746E706971736B6F71
6D746E716D73716C72726B6F6E696B6A686B6969686B64687068706760656A64676D6564
6968686763676569686D6C6E6B64636766656365686461615F63676463635E6160615E67
61665B5E5A5C64C900000000000000000000000000000000000000000000000000000000
000000000000000000000000
E4646960676F616D66666066616264686461666C6B6A656969686E6D6369616669676A68
656D696C676569666B6D696F716E6E666A64746B6D6F6D6C6C64606761686E6767696D69
706E7371716B6E69726F6E7673757873707774767B78797879797879737976737C75797C
7B76807480787B7A81807D7E7B7D817D7C7F7C847C817E7C8084797E81817F8383788188
888384888188898D8388908B88968F95A49B979194908E94908B969189948B9395959991
939C969B959896A09E959B959C96999991949B9D999F9B99A3909BA0A3A69EA9A7A6A3A3
A8A2ACA8A2A1B1ACA2ACB0ACAEACAAACABB1B2ADAEACB1AEABB8B2B1ACB2A8AEB4ABAEA6
B5AEA6AAA5A9B3AFAAB0B8B0B8B0B0AAB8ACAEBAB5B6B0B5B9B6A9AEB0AFB2ABA3B3A6AA
B4AFB3B1A9ACADB2A4A9A6AEABAAAAABABAAA1A2A5A0AC9DA6A7A3ABA7A6A1A8A1A9A0A0
9B9C9EA19F969EA39E9B999E9899989A91929C9F9E99989291948F90919A8D948E98988D
909185888B8A928F8A898C868B918E828786868C828585847F807B808389817B7F7B767C
7D7A817B797B7B76787A767B747373727B7579747672747175737672717270736C6E6C73
736E6D6E706D726A7270736E6F6D6B666E6D68646C71686B666868656B6E666E6663696D
646C6A68696E6968646662666266635E6364646B645E666969636A646561636661606861
605C665E606867C000000000000000000000000000000000000000000000000000000000
000000000000000000000000
DF636660666B6A616C66666167686B6464636B6B6B666B68646468646C69696A6A616864
6E6A69746E6E69666764666F6865706C70646C6C74696A606960646B686265696C76726C
696C766967646D6C6D67686D7B747976736E787C787A777D7B6D7A79787B7D7C757F7679
737B787F8381707C7B817B7B777F847C8378817980817B81807C89837E838B818B848483
80888286918A83858783818C938F9C9799989898938C8C898A8E8F939191919393969692
909998919393929F9D9C9CA69CA4979F9DA39D94979C989B98A197919B9B9BA1A6A6A6A4
ACA7A0ABA6AAA9A8AEABA6A5AAA9ADAEA3AEB1B3ACAFB1B1B4B5AAB6AFB0B9A6AFB2A9A9
B0ACA8B0B5ABB5B1B8ACB0B1B8B0AEB0B1B8B2B4AFB3B2B4B3B5B2B5AFB0ADB6ADABB0AE
B3B9AEA9A1AAA5AEB4B1ABACB6A8ACA8B0ADABA6ABA6A1A3AFABA6B1A6A9A3ABAAA4A6A0
9BA1A69F9C95A69BA19A939C9A92A19696969C9FA1989B8E91958B91908C968C989B9390
908B86888E8C888B868D89848A85868D848C818E8486818983848A8482787E7C83858383
7F7B817B817E7E79737C786B7E74727B7577737972777371767676757879757571736872
707874746E666C75746B6C716E6B686E6D6B6A69646E6B616E66636C7070696A68617268
6867686669636067656B68646B685E6460686863625C6166606066636268666160645F64
5D675C6058605EBF00000000000000000000000000000000000000000000000000000000
000000000000000000000000
DD636266635D636068636967646669636F6D636665686A606F646E686B66676B6C696E6D
706B6964696C6B646769667172636A6C6E736C6E70716B696363616464636C6C68706968
716E6968697270696B6B777873797979737774767C7A7B7F7977817A76707F7678807A76
7B747E79797E7E837C7F7B7E807E7A7E7379818180817B7F80867E7C8180827F84878B83
8A868286878D85868F918D8C939491999B989293898C8E96938C8899938F93998C8F9597
9897969C9898A194A398989B969D999A95999398999B92969F96959F999F9EA0A6A5A8A3
A6A6B0A4A6ACA6A5A9A2A9AFA6A7B1AFB2B0B0AAAEB5AFB7ACB3B2B0B2A8B0ACAEA9B4B7
B9B8AEACA4BAB0B2A4ACA4B0BAB9B0B4AFB8B9BEB3B6B0B8B4B1ABB6AEB8B0B3B0B0B7B2
B0B0AFADB8B6B2B4B8B1A9A4B0ACAAAEADACA7A5A3A6A1AAA5A4A9A9A4A0A5AAA6A99CA1
A49E9E9CA1A7A39F9EA49E979B9C9894A197989A9498989C8F9493979693908F9195968B
91948690888C8A8B8B8C91848B93848E878D8E838483887F7E8483807E83787A797F8079
8080787D7F807C8079767C747177757D797E7774736B796F757876727073726C6F6C736E
71716B6E6E70716C6C706C7172686B686E6E6C6D656A68716B64666C6268626D6C686B70
666E6465676C67656C6B61606C686C6366696461636967646165605E615C64645F5E6164
665E63575E615EC100000000000000000000000000000000000000000000000000000000
000000000000000000000000
E15E64626463636865686969686E6669696462706968686A66696D686863686D696C6A6D
6C6E696365606C6B6C696B6C6E74656B6F6D6C716A706565606764686A666B707272736B
746B7270646C646C6370716C726D77737674807C7C7378817C7B7B7978787C787D747C77
7B76757F7F737C78817C837C817A807B8083818584838785848680838383918983888186
848E8387898586888D898991969C96929990908E8E90938A8E8E91919193938B8F948E96
96968D9596989696929A8C968E93979C9A979E95989690939E969A96949D98A49BA2ACAC
AEA3A9A6ADAEADAFAEACACABA9A7B2AEAEB6B9ADB3B6B4B0B1B1ACB1B0AEB3AEB2B2B3B3
B0AAB3BAB6A9B6B3B2B9BAB0B3B3B8B4B6C1B6B4B4B0B8B7ADBEAEB9BEB4B5A9ACB6B3B4
A8B0ACADACB2B3B2AFA9AAB0B8A5A4B0A5ADAAA4ADA6A9A3A9A9AAA0A2A7A1A1A599A6A2
ABA4A0A0ABA3A0A0A19E9B9C9B999A96959E9992969B9898988C90909498899A94999297
918B8D878A8B89838F8882868E97848B8B8E9086818C8B8985808581838082807C797B81
7D7C7E7E7C807474777E767D73727877786F7B78707B786F7B707873757170737276706C
687171736F6D6E69706C706F6E6B6C70696D726A6669676C6871696D716A76696A6E696C
6566636E68696369636C6463686B69686861646463685D6361685F645D61605F5F646060
5D5C615C5C5C61C000000000000000000000000000000000000000000000000000000000
000000000000000000000000
DD5B646563666464666961626168606967646769686A606668676B686467666669636B60
69666B6B6C6964636670696C6873616970656E6F736A6766656B656369696F7466736B6E
6973726A656964686C6F7673707581737A7479757679787876787B797B7E767A7E7A7C80
7C737B797C7A797B7C807B827E7987807D7E887D7D887F87808080898A8088808E8A8788
81888F828890898A88898B8C91948C9B918F938E98999B889391848B9191939092939396
909697889B9999989D9391999A98959B8F9493999A9BA2989E9F9F99999C9CA4A2ABA9A6
ADAFB0A9A9B0A4A9ABB1B4B4B1B3A9B1B8B1B4B8B8B6AEB3B4B4BBB6B5B3B0B3B7AAB0B1
B9B4AFB1AEB5B4B0B1B1A9BBB6A9B2BDBEBAB5BBB8B1B1B4B3B3B3B7B9B4AEAEB3ABB6B4
B8B9B4B5AEADB4B3B2B4A9ADB9B4B0ABABABABACA4A0AFA2A6ACA9A9AAABA6A6A1A1A3A2
9E919DA0A0A2A1A5A1A3A39F8B9A909A908E9E9C9B99919199909098948C939195938F8C
8E888C8E908691898B8A91938D8C8C99968F8B848E8C8B818B89887E817D7B7B7F797A78
7C797E79797A7A747879817D7C757776767C7671737871777972767172736773706E7572
767C71736B687069706C6F6B706C6C6A6E6871696C72697071636670636A65686669636C
6563645C6D6D6664636C63636465656169665960686561626361605E655E636658636162
5E686356615E64C100000000000000000000000000000000000000000000000000000000
000000000000000000000000
DC666960666866615C646868606A65716B686C5F6B666469696B646C6871636B6B6A646C
706869706A686966696A686D6D6E6B6E6E72706F686D6465686B6967636E6B6970707973
6772746B6E706C63696B707A737C76717479797672787C8282797E787C777678777B7B76
7B7C7D7E8080817F7E7B7B76787E797A7F858081817E7B827C7C82888189888888858681
908686818A8B84868A8C8B8E8E90938C9090928B928E94988A91909692949A919196988D
9B8D999B9A9B939B989090919291939493959498A1979EA0A49EA2A1A2A19D9C9EA2A1A6
B0B3ABB3B1B6AAAEABABB1B0AEB4B1B2ACB9ABB3B6ACB5B6B6AFB5B6B9B4B9C0B4B5B8B3
B0B6B1B7B2B0B8B1B1B5BAAEBABFBEBFADB3BABDBAB8B0B5B6B8BCB3B3B9B6ABB4BAB3B1
A4ACB0B4B4B9B1B2AEADB3A9AAB0B1AEABA9A6AEACA6ACA4ABABAEA0B0ACA7A6A3A7A5A7
A99FA9A0A79CA3A59CA49E99A198949B99A3969A949B948E998F929090939D989C8F9393
8C918E8E938A94928A83938B908C8C908C96988B8D8B8C908784887C83847E797E848082
79817D7E807B7B807A7B7A7B797A787A7771787373797073777376727474797874707371
7070746E6C726B6E6D6C736C6C6B6C70696B696D6B6B6B646E7566736C66726963666767
6266676D61696966666E6E6B666460606469616364636167665E62615D5E6E6163606360
655C6161635E60C900000000000000000000000000000000000000000000000000000000
000000000000000000000000
D66660636066655E636B6668666B6B6463666A6C6B686174616B686C666F6A6E68686B68
696C67656C6A696D69676B686A68736C6B717073726A6E696667616A6667686B706D736B
67716F706E61646769677379776E797379767471747F777E797C7978727878777E817975
8178767F7D837E7579797E737F7B7B7E7B8286807D868482898487868C82858983848F84
8088897E8688968C91838E8B8E8B8B908E8E8B8D8D8E93938E949394998F989690939298
97959693949793918B9498968C8D8B93919992A0A2969EA6A3A2A1A69BA19CA8A8A0B1A5
A9B3AEAFA9AAAFA5ADABACB2B0B3B9B4B4B8B6B9BBB9B2B8BAB8B6B7B9B9B7B4C3B3BDB5
B3AFBAB3B1BCB8B0B2B7C0B4B9B4BCC3B6BEB9B1BAB8BDB4B0BEBCB6B0B5B1BCAEACBEAE
B0B8B9B1B6AEBBB6B6AEA8AAB2AEABA8ABB2AEADABA8A8ACA7B0A8A6AAA1A9AEA4ABA1A3
A999A499A49CA3A1989E9A9A9C97989A9D969A9B91969E9DA29D998E9B94949294968E8C
8E948A908B9688868B8A8E9388938C96908E918C89908E8481808985808282838579817D
7C7E80788275807B747F7F767A75747173717E7B78737B6E7874767A796B737271767371
747071726E74746F73666B6E71636E746C6B6B69646A746F69716868696A6B6D71676E67
6664636467646C666764686962666169666663616364646463616468605F616263676263
645C5B61645E64C700000000000000000000000000000000000000000000000000000000
000000000000000000000000
DC68665E6368646968666666686B646B67646B6470696961636865636669666F676B6668
6A636965696B696E706970706B69696878666C6F747266646866666970736F6B6973746C
6E6E6C716E6C696B66717170727B727B7A7979788171787D7C7C7A7A747E787C7D7C807C
747D80717C7B79837B81777C7E7A7B7D7E818481877C80837E8581838284818889898988
89878D878B8B888391928F898F908F918D8F848D96968E928F9796998E8E9093A0978B91
9793949B9793949191939596939391929394A2A29FA3A4A4A3A4A4A3A6A59C9DAEA0A6AB
A5B0ACADAEA7AEAFB3B4AEACB8B8B1B8B9B9B0B0B5B8BDB8B4B8B5BAC1B7B4B6B9B4B9B9
B9B2B3B3B5B4B5BCB7B9BABCBFBEB7B9C3C3B8BBBEB7BAB6B5B8B6BFB5B4B6BABABAAFB9
B3B0B7B4B7BBB0ADADB0ABAEB2B6B0ACACABB0ABADB2A9A9ABABA9AEAD9EA4A497A4A0A4
9EA7A4A4A2A5A09E9C9BA1A1A0A39BA3979C9BA09E93969898959896939A968C998D9391
8E8C918D87868990908E8E87918B93939791938A908B8F82828683817D837D7E8280807C
83807C7D797C7F7C7B707B7D797E73717B7E757C7771737473727073716C717373767378
6E7971756E68716E6C6B6E706E6D6F6C6C6D6B6D716F6E6E6F766A646E706269636F6B6C
6C6B69666A6D6462646463646C6764696163695F6160616664616564636061656063615B
6063685E5B635FBE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D8615E63605D61665F646968646F6462676B6C6C666E6A646C6A67637066696B666C6C68
6968696E726A68696970676B6E716A6B6B706B706E716A6B6F65616B6B6F6B716A6B6C66
6A7175706B696C6E667571777C77777071787E7B73777D7C737B76797C7B7975797E7774
83777B78817E807E8180807B797E88868382787F83818B867D8A82888187858C8C84888C
8789868C8E90858E908C8A918A8F898C84908E8C8B96908E889094939D96949E9A9C8E96
999B91969B949496999B93919293938D9493A09CA3A1A9A1A8A4A09BA1A1A19EABA2A9A6
B1ACB0A8B0B0B6B0B3B0BDB4B2B0AEBCB8BCB8B9B8BEB9BBB8B3B9C0BEBCB9B6B8BEB4BD
BFB6BEB7BCB6B9BEC0B6B6BFB6BBB8B6C7BFBEB7BBB3BCADB6BEBBBCB7B4B2BBB9ABB0B4
B7B2B9B1B7B1B2B4B3B1B6AEACB9B2AAA9B0B8A9ACA6A9B6AEABB2AAACA8A8A99BA3A4A3
A9A8A28EA19E9BA2989C97A0A2949D92989C9798A1A09A9D9890929B96948B8D909A9A97
8A8F948D8B8E8E918C8984948F918E918C8A89918E8C9189817C7E84898981848383817F
7884807E867D7B7F7B7678797B727B7680737777797C796D797B7474736C707371727071
73736F746E73756D79716F707774716F6F76697072736C726E72696D7069726F6F6C6E6B
696A686770676B67686D676869645F60605D60656167645C63676362615D606264615F63
5C5C566366595DC900000000000000000000000000000000000000000000000000000000
000000000000000000000000
DB5D605C67615F5F6862675F6968696868647164646968646662686A646A5C676F6D6A66
6E646765656A6A6C706D70676A71736C706D6D746C6E666C666F68696A6E6C64666E6E6E
69696A6E6B686E6A68716975727C7B7678767878737B78717D73767B7D778083717D7876
767C7878857F7F837E7F7E81807E847C7B7A838886857790817E828B8484808B8A86878B
898D8D86888D898B8E8B909089878F8F91938C888E9395978E949098969391929696958E
959B93949C949E959298919293949896969FA3A0ADA9ABABA3A5A8A6A1ADA0A19EA9A6B3
A7A8AEB4B4B7B4B8B3B1B8B7B4BAB6B4B3B6B5B3BDB3B9B4BABBB9C1BBB8B9BCB9B6BAB8
BEADB3B1BBBCB9B9BBB7BFBEB4C5B8BCC0C5B9B8BFBEB1BDB2B8B6C0B8BCBEBCB8B6B7BC
BDBEAAB8BBB7B8B2B8B0B9BEB1B1B1B4B4ABAEAAB0B0AAADACA8ABABA4AEA3A3A3A6A5A1
ABA8A4A5A0A29C99A19EA59CA0A49EA0A09A969C9B9B9B9196999398979A94978E909698
939894958E8B8B9187889084948A90978E829392848C8584818486847B87818484868A7E
7F7C7E7A7D7C817677757B7B7976787779787473767A747279797679707271756A7E726D
70706D6E736F727073746E716E706F77626E6C69676E696B6C71706E6E73726F6B71686B
6E686C6365666564696969656669606165656864655E66696464686163695E6366596766
61605E66616460C800000000000000000000000000000000000000000000000000000000
000000000000000000000000
D260595D60625F69615F68646569696369656B66676168686465646D6F68686C6B696867
6F676A66686E69656573636E6A6F6E69726A6E686E706B606E68616869666C696B6D6A6A
69666E687066696E6D757176797B7A747574727B7977737B7A76767475847A797E74807E
7C787E797A7E7B7C7F7C76797E81807E7D80838182868B8B7D8C848886868687868D9087
8C8688819089898C8D918B8C868C8B888D8D918C8E8C9990948F9B9B9296919798999596
9C9193989F9999989C9D939C9B929897999AAAA1A4A8A8A5A6ABA9A4AEA899A3A1A3ADAB
A7A7B4B8ABAEB2B4B8B3AFBBB2B8B6C0BCBFBEB8BABCB6B8B8BEB8B8BEBBBEBAC1B9BEB3
BBBAB8B7BDB7B9B1BBB6BEBDC6C1C0C4BEBDBEC6B9BCC3C0BBC2BDB7B6BBBFB9B8BEBBB5
C0BFC0BCB4B8B8AEC0B1BBB7B8B6B0B0B6AAB3B4B3A9B9B1ABB1AFADADA8A9A5A9ABACA7
A1A6A9A8A3A2A39D99A59E9B9DA6999F9C93A191A19CA19D8E9D9997959C9992948F9494
9490908D8C8E8D8B918C888E8C908E8E938A898B8590908387828380888A8081837D8783
7F7E7C7679837B7D79808079797C767473747875747C7073746C797871746F7173717573
6B76707972726C716F6E71716B6C787263696C6D716E706A6C6878767379737166726C69
6C666966666B6B6C6262646466636362636664636467605D666A6363645960605B606168
62646A62686060C400000000000000000000000000000000000000000000000000000000
000000000000000000000000
D65E61625B5B6361685C6367676666696365676B6A61636B6B706468696768706B606B64
6465696B6A706F6C69726B7269747466707368707470696E676C6C6E6B6E6C696B6A6A6F
6C6D6867675E6A747579737477766E7678757479747679707679777F807677797B80797A
79797C777B78787B8483857E7C80818381818583888385838086878388848B8787858688
888C8885808C8A8D908C8C8994938D949390898B91938E8B918C8D989798948D91938E96
9395939998989C9A9B9A9B98999896989FA1A4A1A1AAAFA8A6ABA4A6AFABA8A9A1ACAEA9
A8AFABB0B3B1B8B7B8B5BCB5BEB3BEB3B2C3BDBCC0BEBCB4C5C0BBC3C0B5BCBDBEBCC3C0
B1B9B2C4BCC3B8BDBCC1B9C4BEBFC4C3BEC2B3C1B7B7BCB9C4BBCCBABEBBB4BCC1BFB3C2
BBC1B9B9BAB7BDB5BCB6B4B5B5ACAEB6B2B7B1B2AEB5A4A9B2ACACABA1AEABAEA6ADAEA3
ABACA3AAA8A0A2A8A1A09BA09B979E9A9C9FA1A3949E9F9C96989BA19A8C94959293988E
8E9894909388908C8B978B98948E90918E8B8E8184848981817F868580878586807B8781
84827F8B7E7E7980777E76807978787E79767879717270746B7B707076757673746C7171
736C7971697070747273696E77746D696E607369716F6C696D6971646B6B706E716E6B68
61656D676B6670666761646B67645E6968665A69645D626666596C585F6D616263656060
62636161646360C400000000000000000000000000000000000000000000000000000000
000000000000000000000000
D85E5A5B5C606352675E675F5F696B6367636D6B686A6766686B6E686B66656868666965
73696A7067696C696B6864686C6E6A6A67666A6E6D656C6A66696A686E69616E6A656C6C
67676C6E6D686C6F75726E71727A78767B7676737C7A7A757579778180797983807A7984
71797E73797C7680837D817F7C7E828183858186848984888589867E837F8C828A858B8A
8689888B91899391908B8F8B8D998988919089928C94909499968F96919C979A8EA09898
8D989596A09B9C9D9F9FA1999A959EA19FA1A5A7A7A9B0AEAEA9ADABA6A2A9A9A9A5B0AB
B1B5B6BCB1B8BCB2B0BEB8B9BBB8B9C0B9B6BEB9C1B9C4C7BDBBB9B6B8C0C6C4C3BEC0B9
C4BCC0BCBBBEB7C4C3C4BBC3C4BAC3BFC1BCB5BEC4C1B8C2BCBBB8BFBEBBBBC1BFC3C1BE
C1B9B8C1B4BEC0B8C1B7B1B6B6BBB2B3BEACB4BCB3B1B6AEBBABA8AFAEA8A8A7ACB1AFAD
9FADA4AAABA8AAA0A99EAA9EA29EA2A1989B9B9AA4999C9B989A9298968C99968E939594
8F8D8B8E888D8C89878C8B93918A878B87838E8986898888898C8387838B7E897C868681
8182797E78827D7E797C797976777B73767E7A7B74827C757174797C7277706E71797871
6B6C6F706F6F717178686E69766E706F6C75706D70756D716C6B6A706E6C6E6D666E6C66
6467676B666663616763666163686766655F69656864655C6863656B6563615F66646A60
615B615D646065C200000000000000000000000000000000000000000000000000000000
000000000000000000000000
D45D615B66616361665C665D68656A6A656769686C686B6661676A66676B6E666A6B6C61
676C656E70666C6C686A676B6A716A706F666C6E6C74696F646A696A7070697464706D70
6C6E6E7072736871727876777579737877707178757B737B78797C767B77767C817D807C
7E797A73787D8079887C7E80838881818187898289848784878186888C8B898684868889
8685848B8C869190918C8B94948B928C90948C948E929393978B9496979D9C9A9C8C9294
9193989798999E9DA0A2A19BA6A09B9CA39BA4A7A6B0ACAEA5AEA0AEAAA9A0A4B1B1ABA8
B0B6AEB1ACB8B1B8B7B6B5BCC2B4B4B9B6BBBEC1C8BAB6C0C0C2C6BAC1CAB9C0C0C9BBC0
AEBAC0BDC8C6C6C2BDBCCABCCDBFC4C1BCC8B9BCBFC1C2BBC0BAC1B8C0C0B6C0C4C6C4C4
BEC0BBC4BFB9BEC3C1C1BBBAB6B2B6BEBCB6B6ADB5ACB5B0ADA9ACB4ABB1AAACA8B0B0A8
ABA2A4A9B1A5A4A3A3A4A69C999DA7A1A19E9DA4A39C999E98979A9894968E908E8C9595
9493948E8D9390919391888F85838E8E8E9090858983808E7E857E87838487877C7C8685
7A807E81807C83797C78797C78787B7A717974737A76747570787B726F76717374717470
71767370747070737569746E7170737570686F6C70666C68736D716E6E6D6E69716E6B66
6765616B6C6B68686265686766646363626568645E636967656C6666636466665B636063
65616160646465C000000000000000000000000000000000000000000000000000000000
000000000000000000000000
DA616063636062655B5E62646861626363646B6C666D696C6E667068676C6962626C6D67
676E6B6E6969686A6B726C6B6B6D6B696C70646F716C6B68686466656F67666D6E706F69
6C706B69716D716E756F707275726E79717879797F75717B7D797B7A767C78787C7B767A
737B77797C7B7E7B7979787F7C897C838489868986898A868E8487888D858E878088898B
8489868C8C8C8F93938E8C96908D8C998E8A948C9195919992999A9A9498969AA1949495
96A1999B97A69DA49DA2A398A9A69C9C9CA5A3A9A5ACA4ADA9B1ADA8A8ABAAACADAAA7B3
B3B8BBAFBABBB9B6B4BFB8C1C0C1BBBBBFB4BEC9BBC0B3BEBEC2C7BEBCBEC1C4C4BDC6C7
BFC0C9BFBEBFC4C0C6C4C4BBC1C6C8BECCC8C3C4BDC4BCC4BBC7C4C6C4C5C0C3C1BEC0C3
C0BBC6B9C3C2BDC1BBBFBEB6B6B6B4B4B9B0B9B6AEB0B7A9B0B4B5B3ABA8AEB3B0A9B0AB
A3B0AAB1A9A9ACA4A79E9FA69B9DA19CA4AB9B9B9CA09F98A09E969693988E9394969198
9692938F92958E8B8D94878B908E93878E8A8E8E86958984878789897D8B858686857D83
81817E7E7E847F7E81767A787C777C73787479777978727B7C7778747479717870737876
776B76769E6C7370766F726969707671726E6C6A706C756168696E6C73746D6E716A6868
64666C6660606C5E6969636363606466616867655D606A6A69656F686866645C66646661
636363635F5F63BE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
DF5E616869646269665E5B65686465666F626B686569646164696F6A666F6B656B68696D
6C746B616C69706B6C69686C666D6A6C66656F73676B6B6669666E716E6C6967686E6E75
6E6A6D6D6E717174797674757374767C737578756F717A76767E818174807679797B7B81
7E797B827B7C7179807A767C8781827C86818681858489898B8A818888848E8186898785
828488868C8F8A8B938E9190909086898F8C908F9191929894918C978E9B9C98969C9D97
999D9BA59B9D9A9EA0A09DA396A6999E989BA59CA8A6A3ABA8AAB6A9A6AEA9AFA4AFACAC
B1BCB4B4B3B6BBBEC5B8BEBBB6B6C0BDC3BCBCBEBCBEC0C7CAC6C4C6BDC2C6C4BCC8C6B9
C4C9CCC0C5C5CDC2C8C8CCCBC8C8C3CCC5C4C3C2C1B9C4CCC7C1C0BECCC4BDB9C0C8C4C8
C7C5C3BDC3C5C4BDC1B5C1BBBBB8B4B8BDB8C1B8B7B4B4C0B6AEB0B1ADB0A3A5B1B5AFB1
ACA7AEA4A8A5AE9CAA9FA3A9A0A49CA1A4A999A39B9B9E9B989C9B9B9896A09D9A929B90
91928E909895938B93908B9392838B8B8C888B86848383888E878289837F808482847D87
807F8680827F81807F7981797D8082747C76747A7C777874757676767470747778797175
797470738379717172697B737874716F6B73756C7373686D706F6B696B6960636B6B636C
6A69646665696A6B73706069646561645D5C616164696869696B66645E63686063616160
64636063626364CC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D56367636168646C626162646967656C6C63616C64666D636D696B686663626C65676970
6C616B66696E6F68706F6A6F6C6F707269706E696C6B6C6E69676C6C6E6E736D716F6E77
726973716B76767179717E787A787F79707C75726F766D74707471797879757E797D7D75
7C787D79857977808583787D80808786808779868B8683898A88848A8188888C8890848E
868885878A8C8C918E958B948C908F8E869193929590958B9196919E9792949AA0949D90
99999E9E9DA49F9EAAA5A7A6A19698A3A1999B9EA5A6A9A8A9AEA3A5B1ACABB0ABB1B0B9
B6C1BCB4BEBAB3B5BEB9BEBEBCC4C0C6CEC2BDB9CBC0C3CAC1C1C4C7C1C7C2BCC7CEBFC0
C6C6C6C1C0BEC0CEC8C4C6C7C6D1D0CCBEC6C7BFC8C4C8C2BDC4C7CECBCCC4C8C8C4C2C5
C6C1C0C1BDC1C3C0B9BBB8C3C4B8C1B8C0BCBCB7BBB0B4AAB6BAB1AEA9A9A4A9ACB6A8AD
B0AEA9ACABAEA3ABA29CA6A1A0A6AAA2A1A3A69BA39BA0969E989B9B9C9996959C959794
9192989089918E918F908E8B8B8E838B8D8D8C8C858B88888D8886848B8889868183847B
877E7A7B8180837975717B76787C7A7980807A787571767B737275727377777471717B79
73747B76707077736D706E6E74686D6C6B6B6B6D6D6A676D6B6C6B6C6B66686A76707064
646969696B6D60606E6A636366646D6669666C5C5F6663716F6E726F6C676563695E6468
6360665B646062C200000000000000000000000000000000000000000000000000000000
000000000000000000000000
DC636269646E6361605E65615E686368686A70696E6A686F686967686C666B6369686866
6D69636A6866676D6B6E70766A6C70706A666C676A6D73716A666B6F666A746B7271746B
707071686E7074787E787D7078757A777B706E737178767979797B7B7A7E747C73797B77
7D7D7D817A7C737B837B8480807F80808488868B888A83898C8E8C88838888887D8A898B
8E8E89848C888C918C8C968C918D898C8E9195908D9690958F93979F919C989C9E968E94
98999B9CA2A499A3A1A2A4AA9C9FA19B9F9BA1A19EA6AAA8ACA8B0A6B0ACA8A5ACAFB4AC
BBB5BBC0B1B5B8B9B9B6BCC0C1C0C6C4C8BFC1C5BEC4C8C8C7C8C4BECBC8D0CBCDC9C7C6
C7C5D0C2C6C6CAC9C9C5D0C6CBCAC8CFC8C6C8CBCCC6C1C6C7C3CBBFC2CCCECBBECEC0BE
C6C8CBC2C0CBC7C3C0B9B3B9C4C0BDB8BEC2B9BAB4B4B6B5B1B4B1B3B2B1A9B0B0A8B1B3
A9AEABAEA6A5A6AAA6A9A8A9A9A6AA9F9DA39E9DA39F99999E9394A196999B928D919793
949E979390939B948D978E9091948B8F8B8889848D869086898B87867E8C868581858483
8179838180807C7B787C7B817E7C7E7876757A7771747E77717B776B737775736F737879
786F756E76766E73786874716D70706C706E776B6B7373716872696F6C7369695D6A6969
68696B69685E64666369666964616B61686A66605E65676C766E6D67626468635D686364
5E675E6163665CC200000000000000000000000000000000000000000000000000000000
000000000000000000000000
DB6661666A656C61625D5E685F5E60636862656E66636868676B687169686A636F686E6C
64646C696E6A6A6A6C69736C7468696E74716C6E6D6B6A6F6C727371736C6C6D746D6E73
73706E717671727E6E747D7B767B6F7B79777678737476737B7E7B7E797E807A7A757580
7A797C7B7B7B7D7B79847A7C847C7B81837F8589828C8783888888868F87898684868B8E
868E888B8C868E8D928F908D8F8893968C928B94909693939C989498929EA1949B9F90A5
A0999B9FA0A4A3A4A3A7A7A4A3A19DA0A0A3A1999C9CAAA3A2A6A0A6ADAEAFABB3B4B0B3
B9BCBFBBBBBCBFBCBFB7C2C0C4C0C0C7BFC6C4BEC6C5C6CBD3C8BEC8C5C9D0C6CCC9CEC6
D1C8C8C5CAC6C4D4C8D3CED4D0CACCD2C8CBCCD1C8CFC9C9C7CACCD5CBC4C6C3CEC6C6C3
CDC0C9C3C4BBC3C4C2C1C6B6BCBFC2BEBDBBB8C2BCBAB4B9B0B3B6B6B0B9B2B2AEA5AEA3
A6A6AEA6A3A7A6A5A3A1A0A3A9ACA7A6A1A5A0A09AA0A0A7A09C9F97A09F9B999B9B9A96
94999798989293908F9891898C8B8F87878B8889898E8B8883868686858D848186818481
8284798381848283787C7E79787980758079797F747B7B7C7874766C75736E7B78787375
76757B746C736D6C727974796C7B786E6B707271716C6D656E726972706E686B686E666D
696A6E6C636C6C63686363606B6864696265606466686B6C736E63646968695E6361615B
61636359646060C600000000000000000000000000000000000000000000000000000000
000000000000000000000000
DF65656A6568616061645E665C60686663656564686B6E67676C6B6E736E69636B646F6A
656E6E6A65766E656F69686B6A6E6B6B696D6D6B6D6A7172706B69727175736E736E6C73
716E6E707373717875747377777A76746E7273767777787E807979847F8280807B7C7B7B
7C757E827D7B78807E7C80857C8583837F827D8188838D8789938D848E8A868283918888
838989908A8F91838F8E8A9096888E8991918F918E93958F94969C9D95999B96A3A49E94
9A9BA2A3A69BA4A0A09BA89EAEA49E9C9E9B9F9CA4A2A5ABA8AFAEA6AFA7AEB0BDB6BBB7
B5BBBEC0C0C3C3BBC6BFC1BDBDC6BCC6BEC6C9CBC4C7CBCCC9C4C9CAC8C5CCCECCCCCCCF
CCD0C7CBC9D0D1D2D2D1D6CED4C8C9C9CCC9CDC9CEC7C8C2CEC4CFCED0CFCBCBC6C4CEC8
CDCABCCEC1C4C4C1BEC4C2C2BEC2C0C1BCB8C0C5C7BBB6B8B4B3B7AEB3B2BEB1ADB2AEAE
A4A8ABB4ADA9A5AAABA1ABA8A9A9A8A2A7A3A19AA1A19EA69FA09F9B9A9C9E9794949197
939797949199958E95939594938390988C8B918E86878B847B8785898C8A847D80818983
81887E7D7D7C8083837B7B867C78797C767E7D797B73797E767B77707C76797575717476
7076796D74776B787171716E73736C6D736D7071726E6D6B716668696E696668676E646A
6363666563686B62526368676568666C6366636A67636C7167656B69635E5D62635F5E60
5E666365606064C300000000000000000000000000000000000000000000000000000000
000000000000000000000000
E16869666367666966655E616664625F6664666765716467646C6B696A68666867636F6B
6A68686F6E686E6A68666A6E6C706A6E6B6B706A73746E6C70686B6E716B727468727971
72706F7773767475787B7075767073786D7476736F767D7C7D7C7C80768373817C7B807C
7D747480797B8181838080827E7E7C7F7E858583898481848F8391888A837A8985868E8E
888D89879090939091938E8F8D95938E8F93938B9691909C96959194989B9DA4A1989994
99949B9DA399A3A4A4A1A8A39CA8A1A3A29B9EA1A1A9A4A9A6A1ADAEADABB6B0B3B3B4BE
B7BCBDC2BBC5C1C3C0BEC3CAC3CBC8CBC8C6C6C9C7D0C9D2CDD3CBCCD4CED1CCC9C7D1CF
CCC6C9CECDD7C8D6C3CDD2C9D2D6D4D6D5D0D1C9CDCCD1D3CEC8C6CDC8CDC4C9CBCACECA
CDC7C2C8CBC4C2C3C4C9C3BEC1C0B9C1B8C1B9BCBEB8BBC1B4B6BDB9B0B5AEB8AEB6A6B0
B1B3A8B0AAACA9A59CACA6A1A1A0A6A6A99FA5A29EA39EA3A3969E96A19B95A09A9B9C98
979896959D9291968E918D95918E93918E8E8A8A8787808984888B868488818C8084848B
837B7C817F817E8387747C7C767E767478737783857676737D6E7E7574717B737376746F
767E716D70787674746F736E76726A71707369716B6E6C736B706868686A606A66686C6F
6770696B6C6367656C69686164676562645F6662635E666E6A675E6B66646369675E6364
68665E635D5C61B900000000000000000000000000000000000000000000000000000000
000000000000000000000000
E2686463686F6658645C6365625F6E696B64696E6C67696E636A6666686C73686B686C69
6B73696A60676F6A706A6D70696F6F73746C6C6F6B65706D69686D6D6E696B706D6D7774
706E7171747B70787674716971786E6C7C78727B747B797A797F7C808279787E807C7C7B
7E7975827C7C768077817C7E83837F8684837E82877F8B897F898D858B87868E8B86828C
8A8C87908B8B8D8B89908B918F91958B89928E938F99969D98999898A0989CA3A39CA0A1
A4A69E9EA3A99FA39FA4AAA4A6A3A59FABA1B0A4A5A3A9ACADACB3B2AFB4BAB4BEBBC5B9
BFBAB9BCC8C3C8C8BEC7C0CFC6CACAC2C9C1CBCBC8C9CECBCCCBCDCECFCCCFD4CDD1C9D9
CACFCFC8CCD1D1D0D1DBD3D5CDD4CBD1D4CED1D6D4D0C7D3CBCBCBCBCBD8CBD0C5C9D2C3
CBCEC5C8BFBCC9CCC6C8C6C1B9C9C4C2C4C1C1BAC0BABEB6BCBEB7B3ACB7B7B6B6ACB4B1
B6A7B0AFAAA8ABABAFA7A4A2A9A3A6A8A8A7AAA8A6A0A19C9F989E9EA59E9A9895919996
96909D9897949D8E99938D95948C8C9190918989918A8E8A918888878686848489838181
767D847D7D7F818076837C7C737E767A817B788275787B7375767D78777571777A717674
727371737370787276717873707671716C756C70726D6C6E66656B6E6B686B686C696865
6B6B6B68636E5E646864606C6961686C686365656261686668686B645C6263666566615F
69646266646461C600000000000000000000000000000000000000000000000000000000
000000000000000000000000
E16469616968686163676168645F636468646B62696B6260626368656564706D64696B6B
686B66706C6A6965706A717071707072756B766C6D6C6D6F6B6C6A6A716E6C6471726F73
7776737B6D697074727376756E7171706E767973777A76787C7E8484817B7C7C817E7E83
767A7E79847F87798483798082837B868185828682898B888B938A8C8C8C90848E8A8D89
8B8C87868B818989968E83888893919091968E98918E98999C98939B99A3989AA1A3A4AD
A6A1A5A3A49DA0A8A49E9DA1A6A3AA9FA6A1A9A69EA9B0B3AAABB0B4B0BBB7BBC3BABEBD
B7C3BDBFB9BBC0BEC9CBC4CDC9C3C3C8CCCBCBCCC7C9CBCCCCD0D0D5CBD1D4D4D0D7CCCA
D1D3CED8CBD8D4D8D0DBD8D8D3D1D3D6DDD8D1D6CDD6CFD6D8D6D8CFCECED0D4D0D3CDC8
D0CBD1C9CDC8BDC3C8C6C6BAC9C6C8C0BDC7C4C1B8C3C3C4AEC1BCBEC0B8B3BBB8BEB0B6
B2B0AABAAEADA4A6A5A5A6A9A8A7ADA6A8A1A6AAA1A4A4ACA097A8A0909C9F9E9B979E91
9894989C979394939C9091978E90908C898C8B8B8D8C90888F908F87878B8A88817F7B84
85887E80867C777789847F7C797A7A7F777B7B79817C787773787E718476747073747671
7C737075736F7170727676757975756B6D6B6D676D70697263697071686F6C666A676B63
626C6C65646F696063666E616964696463606B686467696261666665645E636965636363
6164625C656159C200000000000000000000000000000000000000000000000000000000
000000000000000000000000
E36463666861646C645D60625B636B64646B69666469666662656566666C68626468766A
666A70686E69686C736E6A6B6E706F7269686C6C6C6C66646F696963716771706C6E6E76
706D78737478736B75747A7573756F7171757673797476807A8088847F7B817B7982737C
717E7E837B80857C7E7F7E7D808680828688848D8B8486868C89848E8A868A898C918290
8E908C88908C8D898F898B8D908C838B948B9D958D9995969E9F9C9EA3A0A2A0A2AAA9AC
A89FA3A0A3A09B9EA69F99A1A2A4A9A9A8A9A5A8ABAEB0B8AFB3B2BEB8B9B5BEB4C2C2C2
BEBCC2CAC4C9CBC8BFC0C4C3C9C9D4C8CECBD0D3D0CAD0D3D4D5D0D1D7CDD4D8D3CCDADB
D1CACDDED0D4CFD5D5D7DADED1D6D5D9C6DBD3D9DAD1D4D1D0D8D1D7D4CFD6D0D3C8C4CA
D1CAD7D3CBCCCECEC5CBC9D0CCC4C8CAC4C2BEC3C0C3C4BABDC0C0BEBCB8BBB9B8BEBBB5
B6B3B5B4B0B3A9ACAEACB0A8A9A9ABABA3A4A9A79CA2A9A4989EA6A195A1A09E969093A1
9196949D9E9B91959294908994938C908A988B898C8D84898C9192858B878C8C86888B80
837F7D7B81797F7C7A797C7C837E7E74758280787977797E7478717470757476747F7570
6D7371767270746E727675747677776B756B6B687169706E6F716D6973676A766B666869
6C636563636B666465686A666A66686D6467676B61666067636865636364696262636661
60606166685D62C700000000000000000000000000000000000000000000000000000000
000000000000000000000000
E669616464645E666566646761686A6663666169666E666964666366746F606A68696568
6667686A656E666D68686F696C726E746B666E6C65686765646869696D71666970767170
736B7476747470746E7F70756F7273716F7378747C737F80807C81848381807C7B7B7978
81797D7F7980827C88867A817E817E80807B818B8186898A878A8D868E8984918F888A8E
86899089928E848687898B898B8E8E8E958D96929698979C97979B9D9D969FA6A89FB3AA
ABA7A9AFA7A09CA7ABA5A3A1A9A89DA9ADA2A7B1AEB1B6B5BAB4B8BFBEC1BCC0BDBBB7B6
C4BAD0BCC1CBC0C0C3C5CDC5CDD0CED1CCD6CCCBD5D0C9CCD9D4DED9D3DCD7D5D0DACEDE
DBD8D1D6D6D1D6D6D7D8CFD7D7DDD1D6DCDDD4D4D0D9DDD8D8D3D3D1D6DCD9D0D3CCD3D1
CED0CED3C9C7CCC9C8C3C9C3C9C7CCC3C7BBBEC0C0BFC2B9C7BCC2BBB9B8B0BABAB4B1B3
B7ABB2AFACB4B1A5ACADB0A6A7ACABA8A3A9A0A3A4A4A9A2A8A49DA7A39C9899999C989B
A49895949897928E96948D8C8E918D88948E928C908B889A8C90848790868586807E808A
828582887E838384847F7B767478797D7B797A7879767B7972796E73716E7D7577777370
72746E75737271736F71717A716E726871716B6B6E6C6E696B666D6E6C686A686869716E
636E68606969676A6367626C666B66656D636A666D6C6464646267666660686463676360
64685A675D645EBE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D76F686762606B5E5F5F636464645D676969696B685E63646765686E696B685D68696E69
616F6867676E716D7069676C6B706C6D6D6E6C6C6F69696A666868726E6B706C6B72696F
766A7870736971777170716C71736E6F77767A7D717476797B7E7A817E7C7E7D797F7B7B
7D7E81807C7A8185748884848083817E80838686838E8684898D87868E848B8F8A8A8E8C
928E8B8B8A878D8B8F928887898B8C8E8E8D908E979B9C919B9D9C919E9EA8A0A4A2A6B0
AEA3A3A49FA1A1A09FA29CA4A3A8ACADACACACB2C0BFB8B4B9B2C5B8BEB7B6B8B8BEC6CB
C9C3C9C3BEC3B9D4C8CBD0CAC7CACDD3CCCFD1CDD5CFE0D3D1D7D2DBDEDCE0DCE3DED6E1
DFDBD1DEDDD8DDE1DCD9E2DEE1E3D7D7E3DAD6D7DBD6D2E0D6D4D8D7D6D1D2D9D9D3D1D4
DBD9D1CFD6CBCCCBD3D1D0CBCCC8C3CBC8C7C6C2C4BEB8BCC3C1BCBEB9B5B7B5B9ADC0B4
B0BAB4B0B1ABB3B4B0B1AFB0B1A7ABA8A6A8A3A5A59FA0A4A4A3A0A1969E9A9E97949E97
9291939C9E9C929094938C93908B998B8C8B908F919191908C8B90898C8987888A838084
7E7F8386787F84837C807C787A767B71797E7A797B6F757C76757B75707679797D787973
787376716E7C6E7374736C7470716C7A6D6C617570737470696B6C69646B6C696F616765
6E696E6B6E66686468616467666869646B6C63646664666A666163636464635966646869
6060615E606659CA00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E363606064686E616461645F696960636560646B6C696E6A68656D666864656864766666
686E736469696E6C686E6A6C706C70706670726B6C666B6C686E6C6F6F71696E6B706E71
73716B71797572716E716D6E7874737870736E79767B797B7C82837E7F7B79797E7B7781
7B748080807E8480837C7F7C807E848789807F8D8881838B878B8B868F909090888E989A
8C8F8B878390888389908F8B8D9094948E938F979A8F9D999999A09C9CA7A1A2ACA6ACAD
ACB5A8A7A4A5A7A3ABA4A2A8A8B4ACAEADACBBB6B5B8B3B9B9C0BBBCC0C6C2C1CDC1C2BE
C5CACBD3C7CBCDCED0CAC9CCD7C9CECCDAD4CCD2D4D6D6D8DEE3DCE1E1E3DCDAE0DEDADD
DDD9DCD7D7E4E4E1DFDDDCDED9DFE1DEDEE8D8DEDCDEE0DDE2E4D7DCD9DDDADDDDD3DBD7
D6D1CED0D0CCD3D6CFD4CBC8C9D1C8CDC7C0C4BCC0C4C7C3C0BDC4BCC0C4BEB8B6B9B6B9
B8B1AEADACADB2ACB0ACB2B6AEA8A8AAA8A6A4ACA4AAA3AAA2A19E9D9AA09FA5A1A09698
A09B9A9592929B93938E939192959094909391898B8B8C8E918E898E838E8B8485897E7F
81827F86847A807C867E7D80787C7B837E74797C7B72787B7370797C7479706972737070
737071767476757B6E6F7070716F6C77746F70747469726770716D716B636867646C6869
6B676967696C66686B6868626666685E68666463636D6466686F606361686664675E6963
62616366635562C300000000000000000000000000000000000000000000000000000000
000000000000000000000000
D966665E5F68686461615B626B686860666666666B6D69686564686364656E676E66686D
6E666C6D706F6A696B706B6C706C6E67686964646C68696E6C7368696E706C6E6C6C716C
717078746E74716B7374696A717B746B737476767278787B8179817B7C7E7884757F7777
7E7E7E787B867F847F828079837D8183808182878C89888B8B8E838990848A908E8B8E91
8B93878B8692908B8C8890918C908F908B8E908E93979494999FA3A69C9C99A3A1ADA3AB
ACB1B0A9A8A8A3A8AEA6A4ABA8ACAFADB9B9B8B7BEB7B3BBBFBCB9B8BCC3C1C6BEBEC8CC
C1C3C8C4C5C2C2C9CCC3CECCD6D9CED1D3D0D3D4CADADAE0E8E0E3E2E0DCD9E5DCE4E7D5
E4E7E3DCD8DCE7DAE6EBDFE7E3E8E0E7E2E4DBD6E8DADBE4D8DED6E0E2D9DCDEE1DBD4D9
D8D9D3CAD1D6D5D0D1CECCD3C8C8D2C9D2C9C9C5C8C6C2C1C2C2BEBEC4C4BFC6B8B3BCC3
BCB9B5BAB5B3B6B2B6ACB3AEA8AAB0ABABA2A4A6A5A4A199A3A5A6A1A89DA1A1A199A4A0
9BA1988D91969492998D92968D8E8D9194929291898C909494938C8E8F84818688898986
887C7E88797C8476857C8186787E787B7C7B8279777B7B7B7679717E767B797479747473
73746C71736F756A717871746D6E736C6D6C746E756B6E6C746C686A6C7171676B68686C
6564666C6B5E6E6162616665656168636A5C66696969606368636464645966646A676663
666460615B675AC600000000000000000000000000000000000000000000000000000000
000000000000000000000000
D7636262645D646964616B68666B6864696C666B6B63696B676C6B66696B6B666B6E6B68
6F6A716869677274686F6A6C6E6B70696D6565696262706B6C696E7473697164686B6F6E
736B716C716E70767371747975717574757174747B777477717876797E7A7F757B7C7C83
7B797F8085837F8784847E868686837D79847C81828C80838E868B8C8F948C938C888C95
908E8887888A968D918D8F8E948C8B8E908E91949B979D9E9E9E93989FA2A69DA9A3A2A7
ABB4A9A7ABACA1A4A6AAB0ABB5B1B1B6AEB0B9BCBFBEBEBCBCB9C1BFBCBBC0C7C8CFCFC0
BFCCBFC9CBC8C9C9D3CECDCFD7D6D8DCD9DCD8DBDFD9E2DBE6DEEFE3EFE0DDDBE6DCE1EE
E7DFE0E1D9E3DEE0E4E4E7E2E1EAE7DDDFE1DFE1E2DCE4DBDEDADDE8E0E2DED8D8DDDCDD
D6D3D0D8DED6D1D2D6D4D1CCCECAD2DBC4C9C3C4CEC0C4BEC4C2BEBEB9B7B6B9B7BBBEBB
BEB8B1B2B1B2B1B5B2AEB2ACB3ACACA3A4A8A6A3A9ACA9A7A4A8A19EA19EA4999E9E9CA1
9E999B9698999A9398948E939694958B908E8E8D86938E8B8D8B888E90898E8980868686
8183888384818081797F7D7F80787A7C7D7E7C7C797A7C767C7470717E7C727572756F79
757270757276736F7876786A6E75716B6B73676E71756E6D75716874727073676E65696B
6E636C6469656669646964646564676669646467685E6668686466606366646162605E60
64605B5C636164C100000000000000000000000000000000000000000000000000000000
000000000000000000000000
DD65685C62635E696E61666667746166656B666B666B68696E6C745C69666E676A6C666B
696B6969636E6969696B69676F6E66686C6A696A6F6A6C6E65716B73767975786E6E6F6C
697870737475717178737471717175747670707870797175737378807C7E7C807B777B83
857E84807F857D8A82817E7B857F7E8886888883878F8E8888898E908E8C8B8B918C978F
8B8D8D898B8B8C89879093998E969B9699919394969B9A999C99969D9EA49CA4A8A8A6A9
A8A1ACAAAAAEADA3A6ABACACB0B7B8BCBBBCB9B6B6C3C2C1B9BEC0BEB9C6C0C7CDBACACC
C9C3C9CBC2CED1C8C2C8CFD8D8D9D3DBD8D1DBDDD4E0D9F0E8E8E6EBECE7E9E8E4E2EDEB
E6E6EEDCEADCE9E1E6E6ECE3E4E8DFE4EBE3DBE5E0E1DFE5DDE5E2DCE0E4DCD8E4DCE1D4
DCE1D3D5D7DCD3D4CED6D6DAC8D9D6C5CEC6C6CBCDC9C7C3C3C0BEC5C3C9C4B7C0B8BFBC
B3B5BDB8B6BDB8B4B5B8ADAEB2AEB3A7ADA3ACAAA2A3A09DA8A39BA6A6A3A8A6A3A3A39E
9E99989598979D969094938D9194908B918E9498908E89848D8B849189888B8381888689
80878486847F81807F797E7F7E787D7C787679797A817678767A80757B767C7A74767275
727770727A6F7771726E717074717171747870736C686C70726A6D6F6E686970656D6C6B
6365646F626468686A686C666C69675F61686A6668656468696661696864666263636259
65686465686361C300000000000000000000000000000000000000000000000000000000
000000000000000000000000
D56861606168666C62625D6C61696B6B6D6A6B69656B6A6B636D676B6F7066696C69696C
716C706F6671706B696E6B636A66686569636B66666D666E707073736F796F716A6C746F
717671747067706F6B717370747C737979747673786E78706F756E7C7B7D7A7B7C7E857E
7E7E79817C827D857F80837E8383838B858C82897F8C8C858A888791908E93978E8E8B90
918D888D8B8988868D90918D989291979A9494948E959C969B9B9CA3A09EA3A4A5A69CB9
AAAAADAC9AACA6B3ACB1B2B4B7BBB9BAB4BBBCB7B6B6BDBBBDC1C1C2C1C3C4CCCBCECACC
CBC9CED0D3C9CDD9D8D4D6D0D3D0D5CED3E0D8D5DCDEEEE0EEF5E9EAE6EBE4E5E0E4E6E6
EBF0EBEEE9EFE7ECE5F0EEF0F0F6EBE7EBE6E8E4E0E6E5E4E4E2DEEAD6E1E0E1E6E1E5D1
DEDCDFE3D7D8DED8D8D9D3D9DCD9C9CDD2D4CBCECAD0C6C0C5CFCDC3BEC3BEB8C5BAC0B9
BEB8B8B4BCB0AFAFB3B0B4B0B1AEABB1A2AEAAA8A79EA9A29EA6A8A7A6A2A69EB1A4A89F
9799949991949990989892979692949591918F988E8D8E8E8B8C8B8A7E888989878D8D82
83818A807E807C7F7D837C7D79807C7874827B7374737C8076787979737E707B74767574
6E7B697072716D727A797573726E69756E70786E707469786C6E6F69716F6C6E6B636A6B
69646E70666C616966666A6164655F6969696C675A6A65686665686868636561665C6266
65635F61686065C400000000000000000000000000000000000000000000000000000000
000000000000000000000000
E16268636162645F6769636968686C64606C6D6867656A68686969666C7066696B6B666B
666C646871736A696E696A67656C686B686668686D6972737677746F70716E7475716B6D
71737A6E736F72736E6F747476736A72787878727076716E736E76747E807983797D7C84
7F7D7C81837D868381667E83877C7E83868B7C84808A8F838C8C8E8A93898C8B848F9184
8B8C86878D90889090929A99998E919B93959190939398959B9999A39EA79EAAA2A1A4A6
A9AEA4AEB7B3B1AEB1AEAEABB1B4B8BBBEC1B4B6B3BCBEB9B8C0C9C8C8C1BEC1C4CFCBCE
CDCBCCC6C9CFD9CDD8D8D8D5D8D8DFDBD7D9DEDBEDE2EBE4EEE8E8E5EBDFEBEAE4EEE3EB
EDE4F6EEE8ECF1E6EDE7E4ECEEEBE9ECEEEFE4E3E9EBE6EDE4E5ECF1E9DFEBDBDBDDE3DC
DEDADFDBDFDED3D4D5D9D4D0D8CDD7CDD8C8D1D1CBD0C8C9CEC4C9C3C2C1C9C5BDC0B6B8
C3B4B6BCB8B9B7B1B4BCB0ADB3ABABB1B0ABB1A9ADAEA8A7A6A1A5A8A2AAA7A9A9A0A0A5
A6999BA09E949C8F979B979193988E889190909A8990908F969190918F8F888884878483
7F868183827D827980817B797984847B7981797B7A807D747678717A7872747378797374
73716D6B6C7478737270706D6F7270706C6B696C6E75636C6F6D6A66636A6C686E656165
686D5B636C6A6B63696961666363616164686D6B656E6C64656863676161606761666766
656463635D6261C900000000000000000000000000000000000000000000000000000000
000000000000000000000000
EC6B6560646863626B6B64646C6B6A7365616C6B6C6C716464696C6C6461696B69686863
6C696C6E6971726A6664666D6E6A646967686B6B666B6F707B79717074726E6F6B706C70
706F787071746D6C716C7B766F6E71767381797176736F6F716E797F7674797E7B83807B
807D7F807D7D807E8580808385838385808B848783888D89878789838B8B948B8C94998C
8B858C8B8E898E888F948E8E9998919B9396978F9496999CA0A3A8A7A4A4A1A6A7A2A6AF
A2AEABB2ADA9B0ADB6B1B5B5B8BAACBCBEC0B2C3C0B7B7B8C2BFBFC8C1C3C5D2C9CDD9D8
D1C6CDD1D1D1D4DED3D4DBD6D5D8D6DFE0DAE1E4E3E4DBEDE4ECEAF1E8F2E8E5E5F2EEEB
E8F4F0F0F3EEF4EAECEBF0EAEEF4F2ECEEECF2ECEBEEE1E8E6DEEEE4EDE4E0E7ECDBE4E9
E0D6DEE4DED9E1D8DDE0E0D9D8D7D7D2D9CEC8D5C2C7CBC9C9CBC6C3C9CEC0BFBBC2BABB
C3C2B6B7BBB1B4B1ABB6B1B3B3B3AEADABB1B2A7B0A9A4A8ABB2ABA6A0A4A1A39E9EA09D
9F9D9DA0A19C929B9696969198989193969193928B938E89938C8993899080868D868D81
83847E817B817A8B827E827B7D7C7E7C82817C7A7778766E7D767B767C817675766E7171
73717477776D716F707873717173716E69736E717168706B696E6E6B6E6D68616E6C6B66
656C6F736B6A5E6B676E696B696268665C6465656965666E67616266646462655B666664
6859666063645CC600000000000000000000000000000000000000000000000000000000
000000000000000000000000
DD636668696A676669676C6B68716967686C727064636C66666E686A666E736864686C63
706F6C6D666C6461676869696D69646D696D696A6B696D6D696672736E74797477707270
6F746E7B757173796C75697970757D767676757B71767074747C716E777C7C7B737B807B
7E7D818689848D7B888583878986878683868A838B86888A8786908C898B8E8D9394908F
8D8E918F8C91949193969C93949B9C939C949796919B92939A9DA5A3A4AAA4A8AA9CA8AE
A8A8A3ABADA9ADB3B1AFB8B8B6B7B3B7B0C1BBBEBBC1BFC6C2C0C4C7CFD3C6CDCECCCBD0
D1D4D0D2DAD6D0E1D9DDDBE1E4DEE2E0E2E0E8DFE4E9EBE1F4EBECEEF3E9F1F3EDF2EEEB
ECF1EBF3F9F1F1EEEBF4F1E5F8F8E9FAEEF0EEEEEAEBF4E6ECEEF3E8ECF0F1E8DDE9E6E0
E0DDDED8E6E1DCDDDEDCDBDBD5DEDDDBD6D6D8C8DBD8D1C8CBC9C5CAC5C2BCBFC1BCBDBE
BCC3BBB1B4C3BCB0B9AEB8ABABB3AEADABAAB3A8ACABA8AEA8AAACACA8A2ADA09EA69CA1
868BA0989C9B93969B91909694969B94939296948E988E618B88888B8C86878C8B8B8889
7E8B81817C8C848183777F7E7F7F807777777879747E7D7675797B717373787776787975
73716A7876706C78746D76776D6C776778736E696E74756D6E6B6E6E676F676C65696F64
746A686E686A66686C706D636767676D68626B6C636767626666696367646B626264605C
64615D5C5B5D5BC300000000000000000000000000000000000000000000000000000000
000000000000000000000000
EB67636A6E6A6B6A64656A6D606665696866626B66676666696D6C716D6B61686B686E6F
736D736B666A666E6C69686B6F71677072666A677169716F6A6D72736E747372716B7670
6C736F68726C7078727570767774777A74777979737176726E71747377777B7B7E788380
7D7A7E80847B83897882838180867E8883818E85838189908B848A888C878B8E8E8D9593
8B8B9096898A8C93989990989B999C9B9394959D999996A09EA0A9A4A49EA3B1A9A7A3A3
ADAEACA8B0B1AEADACABB5B1BCABC3B9BCB9BCB6C3BCC2BDC2C8C6CEC9CCC9C5C8CCCED2
CBCED4D9D8D9D1D4D8DDE3DBE1D4D8E1E1E4E3EEECE9EDF0E4E9EAF4F2EEEFEBEEF6F0F5
F6F4F1F2F9EBF3FBEEFCEEEDF5ECEBFFEBF9F2F4FFECF1F3E6E4EFF1EBE9F0E5E9E5E8EF
E4E1E4E3DBE1E4E5DEDEDEDBDFDAD9D8D8D9CFD5C3C8C8D1D1C6C4C3C8CBC6CAC6BEBCBC
BCBCB9BBB9B4BCB9BEB7B3B6BAADB0AFB0ACA9AEA5ACABADA6ADA4A9A7A7A1A5A4A3A3A6
9B999BA19C8F989EA0999390999C92988F8E928E908C918D8E908B898F8D828C89898883
838488887B887E807D7F81797B7F7B807E7F7B79747C7C7D717678727671778078707373
79736B7574717172717170726E6F6B716C6B696E717071696D6C71686B6D686F68696966
6A666068696C636263656B6664655E62636764606368636760696A6D686463626563675E
60675D63635B63C800000000000000000000000000000000000000000000000000000000
000000000000000000000000
E76A626A636B6B6B696C666C6667676B6B6C6669686B6A646B6C6D776C6E696E6474736C
696C646E696E6168696E6D696E6E6C6B6D68666E6D68706A7064726E746E777678717474
687271747675747174756C73726C72726E7178746D75717370737176787070817C7D7A83
7C81807E807D7E7E7D84807C80858288818C8C8985828886848F888C8E918698898D9181
968D8E878F9188909898999B9690969D979399989990999E9C9D99A4A5A5A9A7A2A2A5A9
A5B1AFADB6ABA8B6AEBAB2B4B9C3BAB8BAC1BDC3B9C1B2C0C9C0C5C4CCD0CED1D4CAD5D5
D0C8D5D5D6D5DCDBDDE4DCDDDFEBE3D8E8E3E2EBE9E6F4F1EFF3EBF0EFF1F4FFEDF0EAF3
F1F0F7F8F6FCF3F3EFFAF5F3F6F8F4ECF9FBEDF8F4EDF6EEF1F0F9EAF6EBF3EEE5EEF0E9
E5ECE3EBE3EBDCE4E3DADBD8DDD8DCDADFC9D8D2CFD2D2CEC9CCCECBC3C0C4C4C6C9B3C0
BFB9C0BCC1BFBCBDB8B3B3B9B0B3B4B3B0B2B1AAA9ACACAEAAA8A5AAAEA0A89C9E9EA1A5
9E9AA1A09996959C9A98939C909B99969795909099908D919288878E898B888988898C83
8C8180867E7C81837A807F8180887D76787C777A837C81787C7C7E7F74777A7C76787376
7373777175747571757370746E756C6D6B6A6C7170706F6D70736D6D7169696C696D7166
6C6666626A6C69686B69695E6161696163645F696364596969646369636760665C636161
605C5C63695E61C600000000000000000000000000000000000000000000000000000000
000000000000000000000000
EF696E68686967686962626B6A706B655F67696C6463696B6E686B64696C71646D6A6D70
6670726869686A6C6966696F6A6E686E6C696D6A766C73656B756E6E6877747071647073
73747473736B75787473706F7778767976767B78787479716E736E787577817B7B807E81
78807C7E81838084848B877E86868988888A8888888C8A888F8C8A8E8C8D8D918C909490
839E90908B91928F92909696969E989F949B98989C92969E969B9EA6A69DA8A1A8A1ACA4
A4ABB0ACB4AEB3B0B0BDBABEB3BBB3BCB8B7BBC0BCC9C9CDC3C9CECCCED2CDD4D1D5D1D6
CDD7D3DCD9DEE1DEE1ECE3E0E4F2E8ECE9E8E4E8ECEDE9F7F0EAFBF4EDFBF4F1EFFEF3F4
FCF3F4FFF9FBFCF8F5FFFAF4F6F7FEFFFEF8FFFFF4F8F2FFFFF6F2EFF6F4F4EEEEEFEBF1
E4EBE9DFDDC9DCECEBE2E3DCDADBD6D8E0D2DBD8D3D9D1D9CFC8C5D1D0CAC9C3C4C1C6C1
C4C4C0C6C1C1BEBBC1B2BBB2B1B0B4AEACA6A6B4A3B1AAA4ACACA4ABA8A4A7A39EA1A1A1
A3A3A19D9D99A296969B9C919698959496938E9199918E8C8E8C868B8C8E8186898C8389
888A88808C83787E8A837E7C7F797F827C7976747E7B817B74767B767C76787673777374
747273786E767770726D716A736F6B71716E7071766A697170666D696B696C6C6E636B69
706367626A6E696A68646B616966616164686161646862667068696066686865646C6761
5C63625E606D5EC700000000000000000000000000000000000000000000000000000000
000000000000000000000000
E46C676364666B6264666466646B62686B6871696D686D686C6D6B6A69676E656C686B6A
696B706C6B706C6B6A6E6F6970716A6E69706D697075666C6970706B6B716E7170747173
716E72796D6E746E7374746F717379786E7676737C757473766F73767B73767778797C83
817E807D7D818081877B817E89868284837F8484898686878D8A8A8D8391898E8E988C93
94848F908A8D9998959396919AA19198A19DA1928F94999B9BA0A6A0A69CA4A7A6B0A6AA
A6B4B0A9A9B0AEB1B3C1B4BEBDBBC0BEBCBCC2BAC5C7C9BCC6C8D2CED1C8CBCAD0CCD1D4
CFDADFE0E4E0DFE3E5E3DFE5E3EBE8E5F0E9F1F3F0E7F1F0E1EFF1F6F1EEF9F3FBF9F4FF
FBF5FCFCF1FBF8FEF8F7F6FFFAFCFCFBF9FBF5F6F9FCFFF6F0F8FFF1FFF1ECF3ECEFF0ED
EBE7F2E9E2EEE4E7E2E1DAE9DBDFE6D8DBE0D4DDD9E2D3D3D3CBC8CBC9CFBFC9CAC3C4CD
C1C4C1BFBFC1BFBEC1BCB4B4B3B4B6ACB3AAB6ACAEA9A6A6A6AAAEA3A4A3ACA3A1A4A7A1
A19BA3999EA4A3989494999B9B949B97929798979494939690918C8B9190898A838B8892
89818B828386837D7D89828184798181817B797A7C7B7673787A7B7B767C717877737675
73747370746C7376737073756E70736F716E72726F7174706F73716C6F7070696B6A6E66
6C6E6B736B6E6364646366666364605D5858615C645D64695C635E6660696963645C5C63
636B66605A6363C400000000000000000000000000000000000000000000000000000000
000000000000000000000000
E8646666656B666C656D676B6E6A6666666B6765726C6A686F6E6763686B696B6E6C6B69
68716C6F71676A68696C6B716E6E6C7669706D716B6E6F696D6C6E6E786E716E72787170
7878706E6B777974717676737274737C7B7475777A797B757476777D737A78827A7C817C
7C82817D86897D8284847B7F888C808988938B8E908D928386938B8B908B899190929094
95918C8A97908E90979796909E94919191999D9799999B9E9A9D9FA8A6A8A0A4ADA3AEA9
AFADB3ACAFB1B7B8B7B6B3B8BEB6B8C0BEC6C8C7C1C4BFC5BEC6D0D1CFD0C5D2D1D1D1D6
D7D5D6D7DDE0E8E0E7E6E2E9EBE7EAEEE6F2F6EFF6F8EDF1F5F1F9F7F2FFFFFEFFFBF9F3
FDFFFEFFFFFEFEFBFFFFFFFFFFFDFBFFFFFFFFFFFFF8FBFEFCF9FEF4F7F8F7F2F3EEFCED
ECF0F1E7EFEAE4E9E3E6E8E8E6E6E4DEDDDEE1E4D8D3CFD1C6D4D6D1C9CFCBCDCBC8D0CF
CBC2C4C0C8C2C2BCBEB5BBC4B9AAB7B7B8B3AEACB7B0B0ACAEADA9A4A4ABB39EA1A8A0A4
A19B959C9A9C99969790A1929D98999E92939A8E908E909391908886848C8D8B8D898986
81888085888683807E7E817F8084807F827876797E7778787878787879787976797B7273
77747976786F7670797B70736E74706C6B706E74716E6F68716C6970686C6F6C68666A66
676C6D6A6567646D6968636669605E5C5354595F5C606669636163666262696263646764
5C626464685B66C700000000000000000000000000000000000000000000000000000000
000000000000000000000000
E76C7161636B69696867686D6C696C6E6F6468686F686D6574686E6C706C6B65706C6B69
696B6B6D6965666C696B6C696E70746E756C686B666A7170696D6A7376726978716B736D
74767473716F747672756F746F6F737B7C78817A7C7A796F717B747C79787C7C747C867A
808179868283898384838486838488868B838685898986918690978B91938D90918B8E8C
96908E8E908F958E98899E989D9D999B9499998F9E989B9A9C99A4A1A8ACB3A6A8B0ACA8
ADB5A3ABB3B3B4ABBBBABAB4BBB7C2C0C4C7C6C7C6C3C8C8C8C4C9D3CFD6D1D4D1D3D2D4
D5DBE1E0EAE0E0E9E5E8ECECE8F0EEF1F0EEF8F0F6F0FAF5FCF5FFF5F8FFFBF7F8FFF5FF
FFFFFFFFFFFEFFF8FFFFFFFFFFFFFFFEFFFFFFF9FFFFFFFFF9FEF9FEFBF9F6FCEEF9F2EE
F0F3F0F1F3E8ECEEF4E8ECE0DEDDE9E5E8DEE4DBE0E4E0DBD0CBD7CFD1D1CECEC6CFCFCE
C8C8C8D3BFCEC3BDB8C5C8B9B4B8B5B8BDADB3B1B2B2AFA9ABA7A8A7B1A7A0A19FA3A19E
9E9B99A09B989A9A9B9297A098939193979999919492969499948F8A8B8B8C8489858B83
7F81837C83828680828682767B797881797F727E787E797979787B7E71737A7C7872786F
717A6E7C74727275797077707371746C6C72667173676E7370766A706B6B706E716E6A67
64666C6C62696A63626A656864605D563D4E5462606464666763696264636B6465606160
6368645F646661C500000000000000000000000000000000000000000000000000000000
000000000000000000000000
E36368646767676066686664696B666D6B687264696466636C67646C686F6769706B6660
706E736865626B6B6C6B6C706B6B70686B6C6E6A706C6B696B636C6E6C736C716D6E6877
71756D737378727378717169737A79767D7A7B747C7F7C7179787B7C7879747E7B7B7584
847D8088898383807E838083868082848B87877F8C918C8B92808B848C908F888D93908C
959192929191989A949F9097939999A59A949494A09BA09CA4A1ABA6A9AEA7A6B1ABA6AF
A7A7A9B6B3B1B5B4B4B3B7BEC8BBBFBCC3C1CCC0C9C1C8CCC8CFD3D5CDD4D5DCD6D4D5D9
D6DCDBDDDEE2E4EAE8E4EFE9EFF2E4F1ECF0F1F8FCFFFDF3F5F8F9F6FFFFFFFBFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEF6F8FFFBF9FEF6F9F9EF
F2F7F1DCEEEEF6E9F0EAEEE4EFE9E2E8E7E5DBDEDEE1EADBD3D6D4CEC8D1D1CCCAC6C2CB
CCCFC0C6C8C0C5C7B9B6BCB9B3C0A8B4B1B1B1B1ABB1B3ACAEA9A8A6ABA4AAADA5A0A4A3
A09E9F92989A9C9C979B989E9593979E97958E93919097918F8F90928A8D87848D85888B
8D8C8B8B8284837E887C8188807C7B81747487757A797B7C747476737B787B6F70727176
76747878747079736F7173767471716C69736F6E7072747072706C686D716D6B6B68656B
6C6969686D67686A6764636D615F5E502544546663596C5E666A65606A655D6965646C58
5E646665655965CA00000000000000000000000000000000000000000000000000000000
000000000000000000000000
EC6864706B6C636A7064686569696F6C66706C6B646A6C6167686B6A68666D696F6E6A69
716869696B6C6D676A66696E707372707071736E6E6E68676B696B726B6E6E726F736875
79746D6F77737379737174717177787474787B76767C797B7273738174787A7D7C7E797E
7C837D7C7C7E88848584848884818B897F8C8A898683898E86878A8C8B8D8C908E91938D
93978D91888C92909193919094979799989A9C9798A095A1A0A79AA4A8ABABADABA9ABB0
ABBBB6CDBCB5AFB3C0BCBBB9C1BDBBC5C9CEC8C6C6C6C4D1C9CED4D0D9D5D3D8DBD8DED6
DFD3DCE7E2E5EBE4DEEBF0F3EEF3F9EEFFF6FDFAFBFBFFFAFFFFFFFFFFFEFCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFF9FFFFFFF9FAF0FAFBFA
F2F5F6F4F7F0EBE5F3F9ECF0F3EBEFE8E6E1DFE1E0E3E0DEEBE4D5D5D9D8CCCED4D1CCCE
CEC4CBC6D0C4C3C5C6C1B6C3B9B8B3B4BBB4B6B4AEACA8B4B1B7ACACB4ADB1A4A3A1A9A4
9CA2A0969D9E989A99949F9C9C93999B999A9D9296968F938B9694958E84898888818993
888683868586837B8386837F797E82817E837F76737A777478767874717A79747B767678
7683767774737674786F73726F74736A6F6E746D70716C686B696D686C6D7571656B716E
6C6C666C68646C6B666768625D60585C5852595C5A6661685C636863635C66696868626B
6360686964615EC100000000000000000000000000000000000000000000000000000000
000000000000000000000000
E66361686B69686863686C696C636C6B6B6A65686F6C696B6C666968686970696B686B68
656B6B7164686B686B706E716F6E6E6B7476726F6B666C676569646B6B666B6B6479786F
70757676747276766E727377726F7C7878807C7376767475717B7574797C717D74777B81
7B7C817E81838484898681838B8D8385888986878C94918788868C8B86928E9091938D8B
8D908B8E8A888C9098909C9895959694999C979CA799A1A09CA49CA8AEA8B0ACADAEAEB7
AFB1ACAFB8AEB7B1BBBEC1C2B8C4C6C7C9C7C4C8C7CACACBCBCBCED0D4D4D4D3C9DCDCE1
E0DDD8E6E3E4E4E4EBF1EBEFF3F3F1F3FCFCF9FFFFFEF9FFFCFFFFF5FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFDFDF9FAF5
FEF6F9F3FEEEF8EEF3EDF4F4EBEDECE4E8DFEBE1DBE4E1DDDEDCD6DBCFD3D1D3CECECED1
CEC1CBC7C2C6BDC8C9C1B8AEC3BBB7BDB7B8B2B6BBB8B8B4B1AEAAACB2ABABA6A3A69CA1
9BA39E9D9F9A99999B97989997979A9A989E9399878998908C8F908B8D90918D8986838A
848B8E838385847C7D7C7783838279787B75787E7979797C7B787079857E76716E747479
7678747475707B7376747070766B736C6F717576706E70746D6A6975736E786B71736B6E
6D6E69716666676668646763675D63665D5C60586366635F62646E676360646163686667
616764625C6666C400000000000000000000000000000000000000000000000000000000
000000000000000000000000
EA6D666B6D6D6E6966646A6B6B6D70686B6C6C61686C676A6C6E6C6B686B6E746966676F
64696C69646C67706E686D716C6B7071666B716F716B696C6969736C6776696B6D767171
7B73747476777C7473736B6B717A78797C7379787B777C767B7A807A80737974797E8183
7E8380838080898684838881827E897F898A8E948689898B918F8B8B888D8994868E9694
93948B8C94908E92958E9998969099A19B9999A19A9F9C9CA09CA6A99FA1A7AFB3B0B4AE
ADAAB1AEBCB1BCB8BEC0C0C3C4C1C5BAC2C9C8CDC4C9CDCBD1CDD9D9C8D2DADBE1DED9D4
C3DBD9E8F1E5F3EBF3EBECF4F9F2F1FCFFF7FCFBFBFFFFFFFFFEFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFF
FBFEFCF7F8F7EEF1F7F8F6EFF0E4E6ECEAE4E2E6EBE4DBE3E8D9E1DEDCD9D6DBD9CBD3D0
CFCBCDC6C7C3BDBDBFBEB4C0BABCBCB1BFB9B9B2B8B6AEABAEAFABB8B0A4A2A3A8A8AB9E
A699A2A4A0A09F949FA59A9692949B9690A0999190999090898E958A898C8988898B8989
889184877B82847D7E8082827B767F75777D7D7B80737876807978727C7B79757D747676
797371766E767770737A71766F6974706C70706C73716E6D716B7C716D706F606C6F676F
6C6B6B686468686C6D666B6761635E59555E5F5E655C69646A6161666766636969686664
61626064626163CB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
EC6B68646365706B6B6B6B616A6868636B686867666E6B69716D6C687067716E6D6D6B67
6A646970677369666D66737166686B71727173696C6E686569666D696C6F747072727372
78746F7175757C767D707A6F73766E707176797B777078797B757C7376787482817A7978
7B837985808C828C8485808186848683868B8C8C888D8D89888B8991918C899091918C8F
8C8E938F9994959694938F989B969596999BA1A0A49CA6A5A59F9FACB1A7A8ABA6A8A8AB
ADB2A9B3B1BEB5B9C4C6C0C8CBC4C6C4D3C6CBCCD1CBD2CECDD3CECDD9D6D3DEE3D8E4CE
D1E0E7E9E9F8EEF2EEFCE9F8F6F8F8FFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FFFBFFFFFFFCF1F9FEF4F1F1F9EEEDEDF0EEEEF2E3E3E8E5E3DFD9E0D9D9D2D0D1D0CECE
CCC8C8CED1CDC7C4C2C0C1BCB7BCBFB9B6BBBCB6BCAEA9BEADAAA8ACAFB3A4A5A7A49CA6
AB9FA19898999DA19F98A1989E9D9098979C9891959490918E8993938E8B878C8E868983
8A8481828482827E85827E7E7B817D7E6E7B7C7E79787B7E77797B75737D717B77747979
7674746F7370757475797574787171747079786972757179737168687069696B6D716D66
74686C64676569686469606360615962615C635E65625F67636563616266646468706460
64636461635D66BF00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E66F666E63676766666C6D69686A666A66666B66696E6B716B706D6C6C6E716A7566716B
726469646E69696B6E6C6E6E736C6B736E6E706A6B76736C74666E6A716C677974767274
757973756B7E7C757178757B766F757576717176767378777875767C827873797A797A7F
7E7E808285838385807B7E7C8C88908C8E8E879088848B8C8C8D8B848B9489918D8A8C95
938E8C8F94949693938F9D9B9998969F949E9C9B9F9EA0A5A1A9A9A0A1A8ADA6A2AAAFAC
AFA8B6B3B4B8B8BBBFC1C3C3C2BEC4CBC8CFCCCECCCCCAD4D2D0DCDFD2D5DCE7DDE1E6DF
E9E9EFE5EDF6F0FBF8EEF8FAFAFFF9FFFFFDFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFBFCFFFFFCFEF6F3F4EFF0E9F3E8E9E3F0EBE8E0E3E7E0DAE0D9D9D4D6D9D9D6D9
D0CBC6CBCCC4C6C4C3BDBABCBCC3BFBBC1B4BCB2BBB0B6AAACAFACA5B0A8ADA4A8ABA1A6
A4A59F9F98A3A4A19A98959995969F92969698938F98928C8F9788888A86878989898687
818788888383818180807B848384807E7B7C797D7E767B82787B7A786C7B6C74727A7675
73707074797871737176726E7470766D716A6D707170736B686D6C66736E666B6D6B6B6E
6C706960666363616369636964605A66635F6461615D5F695D6460646E66616265696663
5E5E6868616169BE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
F16B696B636B68686C6A6F6C696C6A71696C68666B6370736C666E746F6F6B7572667172
706E6C6C6B696C6B6A686F69696C6C6B6F6C716E756C687070747873726C70746D74767B
787178797C76787570737773767B75747476726F6E71717574797E7C807D7D797E78767E
7C8582807D808187858686808F7C8389858E87868E86838D868A8B91909189908D909294
8E948F98999691989B969497A189A19D9D9FA09BA2A3ACA5A6A6B0A9A4A3A6ABB3ABB0B0
ABB2B3B9BBBFBAC0B9C0C5C2D1C8C9C8C6C5C6CFCDCECFD3CEE3DDD6D6DCDCDDDFDEE2E3
E1E5E3ECF3ECF0EBF5FFFBFFFDFCFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF4F8FFF9FCFAF9EFEBF3EBECE3F1F0EBE6DBDBDEE4E1DCD1D6D8D4CF
D5D6CED5C9C8C8CDC1C4C4BBC3B9BEBBC4BEBDBBB4B7BCB1B6B5B0B0A4A9A8AEA7ABABA4
9DA3A1A8A0A59FA496A39E9C9799A097999695959399969793908C8D8C8C888E8B88888B
868C898589887E838186807F817E7B867C79777E7C78807C7B78787C787977746E727675
706D7575747376777475736C77696B6F6E6E716E69766D6B6E6B716C6F70756E67707171
6E726C69666365686863656665665E5E645F646064616461676C61636468686862665D63
656463645F635DC200000000000000000000000000000000000000000000000000000000
000000000000000000000000
E9666861646A6667686668695F626D686A6A676B716C6B706B6B6E67686E6E70706E6E6B
6B6D6B6E6B676E6F6E6F6B6B6B6D6E6C656E77736C70787673706F7276727271736E7571
747E7A777B7B7D7973706E7B77717D77736E70686E7471707774807E767681847E7C7D76
7B80817E81878784858389817F888B86878587898F8C908C8A8E8D8C8E9086859B94918A
93988E98909490909396939B8E9BA39C9DA09B9CA2A1A4A8A9A3ABA1B5A9AEADA8ACA5AC
A9B4B6B3B9C0C0B7C9C8C2C9C9C9C6CACBCCC6CBCCD0D1D4D1DDD9D3DFDCDADEE8E7E8F3
E6EBEDF0EEF4ECF9F9FFFCF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFDFAF9FFFFF0F6EFECFBEEEAE6EBE2E9D9E0DCE6D6DBD9D2DECC
CED1D1CDCED1C2C7CCC0C8BEC3BCC0C4BCBEB7C3B3B5B3B1B0B6B0A9ACABB0B0A7A69FA1
989BA498A0A399A39E9D9C949A949A9B969894969390908A998C898D8B8A8D908F898F84
838C848085877A82847D83868381827E7B7C80787A80797B74797E737372727376717678
78747F746E727B766F756A74706D717069786E69736E6B69746F7069646E6A6B7165696E
66686C6864636561696B6964666B68636368626360666866636864646668666763666664
61646067665A61C300000000000000000000000000000000000000000000000000000000
000000000000000000000000
E66A61686B666568626C6E67746C66606D6A696B6D6E687069716B6F756F716B6A716B69
6B70706D6E706866736868706D6F71736C70716F67717067707974726E76737478737876
787A747C70807B75797C74747471777071716E7274716E6F737E827B857A7C7C7D847E78
797E7E8183818C8B838486838C8485898E8C8388808389838C9090919490969193939891
9A8E9695969D9992999D999E9FA3A0A1979C9DA3A1A6ABA8ADA3A3A6A6ACB0ABACABBBAC
BABABFBBBEBCBBC2BDC6C4C4C8CECDCCCCC7BCCECFCFD1CDD9DFDCE0E1DDD9E1E6E1E4EC
EFE5F3ECFFF6F3FFF1FBFFF9FFFFFFFFFFFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFFFFFFFFFFF8FBFBF9F4F2F4F0F6ECE7ECE1EDF0E1E3DED8D3DEE1DBD5
DBD6C9D0D4C9CBCFC4C4C9C1C9C6BEB7B3C0BEB4B9AEB8B5B2B4A8AEB3AAA8ABAFAAA99C
A1A3A6A09F98A0A1A39B9E96989A9B9999968C949093938E8D8E9590918E859088898B8B
8E8B807F8488858586797C80857D7C837D7D88737B7881787F787B807B71787B74797C78
6F747473727A737075757971766F767074736E6E70716968696B686A6A6D746D6A6B636B
73696A6B6964636E64716868696A69686463636466656B6069686062665E63635C68646A
64676563645F5EC500000000000000000000000000000000000000000000000000000000
000000000000000000000000
ED656C69646663676B6C6666606963606C65706669696A69686E6E6C676E69716C6F696C
6C6E6F6F6E767168706C6B69696C6E6476736269776B6A6B6E736E71787A727874737272
746C79787878757A79797B797778747570796E6D6C7576766E7775797B7C817E79777C81
8577808389868C877E83898B828185868B8E86848488898C838B8E86938E8B958E92908C
9498919698969995A097999F9899A0A3A09AA6A4A7A6A9A8A2A6A3ACAAA2A4B1ABAEABB1
ACB4B2B5B9BBB9C1D0C9C2C0B9CCCBCFCAD1CCD4D0D3CDE5DCDEDCD8DFE2EBE1EBE5EDE8
E9EBFEFCF8FBFBF4FDFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFBFFFAFFF8ECF0EBF0F0F0EEEAF0EBEAE6DEE6DFDCE0D9D6D6
D3D2DAD4D3CBCECBC7CAC6B8C4BFCBBCBCBDB6BCB7C1B4B0B3AEB1ADB3ACACACACABA7A9
A4A29EA0A499A19F9BA59AA39BA19B94949699998F968E928A9B8E8F89918B868D838B8B
848A897E818A88848186897E7E81807980827B7E7B7D7C7B7B7E777479767E707D787473
737170707279767271736C6E74786C6E7476686C6C71716E7873676F6A6A696E6C666866
70646D6E6C6E6764696B6E64646E6469656268636261606167686C60645B606B626A6969
665B626064605FBE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
DE69606665636C666960636A69696A71696869666B6B6D6B6D726E6D6E6E6A6B7370676C
6E736974686C716F6E666C726973706D6E6B726F746E6E6F717971707378717070747179
776D6C78767972707C7B7E798079787B786A71726E787677817A80767B7C787C817C7C80
7B7C7F8382878880857E918B8B868C8788878E898B868A8587918B938888948D90919990
979C969499949D95A09A99919EA6A1A1999B9EA3ABA5A5A5AEA4A7A6AEABAEACB3B1B0B7
ABB6B8BEC5BEC9C3C6C6CBCBC6C7D3C3CBD0CBCCD4D3CBD8D4E0E1D9E6E3E4E8EDF1EBE6
F3F7F9F6F5F5FFFFFFFBFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFCFFFFF0F2F9F1F1F4EBEDEDEBE2E7E3E2E3D8E3DD
D9D7D3D8D6D7CBD3C9C9C4CCBFBEBBBFBCBCC2BEB8B8BCB9B3ACABADAFA6ADA7A89CACAA
A3AFA69EA3A5A39EA09B9D9E9C9C9B99999C9B959A8E8E9898829094868E8F8C8991888E
84888D807C88878A7C83897D807C807B817A7C837D797B7B7C7574807C767A7972747373
737673727274707B7474707673726E73736A6C6C6D736B6B6C6E6E746F72666B6E6A6E64
696C656A71646D6C5F686466696865675F64666862656064665B615F62615E645F606B61
60645E5E5E605FC000000000000000000000000000000000000000000000000000000000
000000000000000000000000
EB6665636466606460686E69686460666968696E6674696B686B6B726E62656C666B706E
6B70676E717173707670707474716C6E72726A676972736F706A79767971777671787570
777674727676747C79787E767B837C756E737571757174767C767B7879877A7881817E7C
787C7B867C81898E8F81818188878790838588898F838C8D8B8F8F89928F919391959491
949897909DA0949A9699999BA39E9B9F9BA79F9EA4A4A2AA9CA3A0ACA9AAADABB2B3B2B3
B8B6B4BEC1BDBEC6C6C7C4C2C8CCCBD0CECED5DBD3D4DED8D4DFDBD7E1E8ECE6EBEAEEEB
EEF5FAFFFEFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF4FDFCFBFEF6EEF7F6F4F0F1E9E8EAEBEAEADDD9DCDDDD
D1D4D7D8D8D0CFD3CCD2CBBECBB8C4BEBCBEBFB9BDB6B7BBACB7B4B4B0B1ACADB0A9ACA9
9FA7A6A9AFA2A49E999EA1A19E9C999293999D9E8D8E8F988E8F9193948B9293848A8E7E
878E86838686878381817E7E8C817C8382857C7B7B7E7C7D787B7C767C796E737D79797A
7873727D72777B767B7472737173726A6E6E73786F706A716C736C6E706C6568636A6B6C
6872656B6E656A6862685F6D6E66666268626C69646B6663636867656B67686860606065
6166605E61605BC200000000000000000000000000000000000000000000000000000000
000000000000000000000000
E866616263636C666969646C69676B6C6F686E6C6B6D6C696468686C6E6A6A6E6C6E6870
6F66706F7070706E6C7670716D6E6D7365706972786E75787674706E7377766F6C74747A
7B7E6E79797474787879747A7B7B7B7373747372736A7178747B807574787C7C78817980
79847E8489878E858186898C8686898D8789808B90919684929089949591949391948FA0
949D9798989CA09B989B9E999CA1A0A6A19DABA1A6A8ACA6AFA9A3AFAEB3A8B2B7B6B3B9
B7C2BDBEB8B9BFC3C3C9C2C7C8CCC6D5D1DEDED7CDDDDAD6DEDDDCE7E7EBEDEEEBEEF1F3
F3FCFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6FEF4F6F7F8FEE8EAEBECEEECEDDEE5DDE4DBD8
D8D3D0D4D4D4D8D0CBC6CEC0C3C3C1BBB6BBB8BDB9BDBABBB8B0BBAEAEAEB6A6A8A5A49E
ACA8A5A3A3A3A1A7A1A299969D9C9C9C9B959F9190989094938B908E868992938D8E8888
897F8B828784807D8B8D79847B8F7B7E7B7E827B7B807E8379837C7B727F736C76767B78
7C71776F7374797A76766E6F706C6E7178716E6B6D776971706E706C696C6B67646F6E68
6A6962686469686A686A696967646767616459616E666C6763616960666469605E61655E
60665E63626065C100000000000000000000000000000000000000000000000000000000
000000000000000000000000
E1656368696C656B676E66686B696C6868616E6D6C6B6D68706B696E6671686F696C6F6E
6C706D6C75696E6A6C70706B70686B6E716C786E74747B76767477757B737375717B7478
7B797679747A867B7A7D797E7E8376767478737076767B767E7B747981807B817B7D7B7C
81847B808384828A868981868B888A888A868B8D898A90868F8C868F859493918C9C9694
9695929C9C9E9C9A999595A196A3A1999CA9A8A8AE9EA4A4A3ABB0A4A9B3B0B1ACB4B7BE
BCBABBB4BBC6BECBC7C4CCC8D6D2CCD0D9D1D8D6D6D5DDE1E5E8DDE4E3EFEAEEE9E2F2F8
F5FFFCFBFCF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFF9FDFAF1EEF1EDECF1EFE4E5ECE6E1DDED
DEE4D9D5D8D2CAD0D4CCCEBEC5BBC6C5C6BFBBB4BCB7BBB7B7B0B1B4AEA8AEABAFAEB1B0
A8A5A4A69EACA6A3A299969E9599979B97909597919695908E9491938990908E8F8D8988
848B88908B7C8B76838187788185867A757A7E7B777B7C7C817B7976767877807B807172
757676787874706E746F6D707069706A6D706E6F7475726870666B6E6E706A636C696E69
68656570686866656666636C616E65695D606360635F6868646C6B64686B5F605F656864
666664655D6164BF00000000000000000000000000000000000000000000000000000000
000000000000000000000000
EB67646B69646A616566666B6B686E686867686A6F676A6A706D6C647269686B6A6A686D
696E736B756C7370716C706D696C71707468717478736E767471766E70707171776D7A6F
747874707374767D7F7F7E7A80837B7C7B767678827874797A7E7480767E74807B787D7B
7E83818387898886818989849086878A838B898E95888D918C98888B8F948B8D918F8D96
94999EA19B99989EA4A19D9FA6A19D9FA3A09EA8B1A8B2A9ABB1A9A6ABADB2BCB4B3BCB1
BCC0BABCBDBBC8C1BEC1C2CCC4C6CED8CBD0DED3DDDEE1DFDBDDE6E9E9E5E4E9F1EEF7EE
F5FAFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFFFFF9FDF8FBF8E8F6F3EEF0E3E9EBE7E0
D2DED7D7DDCECCCBCCCCC9C1C0CCC4B8BCBEBCBDC2C0B8B6B5BCB1ACB1B0A9B1B5ACAAAD
A8A6ACA0A29A9EA2A0A49F9E9E9DA096979491949C968F9998938B9887938E8C918D8893
8B8C89807F81888784848183818680817F88817B82747C807D807C787E7B807779787B78
71747373797477717377717378696F70687273716C6D766F716E7273666870686671626B
686E69616C6B666E68676E6F5D616368626B666161656662695F666760636766655C6864
63666668595B60BE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
EE6B696868616668666A68646766656F7165696E646C686D6D6868646E6C6C69756B6F72
7C74706B736E727070697B6F6D6E726E786E74747076717A76736E7378717A747071757B
757C71737A797B74747A78797D7B71777B796C7876788178767B83797F7B7C7B787C7478
7B807D7E848C89818D82908D89898C8D898C8884868C918C8F8B8E8E848B8A939099A19D
9B97969499A39CA090A1A69C9D999EA0A09BA7A9A6A1AEAAA8ACA4ABB0B8B5B4B6B3B6B2
BAB1C3BBBFC7C1C6C4D3CECDD1D0D1D2C9CCD4DBD4E2E4E0E4E7E9ECECF0F0F4F3F4F8F0
FFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6FDF5F1F2F9F6F0E9ECE8E8E4E8
EAE0E5E2CED9D0D0D2C9CBC8CAC1C9C4BCC1C3C0BDBBBEB9B4B0B7B0AEADB0A6AFA9AFAE
AEA5A8A8B09FA8A69B9A97989C9F959D9A9C9C9A928E9699918E918D8F8F868E81918B86
8A8486868D8388827D838A867F80807D7B857F847F7E7D8176797574807176737B767678
7876787C7073777173736F746E73736E6B6F716C6F6B6671676F6A6B6B6C696C716C7068
6C666C646B636868656463656B66655E6A63645F606263696668695863626761676C6566
5D6B615E615E61BF00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E16B68686E646E696F6B6E726B666B6766686E6A726E6E6A6864727465666E6C656D6F6C
68656B73726A696C6B707271686972696E72706C6F70786C7A747471797670767174746E
787471737677797A7D7C7C817C767C7C7A737577747A787E7F747A7E7C7C79787E787779
7F7E8A89868382889089898789858C89858A8A89878891918E8C8B8C8E8D9A97999C9698
979F9E9BA39F949994989B9CA7A3A1A6A6A5A9B1A4A6AAACA8B4B4B3ABADBBB1BDB3BCB9
C1BCB8C0BAC3C5C8CDCBC9C9CAD6D9D7D7D6D6DCDCD6DDE6E3E1E7E5EEEFECF8F3F9F8FF
FEFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFEEBFFFFF9F9EEECEEE7EFECE6E6
E3D9D9DCD3D7DCD1D5C5CAD5C9C1CAC2C9CFBFB8BEBCBEB9B4B6B1ABACADB0ABAEABAEA4
A9ACABA8A3B0A2A39D9EA1A09A9CA19E969F99948E9B9898969891908990908794908B88
7F8B89867E8587848482818871867F807C7E7E7B86837E787D79787C767C7B70737C7A79
777D75797276737175776B6C796B6973707071726E6C6A72706968706966696E6E696B61
666868676769686C6C686463686667646661636166646A6C64616664646362666063635C
64665B67616462C800000000000000000000000000000000000000000000000000000000
000000000000000000000000
E968696D686C6B6C6D69686A6B686B6D6B6B696C6A656B686561646D706C6C6D686E676B
706B6E6A716E6C6B75766C6B756C706E71726D6F6974766C707573717477756D76707677
7274727676717E787D797D757C7D76767A767C78797B767B817E827B807C767877768483
8488888C85898689888B9180888C8C849189858D8791918E88898791999B8B949998A093
919C969B9E9C9A97959AA19F9CA19BA8ABA7A3B3A6B3A6ACB5B3B4BEAFABB8B4B2B6B7BD
B4C9C0B6C8C0BEC8CED0CBD0D6D7D9D0D1D6DEDEE8E5E1E4E8E0E4F3E6EEF4EEF8FAFDF9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCD0F8FFF0F8F2F1FEF4EEEBEEED
ECE3DCE4D6DEE0DBD9D6CCD4C6CBC0BFC2C5C6C1BABCBEBDB1BAB1B4BCBBB2A8ADA9AEA8
AAA4A3A4A1A3A8A5A7A1A0A19E9EA1989798949D9B95909B92968E949194928991918E8E
8F8B89889081838585888888867F82798284768C80787B79817C837D7979797B80787E7C
787979767775767B726F706E716E6E73716D6C70766C786D6D6E71706A6E6E606D6B6C77
6C686C6C65636A6E696D6A696361666D6B6F63646C67686A69626769606B6369635E6961
665B605F615F60BE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E86A666866706469696068646763646B6769646B6B676D6B686C6C696C686574685E6E6C
6E71697668746D74766C71746E747078666E716C7A6E716E757575787173717673767577
797470766D74747474787E7980807C79727976757B747A7C7B7B8183787E838075797B7C
7D837C8688898E8088888B8B8C89848B86898C908C8D8B8C918E8D90919190959192989C
999CA49893989A949899A09B9E9BA19EA1A5AEA9B5AFA7BCA6ADB2ACB3B3B7B7BFB8C0BE
BEBDC1C1C0C9D2CACCCDC6CCC9CDD1CDD6DEDED9DFE5E8EBEAE6ECF0EDF7F7FEFFFDFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFBF0F0ECEBEFE6F4E4
E9E3DAE1DCDBD4DAD6D3CECBCBC4CFC1D1C7C6C0C1C2C3BCBBB4B6B9B3AEB0B1B0ACAEB2
B1A9A8ABADA3A3A1A39B9E9EA59A98999B9B969E949C939890919E908D8E898A9092868C
8A898C898C8884898C817C81817C7B807C79817F7B7A807D787A79757C80777B76797976
7776747678746F6A73717B696E6B746A706C74726D6D66736C68686D716B696F6E606668
66706A68656E69646A636464686C64626465686063656562676760626864695E64676266
6560635F5E6359BD00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E86B6D66716B6667646968666E6B666469656D666B656467696964686E6E686B6B687069
6C706C786D6B74706E76706F6C6C6D6F707375686E7172717B7973727672747276737373
767270787669787771807B7976767A76707678797A797D7481807F787B82818B777E7B7E
8080828D8B90898B8B8D8A868C818E9086898A868A8C91888B918C918E93969092969394
989899969C979692989B97A099A497A0A2A9A8B3B7ACB4A7BCB2B4B7B6B6B6BAB3B3B8B8
C3BEBEC0C8C3CCCECCD1C7C8D1D0D0DED3DBD7DFE2E5E6E9F0EBE8EBEAF1FEFFF8FEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFDF6ECFCF1EAF1F1EC
E2E5E9DDE4DBD4DBD9D4CFD1D6DECCCDC8C3C3C1BDC4C1BBBCB9B6ADBBB3B5B3B9B3A9A9
AAA6A3AFA8A7AAA89EA3A09AA2999D9D9499989B93A19696938E99918D8D978B8C908E8A
888B8D838388817D8882828081897D7C867C7E7D7B7E757D747E76747E78797C71796E77
7B747672757178716E79766C6C6C716E6E6F71716B6B706E6E696A68716C706862696666
6F636C696361686C6E696B63686B6366666165666A6D656361606063646361625E666261
6366695B636963CB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E568666C67686E6C6C70726E6B73646C6B696C6B666B6E6B686A686A6373706768656B69
6A6B6B6F706E706B6E6B677370736E726E7376726A716F76777C767475766E79787C7471
74747675737675737C7A787D767F767D78767B777C7C7E7F7B7D7C8383827A8180818179
81838586908A84838386808E8F868E968B96858B968C8E8F8B9490968F919898969F969B
90918E8F9B99938E91989C9591919C9CABACA4ADACB8B7A8B2AAAAB7B8B5B7B2BBB8C3BB
B8B7C1CAC7C8CBC4CCCBD4CED7D0D6DAD7E3E5ECE1E2EAEBF9F0F1F1F6FCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFBFFF6F1F8E9E9EE
E3E3E9E9DDD7D9E5CDD8D5D0CFCDCBC9CCCBC3CCC8C6B8BBC1B9BEB8B7C0B1B4B1B5B7AE
AFADA4A8A8A6A2A1A3A1A49EA19E999A9899A3A0959198999191928F8E8E919090868B88
8888807E8B81857C837C86817C828682837F7B78787E7C7B7F7B7981767B74787C7C797D
7C767C7C74757876736E747671766A66726F6F6C696E686A7770686C6F6B6C6568686969
676C6669696E65666C68746C6C69696165636A6968665C6B68616A5A68636A61646E6264
6668636862605EC800000000000000000000000000000000000000000000000000000000
000000000000000000000000
EA6C70686C66676963696B666B646B6766666A6F6C69636E6B70706B666B6E6D6B687068
6E76746D6A6D68686E716C71706A6B6E6E73696C6E6C69736E7178777A7874736E737575
747B777574747A7D7D71797B7775787B7279787E79777F7D7C788082887C807B77847B83
838389818E8C9095838A90898E848B8C8F8E8F96908C8989888E928F998C979994969A96
9F939E9C918F9A9493939890999992A2A5A1A3B4B2AAAEABB1B8B4A9B3BABAB2BEB5BABD
C2B9C1C1C4C9CECECFD3CCD6D0D9D4D5DCDDDBE7EEF2E9EEEEE6F8FBF8FBFBFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF9F4EDFCF1F1EBE0
E4E7F0DCE6EBDEE3DBE0CDD2DCDBD7CDD1C0C5C3C7C9BCC6BEBCBBB8BDB8B5B8B1B0B8B1
ADACA9A3A8A2A7A59BA2A8A59B9DA1A89F999D9D969A9993949C9696948C8C8B918E9590
8F8C89927D8B838A83808E83817E858180867E767C7E7776787B74727B7478797E767375
72767C73787978747471766B6E716F7C75716F716E6C6D7369716C67706C66706F6D6868
6B69686C6B6F7071636B66666E68645E6E626E69666A6666656B60686061646A6B645F61
6365606361665EBA00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E6666B68616671686767666C696967696B69646B676B69696A606C69716C686F6C686D74
6C6B6C756D70776F6D6C6C706D6F6E71726E6F74736D7473766E73757972737478747872
736E77747C73727A75787876777C77757879787B7E7B847A868380807E807B7E7B7F7C85
7D838F85838E8886918B868E8E878984868B888C878C8B8F958F8D908C9491989A949099
92908F9890919194989C96999F9A949CA3A49EA1A8A4AAB3B0B1B7B7B4AEB7B8B8B4B3C3
B8C1C1C0BABEC6C3CCCACED2D3D7DCD2EBE9E0EBE3E6E6EFF3F6F0F4F7F8FFFCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFAFEFDFDF1F0F8
EBEBEAEAE2DEE1D8D5DCDBD8D4D0CBCCCCCCC3C4C6C2C3BBC1B9BCC0B6B4B5B5B4B6B0A6
B0AC9CA3A6A8A4A3A9A4A7A0999E9D9C99909AA19591999197949195909494918C88908A
88868984858486847E8280807B83868481797F807A7C757C7B7A6F7F7E7578737C787A71
737A8078766F786C70736E6C686F706B736B706B6F727272636E6E6D6C6B6B71706A6670
69696E706667686C6D6E6B61666764606A626861636760646569666160695D6365615F5E
5F64596B605868C600000000000000000000000000000000000000000000000000000000
000000000000000000000000
E26566695F606968666571636B6665676F6869686871706C746C69706A64666B6E747069
6E6C6C6B69706C776E706872697274706D6B696B787170727079766F7371737879767979
7277787B767375767878757B797477777F717479777A7E7E7F78817D7A7D7A7A7F7E7581
897B86898A868686898E8F848C8B8D8C898E8E8791928D8990968F9498969E9690919694
92948D8C90959992949993A19C9C9C9BA09FA1A6A5ABACB0B3B5B6B2B4AEB6B4C0B6B7BB
BCBFC4C7D0C9D0CCD4D4CBCBD1D1DEE0DCE6E9D8E9EEE8E9F4F9FCFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFEF9FBF8EFE9
EFEDECE4DAEAE1E6D8D6CECDD6D4C9C6C6C3C6CBC6C7BEBBB8BABCABBCB1B4B7A9A8AEA7
B0B0AEA1A49CA6A6A1A298A7A09CA0A09397989C9699939497969190918F9088868B8986
8988888C7E84878A857985827E7E8581807980847E7C817C787B797B7B77707F70737675
7D75787B7776767976746E7274697174716B6F706E6C7067706973686D6C6F6F6B6C6D6A
69646B64636C70616A68656D7068686560636B6964666669626262646660665E59626361
665D656167645DC200000000000000000000000000000000000000000000000000000000
000000000000000000000000
E467666669686966706B6F71706B66626869696B727074706E6B6C68696B6B7072686971
71666D727471686E6D6C707B6C6C71737173737175777376797476777676776A75787679
76777479807B7881807A7C727274767881797779817B7E837C79837D7B83867C7D7C7F83
817F80918886898E8C8B8B868C909391878E8C89898E95939A939197969292969397958E
9F969491989B9E9598969E9C9C9EA0A19BA39EA4A5A6AEB5B7BBAFB8B2B4C3C2B3BDBAC9
C9CCC8D6CFC7CCCCD4CFCFD8DADDE2E0E6E7E3EAEEE6F3E7FBF0FAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFBF9FBF8FD
F6F2E6E8E8E8E1DCDBD6DADAD6D4D1D1CCC8C6CCD0BEBEC0C0BBB7B4B9BAACB2B3AFB8AD
B7B1A3ACABA9A5AAA3ABA4A39CA1929B969B94949B97998C9194919991938F928B8B8E8E
8E828689878683878C7B7D847E897D818184807A8179797F7B808080777975787C7C7679
7A7871746871717973716E7472746B787A756D6F726E6A6D6F6B70716C6E766E716B6F6D
68726669636970656666696D6A6A6466666D64696B6D686C696266676466686462675E63
63665C636A6564BC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E96E606E656B6E6E666A676963686D68646E7066646D6E6B716B6F696D6D696E6C647169
6B737168706E6C6E6A6E69686D71746D6C7374797373777B78787D74747876776E70767B
73737E7176787676767C7D737B7576707B827E78857C7C807E7B83827C7D7E7F80808780
81878487848E8C8D8D86909096968D948E90958B8B918996968C99969698949A969B9198
9298919696949A96949F9D9FA09D9BAA9A9E9CA4A6AEAAADB3B4B5BCB5B2B6BAC0BDBEC3
C3C0CAC0C9CBD4D3D0D5D6D9D6DCE4E7E1E4E8EBE4F1E9F1FBF9FAFFFEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCF4FFF8F5EE
F0EFE9F3EAE8DCDBE1E0DDD8C9CED3D9D2D6CFC6C4C6BEBAC1C0BFBFBCB6B3B5ACB3ADAB
B4B1ACAEB0A4A0A1A6A396A19C9FA096A697A09F989A959094929391949B948E86909289
888C8383888484887B7E80867D828383838184837D797E7D8784797C82807A727F787779
76747679747072777070777373766C6B6F706E6C6A786C7076686C68666A6E6E66696C66
69686B6C716A686C64706A66696166656B62636464636769636868615F66646163666160
5D5E675E635D64CC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
EA6F6E6969656E6E6A6C6E6D6C6269696B646B69686F696B6E6C69716666686D756F766D
72716C6C71666C6870706E676970706967776E766B6F7579767B7A73747670787376767A
7A737A787E7B737B7D7B757774738074797F7A78787C818180848280858C7B8182838084
847F848A818C848B8E8E8E8D9290898A8A8B8A8E8C8E89919694A0949A979B9B93989699
8C96929A919497A5A69FA2A5A0A69FA0A0A3A0A4A6A8ACAFB0BEABAFADB1B9C1C0BCBDC4
C3C3C5CECDC9D2CBD1D6D8D4DEDFDDD8EDE6E9E3F7F8F9FCF9FEFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FCF6F8
F4ECE9F2EFE4DEE0E4DADFDBE2DBCBD3CFD4CCC9C4C3C5C0C6C4B9B7B6ADABAFACAEAEBB
B9A8AAB0A8A9A9ADA8A0A1A29F9FA0A2A0989E9E9990A098938E93938E928C91868F8581
88838D8387808682817E7D857C7983837E7C818387837D7E7E78827B7A8176757E777774
81787C79767775746D7271716E706E7A6C786E6D706F716C756C706D706C7075656C606E
686F68676B6A69686B65666D68716060666C6166686A6469646263646364685E6A676063
5C626264606464CA00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E86A6A615C65646C666E6E6970677063666C6A696B6F6B6E686E70697070686F6871696C
766D716B686A7070686C636D6363696E6E6C76666E7775777B7C7F74706E726F6B787B7B
7476747676707475767C6B7E73797F787C7B76747C7B7E837C7C83867E80837A80817E88
8190858984858C8A8A888F898E8B908B8F938E948B8C939A91959198999B949C94988D96
8E94968E9BA19FA5A1A4AAA9A9A9A7A5A6A5A69BA1A3A8B1AFB4B5B6C3BBC0BBB8B6C8C3
C9C8C3D1D2D6D0D9CED3D6DDD8E1E7E6E7E7E9E9F2FDF4FAF6FCFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFC
EEECECF1F1EEEBDDE2DCE0DCDCDFD1D1C8D5D4CBCEC6C7C3BBBDC4C1B4B7B8BEB9C3B2AC
ACB0AEABB2A6A1A5A9A29DA49D9EA1A0A0A29696A29C949C949798919490888589898C8F
8E8B848988898289808682828684867B817982818388797E81837B817A80817976787674
80747473767074737575757774716C74706E706D736E7070686E66626D686569696B6F6C
6C6B686F6C6B69686568636A647165666767666C65646B66646664696962646A64646460
6166606560645EC000000000000000000000000000000000000000000000000000000000
000000000000000000000000
EF6B6663716665696B5C5F6E6B6B6764656C666B6A66686C6F696A6A68696F716F6E7474
676A6D6C70706D726F72707266746C686E71706C7472757582707C79736E737276787676
757C797B7F7B787580767C7C73717E7D7C7C76747E7C78778081767D87797C8980857983
81818A868A8C89868D8C8C8E979B8A9288958D9594899691909696919693969E9E949994
99968F999899A19BA6AAA9A5A7A5ACA6A6ADABA4A8ACACADADB8B3B6B5C1B8C3BFB7C4CD
CBCDCCC9C8D9D5D6DCE3DBDBD9E1E6D9EBE9F2F8EBEBF0FCFCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FCFA
E7EFF3F2EEEBEBE3E9DFDCE4D9D8D8CFCDCBC9CFC6C6C8CCC4B9BAB6BCB8BAB4B9B0B7B7
A7B1B2A9A2A0A4A3A7A19EA0A09AA2A39E949C9B9597A0999899929E928D8E90898E8B89
888E898B8984818A80898680817F787E877F81798079817F807879737B79787B7F787871
797872737773737B7976767179757676736E7069706A7064716D716964676C656B71696B
6C676569696A68686E696B6E6E6A686B62706B716F60666469636D6F656466686361616B
6365635C61605EBF00000000000000000000000000000000000000000000000000000000
000000000000000000000000
EC676763686872696E696C69676B68676B6B666764657273696E686B686D766E6E6F6B6C
6F6E6C6E69716B72646E6A726D6C726B747375757173787C8482817575786F7471767976
7A7E7B7E7779767A7E7B6F717C7C72747E8083797C7E7681807C7978817F7E817F7E898B
838687888188888784888B8B8F898C8C93918E8B8C93938E91929B91909B9894999A9697
9697969A97A0A1A8A5AAA9A6A6ACACAC9FA0A0A9A1A6ADBAB1B7B7B8C0B7C3BDC2C9C6C5
BCCEC7CDCECED3C9D8D8DADBE1E8E7E6E4EAE7F1EEFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
FEF0F9F4F4EAE1EBECEAE8E4DBE0DCCFD3C9CFD0C8C4CCC4B6C1B1BDBAB6BAB4BBACB5AC
ADACAEB4A2B0ABA3A4A1A09CA9A19EA0A19D97969E989B989698999B9888908C8D8C8E91
8E8E8C897C888F858484808584877B80817980847E837C7E7C807E7E777E73797E79787D
7B75757E7076757073747472717175737678716E747171696A70676E6D6F716B6F6B6969
6C6B6E6C6B636C6C696C66646C70696E6761667665696863666860616664666A64636566
61615E65616167BC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E7696968696D6A6D6B646B69636F686C666B676A686E696C6C6B6B6F6C66667073666C6D
6C6E6A6A6A6170636A716970706F70746669746A6E767D78797E7F747479747D78737279
7C737C797C787E7980747978767B7D7C797E78837C787A7A7C7B87807E7F808286808388
88848B83868690888686898B8C8F90958F908D8E91999098959C9B929F99999899999398
928B8F989998A5A5A4AAA0A9B1A3A1ACAEA59EA8A6A7B2B6C0BBBAC5C1C0B5C3BEBFC6CC
CBC6CCCACCD3D7D2DEE9DEE3E3EBE8E9EEEDF0F6EEF4FBFFFFF4FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB
FFFAECEFEFEFF9E7E9DCE7DFE0DCD7D0C8D1CAD2C2C8C9C6CABBC2C0BCB8BCB1AEB4ACAD
B1AFB1AAAAABA6A3A3AE9CABA1A8A4A3A09CA291A0A397A1969495988E9190889398878E
898E8E888B8C8A827C88867E8384817E7980747C7F7A7E7E7A817E7C79767F827979797B
867A7775737A72797F73787973767C707373717970716C6B6C6F6F706E6B6A66736E706B
686B69696C64696264666B69656F6465636C64676267636664616160626866626363625E
645E6864616163C300000000000000000000000000000000000000000000000000000000
000000000000000000000000
E369696969696B646B67696B6C6865636C6E6C60706E466B6C6467686C686F706A706E67
6C686768616C706E65726F6873696A696B6B756971746E74717A756D7470717679707D78
737778747978817C737476757581797E7B81827C797C80817E7D82877E838082887F8A86
818C8981898A8A84878C8E89918B948B888B8E93918F93989C959499959893929A9B9893
9895989A9D99A3A6A2ACAEA4A9A8A8ABACA8ABA1A8A5B4AEAEBCB9BFBBBDBCC9C1B7CBC1
C8C9C8D1DAD6D9E0D4DEDDDCE6E5E4EBF0F6F8EEFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FBF0FAFCFAF0E5EFE4E3DAD9DBDEDBDCD0D0C9CCC4C3C9C6C2CBB8BFB9BCBDB9BEB6B0AB
B2B0ADA8A9A8A4A89CACAAABA3A398A2A69E989B9EA09C9A918D8E8F958C8A9490898B8F
8D8791888D87868B86807F897E7E81767F80807E7F81807F7981797B8073797F817D7C75
7B73707B7478767373786B7978716C776B74716C6F716E746E686472686F696F636D6B67
7364686E6E706C6B6E6C6E676D6C6B6B6766666F665F666C5C646464686769616D616468
615B5E6163635FBC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E5656A6C69686A676C6C6E7066646B646A6D6B70706262706E69716D696C6E6B71676C74
6B5D69686A6A696B696A726D6C68706C746E6F6F6B736F6C807673737779766C7B7A7476
7A787976797D7F73747C72727688837E86807B7C86847B797A8380827C81847E7E818581
898B879489848A8B918F8B868D9691939398938D938E919493979891989D97929196999C
93969797A19C9FA3AEA9AEAEA8A1B5ABADA69CA6A7A8ADB5A9B4B8B7BAC1C9C5C4C5C6D1
CCC8C4CED9C8D6DFD4E4DDE3E4E3E8ECEAF6F6FBF8FDFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFCF9F7F1E9E4E5E3E9E4D9D4D9D1D3D1CAC9C8D0CAC8CCC1BDB3BDC1B9B9B4B9BCB0
B1B7ADB0A6B2ABA4AAA6A69CA199A5A1A29A9E9B9C9A979C9B9C96918C918F9496918A8F
8D899888878C8C8C8581817B8780847A7A83837F7B7981747E717B767779787984787D7D
767677737973727B7B81817972746E727173726F6F716D6C766E716C70796A6D67697173
706E6864696C696869646564696D6666666769686E666C64696465646464686264616363
6268605C636666BE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
EB69656C6B696664686B6B6D6C66637069686B6A686C726A6A676C6F717170706E6D7065
6E706A7069746E68676E766D6B706E6F68686D6C716D747C737A74787169727678797574
797679747F73747C7A7D7A7B787C797F81827D8378798478837E867F807B80897F7E8185
81847F8188868E86908486898B8F8D938C90939391899199928C9A9E949794919D979C96
9B8E989393989BA4A6A6AFB2B4A9B0ADA8A9ABA7ADABABABBABDBDC3BAC6C4C0C9C8C3C4
CEC6C9D3DBD8DCE6DADCE4E9E9E6E7ECF6F0F9F5F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFF
FEFFFFF1EEEBF5E7EBE8E3E4E0D6DAD1D6DAD6D1CCC6C6CCD1C7CBCABFBCBEB8B3B6B4B9
B3B0AFB1AAAAB1A5A6ACA9A59F9CA3A69F9E9D9C9A979C9E929A948B99918C838C92928E
8A8B8C8C8F8987838980837D8679847B7E7F7F7C827F7D7C7D797E797475797B7879787D
77797876757974767E757B717279747170706F70736C71706F706F756E6A717168716765
6D716D706B6D646B6A666D63616B6A6667646569646C646168615E606069596464646161
635E6B635E615CBF00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E96A6665686762686C706F6C6B6C6B6D6F6F6A6B6868686A65746E6B6D6B6D6D6D716669
676664676C6D6F6B686E6B6C716D6D6B68707066676F6E736E6B6F7176726E6E71717479
7571767E73797B6A757276767A797F827F787D7B7C7D807D7E7B84817E7F7D8183868B83
868B84818187858C88888A90968A928B98909699919894939894959B919B969F979E9897
9798969E94A9A1A3ABACA4B0AEB1A6A8A59FA3A9A6ACB5B9B9BCC1C3BDBAC0BCC5C7D1C3
CBD0DECCD3D2D9D6E0DCE1E6E1E8ECF0F8EDFBFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F9F1F1F1F1F1E1E3DEDCD8DDD2D8D6CAD0D4D4C7D2C8D0BCBDB9C4BFB8BAB9B4B3
B7B0B1A9A6ACA6A4ADA5ACA2A2A49FA0A6A1A3939B9E9F9A9E96929094909397988D9391
958B8890898C898B8485838281817D817C7F79807B827D7A797578797E7C7B7C7880797B
7A7871787678767379737572706B70737170766B6974716E686B6F726D6E6E6D746B6A6B
6A6C6C63696B706B6B6C6C686E75606D6A67656B66686A5E66686560676361636864645F
626B6B5C656369B800000000000000000000000000000000000000000000000000000000
000000000000000000000000
F06466646E6968736D716F6965666E686A706F686E6C696B6D696A6E66696D6C69716D6C
6C68636F686C676B65736B73746D70696B666C696E6E6E6D727870757A7471747B766E76
767976727980787C726D7971787D7E7C857B7E80837D7E7C807C84837E7E83838E8A8988
888686898D86898E8A8790938B938E8D918E979496978F9A9F95939B989A969B9999999B
959B9C989499A1A6ABA4A9A5A9A1ABA99EA4A9ABABA9B1B8BCBCC4BAB6BAC4C1C5CCC6C4
D1CBCBD3D8D5D8DAD6E5EBE0F1F0F9EFF8F9FBF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFBFAF0F4F3F8EDF0E9E8E1D9DDDBDBDCD3D2D1D6D4CBC9C9CEBDBCB9B3B9B4B6B9B0
AEB4B4ADACA8ACAAA1A9A39BA096A1A6A39CA49F9C9994959099999B868C90958B989493
9488908C868B8683898189887C808182787E7A788382837D7C74797478717B7C7B7C767A
747E7779787678747875727572756D74726D656D716B6D6F74716E706E686E6C6A6E6F68
6F6F74716B6D71676E6A6B6D6A636B67606969686D666464606A606766656666625D6960
6366616161615FBF00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E96E68666E6B696672656C69736B6C71696B6E66696D6E696F6C6B6868686B6A6A6B686B
6C666D686169676E686F666D756B7672726A6B7069717174716F736F737675747B777474
72707A797777757B787B767B797B817E8280747D847F85808082868484838E8C8A868C8B
8A818B8B838C90888B928485918B93998A8E91949199939498989699959C97989B99A1A3
9E9996939999999CA39EA8A3ABA8A9A6A5AB9BABA9B3B6B4BDBDBBC6B9BCD0C6C1C9D0D1
D0CFD9CFD8DED8DED9E3E0EEF0E9FBF4F8FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFFFEFDF9EFEBEFF0F4EBE7DCD9D7DADCD8D6D5D0D9C9CBD1C4BFC4C6B6C1BEC1B4B1B0
B0B3B0AAB6ABA6B0A59EA7A4A2A5A69E9FA498A1A09894919693998E94988C9091938D86
8F878C918589819287898A79887D848080838684797A7B767878747979737B7877737977
7574746C7E7574757970767B6E6E786F706F74776E707B6C6F746E716B706B6E71706A6F
71686D636A626D68696E6A706A6866666C6968656964656361636461615E636165645966
61635F685E6365C000000000000000000000000000000000000000000000000000000000
000000000000000000000000
E9676D6D706E68736A6974666D6A736E6A6E70616D6A686C726E6466676D676C696F696B
68686A696D67696B6E6B6F737075716D6B69686C676A6E70706E6A747E7976787371787B
7B756D7476767477717E7F7E82827E7A897C877B80807B7D8386837F8185898784908788
8882818A93858A86948F8E848F8F94938B8B90958E899B988F8D9E95A1939C9A9C9B9C9D
9B9DA090969A9F9B9CA1A7A1A5A8AAA4A3A4A4A8AEA8BBBAC4B8BFC4BBC1BEC0C5CCCCC8
D3CECBD1E0DBD6DCDFDFF0E8ECF1F9F8F4FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF9FFFFF7F3F6F1E4EAEAE6E1DBDADFD4CEDAD4D8CFD4C9CCC5C9C5BBB8B9BCC0A9BC
AEB8B8AFB6A9AEA4ACA9A6A6A8A09CA19C9C9C969E9A9D94909A989B8E91938C90908E91
8893888B909389808285868C83808286817E787C757E827D7D787C7C7576787E7B7A7376
797474747478757579766F6E77726F6F746C6F747270746C71677670666C736B696B6B6C
6D6C6E70756E6668696670686B6B696A6866686164666168676C69685B6A666965636164
67666B665E6562C300000000000000000000000000000000000000000000000000000000
000000000000000000000000
E86A6B646B6B6E6C686A6A6C68706E6C6E65696E6B6B6A666F69686E6E6F6F6E71706767
66656C6E6974657172696B7373716D66736E6E6C63676D727075736F76767178736F7B7A
7C796C787B747F797D75787D81817E7E80867D83828183837C8085808684838590868C84
86828C8588889181848C908F91898B91969693919B969B9B949B94A19EA1A3A2979EA09B
9C9E99A39E9BA39D98A1A0A4A0A3A4A2A3AEA3B3B4B7B9BBBEBDC1C7CAC1C2C9C8D4D5CE
D4CAE0DCDBD8DCE2E0DAE6E5F3EDF6F3F6EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEF6F9F4EEEEE5ECE1E4E8D4D8CFD9CCCFD2CDD0D3D0C8BBBEC5BCC4BEB9BCBB
B9B0B7B0ACAEAEA9A5A2A5A6A5AA9C9C9DA2989D9E9E989A969996949B908C8D948E8990
998F908A86928E888680898885827F8479867C7B837F7C767A7577777383787077747172
727C6E7C706A79747376766F7477737175737579717C6F71756F716D6C6C6E6F6B69686B
696B6B666B66646A636F66666864666A68666664706764675F69666660665F5F5F606268
645B6862585C5BBF00000000000000000000000000000000000000000000000000000000
000000000000000000000000
EA686C6A6A686C6B6C6A696E71646B6566716C706E6C6C70686B6C6E6E6B6B6D6E6D6E67
66636C646E70636B726C676E70716D6A6A6E666D5E70716D757478767373747379717579
766E7977747177807E7B8179808181847E7C8579847C8181837A84837F84838888888E83
8990878D8C888791928F8B90948D8E8C90989090939A90999B97909E9999989E9BA19899
969DA19C9D9B9CA599989D9FA1A3A1ACAEB0ACB3B6B7BCC4BEBDBBC9C5C3C4CECCC9C6CE
C6CFD6D9D6DDE1DEDCDEEBEBF0F4F9F9FCFCFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFEFCFBFCF1F1F1E5EFEBEBE4E9E4D4D6D4D9D3D1D1CED4CDCDC4C5C0BCC1BBBDB6B8
B4B1B2ACA8ACADAEACA4B3A0A6A8A6AAA895999B99999C9393908F9994968F8E94938E91
9498948A908987878688848888878081827E7B847877807D7A807B7C777379787E797A73
777177796C6E73746F71757574747673737073727475767274706D6A6C6D6B6E68696B71
6B6B666C696B6A676E6964686A696669686C6A6462696264646964696871666664656365
65686764646360BC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
F06664656B6C6D6E686A69686C716D716E686669696D696C6C6E6C6A6666707475706970
666C66696A6B6C6F726E6D776A796D70706F6868687170736B7B737B717C817077797173
787C7B737A7C797D7A7C7B797C867F80807E817684817E84797E907E838B85898B8B8988
898B8385848E86918B8D8A8C8C8B8D8F969B909796909B98919E9E94999B9C9E9E9FA19C
9E9E9B9E98A198A3A4A19FA4A09BA4A8ABA6B1AEB6BCBAC0C0B4C7C2C2C9C6CBC8CEC9C9
D3D6DBD3D6DCE2E0D9E3ECF4ECEBEEF7FEFAFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFBFEF8EAEBE2E7EAE1E0DEE7D5E5D5DFCBD0D1D1CAC2BFCBBBBBC1B9B9AEB6B6
B4B1ABAEAEA9B0B8B4A5A4B0ACA19EA1A1A29C9E9F9E9893A197919288939190909A8C8B
949190958A868A899087888384898181817E817D81787C767B75707880717774777D7074
6E73777978737379747178787670647774717471736F72726D706E756C68716C6F6C6B69
6D6A6F6E706E6C676868686D6A6B6B6E676C7067636D6B66656166686862606163695E61
5F60595E61625BBC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E36B63716568666B6D6F6B6E6C646E6B6A716C6E686D69646E6A6C6971676C7373746B69
6868696B6B686E6E6B6E6B77766F736B73666A68676E6D737772717B797B72797E7D7C75
7176767D777E79857781787C807B7B7B868184847C7E9081818283818989897E858A8684
848E8989908290928D8A898E9294928F939B9390979C9A909E9E9A909A999699909B9CA1
A1A2A5A2A8A5989CA4A1A2AAA5A8A3A5B4B2B6B8BEBDB9C1BFBABEC3BDC5C5C9CCCCD3CC
D6D9D5D6DBE1D5DCE0EBEEDFEDF3F8FFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEF9F5EFF7F6EBEAEDDCE5DEDDD2D3D3D3D5D0D1C8D3C6C5C3BEB6BBB3B0BAB1B6
B1AEB1B0ABB2ACAEABA6AAA7A99BA59E9DA8A1A19896979E949A9791979699968E90938F
8B8D918C89828885868A878982868B7C837D807D7B7B777C7C847B76767C74797B7B7574
73776E79727D7174707478726D6F707474726A73777B797872706B6E736B6D6A69706868
7062646869666E616C6B726C6A68656B6861686569635F6665676C6A6565616B63656469
5E636663616D5FC300000000000000000000000000000000000000000000000000000000
000000000000000000000000
E9696C6A66666E6868626D6C6E6C646B696E676E706A68706668686C68686F6B716C706C
666B6963656C6868716C6E74706B736E6C687166696A6E73757A7375717A7D748278797B
7D777E7878838181807B7A8176787E8079827E818185847F877E7E828A8989868287858A
8687918B888C8D8692818D949690A0939096989199909C93969C919F99A09C9996A19EA0
A0A3A5A1A09DA1A9A4A9A6A9A8A8B1B1B4B4AEBFBDB6AFBDB8BFC3C4BCC3C3C9CAC8CCD1
D2D6DBDBE0DBDCEBE8EBE4EFF1ECF9FFF5F7FFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEFAFBF3EDEDEAEFE6DCDED9DCDCD6D6E4D0D1CEC8C7C8BBB1B7B3AEB8B5B5B6
AAAFB7B6AEACAEA1B7AAA9B2A5A8A19F9CA3A2A8A79B9A9C9496969694989C9693938E8C
93838C8B888E8986818B8B86848380837E8083747F7C7E768082797C7B7E7A7B787B7975
72766E596374797978756B747876766B6D737366787473746F6B71706C6F6E696C686D6E
6B686F68646667686669656E696C70686B696D67666767726E6B666B68656A5F666A6867
616B6561686264C400000000000000000000000000000000000000000000000000000000
000000000000000000000000
EB6E6C61646C6C6B717466676D6E706B706B6F6B64696970736C7669686C646F706B6F67
656D6867706962746E706C6E706A74706A70666C6B6F6D6B7071757978707479797B7B7C
7B7D6E8079717F787C81807C817984837A7C7A7E88877D86788481888481848488848889
86898889938C888991848B898E92938E8E999690909094959099A19E9B9B9CA39EA5A1A4
A89FA6A0A4AEA4A0AFA9A3ADB0AFB3AAA6B0B9B5B7BFC1C6BCC1BEC1BCCEC4C3C3CED2CC
D4D4D8E6DAE3E8E9E4E1EBE9F3F3F4FBFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFBF8EDF4EEEEE5E4F0E4DCDBD8D6CAD3D1D4CED1C2C0BEBEBBC0B9B4B0B6B3
AEB1B3B3B4ADACAAA9ABA6AEA3A1A49C9BA3A89CA098939D9C9498969A95909399968E8D
88908B8A8E8D848C888E848482878080787C7D807D7F7C798078787374797D797E79787E
78807266736E727273786B7176766C687A6E73656E70797378706C696C726E6E6B646B68
69716C686B6A6A6968636D6B61656C6461696470706C716C696E686567646F7064646A65
56605E5D5E6062C400000000000000000000000000000000000000000000000000000000
000000000000000000000000
ED70726C696F726C6B7665637067696865676369706B696D68666E6B706769697470716B
696A636B636369656D706974706E736C7568717369736D6E746F7B717478767677798076
7A787E76817B748484837B7B7C817E7B847C7F7C7C7B8188848180867C867F91828B8B8B
8685858488888A9486878C90939791949496949C95919C9F999E9C9B9B96969DA19E9FA9
9D9FA6A6A9A9ABA7A5A7ACB0B4ACB5B1ADBAB7B7BBB8BEC0BEB8BCC2BEC6C9C9CFCFD3CD
D3D9DCDDE2E4E2E5EAF4F5EAEEF8F7FFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFCFEF9E4F6E4E6E0E1DCDCD3D6D5D9D0D7CBBEC9BBC2B4BABCBCBFB9BCB9
B4ABAFB0A7ACACAEA7B7A8A4A8A3A8A09EA6A29D9B9E9F9F969B98919D9499979792938C
918C8B8189838E848A838686867E897E8681887A7C7F7B7A827A7B7779797C7876737776
827873737471706E7B6E7476747972746A726D7978FFFF7570767163666E70706C6C696F
6368736C666B69646E64646B6F686F6B69666D66686868656D6B68646061606964616163
6C666461656468BC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E96E6B6E71706C716F666E6E6E6C646771696D666B667268666B6A6C656E676E696F716B
696C696564696E706E6C6E716B7470677070686E67737072737C6E777B7478777176747A
767779787D807C7A747F83797D82817D8183828888848388898283818888898581888D85
8C8486838B848B8B8F8C96908E8E95908E8E909C8F9990999898A2949D9E9DA3A39A9BA4
9FA5A9A4ACB6ADABAEAEAAB0AEB5B0ACB4B4B3B6B8B6BEC5C9C6C1C4C8C3C8C6D2CAD1D8
D3C8DFD5DCDCDFE5E6E7E4F8F0F8F2FFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF4F1EEEEE5EBEBE1DEE8E3D9CED4D3CBC2C0C4CCC2C5BEC0BEAEBCABB2
B4B8B0ABB8ACB6AEAEAEA8A8B3A0A6A3AAA4999F96969697A0979897989591929393898E
8E858B87878B8A857E8A828E8185817E7B7D8180747E877A7E7C7B797C757C797B717376
7D787971717175747673766C6E796F746C7673767B837B7270766C6C6B656B646E6E6C66
6F6D686C6A676767726B696E6D636670636B6F6E6E666A61646C6D626B64696366666864
66635C6763655CC400000000000000000000000000000000000000000000000000000000
000000000000000000000000
F0667168676A6767706A6C6D646A6E71676E6C6C6C6C6B6C6B617168696870736B6F6C71
6B696B656C6A636C676F69696F696C6B6B6F747073747375717272767A71746E73737377
717E7C76787881817C7472817B7D7E78807A7E86807E818B888483808D82848384868683
83838B8A8A9089898B8C929193938E9592918F8E9190949994A39E9C9C9D9EABA0A4A6A9
A399A899A6A8A6A9B0B2B6B0AEB3AFB0B4B4B4B4BCC2B7C5BEC8C6C3C9C6CCC4CECED7D8
D6D2D6D5DCE3E6ECECE9F3E9F4FFFCFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDF8F6F4EFE2E9E5E9DBE1DDE3DBDDCDC9D0C6C4BEC3C8C1BEB6B9BCAEBC
B4ABB1AEAEB3ACABA5AFA8B1A6A49DA1A4A1A29A959F9599A29C9E9C949996928D90978C
918E8E938A888C898B8B8784898C838481817B7A83787B7C797C8379797C7C7A77757778
73717D76797778727B6E747475737779786D747076756F78716E6C697072686F6C696B70
6B6C6B68686F706B666A6964666F6C6B65686A646B6B676865696965665E63656A646466
6268606164605EC000000000000000000000000000000000000000000000000000000000
000000000000000000000000
EE6666696E6A6D696971676E69645F65676B75696E6C6E6B696F6C656A6C706C6E70696F
69696B6C70716C68686E6C6E6E77746671666E71777073747E73757D7C6F80807C767B7A
8479798277737C7C7781767D858482798084817E81848483818481828E88818781868686
8D8984898B82908B8B918E8D8C90899291968E8E949593959798959E999E9FA399A19EA1
A0A1A4A9AEAAA9A3B3A9A5ADB5B6BAB6B1ACB1B6B3BBBBBEC4C4C3CFCDC9C6CECFD3D3D8
D6DBDCDBDFE5DAF0F0F0F1F4F0FAFDFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEF5F4F5EEE9E9E1E8DED9E5D4D5D0CCC9D0C3CABEC5CBC8C5BEBCBCB4
BCB3B5B0A3ACAFB2ABA9B1A6A4A4ABA6A09DA0A096989A96979B94999696958E99998E91
8A8A8C898C89808A8590808685848086837979807F7F7E7E787B7E7A757C7B7674808078
7B79737676707C70747B71786E716A73737073706F7770706B6C6C6D6E6C7071676D6767
6B63696B67696E61676B696C64656E646B676767676971616764696064616868636F6669
6564665960605EC200000000000000000000000000000000000000000000000000000000
000000000000000000000000
EC6969666A6B6B72726C69696E6E686C635F656466696C686C6C6E6C6C706C687071736D
736B736C6660646D6D6C6E686968706D6E706C6C6F6D6B6C7271747A75797578787A8075
747A7973797C807D82767C7B817F7C867C737C7E808984858083888A8A838E889088888F
898B90818F8884939392968F959390949B8C8BA09A98969C9E91999E9EA3979EA3A49D9A
A5A7A2ABA8AEABB4AAABADB1B1ACB3B7B2B5B4B8B4C1BDC0BCB6C8C4C1CCD3C9D3CED2D4
D5E2D3E1E8E8DBECF9F4F4F2F5FFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFFFAF3F0EBE9E3E2E0E3DBDED5D1CBD4CFC9C8CAC6C7C5C1C3C6C3B8B4
BAB6B1B3B3A9AFA5ABAFA5ABA9A9A6A79E9D9E99999E9894A096999090959F909094938E
90918B908A8B868E898A8783848884887A817E837C7F82807C7779767E807579787A797C
7F7B7A7979747474736E79726E6D716D7178757174736D71686E6C6C6C6C68677268736E
6E6C676B6C716869686E686E686867656C696E676E6C6B6C6A636460686162665F5E6B69
63646367636161C700000000000000000000000000000000000000000000000000000000
000000000000000000000000
E471696B6A646D6662666871696B676F706E6E6F69726C696C7169776B6A6E6B74696C6E
7174676B6E6B68696C68706B716F6C6C6F6E6C74776E747978726F76747876747676797B
787C7B837F7D7979787E7E7879757C7D817C7C7E848B8587858C83838C868586827B858D
838B848F888E95908C8890988D959B988E97999596928E96939E96929F96A1A1A3A5A6A3
9EABA8A6AAA9AAAFA9ADB2ABB7B4B9B4BAB6C0BBC3BDBDC4BEC1CBC6D4D4C9D6D3D4D7DB
D6D5D8DCE6E6EFE9ECF8F8F4F7F8FDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF5F2F1EFF9E6F0E4E5DCE6D3D6D1CBC9CEC8CEC3C6C7C9C5C0C4BBC1C3
B2B4B7B0B2B3B0AEAEA8ABAB9CA1A4A29E9EA0A1A19EA1A09CA09D96949494908E8C8C8B
91908C8C918E8E8F88918984838685897B80747F7C7C7F7974746E77807E77797B797C76
79767974737B797273707073707368707676726F6C797175726E70786B717068716A6970
6E6F6C696D6D696968686B6E67686968686869696C6664666B626261696664676E696562
64616464626662BE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
EF6C6E6F6B696A64346C696C76666B6960666674676C6E6B6C7172687171766D6767726B
71706B7367696B64666B6970736F707070696F6E7672717574727376726E73787B79737D
7C838584787A7A7D7C7B7A80827C7C7E83857D80828889867F898686898680848083808B
8B908F888F928D968B93929193938D999394919990969C9E98959F94999EA49CA49AA6A9
AEA6A6A6A8AEABA6B4B6B3B0A7B0B8BBB4B6B5BCB8BBBDC4B8C9C5C1CDC9C9CDD0DACCDB
D7E4E4E3E1E3E8EAEBE9F5EDF9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8E7F1F5E6EBE8E7E1E3E0D4D8CCD2C5CCC3C6C4C3C1C7C6C3BEB4B9
C1B9B3B5ADB4A6B1A4ABA9A1A4A9A5A6A69CA0A49FA29AA09A949C9B9996918E9895908D
8C8E8D918C8D8A858E8B86848285817A7E8E7D7B80817479787F78777A797B7A79797B7C
7E7B78777E716F73767B6F73736E6E6F7275757070726B6E7173756B716C6E6D71686C6E
696D73696E6B656E72646869686860646A6E64656A646C656769696A6E646664606D6160
66636161695E67C000000000000000000000000000000000000000000000000000000000
000000000000000000000000
E962676A6A6C6E685B646B6B696465696B6A6B6C6E6B6C706C6D6D70706C6E6E73686B6D
696E6C6E67696B696E6E696A6E6D6C746B6D6E71797573797D767776787777796F7B767C
7C817C7B7B79817B7881817B7E7C7C7A818482867F837E83898784897E888183838B848C
808B86868E8B89888D8C93889495909989939494989E89999BA1A19C9E9A9EA29DA09EA3
A3A6A2ACAFAEA1B0AAB6AEA8B5B3ABB5B0B4C0B9B9BBB9C3C6C4C2C4C4C8CBD2D4D6D4D3
E1D8DFE1E8F3EEF9E8F3FBFBF6F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF6F3EFEFE4EFEEE9DEDBCED8D6CBC4CFCED6BFCBC3C9C4C9C4C6B7BC
B3B9B9ADB3B9ADA9B3AAACA99CA6A3A29EA39AA39EAEA1A19C949B9A9299998E8E8C9090
8C8D9098848D938C87848088838A8480807E787D7F7F8181837B7E8074807F7C777C7871
7D7A6E74717B7B796F707672716F6E767070747471746B68696F76697074706E6A686E68
666C6C606F6A716D696D696365666A6B646668665D6E666A666665666162636761606763
68656465646D63BB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
F066666E6B6D6C70706A6E62696C666C6964696B6E6C6B666F67706B746E766B6C726968
6B76707370646C686F6B6D716E6D786C6E74707868766E6F7472787272717B767C7B7A7A
7E84807978767C797E817B7C7C84837A7F7E8383817B8384868485878B8487818A898189
88898A878E84948B9092918E91918F8F95939B98919699999D9DA0999999A099A1A5A1A3
A6A9A9A8A9B3B4A9AFB4A7B3A9B3B0B2ADB6B3BCB8AEBEBCC6C2C2BECEC4CFCECCC7CDD4
D9DCD7EBE1EFE6E7F4F3F1FCF6FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF9FFF8F9F9F1E6EBE0E3E8DDD9D7DCD1CCC8C8CBCAC8C9CEC1C0B9B8BCBC
BCBBB5BCB6AEB0ADB3A0ACACB5B1A1A1A2A19C9CA09A9997959994959898928D8E93948F
938F8D888E8A858B81858B888389807A7C837A7D7E887D7B79817A7E7473767675827276
7B80747976757A777474727B747471756D6C6C706E78706F796E716866707067696C716C
6B676B696972706B696C696A6E706D61646B666A6666666A64626261646B5C635F636866
5F656364616161C100000000000000000000000000000000000000000000000000000000
000000000000000000000000
EB6265706B6B6C6E6B6A6D676D6C64686B6F67686A746E6D6E667870717066726B6E6970
6F6E706E7171736C69666C71756C70706971746C737076737B76736E7A79787883787F7B
7E787D7A8280767D797981847E7E7E817D8280807D7B848483858D848B898888888B9384
8C848B8D8B998E988B9E948B93928B938E978E9999909391929393969CA0A5A99EA09BA4
A3A5A2A3A8ABB1B3A9B3ACB3ACB1B7AEB1B3BBB8C0BDBEC1C3CBC8C5D3CBCED2D4CED6DA
D9DAD7E7DEE0E4F7F3F8F5F0FFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFAF1F9F0F2EBECE1E9DCD4DADBCDCBC9CAC9C6BCC7CEBDC6C0BCB8C3
B9B4B3B0A8ABB2AEA9ACABA7A3ADACABA3AAA1A09A9DA0A39B9B99908F978E9F9390919A
888F8D8C87848889878389898384847F807C7E88797E7E8180807E84767A7E7A76737978
7A757A737276787A73746B736E7579706E70706C6C6D747677727173746B6F6D6C6A6963
6E6E68686A676C6C69666E6864696A66696466696B666A69666567636C62615F685C6A61
62656564626161C000000000000000000000000000000000000000000000000000000000
000000000000000000000000
EB6C6963646E6E706C6C6B6D696B6B696B66646E64646A71736E716F70747067636B6A68
70686E6E716C6F717465706E6F6773736879746F747670747574787B6F78797C757C7381
8375817E77737B858181818681807C807F80828482828A85808389818084838388908087
908B939686908C91998E8D90988B968C918E8E8E9699979C98979C9B9B9CA598A09CA2A4
A8ABA1A6ACAAAAB8AEACB3A9B0B7AEAEC0C1BBBCBDBEC1C3C3C6C8D0C9CEC9D5D1D5E1D7
E1E3E7DEE0E6E8F2F1F3F0F6F6FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFAFEF7F3F2EDEEE6E8DED6D9D4D6D8D4CFC1D1CBCFC1C6CBB4C0BEBABE
B6B8B2B4AFB0ACB0ABACACA8A3AEA3A5A3A6A09BA099969D9B94A098989098919B968A8E
918E898F8885878B8C897D878B83817F84807E7982787A8178747D79807C7E787B7B7D75
76797C7E817C78757673706F706B706E6F746E716A7476706869696B71686E67696C6E6B
696C6C706068696D6C606A6A6B666E6A626263646569686365656166636D686865685F61
5E606163616062C400000000000000000000000000000000000000000000000000000000
000000000000000000000000
E7726968676C73706F66686E6E6A6A70686C6C676E6B6C73726E7166696C6F6876737168
68706A6B6B7074766C74716F77776C7071747078777470747B757E797C7A767A76797E77
7E7D787C787A7D76767C807C7A7E82807786817C88808083897D8881868B8C85898B8E86
838C8B8E8E9291929598969094938C9091968E8D9498989C94989EA499A1A39C98A39E9C
999CA1B7ACAFB1B6B0A7AEAEB9B4B6B0B3B0C3BEB8C3C0BDC3CDC9CED4CECCCAD3D6DBD9
D6D8D8DEE6E6F2EEE8EBFAF3FFF6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF9FBF9FBFBE8EFEBE6ECE4E0D7D3CACAD8CED0C9C4CAC6C4C0C6C0C4B6
B9ABB4AAAEB3A4ACB1A8AFA7A0A8A39EA0A7A19FA2A19B96999896989890949B9A8C8A90
878E87848A918B8C8389888A848D808088897D8489837D7F8579827A79797B7582797C75
757470767E7F7474717C71767B76717076776A6B766E706E696B756F69706C6F6A706B69
6665636D686C6F6B616868625B6A6468626367666768676C666461646867636663626568
6668615C606063C400000000000000000000000000000000000000000000000000000000
000000000000000000000000
F2696F6F6C6C686D6870686C736E6D66696865666C69666B6865716C70686B6E6B707066
6F6F6B6D6B6D6C6C6B7377696D6E6B6879717775717179767675727B7274747079757C76
797F807B7A7B7D76747B7A88848283867D818A807F88838384847E86858085848C84898D
8E8990898B948F8B8E939289919490909097989994939790999AA1A09B96A19F9BA7A4AC
A6AEA1AEAEB0AEADB2ACB2B4B8B1AAB5BBB5C0BABCBAC1C8C4BCC6CCCEC8D3D0D8CED4DC
DAD8DAE1E8ECF4EDF3F7F7FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF9F0F7EEE9ECEEE8E3DCD9DED8CECAD0C6C9C6C9C4BEC6B9C1BBBD
B1AEB6AEACADABA9B0B0A6AEA8A8A6A5A39C9CA0A599939A9B95989391979496918E9193
908E90888188838B8A8C83818C86877E7D8481847E8B7B7C797F7D82807C7C7C7C7B7F7A
80737B78747B797172767170717172737474767775716E73767070716E706E716E70726B
6E75696D6C70636A67656768686860696068686666656362696963686D6C6560645C6368
5F5A6460695F5DB600000000000000000000000000000000000000000000000000000000
000000000000000000000000
ED6B69686F6D686A6968706E6C6C686C67676E7168686C686C6B71686D6B6A6B6F6C6E72
6969786D6D706E696E626C6D6870716B78787771767373777171767E72777774747C7880
7B7C7C7A7B737880827D847D7B807E807E837A86807F7C88897E7B7C858B8B7F7C818681
898990878E8D9094889094908F908C919191929193A19B998E9CA1949DA1A097A29CABA0
A8A0B0AAA9A7B2B3B8B6ABB0ABB1BBB4BDC2BCBFB4C4BFC6C3CACACCD8D0DCD7D5D0D1D6
E0E1E4E3EAE9E9F0F3EEF6FCFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF4F8EEEEEAEEF3EBDCDED3D3DAD6C7D5CECBB8C0C2C9BBB8B7BBB4C0
BEAEB6A9A4AFADADAEA6AAA4A7A5A2A19DA2A2A0A1A09A968E8C9A97949A86949189948C
93938C9186938988858F878183818180848479807C73837B817A797B7873767F7D70797B
74747978787B79736F6E717370737472726F6E7472786E68696B70706E6F7063696F6871
6A6F6964636B6E6F6E63676B61686C6A64666C6665646C696666636B5F5E6A61645D5E63
64665C60615E64C800000000000000000000000000000000000000000000000000000000
000000000000000000000000
F16E6B6C766D6B696A68626B6F6E706E6B6867666C666966676B6C706E69706E6E6D6E6C
70707074736773726E7672746974756E787276717274767B78777578767173807C768079
75777D797E797F7980767A7E7C837C7F838681848884868183838682818980858588818A
8C888A918A909290918B87918F9C968E93919399909698969E98A19CA1A19EA5A2A0A5A9
A5A6ACACA9AEB4ABAAAEB3B4B1BAB3ACB6B4BAB6B9B9C1BDC8CBC9CBC9D2CFD8D4DADEDE
DBE1ECEBEBE8F9F3F3F6FFFAFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDF6FFFEF4ECF2ECE8E6E4E5E6D9D7D6D6C6D4C9CAC0BAC3BDC1C4BFC1B9
B4B3ABB0B0B1B5ABB2A1B0A9AB9EA5A4A0A6A4A6999D9A94969694918F948F9398929190
8C8B8B888C8B8486898B84838886887C7B8679828884747D7C817B7B7C7E74797C737678
757974707A7A7A777B786D7774747973746D6978726E696B6E73606D696F686E6E6E6A69
5E68696A6A6C676A66666760686F6C656361686E696E63606165676069666A645A656464
63636166696062C500000000000000000000000000000000000000000000000000000000
000000000000000000000000
EE6E636E6C7073646A73716D6B656C69686B6F6C6C6668606970646B7469666E706D726C
686B677074746C6E76726C6F7172787174746E76737279767872767279717471757B7372
7A6E7278767E7E7D81807D7D7E7A83807F89827E8681798E897E808382818B8989868390
8E8D8C8C8989919091968D9492868D94968C98919A9B98989D9B999E9F9CA89B9AA0A69F
A3ABA0AAA8B0B0B2AEABABB4B7B0BBBBB2BAC0B5B9C1C6C3C4C5CCD3C5D6CED0D3DAD1D8
DCE5E4E3E2F0F4F5F5FCF6FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8FEF7FAF9ECF7EBF3DFE4DCDEDDCFD0CFD0D3C5BBC4C1C0BEB9B6B8B8
B9B6B4B5AEAAB4B4B3ADAEA1A9A8A5A6A0A1A49F9D979BA69B9D98A2949693938986938D
888A868B8C8C8C8B8980908B88808A827B797C83818180797E787C8276817B787F7E7B74
76737D787175787575746F706C776D6A717978776C6E72766E6A7561726E6D6E6B696E6C
646E69666D69736861686B66606C67686E68686362636368696361626063606A68696066
64636363616363BD00000000000000000000000000000000000000000000000000000000
000000000000000000000000
EA686A696B6D6D6D64696466726B6E6B6C63636A69696E69666F69636E6C7169686B7168
68776B717272746F71736F7074747B7B73757373747074746F7475757473727977736F77
77747078756F707876797F7A83848480887B827C7E88817F8683838C8089808586848883
898E8B89948C8A898E918C94979194949494939795969891989E9C99959DA0A09AAE93A8
9E9BA4A4A4A9B3ABB0B4B3B0B5B3B1B0B4BBC3C7C3C3C7C8C6C6C5C8C8D0D3D6D0D0D6DA
DDE0ECE7F0ECF0EEF3F6F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFEFFFFFAFFF9E6FEEBE0E5E6E8DCDFDDD7D7D0CBC6C4C2C1C3B7BEBCBCB9B0
B7AEB4B2B3ADB1B8B1A2ABA6AAABA2A3A79AA6A19D939694998C9696999B929292908E93
8D898E8D92958686888086877C7F83897C7C837E817C79827B7C7C7A7C7B76747B7E7C78
7A777976777179727478726B7576756F707270706E726B726C6C6B666A69716F67697068
66696F6970686A666F6B646E6F6864676B6765666469676169686963626A69635E636866
5C6165635E5F61C600000000000000000000000000000000000000000000000000000000
000000000000000000000000
EC686B6869696B6A636B6968696E6C6A6D6A6C6B65676C6A73696B6C686A73716E706F6E
6A6E6E6B71766E6C7067706D74727572766D7370766F7071757A767476747177797B7976
6C786C7B6F787779797C798179847E7C7E80887E8B858181807E808080848B84898B8983
8C84907F89868D8D86898F90999992959A9490989B9E929D969C9E98A29598A3A6A0A1A9
A5A3A3A1A9A8AFB1AAAEB6B4BBAFB2B7B2BBB9C6C6C2BAC4CAC5D3C9D0C9D0D7CED5D4D1
D9DBE3ECEBEBF4F1ECF6F6FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF9FAF4F5EFE6E9EBE5E6DBE1D9D4D9CACDC1C3B8BFC1C5C1BCB3B9
B4ACAEABB4B3B0ADB0A4B1A6ACA3A4A8A4A0A3989497979E99999B8994968D8E90918992
8E888E8A8090838983887F818385807C897C848380847F7E80857A81767D7A7C7A807574
797A746F727679787B7A72707270767275736E6F69706B6D71696E746C696F6E6E696B68
6D6364686769656C646664696364646C646668676D68635E6565676869676A66666A6569
665E6366666463BB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E46964676C6C6C6B68736C6874696663676C6A68696C6C6C746B71727065736C6D6C716F
6B6B7673706C6C6B74766B6B7074726974766F7874797A79777B747478767877707C7171
737472717771787774797783838580828388818281838386808B7F7E7C80818B8B84858C
8882838984898C848690919189918C989990A4929E96959698A29E9D9898A4A29E9EA0A6
A9AAAAAFA9A4B0AFAEA9AEB0B5AFBEBDB7B9BCC1C3C1C0BCCCCDCCD1C5C5D2D9CCD6E0E1
E6E7E4ECE7F0FBF5F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAF4F1EDEEE6E1E2E4E3E2D4D6D8D3D2D3C5CBCDC4C7C4B6BBBDBE
B9B6B9B2B6ACB3B0ACB0A9ACA9ACAAA8A8ADA794989E9999979798909796989292898C8F
908E8E8D898A888383848683897F848889837C837E7E7D7C82817E837C7679757D7B7C78
7C7C7875747B727577757076767476716E70726F796F6B7265736C706C6D73716D736B67
6B6E686E706967666B5E646E6C6C6D686767656B6469656962636169676B6A6964686060
60645E6B656561BA00000000000000000000000000000000000000000000000000000000
000000000000000000000000
EB646B6A6B6A6C637066686870666E64696668686F6F686F6A6976736C6C6B706B6E6C6C
6F6C6A746C6E6C6D7971766E757079726C7670707074747C7075767B757573756E736B6F
696C736E7A74737174767F84818381838986807A888381837C83827E728289898989898A
8A898B88888D8D918A88899292918C9397949993909196909A9E9E98949AA39899A9A49F
A8A3A4AEA6AAACABAEAEB1AFB2B5B1B0B8B9B8B8BEC8C0C4C8CBCDD6D9CDCBCAD6DBD8DD
E4DDE1E3EAF9ECF0F7F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEF5F4EEF0E3F1EBE5E3E5DBD8D6D7CEBFCCCAC8BDBAC7BBBCC1B3
B9B5B4AFB9B6B4B1AEAFADAEA7A0A9A49E9CA29C989BA09F9A9E9B969695908B8C8C8486
909494908888918E84898B89838884867E7E827B80797D7D808274787C817B7A75727E7A
797878787579727277717373706C6C6C6B6F6E736C746B687271746E61667069696D7068
697070646B706E6C626A66686C656B65696864665E5E63666469666661676A6C665F6660
636161645D5C5AC900000000000000000000000000000000000000000000000000000000
000000000000000000000000
F2696E72666C6A6C6B706F6E6F626B6974686F706E6B666C72696E6C6B69786C7266717D
737B697773737474726C76716E6E797170707171717875727775727C6F74727273757076
706B7570717C6F7177747B7F80817C817B78887F7A84887E868181867E868E86888A8B86
8C8C8C8C91918E9389898B8E9393948B94968D919C9D9496A0959C9FA1A1A59F9EA0A4A0
A5A4A7A7ACACAEB3B0ABB5B5B4B3B8B6B4B5BCBDC1C3C3C4CBC0D3CECCD4D3D8D2DFDAE4
E5E1E9E3F3F5F0FCFFFDFFFFFFFFFFFFFFFFFFFFA1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF2FCF8F2EBE4E3E6E7EADBD8DCD2D6CAD8CCC7CBC4C4BFC4B4BDBE
BAB8B8B6AEAEADA8A1ACB0A7A8A2A6A0A09FA3A19E969490979A9A959699908E938C8E8B
8D8C8D8E8E84868C888C848C86847C888783827C7E7F797C7E787B737C797B7D787A7679
73847A77817E76797375766B72747473706E6F716E6C6C716B70686B6E6D6E706C6F6E69
6869696C6462706D686B666E616666686B69696868636662606458686C635C5C645C6262
5E615E5D646363BA00000000000000000000000000000000000000000000000000000000
000000000000000000000000
EE6C6C6B696C6B6C636C686A6B6D666B666B6B6E66716D6B72666969716F6C6E7372726C
6E6C6F7A73716E707071717578747075667572797B767D7676797A787B6C75747B747174
726F7277767073787975797C797A817E80837D818080808382868687849086848888828F
8D86888F898C928891918D94989591969293979496A28E9D9E9B94999B999E9FA1A4A2AE
A2A6ACA2A1ACAAADB4BBB4B4B5BDB4B8BCC0BFB6BFC3C6C1C3C5C6C9CBCFD3DBDFE0D8DD
D5E6E6ECE4EEE6F9F0F9FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFFF8FEEAF0E1E8E6DFE1DFDCD8DED3CCCCD2C7C2C6C0C0C4C2CBC3
BAAEBCA8ACAEB4B3ABA8A4A9A4A19FA8989E9BA19E9B9898918F959196958B8E8B96908E
8F8E9189898984868C868E86868C807D8384797C7B7E7F7C76817F797C787979767E7E75
76737676747671736E74777675766C677B6E70717072756F6F6E7470666B686C6369656D
70666C6B6B636671686168636866686D686F69636C636E63696668646164646368686263
61645A60645E61BC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
EB676B646971666D6A70706B6B6E6C696A6D6E646E6D6E6B6B706E716E6F73726A767472
7674766D71727971776E7172716F71727376797C72777B7A747873747373736F7B737B7B
757074727C7474767B7A777C807B867D7C867B7D81888282848488888382858986858B88
8E8A888B848F8B9190919091908B8E978C9A939A9691979DA4999B9EA19AA099A8A69CA6
AAACA9A7A6A3B0ABB3B3B8B9BBB7B9B8B3B9B8B8BCB7C4C3CAD0CCCEC8D6D3D0D9DCDBE5
E6E4E7ECF6F6F1F4FFF9F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFCF9FAEDF5F0E9D6E3E9D9D8D3D1DAD4CFCACDC3C1C9BDC0C0BEBB
B9BBBEB6BAB2B6B0A6ADA8ABA9A6A4A9A3A6989B9FA49697A099999B948E9093998B9394
918D9289898B848E838E898C8C8385847D7F7E7C827874797E807C787E747D737C737679
7E787C79717577777675716E717069736B6E766C6F70707170716C6E706D7373696E6E6B
6D6D63656C69616C6B6C6864616A6C6766676D6666636E63646864686763646B6B6E6561
645A5C63686363BE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
EF696D6869636A686E6E7370706E786B6C6B686C686864686B6E716B6E6C6B6C6F717176
737078706F76707670737376746C7774766C7978747B7B77757A79797B707073736F7779
757E727879787A747677767C7C8480867A847E7C8684837C89868683858990868B8B848D
888489918B8E8B8E94889291899391999194949499A197969A9C9EA0A1A3A0A8A1A1A7A6
A4AAA8A7A9A7ABA6B0B1BBB6B6B6B6B1B9BFBBBBC4BFBBC6C3C2D1CCCEC9D7D3DADEDBDB
E9EAECE8E9F4EEF7FCFCFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDFFF7FCFAE6E2EAEBDEE1D8D8D8D9D1D9CECFC3C9C8C7C5C4C1C3BB
B9B6B6B4B3B4ACAFA6A6AAA9A39D9EA2A0A2A09EA19AA1A19497958F8C9391918E8C8E8A
8E86898B8986878886868C8981898583866F6F7E7F847C7E78777C7B787A7E77787C7F78
7D73717473797675737874737375716F6F6C746E716970706E70716E6E6E6B736E6B6969
666B6D6B69676D7064686666647064686966666A686E68696C6368636260676364666464
666465655F6560C000000000000000000000000000000000000000000000000000000000
000000000000000000000000
E86C6B696B6B686C67736B6B6D6C656E6D6C6B696C746C676A6E73776C716E71756E786E
747373717A74796E736D716C7C757673767473817E7C837E76767573706E70716F737B7B
747875737C72707B7479777C7C7B7F7F837E7C7F82847C90838681888C8384848C8A8C87
8887898E978B8B8B9093838C948B8E969A95999B9494999C9D9EA1A2A29F9B9EAAA8A9A3
A8A6A3AFAAADABB1B6B1ADB2B4BABBB9B4B8BBBCC0BECCC8C3D4CCCAD3D1D2D0DDD9E4D7
DCE8EAE9EBE6F3F4F2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDFFF1EEECEBE7E1DBE4E1E1DBD1D5CAD6D0D0CBCDC8C8BFBDC0BA
BBC3BCB4C2B3ABAAB0B0ABA7ABA2A4A4A1A3A39A9699979494908C8E9192888796988D92
918C8A8C87818E8D8B8A8B9088868384808B5C7E7C7A767B767F7A6B787C797D757B7374
737E7A7D7C707C767176707B7478776771766C6F6E746C6C6D70686C6C6B6E70706B6B6E
6C736D69696166686E6C6B676868686769686C6A646468636363626360606261645D6B60
6269605D686361BC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
EC6E6C6B68686C6C726A676F646E706F686C706D6E6E6E73716D76687270716A78707374
707178786E717172717B706F71796F777B727776777D7D7C74757076766E6C747A747874
78797B767676727370746E787B80807B818083798380818888838187848B858983848694
86838E8C8C898D948A87928C93948D92908F9B959391989CA0999B9AA6A09B9EA3A9A19A
A3ABA6ABA4AEA9A6ABACB6B4B5B6B5B6BFB5BCCEC6C6CAC6C6C4CACCD1C7D1CCD8D9D9DB
E7E7E0E9E8F0F8F5FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFBF7F1F2ECF1DFDBE3E3DEE8DAD1D8D3D2CFCBD1CECAC4C5CCC3C1
C0B9C0B4ADB4AFA9AAB0A8A2A4A9A69DA29C9AA29F9C959E9D989A93939A959690939396
8B898788968B8B898C8C8F8888827D7F7B7D7E7C7E7C777A747E7377767774747179737A
7C7A7574707674757C707870706B6B736E686C6E6F726970726D736A70776F6A69666F6B
74666B71686B66686C68657070716F6C6A696A69696C6867606867666068676860606561
5E626166645E5EC300000000000000000000000000000000000000000000000000000000
000000000000000000000000
F06E6F616B6C6D686966697366766E6C7068717077716F67736B6C736E6B6B77766B6F76
7772736E717874706B6F726C6C77756F7C73777E8382798178736C796B7372717970767C
7A72797C757C7973717B7774767E84817D837F7E817E8B7C86868686828184838A8D808B
8989908F8B8B89878C8E8E94928B919395928E979499929499999E9690A4A4A89BABABAA
A9A9ABABACA8B1ABB1B8B0BEBBB9B4B7BDBEBEC6C3C0BFBECBC3CAD0D2D1D4DFDCD9D9DF
E4E7EBE9EDF5EBF9F8F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF9FEF6ECF3EEE6E7E6E9E3DED4DEE0D9CCC6CED4CCC4C7C9C0C6C3BE
BDBEB8B3B9A6ABB1B1ABAAA4A4A6ACA4A6A39E919B9598988F96949A968E919093968988
90908D93868A8E908389848B858780807E807E80797877757A7C787678787A7E79757878
7673797B75717C6E6E6D77797471716E71747373706C736E6B73707868726E696C686972
6C6E6B676B6B646E68666968696C616469696B616869665F64635F636C636766686B6761
5E6362675C5B61BE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
EB696E6973666B6B726B6B6E6C6B6866696B7068696F6F706B6B6D70776D747075787374
74737178777173767072736E7A707874707770807D8083827D7B71717071707475807B73
7B80757D7776787574737C7C797D7E82767C7E80847B888B82818F8B8B8283838B848883
8C878885868D8C8F90898F939192939693929094949B989B9E9B9C999EA59B99A69C9EAB
A0AAA4ACAAB19EB6A9B3B6B3B1BEBCC1B9BDBEBEC3C3C9C1C7CCCFC8D9D0D8D3D4D7D2E1
E1E2E4ECF2FBF8F8FFF6FFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF5F8EEEBE6E8EDE4D9DEDBD8E5D6D0D4D4D1CCCAC6C6C4C1CABF
C1BCB5B8B8BDB5B2A6A6B3A1A4A4A699A39BA09D9A9E97909696968E9993929790928E92
918E8E92808C8C86918E8186818786857D80787679707E7E7D7C7C72717976767B7E7E7C
78797878717174787471706B73716F70756C73737572776E736B6A6B7073706B69686768
686B716A6A6B696D6568686B6B69686A656E6163696462616569646C6864646161646463
6166605C625F61BB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E56569675F6B6766716B6C6E686472656F706B7164696C72716E746A717175766E70736B
7071716E766F7170786E717473747175797171817E817C7B7C74786C6B707278807B7880
78767F7C7479797574797A7473797E757C7E80867E84837F7B897E827F848C8086868A8A
878D89888C8E91908C8B919393949C908E96939793989B9894A29999A09EA5A4A2A3A3AC
AEA3A1ACB2AEAEA9B7B3B2B0B6ACB7BCBCBAC0C1C3C4C7C8BCCBCBD6CFD2D4CBD9CFDCDE
E6E2EAE8F9F3EFFDFFF9FCFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF9F8F0FFF6F1F3EEE9E2ECE6DADCD8CECFD6D9CDCFD3CFC4C1C3BEC6BF
C4C1C0BFB5B3AFB4B0ACABA3A7A1A0A6A39EA0A19B9B9C989698988C91958C8E908B8D8B
8286908A8A887C898C89848C80868579867C7C807C7B76777C7E767178787A787A7C7783
7F74797E767472767C7C746D746A7072736D7072746E746E7174706E7073717A726D7070
6A6C676769726A69686767686B6671666864656D696C6368696266656068666160666666
64616062606164BE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E86B68716D686C6A686B68666E6C716A706D66716E6F6F6B6E6E6A69686F706C76737379
707874747473797471756D716F717571777978757F7C747776746E6F72767476737C797B
7B71747B787B7E76797A7C798273797E8384848680898884848387878A90858E82898688
8E919489888D8C988C8B908C9091908E8E8F969C8998A09A979B9BA1A2A4A3A1A0AEA69E
A2A9A9A5A2A8ADB5A9B7B8B6B1B6B3C1B7BEBBB8BBC1B8C1C8C9C7C9C9D0DBD0D6E4DBE8
D8E6EBF0F4EEEBFFFEFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF8F0F0F2E8EAE1E4E6E7DEDDD9D9D1CBD7DDD6D2C8CDC9C4C3BDB9
B4B8B1C1B5B4BCABB3B3B2A8A6A2A9A59D9DA69E9C9C989B999A9D8D989093899190868D
88918C9586908C8E90868884877C7E8078808680807C76797D7C767E7B767778757A7B7A
7A797D7E7B7C7B736D6F777571786C716F7074716A646D6F6C6C6D6D6B676D6E7074716C
6E6E6B686B6C6C686F626C696C666A6B616A62645E6763616C6269636D6B61615F685C66
645C5966615F5BB900000000000000000000000000000000000000000000000000000000
000000000000000000000000
DD6B746B606464696B6868736C72706B6E656F6B656C6E6C6D706C6E706E727171707071
767476716F72707471706D73707476786E6F78737B7D7679787176737377717473748373
797F73727E757976797E777C75778486877E7E7D818280808888838A8E88908D84878691
8E848B8788868C908C8F86968D9699908F9C988F9E91A0989D96969F999E9AA6A8A9AAA4
A2A7A8AEA4A9B0A9ACACB2B6B9B8BAB6BDBCC0BEB8C5C7C8C8CCC8D0CBD0D8D4D8D1E5E1
E2E3EEE3EEF3F6FEFCFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDFFF6EDEDEDEBEAE7DCE3E1DBDDCBD0E1D1D1CCCECDC9CFCBC0BCC1
B8BCB5AFB0B8B3AAB0ADA6A8A9A7979CA39CA29C9B9997949497988B919389888E878B8E
8B8E888B868F8888858B8283878381787A7D7C817E7C7B80807C777C74777D76747B7A7E
777B80798371767376716F746C6D6C7674706F686C7173696A7168697170737472677470
727370646B69676568716B64706F68656964646666696666646865686863646369626461
5B5E5B6160635DBC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E065686F6D6E6B6E6C6A6474706A64706D66696C6A706F6C706B6C766C6E72706A796A71
787274696C646D7472786E7575727A6C726E7778797C6D757173736E786C747B7A767B7B
7B7B807371797A7376757679737C84837F7B86827E8083847F7E87868A8A8B88868B8889
89898B898C8E888C8C90919292919291919A999B9699989693999BA79C9AA0A4A2ABA9AC
A8AAA8AEAFB3ABB4B5A6AFAFAEB8BFBEB6C0BEBBC2BEC4CCC5D0D0D1D0D1D4D2D4DCD8DC
EBE9E0ECF6F6F7F6FAFEFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFBFFF5F8EDF0F4F0F1E8E8E1DFD6D9DAD8D4D1D1C8C9C6BEC8C1BCC0C0
B3BBB9B0ACB8AAB2ACA9A5A5A3A1A0A0989B9B949E979896909898978C8C8C8B94928C8C
8C848E848B85888D87857F837C7B807C80817D78827E787C7C7B7B7B76767C7472737C7A
7E7879767C7A757578787173717570737B746D706E6A6E6F7A6E6C7471736A756E756F6D
70716E6B6D6C68666468696C73646864635F666567646C5C626564675F67615D5D61645C
5E5B61695B5C61BC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
EE6569656B646B616E6E6D71697170716D6C696E746A6B716E717171736C6D78666E7470
716F7073717271706E6F6E70736E746F6E7B76787678717C79727173766C7370777C7476
7A7481767377787276727B797B807B7A7B7F81787E857B867D8083878F84848B8B898481
838A86888B84998C908F949989929693969B99909E96A298A395999AA2A09BA09EAAA0A6
A1A6ABAEACAAABB3B6A9B0B6B9B7B8BBB7B4BDC5BEBDC3CAC8C7CCC6D6D8D1D4D1DCD7E0
E1E4EDE8ECE9F9F3F8FFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF9F7F7F3F7EBE7E9EFE9E0DCD1D8E3D5D1C2D2CFC6C7BCC2B8B6BA
B2B4BCB3B1B7B2B3A8ABB3AEA8A4ACA3A49B9BA393989E96908F90919489968F898E8C89
848A838D8087918F82878B7D84817881777F7A7B7981877378847E81797C737773747373
7C797D7878737E7E757872706E786E6C69776E6E687071756F6F716C6C77747171777C76
726A6674666E68676B636B636C676368666964646869656668686662636566656C5E6A5D
606363625E615CB700000000000000000000000000000000000000000000000000000000
000000000000000000000000
E8656B66646E6B6E70706A6A716C6F6A6E68696B70706D72717071716E70737972747878
6B6F74726E6F70726E74717178737970746F767373747675727471716C72707479747470
74757974737B757476767C747C8081837780787D8582817C81808B858B8B858286868B8B
8E898E858C898E93928A888B8F928C92948F969D999C9E969A9BA0999DA2A2A3A0A6A19D
A6ABA2A9ADAEB4AEAEB1B2AFB7BCB6C1C1B8B8BFB8C4C8C6C0C7C9D1CDD4D6D9D1DED9DB
E7DCE5EAEDF0E9F9FFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFDF4FAF0F8ECE9E8E1E6E4D9D6D0D3D0CBC4D1C6C0C0B8BFBABAB3
BEB1B5B4BCABB0AEACAEABA6A8A7A7A3A39A9B9B94999999998A909396939791958E8E89
928886908B90828E878882847E8B79817E80767B7F837E7E76797F797E79766F7B787B79
7A7B797A797B696E6E7676766E6E6B73737463726870696B6C6E6C73747370787C75777C
747468656867676A6760696C6B646869615B616368666B646969626561666864625D5B63
6563685B635C5BBE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
DF686A6B6E6C616C6569656C6C726E6E6D666D6E6F74716F7073726D6B7174787772716C
70716E7371736F77717274726E7174777677776C747A6C757577747370707370757C7372
787179727973757481797E797B7D797B7D83807884847C82838A7D807E898886848C8889
868B898C898A968B8F91918C8C94969690919999919199A09B969E9F9C9A959B9BA8ACA3
A3ADABA7A9A6B2AFABB2BAB6B3B3B8B6B9B6BCBBC3C1C3C9C9D1CED1C1CFC9D4CDD0E7D6
DDE8DEEAEEEEFDF7FFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFDFCF6FEF1F3F0ECF3E3EAE0E4D8DBCDD0C5D2C7C3BBC3C5C0BEBFBAB8
B4AEB6ACAEB0B3A7B0A2A8ABA59CA6A1A1A0A19C938E959494939498919091908A8F908B
869189858C8382888E82837F7C7F82847D7C807C7E817E797B7F7A797E7D77787E7B787B
7B787A6C7974787572757377706B6F73726E696670697379726A6C6B6B746A6D807A7C7E
72726E6C6C6C6B666B68696A6A6867636166666A6664686463606466695D60665F606366
615B6362606461BB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
DB676A66636D6E686764686E6A6C647173706D697166726A756E71716E73717166697170
6B7276737373796E746F757074747079707C697772787973737770777B766A73786F7879
79747B7978797A7678768078797C7F7B8178887C7B7C867E88818A88848B84808B858685
8A818E91908C878491898B9195909198919595979C988CA0999B949EA3939F99A1A0A9A5
A5A5A9A9AEB0ACA9B2B0B0AFB9B1BBB3BCB5BBBBB8B9BBC4C0C6C9D1C8D1D1CFD7DFDCE1
D9E0E6F0F3EEF3FEF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFBF8F5F3EBEDE1EBE8DEDCDDD6D3D4CDC1C3C9C9B5C0BEBCBDB9BE
B8ACB1B7B3B0B0AAAFA4AAB0A8A1A19E97A19E9197969A919588918D8C9B8A908C90868A
91898C867E88848F80838383827E7B7D7E7876767D847C78787E7F817E727A767A767C74
7371737977767979766C74737176687673706C6E766C736D726E6C727069757471797673
6E746C666F745F6B6A6663666865696A65626263615E63685F606769656264606168645E
66615E5C5E6760BC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
EE6E68656D686F6A656B6E6A69696C6867696D716E6C717473716A776C74696B73706D70
706D7870787172707473706E796E6E7175706A7A71747A73767572757474717671737073
747E79747D79797D787C767B7B82817B808086797E867D82838B8381878F8C86888C8C87
8C8C8C8D8E848E97878C8E91928D918C919499A0969E9D96929C98A69D9D9FACA2A2A0A0
ABA4ACA9A9A5AEA8B2B0B4B9B9B1BABEB9B2C4BBC0BCC0C4CBC6C4C8CFD6CED3D4D9E6DE
DAE8EDF4EBECF6F9F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFFFFFAF5F4F3E9EFE9D9D9DEDBCCD3D0C3C3C5C6C6C6BCCBBCC9C1B4
B2BDB9B5AEACABB3AAA8A9A6A39EA1A3A0999CA29B9B9994909F899A94818E8289969389
88898B8589868088868188807B7C767E7B7F808784877B7B807B7C78767378737C768078
807B707574736E6F7971786E736B726F74736D6D6F717376716D70726A6E7378717A7A74
6E666C676E636968646B616B636868636C6766696B656B66696762606664675F5E625F66
645E585C66615EC400000000000000000000000000000000000000000000000000000000
000000000000000000000000
E46C696E6973656B6A6B656A6E6A6C6B71716C6E69706B6E686F6C7175716C706C737174
6F6A6E6B7871726E77786E726F767273736E7077796E766D747974736E74747976797479
767578747F727274797B7C7E797C757F8486868288818384838B89838B8888818D858787
858888878B838C8A8D8987919288929197979394A0939498A8979C9CA3999CA2A5A4AAA9
A6A2A2AAA6ACA6B1AFADAFB0B3B6B9C0B9C0BFC3C4C1C7C0C9CBD4CAC5D3CDD1D1DADCDE
DEE2ECE0EFF3F1FCF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDF8F9ECF3ECE4DDE2E0E0DFD5D5D4D0CEC9CDC4C5C8C1BAC0B8BFB7
BEB1AEB1A9B4ABABACA49EA59DA498A09B99A0969399968E9390918F8E93968E8F91898C
898D8B918F85887D8E7D817D827B7D817E7E847D7F7E737B797E767D7B78797C7B767879
727174777971737C77716E73706C726C6D6D7171766D6A666F706C6E66767776736E716E
6F6D6C6864686C6B6B68685E69626969706463606B5F61606066696464616661685F6162
64615C5F616354C300000000000000000000000000000000000000000000000000000000
000000000000000000000000
E16C596967666C686B6A6A746D6E656B646E696B686C726C71716C6F756C6C756D6F6C68
6F736C74777775747371746D70717171696E70776E7A70767773757D7672747675767378
73786F7874717B78848178737B7E83847E85887B7D7F7D867C7D8282868181838985848A
868B87868C8784838B8B8B91948C9693949691919B9396999899A09B9B969CA19E9CA5A3
AEA6AEA0ABADB1A8B0AFB1B4B4B6B7BCC0C0B9BBC0BCC3BEC4CBCDD0C9CDD4D5D8DAD7D8
DEE1E7E3F6F1F4FFF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFCFFFFF9F9F4E6EEE2ECE4D6D8D8CEC6D1CACBC3C2C3D0C1BDBEBBBBBA
BAA8B3B6B6B3ADACAFABAEA1A3A1A498A4A1A19F949699949993908C87908E8C8C8C8C90
8C86868D8885897D817F837F7B7A857A7B7F7C78817B7E81817B7B7E7871786E7B777A7B
767B77797571717173716E716E71786D706C797370747074686A70696C70706C72716F6E
7069696B656B6569636A666D65686667696B696264656164626767626466616465665E63
5E616464606156BF00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E56E6B6968676C6B686C6C66696E6E736B6B686971706C6E6973716E6872726B6E6E6874
737878696B7671777570757078737B6D7178737471737876787676717473797A78737476
77747278797C7E70787375787C7B7682837B7B86808182808B8186828982848880808A86
8484888C898D82888C888C8D878F8D9998969C98959999959D9D99A39CA39EA1A19E9CAB
ABA1A8B1A3ACB2A8AAB0B3B1B3B5B9B0B9BEB8B4BCC7C2C3D0C7C5C4C9CCCECDCED4E1E1
DEE3E8EEF1F0EFF0F9F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF8FAFFFFF1F4F6F1E7E5DED8EBD1D5DBD3C8CECFCBC1C4C2C7D0C6B8B9B4
AFB5AEA8ADA7B09FAEA0AC9FA39DA0A39C99989B9B989892979191958B91968E988E898B
868D8985868387808984808481837B767E7683877D817978797C847B7677767473787C77
7679767873766E7972777773716F787A746F706E716A65726C6D766B7065736C6B636C6C
6E696E6D6C676566666766666664696B6366606168666066666069655E626B6462636F5E
64605F5E625E5DBE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E96466696A6B6E696B706F6B726C666A6F6E6A64686B6F746B7079786E716C736C6C7271
717370737272726E71707073787570787374747374727573767A76777B80747B7776737E
7E7A797F777C7880747E767B8278807F7C7B7C80798B878282868685837E84818389888A
868B868793888093888C8E8E888B8D92909690989C9C9C99929A9B98A8A6A4A3A3A3A1A6
A9ACA5ABB1ABACABA8B6B8B6C0B6B8B7C0C1BEC8C3C4BEC6BFCCCFCFC9CFD0D7DCDDD5DF
DEDEDFEBE2F3F3FEF8FCFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFBF1EFFFF0F1E2E0D8E1DBD9DDD2CFD3C9CFC4C2C6C1C5BEC4B9BCB1
B6B1B6B2AFABAAB3AC9DABA0A9A3A1949FA09BA1969E9593919499949693939194838D99
90898C8A9288868C8481897C7C8C7978787F7C7E7A74767376857676727271747B727674
776E7A716E73736B726F727178706E766E6E6B6B696F776C74686C6F716D686C6B6E6570
6E6D6E69666B686B6A6A6A656662616868696A6960636165666066646461606267626168
635B65665C5A5FC200000000000000000000000000000000000000000000000000000000
000000000000000000000000
E8647065656A6D6E64666A6E65696B64696E716C6E6E6B696B6C766C736E6A726F737273
6D6A6B6F767576716C7677726C7574747477777379767B707C6C777671787C797B7C7E72
76807C767E807D7A787C7E7E807D80798779817E85817C8183848284858B827B81888581
8988898C8086898590848B8C869090938E9093979C98979B9B9697A0A09BA49DA0A7B0A5
ADA3A8A9ABAEB9AFACA9ACB8B8AEB8C1B7BCBEB6C8BFC9C6C4C4CFCBC5D6D4D6D7D0D9E0
DCE6E3E1F1ECEEF7FFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF1FDF8FBF6F1F8E6E4E0DCD8E3CED1CCCBD0C8CBC7C4CAC1B9BCB8BBB8
B5ABABB4B4B1A5A4A2A8A8A5A89EA19CA4949C9CA09698999C8E9491939492918B868B8C
908D858C87808E86868877867E817C7C7D797F7B7E7481807C797B7C717178717B726F78
746F6F767373747A747172746B726E7470766870686E6E6A666A6E726C696B6B686D7070
686068626C63686B706C6B65696A666767646869666666646A6B6C6363695D605F636660
5F616160645F64C200000000000000000000000000000000000000000000000000000000
000000000000000000000000
EB6D6A6F69666E6B6C686E69706A6F6C706B6B6C736F716B747369666E72696A77687474
726B7674757C6671767C7371777470717471757377747B7A787B7A7C7B7B7B847C797C81
77767A81747B797E7C787B7B7E787F807A7A82827A7D817F857E7B848380848B8A7F8683
8785868482838987868791898A8D938B968D999999949BA0A09C999B9EA6A6AA9CA7A3A6
ACAFA6ABB2A8B1A8B1AEB0B1B3B4B8BBB9BCB9BCBEC3BECEC7C9C6CCCFD3D3D6E1D7E0DD
DCE3ECECF0F8EDFAFFF4FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEF4F3F0E4EFD8E4E2D9CFD8D0D6CDC8C8C6C1C2C6C6B3BAB1B3B8
ACB1B0B1A9AAB4A9A4AC9F9C98A69EA0A09C9DA3969499999196909091938F8B908E8988
898B88868B8B87888686837C7F7D7F7D7A79817E80777F7974737E74777D767675737370
75766E716C7175716D7575737173786C696F6F6C74766A73756C6D6C70686E686B646B69
6665656B6C6E6E6D6E6B65687361686B6466616269696667665E636368646D5F6A60595E
5A66585E616061C100000000000000000000000000000000000000000000000000000000
000000000000000000000000
E169636E6B696A6A6E696A6D6B6B6B6C6C7269766969666864696B6E76736C736D756C70
6E7B6C7573736B72776B746E737073667375796B77747B7370797178747E787A787A7D7C
7D7B707B797E7671777C7D7E7E7E79817E8178888181868287837E7E8A89817A8186888A
8A8A8186848B8B908A8384868F9189968E8C91959598999B989D999E9FA297A4A4A69EA6
ABA6ABABA9A8A9ADAEAAAFABB4B8B8B4BAB9B9C6BBC1C3CBC1C6CFCED0D4D6DCD8DBDEE1
DBE3E1E9EBF2F1F4F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFCFCFAF3F8EAFAECE9E4DDD9D5D9CDD7C1C7D3C1C6C4C3B9C4BBB4BAB8B9
B4B2B2ACADA7ABB1A9A8A5A8A29EA1A3A0A39D96A196959390938B8E8789918F87908F83
8B908587818486848681838B8D8B7C7B7B757C82747A7678747B786F7B767170736E6C78
6F716B6C71717073716C726D716E726C736B71726B617071706C736F68666B6B646A696D
646E6B6169686C6768616D646B6066616B6469696B5D646366596A67586266635E636065
596563645F5962B800000000000000000000000000000000000000000000000000000000
000000000000000000000000
E86C6C6A6168666A636A706C6F68696B6B63756A6B6C746B6F7073736B65766C72786F69
68796C7C6C7770737476757378717871707177767771707276737674798376727C7E8084
7C7C7B7E7C7777827B84727F7978827C807B7881837F878280848181818483827D898488
8483848881838886838A888788858B90908E989C9C999A989E9BA4A39D9CA0A1A1A2ADA3
A0AFA4AFACABAFB7A9B7B3ADB6ACB5B3BBB9BFBFBDC6BBC0C3C3C9CBCDD9D0D1D2D2D4D3
DCE6E3E4EAF5F1F0F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFCFFF3F0E6F6EDE8DFE2DFD6D7CDCECFCEC4C5C6C8C5BEBCB8B8B8B4B3
ADB1B0B1A9ABA9A6A8A19EA0A1A3A0A09C94A397939B9E8C959A98939091908C8D898B8E
8E918B81868D888A85868B818088828084797B7E7E787B807D747B7B6D73787376787176
6D787474726E6E6C7471717670767270757472716B516369726E6D716C656B6E6A666B6F
6C6F6868656B6B64686D6C6C6A666A666C6264646265695C675E635C645E63685E5C6663
5C64615D5C5E5FB300000000000000000000000000000000000000000000000000000000
000000000000000000000000
E0676B686D676C66686968707170776A6A6C72746E686D6E706A6C7078767773716E7474
716B6E73707173747071736F6B7176736F7477797573767B73717B797D747E777E7E7B73
7B7D797E7479747A767A777F79817E79807F8188877E7B8C847E7E81888183838186898D
88878A87888C878D878B8C8989878991919496989B9B9B9C9E99A0A19FA09DA49CA2A6AA
A8ACA8A9B1A4ADA8B4AFAEB4B4B5ABBBB8BAB9BABAC3C3C4C8CACDCEC9D0D3CECBD9D8DE
DADDDBE2E0EEF6FFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF9F2EEEEEAE4E6E0E4DAD8D8DACBCDC9D0CCCAC2B9BDBBB7B9BBB6B0
B1ABB2B3AAA1B0A7A4AEA3A09E9B9799969B9B9899929898969196929095939193909087
848889818C88868A817E818281808583797A7D81757E7B737B737C737C6F766F76717370
766D77726E79796C6D6E6F6E6F707370776E6C726E6B686B6D6E686D76716D766C68696F
6B68666F6A68696E69686865696962666C66616D65645E616A5F605C63615F6264675D64
67605D60645E60BD00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E86966676D636C6E646A6C696B6C68706D6C6A6C746E6B736C6F72716F726C6F7276726F
7073717278706D6F737375756A6A767470787578767870707C7C767879777A78787B817D
7C79807B7A77817C817E7B7B7F83788386818182888A8283858680867F8480817B807F84
8B8A8C868A898A938B87888D8D8B8A8C979999969BA09B9C9CA39CA59CA4A1A4A6A39BA0
AAA4B0ACB5A3ACAEAEB0B3A8A8B0B0B2B1BBB4BEB9B6C6C9C1CCC9CDC8CEC9DDD6D8D7DD
E7DBE3E9EEEEEFFCF6FFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFBF6FCFFF5EEE6E6E2DCDCDEDBD0C9CABEC3C1C9C3C8C3B7BDC0BAB4B0B4
ABB0AEABA9B2AEA4A29DACAEA19EA19DA0A3A0A1999C94979198939793908789908E8B89
848386858A88827F88828B81837F7985888076857E74807D7B7E746F7774787B79747478
6E7671786B6E706E706A6E70737573716B716974746F6C6B6F69706A62687068706F7166
696E69666C6470686B64696070616E6061676768676165666D63625C6166666561606063
6162595E5A615BBE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E16E6C6666646E686A6866676A6C7370716E70687072726E6C70696E7873736C746F6B70
76737976746D6F7477747A7C767B7578797773737A7675797978807778778373837E8078
74767978787E8077717E7C7B797B7B867F82838C8B848385838987897E7D7C7C81838987
888C8388858884838C8B918B878E8E8E898894969D9BA0999BA59E9CA0A69CA29E9F9DA0
A8A4B1A9A6AEAEA9ABB9ABACB1B6BFB5B3B3C6BBC1BCC1C5C9C4C9D0D1D1D3CAD6D7D9E3
DBE8DAE8F4EDF3F9FBF2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEF8F4F2F3E4E3E5E6DED6D7D3D0D3CCC9CBC1C1C8C1C2B7B9BAB3B3AE
B3A9ACA8B1A4ADA4A0A5A3A0A69B9B9F9CA3A6A197989390929C879C92969991898B8C87
868C8C90888C887B80897F838281837B807984788380817C7C77707D7B7B787677787979
78727274777471717470736E716F6E69706B716D716E6972726C776B6C666B696B6B6365
696B68636C6365686668606964625D635E636B685F656868636460676161686862635E60
62605F5E655E5CBD00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E96368666471666C667072666A6F7164696B706A69706E6B716C7070707371696F707371
6C7172787073736E7472707478766F71727873787375737470767B78797E737677767873
817C7B768073737979808078877E81838386838184818482868C86837C8280827E8E7786
8E8A838A8B8B93868C8D888E8E918C91979A8F96919398A2999B919EACA6A49F9E9CB0A6
A19CA7A0ACACA9ADB0AEB0B0B4AEBAAEBCB7C1C1B1C3CBC9C7C5C4CACBD0DAD1D3CEDED6
E5DCE6EAE6FFE6F6F8FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFEFFF7F3F1ECDCEADCE9E1DCDCD6CDD6D0C9C6CECBC3C5BDBFBFB7B8BBB8B5
AAB4B1AEABABADA8A9A0AB9B9FA3A09F9EA0A69FA19E9692988A908A8E8D888B8E8E8D8A
8984858C838B8588857D81837B837B817C7D79807C7E7A777D7682787A78757074787775
797C7A757974757071696B6B6978717076736E716E6B6F6A6C6F6B70746C69697168676D
5F6E696F5E69646667696469646A636A6B61656062676063616860646764605C665E635E
636763605C5E5EB400000000000000000000000000000000000000000000000000000000
000000000000000000000000
E16E686C6A646B6B6B71676A6773676B6D7173696F70746E7670747471725E7873767670
716F6E726C6E746E787D7076727B797671767B7477747B7874737B7678787474797D757B
75787C80787D837880817C7784858081838C818689838980807D7D81847D7A7D7B7E8385
848B89888A878E9386838C8B8A8B8C908B968F9A9B9497A29D9A9C9B9D9EA19DA89EA59E
A3A3A8A9A1ADACA9AEB1B3AFB0B4B4B7B3B4B3C0BEBABDC0C3D1CAC9C9CBD2D6D0DCDFE1
D8DCE3E8EBE8F3F6EBF9F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF9F2F9EAEFE9EBE7E3E8E0DEDBD3D4D9C8CFC6C4C1C3C3C8C1BCB8BCB4AEB0
B4ACADA6A0A4A0A8A6A4A4A8A6A5A6A3A4AB9AA2A0968E9B93908D9B898D93918D88888C
8F89868C8B84898C86888881817E767C828180797B7C827F7C797A7D797B6B78757F767A
8171797978716B6B7B6C6C697269706C7270706C6E716970696C6C71646B6B6C6B6C7163
6E666A686B696C646869666A62686661616463636A6C6862606560645D695E6B62636662
5E625F62635E59BC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
DC616C656D6C6B7169696C69696966706C716F68716F6E676D71767D6E6E676D78726971
72747473736D767B757073757877787A7474746B737973737579737C787678787580797C
77777A757F79787F7C7D757C7A8286808983868D86878C847C7C83807F7E8083807E838C
8C8988898B9189888C878B8F8A92899494998E9393999EA39E96999EA6A39B9DA197908E
9EA6A9ABA8ACACAAA8B0B3B3B1A9ADB9BEB1C4B6C3C1CABEC8C3D0CED8C7D0D1D0DADBDC
D9E4E3E6F2EBEBEBFCECFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFBFFFAF8F0F4F7E4E9DFE0D7E2DEDBD3C4C9C2C8C4B8BEC0C0B8B8B0B8B0B1
B0B0AEABAEA9AAABA6A3A3A3A6A9A39FA9A1A5999C99A29292928C88938C9089918B8791
8B848884888187858B80868480808180827881837F757A7B79767371787B71797D767B73
7874797174737273716D706B6B6D6E74746D717075706E766D73686B69696E687066686B
656B6D6E666A6968646A656967656961665E61646660635F61635E5B626460536267635F
616060605B5C5FBC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
DC6C6C65706F6F6B6F6B6C6C6668686A68656A726C68706D71787175736F726E74636F73
74736E747174726E70707276757C757374777C71787276727D7C787E7B6E78787A7B8477
747876797A74757B7B7F7E7F7E807982838B888C8A8588847E8484798184807E82808681
8488868788868983948B8F88878C8F90988D98969C90909C98959E9B989F9EA49D9D9090
9BA1A1A8A2A7A9ABABB0AAB5B3B1B3B1BBB6B8C0C0BFC0C2C8C7C3CCCCD3D3D6D4D6D9D6
D9DEE2E2E2E9E9EDF2F5FCF9FEF9FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFFFFFFF2EAF8F7F1DDE4DEE1DBD7D5CED0D8C4C3BCC9BCC8C0B3BCBEB8AFB4AC
B0B6ADA9ACA8ACA1A1A4A1A4A1A4A59DA0A2A398999B949698938B96928A8D96948E8D86
8380848682848681807F82827E85837E807E7B767F7E7C8178787C7C797874767B7D7676
76797B7A7B7075766D6E7673726A6F78696A6C706C6869756C706971756B696E6D696E63
6767686563676865666661616166616269645F6465606A615E64646465616B6468645D5B
60616061606058BD00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E1706A70606E6E6A6E656E6C6C6C746C6B716E6F7078766B707070757878797378737170
6C73747C736E707678747778737873797E7176837A757275787E87797B7A797580767978
7976787C7A79807B7F7A78807A817C80838684828E808582808686808983897D80818682
8486888A808989908A848E88898A8C8D91939996998E9798A19F9F9D939BA6A49A969090
99A1A4A6ABB0ABADA3ABB2B0B0B1B8B6B3B9C5AEBCBFC2BDBCC2C5C4D0D4CBD3D3D4D4D8
DED3DCE5E6E8EAF0EEF1F1F7FFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFBF9F6ECE8F7ECEFE2E2DCDED8D6D2CBC7CBC8C2C9C9C7B6BDBEAFACB4B2B0AC
B0ABA7A5A3AC9FA49DA6A7A99FA1A1A6A499919B9C8E9E98938E918A8E938B8E9189968E
948C83858486858387848678817E8874817A817D7E7B7F7B7E78737B7B737A747C737778
7673756F74766F6B6B6D716E7074746F716E6A6E6D6C6E6B706F6D6969686B6C6867656D
6867646B6767636B6E646E66616B666E676168686061625F6463615E6161686966626162
5B63633A585B60BB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E2696A6D6D6E696E716F6F6B6B6F6A6B7070696C6B6A68706E736C727873706A73737278
736E77716B6978796F6E7B6B6F797578766C7B7C74727B79787473797579787B7A787B7A
7E7F7977777B737C7F827F71807C83808382888586867E8A7C7F84838084868681787D81
808D888A898C8C8390888D948D8E949393939490949DA49EA0A3999F9BA39C959E9E9CA0
9EA1A8A4A3ACA8B2AEACACA8B4AAB4B4AEBBB2B6B8BECCBDC3C4C1C4C9D1CCD0D3D0D4D9
D6E0E1DFE0E8EEEBF6FAF0F3FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF2EEE8E8EFE6ECECE1D9D2CDD3D3D2CBD0C3B9C8BCBFC0BCB9B5B3B6ADB3
ABADA5ABA4B2A6AAA39BA0A89EA4A5ABA0A1A197969694958C92949197908E8E89908D90
838B8A8587857981867C8482817B7D817B7C847B787C7B78787788767677747A73767871
756E717873696D6F716E776E7371717174736666756C6E6B6B686C5E686E706F6B6E6869
696B6B66666C686A6B66646567686B626B5F6461666763696463666064635D635A606366
645E6316406058B100000000000000000000000000000000000000000000000000000000
000000000000000000000000
E26364706366676E6C6D6A696B6E6C6F6B6E6F6A696C76736A74716A676F757670757974
6D7471746E7678746F717A70797676777376786F7B7C7278757173737381797974777381
7B81768180807B7B837E837B8379867E84847F8382838381798886858481828183838B82
7C83828883888A89888E8E908B928E8F90918E919C9796919899989E9C9DA19C9C9EA3A1
A5ABA6A4A69FA4A4AEB3ABAEB0B2B3B0B4B3C1BCBDBDB7C5C4C4C3C0C4C4D1D1D6D9D5D8
DCD4E1E7E2E9EBE4F0F4EAF5FFF9FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF9FCFBF9FEF1EDF3E9E8E7DCD6D9D8D6CBD3CAC5C8BEC3C5BABFBBBDB0B4AEB6AFB1
A4AEA4ABA7A1A79D9FA89CA798A19B9B9BA0989E9195949696938B8F8D7F608B8C918D8B
8D898C887E877D8985838381847E7E817E80797B7B7B797B7C7E797577796E7176746E6B
74727074786B6B676E736E706D726F72716B686E68716F6B6E6F6D6C6E696C69686C6868
716D6C686A646A6D696966696C666469655C67635D6365665D63676A61635E63655F6162
5E5F6344515B55B600000000000000000000000000000000000000000000000000000000
000000000000000000000000
E66A6B6B6860686E7069736C736C696B70706971706A7378707474716D686E70706F7679
70767C717478717A6D71746D6D6E797A7B72778076757D70727D7B737780727B7F6C8078
7D7C7C797B7B7E797B81808281817B78808879847D7B838780838A848086838683868481
84828C8C888B8890888A8B908D8B8F968E939E9B999896979B9697A19B999C9F9CA0A1A3
A9A9A8AFB4AEACAEACA6AEA9B0B5B7BBB1B1B9C0B8C1BCC1BCCBC9CDC9D4CED3C8D2DADB
E3DBDEE0DBDBE6E9F1F9F7F4FFF9FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7F1ECECEAE7E6E9E6E2E0D6DDD6C8CCD0CEC9C9C7BDC9B9B6C0B3B8AEB3ADB3
AFACA8A0A0A39EA3A7A79EA09E9D999B9C9B999B968F91948F8F928F91968C888B8D8B89
888B86848683888082837E847C8B80897B797B7C807B78767C76797A7870766C736D7373
6E6B7171756D6C74796A706F716E6E706D697574706D696F6E666C696C70686A646B6B6A
6B646B6668646569666A696A63696C68685C66646160646463636664615E61635E62635B
5C5E6460615E61BA00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E46A6766686A6E6D666B6E6B6B6C716D6971686B69656C72716775736B716976746E6E73
73756E74766E74766E797C71777971707279747E7F7D76746F7970777C736D747B7B757A
797B7F7679747B797C74837E8283847D7F80838381857A8386847F81847E7F7679898288
8089839688878E898991949393828B8A909194939397999BA395989B9D9B9EA6A3A4A0A6
A5A5A3ACA3ABA9A8B1B2ACB7ABB6A9B6BDB5B4B9B9BFB8C3BBC1CEC5CECAD8D4DBD4D7DB
DBDCE3E89CD4F4ECF0F3F9F8FCFFFEFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFCFFFFEEFDF6EEE6E6DCE4DED7D6D3D6D0D3CDCBC8C4C3C4C4BAC1C0B7B7AEB7AEAC
B5A6A4A4A4A49DA3A6A0A8A5A09EA49A999999949498969B9D9395968C8E908A89858990
8889889387827C8681828487848A807A857B78767D7679797C7C7B78787C76727472746B
7870736E70726C7278696E747670746C73716E666F676F6C6B6E6E6B66696C686C6A6B67
66646665696B6C69636564646B686163646466626163615F6260666B6664666368646266
67585C64615F5EB900000000000000000000000000000000000000000000000000000000
000000000000000000000000
E36164706E696E7074706B6E70667274686B6C70716C6870766C6C6D7169727577797277
6B70717073737373787976717874786D7179707F7A71787975767978797D78747976787B
7E7878797C7B7981827B81867C8084817C808286838B84828885868B887C7E8385808889
7C84867F858B898B8C8C8B8A96898E9091919097979B9497949B95969B9AA1A69BAAA49E
A9A6A6A6A6A2A8ABADA7B4A9ADB4B3B1B5B2B4BBBEC4BEBEBCC0C2C2C6C8CDCBD8D6D9D1
DCD4E3DCDFDEEBECE5F1F0F9FEFFFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF6F9EBF4F3E0E8E4E5DED5D4D1CCD6CCD0C4CBC8BECBC7BCB8BEBEB0B0B6B1B1
AEA5A5B1A2AC9F9FAAA49BA39CA19B97A0939991919B88949493958B939185868C939188
8B85848686848089838986838486887E817C847A7E7C7C708083807C79787A73746E7172
746E6D73667976726C747571737073716D706A71696E6D716E72696969716964695F6970
68696A6B6667656D6C6E66665A685D635E61666C606666616662616969685B6663616362
5A5E56595E5D60B800000000000000000000000000000000000000000000000000000000
000000000000000000000000
EE666C6C6B706C706E796965696B6E6B696D6B6B7070696A6C706D71706E716D746E716F
70736F7371666B737274707E787674726B7979717C6C77767F7876707879787677797779
777C8179787C807E7C7D807D8484837E7D80867B8A80848383837C838C88818386948D84
898882898786828888898B93898E9892938E9792919299969A9E9D999FA4A1A49B9EA4A4
A9A3ABA2AE9EAAAEADB1AEACB3A3A4B5BCAEB9BBBCC0C0C2C1C8C8CBC9D3C6D2D0D1DCDB
D8D8E1E2D8E1EAE4E8EEEBF4FCFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFEFDF7F4EEE9E9EAE1E2E4D1D8D8D6CCCBC8C8C4C8C9C4C1B4C2BCB4BABEB3B1AFB4
B0ACABA6A9A39EA3A5999C9D9E9F9C9C969C9096949291909394949695928B88908E9288
8385858A7F898683797D88807B798B81817A7F797C777C7E7D70767B7E78757B76767370
6970696E717176717176787271686F72716E716E6E6C6969687161666C696B696C706868
6C64656C6A69696D626966696466656666606763696868685C626060635D62615D5F6860
625E605C585E59BB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E371716B6B6B6D6B6E6B7170696C736D6C68746B71717171696B696E6C7178706D6B7074
717474706D6B71777679797676767C7479786F7B7272717B7674767B74837F7378787E7E
7E797C7B7B847C7A7980818083788283787C7A7C787F7C7D8482848582838C8682888488
87868682898887848C88888D8E938D918F92969494999AA09897939C94A4A4A4A0A5A4A0
A2A2A5A9A3A8A5B1ACAEB0B0B1B2B3B2B4B9B6B6B3B8B9C1BFC3C4C5D4CFCCCDD3D4D2D5
D7EAD8DBE0DDE8EEECF1F9F8FBFAFCF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFEEFBF0F2E5E8E9E2DFDED1E0CED4C7CDCFC6C9BDB6BCBBBEBEB8B7AEB1B7AFAB
AEA9A1A2A9A9A4A098A69C9E96989CA493969990929899949B988B93898E8C8893908885
8488807E848683857F89807F7B8081847A797D857C7C7B777B777C7E7A74827B75767670
737172706E7579797074787073756D716F6B6F7470686B716B726D706E686F6C66686861
6871636670656A6B67666963656963646B6C68666B6967696466646266656463685C6661
5F685963635E5BB600000000000000000000000000000000000000000000000000000000
000000000000000000000000
E966647166666F686C6C6A686D6770696F71696D6F706C6D6B6E6D697472707973707378
7673717370777778787A76747177727A6C73717E76757B767678787B7679787B767C787D
757E7980807B798A7E827A857B7E7B838183867E888B8183857F8586858C86867B858989
8587828984888E8589938D8B8B8C8C9897949498979690969998A19C969C9FA09D9DA4A1
A9ADA0A4A4A3ADA3ADADB2ACB9B2ADB3B9B9BCBABEBCBFBFC6C3C2C7D0CEC0CCCDCCD8D6
D5E3E1E5E0E3E1E6E7F0F1F4FFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEF5F8FAF1F0F1EFEBE4DBD9DBD9D8D6D6D1C9CBC1C1C1C1C1B8B9C1B1B2B3B6B8A9AE
A9A9ABAAA8A7A39FA19B989DA097989397969A9693978F93978F969391908D87908F8B8B
88908686888F8882847D7C7984847E8483817D7C7B787B7B797E7C737879787A81767977
7078747171717A766970706E736C6E746B706E6D6B726B696E706E6E6F706B6A6D6B6E65
69646E69696465676C6D66696A706E696966696860645E5F6965625E6C62625E5B606161
695F6364626061B400000000000000000000000000000000000000000000000000000000
000000000000000000000000
EF676C6C7364706E6973696A6D6B6E68716F6A6B6B736A71706B6C6B737674736B717373
70747072716E7A78747671777376787172737D75767177777C8478727A797C79767D7D7D
7C8179797D79837B7B7E7B807C817F7B7E8081868586867E7E768689878686868688898C
868B90888A868C89948E8E88919397928C8E9C909590939D9B9C9A999BA1A298A1A39BA6
A0A7A3A8A9A8A6AAABB0A7B1AEA9AEAEB3BDB3B9B8BDC1C1BBC3C6C0C7C3C9C9D8CECAD3
D9DDDCDDE2E2E3E3E4FDEEF6FCF5FBFCF2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFBF7F0F3EBF1E1E3E1DBDBDBD4D3C3C9CBC6CCC4CDC1B8BEBAB5B4B1B6ACB1B1B1AD
ADB2A3A3A8A8A3A19F9CA3A1A49A9C9A959A949D9F92968E9C8E948F94918E8B91958084
84817E898084817E80838183847D7E84807B798081808180817E79797B777678707E7574
73747E7572747679746F7872726C716E73666E77706A7069696E73706B735E6968657068
5C69656464696669636B65696569666469636C626962666667676565605E63615D636160
635E5F5B5D5F5CB300000000000000000000000000000000000000000000000000000000
000000000000000000000000
E86E6E6D6C6C6E6E6C6C6C756F706E6A696D736D706F6B736675756C6E6D737374707374
706E7274687373717473737077797B756F747A816B7876787674817C78777979767E7475
817677797C847681748181837E7B7B797B837C8381838286887E7C83858489838B888B8B
8B818A8B8E808B868F8E86888A9690969491968E8F969E9299A09698A59B9899A29FA4A0
A5A3AFA19FA6AAA8AFAEB0B1B2ACA8AEBDB3AEB2BEBFBBBFBEBDC2CBB6C1CCD2CFD6D4D8
D7E8E2DCE3E9E2E7E9E7EBF6F1FFF7FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF9FAFBF5F8E9ECEEDEDAE4E4D2D6D5CAD0D3C9CBC8BEBEB5B6B5BAB6B6AFB8B1ADADB0
AFA9A9AC9DA19F9BA0A3A199A1A09F969294979691929095908D869491939291888C8C89
8B868C8B898083847F8382807D7A7E77807D7E7E7D78787B7B7B797479767E7C7B797D76
707B72737771776E6C7371716F6E72746C746F6170706E6967716B696E6A6C69646B6B64
646B6C6F666461636066666A6D7363656E5860626668606164636B64605E616461626261
625E60625B615EAB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
EA666E656C6B6C6D616B666C6E6C6D696C747063746F6C716B696E6F796A716971716E6B
716E73706F746A737074737B76787975747A71757D7B7074787C767478797476757C7978
797B7D787A81877E8084777D7C817B7C85867C7985877C7C838987808986867E878C8989
87868C888B8C898B868E868893938E8C8D96969C9498949499979E9B9D9EA09AA3A3A0A6
A6A5A8A5A6A6B1A6A1A9ABA7A6A4B6B3BEAEB5BABAB8BEB8BEC4BFBCC6CBC3C6D3D1D1D6
D6DBDCDCEBDFE1DBEBECF5F9F9EDFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAF8F0EFF5EFE7EBE6DDDFD4D2CFD8D6D9C3C1C8C4C4C4B3B8B9B9B0BFB4B4AEA6ACA9
ABA6A4A09DA19C9B999998A19998979D938F918E958C978E8E8C98928F8E8A8B8E8E8E91
8991878383888680858881867C807E817D83877C7A7B787C817B777B8178787171777B73
7C72797B76787874726F717970696C76746F6D6D716B646E6C6B7070696A686A6B6B6D69
6A6963666C696C70686B68646B6666696A666663685E61635D646064636368625E665B59
605C5B6361615BB300000000000000000000000000000000000000000000000000000000
000000000000000000000000
E26F636967706E6E6A6B6C696F6E6B72696C71706C696B69706E6B71716B716E6A786E71
717073737470737170777373787A73766F797473737D797378767C7871767F7C79757E7E
7B7B7D7E807A7C7B7E7E837B8080837E80857B7E81838486807E8083838881898F868287
8A88858C888B8B9391888B988C8B919598928E9B99949C969496989C9B9F9AA4A490A0A7
9FA1ABA6A6A19CA2AFA8A8AAB4AAAEB5A6B8B8B0B9B5B8B9C1BDBFC8BECBC6D3D1D1D2D4
D7DCDCDEE9E3E6E8E0E4EBF0F0FFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
F9FFF3F8F1ECE9E8E1E2E6DEDCDBD1D6D4CFC8C7C4C9BFC1BCBCBBB9BEACAFB2AEAEB8A3
ACACA39B9CA69F9E9E9B9F9B9D94949C9696A08B8F969896999A8C8B918B8D8F8C838688
84878187838B847F807D7D7A877E807C7C7E767E7C777D7E797974767E7E767978747478
7576737974707172707074706D78686E747468766C716B697069656B6A696B6A716B6671
68706F6368676564636E646466696C68656661626469636364676064645E616462585D5E
656360635E5F59B600000000000000000000000000000000000000000000000000000000
000000000000000000000000
E970717368646F6C6C6573666E6E6E727371737670736C736E73716E6E70707572737972
6E6E717870756D73787774766E7073737274746E75797A7A71777C757880767978747B76
7B7A797B787B787B7C7C7B81847E7A7E767B8388817B7D8487848684898C848E89838987
8D8F838B8F8E8686888E8D9190928A96988B96969A989C98989F95A29C9297A29CA3A49C
A3A0A6A0A3A4A0AEAAA3AFACA9B4B1B7B1B3B8BBB7B8BEB6BEBCBEC3BEC8CECACCCBD3D4
D3E0DEDAE1E1E2DCECE5E8EDF2FFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
F8EEF4F8F4EBDEDDE3E1E1DED6D3CED2D6C8C9C9C3C6BCC3BEB7B4B6B0B1B1ACADA8A6A4
A3ABA3A69E9C9D9E9A96989F9099919996968E8C91948C8C9491908F988D92838F878D8A
8C8784817C847F80867F807B83808179787B7E7E7C7F797E80797E7F737B797875797673
7371716F746F6D7975746E6B74767B706B737074706E68696E6D696A66696171626E7172
68686F6668666E646D69686B6B6C606B656663686965636D64666766656B635B61665E63
635D5F645A595DB900000000000000000000000000000000000000000000000000000000
000000000000000000000000
E7696A6C6F6B676E6D6B676963696E736F72766F6E69736C7072747567686C7572777670
6B7972717173756B7971747376747675767D7874767C797A73797B78747A7476797B797F
7B7B78757E817C7C80807F7C7F7C817D7F7F7B8D828281818981838484868B88838B848E
8B88838785898C89899886929190978E9A9694948A9692959C99999EA39DA6A3A2939CA1
9EA0A5A9AA9EB1A5A7A6A6ACA3ACB3AEADB0B0B4B6B8B6C4BBBCBEC0C4CEC9C8D0D3D2D6
D6D7DCD8DDE4D8E8E0ECF0E9F7F0DEF9FEF5FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FBFF
F6FCF2F1EFE6E9E2E0DBD8D6DBD1D5C9C8C5C9C7C0C6C2CCBABCBFB4B4B8B3ADB1A9AFB2
ABA4A9A2A3A29C9C9F949A98A19E9C97969891989496988F92928B8C8E8B8F8B8F948689
8489808386837E827E80868083807E7C7A737B807A76767A7B817B7E7F7B717474766E78
7B746D787371717574737472746E726F6C646B70736A6C6C72636C72706A6769666E646D
6D69686B6C696A6A67686868686466616363616665646968696164656063646466636160
6366635E626161B700000000000000000000000000000000000000000000000000000000
000000000000000000000000
E7646E6B666B6D6C686E6E71666C6C71706C6C6A6B6E766E6B6C6B6F6F6B6D6C70747370
71707070736C75776E6C6C77726A73727873707274737C7476737574797A7D7576787C79
80817A7D7E7C7E81747C7D8280797E7B7B818073857E86808481898686898B888B8A8188
8E898C888B899189968E908D9391928F9B9291939393959C96A2A19EA29AA19FA698A1A4
A3A6A4A0A5A3A3A69FA7A1A8AAAEAEACB1B3B8AEB8B4B5B4B8C2B8B7BCCECDC6D2C8CCD1
CCD5D1D8D9DADEE3DEEBEEF0EDF8FDF2FEFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F9
F0EEF4F0E9F3E1E1E0D9DBD1D7DCCEC3C4CFC1C3C5B9C8BBB9AFC0B7B4B1B7B4AFB3AEB0
A9A8ABAC9AA19F9598A0999A9A989D9696988E8B918D928C9491889193838E8C89898283
898A86887E83858782838180817C88807E82827B7F7D82777A7974767A79797773797972
746E786F747672797169706C70686A6E696C7274726E6864687071646C6A686A6C6D6868
736C6A6A6868646A6B6768636661665C665E6464615C656869606362626361615C67605A
59645A5D5C5C61B200000000000000000000000000000000000000000000000000000000
000000000000000000000000
EA695F726C69716E6B69686871747076706C73707066707370696E76726C6C7378736A6D
6F7377737370707176786F747178737672767679797876757B7A72747674737B767A707A
7D7C767E817E7E78767E7E7C807E7D7E8186807F7F8284898187838C888981898C848484
8E89848E8B868E908D8E8B938E8D8D9BA196988E9B9F9A9C9CA19EA0A1A0A39F9EA8A2A1
A3A2A3A398A7A4AEABA9ABACABB0B5ADB4A9B1B4B5BCB1B8C4BDBFC3C2C8C9C8CBD0C9D4
D8E0D3DEDEE1E1E1E0F4F1F0E5F8F2F5FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFCF3
F6F2F2F1E6E1E0E3DEDBD6D1D0CBCFC8CCC9C8C3C9BFBABBB4B1B0BBB5ADB3AEADA9ABA1
ABA1ACA49D9599999CA19F9998969A9790949699939491988C8E8F889191898484888B84
868689818588888384847D817C81787E7C76767D807978797B7B7C777B80747675796E75
7A73767771766F6A71716D71786F716E706E6E6B6B696D49686C6B626D6963696369656B
6668685E65696065666166686966646463686862646868675C60666362655E63665B5F64
6360585E5C5954B000000000000000000000000000000000000000000000000000000000
000000000000000000000000
E66A696D696C6B71666B6A6B726C736C717268716E7471746E6F7169756871726F6E7666
737272677A747A767874777473786E717B7979746D7777797B74747779777B7C74787478
757B7C7B7881767E7E817C827B7C80807C85807A83808387848083928B808C8A8C89868A
868B87848C918E998D93899289949190919E91909993949899949E98A3A19EA3A09BA1A3
AAA3A4A9A0A4A7A9A6B1ABA5A3A8ABA6AEAEAEB6B4B1B4B9BEB8C0C8C4BECBC9CACFD1CE
D3D4D1D8DCDADAE4E6EAE6E6F1ECF3F1F6F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFAF8
FBF2EFEEE8E8E5E4D9D8DCD4D4D6CCC9C7CBCABFC7B9BCC1B9BBB8B2AFB6ABA6B3AAAAA9
A1ABA3A5A29E9C9698929D9D989293949693919A91959396938B868C8D828D8E858E8486
83908B85857C837D83818280857C7F7C767F847B7E79797979777D7A797B7B807875717C
7870746F6C76736C6F7170736E706D756E7077746E6F6D696B6B65666564666761666D6F
68686B686A636865656D6768646664626463616D68646266616562635D6263645F65635C
655B5C5F595E5FB000000000000000000000000000000000000000000000000000000000
000000000000000000000000
E4696E6D6C67686A65696C716E716C6D736E72706B777272707372736C74736B6B6F7479
6E6B70696C756C747B706E76767E7476757C6F7774757474767E7373757A7D7574757980
7777787C7B8181727874887C7F797E7C7E827E7E8480847E8D8B86828B8486848386858C
8A8789888C918B8B8E8D8B949090919894979E949E939B9B989C93A29AA2A19BA99B95A1
9BA1A1A4A9A6A4AAB1A1ACB1B3B0B1B7B4ABB1B0B4B9B4B9C0BBBAC2C8C9C8C4D3D0CED5
D0D0D6D4DCDCDDE0E0E4E8EBE1E6EDF0F8FFFFFCFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCF6FAFA
ECEAECE6E8DCD9DFDBD9D3D7CFD0C9BFCAC4C6BCC0BBC1BEBFB5C2B8B9AEB3ACA6A9AEB4
A1A9A6A49D9894A19C97A0969194949C8E968E8993929594938F918E8C8B828D8E838688
8386888484788081847E807B807E81817F7F817E7F7A7B7B747681787B737C737671767E
786E7171746E7173726B716E737674696E6C70786B6D6B6868686C6B6366696B6B716D69
66646A6C66696664646063615F646368646661686B6165646561675D63635B615D5A5E64
5E5961505B665CB300000000000000000000000000000000000000000000000000000000
000000000000000000000000
ED6C6D6E6C6B6C6F6C6B696E6868687364696C78736C71727773736D6C74766F696C7778
6E706C706C6B6B71707676777974757374717A716E7774787C73767876747673797E7C71
787B7D747B7C786E7E817F7C807D7C7C84848185807F7880838C868B8488868A898B898A
878E8E888C8C8993889490918C8D948B8E8B959899989D9B939A9D9D989A9896A09EA0A4
A0A0A39EA0A0A3A1A8A8ABB3B1ADAEAAB1AFB2B6B1B6B8B5B0C4C0B6C6D1C8C5C5CFCED3
D5D1DDD8DEDADCE2DBE8E3E8EBF1F3F5F7F2FEFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBEDF4
EAF0EBECD8E1D5D8DDD9D6D5CFCFC6C9D0CAC6BFC3B8B9B7B7BCB3BAAEB0ACABB3ABAEA4
A0A9A8A0A6A4999E8F9599999296929B8B9490908D8F918C8D828F888E888F8684878288
84838B817E7E808B8084848885787F80797E7A82757A77797B787B76747A797870786E71
7079717170717372716F6C6C72747779706F6E6D6E6C6B66666B6A61656A646A6C696764
6B656A68686B666468696B666465666462666468606060646569636B5F635C6063686560
5B535B5B5B5E56BB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
EB686F6C6C68706E6A6D736E6C727470726A6C707671727476706A6E6E706F736E746D6E
7177796E727072736C7374777A74766E72736E756C73777C7B77777B76777B767F7A7B79
74787D787B7A807B7D747D808383837D7C7A897E86867E8A7E8B7F8E82897E88818A8488
8B878C8D86898B8F899391938E8B938A8F939897959B93949B9CA0A39FA09EA49E98989C
9DA3A4A9A2A19FA3A7ACA9B0A4A7B6B2AEAFB1B0B0B7BAADB9BEB8BEC3C8C4BDCCC8C8CF
CEC9CFD6D1D8D8DCE3E2DEE9E9F3EBF7F2F7FEFFFBFFFFFFFEFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEF3F8F1F1F5F4
E6E9E0E5E3DCDCDED8D7D2C7D2C4C4D2C4BFB6BBC7C1C0BCB6B3B1B7AAA9B0B3AEA5AAAA
A8A3A4A29EA499969294949993908E908E948E90998B8E8E8F8A8B89918F888587848693
8D8488878284837F858384817E7B7E7B79787D7E7E7A787A7E7870717873767371707470
7B6C6F716F6F7770766874796E6E7177716B737168736D66666A6D6F6F67696B6D696466
6D6C636666695F60616468686464665E646963676168675B64606868576459605F5E5B64
5F5E635B5E585BAE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
EE7067686C696768696F6D686C70706E6E6F74736F6E74706C6A756E726D6D78716E7472
6C7473736C70726E70747176767B7379727271737474777B7078797878798473797F7273
7B7F767E7B827A7980807E8381787B797F7B838084858880848084818887818688868884
8A8D8683908E85949090898C9492948E8D90989194969C939E97A3A1A3A0A49B9CA39FA5
A1A19EA0A09CA1A6A8A1A39FABA5ABABB3B6B7B4B3ABBBB7B8BDBEC1C1C5C2C2C9C8C9CB
C3D4D6D8D6D9D9DAE1E9E4EEE8ECEFE8F0F6FBFFF8FFFEF7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFF4F1F5F5EEED
E6DFE4E1DCE1DADCD0D8D6CEBFCDCBC8C4C9C3C1BDC0B8B6B9BCB3B4B8B3ABAFA8ABB1A4
A4A8A39D969BA1998C96949B9398909896969491908E8C8F8D8789877E8486868780888C
8386868B877F81818180807C817C807D7D767D8078767E70737D757A7674747075726E70
7C7A70707471747379746A7074706E6E726E6E6A6F6A6D68676C636470716F736D64646B
666E666862686367635F646A63625C5F6865646663605E635F61635E64665F6262656063
60646053635E63BC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E15C656A64686E667070707870736C6C76707078737572716F6C6E696E6D686B6E736C6E
7371767771716B737C7377787876787776717479787A7B79766B7A7B7B77797A75717C79
767879797A807B787A80797D7E797C7B7E737C887687868387898D8681807D9388838688
8B908B86938D8987878E8B8F9592949391918F91969E9898949B96999DA09B99A6A1A1A0
9FA098A6A3A4A29BA3AAA8A4B0ACABAFABACABB7B6A4B8B2B4BAB7BCC0BEC1C4C8C6C7C4
C9D3D6D6D0D6E0DBDEE1E0DEDDF2EBF4F1F4F3FFF8FBFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFCF9FBF8E7E5F0E9
EAE5E3E3E0D9D8D6D1DDCAD1CCC9CAC6C3CABDBCB4B7C0C0B7B9B0B0ABAFBCA6ABAAA5A0
9CA29A9EA19F9B9C9B9491909391939A8B8B909092908C918B8B838F8C8C8F8983898A88
86878988817B798482857A84838073757C7C7D7B80767B7B767E746A7579747170767374
6B747070777174736E6D786F726C6F6E7072686B6D6B69686A6674656B6B6C67646D6668
6762656F6764696464666666666468696860635C5C5E6266686160645E6064606661615D
63616064626359B200000000000000000000000000000000000000000000000000000000
000000000000000000000000
E1676E6E666C6F686B6D706C707169716E766D6F716F6C78736E70736E6B736D6C716F67
71736F6E7273757676747779757B756B77786E716C76767673767C7B707C747A877D7B79
78797678757B8A8178767D7D78818676818380867E8386878486878486889088898C848D
88918989918C908E868E948D948F959191999499969091919B939793A0989A99969C9E9C
9FA39CA0A1A9AAA4A49AA1ACABA9A4ADA8AEACBDAEBAB6B4B4B7B6C6CBC3C6BED0C9C6C6
C7CED3D2D3DDD2E0E2D6E3E8E5EAEFEFFEF3EFF8FFFEF3FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFCF0F3F0EEEFEE
E8E3E7E1D1DDDED9D4D0C9C3CCD0C6C8C9C3C1C1BAC0BCBAB9B1B3ADB0B4B3AEA0A8A9AA
A3A4A0A6A2A49899958F9892909091998C8F94918E8E8C8B8E908E8486848886838B8883
8885818186897980817E7D7F7E7E7880787E7F787B797E727D6E767973737D7A77777674
716E747471737573767676717670716E7071726E66716A6660616A6C696B6E6469666464
696B64615E696460686363606468666D5E5E6464696164666C686566586366645E5A6165
605E61585B5A5DB100000000000000000000000000000000000000000000000000000000
000000000000000000000000
E46C6866696E6E706B6E6F6E727369707171747174767170776B6B6E72736B7476767371
6D736C766F707173747A79777472747174787276747A7879797A7B6E7975787E797A787B
787E788478747B757C807C7C7E8379808188817D837F848388808886838788848181838E
8A8C8B8C92968E8D8F8C88868C909695998D9496938F93969394949E95969E9C999BA09D
A3A0A0A6A09EA19AA4A4A8AAA5AEAEB0B5AFB5ACB1B8B9B4B8BBC0BEC8BCB8BBC1C5C1CB
D4D0D0D0D5DCE0D6DCE0E0E4EEE3ECF5EBF0F7F1F8E4F8F8FEFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFBF4F9F5EFF7E7E6E3
DFDCE6D8D9D8D1D9CBD4CCC8C9C8BEBFC4BEC1BEB5B4C2B5B4BBAAB3B4ADAEACA49EAAA8
9EA39FA3A4999D9B9594989B9494999093928C968F8C858991908A8B8C908B8E89858C8E
8484827C857C7E827E7D79848380817D83787A7A7C7B777B7477797472746E72787B6E77
737370776C716A6B6C686D6E726B746B70706B6669696B60666A6C716C6A6D6068686966
68646769646660636A5C686960646363686860685D60615F646661605D61615C67605A5D
6363635E5D5B57B600000000000000000000000000000000000000000000000000000000
000000000000000000000000
EA64677170676B686A666B716B6E70696E6E6C7071736C736B7074706D6A71706C6F726E
6D6C70726E7676737374766F727A717B757973747C79767B767478707779747C787B7D79
7B78767C78797979777E7B797B7F7E7E8190857E848E7D89828380888088858786898B8C
86918C89868B818C89878A8D9088968E898D9A9A949498A09B9E99949CA49A9A9899999D
ABA9A1A39DA8A3ACA3A4A3A6A7A3A8A8B1A8ABABADB4C3B9BCB6B4C4B8C2BEC3C9CBC9D0
C8C4D3D4CED4D8DCD9E1E3E6E8E9DEE4EBF8F9FDF5F1FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBF3FBEEF0EEE9EBE7
E8DCDEE1DADBD8D7CFD0CBC8C4C9C6BEBFC0C1C5B9B2B4B7B6B0B1B4ABACA8ABA9AAA7A7
B0A69C9FA0959A949894929C968C8E99998C91918B8B948890878D8D85868A868B898684
808389868179837E7C80877E797E7678767880747A7B79777B767C7C727A6C746E707773
747373696E706E6D706E6D6B6A707171706C6A6E6C6B63636C66646867636B6968696163
6966655E61666364606B6764615F646B6B6768665A5E66615C65645C62616362645D5E60
585C6161575C61B400000000000000000000000000000000000000000000000000000000
000000000000000000000000
EB69686C69696B6B6B6F6B6F6966696C6B6B78727075687871717174726F6A716C6B766E
7073746E6E75747472767574737471717576797975736F767873797676767E7F78767579
737C747D82807C818080797C84808382817E81858086837E8185878086868B8089888889
86838987929193858E8E8E8D908E9698959493989698989F949A9B949B9F99A09A979BA5
9C9D969E9DA3A7A5A4A4A1ACA2ADA4A8AEA6ACB0B2BEB8B3B4BBB8BCBDBBC4C0BBC3C7C7
C6CCC9CED6D6D4D7DBE1DFDCDCEDE6ECE6F6EFF4F1F2F8FFFCFDFEFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCF1FBF0EBEEE5E6E6
D9E5DCD7D9E3D6D6CFD6CFC8D1C4C8C1B3BCB6BBBAB6B1B4B6B7A8A0ACAAB4B0A5A5A0A1
9F9AA3A29A979B9D9C959B96909397958E9496948C908E898A8F8C8B818581818B898486
848C8783808B85817D88807E7E7C7C807B7679777C727D777C7277737672746B76716F7A
727074696176707973676F766F726B71736D696C6A636169666E6B6969676C6D6C666964
61635D686666695D685F66636467606062616E5E605C645E605960675F61665F5B605C5F
5D5A5A60635E58B200000000000000000000000000000000000000000000000000000000
000000000000000000000000
F06D6A6E696B6F686E69636F69697268716B6870736C76716B6F796B6D6E696B706F746E
6D6F6C73746E7371747468777371717B6D7C7A767B6F787B7E7C7B71777978777674747B
86757B7F787C7F7C807780827A7D7F7D7C7F7E837E838686857C838888818082818E8B88
8C8C89878E908393868990919494908D948B958F90979798999897A1989D9EA19C9E9D9C
A19EA699A09FA2A0A6A0AAA0A6ADA4A9AAB0B2AEACB4B3B3BFB9BBBCB8C0BAC0C4C6C7C9
CBC6CAD3D8DCDBD0D9D9E1D7E3E1E6E7E4ECF4F1EEF6F6FFFFF8FAFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FEF4EBF6F4F5EBF0E2E1EC
D9E4DEDEDED4D6CDD1C6C6BFC3C4C6BEBBBFC1B9B6B8B8B3B5B1B0A4ADAAA4A9A9A9B09F
AAA19E989C9F9E90948B939394918F8C8E8D8C9190858F888986868B8C91898C8A868C83
83818686867D7D8188827D8079787E737872767E7C7579717573707C76767670726E7375
6E717072707171706F707174696E6E6876697169686A646D68696C63666B6765676C6B66
666461675E63605F606C5C6C66676463685E6066635C61676060616061615E6561605B5E
63636161565B5DB300000000000000000000000000000000000000000000000000000000
000000000000000000000000
EF6F67696D6E6E6A636A72666B6F73726E726D676C746E74707171776C6E6F706C70706E
66716E69707374757175747877746C70767377707573717A777C717A7474737A78787776
7B7B82787A787E7E7B7E81857B7D7C837C7D84878081898088818484888884888880878C
818E8B888C918B8D878D8F939089919A9490979895939490999D9F99A19C9F919B979B9D
9E9EA3A39CA0A6A09EA8A0A3A8A8ABAEB0AEB1AEB1A9B5B4B0B9B3B8BBBDC4C4C6C3C8C4
CFD1CECFC9D0CEDBE1D4D8DBE3E1E8E5E8E7E3F1ECF9ECF6F6FEFCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF9FFEBE9EBF1E4E9E7E1
E0D8D7DCD8D6D0D6C6D5C0C8C8D1C3BBC6BCB4B9C3B7BCB6B4B1AAABA4ACA6A0AAA8A5A2
A199999F99A19796998A93938E94978D8C91908B8E888B8A8D8C858E918C818B88888687
818C848283807F7E91807F76747D7B8181817A78736E76747B74736C74767A7576726F69
686E6C697271676F6C7079746B6B746C696B696C6E6968616B636B64666B666867635E5E
665B5C66696068696664616464676B665E666A5F5961665F61645B5E66616160595E5B60
615C5E605E5D59B100000000000000000000000000000000000000000000000000000000
000000000000000000000000
ED6D66696A6A6D6E6C66746E6F6670716B71706D6A74736D7870776D73716F716E72736F
7377686F74747671717A70717570737B7971767A7279717470787275767E7A797479807B
7E7A7E7C7C807F7A7E817F79807B797E7E7B8681838085867E808A8589848B888494898C
8E8E908C8B898288818C968C8D90908D9A9094918E9499989B8C999B929D9F9B9CA09799
9DA0A8A59CA29BA0A19FADA9ADA8A9B0A9AAB1A9B0B1BEB8B9B6BABDC2C6B8C2C7C4C3C4
C9CCBFD3CBD2D8CFD8DBD9D8D1E1E6E3EBEEE6FCF6EDF8FBF1F0FFFFFFFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFBFFF9F6F3F1F1EBEDECE4E1EAE1
D4DCD4D6D3DCCED8D0CCCEC6C0C4BDC4B6B9B4B5B1B4ACB5B1B7A9B1A9A3A3A8ACA7A7A2
9F9C9C969E9B979398969A939391898E938D888D89918B96918E8D84828388838C878883
828678837E88847B7E81807B7B7C807D79767B7C7C757376777979796C72736B78747375
687370706C686C6E686B666E717171716D6B6B6C6069646A65686463706D6662615D6360
666C6060696060605B66606265666B64615B63605A66615E5B6566695A5A636363605963
616053585B6163BE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
EE686F696E6C6B69686C7073726E6E6B6E686E756D6B716B787172676D73706F776D706D
706C73696C786C7576717178747579766C6D737170717176717976787471807871797880
7D7E7A7779807A80887A807E7E73807C85817B8082777B8180887F838283848788878C84
8D89898C89888D8E8B8C8E8B918D968B8E91948E949E9699989698939E919F9E9D90A19E
9E94A39BA1A3A69B9C9FA6A8A5A4ABABA9A8ABABB8B9B3B1B9B8B9B3B8BAC3C3BEC1C6C3
C6C9C9C9CECFD9D3D3D0D2DCE3E1E7E0E4E4EAECF4EAE8F4F8F3FCFFFCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6FFF9F3F9ECEAF3EBECE9E4E1E3DC
DEDBDCD1D6D1D4CCCCC8CFBBC6C1C0B5BDB8B3BCB3B4A9B5ADB5B1A6AFAEAAA4A1A8A4A5
9B9D989F9B989B9194939297908E968F908E908C888C8F8B91898C8A89838881838E8484
8387848886837B807B7E867B7E79807E7F7D7A817C7C787B7076797B7472756E746F7669
766E706C696C6C687878716B6B6B6C6B666A716C6B6B6B696061636C6B66636469605862
6460666566666263616E64666261646166635C6760615D5D6061605E645C696061646563
5F5761645A5B60B800000000000000000000000000000000000000000000000000000000
000000000000000000000000
EB6E656A6B6D70686C69726D6E6C6E6B6C6E6D7170716C746B767D6E7670667870707171
717B6E766E6E707574707177706D78737E737C737E787B6F797B77787C79757879767478
79787A797A787C7B7E807F7C7E7B7F7B827B857C7E798083858781888789868E8B828A85
8890868B929689918E8A8F8E8E8E91949197979C9C989B979491999B98979C9D9C999893
9C96A4A1A29E949FA2A9A6A6A9ABA9A4AEA9A9B0B8A8AFB4B0B1B6B4B4BBC1BFBFC0BEC3
CCCACBCACCD1D1CCCBD4D8DCD8D6DFD9F0E0E9E4EBECF1F8F3F5F3FFFCFEFFFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFBF5EBF9F0F0FBF4EBE8E2E3E6E0DD
D3D8D7CBD2CBCDCBCCCBC5C2C1B9B8C3B9BAB9B5B3B3B0A8B0B0A6ABAEB4AEA5A49EA09C
A6A19F9792999B8E97989193949190898B888C908C91908B888B908B88848B877C798081
88847E7E79807C817E79837A737B7C77767C72727579717E77757072716F6E73766B6C73
71716B6E6E6B6B6B6B6F706B7265706C6C71686E69666B686C68636860636666636C6464
6564606D646768646466665F5E61656665625E635E6161625F645C5E6360625D5D5E5D61
5A5962555F5E63BF00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E3646B6B636B66716E6C706967656B6971696E6F696C766E6E74726F74746A716A6B7170
74726B7A756E776E707471757D7673737B777E7572797B6E767574767A74767E7E797D7B
7674747A7F7A7E7D83797F817D80827C7C7A79868082807B817D7E83837C88868184818B
83878992898B8E83918E8C918F8B928E92979491919592979B9691959A998E96959C9CA1
9C99A1989EA3A4A3A19DA1A8A4B19EAFA8ABAEABB0B0ABB0B4B2BCBFBAB9B7BCC1C6B9C3
C5C4C9C9CBD0CDD6CDCECCD4DBD8DCE0DFE9DBEAF0E4F0EBF1EEEEF8FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFF1F6FBEBEEF0F3F2E1EBDFE1E1D8DD
D8E1D8D1D8D2CCCBC8CAC1C1C7C0B9B7BEB9B5B3B6B5B3B2AEB0AEB2ABB4B4A7A6A2A1A1
A89E98999A959C99919C908C9690919382878C8C8C8B918C8B948484868A8C868389828C
817F7C817E8082807E7982807E827F7A76767576747A71706A7376737572746971717470
756E746970686964626B696E68706E6E6C6B6E6B696D6F6767646866675F5E6161616862
6369616166646464616463696165606963646958686064635C5C6463695A5B5E61615E60
5860615B605959B400000000000000000000000000000000000000000000000000000000
000000000000000000000000
EC6667706C636E6868686C756B69706E6969686E6D706A6D726F72716B74736C736B7674
7174716C756C737570787575716E7478767C7979747175707479797B7B7677787A717478
7F7C7D777B7E7C83797D7978818775807F7A7B837B8481867F8383838889848E8B888A8B
898E8D858087908B8D8F918D8A8E8F8D9193989693909599D1E399979C909B96A18C9C9C
9A999EA0979F9EA4A0A49F9AA0A4A8A7ADA4B0ACABB0ACB3B4BBB5B8BCBCBAB8BFB6C3BF
C0CFCDC8CEC9CCCDCED6D8DACEE6DEDDEDE9ECDFE9F1E6EBF8EAF5F9F5F8FAFBFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF8FFFBF6FBEBF3F3E9E8E6DFE1DAE0D9DCD8
D0CED2CFCFCECAC9B7CEE0C0BCC2BBB6B4B8B3B7A8A8ADB0B3ABA8B2ADB1A9B0A5A0A1A7
A29AA49895979C9499979394908E8A8A898D8B8C89868888888C87888186858985887C7E
817F8083847B7E7C7A7878797F7E80817C797775777474767172716E6F73736C6D707378
786E6B6A6B68696E6D6A6D666A696B71666B666C6B6E6B6E6666646A6663686663616864
67676669686E6B6869685B6864606366616560636769605F665E62625D605E605D5E645F
5C565B6058645CB300000000000000000000000000000000000000000000000000000000
000000000000000000000000
E36B6D6B636B6A6F6B69696A70696C696C696D6E686F707271746C73706F6D6D6E767173
706F7275767573706F716E716F757176766B737371707379787878797A7A78777D797C84
7679777C7782787E7C827978817C8489797E84817B7C8381798484818A86848A8B888F8C
8B888D8C91868888888B8C8C8B8994918B97A09394949089FF9EA08E91A0A29C99999496
A09C9E9BA6959F9099A69FA5A1A3ACA5A0AAAEA4AAB4B3B8B4B6B5B1B6B5BEBEBEC2C1B8
C4C7C3CEC8CCC8C6D1DBCBD1DCD6D6D5E6DBE4E1E1E6F0F0E8E7EDF7F2FFFFFEFEF9FEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFCF8FFFAF1F1F1ECEFE4EAE3E5E4DDDDD2D8DC
D9D3D1D1CAC9C8C7CBC3CFC0B9BAB4B6B4B2B9B3AFB0A9A8B0A8A9ABAAA6A8AAA9A3A09B
A099A1A297949C988B988D8B8B938C9285918E87938A8B8D8C8184868684848487818589
7E7A7E867E85827E818181857C7C7D7E7C8172797B74737677737178786E69736C6F7475
74756B6D6C716C666A6C6C70696F7469656A66666B63766C666A6B67696C6A6E68676964
6661686364656B5E6C62685E5E60676869646067626360626464625B5F5E5B615E63655E
615D5F625A6158B900000000000000000000000000000000000000000000000000000000
000000000000000000000000
E86B5F69646C69716B696F6A6E70686E706E6C726968736C6B6F6B727666797079716E70
7B76747470757173747372737A717470757C707F797C768071737475787178807A7A8676
7976787777807B79767A717F807C7C7D7D798380827D828485847D807D90848282858886
8C8C87888486888B948C91938E92898D908B868F8E9090949B9992949496A39D9C989896
9C9BA89B9CA3A7A3A19FA1ADA8ABA1A9A4B0A4ABB3AFB9AEA7AFB6BBC0BDBEBBB9BBC4C4
BCBBCCCEC2CBC9D3C8CBCED3D6D6DFE0DCE8E5E3E8E9E9F0F1F4EAF8F8F1F6FFFFFAFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEF7FDF9F3F5EBF8E3E3EDE4E1E3E3D9D4DBDCCECE
D3CDCDD7C7C5C6CEC4BDBEB8BBBBB6B8B1B3B5B8B6AEAEB4ABADB0A1A6AEA3A1A49DA69E
9E9D9E989991999F939193898E8E838A8B87898989898C86828984878680838A8086807E
8A867E8480887A818085807F7C817878827F78787578797B75706D70706B79716B736B71
7975796E74676C665E6B716B676C6E68716C666B6E6E64636D6F6964705D697368636769
6A6364646A6A64646566666760696362616665675D5F5B60685D6063605F5C61605C6463
685C615E5C5A58AE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E86A6B6771686A6E6B677071706E6E716C6B6B716972646E6C7071737070776E71737076
6C79747172787476747B72737179747A747979707574767373757378756F797B78748076
787B7985787B797C807B7B7E7B797F7C83807F807B7B7B7C807E86828381828880898988
838A908C888B898E938D898B8C899691889B8C8F98978B949196939796989095939D919A
9A989E959F9B9893A0A5A0A4A6A19EA8A6AEACACB2B3B2B3AFB6B9B4B0B8B7B2B9BBC0C0
B8BABEBCC1CED7C4CED0D0D3DBDED9D9D9E4E1DFE4E5E9E5E8E9ECE9E9EBF1F4F3FEFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF5F7FDF9EFECF0E8EDFBE4E4E4D8D8E4E0DBDADCD8D9
D3D6C8C9D1C5C4C3C3C4C3C4C0B5B8B6B3B4B7B2B0AFB1AFA8B0A8A4A4A9A5A79DA69B9F
A19196948B8E9394968F9195929388908D89858C89868C80898B87888C868987887F8388
82827E8384807E817C7D787A7880807876827971717C7576737176736B72746D6F747071
736A68666B6F6B7068696B736C6E6C736E70696C6F736B687068666969685E6861696E5C
6F666562646B65676767656463635E5C6662686265646065635F605D5F5E61645E66615C
5B645A5D5E5A5EB400000000000000000000000000000000000000000000000000000000
000000000000000000000000
F26A6B6B6D64656862676C676769716E6D6F6D7073666B6E686B706E74707377706C736A
6F716E787173747079757173737276767C72797C7A727D74747A767C7A7473777D7C797C
7477737A797878787E807F827D7D7C7B7F7D837D7C8089867E87808B867C80898389868C
8C868986858A81908B8C918C8A8D948F9689909B8D93918C988E90939C97929C9B9B9299
9998999A9CA0A4A2A4A1A4A3A3A8B1A9A9A4A7ACABACACB0B3AFBCB3BCBBB4BBB9C1B8BD
BCC4C8C1C4CBCBC8CCCFCBCDD0D9D9DFDCE0E4DCE4DEE8E6E9F3E6E8F0F3F9F0F0F5FFFF
F9F7FFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFEFFFFFFF6F4FCFBEFEBF1F2F5EDE5EDF0DED4DBE0DCDDD4D1CECFD0
C6D1C6C5CCC8BEC0C3BDC5BBB7B0BAB3B9BCB4B5A9B6B1AEA9A8A6A4A3A19C9E9FA09B9B
9A93939697949896929690908788899091918A90868D8987848D7C838481828379858682
7C807C7F837A817F78847C837976767C797A7376757479777D72767C746E6E74736A7371
70707176746768696F6B6C6E686B66686668706A6A6E6A68656B636E6B6B606465686B60
636561676567646260635D6964676A63665F605D615C616165616159585B666054646064
5E58615C5B5C63B700000000000000000000000000000000000000000000000000000000
000000000000000000000000
E86B6F64736E6E6F696C696E6C696E70736C71636C6B6972716C70716D6C666B6E6B736E
7271747371736F717973707778726C7A767A7A74767379796F6E747575767E767B78707B
7C817675777678747B797B7979797C7D7E7C7B84848880868584877E7C88818482838D88
8F88888B8A898C848F8E9089898E878F918E8F8D949091949391949E969B9B9E9B959EA0
A3A09EA69A9FA19C9EA1AC9CA4A19FA4A9A6ABA4B1A9AFAFADB4B4B3B4AFABBAB6BABEC1
C6B6B8C0C4C5BFD1CDC8D0CEC9DEDBDADCDBDEE0DEE5E2DDE4E9F2F0EBF5F5EEF1FAEDF6
FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFEFFFFFEF4FFF9FBFCE9EDEBEEECE4EBE6E3E3DBD8E5DCD9CBD1D3D4
CCC8CCC8C6C4CCBCBEC0C0BABBC2B6B4B7B7BCB3B9B0B0AEACA3A3A89FA0A19AA3A39F9D
9C9C9D9C959494998F9496918C988C8690848B908C848387858B868483838C8781838184
808180837E79807F80787D73787A7980747C7472757E7D767A707B756C7074717171706E
7166716F796C706D6B6B69666E6B6D656B6E67706E64656C7068606364616E6366696166
66686061676664616A606464605F646363605E666568655D645C5B605D6960615B5E5C69
5C685C555E535FA900000000000000000000000000000000000000000000000000000000
000000000000000000000000
E3666E6B69666D706C706369686B736A66707667716F6570716E7071746F6D6D6E726E70
6977766F7573737B737878756D73777574717373766E70787976817E78737C7676737C74
77787E807C767E78787B7E7A7E857A7A7C807B81858086897E8484818989878288848A84
898886938F89888C848D8F8988938C8E968D8E8C9990998E9492939494969B999596979E
9DA3A496A0A3989C9FA1A0A99CA6B1AAA5B0AFB2B1B1A8AEAEB3B1BEB1B6B3B1B9BCBBC1
BABCBBBEC2CAC8D0CCCECDCBD1D5D8D1D6D3D8E1DDE0DCEDEDECF0EEEDE6FAFFF3FAF1F6
FCFEFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF8FFF4F4F0F1F1F1E9EFEBE6E6E4DEE3D6D8DCD3D1D8D3D5D3D0
CCC7CFCBC9C1C5C6C0BDBABEB9B9BCB0AAAFB0ABB2B5B1A4ADACA9A69CA19AAB9B9E9D9C
949E96999891939493898D94898B8F9085898D83898C818C848788888181828682888B7F
8082817B857E857E7C7C7B80797976767A757879757B737B7676716D686C6E70706A6973
787070687070716E73696671666A716C626E6A66706766695E6E63696A61686669695F60
646969655C64646464656761685F68645F636160646460686463615C645E615C5A606061
5E5D5C605D5C60B300000000000000000000000000000000000000000000000000000000
000000000000000000000000
E86D6B66696C6E6B6C6B6B6B68676B73686E66716E6B6B696E6B6E707175736D736B6E78
7173727076767073697879727873747675806E76737371767E77717674797A71817D797D
747B7C7778767B787D71757B7C7A7F767E7885837B7C7D81877C828381867E8E83858487
8088898787889384888E898E968E8D858D8C948B8E8C8F94978F939A9A99918B9399A199
9B96A0A0949BA0A19FA6969EA0A6A1ABA19EAE9EA7A6B4B4BBB2B1B1B6AEB0B6BBC1C2B7
C0C0C7BEC4CAC8CBC3C8D3CECED2D2D8D4DCD6D3DBE0D1E7E7E9E9EBEFF1ECE0F4F3F4F1
F0FBFCFBFBFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8FCFCFDFCF8ECEFF1EBE9E8E8E6E1DEE6E4D9DDE3E0D6CBD3CECDD3C8
C5BDC8CBCCBDBCC0C4BEBEB4B1B9B8B8B0B2B3AAB1AEABA6A89DA4A39C9AA19A9C9E9C9D
A19998919691908B89919489948A8E978A8E8C8F8D7980848389848089898880807F8182
7680817A787C7D817E7C737976817C7A7C747978757C7571736A74746F6E6E6B68697874
6B6D6C736C6B69666B6A69676767616E68686C656D686C66686963676768666266666967
70686662696065616868645E625F605F6959615D6460635F645F61615E675B615E605C5E
5B5F5C605E5C59B000000000000000000000000000000000000000000000000000000000
000000000000000000000000
EE6C6463666B696F716763686B66716C7A6A706E6870737066736B6B6C686E7072736B71
666B72706C77727073786C7373716B71717C767374767A7872797471797978757B76777D
7E787A7C7B7B77787D767374837B78787C7B8480857E827E8481807E80828B8485878987
8986888C89828B908D88848A89908C918486908F91859697959B919B93979C9C949E959A
9A949D939F9B9BA2989E9E9B9EA6A6AFA8AAA5A9AAB4A9AFB0B0B3B1B0ADB5B6B9B4BCBF
C1C1BCC6BEC3BFC9C6CBCBCCCBCED2DECCD8D4DCD8E1E1DCE5DFE4DDEEE8EEE7EFF0EDF2
F3E2F3F9FCFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFAFAEEF6FFF8F0F3F0E6EDEAEBDAE1DCDDDDD6DCCCD3D4D1C8CCC9CED4
C7C7BEC1BCBBB9B9BBBAB5B4B8AFB6B9B5B4AFA8AAABB1AFA3A8A3A49CA7A39B999C9F97
99999996948C8F968E8D968F8A8B8E868A8F83888884898A888487888783837F8681797F
7A7B7D7E837D7C7B7F778079807378737879787273767672797A726B6C6E6E6C6E69716C
6F74646D666B686E6E6668656469666B6E6B636E676A6C6768686566646469686C706066
685B636165606561626160646365666868635C645F605F5A625D615B636360566463615C
605B5B5F565B5EA700000000000000000000000000000000000000000000000000000000
000000000000000000000000
EB6B696B7167706E686C6B6972716D6A66716B6E7473686C746B6E6F716F736F7874786E
656C73736D6E737172767471787270746E76756E737573737477747A6F7674787A737872
76757D7E7F737B7C777D7E797B8682797681807C7F867E798676867D848281847F838C8C
898984928985878D8B8E84888C898B9690908D8F8E93968C998B9496939CA0979199999A
9D9E9AA39899999F9D9BA6A49CA1A4A9A9A8A6A6B0ACACACB0AEA9B0AEB0AFB8BEBCBBBB
BBBCC1BFBDC2C8BEB6BBC8D0D0D0D3CCCDD9D4D9DFE4E0E0DCDFE6E8E8EEE6EEE8EEF8F6
E9F7F8F3FCF7FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFBFBF1FAF1ECEAE9E9F0DEE6E9E4E1E6DED5DCD4D0CCDCD8D0D3C1BECEC2
C9C8C5C4BCB8C2C1BEC1B4B4B4B3B7ADB4AEABA4A5A7AAA3A4A3A1A59B9E9F9C9C99A199
949C9999908E918E8794918B868A888988868388868C83858083838B888C82827C807E7C
747C868384807C7977767B7D837F7A74797B74757C7A6F73736E6B6A6C63766C6A6E7171
6C706D736E6A6C686B6461646662686473696C6C6F6D6764656169646C686863626B6B60
6766626B646166666161686B666264636264626065605C606565626460636558615F5D5F
645B5E5E685555B600000000000000000000000000000000000000000000000000000000
000000000000000000000000
EF696B68696C6D6E6B6669696764686C706F6E6F6E6D6B6D6C6E6A6D707173727473736C
5F6B72736C7371757375707372767471717674777B73736F777475797778757677767977
74787877747776767B7B777483777C7F7B7C7A83817B818181858486828985838D7F8680
888D8887888B9185888C89898D8F888590888B908D8B8C8E9490919894969A96979B9699
969F989E9E9DA096A39A9E9BA498A3A3A0ACA4AFB1ABB0B0B3ABAFB4B8B6B7B0B3BAB7C0
CAC2C3C1C0C3C1C8ABB5D1C9C9D0CED0DCD7D9DEDADBDEE1E4DCE3E1ECE4E8E3E5EEEFF4
FAF4F1F7F8F3FFF7FBFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFEF9FFF5F1FFF0F0E9E8E8EAECEBDEE9D9DDDAE4DCD9D6D9DBD4CDD6CBC9CAD5CBCE
CCD3CEBEC2BCC4B9B9B6C1B3B4B9B0B7AEADABA3ABA5A1A7A8A3A697989D9D9D989E9F98
A29198989692909495899090988C918C868B8A8D9086848984828481827D8A817B848680
827C7C7B80787F7E81777974767E7C7C73757B7B716F76747B6D696E6869616A70706970
6C746B686D716469686466676F6D6B6C70666E6866686E636B6869636D626661666B5C6A
636465646569656865616166626362596962615E5E5C6962625F5A61645C635F635B5C5E
605C635E605E56B600000000000000000000000000000000000000000000000000000000
000000000000000000000000
E16368696B6B6969686C6B6C69686E6C6B6F6E6C636B6E756C68737471716E7570796E6C
6A666F6C71736A6E746F6C6B7673747474726E7170787C7B797276777B7C7678747C7C76
7878797D81747E7977737A788580787C7E7D77837D82827B807B827E8283817E7D838983
8A8B84848C88808B848B8C8E8C9D92919890908A8D8E918A989490929694979D999CA197
909D9E979D9BA1A995A5A49CA5A1A3A3A0A3A4A4B1ABB6B0ACAEB3ACB4B7AFB3BDADBAB8
B9B9BCBABAC1CBC8C1C4C9D0CEC6C6D3CED8D8D3D4D7DDDDDBDDE0DBDCE2E5E3EDE9EBE5
EEF3F3EEF6F7F4F6FBF9FFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFF
FFFFFEFFEEF4F8F9F5ECF1F1ECE5E1ECE7E0E0E0DBD8D6D0D7D4D6CCD6C4C3CCC8CEC9C4
C7CAC0C5B8BEB9C1B3C4B4B4B4AEB5AFB0A6A8ABA3A4A69FA495A3A4A49F99A19E979499
9D96919C999993968D8F87898E858D8E888B8C858487869384837784857C81878080787E
798679817C797D7C7C7876777E7A7C777776767675797978787073696C6E686C686C716C
6D68656C6B6C686763616B68686369696A6B706268636E656D6670656161686164646468
636A605E666B64696361666B61645C5F66626161635F615D64625E605B5B645C5F605C5D
5D5C5B60535958AE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
EB66716561676C6B70696B6B726E736874706D6C736D6B706D6D6D706B6971797671706E
70716E696C706F71736E7B7376766E707973797071797B7772787176777C787476747B7E
767375767B8179777C7B79787C807D81787D7E7C7E7F847B787F81867D827F8386838084
8C847D8C83818C878185808A919291948F938A91968B8C898C938B96909692989096989D
9A8E99979897A3A09E9CA3A3A1A8A8A49EAAA1AAACA4A3A6A7AFB2B1B2B4AEAEACB4B3B0
C3BBB7B9BEC1C3C0C8C4CBC6CCCFD2CCCAD0E1D4D4E0DCD0E2E2DBE2E4D6EBE7E0F0ECEB
ECEDEFECF2F8F8FDF9FFFBFAFFFFF8FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFF
FFFFFBF8FEF6F4EEEBECE9EAF4E4E1E1D8D9DDDEE0D8D6DFCED6D4CCC8D2C8CCCEC9C1C1
BFCEBEC0BEC0B6C6B9B0AEB1ADADB1B1AEA4A4A8A8A89EA6A0A3A09E9E9E9C9B9B9A9C92
979198938E8B918C908C948C968E85868C858885848183828684838B8984848682817F80
81827C7878827A7D817B79807C75817B7A797973786C747C72727272696C6A66666B6E70
6E656A6B6A6C6C696969676B68656968656970737169686C68646B6668696A696A606566
6467665E6863696B6769616265616A646662665C665A5D665F64615E5D605D5B5E645E5C
5A6661605B5B5EB100000000000000000000000000000000000000000000000000000000
000000000000000000000000
E468666E70686B6F666469696C696B6B6B6B726E67706A6D6D6E6B757371786B7372756E
696E717769727074717073747B7371727479717671727376786F797878757A7676777478
797D77707877798377787C7E77747C8178798276817F82768081867D8483888A81848488
87848A7E8185818B8A8E8A909491938C948E8C989090908C938E8C9B9197939B949C9193
9896969D989CA0A8A09B9C9CA0A9A1A6A3A3A4A4A3A8B1ACA7AEB3AEABB8B3BBB1B4AFB3
B7B8B7B2C0BFB7BEC1BDCAC6C4C6C8C9D0D1CFDADCE0D8D9E4DBE0DDDEE7E4E2F0DDE0EF
DCE8E5F1F9F0E9F5F8F4FBF8FEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFEFFF8FF
F6F6F1F9F6FAECF0E9ECF0ECE0DBE1DCDBD0D9CFD3CFDECDD6D0CAD4CCD0CBCAC8D1C9BF
C0C3C3BDC2BDB8B2B3BABBB2AEB7B3AEAEB2A3A3A7A4A2A4A1AA9DA2A19DA5A4999A9B98
969391969895908B8E948E8C948C848589868B84898B8E8B88858C847F7E827D797C8089
80817D7F7E8075837C7B787C7C8273807973747770746278737870726A6D686B6A657170
69686B67616D696465626C6E666E6B666A6C6E69696C666B68676C6B6568666A61656863
6266646863616560636A626365646660666462625E60645E5E6161666259645F62615A5C
665B5A5B5A5B5BB400000000000000000000000000000000000000000000000000000000
000000000000000000000000
E166666B6C6C6D6D686D6B6B6A6E706C6B6C6F716B6F6E706E6F6F746E756D696E737369
736E7476736E7370707374766E6F7273716C79736D6D7A7D757378816C7175747971767A
7B747873797776767F79797C77827F827F8778837C7C8184717B817C7F7C7B867E838088
82818482898990888B918E8C90919291908F8B8C878B8E8E8F938E9791939B9499989D97
97999B9D8F9A97999B9EA6A7A8ABA0A1A8A5A6AAAAA9A8AEABA6ADB2B3AEBAB3ADB0B6B1
B4BCB8BAB4BEC0C4BCC6C4C3CBCBC9D1CBC9CCD6DCD5D9DBDEDAD8D9D8E8E4EAE9E1E5EA
E2E9EBF3E6F1EEF6FAF6F8FEF8F1FFFDF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFBFFFFFFFFF5FEFFF8FAF1FFFFFDFDF4
F3F7F6F2F0ECF2ECEEE4EAE4DEE4DCDFE2DBD1D6DCD4D3C3D6D1CDC7D0D6C8CBC3C0C5C8
C1B7BEBCB6C1B9B5B8C1ADB1B1B1B1ABA9A4ABA9ABA9A5A49D9DA4A3999F9E9B96999595
9793909B9890949390908B848C88908984888B878989818989858984878286857E7E7E7C
797D7D7979837B7E7680787C7C7D7676767B7978756B696C7271746E73726E666A68696C
666A6669696E6B6664616865606769696D6A686C706C6964656567606969636466666166
68665E645E636866636967625E6466635D646162636464615E5E645F585C615C5E55685B
5D5C5B5E605E54AC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E5666468686D6D716369696F707163726668666B6C6B6A69706969736D6B6C73776E7271
6F6F6D7069716B6C756C717271706E78796F736C78747B73807D6D737B6D767978797477
7B7E767776787C7B747C7379827C827D787B797E76807C7C7B81767C8880838183838384
8581848787858286888C8B8993938C928C898F918C8993918C8593958F8E8B9693979E98
91969396929B9999A69EA39FA3A4A0A6A8ADA7A4A3A6A1A3A9A8A4ACB4ABABB3B1B8B0B4
B7B2B7B6C0C5B6C4CCBDC9C8C6C1CCCCCECCC4C8C6CCCCD4D7CCD9E0DBE3DCE1E1E4E2E9
E7F0E6EAE4EEE3F1EEF1EEF4F4F4FDFFFFFCFEFCFFFFF9FEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFF9FFFFFEF3ECF4F0F6
EBF7EBEEEEEEEBE6E5EBE8DFE0DCE1D6D6D8D9D3D6D1CEDBD1D1CFC8BEC9CBC9C4C5C8C9
CABEBAB8C0BAB8B7B2B6B6B2B4B6AFACA7ACA8A8ABA3A9A1ABA39F9CA3A09C97949D9596
949C8E91949795978E91918F918C848C89869487838C81887F7B7C8383837B7884808679
7B828086787E78797A7D7980787B797D787E7573707774757678726E726969696E676E69
66676C6C686A6E69656B646969706667736B6064686D6863686B68646C6E6A68605B6368
6264636B61645E59635A5D6461646060635E5E5966666263645E61635D595F5E605C5E5E
615A645B60595DB300000000000000000000000000000000000000000000000000000000
000000000000000000000000
F466686E686B69696E6E6B6C6A6871696966696D6E74706E716C6D6F736B6D7471746F73
70656A6871736C6E6773717074747B74766B767473737074767A787C7871707274747478
76777179787C7B798174817F7E80807F7E7D76817F8081807F80797B837B80838187486F
8784888E888D8A89818A8890888B8B918F8D8E908C8892919C958D988D938B938E979096
98959B9C9E999E9EA5A29CA2A3ABA3A6A3A4AAA2A3A9A8A7AAA8ACACB4ADAEA9AEB3BCBB
B7B7BCB9BFBDBCC0C3C3BCC0C3C8C3C7CBC8C4CCCCD3CECED4CBDCDCD6E0DFD1E4E3E8DB
E8E3E6E8E5ECE9F4F0E9F0ECF4F4EEF8F9F4FCFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFF
FFFFFFFFFFFFF9FFFEFFFFFCFFFFFFFFFFFFFFFFFFF8F7FFFAF9FCF4F9FFF0ECF2F9EEF6
EEEBE7E9F5E4E5E6E1E1E2E0DCD7D8D3CED3D0D1C4D4CBCDC5C9D3C3CBC9C4BCC6BFC0C3
BFBFB4BBB9B9B7BEB3B0B3B4A6AAADAEA0A6A1ACA4A6A3A8A1A3A4999BA299A0969C918E
9C8B988D8C90978B8B8C8C87888A8B87828C868587848289838485817A7E8280837B8082
8381817B7C797A78787778797B777B747B7C79787B787870736B7B746E7470716A6F6770
726C6A6A6C6B616766646C6763636B6E6C6966656D656B63646761636665606966636868
666B686260666664645E616665625E6366626268655E5C665A615E5C61615D59605B635E
605B5C5B5D4B50B200000000000000000000000000000000000000000000000000000000
000000000000000000000000
EB6D67686B696670716B6C74706C63696F736B6B6E657A6C737070746E706F69736E6C74
70746C74706E737369736C72717478776D70706C7376706D787371737276787776797B79
7C76797973747C7F767F7B847B7881817B817C7C7C7B827F7E7B82817D797A7C8B7C667B
84868183878B868B87908786878E918B91858F8C93888B948C8E8F889498A09493919691
969A9C96959FA39BA2A4A49FA2A4A3A8A5A1A6ABA6AAA4B7AAA9ABACA9B1AEAEB0ADB0B8
A8B8BBB4B7C4BCBEC6BBC3C5C2C3C4CCC1CBCBC0C9C4C8CDCCD8D4D2D9D4D9E8E2DAE8E2
E6E4EDEAE3E6E5E9E8F0E8EBEEF3EEF6FBFDFBFAFEFEFFFFFEFFFDFFFFFFFFFFF9FFFFFF
FFFFFFFFFFF9FFFFFCFFFFFFFEF8FBFFF5FFFBFFFFFFF4EEF9FFF6F8FEF8FCFCEEEEEBF4
E4F0E9E8E0EAE8E1E6E6E4E1E0E4DADEDDCFCFCAD0D3C8D1CBCCC4C6C1C6C0C9C7BEC0C0
BBBBC0B5BEB6BCB0B5B3AFAAB7ACABA4A8ACA9A6A99EA8A4A5A89B9B99A3999C95989D9A
92988B8B948F8C90968B888D8C868888908E89848386858B87818884847F8289817F7C7E
7E857473797E7974827B727F7B7E7677767477786C746E6E76746E6C7075736D696E6B68
696768696B6B67696A6A686A69686C6C6B61706C6B656966686A63676361616669666C61
64666261616361676964656664625D61605C61675C60625961606262645B5F5C5E61625E
605B5D59554E57AE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E75F666B65666E686F6B6A6B676C7068696A70706E706A66717B736E706E717276766F69
6E6D6D6E69707B72716E716C6E71716B79757674727670787A7077797471736F78767773
777E736D7981797C797F797384797C79787E84867D7C76837E7B7B7D817C837B86828380
8485847F8283847D87828E87838C888B898D898C888B919494918C9893998A9C949395A1
9B96A298959C9B9BA398A49DA2A5A3A39AAAB0A0A5A3A3A5ABB9A9AEABAFAEA6ADA2B5B7
B3B6B4B8B7BFB9C1BDBDB8BAC3B8BDBEC5C4C1C7C6C9C8C4D6D0CBD0D0DEDBDBDCDCEBDE
EDECE4E0E8EDE4E0E9E8E0E9EEE9E7EFF2F3EBF5F9F9FFFFFFFEFFFFFFFBFFFBFFFCF8FF
FAFEF6FEF7FFFFFFFFFFFFFAF8FDFFFFFFFFF8F8FFFFF8F8F9ECF1F7F1F3F2F1F1F0F3F0
EFEDEEDEEEDFDCE6E1DED8D9D6DCD4D0D4CFD1D0CCC3C8C8C7C3C8CDCAB7C1C1C0C0B8BB
BBBEBCC4B9B6B7ABB8B1B6B3ABB0B3A5A4A8A8A9A8A4A69FA1969699999B9E9E9A9E8F96
95948C92908E8E8B8A88918B8E868B8B8883888189877F7880827C788286827E82807D86
7C80867C797D7F81797C7A787E78777B76757073706F747272707373757079676E6C6C6C
6A6A6E696A706464696B6A65636D6569697067636D686B61696B6B676A666461625B6A61
6C6E6361645E69666161645D5F646660606366615F646160605C68615A5E64635F645B64
5E6657595D5857A900000000000000000000000000000000000000000000000000000000
000000000000000000000000
EC68676B6C70656A6B706969747070686C6C6C6C697370707272716B6E6F6F706F676C70
6C766D667476797074707B716F75736F747375757871717378707676707A6F747378777C
786E73777F788178767B7A78777C78787877797B7B78797C7E7E7C7680877887817F7A84
7F8883828286868486878C89928E848A898B848B948F8A91928F90938C94929998979B8D
999791959B9C979C9EA296A89EA4A1A09E9F9BA3A4A7ADA5AEACA7B1AEACB0B3ADB0B6B9
BCBDB6B2BAB8BEBFB3C0B9B9C0BABFC1C0C0C5C1C8C8C5C9CBD2D3CECCD8D9D4DEDBDBEA
EAEBE5E5DED9E3E6E3DEE6E9EBE9F9F3EEF1F2EEF4F0F3F8FFF8FFFBF9F8FBF4EEF6F6FD
F9FFFFF4FEEFFFFCFCF9F2E6ECFFFFFFF5FBFBF3E8F5FAEEF4EBE6EBF1EBE4EBE9EBE9E6
E0E2E9E8E2E8E0DDDCE0D1D4D7DFD3D1D4C5C9CCCBC9C9C4C6C4C7BBBEC1BCBDBCBEBEC0
B8B8C0BCBBB2ADB2B0ADB0ABB6A8A2A8A8A3A8A4A3A6A3A39C9BA09BA0929495969D8E93
9090908B94908E8A8C898C8B8E81818989858582888180848D898180828181818080837B
7A767E7E767E797E7F797C787B767978786E76757471737671716D736E72776D70706E69
71716A6869636F746F6E676C646966686265686764666A686B6168666160696668686A62
6C60636363665F646360625C66615D6160606065605E61605A6161665E635E5F6664605E
5F5C605F5C615BA600000000000000000000000000000000000000000000000000000000
000000000000000000000000
E26B6C6E666C69696C646A6B646E6D6E6F706E6C736C6B7069706E79707169716C717272
69726E6A75716C706E74706C6B6D70736D706C7373727374707A75797A7B7B766E707370
7573757A78747681767C867E7E77767878787F8278747D7E807B8083848186838380877E
817E8384878488838386818486838C8B828B8B8B958B86898E8E8D9294A08D969193919C
9A979B949C96A19EA0A19B9D9D9BA29B9A9EA1A2A0ABB0A2ABA8ACA4ADA9AAADADB1AEAF
B0BDA9B4B5BBB6BEC2BBBAB9C2B9C4C0C8C9C3C0B5B6BFC4C0C4BFCFD5D3D6D7E0E1E6E0
E0E4E3DDDCDBE5E1E1EBE6E6E6F0EBEBE8F3F2F0EEEEF2FBF6FDF6F3FEF9FCF6F1FEF9F8
F0F1FBF4F1F6FCF6F8F9FFFFF9F1F8F6F8F5F1F3F4F5F2EEEDF0E7E6F0E6ECEBECEDE8E3
E6E9E2EBDAD9E8E0DDD6D3D6D8D1D5D8D4CFCDCCD1C4BECEC1C4C8C3B7BEC6C6B6C1B8BD
B6B6B1BBB6B4AAACB5AFABB8ABA9A7AAA7A8A9ADA8A3ABA6A4A1A39D9D969C999492968C
8E8A8F908E8893938C8C89898C8B89878288837E838487817C7E838484837F8083877F80
7B817A76797B72787B727473767D787076717474717773747078727871716B7074737870
6E71696A6E61686F61686B676B6B6468646B606867646669686863656965606B68646261
656468606668685760666762606058615967635E666163605E5E615C615E655A58605C59
635E5D5C5C5E59B100000000000000000000000000000000000000000000000000000000
000000000000000000000000
EA686F666B6E656D6B6E6D6F6E6C766C746A6C6B736D73696B6D726C69717275756E7073
6A6E7173726D74766E746D6B6B776E746C727078736C6D7174806C737978767C78707B76
7079797A797B7D7B7C7B7974717C797B7A74787E7C7A797C807C7B7D7E827D808881797C
7E83808685847F8A7B868D848B898B8C888B86898F848C8688939091949091909393949B
98989C98A0999E9B9F9AA4A39C9CA3A09EA8A19EA4A3AAA6A6AEAEB1A9A9A9A6ACA8BCB7
AEB4B5B4B3B3BEBBB4B8C3C4BEB9B0BEC0C4B7C0C4BFBEC3C1C0CBCBC7CDD4D8D7D4DFE3
E7DCE0E4D9E0E5D9E8E1D9E3EBECE8EBE6E9E8EDEEEFE4FAF1FBEEEFFBF3F2F3FCF8F4FD
FEEDF1F8F5F1EDFBFCF3F0F6F1F8FBEEECF7F4F0E9F0EBECF1EFE2EDE6F0E6E9E8DDE7DE
DEE6EBD9E4DBE1D9CDD9CED5CBD4CFD2CCC4C8D2CEC9C0C7D0C1C3B8C4BBC3C0BBBDB3BA
BEBEB7B4B5B3AEB2AEAAAFACB3A9A2A4A299A6A6A8A3A499A19E9C9C9B9C94A0959B928A
93998F948E87908886898D838F868B8185888B7B81818883888B797C8085818281788081
7E80807D7B7C737879766D73767A7471716E747A7077737B67697872737873717076696C
726F7068616B68626C6F69697074696A6D646A646E666C6C6664666B646363646B676861
6166686761696764636661635E6066605C5E605E615F615C625E615E5A6360585B635F5C
5A5E60585E5A56AB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E8697269686B706C676F6574687166746D6C706E6F736E6B747470696D74717068737671
6E6B797273696D707874746F79736E696F73707173717270756975737476727576727071
787579757279787C737F777878757B787C7E7B7A767C798378767C8176807E81807B7C83
797F7C80827A8383828B81867F8189848B8580888D9090948C86958D9098929A96939099
989A96989698979A959BA3A09B9BA0A2A1A3A6A9A6A0A9A6A4A3A8A8ADA5B0AEB4ACB8AE
B5B0B8B6ABBFB0B9B7B8BCB4BCBFB9B6BAC3BAC3C1CBC5C1C7CCCAC8C8C6D0DBD9CEDBE6
D8D8D8DCD9DBDFE1E4DEE4DEE4E8E8DFE4DBE6EEE8EBF1E9EEF1F0ECEAEEF2F9F0EBEBF0
F6F4F8F2EEEDF2F3EBEBF1F5F1F4ECF5F5E9EEF5FCF0F0ECEDE4E9E8E3E8E8DCE9DBEFDE
E0DFE3DFDEDBDAD2D4D0D2D3D7D4C6CECECECBC3C1C1C6C6C2C0C3C8C0C2BCC1BCB4BDB6
B1BCB4B0AFB1B6BAA9A9A7B3A3ADA0ADA7A098A49DA4A19C9EA09C9F94A09795908B9190
89938E9790918B8A918F89818B89888C918D868084867B848689817C8283837882838283
817E7678757E797C7E76777E79797B7371747276716F6F6E6E6B72686C7772746E716D70
7167686C716C6D6E6C6263706666696567656C665E6369686E6164636E5E61686B68665E
6464656A6A695E5B66616561615F645C6164636065605B5F5C5A6764595E61635C57595F
615E5D60595E58B400000000000000000000000000000000000000000000000000000000
000000000000000000000000
E96969696D6C6C6C7068696F6C766F696E716C696F747571666C6670676A6E727A6B716A
6C70716E6B6F6C767170746C727174726F6D7375767674776B787574787573726C777171
7573807870747879797B757C7C7B7875757A7C7A7979807C827C747A7E79767D7E8A777C
837B7C848783828686838382868A8B8B8A86898D89868E928E8691968F9090919294959E
A3988B909B999895969B9C9B9995A0A3999BA9A0A3A3A3A7A9A6A9A5A9A3A0B0AEA8B1AF
ABB4B0C1B4B9BCC1BBB7BCBDB0BCB1BEB6C2C3BEC8BFBDC9BEC1C4C1BEC3C8CED5D3D3DC
DBDFD6D4D1DBDBDADFDEEBE6E9E5DFDFE6E9E9E2E5E8E9EDEEECF0E5EAE7EAEEF7FCE6F1
ECF1F0F1EEE7F2EEECECEEF0ECECECF6EFECF5F4E5E8E6E9E4EBF4E4DDE8E4E3E0EDD8E1
E0D8E0E5D5E3DECED4D9D2CCCFBECDCECDC0C2CDC4C4CFC5C8BCC0C2BCC0B1BCB8B6B3B3
B4AFB4B6B7B4A6A8ABABABA9A09FA4A5A1A796A6A1A6A1A1979C9C9C96939B958C9B9099
91918B94908E98908286898E888C898589898481878D838081817E82847A7B7E867C8481
7F7D7C7478767B72787C7F797C7874776E7370726F727273706E716B726B696C6B6F646A
6F716C696A6A686E6A6B696966636F69645F6C65696A6466686B646C61636A64635E656A
666860686061676063635C605E616661615E605E5C63635E5E605B5E5F605E605E605657
5962635F5C5F56AC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E86D6A6D69696B6B616C686E6B6E6D76746D70706D6C736B7074696E7070746E69726F72
69686E716B726877746E706E6E706D707070767477746C747274707C7E75757673717477
7C7B7671807A797A7A737B78737676757D7679767A7A7B7B807E837E82837F7C7E814C51
7D83898183838988807C858684888B8B8D8C847F8B90868C908C8E908E8D8E9498939196
9E9795959C9C9B9AA0A19C98969F999E9E9CA299A3A6A3A8A5A6ABA3AEAEA6A5A6AEAEB1
ADAEB4B6B4B2B5BBB6C4B5B0C0BAC1BCC0BEC0B5C1BFC0C0BEC4C2BEBCC9C6C7CBD7D8D6
D4D3D9DBD4D2D9DBD9E0DBDFE9E9DCD9E1E3E4E1E3E4E8E4EEEBE2F0EBE9E8E8EBE3E5E8
EDECE9EAEEF0E5F3ECE9EDEDE4E8F1EEF2ECEDDCEEF0EBEBE6ECDEE3DBDDDCDDDCD7DBD9
D6E6E0D0E0CECADBD3D9CBD1D0C8CBC6CBC7C0C4C0BCC3BEBAC4C5B6C4B8B6B8B9B9BCB3
B1ACAEB7B5B2A9B8ACB0AAAAA5A4A0AAA6A4A29B9AA3999CA39DA491959E959596988888
918990919095909292878A8988868986838A8A83848B8980868184767E83807E80817B7E
7E8080757D7879797C7C737B6F7E6C726E7070707579766D696B77716D696B726674706B
6E6B667066696662666C6863696C69646E68666365616867696B6468656A64636B636966
695F64646C61625D616462615E5A635E635B665F645863605F6066605C5C5C605C5E5A5C
59605C5E555F5AB300000000000000000000000000000000000000000000000000000000
000000000000000000000000
E76A696B6D6D646871686E69716A6E6E6C71707370696F69686971696E6A6C737069686E
6674736972786C6F74746E716C6C71716E6B79726E6B747A72737377767B746E75707080
7D787276767F73766E78807A7975797B7B737F7C7B74797A7A77787E807A817E817C7863
7985808B8080868A88828481858C848B88828D8C92898D8795968C948E90919794969194
A49B989696949F989E97A09B9F9C9B9C9B9E9EA4A6A0A9A3ACA8A4AAA1AEAAA4A9AAABB4
B1ABADABB8AFB2B6B0B4B1B7B8BCB7B8BCB8B9C1C0C3BEB9C4BCC0BDC0BCBFC6C9D9D0D6
D4D2CFCED3DBD9CFD1DDE3D6D6D9E2E0E0DCE3E1E5E3F1E8E0E5E8E6E3DDDEE2E7ECF2EE
E2EBDDF7E8E9E3EBEBE9DEE4EEE5EBEDF4E6E9F0EAE3E6E9DDD9E6DED7E2D9DEE1E0E5DC
E3D6DAD6DBDBD3D4D0D0D4CED1C8CFC7CAC4C6C3C1C2BFC1C0BEB9BABDB4B3BEB1BCADB3
B3AFB0B3B4ABB0AEAAA9ACA7A6A4A49E9C9B9CA1A497A1989B98939292908F8E9A879690
8C93918E8A8B8E898B8E8C8B84868C8287887F868A808089817F8678817A8882827E8177
79798282777C7A797B7476737978737173736E78796B6E706E727368766C6E707169716C
706F6B6B6C6C6C6D666A62686D6667636469696F5E6B616C646B6466656B5F6A6B626566
66646166616260696066685A66636063606364645E60615C616361616363605F5B63596B
5C615C5357565CAF00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E468656B696B666F6B7169696C72767068746F6E6F717371716F737374686C70766C7071
73746C717474756C75706A6F756C7071707071797876737A6F777B737E767774797C7777
7C79797A787B766F7C7675767B7B787C787B76787A7B78797B837C7C7B83827B817D7D83
7A847982807C8680808A848384808689888988878E958C8989909095918B9093909D9698
8C979B9A8E989C9C9696A09E92989A99999B96A6A1A2A2A39CA0A6A5A9AAA4A7ACA6A8B4
B3B3B3B8B5AFB4B6B8B9B9B8B8BFB9BCC0BBB9C6C5C3BDB7B9BEB4B5B9B7C1C7C3C6C9CF
D6D1CEC8CECECCD1D3DECFD6E1DBDCDCDBD4D9E7DEE5E8E8E8E5E3E7E2E4E4E8E7E6EEF2
E0E3E4DEECE6E8EFE9E8E4E6E5E7EAE5E2EEE5DFECE6E5E6EEE0E0E8D8D3BED3DCDBD6DA
DCD6D8D4CBD3CECDC9BFC8C6CBCCC8C9C3C2C4C7C2C6C1BBBCBCBBB3B9BBB8B6B9B5AEAF
ABA6B2AEAFADAEAEACA9A1A9A7ADA19EA0A4A3A6A39BA19EA495969B989391988A938A8E
8884918689908B898D848C89899085858A8A82888389837E7D838282847E7B7A7E838080
7B827B717A797B7F767F746E747776706F746B70746C7070716D73766B71706B6A6B6F68
696C696C6C6E6F686C68696B686961696A63656968636E68676967636968646463646B64
686B5F64646569605E5E665E6064665D5864615C645B5E5E5F635E60635C6060545B5C5B
60605960595A58B300000000000000000000000000000000000000000000000000000000
000000000000000000000000
E7706A6870686C71706E6C746C696A6A6F6F6C73746E7666726C73716D6870716E6E716A
77706C6E6D6E7574717971766D73716E787172726E737B6E727176747078756E78707479
737D717A777C7C7B797A7C7C7E7E7981737378817B7A797A767B7980877A807F807D787B
767B817E837A80838B8180828981848887888C8D848E8C908E8C868E959795918D989189
969587949E9996989C949B929B9C939E9C9BA19E9DA4A4ACA1A9A39EA4A9A3A3AAA8B0AE
ADAEAFB0A7B6B1B4BCB1B9B4B4B8BDB4B6BCBCBBC0C6C0BAB9B9B6B8B8BAC1BEBCC4C9D0
CECDCCCED6D1D3D5D3CED6D8D1D6D5D6CED7E2DEE0E1E1DEE1E3E3D3E1D8E0DFE2DDDCE3
EAE1E3EEE6DDDDE8E6E3DCE8E3E9DCDEE3E7EBE5E9E1E3E9DEDCE8E3DED9DCD9DADBD8D3
CDD4D8CBC9D4C9D0CBC6C8C8C4C8C0BDC0C2C5C6BEBBB7BBBCBBBBB4BEB9B6B4B9B0AFAB
B1ACACA5A6AAA8AA9EA5A9ACA3A89E9E9E9C9DA1989D939D9A979696969E979698919290
919491918B8A8C8B888A888C807D838186818486867C848782838785787F8384817D8383
7E827C797A7479767673787C7477796F736C6D74736D73716B6F716C6F637169715E6C6C
6F7068646C69686E696466626E666B6B5E6E6864686469686B6964646667686C69685E66
64596861656361615B595863606568605F695C6660605B6661665B5C665B595B645B605F
5A5C59585F5B5EAB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E8716868656C6C676D676C67636D6C6E716F7070756C736B716F6E726B71686F6E766B67
716E7573726C71767472786C716E776F75756E6E6E6F737179767A6E76767E767A747980
79747878787670767475757C747380767B74777D7673797974757E787F7C7D7E83838480
857E86837F7E7D8083808486848A8D84848B8C818A8D8A8C8F8C988E9593989695919A8F
999291999E969B91A498989990979C959BA09E999E99A3AAA7A3A6A6A699A09EA8ABA5AB
ACA9B0A6B1A9B5B6B6B7A9B4B7B4BAB3B7B7B6BEB3C0BAB9B4B9B8B9B8ADB5B8BCC0C5C7
C8D2C6D2CECCD3D1DAD4DCD8D3D1D5D4DCD9D8D2DDD8DBDADCE3E0D8D9DDD9E0E7DCEBE6
E4E1EDDCEEDEE5E8DBECE4E0E2E4E3DEE0E6DEE4DDE3E5D4D6DCE1DBDED3DED6D8CAD1D5
C9C3C9D0D4C9D1C5CBC9C6C5C9C8C3C4B9BCB6BEBBBEC2C6BBC0B6BEB5BDB4BFAEABAEB3
A7ACB0A9B4B3ADA7A4ABA9A6A4A1A59CA39E9B9E9F94969B969C9991939D9E958B8A918E
8B88888D9090968E868584808583818B8080818189838080808181807C7D7C79817C837D
827C797E7273747879777B7178746973756C69707775786D6C6D6D70686D67706B656C69
696468666C6C6D6968686A6E6468676B666E666363636567606861686C666564615E6162
636B62686062646363686563666058635C655B5C595A6063605A605F605A605E5B615C60
5E60575B5A5E51A900000000000000000000000000000000000000000000000000000000
000000000000000000000000
E868736669676B676C68696B6B6B686E6F6C6E736F6969697073746970737471746D6F71
6B716F736D6E6E6D736E71776D70666B717871697375706E776D6F79737977787A7B7A78
717474737877797279787C727B797877797678747F7481747674777E797C7D80787E8280
78867E867B808784848686868A89858E87868D878A8E8F8A898E90959093918C96919195
919487989D9B989F959496949B9298A39B9F9B9C9E98A39C9EA5A8A0A9A29CA9A6AEABB1
B1B0ABA8ABB7B1B4ABB2B8B0B0B0B6B1BCB9B5BBBFBBBAB9BCBCB8AEB0AFB6B5B2B9C0B8
BEC4D7D4CBD2D4C1D1D8CFD8D6CFD8D3D4DFD6D9E1DBDED9E3D9E4D3DCD7D0DCD6DEE6DD
E3E4E4E7DAEBE4DCE4DBE3CED8DFEAE4E8DCE0D7DFE1E0D8DAD3D1DBD5D4DCDAD4D7CCCF
D3D8CFD8C7C6CFDAC4C8D0D1BDC1C6B9C0C2B9BBC0BCBEBDB4BCB4B4B8B4B8ABABB5B3A9
A7A6A7ACABABAAA7ABA1A6A0A19E9FA6A3A097929E9EA3989A959A999299978E8F938892
8C888A8C8B898B8E889180887A84817E7F7B838A868487837E80817F867F79797E7F7C81
7D7F7E7B7D7B76796C767076776A736E796F6C71737873717469706C716E6D6964616F68
6B6E6C6F696A6869626C6E696B6966645F665C6960646266606A69686061626665646362
686665605D5A62606061665E5863635F5E57665E5E5F6663605960615D605C625E5C5E59
5B595B60545559B000000000000000000000000000000000000000000000000000000000
000000000000000000000000
E06D6666706C6C616B756C686A72766B686A69726E696A6E7172716C6B716C71686F7070
7073736C7473716C73766E68736E6D707179786E796D7474767273716F7C7673776E797B
747B7076726E7C7A78777A767B6F76797C787E7C787E7B7B7B767B797A7E897E7E857D7E
848483847D807C8481888483898E84898788888C888C8B8B8E8D90938E94908A92988E92
999498989C98979699989E9A939D96969B9B9F9DA29DA2A2A69FA4A6A5A6A2A5AEA1ABA9
A6B6B0AFB2ACB2BDB2B1AAB2BBB1AFADBAB6AFBEB7B5B9BAB3B3B6B3BAB2B1B8AFB1BABC
BEBEC8C8CAC3CECDCFCECDCFD9D0D1CCD6D8D1D6D6DBD4D6CCD6D3D1D0D4D3CED6E2DAE5
DDDDE2E2E7DADAE0E3DCD0DEDADBE5E2D6D8E4D4D6E4D9E0D6D8D1D5D6D3D1CDD6CAC8CB
D1D2D6CBCDD1C0C7C9C3C9C6C3C8C4BEBEC7C0B2B9B4B6BBB0C1C0B4B7ACB3B1B2B4AEB0
A8ADAAB2ABABA4A7A5ADA2A6A1A0A2A3A0A09A9E989CA09D989493948E9199928E8A9488
908A8E8B8C81848C808082817B88827E888580808381897E81827C7E7B7881817E81817C
807872797B74767C727474766E766F7173777B7678766F6E6F6E71746A6B6B6F656B686C
716E6C6868666A686C666169616164666063636960616961646561636062665D66625E6F
62656B62666365626161615E6066606763615A5D6560625E61625E63645C545E585F5858
5F58565A545863B000000000000000000000000000000000000000000000000000000000
000000000000000000000000
EA726E69706A6E7170716C6E686B6A65696E6B6B6E6B6B6B6A6D6E6A6A6A73696A6E7368
7073686E717974706F6E6F716D756E77716E74716C76757273767179777A766F7970777D
747B7C7B73727975747B737C7B757A73787C797B797D7B7B787B7D83838083837A808484
7F837E86837C8B8383817F888887838E84848A868B8E838C888E8E9092968C939090968C
9892989995969B979797939B9F9A9B9A9E9C969C9AA2A0A6A0A8A8A6AAA4A7A6ACA9AEA4
ABABA8A6B4B9B0B2B1AEB2B6ACADAEB2AFB2B7B4B8C1B3B8B4C4B4B3B6ACB3B3B8B3B6B9
BDC0CEC6C8CBCACBC9CCD1D0D1D6CCCBD2D1D5CCCFD5E2D7D9CED2CACBD4D0DBD6DBE6D9
D6E1DAD7DBE0DBDADBE0E1D7DCD4D8DADEDDDCDCD2D3CFD2D3D2D2CAD4D3D5D1C9D1CBC5
C5CCC2C6C9C6CAC1CBC6C8B7B8BEBEBEBBBEBEBEBBC3BBB4C0B8B0B5AEB1B1B3B2B1A6AA
ABABA3A1A8ABAEA4AAA9ACA6A1A9A1A19E99A4A494989A91969B98988C94938E89919087
8B8E828F83898888897C7D8186868885868381858284818080797D7D7B7C767D827E817C
817983767576767977787A786F74787C6F687779746A6C6E737173757070706C706E6769
64666E6169706A656868666771666A646465696468646465696662616464646368686066
6865666A646663656A615E6465615E67606B655C615E5E5C60615C615C60616355595F5C
6560585E575751A600000000000000000000000000000000000000000000000000000000
000000000000000000000000
E96B697170647468716E686A7069696C68676D676F70716E707274696B6C726D6B74696A
736E7274736C6B727374666E736D6B71726E747670726E776E7173767277787773787A75
717373767371737A747378757178787D7979787A7879777B797F7B79797B8D8B827E837D
837E83818484807C807E848984818A838890818E8E88888A8F918D899286908E8A91978D
8C9B918C8C99969B9C9B9391989C97999AA09E93AA9EA4A6A49FA3A5A9AAA7A8ABA9A6A8
ACA6A6A9AEB1A9B0B2B4AAA6B1AEACACA7ABB2BAB6B6B8B7BBBBB1B4B6B3B8B2B6B3AEAE
B1C1C0C9CAC3CBC4CCC7C5CCCAD1D3C9CFD3CECED9D4D1DBD4D7D1CCD0D8D1D7D4D6D6D9
D4D5D0DBD4DCD3DCDBD6D1DED9DCDCE0DAD8CECCD1D5D4D3D3D9CDCAC9C6C6D1D1C8D2D0
C1CDCBCFC3C6C6CCC4C9C8C4BEB8BCBCB5BBB6B3B5BFBCBBBCBAB6AEB5B1ACB0AFB4A8A9
A5A8B1ACA4A6A5A4A3A39EA8A6A89B999E9E9E9699A096958B97919591998F9398918F94
898991848684838487828C8C847D87867F7A808B8B88817E7E8B7C787978807E79807B81
7E7E7A7E7872767C7378767B76746B7671706F68766F72746969756D6B6A6971696B6A68
686B686A5F6864676769646863656666666966636C59656767626A68665E68615D675C5C
5F64626362605E60665D5D605D65615B606060645E5E5E605962615E5E5D665A56665E5B
5B615E58535354AC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E36C6C696A6C726B73666C6870696D6D6A6F706E716E696E6F6D727370706970696F6E6E
6E706F6E74694647696E70716E6B737372746E706B737370706E78737B7679797775707B
767C756E786C74706E777A7979787A787B7C727A797576797C7C817B7E82888683847980
8084787E84838184898383837F8B818581888B8B918D898C90888E8E9090948D9095998B
9195909592A0929697939996999498929396989B9BA09E9EA2A3A6A2A0AEABA8A49FB0B4
A8ABA4B2A9A1AEADAAABACABA3ACA9A6B1AEAAB0B4B3B3B0B5B3B4B7B6A6B1AFB9AEB1B4
B8B9BEC6CACDCAC6BEC3C9CECDD1CBD6CBCCD3D4D1D0D3D0CFD4CCD6CACED0D4D9D4D1D6
D8DCE0D7DCDBDBD6D6D6D9CDDCE0D3D4D8DBDBD2C9D2D0D9D6D8D4CBD4C8CBC9CEC7D6D1
CACDC7C7BCCBC2C1B9C0C4BAC1B9B9BBBCB6B4BEB8B9B6B3B6B3B1B8A9A5ABAAB8A6ABA3
A0ACA8A6A4A3A5A2A8A7A4AAA69CA0A79D989D99969C9891918E958E959092948E91918B
8A8C7C81857E8087838980858D828185838288817E868580817E81807D8075767D787C73
7E797B72707A6E7C787A6D746E707874737473717172726C666E6E6E68686E696C686B73
6D716661657162696F6A646164666B666868656761646663646266666761646168636363
646066626262666261626164666060685F5F64635D5C595C685E5F5B5E545D5C5E605C5B
5B575E5E5C5358AD00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E3706969706F6C6B69736D6B7070706C6C6D70716C6E70696B6A6B6E717072717B6E6F69
707170706C6C666C716771716D6C7373736E70747178767270717C707678747E73797773
74747876747572797F7B6F737877787E7C7E7C7A7C767E797B82777C7C82817D7C7C807E
837E86807F7C7F82858C818689808D8C89838B8E898F8991889188948A918B8799938C90
968E939494919392909B9694969B9A94989991999998989B9FA1A0A1A79D9EA1A6A6A0AC
B0A2A8A1ACAFABB1ABA5B4A9A3A3A6AEADA3A8A6A6B6ABB0B0AEB4B8B6ABB6B0ADB1B5B8
B9BAC1BDC3C4C7CAC8CEC5C5C4CECFD0CCCFC8CED0CCC6CAC8CCCECDCED0D5D5D2D8D3D5
D5D8DBD5D9D3D9D4DBD8CDDDCACED0D4D3D6D3D3D2CBCBC9CAC8D1D2CCC3D1CECCCBC9CA
C0C8CAC8C5CCC5CAC3C8C9C1BBBDB4C1BDB8B8BDC4B8B1ACB5B6B1A9A9B3AEABA8AAA8A9
A8A9A6A9A4A4A4A7A8AAA1A8A5A2A1A89CA0A39B9093988E96A0918A92968786888E8C8F
908A7E89908486898C8E838584888080858784847C81817C828686807C797B7B7E797A79
7D7A74748073747B7775727972717575706C6E746F6E687173716E716E6F6E6A7063666D
6C5F706B6B656C676563666B61696868636466666466655C5B6363616761616363626B64
62635F635D625E5D60605D5C615F636261636062615E6258615E605E636264615F5F5C63
605A5E5A5B625BB100000000000000000000000000000000000000000000000000000000
000000000000000000000000
E96E746F706E746C6D6C6F6B6C696D71646B6E6D6A696E74736C6E686A6C6F6F6C6F7276
7071706C6E746E6C6E74726F6E746E726C7173727671726E77767A7070737B7179747479
7B75777C737874746C767B7571787B7C747479767978797477787B7C807977817E7D8084
7F8081837C868080868684867F898B8484898884898C8F858B918994908C908590919193
938F968E8F98908F909192989698979A9397989DA09D9BA899A49CA1A19EA4A0A7A4ADA8
A6A8A9ABABA7ACB1B1A8ACA6A5A9A9A4A9A1A7A7ACB7A9AFB6B2BBBBB4BCB0BCB1B8B0B4
ACB7B9C6C3C5C8BECAC3C1CBC0C4CEC7C3C0D0C4C2C8D2D0C8D0CCCCCCCCD0D5CCD5C8CF
D0D3D0D8D4E0D6D4CFD3CCD0D8CECBCED3C9CFCAD0D4D2D1CBC9CFCCCCCFCCCED4C0C6C6
CBCBC9C5C2C3C1C0C4C3B7B9BEBEC3C7BCB2C0B5B9B8BAB6B4B9ABACA4B1AAAFB4A2A9B3
A4A3A39CA0A3A3A29CA09F9FA4A1A2A69F9B98939C969898949591908E93938F8F96888E
8C8883898586888A878A8286807E85827B867E868B7E81887E7F807C817C867C7B7A797D
7678737A7F75777B787B73737D7A78796E767270736D70707175746D667070766A6C6468
66636C6869636C6C63696669626365635C646264695E6261666960666863666264645A63
5F62665F5D61615C635E5C60615C645C6659615B5F5E615865605B61585E5E6062586159
60545B635D5852B500000000000000000000000000000000000000000000000000000000
000000000000000000000000
E77273707564726D76647368706E6C6C74686A706B6B66716E707170776C6E706E696D6C
716F7870716C7269736E737170766A767171716C787672727076706B7378787473747271
787074797E767A70777471717E7B777B7A797B7C767B787E808081897B807F70797C7A84
82838983807C7C82898083818C868684838D8C8885858C96938B8E90858A8E8B91878C93
909096959393919094939897968C9A9099949EA199969F9EA0A0A194A5A39E9E9DA1A6B2
ACA9A9AEA4A6ACA9A7ACACABACA8A3ABA39EA4A6ACAEB8AAACABB6AEB7B8BEAEB8B1AEB9
B5BEB4BBBCB9C6C3BEC0C7C5CCC5C1C9D1C6CECEC8CECBC8CBC4C9D0CCCDCCC8CBCCD1CA
D3CBCBCBD9D1CED5D6D1D1D4D5D3CECDCECEC8C7CACECBD0C3C9C8C5C6C6CCC8C8C3C6BF
C6C4C6C3C4C7C2C4C7C5B8B6C2B8B5B8B6B9AFB3B3B9B7ABB5B2B6B1ACB3A9A4A8AEA6AD
AB9A9EA4A6A6A0A7A19FA4A49E96A09FA099999C9491899694989493988A918C84919289
888C8B84898483867E848C838886807C7B7982827D7C85817E89807E807E79777B747974
7976787A7A797B7874767A6E7175757272736E75736E736E6E6D716870686E6868636761
73696C60666B61646B685E6E616C6266666267636366606869625E61635E606E5A615E60
5C655E63636660616462675F5C635E63645E63616061615E5B60645A5C58595E60595B5B
5E59565C5E5956A700000000000000000000000000000000000000000000000000000000
000000000000000000000000
F16F6D736B6C656D6E726B6A6E6B707375696F71676C6C70686B6C6B686C6E706D766872
6C6F70696B73706F6D6F73716E736D7270736F746F78746F7473717B746F776E77767B82
707370797073797170717975716E7B787B73787B76787678747A7F7C7B857E7E827D7A7C
867E7A7C838583808684848C7C8B8BA08C80868B858E848A8E8C8C909388938C8F849093
889392918D8E96969B938E8D9898949B9999949A9D9B9C999F979CA39FAB9BA6A6A6AC9D
A2A9A7ACADACA9B1ABB1B0A9A5A6ACA1A79FA3A4A5A1A6B5B1B3B0B4B1B7C0B1B4B3B3B4
B2B2BABCC3C0BECBC8C4C3BCC0C8C8C4C1BEC6C5C4C6CDCCC8C4CCCBD4C5CED0C6CED8CE
DAD0D0D3D2D0D6D0D3D1CBD3D0D3C9D1CCD3C8CECAC8C1D3C4C4C1C9CAC6C8C6C3C1CCC9
C4C2C2C4C0C4BFBEBCB3BFB8B5B8B9B4B0B2B8B3B1BBC0B0B4B3A8AEADABA5A5AEA9ABA6
A9A29EAAA39F9FA3A29AA29B98A3A39E9BA1A093969799998E8D928E93897E90948D8487
888C8786868C897F86858C82867C877C887C7987847D7F83837B797B7D7C797C7C7B7773
79757175717670757B737778787373706F746E75707572746C73696F6D6B6C6B6C766C6C
6C6E70676A6969666364606369646163636666666567646564646B625F615C6566636963
67646060695F665F616066655D5E62615F645B645D5F605B5E625A5C5C5E585C5759575C
5D5E5360625659B200000000000000000000000000000000000000000000000000000000
000000000000000000000000
F479706F71706E6C707175706A6B676E6E6B6D70706C6D6E696F6E726971716A6E68736D
7574686B6D6E737A6B6D706B736C786E6D6F7079747C7078747D7B79747673756C767881
7470787479767C7B737570736D777A797678787A79737C79767B807C7D7D7F827F7B7A79
81848683838185848A88868A8384888C8489878984908C948B8A8C9191898E939189908C
938A90938C919C9B89A1969592949A91988B969C98A09A9E9C9BA09897A5A8A99A9CA8A8
A6A8A9ABA6A4A9AAAEB6A6A6A4AAA9A4A29EA1AAA3A8A9AAB3AEB7B1B3B1B1BEB6B6B5B5
B0AEAFC1B8B9BEC9BEC5C6C3C3C6BEC4C1C2C8C0C1D0CCC9CEC6CBCEC9C7D2D1CCD2D3D0
D1CEC9CFCBCCC8C8C9D3C7C9C8CAC8CCD2C8D0D1C4CAC7C4C6C3C6C1C9C4C4C8C9C1C1C8
C4C1C3C0C1BCB8BEB3B6BEBEC4BBBCB1B7B6B8B4B1B6A9B1B4A6AFB0B0A7A8A9A4A7AC99
A5A39C9FA49FA6A59E9EA9A69AA29E9D9D969B99979B93908B908E968C91928C90898B87
818B8582868A888886818979878384838384827B847C817A747B77837C7A79797D77737C
75727975777871777272747372737874706D6E6F716D6F727361746C776D6A6F6C667064
6C66686C6C6664706766686C62656461665B68646370646661605B635E63606263606063
6860615C66586160606069635E6960616066615B5F6059555C5B60615B5D6460595E5C60
5755585150595BAC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
FF70736A6B676B696C6B646F716E69656B666C756F6C676D666C696C7070716871716E72
6E706970756F737170706B6B6C71777B746F72717674716C7571777479797B786E796F77
7878797E797876747976737679747C7C73717C787B767D7381797C7A7980837B82837986
7D817D7E7C8B897E897E8389808988898684888C838B8E89848E8A90908D8D8992919498
8C9B8A918C919493919898968E9F91948E969296959398A1A6A299A1A09FA69DA1AAA8AE
AB9CA19DA9A9ACA2A8ACB7AEAEA8A8A7A19C999EA4A2ABA9B0ABAEA4B0AFB0B1B6B2B0B4
B1B2B1B3B4B3B4C0C0B6C0C3C1C4C0C1C6C1BEC1C3CCC4C9C9C8D0CBC8C1CCC5C7CBD0CA
CFCFC4C8D5D5D3C7CCCACBD0CBC4CFCACECFCECCC9C2BCCBC4BEC5BAC6BEC2BBC0BAC2C1
B5C5BEB9BBB7B9B1BBB0C1B4B9B8BBBBB0BBB4B1A9ABAFB2B4AEACB0A0ABA4A6A69BA5A6
A39FA19DA29C9EA0A4A39EA09E9E9C9D9E9C98949B9A89969295918E92958E8B8E8D8D8B
898A918681858B7C8479848283837F83817F847D7C7B83767C7C73747880787C74787C7B
7A747F777379737F7074727A7372706E6C70746E786F6D6868706F6D6C6B6A696665716C
6764676F6F686B616762656967646B63626169616B63666461636568615E6365645C6361
6463636059632C105D5D5D5D605D6161625E5D5F60585D5D605B5D5B615E585959595B5D
60595B5156605BB100000000000000000000000000000000000000000000000000000000
000000000000000000000000
FF7C726E706B6C6E6F6E646662676D706C6B6E696C70706E646E6A646B696E746D6E7164
69727074706B676E736B716C6D6E74736C6F7B766E787771717971736B747375766F7978
73717C7B73766F7A79776B6C717379726D74767A77757C7775807E797E7B82817D787F81
8383858386878083838B85898788817D87888481848E868989848C8E8D8A8D8E898E8E90
939093908C9E8E96968E90918F938D9593959C9F9BA0949BA29CA6A3A3A09EA29AA3A0A4
A8A0A4A6ACA9A4A1A6ADB2ADA2B1A6AAA39E95A2A1A6A4A6ACABAEADB9AFB3AEABB3B9AB
B4B2BAAEB8C3BDBEC3C3BBBDC1C8C8C4C8BFBEC0C3C4C9C3C6C1C8C6C4C7CBC3C9CCC5C0
C6C7D1C9C4CBD0CCC2D6C3C4D1CBC8D4CCC6CBC9C0CBC8C8C4C3C1BEBBBDB8C1BEBCBAB0
C0C3BCBCC2BAB6B8ACB6BAB4B5BBBBB5ACAAB4B4BAB1ABB0ABB2B3A8AFAAABA4A2A5AAA4
A1A4A29BACA199A1ABA3A1A5A09AA0949D9D9E9A9690919391938D8B93938B8B8D888B85
8686888B8A8B878A8C89838A837D8C867D837981807E837C7C7C75787C7F7C75766E7678
7C7D717674766E7A767E6E737571706E7172706F72746D72716A6D746B6B6B716A716C69
6C6A636C676A6C6B66616F6A67646B656C62646068666366646663645C5F665860625D64
61615F5D6161533A5D64686060625363545C5A605E605D5B5D5D625B595B5E5B5A56585A
5B575653555859AC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
FF7B766E7169696B6C6C6969676B73636B6A666E70706E666E6C686F6969666A6F6A766D
6F68716C6C6B73716C716A6D6E73736B706E73796E747974797176747475727876737374
7675787C74717371707C737375737678787B767A787C807A7B7E807C8384857F83817C7C
837A7A847B87848280898B8892878585857C84878E86888C8C8C8B888791938F8A908C93
909691998E8D94918E908C9191919896949395968F92A09E9D9A9E9BA3A09C96A0AAA8A9
ACABA8A8A8A1A3A9A3A8B5B0B0A7AAA2A3A4A2A1A29EA4AEAAB1ABB0B0B0AEACADB6B3AD
B1AFB7B1B3AEBEB9BEC1C6C1C4C9C1CAC4BBC0C3C4C2BED0C1C7C4C1CBBEC4C4C4C7C9CB
C5C6BFC6C8CBC8C8CFC4CBD1C1C2CEC1C4C7C3C2BCC9BEC3C3C2BEBABBBEC4C1BBB8C4BE
BEB7B2ADB0AEB3B6BAB5B7B4B6BCB3B4ABABB1AEAFA9AFAEB4A2A8ACA3ACA4A8A6A1A9A4
9DA9A19EA4A5A1A09EA0A69FA09D9CA19690969C999895948D948E918B898A8F8986918E
8E898C9286858983867B81838181817B7E827F79817E787982817E7E787E7A7874757B80
71797779737477706E727D7971737376706D7473686E716D6D746C75706B6C6C5E696C68
636B64636A686964695F64616E666B695F6567636A63646860625F66676166625C60625D
5E676A6364635B5E5E60676164635E605E63636457645E605E5C5E5966635657605B5859
5C56585F585C54AC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
FF7E6E6E70706C6F706E676C6867696E6779686E6C6C6E6C6F696E7168667368726B6870
6F736B73736B7370706E716C716E74746C6B6C736D78737575716C767671657771717570
79787A747979767673746E7179727B767479767C7D7E7474797D7E7E848379837E7F7882
7C79837D8481897C8881838983817B7D818488858989888F83898588949089809194878C
8C8B938797988E88909691918F948B8E949D9E8F949B9F9398989B9A9EA3A2A19DA4A4A4
ACA6A5A6A3A4A5ACA8A9A9A6AAACAFA7A3A4A0A2A49FA2A3AAAAB1ACB1AAB6ABACB5B0AB
B1B0AAA9BBBAC1BBC4C4C9BEC0C3BCC2BEC0C2C1BCC8C4BDC2BFC3CBC3C2C6C1C4C5CECB
BEC0C0C8C0C8CACCC8C6C1C6C7C6B6C5BBC2C0C3BCC1C8C1B3C2BEBABBBCB8B6BCBCBCB4
B8B8B7B6B8B9B2B2BAB3BDAFB7B4B0ABB1B1B2A5ACABA9ACAEA9A9ABA2A3A0A0A6A7A7A3
A39EA4A4A2A7A39EA2A99FA0A49B969297948E9391938C8F918E8D8E888F918C888E878C
888989838B8382888988898084807D807E7881787C7A7976747C7D80807F7B6E74747871
757179757675706E73767778717171797576706C78676E716E7175666E6E6C6F6D706871
696C686667636E6369606064676262636E646665696667656460596064686960625E6164
5F606164625B605F60636360646361595E635C5E5B6364615B5E5F5E5961595A5A5D5057
5C5C5B58565B5AAB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
FF807372666D706F6B6B646E666F6C6B6C6B6D6C706F666D69606F6B6A706B686C6C6E6A
716A6967646E77736E78696B6D71716B6E727669706E787670767473717376787C727070
737C707675707878737478787A707B767E797B7C78797F837B85817E837E7C7874797B83
807A7B798A8688858C848283848587828985868A848687848689868386828389918B8B8B
888B94918B8B9092948E8A9698999093949A8D929C9194A397999E9B9D9C9E98A8A89FA1
A2A0A4ABA7A0A69FAAACA0A7AFAEACA6A1AFA29C9DA19EADA7A9B2A5B4ADA4A9AAAEABAC
B3AEB1ADB2B7B6B8BFC3BFC0BDC3BBBEBCBCBCB8C6BDBACAC1C1BBBAB8C6BDC6C1C3C4BC
BEC6C4C0C9C3BEC0C1C6BBCDC7C7C4BDBEC0C1C6C1C3C5B9BBB9C0BEB9B6BAC1B9B0B8B6
BDABB9B6B5BAB2BCB8AEB2AFB2B3B3AEA9ADACABAEA8ABB9A5ABA8A99EA6A5A89EA5A6A3
A39E9AA0A09F9EA1AAA49D999C99A1969C968C939392968B8E908E848B948C8991888189
898C888B88818B83888284787F817A7C7B807A79807E7C7C7E7C7C7B7C837C7A787E7A77
7C78727174747A7377707070737B70686D7070736B6D706A6B736B696F72686A68646C6E
6869636B646A66676368636662666866666160616664636064646464616B63615C5C6060
5D5B606561616160615E63645B5B5C6563685C5C64595E615E5E5E5E6162595656645D59
5B6056575A585BA800000000000000000000000000000000000000000000000000000000
000000000000000000000000
FF73716A69636F6E70686D676E6D71696F6B6E6E736E73666D6E686A7068696B686E6464
6B666E6B70736A706E726B7174786C7371736B7169706D707673717575716B7771797379
71707E7B75777974737A7A79787C7B797975747E807E8183797B757B79807B7F7B837A81
8781897F8384828684828384848088898883888180888A86868B8D8C8980908688968F87
8E90948B949091969392919097948F979097989091989D9795989E9BA29DA498A3A4A9A0
A2A69FA8A8AD999FA9A4ABA5A1AEABB2A8A9A19AA29EA4A4A2A2A3A8A9A3A9B2ABAEABAE
A9A9B0B2B6B1B3B1B9B8B6C4C1B6B6B6C3BFC4B9B8BFC3B3BCBCC1BCC0B9BFBDC2BEBEBC
C0C4C3C8C5C1BFC9C2C8CCC0C4BBC1BCBBC1C0C0BBB9B8C0C1BCB9BBB8B6BAB1BABCAEB6
B5C1B4B1B7BAB0B4B0AEB4B0B0B2ACB4B1B0B0A4AEAAACA9ABA4A4ACA0A3A4A1A1ABA6A5
A6979C9EA29AA499A2999B98989B8F949998979090939598918B8C8D8C8C8D898686858A
8B8A86867C8C8D838183858686847C7B7F7F827D787977797E807C7C74767D7A7C72747C
7975787974767672716B797674757273706F736D73696D6D69696270706C6C6B686B6A69
5E6A686A646863615F66676C6866616C63655C6764686962606364635C60646561646364
6364625C62615F6162605E61595B5A615A585E57605E5C5B595E595E5E5B5F585A60615A
605C5E59555A59AE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
FF72706F6C6C6C6C6C6B6E6E686E706F6B716C6C6D6B6A6B6C6D6B6E696B6B6C66696E6C
6C6A706D6F6D72716F6C69716F68746C6F78737177746D716D736F6A7874737373737473
72757179736F747573767876747579797B7B76787E7C78777984827C7E7C7B787A79807E
8381828286807E848284838385838386848B7E888D887E8086838D848388888D8B888D8B
868C8E938D898B8E938E91928E909396938C8C96959498989C9D999C9D9E949AA5A09CA4
9CA5A29DA1A59EA1A3A7AAA8A6ACA9A1A3A99DA2A0A4A19EA5A4A6A4B0ACB2AAA2AAACAC
B0AEACABABACB8B9BCB4BCC4B5BCB3BBAAC4B4B8BEBCC1BEBBB6B5C0BBB2BEC6B9C0BBC1
BCBCBFC3BBC6C8C4B9C1C0BCB8C4C0C0C0BCBBB7C0B8B8B6B8B3BCB8BAB6BEB3B3B4AEB4
B0B6AFB1B7B1BCABABACB7B2AEA1ADAEA7A8A6A9A3ABA8A8A3A4A3A9A09BA1A6A09E98A0
A2999D9E9F9CA19B999A999695959391948E96958F95938E919891918A8A89868B8C8A85
88888C86898687888481868387867D7C7E78767E7C7E807C797476767C757878787D7C79
7771767471717E7874786E7373717071686A717674706E6E6E736A7264666B696B6A676E
6A596B6A6863616A666865616964646068666660636162665D66625962646965635E6064
5D67656B61645C5C62625B615D5E615C61615A615C5C5C5B5D5A5A5F5A5963615C5C5C5B
5757565E5B5954AC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
F4706E76666E6E696A7071696E69686C686C6E6A6B686C6E706D6C6C6C696E7062696C6E
6771646C6A6673706D6C6C736F706E6C75707471707470717176706D76726E716C73716C
7872706C7276777076797B7A747A8178797B787B797C8081827C7979807C797E7886837D
8283837E867B86888486897F7D888681888689838E83848488888A8A8680888592898C90
847F898A8F8E928B8E8E8F8B8C95949098919A949B9D94999B90A2989B9998A0A0A1A19D
9A9EA3A9A59EA89DA1A6A0A1A0A1ABACAEA9AEA8A1A79BA09EA4A8A8A4A4A4ABA6AAAEB3
ADABB1ABA9B1B4AFBCB3B5B6B3BEBAC0B4B6B9BABCBCBBB4BEB9BCBEC1B6B5BFBBB9C0B7
B9C1B6C3C8C0C4BBC3C3B6C3BEBBC2BEBFB8B8BDBDB3B6B1B6B5B1B8B7B3B5B9AEBBB4B0
B1ABADADB0ADACB3B0ABA6B1ABB4AAA8A3A7A3AEA8A6A8A2A6A89E9BA3A2ACA0A3A29CA2
96A0999A99A098A29BA098A09B9B90928C94948C95908A969090908C8A8E8F858F868182
888882839084837E8081847C81768083807D797D7E7F7B797D6E827B78767D7E7B777B7C
7A767A6E78746C73767374746E6B716F736868697073666D686A716C676C69626D6F6667
616164666A6C6464686A6664696A5C6B635F69616858636961625B62645E5B5E615E605C
616464635B60615E6456685763655C5C60605E5D5B615C5D615B5E6453585C5756605861
5D5E595B5D5B54AA00000000000000000000000000000000000000000000000000000000
000000000000000000000000
F36A6A686D70726C696B7071716866766B716D696E6E6E716F6D6C716F6B6C6A686A6B6E
716D6C6E7474716E766D736E6A6C6C7670697871707A726D727874767473737072797C74
75706D72786C767579716C76797374797B7E7A7B7B7C7B74777C7D79837F807B79847F79
76818B7F808281848286808383878389858B7D8A83868684888B80848483888B8886848A
8D8E8D8889938E8F93918A9194969290949893958C939B999C969498949C98A099A89FA3
A29BA1A3A3A39EA2A69FA7ABA3B0A3AAA9ADA8A6A99AA0A2A5A7A1A0A1A3A2A3A9ADACA8
B6B0B4AEB2B4B3ACBAB7B6A9BDB7C4B4B4C1B7B6C1BBBAB4BFB8B8BEBEBCC6C2B6B9BDC3
C4BDB9BFBCBFBEBAC3BDC4BEB4BEB9C0B8B6BFC3B4B9A8AEBAB6B7B6BAB4AFB9B0B2A8B8
B9B6B1B0ADB1B1B0ADB0ACADAAA9A6A1A6A69EA6A3A6A09EA9A4A7ABA9A39BA096A69BA1
A19E9E9E93A7A69996989D9399989C9393918993918F8B8E9697948B9393908A85848C90
80817E84867F8481898081847F7B7A817B847E7A7C787C7F7D807C74756E6F7C75757076
707574767A78787173786D79707373736F6B7079716C6C7964686970707466696C6D6966
616D66636C6A6A5D645E66676464646D616769606B616E63686B6466625A5F5E5E626163
63636660616059615C63635F5C5C61616464625D5E6161575F5A5B595A575C5B5A56595B
5B5B5953605A58AE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
F768686B68666E6C72736C6A6971706966656D6A6C696D686C6D65686B6670746E6D6D72
676C65736E6F6C6D716C6B6869736E6C73716E697874686E736C697673736E71736C6E75
74727571787B72767B7973797F747E817C7B79807C7E76807B767E7E82787B82787E7C79
7D767B887B837D837C767F8889838180868688858A838389889284887C918A8487889085
868B8986908A918C8C8A86908D888E96989A909696988C91949F94989399A49D9C96969E
9FA29B9BA09EA09DAAA7A1ABA6A69EAAA8A6A6A6A3A89CA2969CA4A4A6A3AEA1A9A7A9AB
A2AEAFAFA6AFB1B0B4B8BBB3B1BCBBB2B9BCB6B6BFB7B4BCBDB4BCB9B9B7B9B1C0C0BAB4
C6BCB8B4B5BCBEBFB9C1BBBBBFC5BABEB3BCB6B9B5B6B9B1AFB8B1B6B2AEACB4AEB0B0B0
AFA8B1AEA9A9B7AFACACACA6AAB1A9ACB1A3A2A8A59DA0A69B9BA4A1A99990A09BA49F9B
92A69E99969B9E9B9496929A9294998F90968E948C968B908B8290948A9189848A8C8682
84838D8682848B83898180847C7E7B7C81847C7E7B74797B75817C767C777779767C7470
7E767176747374747978697269746B6D74796E6B7670726C6D696A716E616B6B6C686966
696B68666C68626165616761646B69656266696462686364606163656364656568605E60
5E655D5D5C60665F60636465665E5D61625E5C60645E5A5E595F5862645A57666060605C
56585A53535959AB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
EC6C6E6C676E6C6F6C706E777467686C63706B6A716E646B686E70696B6E726E6E6C6B6B
746F6B6C696C706E70746C73736C726F747170707670686F6C747070776B73756977767B
767A76707173737A7B7578757B7972777E7A777578797B798481807D7681817F7E88857D
7C787E81817E83827F888680848B8185868384888382848888838284868B908B838E888D
8B91898C8E8B8E8D8E8F91969091929B9788949292909296959898919B99A19F9C9A9E9C
A296A0A3A0A0A3A69EA5A69FA3A1A6A4A5A0A1ABA6A29FA6A0A0A6A1A1ACA9B0A4ABA8A4
A6A5AAB3AAB1B0B0B6B2AEB0BBB3B3B7BBB9B1B5B1B2B9C1B5B6BBB4BEBFB1BEB8B3B4BB
BCBCC3B8BCBBB6C3B8B4BAC1BCBAC2B4B4B6BEBCB6B0B9B8B3AEB3B3B1BDA8ABB0AAB2AC
AFAEB1ADABA8ACACB6ADA5ABA9ADA9ACA1A29FA3A7A1A0A6A99EA79BA4A8A3A0A198A099
979C99999D95939B94969D9C9C999391948A8C918F90888E8B89948E8F8D8B888A8C8582
8786818E838188808380828388788178837B7C83777C71787B7676787B7A7B7D74737175
6F707976747170707176716B7473766F6F6F706D716A6C7269686B6B7470616E646C6C6B
6C69696D6761696B686867606266615C64646B6469695D626564616161665F605D656161
625B605D5E5C67645F6667605B5E65605859605A605B5F615E63615C5B5A5B6058555C5D
5859565F5C6251B600000000000000000000000000000000000000000000000000000000
000000000000000000000000
E962686C6A686A6C686668696C6A6D6674686E6B686E77686969666E6C6F6E6D6D676466
6E6D6E716E717173786E75716E7071716D6F70727576726B6E7171746F71767370737176
6E747A7578717C7B75737E7E797A78747F7F7E777E74857B7E7A84787D807C837D847E7E
807C877B867783797E8087817C8A88828187888688867D89848F8587888C90898888928A
898C8590908884918489958E8E968C909091899190909194918E9499949999949E9A9D96
9A9B98A19E9B96949BA29BA6A4A79EA3A3AAA3ACA9A9A39E99A69CA0A8A29BA6A4A9A8A9
AAA8ABADB4B0B1B3B1B6A2B3B4B5B0B6B9ABADB1BBB8B6B8B4B6B6B1B8B5B7B4B4BABEB9
B9B8B6B7B7B2B6BDB8B2B6BFB8B2B5B1B8B4AEAFABB7B3B1AEAEB0A8ACC7B6AEB1ACAFB3
AEAFB1AAA2B5A9ACABA8AAABA0A6A8A1ABA99D9EA3A4A5A3A6A49EA0A49CA29EA09C9FA0
98999E979898999599989A9090939294979191898E898E90968C918B878B908B8783858B
817E8989838B8A827F7B8384847E7C7B7D7976757C80797E7775737678747B7879707672
79737975747573736870746C6C706D7370706C6F666872786E6D6E6C716C70696D666768
67666C6B5F6B68615F66615F62666863636468655A61616661616365645C5F5E5D645D5C
63655E595E605F5F665D615E5C575D5A635C5C625C5E5E5A615E5B615F5F5D5A5E62625B
615B5856575B5BAE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
EA69666460686C696F686C6B69726D6974696E6C6C726B666B666B6E6D6E69696D726F6E
76747666697069706E696B706D6D7676707471706E6F797373766F797370747667757370
6E737577727278737878757D7C797E807F83887C827C7A7B74787B747C8083788383817E
808386827C84808282847C8080848178808783838B8188837E8087868880848E8789868C
84858B8B898A90918C8B8C898893919B9193999095969196959B9197999C9A999EA09A9F
95999E9B9C9FA0A39BA1A7A9A5A8A7AB9EABA2A6A6A7A4A6B0A2A6A0A1ABA4A6A3A9A8A5
ABACACB1ADAAA7AEB4AFADB3ACAEB7B6B3B6B9BAACB3B4B8B1B4ADB4B6B3BDB5B4B9B4BC
B3BAB8B8B9BCB1B9B2B4B6B6B8B4BCB1B6ABB0B0B0B4AFABB5BAAFB1B7B7B8A8A9AAABB4
B2A4ADA6B0A8ABADA7A7A2ACA9A3A4A9A4ABA0A69D9DA1A69CA0A1A59B989F95A0A19598
999C9A9C9C9B8C968E919494938E9090908D8D8C8B908D8D878B898C8D90818190848387
8884847980817B7F807C8083807A79757A817C7976788078777B7478717279767B737076
6E767B7A70737574746E6B6C6F7669716E6C6F6E716D6F6C7373696966616C6A6B6D6A6A
646B68666767696B6E61656664606960626862676561626162646560645F5A5A605B665C
5E61605E6756696064585E6961645C5962645E5C5C5E5D595E5E595D546060595C555A65
575C595F565A54AB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E66C66656D6E69696A6E6D707060696C6F6B716368636E6B686A6F6E6C696D6B6E6E6869
6B69696F6E6B73696B6D6B6D6D6B6E6B6B6C736C737273706E7877717B72686C75707570
777472767479747679737A76818280848A818278817C747B7A80777C81808183787A7E7E
7C76837F7C867E818180877D7D85867F82888489888C8188868980828E858A8889848B89
8A8A898A8E93939891908B8E8E99959595918F8D8F96908F949696939D96949A9C9D999C
A29A9C9D9C9AA0A39F999B9EA6A8A5A1A1A1A4A1AAA5A4A4A1ABAF9EA4A4A7ACACA4A2A4
AAA9A1A9B0AEB0AEA9B3BBAEAFABABB0AEB0AEAFB8AFB6AFB3B5B0AFB9B9BCB5AFAFB6B4
B6B6B3B6B6B3B1ABBBBEB4C0BCB1B3AEB3ABB4A6AEADAAB1ABADAEB0B9B4B3A9ACB0AFA5
ACACABB0AEA3A4A69DA6AC9EA6A3A4A1A59E9B9EA0A7A7A4A0A4A49C9D9D9B999F959398
8E9B99989B919C919891919394918B8F8B98939891898C908E8B948E83908B8B8A868C8A
8884838B808287877C897C767E7E808376787B7877757D7F807777787375787170767975
7376797071716E6770747071726B6C7169697369696B6F736F766E66706C63706E656C6A
7369636969616361646364665B6B68656B646B645E5F625B686362695D646160615D565C
61615B5C605E64645B616059635662595A625D5D5B5C5D5C605B5D5E615E5C6360606259
5E595B5A5B595AA700000000000000000000000000000000000000000000000000000000
000000000000000000000000
E16869676A69676B6F6C6A696E6F6E6369706F6F6F686B6B696C666E63696A6E6C6E6B6D
69696769696B726D7670757173696C6F786B747C6C7470746F696F7276706D7473727275
757473737276737278777076797C807E828483807E837E7C81797A807E7A7B7E7B7E7E83
807C7C7D867A7C7F7C888185807D847C878679888180897F868985878B8884848988858C
8E898B938C8B9390899093908D94948E8C9590928C9A8F9494908E9B948C99989C99999A
919DA0999F999FA39CA9A3A4A0A097A5A0A4A1A0A19FA1A0A1A8A3ABA5A9A3ACABABABAC
A8A6B0AEAEA9A8ABAFA9AEB4AEAEACB3ABACB2B1A6B6B1B1B4B1B7ACB8B3B9B4B6B4B6AF
B8AEB5B4B6B1AEB8B0B8B9B3B2B1B2B7B8B3B1ACB0AEB3B2A1AAAFB2ADAEA8ACACAFA7AE
ACA2A9A1ACA8ABA4A4A9A0A7A1A1AAA6A19BA2A3A3A3A49DA1A39E9EA1989F9B9A9B9797
919598949394989E949B8D968E949698918E90878F928B8D868B8F848D86818586888180
8181868084818484807D7E7D7F83797B7C77807E797B797C7D747479767D797C7678736E
6C707075767070746F72706E6F6F7070746D71726C6976706A6C6D7267696C6967676A71
646C6A656B64606B636367635F636766606163666A5960626265646160665E65665D6463
635F5D61516361536159625E5A5C645B5D60615F64605E635F585E5D5D645E595B646461
595C5F595E575AA900000000000000000000000000000000000000000000000000000000
000000000000000000000000
E66B6466696E6B6F616B69696D666873666B6B6176766B6D706E6B6B6C6B6E72646F696A
716B7170716F70746E736D6C72786E756D6D796E7175727275786B6D7674777671717074
7474767778797B76797A7E787C86798C85877E80787D78797A7B7D7B787D81797C827980
8079807B80808385837E8384788580847E888B7B868688887E868686888C8089808C8B85
90888E898D8C8C8F8B868D908D93939493948F9A90968D918A978EA0939B9C9698999B9C
9B9D8FA095A09C9BA29CA0A5A0A0A3A1A29CABA8ACABACA6A1A4A89BB0A49FAB9FA7A3A7
A9A8ABB1ACA4AFADAAA8A2ABAEAEAFA2B6A9B0ABB0B2B6B4B2B2B3B4B5B4B9B1ACB8B0B1
ACB0A6AAACB3ADAEAFABB1B6B6B4ABABB0B1B1B3ABAEA8B2AAACA9AEABB2AFAEABA3ADA9
A7A9A9AEA7A0A89FA2A59AA29EA39F9AA09EA4A1A3A3A29E9A9AA3A0989C969C99999D9E
9591919C9C969492998A8E93968F998E928C918B8E8E9194868E868B8782868789828388
89868681838581848080817C7E7C787E777E79747C7E7E78767378767879757471777374
796F797A78776C7077706F736B707373706C7471726D6C6B6C68696E6E6F666A716E6A64
656C69616465686069646B6464636561606C65605E5F5E6066625B61675E5D645B5C6656
605B685E5E5E5E615E5C605D5C64605E5D595F5E5D615E675A5D5E5E5E5E605A5B595C60
585C5D535C5E59B300000000000000000000000000000000000000000000000000000000
000000000000000000000000
DE6766686865696E69666871656E696D666371736B71676A786B71706A6B6D6B6D69726D
6770696F70696B71717078716E736E7078746E7378767177757171707270767370787575
7271707370776C767A7B73767E757E83838680787B747B7E8080807A7C7E7C7F7E767B80
7E807E7E847A7F83807D87848182817E838382848181847B8689848B8688888086898986
8B968B8D949786928A8C86928E918891938D90948E8B9093978F93999299958E98959594
909C9A9D999C9C999EA0A29D9EA89F9BA09B9B9FAAA39F9AA3A49EA6A1A7A6A3A9A8ABA8
A9A1A99DA3ABADA9A7A7ABA6B6A9A8AEA4ABB1A9A9AAB2AFADABA7ACB1A9B1B1ACACAEAD
B5B4ACB3B0B1ADB0B1ADABB1BBB2ADB6B2B1B2ABB0B0B4A4AAA9AEB3A8ACABAAA9A8A8A8
A9A6B1A8A4A7A29CA0A0A3A2A2999E9A9BA6A4989CA19CA09B9E97919C9A9B9198989497
968E9699989296958E95919690929091918B8E9490888689938B86938E84868588898783
7C897E7D80877C7B7B777F7D7C7B78777C7E74807A797871767B73737778707879787176
7473747573746D6B74696C6F6B706F686B726E786B6E70686964716C6E6E697064666B69
6D6466637169696465666667666060646863636065696966615D5C6165615E5E615F605D
5C63605C6059595F5E605E5E6158595E5D5D635F6160595A5F5D5A5961565C5C5F5D595A
535A62545A5454B000000000000000000000000000000000000000000000000000000000
000000000000000000000000
E86A64646E6D6870686D67686E686B6D65736B66697169706E6873696D6B6B6C6C6C7272
716C6C69686E6F6C6B6B70746C6B7171726B7972797773747A72707376737470796D7179
77717876747C74717674717B7876887C8A80817B7F77717D7C7D7B7779737E7D87798581
7C7E7C7D7E8178807D7D7F8280897D8682807C82828C848B83808D888981848889818A8C
8D8788858F8F838A89948E8C92938B9494938C8F8794949690939095889498979C949999
999E9B969FA49998A09C969BA19EA197A4A69AA8A4A6A0A6A9A29BA2A3A9B1A2AAA4B0A4
A5AAA8ABA6A9A4ADABA6ACACADA9B1A9B0B0A3ACB0B1A8B5B0ABAAACB6AEB2ADB1ADA9B0
B1AFACAEAEACABA8AEACAEA5AEAAB8B8A1B0B3B1AAA7A6ACB0ABABAEABADADB3A89DAAA6
ACA0A9ADA6A6A0A39EA29CA19CA1A0A0A19C989C939E9AA0999B99A1A09B9593969B9697
95959489999B93918D9C9091878E8C918C8E8E898A90888C8686847F858B8387847C7E80
848981838285857E788A817C7B7978767B767877757280787A7C757E7B80757977767673
7D727A786F74767371766879726E6973706A6D726D74706D697467696A67646E6669666A
6860646366646662635E67666161615E695E616263645F606B685E606063635E66615C63
5A5F605B5C635C5E5F60615E655C54615B5D625D6358605E53555C5956595C6159595954
5C5153595B5751AA00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E36563646B6C646F6864696C6B6C6C66706B676E6A6B6E6E6B6C696D6866656970696B69
696567726E6F706B7471686E6C73706F73797C74747878787775756E7171737477767372
71706E726E707676737E7B757583797E8383787B7B797176807C84787E7B7D767975807C
807E7E7C807A7C84837E827E7E847B828180827E8684818489828183828B888587818C86
8886887E868B888984889194929093948B898C8E908F8E93909698949193969992A09798
A199989F9E9C9699A0A09DA39C99989EAAA1A19DA9A0A0A49AA6A49EA4A3A6A3A8A1A0AC
AAABA9A8A4A3ABA7A9A9AAAAB1AFAEA4B0A8A6ADA7B2ABABA8A5A1B3ACAFA9A9B7B3ACAF
ADAEB3A6ACA7ABB3A9B8B0AEB0B5B2ACB3ADACA9A6AAA7ABA6B1ABA6AB9CAAA9A4A1A8AB
A6A2A6A2A8A6A5A5A0A6A09E9B9E9199A6A19BA09E9B989F9694A09E949A93989B93949C
99899393969394928F91918F8C8C90918E8C8C8B8E8C888685868D87898C8E8980837D86
83838686817A7B7B817C817D7E777D7A797B7B7777777478777277766E71747070736F7A
7674757679747674706C6B6874706A676B6A686F6C6B6C75706C696D6969666C67646468
686A6965666364626865666664626369666768615C6160666356635E605C5E6158636461
565B6060615C64695B685E5E5C616168645C64645F635C5E5E5E6160595C5F626261585E
585F5554585754A600000000000000000000000000000000000000000000000000000000
000000000000000000000000
E46B6F6C6569685D716A67726A6B736E696F616B6C666E67706C6B6E746E686C6B696772
6F69706B6B6E6F7174726E6B7274747671736E737979787874746F7178736E70706C6E73
7570786E78747C7571796E7C757E79797D7F7F7F767C767980787E707C7C79807A7C807A
85787A7B81817C7E79807C83847D898584838C80808D8685888C8E7F8890828489848784
88898884878E8A918B96888D8B888E91918E8B938B8B919690938A949490968E8F909C9C
979C919B999B9E9BA0A1999DA59B9EA09CA19C9BA1A6A495A6A2A4A09FA0A3A3A8A4A4A0
A6A9A9A6A4ABA8ABA3A9ABA8A4A9AAA4AEA6A6ACA6A8B1ADACA9ADA4ADADA7ACABAAB6A7
AFAEACB4B0AFA6ACABAAB2B3B0A8AEACAEA7ABAEA8A9A0ACA1A7A1A6A2AAA9A6A7AEA8AC
A39BA6A6A8A0A09EA4A49CAAA59EA49D969F9F9F969E9B96979E959C9A979E989D9B9998
8C9698919691918D908C90938E8E8D8C87908A94898E868C868880888486828383828983
7786807E7F7E83857982787F7A78747C7D8180797678767574746E737274717176787170
717873717672707670696B706C706C716B696C6F6C6B706D696C696B6A6B6B696B666666
6168636C61686964655D6C666867605F666164655E6759695D605C5966645E5F61625B64
6260565F5C5B5D646360625C6660605B5E5C5C5C63595F56565B61595F60595B5B595E53
5A565B5B5C5B58A400000000000000000000000000000000000000000000000000000000
000000000000000000000000
DF716C666B6C69656E676A6766676B6E6967706A686A6B73716B6B6A66626C67686B696A
716C6D696E6E786579707275736973667879737877767979747773736E6F6E7370707174
726C707B747B74757871757A78787E807F7F777F7C7C7E7B787B737E7977837B7C7A7E7E
81787D78787B7A7E8183837C7E837C8181828381808B838989848C8984858689808A8C82
8586848487878586898E838D8B8E8E838E938E938E95918C8F89919494969391979E919D
949B90969F9696999B9E9E9B919BA1999AA8A3A19D9E9D99A595A2A49F999FA0A4A0A4AB
A9A1A3AAA3A9AFA6A3A2ABA2A8A8A7A9ABA9A2AFABA3A5ACABB0AAA9B2B1AFADABB0B1AB
B1A4B0ACAFAAA8AAAEACADA8ACAEAEA9B4B1ACAAA2A0A6A9A3AEA7A9AFA5A19F9EA1A7AA
9DA3A4A2A79C9C9F9B9A9699A197A094A49B94A0A09999A4A09C989C9E9490988E9E989E
93979399919C918E9391938B8B898D8E8F8E838C84898F8E878889838B818987857F827E
8086818685827C8183797E787C70807978787878768176737876787D7A7C75A184737A6E
71767269717873736E6D6E6E69686B6C6C70697369686C6B696A6C6C6669666666696966
666366686668686363605F6664646165606562585E56635F625E5E5E6165646261615C6B
5F5B5E656562615F64565F55645B5C5F56615B5D5B5C5E605C5B58545C6259595C585E58
5E53575A585553AB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E96368656463716E68696663706E686B6B70726B666B7173696B6C696D7066666E696A70
6D6D6E6B707373666D766E6D757C7073707B727977737B717A74736D6D716B7374747871
71716E6E74797476747B76766B787A7A8177797C807A7875787B817B7B7B82827C7B7C78
78797C7C7C7D7D7A7C7C85798380847B80838B7E838B838B878689888789868687849081
8E898888828483818389938C8C88898684908C92888C91999991888C908C919196919395
99A1A29D949B989D9C9E9E969A9E9EA29999A1A2A19D9FA3A1A2A39F9EA3A0A8A2A2A7A2
AA9896A0A9A4A0A4A6AAABB0A2A1A6A0AFA8A6A6ABA8A6A7ABAAADAAA6A4AAA6AAB0ABAE
A6ACA9ACA4ABA6ACA6AFA3A3B1ADB3A9A0A1A4A1A4A7A8AAA9A6A3A3A6A59C9FA2A1A5A4
A19EA1A39E9FA299999E9C999E9EA1A19B9E9B9C949B9C98969596988E93A49493969999
9094919B96908D8E938C8E8C8988949B938C908E8B8D8B8084898B8B7E887F8389867C86
82807D797E797F7F757E80797E807979737C7E797E777A7D767373767872727171737075
736879796D6E6E737170746D6E6B686B667168696671666B6C6367656F6B636860706A62
6B645E6D6B66635F6A6863636B6260615C646A5B62695F6468645B5A65655E5E60586461
5C685C605B615F5C5D605C60615B63605E5E5B615D595C5C5D595E5C5755575A635C5E5F
53585858555856A900000000000000000000000000000000000000000000000000000000
000000000000000000000000
DA686A6766706A686B716E66686D6C6A7267706869686B666B6F6D696C6D706E6A6C6E69
6C6A6B746F6F7367696C6D6871716C7676787676797775756F7177756F726B737473766E
6B6F716E777674787B707A717D7774797B7E7879757B76807C7A7A7B77787B7E7A717984
80797E747B7C7B797C817E85848479807B7C8680848886868E8E84828380867F90868483
888188838283858B89888C8E8983878F8C939389898E8C9090928A8D95978F9998969091
969997A09996949C9D8D98959D9B99999EA59798A09E9B96A5A3A1999C9CA8A1A2A3A1A0
A69FA2A4A0A1A8A79FA4A5A7A9B4A1A1A9AEA6A8AAA5A9A9A1A9AAABAEA2A8ACA8A9A6AF
AAA8ADA4A9A4A9AAA5ADAAABA6A1A1A4B4A8ACACA9A69FA3A2A1A0A4A2A1A6A5A29B9BA3
A09C9CA3A1989B98A19A9C989E989999A197979D98979E9698939A9C9098949896969489
8C8F91888A8E968E8C848C918B968B8C848D9190888E887E8584888685857F7E8C868584
7F848183808078807C7D7C7D7479787D7778787979797674717875787673717075797671
7872717471746A706B706B6E6E66696C5B5E636C6F70666A646A6E696768686E676E6466
64665E64686568695E5A646663656464616363646164645E61635D625C636A6464655E61
615E5F5C6460595F5764625E605C5B5A5A5D605B595A645B5E5C545B5C535956535F5359
575A5E5B61565CA200000000000000000000000000000000000000000000000000000000
000000000000000000000000
DF7166686960716E637166636C6B71706B6C707169686E6A69716B706A6F6F6F6D6C716B
6E6C74696F6B656A7470747170696E707473766F76767179746D76707075736E6E727670
6D7973707B7873716E75747D747D787B7B78757B84757E7D76767A7671747A767E788174
7E758578787979797A807B7F80837E8181827E7F808186857F898480848986847E808481
827D7C84848A8984868C95948D8F8C8B8E919093908B898E8B8B928F8E909596928C9990
928E99959C919793A0909E9493A09C9F98969EA5A699A19CA19BA1A29EA09BA49DA9A5A2
999C9B9CA3A4A2A0A5A4AEA6A3A6A1A5ABA0A9A8A9A39DA4A8B09BA6A3ADA9A6A8A6A1AB
A8ADA0A3AAAFA3ACAEA5A1A4A0A7A3A1A3A4A1A2A2A49FA89EA4A29E9EA9AC9EA6A3A199
A3A6A39C9B99A19B989D9E9A9A9698999CA3979CA4949C90989896999D97949698919798
9090918C978D95909190908D97908C8E88948B908E9086948C8586818B8189828384837F
8A7D877C83847E837A787A857E767C7B7B7E7973738073757F747774737470766E787175
6E736D75716F6D716B736B6E6D736669696967646E68656C6B6C6467666B69605D6A636B
646B5D636B5B5C5C646066645D6063646A616663655C6166655E625E615A5F5C5C606060
6661645A5E605E5B5B5E585B615B5E64615F5F645E605C585B61525A5C54585E605D585C
565D585B565558AD00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E3686A6468676066766B696B6C6F6E6C6E676E6B6C696C706E6E6D6F6A6D6D6C71766F72
71746B6A6B6E736C6D726B746F78766E7B747174787070746F736E71766E79736D767477
7B70717274717371747977767878787B77857C76767B787A797D737C7E797B7F8078807C
7E7D7B7978787B75887F7E7A7D848084887E7E7C8082838686818783867E7D7C7B7E8281
88848587808891878A8B818B8E98898C9691868D8D92908E91948E94949090898D969B98
8E94919897948F91969C988E969B9D98979A979BA69D9C96A4A09D9EA4A6A499A4A3A49E
A8A6A5A0A1A1A9ABA29AA3A3A3A6A0A6A4A9A8A1A5A4AAACA8A1A7A4A79EA1A6A8A8A4A8
9EAAABB1AC9EA4A4ADA4A1A1A5A6A4A6ABA19D9F9EA4999E9BA1A8A49A9EA39C9DA19A9E
A69E9FA5A1A39F9797999C99999C99999998999C9B919C96989398959C959194908C948F
9096918E948E8D908F8C9189898C968B8F808C91888384888789878A8984838580847F81
82807A848479757E7A7F7B7D80797C726D7A7474767776767173737278716B6F74706D6D
71667173717069716C696E6B726B696B6A6A6C6C6E6D6C6F6966686E666B67696271666B
6B656464636765605E6161616161616261646261615C63606363675E6B5E605F63606161
5C5E5E595C5E605A605E645B5F5E60615D64605B5C546350605A5C575E58596059595D5A
5856515B5E5E5BAB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E96B6A68676C666964686F696C6C706C69716B6B64716B736E72716E716F70776E6B706E
697070706A72766C6E6D716E706A726C726E6E7177746E747170706E6E717973706E7070
70727170767776717B737571757774787A707B71798074767D7B7E7A7679827E807C767F
7A7C8080837A7F7C7E89807E797B747D84818586868389888986878487837D837C818483
818683808388898889858990928F8D928A8D8B908D8E898E8C939492918C9B9790998C92
8C9298979091939394949E999D989693949C9B999C9D9BA0A39C9FAB9F95989B9D979FA3
9D9E999C9DA19BA4A3A9A3A3A8A1A4A5A3A89DAEA3A6AAA3A79EA1A2A1A4A4ABA3A1A4A9
AAA3A4A8A8AAA3A0A4A6A1A1A6A19EA8A4A2AEA8A29BA19EA6A4A49D9EA2A6A0A6A0A0A1
A39C9696999C9B9A9D9B9E9E96989F9C9A9C9A918B969A93999696969A96929591908F8F
918F97938D9490918C92848D8C908D89918E898689908B898B89838B8A7E858181828480
817E82817F7C807976797A7874767774797975797373707179777474767675706E727071
6A6C716870727370696E6C6967666D78686D6C7674666F68686768696864696A69656E64
646564636B64596A666964666B645E69605F6460646363605C5F5B5D64615D595B565E5F
6162606264615B6161645C5860595C5A5E5B5C615B5D595B5761595B5C5B5B5C58595157
55565F5858564FAB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E06866666568656A68685B636B666C6B716B716A7173716F7176747473736F7670736872
71746E72707467706A746E736F7173716B766C707070726970717773767671706B6D7370
6F6D6E716C6970767176797677797D757475757478767878787A7B7B777B78787B7D767F
7C787D797D797C7E817D7F788783867C837F867F83838B83847E7B897C7B7B8481838985
85858383818181888485839088888C938C898C8D9084899390948F8F8E8E8E908C8D9091
949B9A95989B949497A095939596959592979DA0A2959B99A0A1A09CA8A1A4A1A69F9A9C
A29D9FA49C9BA4A0A4A29EA4A3A39E9E9BA3A0A4A3A4A496A199A5A3AC9EA69EA5ACAB99
A4A8A6A9A2A3ABA3A4A1A8A69BA5A5A09EA79CA8A2A4A1A0A29AA19D9C9AA29DA6A0A1A2
99A1A09BA19F9B989AA7989BA09F999E989794989A9B94A0939795998C9993919589928D
908C8E8A8E8B8B90918E8E8B908E888D9183858B8F8D8888898483888486868287847D80
81807B7E847D817C7D847E7B7A767D817379747777747071757673746D73736E726B696F
706A75746B6D6E7271715E736C736D6772676769636E6F63636C65606368686661636C67
666B6564646166685E646B60656360636A5B6161645E60635E6065685A655F605F5C6063
5B63605D5C5A5F60625360596165606960625E5B585C5658595B5955565E5859555B5E59
5F5E5E59585358A700000000000000000000000000000000000000000000000000000000
000000000000000000000000
E3616B666C646C676B6F6666706B696D7077706E7273737574787C6D7874767274696A6E
6969706D686A69726D6B7579707171706D716F6F706E706E6E6F71746A6B6E7378757370
6D73746B72757A7E7072747E757976747D75747C787475797C787D777B797E7F79767875
7C7B797A737D7C7A7B807E7B7E7C7C807F79857F8788788583817E818580878181898375
7B84828B807E828687868981868B8D8F898B89989091928E9190968E91918D91968B8D93
9290948E94999C94959696989C939B99979D9B999C989B9D9EA291A19C97A1A1A39B9C9E
9EAAA0A49CA29CA4A19AA09EA1A1A5A79FA9A4939BA7A1A49CA0A2A09CA09AA3A39CA8A3
A1A9A4A4A09C9C9EA3A0A1A6A0A2ABA19F9BA2969FA49B9CA69DA2A89C96A5A3A4A499A1
97929B9B9B9C99989E9B9DA0999B9C9B9A9D989C9B99939197938A9494928D96938C9191
8D8C94928D90938E89868889868E8290848B8E90838A8185848883867E85857E7C81817C
80837E7C807980797C737A73747372767C757A807A747B78737776727172717979736D70
72776B736F6E6D75706F62696766686867666C6F70666B68656868646B646967666C6767
69606068666C6662636163615D64635B6366635C656664605963645C6061665C6360595E
5A606366685C58605C5D635C635F615B575C5D5A5C5E5E64605D5A5A5B59605A5C5B555B
54515454585456A600000000000000000000000000000000000000000000000000000000
000000000000000000000000
E36961686C69696F666466796B6C6E6C736C71797574737F7D7C78827F7B747370756E6C
68677369666C74706C7069736F706E75736E716D6F71776C6F75726E6F746D7071757172
7C6E717670737C7C767471797279707B7D70797370737777797678747B7D7E7B78798479
737B737A7379797C7579807C797F83787B797D7F87837E887C7E81828079757A81828183
848581837F838283837F87818D84888E8B918F9287908D8F8C95898C9688919191949294
86918F9399908C9794989A899394929998949495909C8F9C9FA09E9DA2A19D999EA09E9D
9EA0A0A4A29EA3A59DA3A19CA2A0A4A6A39AA2A2A0A0A4A1A4A4A3A0A4A4A5A0A4A8A0AC
A3A0A89E9BA4A4A1A0A4A19C9DA0A3A3A29AA1979C96A19C9993A0A09E9CA5A097A6A098
9EA09B9892989998909B96989C99989D949699948F94928C999A948E9690949093918A8B
9198918D8E8C878D898C8984878A818D888C878785858684897E83858683838280867A79
7D787C7C7C767C7A81797B7B7C6E717B70797479797775706C787571706E6F696F70717A
6B6C746E6D6E6F716C6E6A6B6B6E6C686B6E646C6D656D666A6A73666663676665646368
666363695D63666662695F646869606664655B635D5C66636358605B665F625C5E5B6356
6059535C585C61605F60595B5663685C5F5D5D6058585B5A5A5D5C5B5D5D58565E5B6153
57585E5C565650A500000000000000000000000000000000000000000000000000000000
000000000000000000000000
E467686B6B6C6C66636C686567697073727673757E7E8086888E8C887D7D737970766C73
6E6B706E6F7470706F6B6E7170736A6B70696B7273736C72726B71736F7470707B6F6B73
6C6B7474747C7973737874797873737476707A78787C74757976757B7F757E8078777676
7C787B787D7F767D7C7F7C7E7E7C747C80778085858284817E83807D81837B80867D8979
848480858682818A87877F828C8A93898E8D8D908C838A8B8B908C939181868C8E909290
959791A08C939496979396A095949B90939F9697969E9099969B9B9597A3999B9BA1989B
9E999E9BA19F9BA09E9AA6A3A1A0A0999FA39D98A5A09D9FA5A4A0A59C9E9EA69E9CA5A0
A8A4A199ABA1A1A0A3A199A29B9B99A09AA0A89E9BA0A4A3A19B93A3999AA098A0A0A097
9D9599A3959A98A19A9B939694919994989493949198938E8F8C979093918C91948F898A
8A8D9090888B908988818D898A8B8C888A888B8E8A908888878C81848783808086797C7F
847D708376797B82767774767B757C7677777675707377766E6B757173766E7076687069
796B6C6E6A74686E6B6E686B666E6B6A656869656469626A706764686A6862656E696763
6B636960666D646D615B64696667645C606364625F585D61615E5B60605E615F5C5C5C62
5D6368605A605C5B5D5B5F59605C615F60645A5C545B60615C59595C5650565C605B595B
545454555C545B9F00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E1695064686D6C70666A6B686B676F6E7574747A88889099A6A8AB9C9B83837D72767473
666A676A6F78706E6C716E70736B7373716D6D6F73736B75767373646E6E777175717779
737071737C707278747178797475777E7874747279717277797A797773787A7E71837677
79747A747F797C8078797B747B7C80867F7680837C7C857C7F7B787A767D7B807A867B81
8187838489838182838188878C8B909188928B88918C8490889288888E898D8C8D90918F
8F86908E8E8B90938B8C8E999398939392969494939998A198949996999EA1969BA198A1
97A1999B9BA0999B9CA39E9C9E9D9A9E9E9AA1A39D9999A6A49D989CA19E9CA5A099A3A3
99A3AC9C9C9B9FA2A0A19D9A9BA09B999E9E97979CA0A79A9B9AA1A496A390969E9BA198
9B9C9F9E999994989E9B989496A19E969593969B94939091939197908A89888C8E888C90
8E92888F908F898B8B878A8C82868B898C8687818C858687808881888189847B7F7E8182
797F7F737E807D858378787C7C776E747871787B756E71747875706F746871736D736F6E
6D686B696C706B6C696E6A6D6B666E6F726B69656666636666635F6C6C6969636B62616F
65686967616164645C5C6167666662685C6060615C68635B5F5E5C6061605B5E5C64575C
615C60615A5B635C685B60645B605B63605A5B5B5C6258595B61566058635660555B5759
605E58555B5754A300000000000000000000000000000000000000000000000000000000
000000000000000000000000
DD6A65656A64666971696E726469697076748283819DA7BBC6DCD8C3B3988C86707B7373
6C6D706B64716F706A71726C7076686D696E69696C6E70717071727271716B7071717271
6B6A716E7175757471717970737276727477757771737878707575787C73787576797C72
7D7B7A79787C88737D737C7980827B767E7E80837C81817E817D7F817E817B768484867D
7E818287837F81838084878685858F938E8C90908B8D818886878B8E91908C8493908E90
8B848A898E9089938C979098929E96948EA19C9E9B999B999B969A9E98979C989999A099
9EA1999998989E969D9B929896A0A09A989EA09DA3A5929299A39C9FA19C9C9C9B97A89E
9D999FA1A39B9CA09E9C9E9B9CA49A9BA09B989D9D9E97979F9B9C949C9BA29B9C99949A
9C99919F9C9C9A94959B95989A94999592969996948E989193968E8B9090948D8E8C8A86
8A848A85888E8D888C8488848B88888C7E87888B8A868685797D7E8181807B838683787F
868082797E7C7D777A7C7B7C73787476747A7171797670756D7070716E6D746B6E73736A
6C716E6C706B7066686E64696968706A656861687065686A646460695F63636266666164
6669605B645D67615D5362605F5E6367636559666158665F635C645E5E5E595E5F566463
6264635E5D5F6167595F5D5F6154616260615E56605F5960565C5F5858585B5C5E5E565B
595E5F59585950B000000000000000000000000000000000000000000000000000000000
000000000000000000000000
E96D696B6C616A666E6B6C6E6C6E696C7B79828B9AB4CFF1FFFFFFFFE0C0A1897E737473
707172656A666E686B6C6E6D7063706E6C7273707174696C71756E747870736E6E78746C
76706F747374787973737575747173757E747D79767A767B7B7B767978717F76747C7976
78747F737B73727B7B75747975777B79767E7A817E83847F7E7D7A787B787E7C7D7B8384
838487837D7C7C807E7C867B8E898C908E8988918C8C8B8A8990878A8689868A89838B85
9287898B939590938E969195969594949C9198959594959499989C939B909E91A4989A99
9693A49E9CA59D999F989D9B959B9C9896969A9C99A09FA7999CA0A29F9F9B9BA198A099
9C9CA699999C9B9CA09F9E9C999C9AA09EA4A19C9F9F9E949DA09B999198949CA19E9695
939899969393909E98989799999C9493928D96959B968E8D918C8C8F91928B8A948A8B8B
8C86919089878288868B888A8B84858E8C8B818B8B85847B817A7E817C87817F83807684
7C797E6F7B7F7F777B787876797E7673757175737773767072756E716C736E706E6E6E6A
706B686D7170676664657069686B716769676569646C736968696260676669666B68625F
6564646165665B666561696860625E60615C68636861685D5F63636668615F5E5E5D5B60
6158585E5E66645E6B606862635E555D5E5D5C595E605F5D595C5E585C5B5B615B585B53
5B5959575954559D00000000000000000000000000000000000000000000000000000000
000000000000000000000000
DC666663616C616B6868696F6F68757279808799AEDDFFFFFFFFFFFFFFE4B09981767372
71796B6C78726F686E6F6B6D666C6C6D6E736E6C716E6973726E7070776E77766C707371
6E717079737C7A7376797074787A7E737478777676737272787A7379767B7B777E71717D
7A7E7C747B7978747579767E7E7C7C797F7A767C77777F81837E7C777C7578757C838381
7E888084818081817F7E7B7B878C848D8989888B918492928F888B8A878B8E81848C8F88
8E898A88919688948D938C9390919390979C999997919799969A959B9898949B969A999A
989E9696949996929E9C9F9599A3999999979B9B97999899A09C9AA19B9D9FA19B9EA2A0
A09EA09E999795A199A3919E9996949A98989A9497999C97A19B9795999B9B9F96A09698
98949E9F9998959098999B98949399938C928D928E8F918D91918F8C918088898A848584
8F89888B84868E8E87898C8789818281848B808181838381837E868381827B837E7C827E
797A7E7E7479757972757B767E717673727478736B767073737A6E776F716A6F74687264
6765686F666B696A686A6F6B66636961696669696D66656568656C64646266675D615C6B
6260655E6463635D5C5F5F6362606A675566615E5D635F5C635E5A6161615F60625A5C66
5C5C5C595B5E5F6061635C615B61615E5E5E59595C5B5E5F5E5E5C565A58575860535151
5A565B56545B5BA900000000000000000000000000000000000000000000000000000000
000000000000000000000000
E16768646668696E696B6F6E6D78707179889BABD0FCFFFFFFFFFFFFFFFFC3A087847C76
716D6C72656E6D726864726A69656A6B746D72716F6970716B6E7471736E696F70707071
7173747670716F7B76717B7871737C7978797770767D7A74767C77797876757575767776
7B78797E7F737E7B797B7C747C7C7A807E8081848179898374797C7880837C7A7B7B7D7C
807C7C80828380788483838390878988848E928E888D868B89898C848D888887868E8E89
8D9190888C8A948F91938B8C90919390949196989A8E959A97939B91949EA0999698969F
9D9A9B95A191978F9C969398999B91A39C999CA09F9A9B999A9C9C98989AA3A298A09A9A
9D9D99989E9B9995968E9B93A29593969E9C9C969D9F96969B949E949B999A9095999191
979395929390969298969198979091969B9897948C9490948E8891898E8B8B8C9088918B
908D888B84948B8A8E888B838981848480848983887C808384828087847E7C867D7B7979
78807E7E797C7981807774736D78757B7974727174716E716E6E6F696E6D786A716F696B
6C74716B6D666A6C6668676A656A646A656D66626B6466645E65666560636661645C6864
58665E6662665E69666461605D686063636061616C626260635C5E63586062615955635E
5B5C6059645B63665E635C5F5D565C605D5D61586561665B6254575E5E59565C59525656
595C5553515755A800000000000000000000000000000000000000000000000000000000
000000000000000000000000
E369686C6C6D6B6969676969717371787C899FBBFAFFFFFFFFFFFFFFFFFFDA9B8F767B71
6E70756D716A756B6B6C71736E6C6C6F7067736C706C6F6E6E6E6F707173777278727170
717173747471737B7C74787273757071717C79716E70817A7E807C7C7C7B797F7A817C76
77847C7B7B7E7C7B747B7C7E797B80797B7E767E7B7C7C88787F76767478767E7980837D
80837984847E858580768181858E8C898A828E858487848D7E84858B8A8E8B8E9788848C
878E86888E86938E9391919395909093909898958D979097939594969A9C91969C9C9896
A2969E979D989C9899A09B959896918E95989A9C949C9E9AA1999E9199A09E9E9E969798
989B969B9E96999E9B99909B9699999D969399959E9B949C99988F9694969C9C97919C93
98908E96928696959496949498919192909194978C938A8F928F8E898B888E8985818889
83808E8C878A8A877E86868887808A8B8584847F81887F817D7A7B7D7C898181857C777C
7B807C7E797E747F76787A7070746F7074747174766E707170707174716B716E6C687070
736E6B696667626E685E616964636C6A68676E66686A6A696368636467655E686761695E
6364686566696C5E62705F636363605C5C635E595B62635C656259585E6259615B565E5B
61645A5D5B5F635D5959595C5C5E595C5B5A5E585D5F66685660635E545A5B585A575851
585D5B5E565859B000000000000000000000000000000000000000000000000000000000
000000000000000000000000
E0646569636C696C6969666E676A76798194A8D6FFFFFFFFFFFFFFFFFFFFD5A18D7E6F70
746D6D6E746F6C7270747073726B696A73746B6C7270786E6B6D707174746F70766C7171
7271767374707475747479717478797C717E7B6F797D7B7671797B767B74716E787C8779
72797A797C77777178787378797C7F7A837C777D7F84847A8281737A78797E7C7B83787E
80807C847E84787E7A7C7F80818788898984848286898B908E898D8B8889898986888689
8B8A8384838A8C949088968F8C9898919499999196979392949599959994949594979E92
9C9E9B91A09B999C9B9A9F9D958F99969B95999598949B959C8E98959E9B9D97989291A2
9B9897949F9B989B969E98989899929F9C9999989A999B909994949996999C9A9896969C
91918C8B8C8E949490968E99948E91919693918B8F98918C898995878787888B8D888E86
8B8F8D848C8E82858583908484878586858483828085897B837B8180867983768477767A
7B807C7C737C7E7C7B797675797274777373796F7D747B78746F7370716D6E6D786C716E
68696C6A706B676866696564666B616969666368686A726E666961626263616662636665
6165615E635F5B605F606761686164645F60606160625E635D6063616260595C5C5B6059
56605B615E5C5E616165595F63585D605D5A5C5E5E5E615C5C605A5C605C605B5C595B59
56565B59565751AD00000000000000000000000000000000000000000000000000000000
000000000000000000000000
DE68686C676C676C6D7066696E75757C8194B0E4FFFFFFFFFFFFFFFFFFFFCC9B867C7872
706C6C6E7370686E696B6E6E6B6E6E66736A747170716B6F6B71716B7073736D71747173
71726E707472747A71727572777E7B7A737478797271777B7875777178757B7B7C767B7D
797981837876777F7B70777B7985797C8081808089817E7A81787A7379767D7C7E847B86
807E8385817E7D817F808780848689868F8B84838189868486878A8B8387838C87948D8F
8B817F727D8B888B8C968C92928C938B96988C93989197919090949E9C9E9C9997999396
949496979B97959B94949C989191929796939599979E96979D9B909B98918F9C999B979C
9C94979C8E9196989B989891989C899993999C97988B939996979698948E898F9E929E90
9496998F8E949A8E9B8E9A959098968C9191938B918991918F888B8B8B8C898A81848F8E
868485938A81868C8B8686818683888785818382837B7E7F7E7C7F8176807C7C7C787778
76747C747E7D7B767476736770766C746B6E78747F73776E7174687673686B7074696E6C
6F6C6C686368676C63666B626B6460686665666C6D6563646B6D69636A69616766646168
655E706463636363686864615B635A61615E5B5D5C635D636161645D585B565C64625966
5B585C605F5F61615C5B63605D5C5E5C5B5B5B605C5B636061615C5D5E565F5C5E5B555A
5C59525B54545BAC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E56E62686461685F6B6B6C70707878758398B4E9FFFFFFFFFFFFFFFFFFF0AE998579727A
716E6B70696E6F747365696E696E69706D6C6C706E6E6D68696C726E6C7B70696F727271
6C747673757370746E73767070746E7776786F7576737073797E7378737878736E757F79
787E7679787D7B7973747E7D7788787C78787B7B7F8080817F7C797D736B7B838081807E
858683807E817B7E75798081888A8A8B87808E868A898A848B8689898F878A8980888A8B
8E89837F7F80898B898C938C8E958E8E8C8C95938D8B979B91999B949191969598969C99
9BA393989E939A9D9D948E9B9394989499969898929A909C969291909996999A98909894
919192979B949A989C9594929398958E949C98979995919491929496948C98949E959096
8E9390918F958F9896869294918E8D908E8B969190898E8D918D888F8B84868684908586
82878B8E86888981838A81848490898687847E787C847C80867F81807E80787F787C7C7A
7A79707B7C7B737776767B7079787674777679797276726E707366677171726E6B6C716C
6E6E636B6964696C6869636A5E6460696464626868616769666066625B6564646862635C
5E67636560606666635B685C645E686363605A605F6159605C606166605B5C5661625F59
5B68606060605C6268595C5A5A5C595C5B5E5E6261635B665E57575C5A5A5C5856525660
5D535B56535B589E00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E66B6964686C647170676B7870717B7D889EB5E5FFFFFFFFFFFFFFFFFFC9A48788816D72
6C6B746F6C6E706F6C6F6C6B6E676B71716A6B71706C6D6E6B686B716E6C766E70707B6E
6A717270727170797871786F7576757274777471787576757177767879797E7B777C7B76
78777476827673787F7C787B747E7B767B827C797D8079817E7C76757878767E7B7E8381
7E8380817E85797B7E7E7F8480839389898B8189807E88878B8B89848B8586887C8D928C
84878483888A889184918A9B938B939191969296909888968B94948F92969498909892A0
92999894999094968F959795959B99A3949F988F9791919091918F9C9A9B9A9896948E91
90989095919392949495969996979B969696959D949892969694998B94949494968D9894
948E8E928E8E918E938F909389918B8A92908689888D8D8F8E88898E8C8C85908F8C7F89
8E8B9086848484848784848481807B8E837C8579847E867E7B7A8081807582767C787F78
7B7D79767A867676757A767A7678736F757B797470716E736C6F736B6E6D66746B707873
6D6D68656B6E686B6869666B5C686469666365646065646B696968626961606966606560
616965695D6160676053635E6466576058645C63625F6160626162646265645E5C5F645C
5A5B585C61605E615E6060555E61595B555D60625B5E59605A5D5E545D5D565D595F5C5D
5C525C53565453A400000000000000000000000000000000000000000000000000000000
000000000000000000000000
E1636A6B6664626B6D6E6F746C6F76788B90B7E3FFFFFFFFFFFFFFFFE7BA9E8C7A777A74
736D6E70716C6C6D6C6D716C75666E6E6C696F6E7371747A716F736D71766971716E7073
6C76736C74737675717073796B75737976787C73747B707B7E7C787C747B767E7A7C807E
787D7A7B76787A7E797380717B747379777E7B7E7D737774767B73717779727B817A817C
837B7F767E797B77807F768183828C88868683838D8380848C8A89898C888F888B868188
898B88848A8A87858A8C90938A908D96949991939B93938F9094979991A0949696959C92
A1918E939A9391949A8E9099979E969B95998E989C959397958E948C98949C9598989195
8D969B91999A949C8F96989B949C98989BA09993989D9793949288949591939293969891
94968D8B938991898F8D8D969193948C91918B91858B888E888F8989868C898482847E86
80948A8B868481848B8386858086848878867C82828378817E7C82777D8277797678787C
7E7E797D7B75807874756F797879747473797075787B747272706E6A6A6C6E6C766D6B66
706D76686C6168686868646B686E636C65645E5F66606466656661636360666268646160
68625A6C6260625D60695C605D615B5F5A6160615F645E5D62695D6168615F5F5C5C5D5C
645B606560595F5B5C5A5C5E595E535A5B5B58665B625F5B63615655575B5B5C58615355
565258565C5858AB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D660646461646E6C6C69706B6E6E7176788EA5D8FFFFFFFFFFFFFFF8BE9988877B7C786D
696F70706E6973726E73696F6B686E6D716A6F6D75686C696B726C72786E6970716F7670
6E707171716E6E726E73747173727A75767874727B7370707B70777177777D7583857779
78797574757079747B7679717D807C757A787F8084827A847A757A757970787475767C7B
7A7C7A7D7B7B7C7B797E788381878088898385828C8B7C8882848B8981848A848C8C8B87
90868C808C878689888B8C89918C90919094939193929A8E98979294989A968C9B989597
A2939395999B92969190969099949B8E9698979B949C98928E91939B949494968E88949B
9A8B998F94969896949B8E93938B989E949692968E9890939693949093998E8E95909692
8B908F8B8E9190968E8F92948987909386908891908B88898688878B8A848B8B89868B84
897B89868487818184898B8688897B838888837E74827D7C7F8580748573807D81807F7E
76787B7974797B75776F7B7578797373726C787176706F76746C7179716C746973747266
686968696B706A6B6867686A6C68686669656B636362676669656863696962686364645E
665B6062666265606A5E5E625E6362645D63606160686459645C635C61605B5D66586056
595A5B605B5B5A5E615C5C5962545C605E605D586364565D5B615C5B56595B5C595F5959
585C6059565858A200000000000000000000000000000000000000000000000000000000
000000000000000000000000
E36C67666864646F68646C686B6F6E7981899EC1E6FFFFFFFFFFFAC8A38E8679736E7B67
6E69706E6D70736B636B6B6E67726F726F68716E6C6969726F706A66686870716D6D7070
6B6F6C6D7774767D6D6E6C72747473767A7576737078786F797A736F7C7F778084C97B7C
73787779797C7973747C7C7D76747D797B7788797C7880857B7F79757879787879747D7D
768078797D83807B80798383828184898883818A7C82818683898B888A8E8B81878B8590
898E888C8B8B878A8A89919191908D8C928C959393988C9489998D91989C9696918E9799
8D938D9797909497949498949492999798939393948892969B988E948F95909191949496
8F91949894979998909A9B9B97949C9D9E909591949B909189978E919494918691948C95
8E8E9496908A8C8C8B928E938E8F838F8E8A86888C8B878A847E89908F8986888688877E
898E8183817E88837F7E837F838080867E7E847D827B7C7E81747C7C7C788179767C777D
7E7E7877737576707879786C717476746E706D73716C6B6C747071707071736C6E696770
7165686270696A666F6F66696C6A6961675E695C6663676364666564615F5F6461645E68
6466606564626466616161645E5861636667615E63675A635C5E635E5B59615D605C5960
58595F605B5D61615E6264615F5E5E645C5857585B5E5E5E5B5E59615C57585B585B5F5C
5D554F58545754AB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
DC676A67666C6B63686B6C6F6D73717479879088BBD4E2EFE1D0BF9C8F887B75767A696F
6A636E666B70706C69686D746E696A6E6C756C706B6B6C6E676C716F6E6E717571737072
7870717276716E6B767070797573736E7C6C7876767075767D777B79787B7B7883747678
7B7C797E74726E73797979747370797D7E7C7E7E7A7C7F7D797F7973787A797E837F7E7E
7A7E7E7E81827B787E76828385818388888C898382878783877E8083897E858C858B928F
8E8A8691888A8B8B8E8E888C8B8E8D9094918C959091898E8D8C919396979399919C9A9D
8D8E93919490939790968C948990959698949391989591999B9093938E8C8D9492968E8C
9694919490979498998B919094988C90968C8E9B94949191908F8E949188938C96909695
919B8C908E898B9A92978F8E888483898F8B8587868B8C82808787828B88898C847C8186
8883897E8C8684817A8983808380818180817E7B78807A7B787D83767E80817982757978
71747579787779787473737874747676736E73766E71717774746F6F71707276666B716A
61646E6E6965706A666C6971686D68695F64605D5F6364666968626168685F636066615E
615C625C62645D6C665C6258645C655F635F5B5E5E61605C5E59645B635F615A5C635F60
5E5F5E5D5B5C5F615B60575C565E5D5C5E5F59635C595B5C5E585E5B5B58595E5957595D
565D5654565C57A200000000000000000000000000000000000000000000000000000000
000000000000000000000000
DE6E6661666E68646B646564726B68707C7E84919EA9AFB4AEA2978F8B78747976726871
68706C6C6C6C60706968656C666C6E6A6E686B6C6D706A6D7373677378616B6E736C6E6B
70696F697376776E6F7071747073747E757074747E7671716B767878787C7E7F7B767978
78737378747170797E7B7871767773797D7981797A7C7B7C787C78767C7E7C7C74767881
7880817F7983797E7E7E7E817B84838C837F898685848982878E848681868588848C828A
8B8A89838E8B8E878489889786878C8A908E849196969389948D8A9590909690968E8E91
969F9394938E9496968F969698908C969191928A8E94918E9093908E968C8E9392898F93
92919491908C94979091918C8C95908E90968B9E928E8E9498978F8B94918C8D91908B8D
968F8A89898D938B838D898C8E8C878B89878B858D848A87818C85838488818083898189
878885857B8180838382847C807E7F7D8080817C757879767C7B7D78787C747678737B75
797478736A72766B7B73767E757377726A7672747C6E71737174706C6F746466686C6367
696D696869656F6C6B6C6F68716A6E686562605E596E616A64665E656462605F6566675B
5E6465656166646360635D6362635863615F615964625A635C5A605C5C5E595D5763635C
585F5A5E5B615656575E605C585E595C5B58645B615F585E6058535F5F585C5456515B5B
595A5E555C5350AB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D46A676E6965666D60686C687168706F707375818890918B8D8990817E79767173706C6F
756A6D726F6B71666E6E696973686E6E6F6D746B6B646D6B6871756B687071707074696C
697672706E776E777074756E6F7871787670797274706F7679777A7879767A7780767C7B
7D797F747374757B7B78777976767D7F807C7A8078767F7980817A74797C8180797D807E
7E7E7B7A777C777B7A8183808081838682848689888D8B86898C8A8A848D8B8C82818787
898B8E8886868E8489948C8B8B8E8C938E8E92848C8A8E908C918D91948C8F8E8F988D8B
8F8E9196939690978F8D969497968E89909391958B93929786968F90948E938E88999495
968C94958C91939C92949197919191908F9291939292909595998C8890998D93988C8B91
8F909283938D8A8E8E89848C90898B888B8C898B8286898588878A8881898485868C8E7D
7C838680847B7B81837F7E7C8279837E83798184837E7C777B79767D7F7A7C7E7A747679
7E717873777772787077796E7376757171706D72716E726E6E6E71756C746B6C6E666869
6B6868636A6971706869696B697063696B6567686063686C6A6C6A636968666660646766
60615E6465686669636263625E61645E645B5E5E605B5860645564605A5B5658615B575A
5A595D605B5E5E5C5E595A5F57605D58565F5D655C6162545D5C5F535C5E5C5F575C5E5E
595E5B6061585CA900000000000000000000000000000000000000000000000000000000
000000000000000000000000
CD6C66666E666A6E6C6B666A6468706C6B6D797678817C5879797F79777073696E6D7176
70696A72716A7070696B6C717769716B6B6E6E6B6B706D6C6F73746C70716C67706E736C
76736E717576726F7F76716B707970747671767572747078757E76737371767B766F7375
767A7671767B75767478757C7C707A7B7A7A797C7780797C78787978797C7878797B7D76
7B7B797C79777D797C83847B837C817C86838689877C827F8B898984898690898B868889
868891908A8C8B8F869084938E8C908C8E909188898B91938B928D92928C8C8B96919692
8F948D948B978E968D8A958D8D918C959A97968E928991988D98928B8D91949094948A91
948D9099918E9190968C94908E91939C9393949E8B948D8E93948B8F8F8A9B8B84949891
95928D8A8D8C8C8E8C898A8B87808B948C8B8B8B888B858281868388848C859083888786
80847C808286847D7B808081837E837E817882807A79798079797B7D837979737C747C7A
7976797475737873767974746F737371777475756C6A7074786C696C706F70736C6F6963
69696763696A65676666716965716A68636C6663666167656466645F65646A6868676961
6463696463676259646A62606361605B595D6061635B5D635B615C5C63605C5B61645D5E
5960606058605A5D585C6255595C5E626061595F6560585A5D595E5B535F565659565B5A
5A5E585D585453A600000000000000000000000000000000000000000000000000000000
000000000000000000000000
D56068636066696B676662696868686A736C6E7471757B7C71777B75706E6971646E696D
706E676A6871706C747169706D6669696B6B696E6D736C6C6E6E71747170727170687272
726E6B716E76737870766E7074767872727A7376717571797378756F777B7A7372797874
73767B7D7A787B787B7B78797C7D7B847A7A78797E8582797C7E797A7B757D73807D7B7B
857F848081857B7E8579897A8480818684857F8B8783888181848A8C8983828788868487
898B8F7E848E90898E82898F91908F8694938C908A8E91908E929A938C8F8F9790898B89
908E8F8B8C8C91938C939190949E918C90839591898F93908E898B9189878B908A8E9096
939390898C978C908C95939194919391918C8C98949591899395888F91948E8E928C938A
8C888B8D898588908C8A8D8C848B908A8987898A8E8F7E8786847F8386808381807E8581
8184848381888180817E847E7E887C7E7B817B7D7A7E7E7C7B7E7A7B797679767B7A727B
73787570757C727773787B73717473717273706C747171766E6D736D6D716B736F675C66
6D6965686A6A6B646467676C676669666A616461696361606663686863616062605C6260
6566615E6364645F5E5E645F5E615E5E6461635E696163645F605D64585D5C5F63605A60
5E58585A5B5A58545E585C5B5E59585B605C5E605959615A585E59585B565B535B5E5559
564E5356575656B100000000000000000000000000000000000000000000000000000000
000000000000000000000000
D47063696568666363686F6A6C6964736E6A706B6D7372766F6C7476737966716D6B6E6B
6E6D746C7168717171716873686E6E6E6E6B6C686B6B696B646C706969746B70726C6C72
74706D7078736D7476736C747E76746E6E747676716E7873796F7872747E72757C766E7B
786E78797A777873797278797978787A7D7C7B7E7E7E7E80817D7C7A7679747577777D7A
787D78807B7C817B7D837D80838C8A7D897E8680848C8B81868C8A868A89858886888787
888D8B868D8A8B898586888B948B848C9090918C908C8E8B8E978A908E8D8E8E938F8F90
8C908E9192918F968D8C8A9090908C89908B87858E938E938B8E9096978B8E898F8D958B
8C83968B9691909490938E8C8E8F93898C948F908E90939185898C8E909187918C8E9085
8B89888C868C8E8C848B8E8D8B8C858489808C897F84818D888185887E82808388878484
83857D8081837B83867E737F7E8383777F797C7D7B777C79797682767481807E6E7E7C79
7971787A6C7073767373757B7972707275786C7476696F6E73697176726A6B6B6E6A6F6D
6669695F62696A6A70636A6A63666963615C6362616468666666665F6A5E68636466665E
635E645F5F635E646363695B6162645C5E5E605E625A605C5D5A645E615F615E60595E5E
625458575955585752585660595C5F605B605E6059595B5C5B5D57615E605659605B5B58
5A59575B555A58AE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E168666C6863656F6161675F6D6964686C6C696C6E66736E6B68706F6B6A746C6C696566
6E666571676969676E716D6C6E6671676870686E71636D6E6C7373686472706E6971766C
71706B6C6C6C7671737274687271707973706E7172737676777C7478746D7471717E7872
73757D747B73787774777D79787B747B7B7A79777B797E7B787E7A7B7C7B77797E7B777E
7E7A7C787C7E797A79807C808081817E848680868483868689908B898885888C8A86898E
809183878B828C8C8E8A8C8A868B84919097888D90909491928C8C8E8A91828B8E8C8E8B
8D90918E908B899397998D898E8E9494908E8D8E8F888C868F898C888B918E8D998E938C
8E959596958E95949493909093949190928F8D908B909299918F898E8C8D898B8E8C8C96
908E8A8887898C89938C8A89898684848D89888B9081848486838181827D7F767E817684
81818B848183827C7E7E7A817C8186807C7C7C8079787D7E797B797D7873757578767A7B
78747B767970717274737370767673736F6E6C6E6E716F75706D74726E6F6C6C6D696A67
676762636861636A676E68666E695B616460606661675D616B62626569666064645E6866
6160666865615B6264695F655F5F63645B5B585E645E595A625D5A63625D605C645B5B68
59605B5658565659585A5E5B57595B5C5A5E5F59635F5D58645C5F5A5C5C5A6058595B59
595D5458585559A700000000000000000000000000000000000000000000000000000000
000000000000000000000000
DC6861636468656B617266706969676F71646D6A6B6E6A686A706B73686A706B6E6B6968
74666E666C6B766E71646C666C706E6D6B6B6A69646D716D746A6C73746E706869707171
6C706E6C70696D6D6970746B6E7873767272747376777478757076727676727C78757679
707479767C767B77807976767578747A7C767B79747C79707E867884797E79787B7C7678
797B7C787F7D807B79867E8B7F818184808383828081878990878B899085888B8188898A
888683898E87848E888B908B8B86908C888F8C888F948B8A908F88868B908E928F8F8694
9189918E95898F949194938B8B948B988B8F8E94938D888C86908E8B898D868E8C918593
938B8F89918F8D908B8E8E8F8C8F8C8E8C93968B96908E8E898C8691898D8B868C898D91
8A91888A88898B8C888F8A838E8787888C8087878782877E808A867C7E837C8887868681
83838684857A7F7F8483818080787C83787E75807A747676787771787C76797B7B76777B
7A7C727773737473766F747971747C716E7571737370737070717A72736B7173706E706B
695E6B6C686A67686660636F67645B60676664686A6164666A6463695A616462715C6160
6761626366635D666064635B62615C615F685C665D5C5B6464595A625D5A5C5F5D605F5E
5E5C5C5D625C5C59595D5E5C5C5F56595E5C5B635A565C5B5A595E5C5F565C52595D574F
5C5A5D5451565BAE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D65D6763686E686968686869686A686B6B666067686C716E706E6E6C6C6E6E6A68706B69
66656C6B636F69686B6B6B70727265626F71696F6E706C6C716D70676E736E6C736B6B73
6E747173707566746C67737472747679676E78777974747476747373797671746E757476
76797974738171757978747E7B7576817C7D7E71797C767B76817A787B7C817F7D7B7E7B
7978837B7B797F8083827A7E7D838686828083858483838A86928C848686868487848A84
808C888184838488929089868D9087908F938E968B94908688898F8C8E8A899190918B8F
8E8F8E918B9090888E8E8E90939196918C868B8A9390988C95898C909389938E8D8D8B8C
969597938F8E8B8E968E9097978D938B8C8990928C9C8E908C958A8C8C86948B8B8C8887
8B858C908586838387887E928A88818A89898B858389828E8583837F817B808081818281
7E867E8478838480847B827F808279818076827E7E7B777B797879767C7470737077737C
7077767572766F7B757A797C6A716D716E6A6E7372736E706F70696A70696D6E69656E6D
68696663676769636C60665E666467665A6666635F6968666968646B615B68615C615A64
60636661606664645D6B595C6260615858665C5C5F5E5E615E58595E615D60696461585E
62615A595B5B53595B575C5B595B5E525D58565E645C5C5C5B5B535F605F5C5E59585958
5C5A58595E5254AA00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D16A6465646968646E6E686460646B6A696B6E71676B67696A706B6B6A6D6B6F69616A68
686F686572696B6C6E686A6A70716F6771606B6E6D6C7276736C69706974776C71706F6E
736F6C7C727574736F71786F7D706F7472757375767671727D797674766D707979717B79
76767373747874777776747472747381777D777C79797D777B71807C817A747C787E7B78
73838077797F7B797B807B7F807B8585867E8388898486878888888983858C84848C817D
8085838A8A8B868B89858489928685958A8E8D848B908F8E908B8C8C888A8A8E90908890
8F948C8A8C8B8B908F8D90848A858A8E8C8A8C948B83888789938E8E8D8D8991978D8883
8B89908A8C938E8A8B8A8E908E8F8E8B8B898D93949392918C898C8F8690888886888A8E
83858C83878C9189889287808A808885898C878983898384857B81857B7E8C867E7C7B76
7C7B7A81837A7C80787B827D7C8379797A7B81807B7B7E7A7A7C767578797C737B76787B
7975787572767379747570757372737379706E6F6E706C6E716877706C736E6967686869
685C69626466606464696063666B635D61666C69616466616264636066666665695F6362
605D61636A6461615F62695E5E656162615C5E5F5B5E5F5A63595B64615C5D615C56615C
585663595C5C605D5C5E60615A5F5B5E5C58595E5E5C605659595E5B5D565A5C5A5C5B60
56585B56545755A500000000000000000000000000000000000000000000000000000000
000000000000000000000000
DD665D646966656966625E63686868656B65696B6B666E6E6667706D706B6A646B6C6E68
6C677068676B6C696B706E716C6D6D706A656D6A706C6A70716D676B716E72706E6E7175
6E786C73727771746B70716F776E707173717074747973756E7875767A78767771727076
737176706F73797F7675797E7471787875797B737975797E7B7E7674787B7C78787A7874
7A737C7B817A81797C817E808183807F8982807E84888178888B88808684868487858784
83847F8386888E8E8788888F878C8B7B91888B8E8B8886898491898B8C868D89898D898A
9090918C8B8B948F8C887E8391848A87858F90868B879086898A8B91838C8488898B919C
8C938B918E9192898C90898F888E86918E8C89909191928B899086888E9084838B898A8E
8080888C858C86868884848287848B878A8889848786877E84897681837F7E7E82857D7E
7D7F807A7A7D7C817E7B817E80797A7E7B7D737979737C7979737173706D767C76787774
747275797370766D787474787074767B7174737173707271706D73746E6D6E6D716E6B73
666663666A69636E625E5E6467645E646A676B635F6B6763666564666A615F64656A6362
635B5D5D635C62645B615B5E5C5E565E5D626064615B5E5D63615E626364615C5C5E5B61
5C5B5D5C5B5B58605E61605C5B61585E5C5C595C59615C56585B5E595C5660625D5B5658
5F58525654565FA600000000000000000000000000000000000000000000000000000000
000000000000000000000000
D8646367616B6B66636E696365636866666F696C63696A6A6C676C646D6F6C706C69686A
67686C696E68686A6D716C676A6C69626C6E6C6C6D6C6C6E6F796F6A6B6B696C766F7870
6E7378706D756C706C746E6E757070737070707075727271747B73777B74797674716C77
757174737779787E7579767476777E7D7B756C7B767D7F7C7C797E7F7979797679817E78
817C7C7C7B7B787D86817E7B88898479848181877D83867E8686888B8B8D89828488838A
80878881838D8489858891898A8990888D8C808D8388868D8F918F928C8C8A8989918693
93888F8B93888A898C878A8E8B8882868C898B838A8B8A8B888680898D8C91848E838C88
888C8D8892878F8D8B8F8990908D988D89878488887E8B888E8E91888984838C858D8686
838887868A7E89838993858A8184888C86868388838883847E817E7C7B817C83817C8178
817E84847B7584817A7C777B7C7E837E7879827C7977707C78797E7C7C76737871767875
76787B78767371757373777876706E75736F6F717374707173716D6F696E73716A6C6D6C
6C6969666B616569636C6360696265646768625A65636B696464616661656163685F5A60
665E64635E615E5A6468605D5E5F64635E64615F5E605D615E63605C5C635E635D595E63
5A5B5B595B585E5F5C585A61605B5F5E5B5F5C5B57665A5D595A5B5D5A5C5B595C5A6156
595D595E595753A800000000000000000000000000000000000000000000000000000000
000000000000000000000000
E0616663686369646065666A636764636C676370676A646B686D64666E6C686B6A696871
6B666C6D666D6B686C6D6A696C6E6A6E6668666C6E71656C71726C716F7172716F6F716B
6E6D737171756B736C737274716A6E77736E78707371646C70707677747478797B757076
7378777B7578757E6E707A78797877747B7675757B79837D767C77797E7F807B81747B81
7C8078847A807D7F817B8084887E84818179818686848785848984867C81848C8B848480
8484827F82838982838E8688838A8B888689898B938C908B858E888B8886908D8D8B8B91
8B8B88938988888F8B8E838985888B84837C837F847A7C87778480837F8389848C898D8D
89888889938A8F889393938395888A8F8394868B8A908C8D8A8689848E8E8B8489868387
8B838384848A8488838482808C848489888B8188807E867D80868083868380807A848079
837B7F82877C7B7B7D747B7A7384788078767C7C7B7E7E7E7C78797C7D7E7475797A7880
7B7B7673766B79767A6E707876767B6D766C746C7471736C70766E706E696666706A7168
6C6F6B63616961636B69646B65665F6663665D6B6A666269695E655E6267646762666063
67615A61625E5E60695E6361635E675C606960616864675C60605F54605C6364655D5356
5B595C54566659595A61615959635C5F575B5E615E605D605B5C60595C5E5C5A5C5B575E
5E515C59565058B000000000000000000000000000000000000000000000000000000000
000000000000000000000000
D967646A626C696568605E65666868606E676B656868666C656366736B68696E6E6C6B6E
6C71706A666A696B70696F706B6667696B6B6C6F706E696C6E6C6F6E717171707170746C
686A78747470756A746D706B7274737376747771717671687371747177787476727C7675
78747C75717476796C75797E767775817C7B807B7479797A7A757B717A787A837C7C7C7B
8479787C808178787C827C7B7E867E808285827C80877F838D8981838386817E8384838B
838783888C83848B968687868B8B898D8C93878C88898E8B87858981899086908C918483
86898983898A8B9983818684847E7E847E7B797879777B7B75757D78868184847E808785
82848C7C8C8D8B8F8988898E908B898684858B868885868589848C8A898788848884887E
89828B9088888986898988848786848183887E8186888385838089827B8588827C7E817C
7B7B7C7E7C7C817E797C757E7B79747C747C76747672718276827B7C7B75747879727B7B
737376727B72766E737074747475727A717B7375747672726E76716C766F69736C696F6B
7065666760646863636F6D61675E67606869676E6D686C626569646366636664615A6366
5C606661635F626466605F63575F61615E616463635E61635D615E595B5D625A605D5C59
5B5E61665B5C5D5A5A605E5D645D6060635D58655956595661575B525B555C5C5C595B5C
57565A585E5859AB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
DA65615F64696261666E6868606868636B6B69646A6B646966696B6B70686869686E6D68
6F6B686E6B6C706E6C726E6B6A70716D716F6B6F736B746A6C6C696C6E6D706C72716E6E
6E6B7370746B74746C71736670726F6F76716E6B73747375787B7579767077756E747670
797876737B75737A76727980727973787B7B75747A74787B6E7C7C7D7E787F787E807B7A
807E7E8284807E8884797E807E8380868680818689817D8388838085857F8287847F7F88
8688868789848C868987868489838C868C8D848983858989808884868A8789838F85888B
82838F90888D8689828085837C80817C767670716D787775717B77767F7B78837C838688
8C89948C898F8E8C889085918C8786908E868888898C818C868687829088868C8B848180
878F8288868C798C878A88898880898B8A7E8483827C838B83837E7E80857A7F847B8183
7D7E797C7980838079817A79737C7B7E7A7C7878717885777B71747A7282767872747572
73747674736F70777572707075737072716E727B78687375757468736B736667616C6B70
68706B646E6F666A6569696F68636968606165626861645E66696266646562635F5B5664
6164676064635C6464625D5B585E6262615F5B5B5D685D6459665B5F575C61605E5E5B59
59585959575C615F605E6159556159595F5B646260605C5D5B5D595C56565A54595D5754
5955565459565CA800000000000000000000000000000000000000000000000000000000
000000000000000000000000
D4696268696663686D636362616668646869696C706668656770686366686C636C666C6B
6C6B676B6E676F7169706B656B716E68756E71686C736E69706A706E6B6D7471706E6F75
706C746A7170716F727374716E74746E706E706F73687471786E79757173707474757372
6E707A73736E75747676777176737A6F6E707773737A787377727C7374787B787B807879
797B797C817C7B797F7D8283847E7F79857A89817B84877C8480848884827C7C83838182
8790847D858A8587838684848C88858B8C838B86868396898E898688898B8B81838B8789
8B8B898993899189817F867E8274757570716B6866636A5F6A6F6B7277737D7982838482
848B8A908B8D8B8D8D89848788828F8988888B8989908890868890898689877F81887E7F
868580848E8389918C828582838A7F87858082827C807E838673817C8076868280887E78
76737B787C7678817E787B767C7C737D7579727B7473797976717C7173726F7371787672
6E7B74707374746E71737473766C686E73747473747C766E73746B6C6F706768706C696C
6C65676A6966666767686E69686969666466616760636363685E6464615F645C5E635F59
66615F655B5C635B68675F5E60675C5C675F66656162645F5B5E63635A6059635F5D565A
58545D60565758595E5D655C5C5C5D585B5C5C5E5F55595D5759615C6053595C5C585D57
5558585855535BAB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D86166636466666B686968606466626269656B62616B696A69636B686A6B6A6F686E6D68
6C66686F686C6E6F6C6B706C6B6E6B6874716A6B6C6B6C6C70736D707071726E6E717172
6E6B74666F797374707476727176716A6C697470747172747274767C7370767176797474
757C73796E7A75727C7373767E767779787975747C767D767B7F777976708174797D7880
7B78837E7C7D77807E7A87837B7A80817C7C7E7B7A8186857C7E788482847E8880828580
80888087867C8B8B82867B888E8385858689898D8B84838989858D928B8C84898A87808C
8E84898E88897E85887C817C74747274706C70646463576561616869676C74797F75847C
80858889888E9084878788888E8F8B87818E8D818A848689888B8D848888888B83908683
827F80868485808188828381818688837C8B85848284867B7E808179867E80838181807A
71867D7E767E7E7C767C7B767F767A7B7378787E7677777178787878727374797B787771
7776757C7C70717D74777474766B726E737A7879717A72736F727469706D716C676E6B69
7069656F6567676370696866616B6668695E686B606764646462625E5C635F6060665C63
6268646462645D605F5C605E6158605C5E675C64675B6463605860565C565E625E605C56
58536059535D5D5B595B565D61545B5A5F605C5B5A5B5D5859595E5B5760595B4E60565B
5E525B56595959A600000000000000000000000000000000000000000000000000000000
000000000000000000000000
D869626B7068636663616E606566685F666A686C625F6863726B6B6D656667686866636B
6C7168676D6B646C696E73716B6E6C6B696A716E696C6F6E716E72716C746C6E706C6F6C
70736870706B6B6C6C756C7474757273736E6E7372736C73706C6F747275737C73716F6E
77747470767479767772737678787A7578787C726F77747F767E817378787E777D857478
768281797E807E7B7A827A7E798280838182858686877A877B7B837D7D8581888381837E
8384877E8C7D828A8684888788878E848E8985808B8B8B86878882838B848A818B878985
8C898D86868384837C81797A717774646B6E60635B5E5A605B6860626C6C7A7C767E7B7C
80838983868C9091888184828C878886848B868B9086898088888480858184867E7F867E
847F7C83838A838689878B8382868288828680828984848179807B7C7B847E8381807E7E
79737B777879807E7E7E7B7B767D7F767571797B747B7670727670787C75737D75767878
797472727273737A737E717370716E747379737B7576737173666E696A6C6A6B696C6C6C
6D6D666C6C64616A6E68696F6663696E646965656B636760606063665C5F606866645E61
635E5B6060615F5B6860635D5D5C615D646865605E6359615A5E58615B5C59595E595B61
6063595B5C5C5E565E60615854595959565C5959575A585F59595958655C505658565E59
565E585A5C5255AA00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D066686166666666616B69666762666B6969666868666B6C6363696572666C6F6B6B6868
686D68656C6B66686C71706C6C6E7169706F6A6C70736A716C676A7571706B716B736C69
716B6F70746C73706B6B686B71736D70747273746E78706F747676707C797B7C6A747D76
6C6C806D717372737876736D7374747474767674787F77736F78797576797E7676797775
83818183787E837B8181777F8082767D817C787D7B7B7E837D8384867E7B7C7E7C808084
868383868482818D8481848488858E847D848A84847E878E84828587878B8A8D8C808884
86848E8882897F7B7B797B7A79736B716B636061605D6061635E6B68636D6E7676747A7F
837C84888A858D858D86838383898486848C8484908C8B8D8486817B8881848385838184
7E89848287818D838088848584817D84827E85817E8383857C847A79808382787A82827E
7A8179767C837B7879767B7B7A79747C76787F72767C78787570717676717E75716F7172
76716D7474737773706971707472738175717877737972687074706C7369706F706F6968
6C69646D6969696E6B6B666367636E696B686767646A6267616668666469646460615C62
60605E5E606364636963635B5A59645C61605C60695856615D6064615B595A63625C5E5A
53575E595F5E595B5C565F57595D565857565B5B605B5E5C5C5B5E5556575F5C54565557
595A575B535354AB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D1636364676669616968616363696663686469686A6868686567616B6C696B6469696868
6867666B64696E6E6C6C6E7169706D697070706E6F706E68677173676C6C716D6E6C7370
716E766D70706873736C7569766E74736E717070737D736B737371717A7772787A756E75
717679717376746E73707176756F7B787371737873777C747078777B79787A7B73787B78
80797478817E7F76737B7E7E7A787D84817D81837C867B7B797E7E7D7A7E7981807D8280
7B7F818C8B877D878A888686898987888484858A83848380887C8886897E8780888F867D
888384827F85807C7A7D7676746A716F68686966606C615F5E63686B606B726E76757C7C
7C88807E8483898884838A84887F897E898C84888E8C80868784897B8B86848F84838988
88817E887E877C7F8887817B7C868385888181847C817B88827F7876808482797D7D737E
7E767E847C767C777B7979767B7B767D7D7479757A7077737078797174747B6F6E757475
76767073717379706E726D71756E767274777B727F7477737073706B666E716B6D696B6D
6464666A6E64665E6C686E67656869636962666B65645D63666164686663616669626761
5E5C6363605D6068635D615961605A5C63616163655E5E6160595C595E615F5A60595855
595758635960545B5E58615C595E5D5C595A605E54565356595B5E5C5A57595857595451
5B565552524E57A200000000000000000000000000000000000000000000000000000000
000000000000000000000000
DB605E666660685E616C6865646B68686069646B6A6C6B666D69696C67656A6C6C6A6C6F
68726B687373666B6970696E6668686F706C6A72746B686B6A766F6A71696F6A6A626571
656E6C716C7273736E6D77697474707072736672706E7675766E6F7170756C7073787373
6F717472707171717276716C757170766E76797979746C7079746F7174727470847B7379
78717B737A7E797C777D797D837B7B807B7D7E7C748581807C81818586858281817C8179
7F848081838684828B828582828887858882808780888084848688838B86878587818A84
86857D837E847A78717676706B74756A6B6F696B6764676360676A67696E716D73787B78
7B818483828C838C86898484828B89888A838480848B83887E8783887B81808383848484
807E86868380848B83838083877B867E8486817E788089867D7D7B7C7D7C797D80797A77
7D767876757C7678788380767C73757A78737A7C70717373796E78747369737470746E6E
6E767470787370757473736E7471766E7876767972786E7371726B73717473716E706971
7066756C696A6C636A6C646C646C675C656C66636364666C6C6662655E6364645B695E5E
5C5C5E5B5F5D615D655E605F605F5C5D596163605C5D5C585F585B58595B585A585B5E5E
5B595D5B5A635B5C5B5C5E5E5C635F5060585956595C53565F54535956655C545C545760
5859555E5C565BAC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D06264656A6664686B6A68646B666E68676B696B655E62676B606C6964666A6869686D6E
6B686A68686A6B6E6666686D6A70706F6965747070696F6F6E6969706F6C7070716B716F
72706A676C6F686B69736B6D6F67686F706E706E716E7177777478757271707273787673
7170716B7374716A70696A77717C737070767370727A6E79787479797F7172757977797A
767A7B7C787C7F777D7A7E787C7C837E7C7E7E797B7B827D78757F7E81797F7C81787F7C
817C808086898886868C80868B89888485898B84848184848B7E84898A8B84868E88918D
848080808E827F7B7278757A78766C6B6A6C696B656D696A69716B6C6571666E736B7279
757B817D808E8A8C828C81838279848584848889868780848084868182808183877C837F
8187868486818280897B887A7E8484807C7E7C7E81808183797980818079817B797A7C79
70767F7B7B7C7C80797B78777470767E7B807A767B7B7479767576787478707878697470
71737376717377707674736F70736D74776E77747471707177726D68706B726B706E6F6B
6D6D6F666B6B686C68636C6964656C67646C6C66666F65615F616068596160645E60615F
5D615E6561645C62665F605D635E5A5E5B64615B5D5B5E5C5B5E5F60585B59615A5C5C5B
5F5C556051595C58555C6756595F5856555C5B5E545B5759635D5B5B58595A5453585854
5A5C5E59585359B100000000000000000000000000000000000000000000000000000000
000000000000000000000000
D65F6761626260696269696365676B66666967686B6868666C636C696C6C6569666B6566
696C6C6B6B6F696B6972646C6E6D6A6A6F716873696E686E6F6C66716A6970746B676E6F
69686C6E6B71706E6A6C6B71706C7173736E6B6E6E6E746E6F7C707B7A6B727879717271
71707774706E747270667070787B777874707E777371777A747A777979767E73797B707A
76767B7B747C797C7E7C81797A7E7C7C7C7981807D7885807C7B848383808084837E7B80
80828A868588898285848D8B84868586848A8A8C81848087848481848F8186857D917D8B
838C8080807E7C7B787278706F6C6D6C71686E70767270747073706E6B6A696E6C707074
777C8082867F7C8B838A8A8883808185838388868C888683807F8887867C7C8081837C8A
867E808285868286818E7E857E7D7B80868181807E7C7C7F83807D817B797B807B798080
7E7B79767E7F76717779787C7B73747878767B737B7D7A75767677716E6E717873717175
6B6E736F787370776C736B6E6E766C736B79746E707A6C736F787473706B6E6F68706D70
6C716E736A6C616C6369676072656C696A66666664616769665E635B625D61606362615E
635C6363665D5966615F62605E605B605E5F5C606163625B596059595E595958565D605B
595C585C615958605F5F60575C5C585855575E5C665E605957585C605B53585354545958
5A585855585659B300000000000000000000000000000000000000000000000000000000
000000000000000000000000
D0636463666B6268646469646668696D666464616B64626B636F6469686C6B696B6C6B64
68706869736A6D696968666F66686C6D6471686B746A72686E6D6F6B6C706A706C6B6C71
68706F73686F717167686C6C696D71716E7674736C6F717171747375716E716E75747379
7476737A796B737371757474767B73717B76777F8076797C787974747A77757C7F737C7E
797573797B7D75797779777D827E7F7C81867C787F84807C81787C7780827E7C817C8881
7F8681838884837E8683828388898486858B86867F837E818385818083838189868B8184
8987848282877976766F747370686671716E717972737376716C7068686A73716A737073
757D7E81897F8688818A86828188848184848884848484847C81838385807E8688818081
7A8E867A7E7B88857F7B827C7D807B83817E7C7F7E817E857C79797B77797A797B7F7B79
757B70787C757979737576777879717673767876747575747A77756F727179706E73737A
7172707373707378746E6E6E6D716F7672746D7371726C6F6D73746E6A7067686B6B6D6E
766B676C656D6B70686865676A6C6A6E69616962636666656962605D6464665D635F5C64
5D6162665F5B616160585E5B63615E60615659595E5E5A595F5A5C5E5F5D5E5A5B565E53
5E5954606162655B5E57565B5F625B515C54595A5A555A5A545E6056595E5D56635B5B53
635A5B535B545EA400000000000000000000000000000000000000000000000000000000
000000000000000000000000
CE616368646466646863656B6768606D6E64636B6967666A6B666964626566696F6C6A65
68676C6464706864686C726E706F686A6B6F686E6E6E68696F65666C736E6C716E677171
686569696C6E716A6865706870786D7171746E707274796A766F7673756E74777871736E
7273777B707776726D70757076747871777A78777A7874707173787472777D707A767775
767E6F76807574747A807879807A7B8478827C7C827C7E7C7B7D827A7F827C81847B8184
8481847D7D797B8C7E84807C868686888585888B7F7C8683818585807E837F888C878187
8B7E84887B83767578726C6E6E6A6E7566707676797B747279797374716E6D6E71687473
747C807E8581848C838783847D7E85808084838C8386898C8580868383807C817D7E8182
7E807C84867E81808182838281807D7B7E777A7E7C737F747C7B7D807E7B73797B7C7976
7B7C787E717B767B76717B7374707079787E6E7B73767979737370786D74797574737470
737273756B7370676C6874716E72717169766979717371717971756D69716E6C6E6E6D71
6B6C6B687670696E6C6B6B686868686F6366636468636361636060646165646268616665
5C635E61695F5E68565E615D59615D5C61615E5D5C5959595B5C5B5A5D565656595E5A5B
555E5A565F5D565B62595D5F595A585A525D575D5C605C5B545A575C5E5C535C5953585C
565C5059585456AB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D1635B676562626465666C6468616269626769656761696F666870626B6965636C697467
66686B6C636B65656B6B64696C6A6A6E6C6B6F6F6E6B6C6371706D6C7B6E6C686C696B6E
6872646E646B746B7168646C766971746A6873737274726F6F7671777074766E6A6E7270
7170696E70707478746A6C766A747079797B7878717C7277767974707B7376787B787972
72767978737874797879717C78757C787B7C7B7676797D7C7D83818180807C88747E8088
857C7C897E837E86808A7C837C8B898380868683877D898188808880867C847B7C7E8686
89888B8D797D78766B72706E686E6D6974706C6C707D787B7373736A6B6C6B6F716F7175
747C787B7F84818988838E878080807F858486867E7B817E7E817E80837C867E8381837C
7E83848085817D7E7B79847B7C817A81787E80847B8078827E7378757C797E7776797677
7376766F7B7A7875737677787370736D79777B7B76717B727674707273707C727170726E
7E71746E72706B6F6F736B6C736E74716D6F6D7074716E717269706C6670706C6C6A7071
70716C6D6D6C73656B676B6E6C6C6B68646D68646A686D636466656068645E606B606063
616261635D5D5C645E60605A565A6A5C5C5B635B5C5E5A5C5F5F5C5A5B585F5460555659
635B5E595C585A5C5A6059565D5C61586061605B5456565E60535D5952400055585B5860
565554555159569F00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D6686368706E64696962696B656D6666666B616E696864646C6A6D6C696A6A666C6D6B63
6B656166696B66716D6C716B69636B666B6B706F6C6B67716E6C6B6E7074706E6B696E72
6E6B6B6D69686B6C696D6E77646F6E716A6B73696E7B6B68706A70707269766C70766F6F
716F6E777677707473767471746B7474737376737178776D747C78737875747371727876
7178777B82767E76707483748081747E7F7E807C7B81747C7F7E7E7D79797D837E7D787B
8685848380888A837E7E838088848483838687868080898486847D7C858B808886807A81
8986817E7E807774717970706C696D6C6E6B6E737579737C73757468736B686A6F6B7377
767E807B7B7683817B8080867F7980837B83867E8482818085827F847E8082818182887B
7E807C87837C808381817E7280817D7C7C7E7D7B847F787A807B7E7C807679746E71767A
7B7B7C7777787D78747A746F71757476797576737871756F7374786B766E6D70746A746F
7371776C766F71736E7761706F6E706B746C716E71717170766E7070716E756F6F696C6F
6E6A7178736E706B6D696A6B69676B696761666E6C696A60636C646461595F6767605A5E
6063635C5E6463605E655F5B5669645C6460635C655F565C515E5454605461565B585C5E
5B54625B595B56615B5C5659595D59565A545A5A56606459555D595B5711005158575C53
5C575658565953B000000000000000000000000000000000000000000000000000000000
000000000000000000000000
D06666616B61626368606861696663646A65646366605D6465696A695E666B646A646A6E
63696E6B6A66686C726B6065686F65716C687071706A6D68686F6E6F676F666D706C6D6E
64676E716B6D6F6C7166706C6869686B6B716B6970696C6B6571736C7171746E796D786D
6F73776C65767A736C73706B6C62727872737579766E776F7671727B747B787875767274
7B7C7D7A7A7178757B7B767D7A7C7A76747B7C787B7C807E7B78797E7D7F747E817E7D7C
7C868184868A797F8586818A7C818E89808386808584817E8C817F82898379807C838188
868081837D7876756E6F6E6A6E6C6F71696C6473797678787A6D717268676C666B66726D
75737F7E77877A81847B827E7C85807E7E838380807F8682807C7B7B7E81817C7B757E7F
8185808B8081837E83817E747F7A82797D7E8381707679777B7878727377797D767A797C
757A777C7C7372716D7474706E7173737479716F75757478706B707874786976717A7869
757675746D706F6E6B6B6B6D6C6D73686F77716B706F756E766C6B6E6D6B706F7479716F
6971726F71716E6E6C676B706C68756C696C6B666A666567656C646B606364666162606C
68656A586163636162605B5A5F615E565F5863585C5C5C5B5E595C595B5C5A605A5D5C5E
5C5E5E5B585258585B5D5B566160585D575F54595B58525B5F5C5D62554F495859595D5C
59565A56515358AC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
DB64616463626364646A6B66656B6C666B65695E6663686C696963666863696869676A6B
6A68686C6C6F70736D6D6C696C706C6B6B646D67706D706D6E6C68667174736D70696D66
6767696F716E746C6C6771726B736A706F706E706B6E796E706F7470746473716B737072
706B747377727374736F7678746E7173737373726F727073767878787378706E7C757673
738475777A7680777479757A7A77817A787F747A767B7C7F7C7C84767D7B7B7C7B7B837F
81827D7880798482828086837E85827C8189848C80867B857E828484847C768189878183
82828485807976716E70706D66636663687068706F766E7164736C6B6F67676B6B6A6F6B
76787C78838281877E7D818083837B817D7B7B80898483838383797E80797B8080818686
8081797884797A7E777E79817B80767C797C77787D7C787E78767A7E7A737C72816E7870
7E76717A7B6F767278766C79757E7873736B717074716E746E69736B73767174756F6F78
70716E6F736B6E6B6E6C706B706664766B6A6E6C746F6E6E7174766E757176706E6D6C74
6F796D767471766C74667075686B686D6C66666A6064666A6363615F5B6566635F5E6660
616062635A605C635C6161575C5D5D5A5C635F5E61615B5D58515D565E5D595B5E605F5B
585858565E5B5D545656595E5E5B5E5A57505E5C5D5C5B5E605E5C585259605059565A53
5C5A585B556058A900000000000000000000000000000000000000000000000000000000
000000000000000000000000
CC5C666462606465666863686A6E68626468636365636164666C64686D71676869646963
6A6A6B616968726A626D696E6669696C6A67706E736F666E5E6B74696B6C736F72676E6B
7071706A69706F786C716B70716E696E706E6E71666C707070746C717073766E6E6D7070
6B7269716E74706E68706E7C6C70727576786E7673767274797571767578767E76747572
777C73777E787774787379787B7A79777A7B79797D7980817E7E7C7B7D76827F7C7B7E7B
7C7D7E807D818A7F7D84847989808682888485837E81808481857D837E85847E8080837C
8584847F7C7B767A736A6C666F6662666C64696B6C686E676B6666675F6663696A66666E
79797B81797B7E7D797F798086797F818681877B8180807C7E7D83817B7B807C7B818286
7B847F807B83837B787E797C79797886807A767C7E7F7A757E7878787471807B7573766C
767A7C7274767D7B7871736F746D7B79747470747473746E73707375786E757472736A74
78707270686B7072737070766C6B6D706D696B716F6C6C73707274736F74707A78737B73
6E6B6C737475716F6E6D6C706B706B6E6B6C6D68676E70646C6C606160675E626061635E
5B646059616160645C5C5E57585B585C60615B5B586453565A575659535B5C5C5B5E5B5B
5B5C5E5E5C5358595B59595A53555C5E56635856595A595656565E5B5D565B5757555458
5E5C565A565654B000000000000000000000000000000000000000000000000000000000
000000000000000000000000
CC60635D62696C6366626B666C63706A6166656865647268736662666C6A6A63666B6666
6C696468686F6F68676A6E6B666D687064676B67696E72706B6E6E6C6E706A6D66656B68
696B6870706B70706B6D666F716A6E6E69676B6F6D696E72746F6E6D787969696B70726E
6E6F6C706E706E6C7074666E6F6E72717970747275756E7A757B76777173797678797678
77777B767979767B7871787978767B7480777B7A7C827F78817E807F7A7D817E80837D83
7C818683848484837E88847F7F848B838282817D89858079888286898883837C89817E84
8C848C7F847E766F666A6764646B5E6363646163686060606B62685E676B686A696A6169
6C7981827F807B817E7C8A817B7C7B807E80817E807C807E7B79787C80837981827B807C
758080777B727B7A817C7C767672727D7777787C7C767B78767C7A7F717B787C73767378
71787476796C7D6B7672757871706E746D706E716E787070717A7571796C69787674716C
716C6E71716F79766D69696C6F6A6B6C706A6E7173726E7170707175727B757578707771
737076706F746F6E786A72756D6D706B6C69696761666A6465616361666C655E64646363
6458635B5E5D5F5B5B5B5C66585D5C5C6659635D5B5D5E5D5B5C60565A5D595A5F625B5C
5A585A58585662555B5960595F5A5952595A5E5C54545B565D5B57585A59535757575A5D
5254585756595DA400000000000000000000000000000000000000000000000000000000
000000000000000000000000
D065665E6C645E6965686461666961636E6C6665656469696961696E636664646E6B6468
69696B676869686769697061676A6E6869706D6A6C6E766C666B666F6E6B6666606E6B6C
6B6F69686A6B6B72696C6C706C68696B6E6B6F6C6E61716D6D726C72757272716F737870
71766E736B7673706B747A766A71726E6E746F746E6C7974766D7274777A787678787374
737F767874837A777C7479757A747C787C7C7C7A787677767E80847C7877837C7D787B80
747C7D818381837B86817B8681797C837F848383787B8673797B7D81877B7F7B857E8983
8884848084797C82797A67696C60636758635C635D5E615E5E6368685E6562666E6C7070
7C79777C837D807C7C837C767E797C807482807C7F807C7C87897B81787E7C7D75808088
7B7E7977787D7D7C7B7E7A7D7B827E767B78777D74787C7E7E7882767A81787B767A7A78
6F767173717A7470777877707B6E70747474747073727173717470747072747575736B6D
6E6C7072716C6B6C6B716A706E6A6F726F6C6773716C70767472786B787179737079757C
7E7C7781787B7C75707972707675706E7070686E6C696A6B6869616C6763626164616369
635F645E635F5F5D586463615E605D5E616459605E5F5F605D5D5658635B5B5560595E57
5E595B58545B5C58575054595E60594E57615B595B585C565559595B5B565E515D595356
505C5B51545B56AE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D1646863666561666368666461675E606966696865606F666D647068676A6B6867636969
67716B66736A62696B6B6E6E666A606B63696874646D6E7070666A74736B6B6260696B73
7170686A68706C696F646A6C6C61646E686B6C726C66746D7373706E72717075746F6B6C
6B736C6A7A6D6C7079726E7270727377727172706D6E756E6B727371766D727B73827375
737971777C7B7679717979787B73757574778178767A7D7C7E78767684827E817C7D807C
848178807E807B7E7C81868288817F848682807F7E787C82848083837E837C867E8C8A7F
88858C87837A7973746A716A6761605B58585C5C565F605D645E5A5E5B645B696B636C74
6F7E7778817F75868283797E7C7D7C7B807C74787F7C797E837D777E837C7B827B797F7B
81857480827A7B827A7B7A7A79797B7E7A767679787B7678757978717978767B7C7A7B73
8072737279757173736F6F7A767B7278696E7171747670706F70706D75756D7169747174
71746C706F70707073707371736F6E716E6E716D6674716E6C7678766F7979767B7E6E78
7A797678737D827C8273797174746F6D6F6C696C66676A6D6A6765686468646864646361
635F615D635F5C5F665C5F5B606161575C635B5A5C5360585951615A5E5E5E5A5C545A55
63545457545C5956595664605458615B5A5763585456595C555B58595252565C5C535154
535A58565C5357A500000000000000000000000000000000000000000000000000000000
000000000000000000000000
D16064675E64646666645D666B666569646A66686A6868666B686963656B686C6C636C62
6F6C666F6B716B72666C6369686A6B6B666E666F6F6E696D6E666869686D6A6570676E6D
7169716E736A666C6B696E68646D6C6C696D6E6E6C726F766976726F757271727170766E
6D6C7373716E6B767672796A6F71706D6B737576717879726E747B73747B71747B73717C
7870787A7876767A7578797377787873787878797C747C867C807F7E807A777E78798180
7D83867C7D7E78857E807686798B847A807A8583837A797B7B818080848382808084808B
858884857C847D797976707061686363605E59595E565A5D60565A6355646166656F6F82
767D7B7B7E7D7C827D7C807B8077847E82788174777A787B7E808183807F79837C817C7B
7C79807B78767F78757C7B7D7B7B7C7C747D7879737879777B7E7C7674706E7B79787371
787674756E727771686C716C7078716E79707670706B6E716E666A716F766C70746B6873
77717073676B6D6E6E7069686A73716B726C7471717673707172757A7075727B7A738282
7D81847D78817F7C7B7D757972737471726C6E6B6D6E696470646B69656E636D62585C69
5D62605C5E5C66636262605C59585D5F605B605C5B585B5C61595C5D63575E6154585B5A
54565B575954505E5B5B5D5961585B545D60545F5C545459595C5A585460565260545959
515C5658596256A700000000000000000000000000000000000000000000000000000000
000000000000000000000000
D964635F6B666A64666B686666616662676668686A696B686F6768666F656F706B6B6968
6964666C6762686B656F696C696B68686D6B6C71686C686D706B7070716F716A6766716B
686B65696569696964656A6B686B6B697064687670726B6E72736E69706E706C6F6C6A6B
6E7676766C6F6E73726F73696B6E727172737374716F717C72716E737A6D7375707A6D74
7C7B76727372726C717378797A797976737C787676777A70747E7778837880808283797F
7E747F7B7A7A7C7A7C7B8179847C81877E8386827981807F817F7A7A847E808180868275
8885878181847F7B7D7471666B65605D6561575A5459575E5C595B5C595E606764746E6D
7778827C8079817A7F83777E75807D84737A767A867878797F767A767A767C7D7B828079
71787B7E787C73797A737E797B767D7E78787C76767781807174777073777B7476746E75
6E7677707172757173727270796B71746E7974787571717573727971746D73716C747270
6F75716E71696B6C6E6F687874716E706A6E6B756D706C7A6F747A7481817A7979818787
8183868387878E84817B7B787E787472727B7378786D676468686F6269646A6666695E62
646361625F5E5E615866595D5F5764575B6053565C595D5B585A5C5E5C5C5C5B595B5A5B
5559565B57555C5C636055575B565A5B5B5C5E565A5C5E605A5860515B5E585D5D575856
56585B5B605B4DAD00000000000000000000000000000000000000000000000000000000
000000000000000000000000
DB605C645E5F64696865676C6664696468646B6568646E66666A616B6464646767686B64
6C6C686C6E6466696668646C6B6E67706766697269685F6D676F696B6F656C6D676A6C65
696C696969716B66686C696E666370796C6C6E6E6C6E71706C7B70666F6D747170676668
6B6F6C677370726D76716F6E6F6E706A6E71716C717578787171786C6E70747071737677
71747A736E76727D7972737580707476787078787A7779797279767D7B80777B7B767A7D
787E797C7C80827B837E81807B79817A817C7E7C7D7F7884807C7F7C7E7C837E85857F85
7C817E8079847C78767774736F68616166605C5B5E5B5C6163675D5F6463616C72726F77
7E7A7E787B807A7B7B7B817D7C7D84847B7C81757E7C7A817B7D817577797C7A74798178
7E72797B7C70767C7A807876807978757A7B767C727772747874787E7B7573736E787971
7B71736E777075707075706C6E7373716B6C78736A706C6C6E717469746D71736C69746B
6C6E727272767270706F706F6E6A6C6E6C70736F74707070736F767E7E7C81827B7C8889
8386918B838E8D8C7E8B8882798178757074696E706969666F7066657064606762665C63
656363646268626160615B5B585F5F5C5B5663615A5C5B5A5E5C595B615E565B56595B5E
575B595B595E5E5B6058565D58565E595B5E526156535A5659555E62575B565959555A53
54545656595052A600000000000000000000000000000000000000000000000000000000
000000000000000000000000
D66269646B60636667646568686469636964616A6666666468606B666B656C706C686B70
6F666C696E646E68666766676C6866666B666A71696B676968636D6C696B6B6F6B726B70
696E6E676B676E6465666E696B6866696C6D6E706C6A6A686E67706C727470706C6B7170
7269646F6E6A71746F79636B7171727470727878736E746E736E71717470757971716C74
7174786F7E7B7674756B73776F7675767E7B737376747276767C827B7D7C7C777B7E8077
787B7579827D7E7B7D837F86877E7C7B7A8678848879848284807C7F837B7B7F81807E7D
7C838182817E7C827B7A73716C6E786E6A69686867656268666466646B666C6C74767879
787B8080837E7D747D7E7A807A7C787E77787B8379818082807879787B7A8073817F7E76
78797C7E767C7B727675787D767972797C7477737370787770797A7475796D7676787379
746D787B796C73736D73736E6E6D706F75756E7171746C736D706B686A746F70696B6E6B
71706A6D736773707467736B7070726F666E6A776E716C787B7B767B7C7780848282898A
89919391969A9F959693898C888779807572706F6C736D707265686C6E63636361666360
5E65636063605F616761645E5B5D5D565A5C5E5C5C595C595A5C5D5563565A5B565B5959
5C58595B5C59595459535959545859565E5360585A525B5359605856595257515B615357
585A5658525156B200000000000000000000000000000000000000000000000000000000
000000000000000000000000
D163636764606E6661626A66646C6866676864696C6166616B666866656369666C6C6669
6B6B64646E6D68676768696B64666D6B696870736970676B6466706F6B626F6B6E69666A
6B69666D6B656667686B6C6B626D6C7169706A7270696A706C6E737671706A6C71696D71
667276786E70706F706971786E6E7171726C737172736E716C6F716C7473716F7C767779
707379797379757E797472757B7979787A77777C717879797E7A7679797F797F7E7B7B81
7E7A75787A807B7B81867B81807B7C8580808278818280747B7983837A847C81767C7980
80777C7D83817F7E81767B7581716B6B6C7166696C6E6A6667696B6D6F71736F75787676
81877C817C80807372817A797C797B787480797C7C79797983787D82807976807B7E7C74
7B757576797772797B797B76777A727E7471807470747C70757470747C72747874766E74
706E767070746C72726B726F766E6A746E77737773736670667778737B736D696D73736B
736B6C73696C766C6D6E6B647069786E73716870747C7174787B788079807E8A8684908C
949BA3A0A4A6ADACA6A89C9891898484787B73686D6C6E6C67716A696564676B66666666
606060615E6163596661595C5E615F5E545D5C5B595A595A5E5F54566056595B5B5B5C54
53605F5758565954595B586061625B545E5B58565A515E61595B5954595C5C6158535B5B
5457595B58565EA900000000000000000000000000000000000000000000000000000000
000000000000000000000000
D067636866626366686861625F656266606C68676868696C6B66686368686364686C696B
6C6A6E6969736765646464716B6A6563696E6C6966686669636671687168676B666A6D6E
6C6D666C66666E6A6B69706B6861686B6C716E6B6E6A666C756C71666C736C717068696B
6E796A71726B74717270726C6D71746E73747073736E70727170707170746E787178746E
73787676767177757579797071766F787578737A787470797575797E787B74737674837B
78798479767B81837E82807983817E79807F88817E7B7C807C7D80827E7E87817A78867D
7B7C7C797F807A8078758179767871737C6C74716F6D6B6A7067716F6879737374797284
7D76807C79797C7D817C7674747F7A747B6E79757981817D79807C766D6E787B777C7E7C
747C76787D737178707B7B7A767C747479806D7E7A797076737C78757478737272717070
776D726F766B7673777374746E7172716C6C747170747676737B74706E7470707175736C
79746B717271746E766A7272696F6F716F6A716E7B7673777E807B7A8487847E81908D96
9BA5A9B4BCC8C4C7B9B1B49E948A86807E81767673727070766C6E67656867646560686A
645E6361606063595E5C615D5B5B5B5E5E5F5C615C5B605A5C565A58595A605C5D5B565B
5C55515B595B5B625A5A5755595B6261615B5D595C575E575655535455595B505B5C5C5A
5F565959545056AB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D46160656967656A60696165686664606B65696262615E6369636367616468686F61716B
6B6A666368656C6E68646165676C6868656E6B696968686A696B6A6673666B67695F6B66
6A676C686C6E676B66636B6C6D6C63676B6E65656A6C706C6E716E6970666D7068676E72
6A6968696E6C7071686971696D73786E7B726D706D787472736E74567474777572786C73
716F7274716E7B73766E73737272717B777F7A73727878797379797B7B80777376767C74
7C767F77748376807C82797C7A84717C8178847C7B7C827B7C7B7F777D7E75877E87867B
7C7C777379817C837872807B777374767174717B6E7172726E7578747571787276707678
7E767E747C7A757E7479747978767177767B7A767B767C797C737C767B7F78797D787E76
787174758273777A77797979747078717776796F747074746F797177737077706D7A7076
76736C776C6E736B746D6B787272736C786F686C767170716C6A6A71786E6B6C74706D65
71737470706D6A6A6B6B6D6D7171696B6E6A70697872736F727C80727986848680939BA1
A3A5BCC9D9DAD9DAD6CBB9ADA08B918B80837C7976746D6B69676B6467646B6269616163
5D696261615C585C64665B5B615F5E5B5E67575765595C5C5A595C5B61595C5C58585961
5F5B5A5C5E6858545A615B5E59545C56545B595B565B50565C5F545C5653585654595755
50565353565356A800000000000000000000000000000000000000000000000000000000
000000000000000000000000
D46368695E6060685E6266646366646E6963696963676861666E666D686B61656B70686E
676C646469686B6B646A68696A6E6C6C6C6F706F69696E666B676C6E6E6A6C6A666D6B66
66676A696668696969696B6674716C6C6B686A696B6363687271706B6C71706B696E706D
6C6A696B6C676F66697170746E736E7371706C76786F70756E6C756C7274777177737076
766E7371646C7476757471767075767870717E7A6F7C787D7779727E7A77767979787879
767C79818081867D7F797C7980767E77787C80807F818082807A797D80787B7F7B7B7E7C
7C868383767A7C79787D787878787C7A717972717B79717B6F7C79756F797979807A7D7B
7379787B81767B767B8178787E7C7D79757E747B7178717A71787A7D7B767B757C7C787D
7A7276757E787A7A7A7173746E7D737370737676717973717770747374727A707A757772
747370787472766A747474727474717170706C70746E7173706C6B6E7371726B706E7073
6E6F6D6E6E656C6E706C6D6C74646A6D6D6E6D6E6F6C74747D7C7B7C7C83858A9292949E
ABC4C8D8F3F4F4F9F1E0CEB6B1968F85807D757370706E696E6F696C696B5E6964636664
6368646462615C5D5E57625659635F635C585659605C5C54575956595B5C5C595D545D58
59605B5A5A605C5B5C595B565B565D5B5A5C595E585659565B585C59595A5A5E615B595C
58525A51545956AC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
C663676062666365666269656161665E6962626967656164696969636C6565666C666E68
68636E61616C636963616767636B6D6B6A6E646A706C6967696C6B68666669696E64696A
6C626E68696E6E70696A706F6C6C706969666B63666971756B6E7073686E6E716E716E69
6C68686C697168656D6E7470696C706E6A717B7C707174787077686E766B71737B76737B
747071746B74756C7278767876747F767D76767E74707381777A7C73737D757C7A797B78
7E7677787C7786797C79808483787E7C787B817C867B7D807B84838380787D7A7B81797D
817C7B7672837680797F7F79767F72756D767C787176746D7975787D7476747179747477
80777E75767B78807979797C7C767C797B72747B7479797973767678757C7054717C797E
787C747884717C76787C7674787B7B737178797C73707A7170707070717672756E707174
79747170716B716E717473736A73697472796C6D6C6E7270736F7168736C706E70716A6F
666B716F716A6C6A6E6D70716C6E6E6F716B73746F676F76757B7D7A7F8185888D8CA6A9
BEC8DEEBFFFFFFFFFFEFD3BFA6A0988F817C7C7777737672766E6E686E61676062695B6F
60616561605E675C6059615E5B5E5C5E6161605C5B5D585C62575E5A59585857575D5B5E
5B5F58595C575B585C545B606360535858595B54595C585E56595B5C565B56575B55595B
525656565C545AB500000000000000000000000000000000000000000000000000000000
000000000000000000000000
CE6164636966676565666963656C636B6863626065646963646368646668666362686668
6D6D676C696A656F6A6E66656669636B68666D676868656C6A6B6B6B6970606460736E66
716D6C6866686969666A6E6C676A716C726A6969676A6B72736B68686B6E696B6B6E736B
686E6B6C746D6B6B6E6E716B6673736D71766E7671736A72757077786D6E7975736E6F79
7470707072757971767A76767077717875777673717977787476767877827B78777C7D76
75787C7B797D7B7B83737B797C787C7D757A787E81797B7B7C86817C7E7A787C7A76797F
7A7E84757D797976797779797B7378787B7679797A78707B727474747D797A7B79798183
857B7E7B797C76737B7C7B7B776477797578797A79757B7974787973717C7A727E757674
7B75797B73797C757A767B7679796E7674777271747377767B73787676726F727B717172
71736F6F7070727570746F72717675707271706F7471747670736E746F6E706E6B696D68
706F6E6A696D6D6C6B696A6B646D66706A6F716E706D7378757A747A7F7988868E9496AC
B7C8DAFBFFFFFFFFFFF6D3C0AB9E918C8589807E7970746A716D66646569656567646764
606363625861585E5E5D626360585C58605C5B605861565B5F58585B5B5C5B595E5D5459
60585C5961535B575E545A5C56595E586154595E5C5C55595C5A5658566060565A56545A
5B595355545858AA00000000000000000000000000000000000000000000000000000000
000000000000000000000000
CD686663635C616761666365615F6661636A6764646968686B676866686B6A6C68686763
64676C696A6B696B696C696A686C6568657063696E666E6467696A676C6E616B69696B6C
6C69666962686666696C68686C696B70736E6B6A666A6D6B746C72706B6E6B71706C7170
6B67666B73696E7071736D696F756D6D777074737077746E7474717075707A747B6F6E6E
7170737171707370767170777173777779777A7270787D7671807B7B76787C7476798477
7B797A7878847E7C787D787F7D7A847D8076777580807C7B7C7D7F797D797C7980807E75
7B7E7A837C797A7676797B797E7B817C7573737B78767B7C72737574787979747E747E6E
7B7C7B7E7C81767D797E7A7B77787A6E7679797A5B74727D78757B7679727C7B7573797C
7A7677717B8377717B76786E70717970747072707274737871716D7271706E7674767173
70767371787E72727370766A6C76686D736D72746E6D6B706B6E6D6A6B6C736C71736C75
6E6C69796B6C687470636B6B6D76686B6C70706E72746F707B7C7A76777E84899695A3AA
C2CBE6FDFFFFFFFFFFF4DAC6B1A6998E867E7F787E786E6E6E696F6B6B6769666562665F
6263615E616060615E6056605F59585E615E595E51585F5B5B5E6059595F605D5A5B6059
5B5B5B5E58565E5C5C5758505E595B585A595D56545A5858595B60605B5E5A5557555C56
5C595157545456AC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
CE6561666C6367616B645C605D635E656664686D61616868696B6469646B656664656E69
63686C68686964627469677066686C696966637369696869696B68656C666C6B6B666E67
69686E776B616563666A696E6A6F6C6B6E706B666B7070686B686C6C6F6D706E6E6E6C6B
6C746C6E6C67686473686E74716F726B73776F7774766E77726D70737676726F716C7377
71766C746E767373747A736D7474797974757A76787972707B77767C75817B7A77757C79
77767B787B777B787C7F777B7E75827E73777B80797E8184787E80817C7C7A7E7B7C7B74
7B7B80787C807879787B7977787B7D7C78787A707C75776E786B7473737975757482787B
76797E7A7D7E837C7A7A7A707A7E777778707A787A8173797E7B7A767676786E7B737476
787475747E7478747E717877787978737D756D7870737078766B76707974706D6E71736E
73787671716F736F716971736C6C706E74726E6D746C6F7075706D6862796F6C726B7978
6B686C6C717069686E6E6A6E6B736C6B716C736D71687071707A787D7A7C84848697A4AE
BBC9E4FAFFFFFFFFFFEAD0BBA89F9A8B8488807D79736D70687264686E7364666A666163
60635B5863645C6156605C5C64615B5960595E5B5960585C5859615A615B565B5C60555C
575B615C586054585F595756575D5C595E535A5A5B5B5B5B4E555658565458595D52595B
5B5B5B58555154B000000000000000000000000000000000000000000000000000000000
000000000000000000000000
CE5B5C626366606361626468646B64636765646468696C646D6C6B67695F636668706369
69696C69706B6760676A6A656A6A6C62696B6963686A696B6F6D6764696B6C686867686B
686B6764686A6A6B64636D676F6D666E6A696B6F66716B6D706B7072706E6C6E6A6D736D
74786E74746C756B716976786B766A676C6C6D706A6F736F74807271717173707975737A
7373726E777A7273746C76757671737575747174736E7B76747B79797376767D797B7A76
79737778787E7E817981817C7E777C7A7F7B7C7384787E7C7A6C737C7D797F84797E8081
75727B7F7C7B75798071777C7D787C737675717778787C78797D7672797376767C777979
7C747D75797E7B8079767C7B70787B7379757E74797B80777079787173796E7E73797372
6F7A7F7976767A777674767B797273716D7675797673766F736B7172786C737371777073
6B6F7770726A7071717478707477796F78756E6E747172726C7071696C6E6A6C706D7070
7270666B696B6F6E6E6A686A6E68706C6D716C6B7676717579767C767C7B858087959DA2
B6C2DBE9FFFFFFFFE8D9C3B7A798918B887E83787C70726E6C6C6E6F686B6A67685F6564
6468615E5E615E64655F585A64605F5B5B635E5C615B5E5B5556595B5E56615C545B5D58
60616360575B5458595C56595956615B5D545B545B57595C5D575C57594B5C5C575A5156
5B5B5854585C59AC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
CD5E646363626069646660666D656A686B6E686C6963696863626A63676E6B646366696D
6B62696C696B656C68666E6968656A6E686B6A7061656E666A6967676B68706A6A736868
6B686D676660686C6C64666D66706E6970686D646C6E6370696A716C6C69746C6A767973
6A6E716B6A6E71746C6C6B7070707473746F7078717470706E756D6E6E6F797674747777
7A716E6F766D71787371736D716D757877757174767678786F7D707971807C7E7A7C7673
787B757E817D7C7E7A787E7C7C767B7F837E7B79837E7A7486747B7F7780817B7B7F7A7F
7B807576807C7877767E7A777A74777B7B7D7373797A757975797778767B767C76797876
81797D797473817B76747B777879737C797B787976787175807C7778797478707E767074
797471717870727678757C747A74766C7770767170747372747471706C6D746E6F6F7174
7778766B7268776D7172717072706C777174706D736F696B70696D6F6B706B6E6C6C706E
7273726E716E647269696E736A6B71696E6C73736D746B717573727478777C8389939B9F
AAB8C6DCECF2EAE4D4CBB7AC999394898478757879737473756C736A6B6C656764646163
636062615E625E615E5C6260555B595D5C5B635C615E54565D5A555F555659635F585C5B
5B5960535557535F5C5D5959595E655D56585C5B5B575E5459585B5C565B595658595E5B
56565659585756AC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D3665E69676663696460665C65615F64636966656565696965636668646A636665717069
6B6C6E64716869666968646E696B6667666F6B6F6D66645E706C6A6667695F6269686D6E
696C6A6B656C6A636867686C66686C6C6A73646F6871667671706E70746C69706B6E6B70
6E6D6B6A74766C6C6F70736F6F646F7570707072706E7875796D72747073717676717370
736F727374716E70736D7978736E7C7878747A777676737E736F747478707C787875797E
787977797E7C7C75797979817B7C7C777D74797C7C7A7D7B7D7C7E737C767E7D7879817B
797B807E76757A7E817B78787A737C7D7C707C7C76747B7B747777787C797C787D787679
6C7C767871737B7876797874767078717C717079767A746E767475747876757B7C787372
757579757373716B727171707473716E726F717C7273747B7178657073706C6E76727575
73736F736D6F746C6B756B666A717674746E6C7075736F6A72706F656B6E6E6C6F6B6970
7063796C6C6E666E68706F6E696B6F6872736E6E7470766E6D6B74787C767C8089908E94
A0B2C0C1C4D2CEC8C4B3ABA6969088887F7F817476777171706D6C686C645E676567625E
5B69645F625B5F5B60605E5B615E5659605D5A5B535E585E605E5D5C565B5B6159566361
635B595B5D5C5657545960535E585A5C595E5E5B575D5C5F575D55585B5B5B5D5C515659
5459515557555AA900000000000000000000000000000000000000000000000000000000
000000000000000000000000
DC63616660645C6968616369645D646661636863616A65646C6F69626C69676D676B636E
6869696E61686A6763677166676C666967686C64686C656666646064686A67686F65666A
666B636C716B6D6C5C686659666969667071696B6669686C71716D6C6F6E716A72736B6E
6B6B7373666C6972767073706E736B746B6E6E6B7075706F7370747476736F796B717778
74746D70746F716F75707970716D67777974816D726E737474757B727B7476777A7A767B
7774776F6F83787C7C76827E7D7C7B758276817E7B7E7873757B81797C78787B7A81767D
7B72818079818B77717E7B7D7C8179757B767D7479817B717878797879737975737A7475
6E797E767A7D6F7374727377787A73737973717B7276757676797178747983756E767572
727C7A727172776F767C7173767374796F78767970736E71766E7676736B706E73717174
717B746F79786F76686B6D697373746F756B71736B707367777175746A6C6D6670706970
6B6E6D6D69696C6B6C6B6A70696E6D6D77706E69736C6D6D68746E7475767B79858C8691
9893B3A9B1B6B1B5A99EA298948E83847E756C71797570716F6B706A6B69636664635E5E
63635D605C615E5E635C5D635C5C5D57596462595E585D605D5B5D5B5A58625E58585A61
6158585B595E565454595B5F5C5E5E5B535C5D5857615554585658565F5C5C595C585856
52585660575458B400000000000000000000000000000000000000000000000000000000
000000000000000000000000
D1676064646163646A5E6165646B6868706B696B696665676B6868696464666967677168
686B64666968716E6D647068696869686C685D686468736E6A685F626E68636B666B6866
696169696B6F6668656969696669676E636B69696B66666E6B6B6C706D67696B6F6F6D6A
6A6E6C6B71766E72686A6C696C6B6C6C6E7279787371796E79736C6F7674747374787177
6F7877737071756F74727C78707373787174717C6F6E7977717475747778737B797E767B
717179807B7677787178747C777D7B807B707B797B7879797778777C7C7C78737C6E7D77
7F727978817973747B79767973797676787A7675766D71747B7274707679747979747979
7875767574767276797876767C707D76767877767E7479787778787578757372727E797A
74707973747378787378757076767678766D766E747A7673717070726B706A706E74746C
71706F717576706F6E73737179706F7A7077746D6C686970706D6B6E7078696D7571766C
716B6D6B646E6B6A6E69676C6B696D68746E71666F6E6D6E6E6E7970727B787C7E7A8884
8D919A979EA4A0989D9491888E7E867780787B767770706B686A6C686C65606764666A63
66685E5C63615B625C64595D595C5C5E5C5857575D565B595A605D5E605E595F605D5C5B
5F5C59595E5C5B56575B62635A60615E5F6360565C5559555E55615D5B595A565B52595E
565B54565B5B56AD00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D3606769636866646866666364636163696461626A6B6866686669636F6C666968686C6F
61676B6C675F6D6C6869696A646B666B6B6E67606E6666666A6167636B6462676E61676B
6D696669656E666C7066636B716A6B6A6B66696D706B6A6C6C6C6C70706C716C6D697069
6E736D6867706D696D6E6F6F6874706E74787276716C736E7170697078666E736E727074
6C7173777577717673717178727471797174766B746E7B767A74747E7F757778787C7877
767974807B7475807D7874797C7D787A787C70837676787B7B777A7F798175787A78787F
847C7C7B79797C79797A80747B79737A7D7C747B727979777B766F767F76767C7679716E
7B74777B71767B7A70717479727878737E7476717777787876777B817C77757674727678
707775767873767B70747976747675716F7C7378756B7367766E71727174736F69737168
73706B6F6E7172716B6C756C6A7B6D7370726F6F6E6E6E73696B6E6E72706B6C74697167
6E6A67646E666B6C727263716B6A6C6C6D736E68686D6C6A71677071706F6C767E7E8281
8284898B8E8B94898B808E8B8E7D7C7777767777726E72696C68656C666669666A646162
6366646462615E615C5C5C5F60605B605C5D5C5B5B5859605D635E635B58655C5C555861
5C565B5A5C5E5C5C685B5C5A5E575A5B58565955575C5E5B5658605B5B5357535B4F5661
5C575454575C53A900000000000000000000000000000000000000000000000000000000
000000000000000000000000
D6636B665C636368706468676C696C6369666A66696662666367616469666868706E6967
6B66616B6C6864696267616069676E5E686868646A606569676A6D636B646B696B66686C
63676B60606E6B646F686662656E71696A6E646C73706E716770726B6C6E6C6C6F6B6E69
7070766A6D716D73726B6F6E726C736973736E7674737071767373736F74797674766E70
717274766670746B70756D6F7B72747B7370746C7776726F747474767D71727276717881
727B7978787B7576797A7C7B7E7C767E7A78747C807F747C79787C7B7478807A7B7B7C80
7A787279866C7E7C82787178817378797F7573767B7670737B7675797475797472767078
7275707B7B796F787872797671747673747A73716F7E7B6D7A727570807C6E6D746F6F73
6D747174787573737C6E737578797A7E787371766F6D6A7278747475726C6C75706B726C
7472717169706C70716C7270726E7874736C74706C6D6E6F6E6E6C6B7270706D6C6C6B64
68706E69696D6B6A666F74646163666B666C6A6C646B69726E73686C726576767B737B7C
8086827E7B8E888387807C847D747978787070756F706C6E796667666B67656B66656761
665E616360665F6660656461605E5A5D635F5B5C595B605B59595F5E5D645E5B5B5F595E
595C545C605A5C585B5E5E5F5B605A5B605E5B5C5D595453545B54595C62545853585C54
515A59555B5554A900000000000000000000000000000000000000000000000000000000
000000000000000000000000
D55F616260636164636C68606968696C63666764626A666864686C636B6867656C6E7166
6D6468666963686E6E6E666E636264686A63666A6767685E6C6763696967636068686667
60666E6E72666B66676B676B696B66697166696C706E6872696F6B697968716E756D6967
6F6F6F716C6C6B696B6D6B6F7370736F6C6B766E6E73736C72737C716C6D7C74736D6C78
766E71707176707976716F7073707471727074707174798170797673747874777B77787B
7878767A7979797879797C797175737B7A7C757879797B7E767777807E7E807D78787A7C
7E787B79776D747378817B787A81796C7D737070787B797E796C737373747A7C78807976
7974757176737B7375746E75747A7B7870787674767473797A737B78776F7378767B7871
7478766C7972736F70766E6A736F716C747676717670767074707476747074767470706F
6C746B6F70717171746E71656E6F73716E6B6B6B716C6871736E6B6B6C706F6F6B6C7164
6A6C68736966706C696A636869646A706A64716E6B66706A6F686B6A696F70706F6E7983
7E7C7F76807B7E757D807B7F7E7E6F7D766E7378697366706E686B636664606064646064
6157616463616163625A61625D5E615E5E5E5C5E5E5C5C5C5F5C5A645455595E5C56605C
57595E5B605C5B57635D5D5D595C595B5E5C5658525B6157545B595353535A5353575553
54535257555353A400000000000000000000000000000000000000000000000000000000
000000000000000000000000
D761666961616868636A5C636D686B68686A666C6666666968656D716B646C6A6A646969
6A696966696B6465646E6564676361666B686C696468666D66656C696B6664666B686468
60666B6E5F666B6B6665696C6C6B6B6F686E666A6A6B6E6B6E6D6E706B6F706E68706766
6D736D706A676C6F6E736A6E6969706C736B70696F71666E73736C74736E776E6E6E716D
73767478716C756C6C706E787870717A747A7674777479767971767877717D707079787A
7977817179727978797B73737C7A717877747C7C7E7A797B7B7B7D75787F7E7379747874
6E79767F7D7D7177757C787C7C7B78797679787A717375787A6E766F77797E7C7976706F
7D797577786E7A797973747073787174716C757679797C73727A7D7974767C777570716A
7572746C7370717871707472756B6F7B6A717173706B77767772707571736D7177716D74
707679746D716E776F6C706A72706F746F7071746B736E736D7271716B6963666F6B6F6B
6E6C6C6E6E6C6A6A62696969706E6E69656B696E6B6E6B686E6D6E716E71756B70717672
717E707E747880798072797A767C727773766C6B6F64716B665C6B6D6A656B636461636B
636361646660616064615F5E5C5E605D585C6161615E566156585C5F59595D605C575861
635859575B5C5C605C615C5C5A5E6054595856545B5C5A55525655575960545C5A565B5B
55575353535F59A300000000000000000000000000000000000000000000000000000000
000000000000000000000000
DE666768656164636866696964646667655E6C64696B6C6368686562706C65686D716665
696A69676A6A656B67676761606C685E636F666867666A6C6461696B6A6A6C686968686B
6B666A6E6C69696969686C656968696A6C6B6B6F716C65696B6670696B6C676B70706C70
68737071696C6A6B6C716E6E6C6C7074736E736B6E706C746C6E7471757771707069746B
6B767276707068716E797676716C74707C7771727D76757079777C747A7F79787D7C7778
757C7E6E7374797273777477747F75787A78767E7C7D7A767A7F7B797373747974767976
807A78757B78737778707672787878757E7977817673747379796F76787478786E737170
6B757474787175727C736F7A6C76767C74747472696C73757E747979837475757374727B
6C7571707C7077736E7169706976726E736C716D6B717474747471727375706F76717370
776C707066706A6B70756A70736B6E6E6B73666D6D6C716E6B746768676C6E6670736A6C
67666B6C6B6B6C68606C64676A6B6C666F64667166696A6C67656E68686E716E73767371
7377726F7D71737370667470747E7071696F706669706E6E6B666264646B6A6464656168
64655F5F5D626665595B605D5B5F6164635D60605B635A6060605C585C5B595E575D5858
56615F59565B5958546658605F51595B5E575B5B5A54545459545E585660515C56595754
575B5B58565651AB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D767605C62666665676C6A6A666D64616269606B666863656569686E6C6663696B706D72
6E6168656B6268646E626967616362686969696B64686B69656966666C6C646565696968
68676869696473646B707168696B6A67706B6F6C6C6B6C696D6B6E6C6F6A71706C64746E
726C69716C6B6E706B70736B7271706E6D706B6D6A776B666F767477736B717472727571
6B7371737B706D787173746E757274737776707A6D717978737874746D7171747C767577
7B77787676797E787475797B7A7B767474797773777C787F7D747E7A7E7B7A7C7A787E73
7C7C7B767576737C7D6F757384757E747A72787A767179767C77747378736F7B6F7A7B75
7371737477707272736D797978777677737970747378717073797B7178777B73776E7070
7378796E70777E77767871776E74736B6F73777671736D777370736C72766D7572706B78
716D727C6C6E726E707171696C6E6E716E6C6D6F717268696E686E706B69686B60716969
696E7169646765697469666E666C68696A6B665C6F686473676B6B736B6B69716D696D6C
716F7371746D706C6C7470756E6E6E706E7069706A676B5E646A62616963646064666A63
6361646564636060635F635E58615F5D5E5C5B5B5C5D615A5D635E5960655B5C565C625E
625E5B595E59615C5B5A5E5D58535E565958535D545B56565B57585D585C5458565B5A54
5456565B55535BAD00000000000000000000000000000000000000000000000000000000
000000000000000000000000
DF60646664646F6D6964636A606569686869655C66646A60626B6B636B6A6C6C6D696B68
6B6A6A63685E6C666466676167666369636B67615F6B6A5F5D646C6D68616B6963646A6E
686167656B64666B656F70666C696C676666656B6C6B686E6B706F697B666C64696E706B
696A6D656B7068676774676B716F746C7479696E6C6F706D6B6870716A78697072727174
757674736D6E6F76706F717378787A75746E6C6E6E6F74767B7278707C777473707B7874
787B75767678707879767C74797C7B73767E797B6F7B7E7B817B7E7679777A807C79737B
7D7575717C71777675787078717177767674717773737971716E71787176727871727471
6F737676716E7579727779766D6E7C7276757A74737073737171787174737370737A7171
746F79707374746970767076787072706C746B6E717A71726E706E717E70707474787174
74747676716E70736B70746F6C6C776D6F6C6868716E66696A736C636B70686B6B6B6C6D
6B6C6C6B6164706869636868706261626A6B6C6C6763746A636964696F6E67696A636F70
6D696D707673766E69706C6E766C736E696B666C656971616B6671636668686768686163
67605E63646461645D645C6160615C5F60625A605C645D655C5E5B58615C605D545C5A61
5B5D595E605E605D585E5B575B5D53585C5C56595B545D545B5359595663545B58565B58
545B565E5351519F00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E160665E6B616761676368646367646369646666686465686764645C636568686969686E
62716866666863646C646A695E66646068636864686A646A5E69676E616F6663716C6660
666A696C6668696669706B6E6869666971696E716368696E6E686D70746D6D6B65716B6C
666F6C69706D6E6C69666E6A68696D6E6B706F6E736B736A6E6F746C696D786C706E6C71
7073726C6F747570797076766F74716D7174717376747E6F786D74706E7475717A747677
73787872817D777C79797774756E7E7B7A757576757B80827B7677767378767977787874
8175717877786F7A7878787874786E7079767D77757274787472776E7179717B7A747771
6E76737174717177727374726A70787B71746F726E7279727670787B78796D7C6D6B7073
7370718070716C756A746D7671716D7971737170776E6E70727C717C72737174736F7174
6E6E6F747171736E696E6E6D6C69696D67736C746E6E6C6F716E696266686C6968716A68
666E6D6A6B636866676D6D6969666A6B6C636C616E626B636669706F676961706E676C6A
68716D7070706D696B706C6B6B7068696867695D696867626266696C676563656669666A
6667615C665F615F5E5D6164605B5E5D53646361605C59556356625C5B5A5E5C5C605659
595B5D5E5B5C5C5E5D605E5A62565E545C5859575B5D505661615852525852565A575A5D
56506152605355AC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D6676165665E686C6465666068636260696769646B63625F6069685F6967666364626869
656E5C5B65696663646F6368696967665B66686B607166645F686C69666F686B68666B6E
6E646669686969646B6E707069686C6C716B6C6F696F6A6B6E6968656C6871676C666B66
6871676D706B696E796C6E666C67736E686E716E6E6C716E6C6C6771676E707871707473
6B7370716E7171736C74706D767970747176756E71727370767A76757870707873787976
73797B7C7875767B7E7178796E7779747A7473777E717473707976797375737D7D7C7278
71748076767878747879767D79737C7A8077767A797877717A747071716E757172707A70
7278747578737C70747874747279737174717373776D716D756A7677766E7673736C7772
706E6A6C73736E7071737179777071766C75716C6C727071667573736B7378717474766C
6971706B7371697B7269676E6D716D6E716E7268706E6F6B6E6D6E716B6F68726769696C
6B6C6B686E6770686C6C6C676A69646F616C64656C6864696E6666696467696A696C666D
7266656B6A71686B6E6C716E736A6C68666A6964666E686165636166646361656664605E
64696964636461615B5F61665C5E5F5E5D5C61636457665C575D635E655D5B5B5B5A585B
5C5E5F6159585551665A5F615D585B5E5E5856545C56595B5E5C535158554E5152595858
58555A5D505256A000000000000000000000000000000000000000000000000000000000
000000000000000000000000
D068616265715E5F646B686B66646965616A66676768636A635E66696B64686667696968
6363696667666A646A636E666B6662696765626966655F6A646069716668626C696C6668
68696A667368636A6B636B6C63666C676C6672626C68666C716D656B6C71666B6A696C6B
71666B697070696C71747371716C7169696968706A6B73676F74767473746A72726B6B6E
67736D6E686E726B6F6A767472746E7070747171676B737C7878756E76737071747A7974
7A7474787578766E6F747B7A79707373797B7A797E7B82797875837C7F7F6E737C76767B
7C73767C7D79737F737573737572717A707278737578767371737378737079757078707E
71817372707174727573736E707275726E7375706E707073717076717371706B74767A6F
7377767570786B7073727170807571736A74736C6E6C6F756F6D6C716978786F6D767479
7075696E74726C6F746F6A706E6C68716C64736C7269666D6D6871676A6E6B6669686966
686F6371636D6A686C715E705F6C6D686B6D62636A64676968635D666A695B6768666963
6E6C6C71696471686C686868686768676668636065656869616368616466635E66686061
61635D62636461655C63625E5E635E665E655D675D5A615A5B5D5A5B575D605C6056645C
665B595951605E5E565F5C5B57595E5C5C5D5355595A55535353585956585B5B5F565159
595A5859585754AD00000000000000000000000000000000000000000000000000000000
000000000000000000000000
DD666569686965676160656166646164706C67606A696C60616955646465686469666769
696C6363666B6368636B6D68666A6967656B686960686C6464696468666B69676A666961
646C64686B716C6C656E6C666E68696C6C6067686964676E696467686B6B666E66636F70
6B6969646A69716C6D6E69656E6A746C666E666B7170706C707A68756B74716C6E70686A
736D6E6B6D6A726F72716E76707075746E7071706A696D77766F7979747475657B727474
79787B7C767B7871747373757176787979797476797378777A7C7973797C7879787B7878
6F7979757B727B73767373737675727B747177766F7B73747472707E7172747176757370
74737871736B78786F6D7073716B757073716E7A79756A76766E70717571777079796E71
75777B71706F6E6B706C6E6E6E6C7375736F736E71746B7573757673796B6E7B71707B72
737378737477707B6D746E6E6B71706F706B666D73716B6B68736E686E7169696B68696A
6C686B7169696A697062696364686B6869686B6266646961666A61687165726E6A666467
6B6A69696F6E6A65686C686966696862676E666F6966676B66696861646766665E68646C
5E66636262625D5E6163615F5F58616763625F5E59615B5F635B635B60665C5B565A6061
605E5F5C58585C5E5B5B5B5C5C555B5B5A605B595B565C5C55525B575E595953535A525B
5D5652535A5456A900000000000000000000000000000000000000000000000000000000
000000000000000000000000
D76365666D5F61686466636561666964636C696E695D6660686C66676962716A636B6467
6A646C64686769696E666064686164646B6A646469666E627169686666636B6963696B6B
6B676B696864666B6B6469676A716C6E696D6B6B6C7273616A66686B6B68666A6A6E7067
6B6C6B687168736C6B706E706C6C706A6D6D696B6D6E6F6E726D6E706C706E7370707068
686F706E6B6B6C76686D716D686E70717077717073767673746A6B747271736E767C7275
7A71707678777478767C717975736E7A7E7B787E7373777B767B7871747C777679737076
7F787771736E777A787A7B717878747572786E72756E777772687C7B70796E72786C6F72
71736E6B73757069737170717072706E6C71706A70717077736D6B776E747779726B6F73
736D716F706E7170736C6F6D6E767070727471707279726F746C6E766B75717273787079
7C797C797C787979707373706E4C43676E6B78706F766E707167696A676F696D7264666A
6C6666696768676368666C616C70606A686B6B65696B656A635D666964606464606B6966
6B6A6E696861636C6661606C6867626A5F5F656366656464636E616260676060586A645C
5F6161646A5F6162635B64645F59595E61605A665E615F5E645C6461655F5E61605C5A5E
5E5561555E645D585959635D5E5B585B5B5A51575C5456566259595B5556575A5962555B
5B5D56564F564EA600000000000000000000000000000000000000000000000000000000
000000000000000000000000
D95C6664676763686A656D655E6661686C666869696266676864666462696160665E636C
656866685F696A6E66666967676669646465646163665B6669696663666F6D6861686968
676C666B67696A6C666669666968686771696E646D6C6E686968647066706B6B6C736A6A
62696C6C716C6E7167706F6C6C716168676C6D666C686A70686D706B7460717A70716E75
6C6C6867696E6E6870746F6F70767574727B726F79716B707674767675747978727D797A
716E707B7374797371807E767B737574787B837A6F7474787C857C77767175787B717B76
747873737D76717C74766F7476727B7C7374707373737071787973697276747573797272
786E71706B727377747B71736B6E6C7873717871726C7070717374737871796D72707766
6A716B716E746E736F6E6E686F737576716B716F73706B72727870756E7274786F777B7C
7E7E808C90867F7E717173766C686C6C676B6C74696B6F707376686D71646A6A6A696E66
716C6C6B6B6B6763695E68676661646069636A69665F696562636A636E66666166656263
6A6C686B666A66666866666962645C6B6B6F696367635E60665E686C62605F6666616A5F
69636865686462605A675D5962615E60605F6361636064656466625E63645C60545C5F60
5E5C5661565E595D5859585B5960595457575B565C5E585B5658585E56585A5557515E54
575959514F5654A600000000000000000000000000000000000000000000000000000000
000000000000000000000000
D26460645D67636562696862675F686968666467696567686367666E63696C666C646B66
6B6B6B636C66696561616569686862666461616865636468676A6B62666164636F646872
6C68646C696B6C696B686E686C686768676C6D66696B646B68686B656C68716E6A6E6A6B
676D6B6B69676C6C6D68706E69726B6C696E726C736B6C666C6B6B6B69666B666D6C706F
6E6A6E72746F66707273707673686D6B736F6B71716F746B767574737074757279747773
717475747B747C7978717D747A7575737671717476737474797F767F78787D77757A7879
7475787B787A77767B7773707B747C74767378707171777378736C737C7171707A6F7674
7373736E757574796A6D7478746E7A74747773777B6D716C746C736E746E6F74786E7071
6574756C6B70736E75726E706973786E6F7176767265706E706D706F706C6A73757A7382
858E909CA093897D7B71706E6E70686E7A73736E6E6B6C6C6B666668666469606B666A66
6C6C6E60656667636F6E666969606C68676663646C6960646C6968696868676668656968
66616862686E685F63655F6B5E67695E67655F64666864605E636665666160616261595B
646A6368695F64646360555D5D655C5D596366616069625B5E635F635F5E5E61605B5C61
565C60615C596161595B6057615E5E535B5F555C5C525359595256585C5C5C5958575455
57575256585153AE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D9666964606963636664686A6C605F656A666A65665E6866646D6B6363616B655F676A67
616B64626460686463646565706366636263616263606E65646C6966646B686764706365
6C6C66646568656E616B6B6A6B68746268696A686A66746669686A696A6C5F6768677464
6E70696F696B72736E6E6C6B6D666968686B6B746C6A6D66686B6D636B6E70726D6C656E
6E716B70646C736A6E6B706A716C74706570736F6C70706C6E71786E7473747878717476
7B777872767A78797B7E6F70767F7176776E7C797A717979786F787F7B6F7A77777B7979
7079777A7A797374747A7C7177737371747375746D706B746E7178766C7369756D727371
71737173736E747174736F70747873767174777475716E6C786E756E756C7071756C736F
64706E707276766C6D70717175736E736E7074727471706B6C72716D6E736F77747B8286
909AA7B9B4B1A6897A786E736A696A72707072706E68707165696769706A6C68716D7068
6B69706B727067676564666C6B6B69656168686961626463696A66646761686663656464
68636A676366626668656566645C66616364615F65616661606363665F60635E68645961
60676262646664665E68666561616064616664665F615B60625F605B60605D5D68585A5C
5A585C6257615B5D5B585B5B5B5B5B57565A5D5A595C585A515B58595456535858565C51
53535050565450A700000000000000000000000000000000000000000000000000000000
000000000000000000000000
D8636064636867685D656864616368606763646867646362696769606D6864636B69666B
686668686368655F6365626468685F6B67646368676A646B61686B696A6B6966655F655F
7073616B6369656B6868656B686870705E6364666E706868676E6B6C66696B656F6C6672
68676372706C6E696F6A6C6F6F676F716F73716B67676C68636A666A6B68686A6C6C6B70
6C6C7072706D696E6B6E6F6E6B736E6E69666F717873736E737070766F74737076767770
727E7573767872736C79747974747C7278717A747175797E747E7C776E77797C74767878
72777573766E707373707A767473737E737377766E746D767573797073727372686C706C
766C727168717074706E76716D7173716E72707473706F697374726C72726F73676B736F
747072736B76706F71726E7372706D6B6D73736D6D6C6E716E70727673726C797379888F
A0B6CBD5DDCBAC937F726E6670686B646F6C68746A7073726A6D6A726B65636A666E6664
6D65666B68696E64686B696565666B6464656464635E606B63686460696E636160686B66
686366666563635E6366665F58626262646063636069635E6763636665655E606363635F
6062646261626561665C606862605F69635C646365605C64615A655E635D6866595C5A61
5661635E5B58545B5E61575D615D62575A5B5E595A545859595658535356535853594C56
58585856545854A400000000000000000000000000000000000000000000000000000000
000000000000000000000000
DE66655F6365666C6766636C5F66686064636B66666665695C6366686A666A68626A6467
6C6C616B5F66676465645E646660626164685C5B6B5F63666863666F695E686269687163
606B666C6565696B686A666068696768686967686B6C726471696A656F6C6D6469706065
6B666C6E63666B696B68686E6E6E686F706E7069626F6C6C646961666B6A746D706D6E73
6E726E6B69706F7068706F727378696C74706F6F70716F706C70726E7174767671757070
777674757475767F7A76737371736F78727976767771727D787472767E797379787B7979
74747377777678777979767B79767978707276747A6F696D73747471767373786D6E6C73
706B717472706E68716A6D767771736B6B6E7073757071736C6A767B74717B736D716C73
6E6D6E73717971747479727675746E6F69756C74707A6B6D7070717970746E7478808397
C6D9ECFFEBDCBE9987757470766F6E716E7169686F696D66696C70656C666C63676C6969
6964646763686A6869666B6A686367666A61606066686569616264676465686B6B68615B
6663686764665E5B6266666463616860645F616364655C5F64615C60616160645E635E68
5B64655B62666161605B625F615E59645D5F5C5B615E645C5F6768656361606060615B60
5B5D5A5E5C5A605E625E5C5C5C585C5B50585653535B5859515858555A57555A56585651
5B5459544D5958A600000000000000000000000000000000000000000000000000000000
000000000000000000000000
DB636664656166656868656C6764606B69666764676C656B6B65666C6465686369666E6B
71676D6D646468676A5F636363686164646E66616B666369646B6B626668696666656569
64646B6E6766666869696B6E666862705F6B686A666B7368716C6765717269696D686F71
70686866666C676C646870686A69686D68647269706F6C6670666A6C6665696772706A6B
6C67646A686C69706A69716C6A727071716C7C6E776E71656C736F7C7478747471717072
75706F7076747178727677787A7A786C72776E71757973747B76786E72727677717B7A79
78737770767272767378737F6E7B7879747270716E73776B78706D756E71716B71716B72
716C6B707074746B736D6D766B6B6B716F766C717278707074797A706C736E756C706E73
6E7073716E6E7471717470796E717170766C75766F76676E756C6C74746E6E757E8991A6
D4F3FFFFF6D6AF9681786B746C6C76736F6C6B71736B706C6B68696866696C6C6C685E6C
6769686B6066646F66666A6968696864647065636A69666466626164695F6164646D6168
646768666164605B6666605E64645F6666625C635D5E60616761615E5B595C5E62625F60
605B5B616356606363615C66606661615E5F60635D62606867695B5D5E63625E5F606359
66615C60645E5B5B5D5C595C58605958595C515B5554585758595C57534E565C59535457
56565A595056539F00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D86560636863626563686A666C6963636C686666676C6E60695B636B665C645C626B6661
61636064686666646163666B66616D666B665B6464666669666369666563656E69696465
6564645D69666B68696464686B63696960666C666C676B6967646767696D6B6B726B6E6D
6A6E686C6C6867666C6E646E68726B696D6A6C676D6C706C6870666F66726D706C6A716E
696C63696D6E6F6E706D6D696F6E71676B6B71706D7271726E6E7473726D6D7477776D71
7E77776C7A786E717A7C7E80747D786C6C75717D77707E73717071797571747970737474
746C747D75757E7C7B767679787B70797A7C6B6D71756E716F7974706E76707873707365
716F6D767474707373767171716C73747571716E727466716C6E6F6D766E6E717474706C
6A756E766E6E717270736F6D716F6C6C6A706D6E6A70706A756F6C6F707973747E8395AD
DBFFFFFFFCD0A48876786C6A6C706F706B6E6A6E6F6E6C746C6A68686B6B616465647369
6566646468676A64616B6466646A6F686E6365696B645E676962665E5B5E696460636566
60656361615C666359605A635E63665D636366666664615B5D615A6364605E615C60675C
605964615E62635D5E6063635F6A606A5C5E5C6162655868616B5F625F676464615C6660
5C605E5F63575E605B5C635E555D5C5B605C595658535A585556545759585552585C5857
545A5654534C4EA400000000000000000000000000000000000000000000000000000000
000000000000000000000000
DF6362676163616865675E64656368656B6469666A676464676668686965666663636960
69656964645F636666676467676864646E686E686B6C69666663696866676461616C6869
6964616E6C686869696363686A6C68716F646B6D676E6F686863646C67666D656F6D6A66
70696E6E7067696D706F696B70696569696A6C6D6B6968676763696D6E6A6C6F6C6B6B6C
636C6C6C6B716F6B6E6B6C6C67747274666F736D6C737173757274767674747071767374
75756E7177717A797B717877746F767374736C797E7673707179777B777D757773757874
7471707179767574707674707B72736E727272717071756878736D7275707B71766F6A73
6E6B736D766E6C6E6D69716C6C757070736C727466756E766F736F6E7470697171736D6E
6E696C70716C72786E746E7771786E77716F6E726E747170736E6E736E70787D7C8596B4
D5FFFFFFDFB49383716A7171676C6B68696C666A637067656969696B6C6471696869666F
67686764656C646C656A6A676463646E6668666C6866666068626667666F6A685E636660
6A6368616163636067636665695E605E655D686660605C616564605C5F62606263666263
5E64616D58645B66666464635D5E63645E616161656463696B6963665D6061605F5C6661
59625E5E605E586060596059605A595D54605B59585E5E585656545954565B5A50545859
57545F565753509300000000000000000000000000000000000000000000000000000000
000000000000000000000000
E366655E5F65646966596665656364625C5C616564686B706A6968676163686068676765
646A6B6E676363686765695B606465656B65666668645E6A6A6368636764666766696C64
646C6C61646B69646D63686968666268606E646469696B6E6C646A6E6B6C676867686868
6A6C686B666C616A6868676E686A6F696B6C686C66626969686769756168676C6C6C6972
7069716E6B6B676B736E6E6F7373706972706F706873726C747070717A746F7370737378
767679817674747476796F797E7678687B73747675716E777971737B7378777675736E70
777473786C7377787F7C7571757E7176707079736D70736D6F6B766B7071736C73727376
716E6E6C6B6E6C737174706C736E6D707173706E6D7575746B6A7070696E76727570726C
6F6E6E68716E6C74746E70776D776C6B706B6E6E71706E727173706E72717479748797AC
C8DDEADDBC9B87736F706A6C68605B6E69646F6C68656568686C646866626D6668665F69
68696664686768697163676D6763656362696566666B69665C64655F6460636163676661
5C62635B635E63605E645F6661605D666266625C5B605E646365645F5B61585C605B6763
636263636061635E5860665B615C6060616159645D6B6568606969636965606461646563
5B5D57615C66625B5C5E605A605E5559625A5F60595B595E545B5B5A55595B5954595B5C
51565654574C549900000000000000000000000000000000000000000000000000000000
000000000000000000000000
DD616161636468626363616964636664646B6866686B6968696B64636568646B606B6964
615D636A6B61606667656865636C6569636C6B68686863636D69605D615E6A6868646562
636A67656661676D646C6B676869636A686E68626663706B6E69636B6C686E6C636C6D69
6F6964696E71656C736A5E6C71706E6C726969666E6B6D66746A6E68716F6968686A6A65
656F66686E706E736E6E696E6E715C766D686D696F756D676C71706E776E7271746C7570
7571726A72777871717078707A7074797073767976757D7779767772777474787178737B
736D6C7777707777706E7979696F7373717D747470736B717371737278716C6E6C73686B
6A716C6E696E716D6A716E7471706E6971686C726C6D726C696F6E6D6E716E716A687073
766771706D6E71666C7173706E68726D73706B70696D6A70716F7171686A7270777E84A3
B6BBC0BA9686786C72706A5F65666869676C6C6B6B64696A6A686E6F6E6B666468666267
686762626C656C656A63666B696B5E636967635D616168665E6062646862696560616560
685A6464605F5968636263615E68615E63606360665E5E61615A5D5E64615961615B605A
5F64646060645D625C5E5D605E606861625C6361615B5961685E5E60666B676066686463
606368616361595C58615C595D596556585C56575E5958585459595A5150515357555A56
58525255505453A000000000000000000000000000000000000000000000000000000000
000000000000000000000000
D866616668675E6668665B69676664636561646B6869686563696C6A6664655A63666762
6E6860646A646C61666165686368616369666B69655A686B706C696B605E63635E69696A
666569705B6C696B616271666663666B6C6166696A686A676B686D6665666B7263736B6C
67646B6769676D6A696973666E6D6D6B6367666966756C6C64646B6C6E69686E705F6961
6968646D6964706C71707276717170796C6A6D71716F71727471736C7473737573767575
6B6E7775736F7179756F7C7A6E787C7273716C717676706F7A767374747C7374786F7170
6F787476727478747A76776E747072727B71706C6C777475776F6C6F70736F716B707471
756F7469656E6E69686B7275726E6E726C6E6A7272727373737171706E696C6C6C726F68
6C6F6E7073737170686E6D6E6A6972696C73697269707171757467716B706F737C80869B
A1A0A094887E776C70646B696C6768696F696B6C6367696C6B6B696E6C6E63686263686A
69636A66646B6B6B656466616A6D6F6167666467636060605A6364656360615960616366
6C61655F63636163655A615E5C5C63615E5B5B5F5E6359615F5D60635C5A645E645C5C5E
61605D6360616359615E5E67615B5B636460665E6566665D6B66645F7065696C635E6664
61615B615D5D5E605763585B585C5E5B605F5958565C53565958555454565D515C565153
525852554E544EA700000000000000000000000000000000000000000000000000000000
000000000000000000000000
DC6963686863636060696766656168646669606B606E65636561656669666D6369666468
636E696C6B69635E6966716C65696963676C6B686B6D6161696C606166646765636B5F67
645F6764646A66656E666162646763616863666E706C6D6D6969636170646B666C666C6A
6C6C6A6B736C6F66686A696A66696E6F6C696570686C66626D73706C617570696F6F696C
68676B6A6B68746F6B7270686E746E6B736B70696D696D6C696E6E6A7079767172747278
7170737370746F7A7B6B78706B6C786B6E7A76717773787378807F7973797B7779706F78
747079717B767A78737873736F746D6D7575687768757A71786C737373766E6D72747171
716A76686E6E76766F6E6E6C726E72746E6D68706C717273786D736E7175716C74687070
6D736F6D766971716C6F6B6C6F6B6B6D6B6D696C716D6E6671746C6F736B6C767371837E
8E918A807C777066676769646969636869666A6A6D6B656B696869636D69686C646A6A65
6A676170646B63606F69646869675B6358636165645D5E565E5E6164636863635C63665B
5D5C65635B665D646062605F5B5E5C606366695E6059686061615C615E5D5B66605A605B
646861615C5C5E5C5E605C625B68645F63656361615D6162656C6D6C6B676A6669606365
666B615F6160655D5E595E5C5C55535A565B5B5956505A5960585956565B5C5A58575850
535658594E4D56A300000000000000000000000000000000000000000000000000000000
000000000000000000000000
D4616869646468656666646B676871616A67646868636B6B6960676466626B6068686369
62646266696468636D68646C69646D6E66646362616367676664685C646267666A675E69
6361676863675F68636B68716168696B6763666A6969666C696369706868666E696B6968
6D686B67666E6A68686A706D6B6C6D646B6E65676F6C6C696A6368676D707069686D6366
6369686A6B706A6E697069736E69676C6E706E7170716C716F736A6E7271716E7A746F76
6D6F71786778777C767675716B70757377786B716E7778737077797879797B7676726D71
6F6E75707A737179727578726F7076717869706D74766F7073747474736C7172726E7674
6D6B696E6C6A6F70716E76737472706F6C676F6F6E716A736E6E68716E7070716C6E7176
6A69716D6F69696F7268676F6E657270716978716B6C6E707468706A70736C716F737374
7E76777D78736E72676A646365646370696C6166696F686B6A6D71706B65706866666365
65626961646466656D67636E6668666A6469685E62646165635F60636160636362646B5E
616261615B64645A5E60615D60595D63595B68646567636459636359605A5F63635C6164
6560605F5C595F585E626065605E61615E5F5E626461686163666469686A6B66666B685E
5E66565E5E56606060615C565B5E5C5A5B5B615A5A5B545A5656545454565B605653594E
575754544F5453A400000000000000000000000000000000000000000000000000000000
000000000000000000000000
E062696461666369636266696360626666706C68616D666666636E696168616864616766
6A6366636D6E606665616066696269636965636A646663666167666A686668656667645F
686661666D6A6563666C6766696A67686967686368666163666C6C656167696D6667666C
686F646C6D686E6C70696971696B7169636C67666966666D6F6C69696A696369686C6769
6B6B6B69647073736E6F6C70666B716F736C6A6B6F6D6E71746F7473787369777473766E
766F6B70756C7374707377736F716B726D797574776F7070776C74797378736F70726E74
71737B7B7B7276787975736E6F70706B70686E6B717474717873766E7275776F73686E69
706B726C70736B71736C7271717075736A6B6F756F766C6773706F706B6E6C6E766C6D71
7373686B6C69736A716E706A726B676D6C6C6C6C736B6B696B6D6E72696E716C666F7571
756D746C736A6B6B696E636766646B5F6B69656A6F6766646F6A666A626864646B686663
6369666664686E636B6D6E66686B706163676359646766636D615E5C665B61605D60625D
5D686164635B5C5C615F645C6164605B6163585D6160625E63625D5D5B615C5D61585966
635A645E635D626262585F5F586166615F6166616469616B6169656374726F6F69686069
64656263595D5E60625A585C5B585C6056595756585553595C545C5851585F505655545B
58564D53515350A100000000000000000000000000000000000000000000000000000000
000000000000000000000000
DA6161616168625F62666366645F636565635D606B60705F5E636D65606A6469706B6564
636267636864626966736B6669666568686363676163686865636665696464666665636C
66686B6C60636965646466636B6766646D636869696D69616860676C69646869696B6265
696D5F6966646E6D69666C6365686E5E6C6461626F64676C68686B666B736C6E69636470
6570696D6D6C716B63696771686C6A6B6A6E6C716A6E6B7A707271717476697670717071
6B7673706B767272707274726D7B6D76786F6A6E6E7374766E767079736E76747470786C
6E707071707B6E7470797072736A737469736D71776B68757873717277796B6C696C6B73
6E656970746E6F6E6A7471726E73736A6E6E6870686C69716E736C71716F71696E6D6675
66716E647071646667666C6F7066716B69726C6C69696D6C6A736A706B6F6E6F6E63746C
6E736F7168706A6E6E6C666768686A666B6A65616870626C67676968696B696968676861
676F64696B636360666466675E676361646361636561655E646463615D5660635E5D5E5C
605D635B606561635F5B60605C5C6163605E595B5B6160645B5B605B645E665D5A5C6061
64625D59655E5E5F5F6164545C666466636167636260635F676C6F69686E6C72696C656C
6462656263615E6C625C5E635B545E595B5E5D58595E5A5956545F545A565A5A51525856
54545A56575651B000000000000000000000000000000000000000000000000000000000
000000000000000000000000
DA6463615F5E66646466695E66606C6D666268696964606547665F616563616960626066
66696669666B60686B616C68626065636268676167646B66616263666868666860686F66
656165666669666863706365675F6168646664686764666466646C6E69686C6368676964
6769686C67676B6A6A687070656A6A6C686965666368676E6C686A706D6C6E6971696960
6969686B6C696B706B6C686C716C6C6E716D64636F6D6E7374717170706E707273686E70
73736A73786E6A74726F776F746F75667170736F7073767371727174736F7668706C7472
748070776C7173747676747A69717472746C71787676737574777571746E6E6A6C736E68
67716A6A696D716F76717372736F6C7178706E68736F70736C706C6B6E70696F6A6C7377
6C6E6E696C6C74706E74736D68736A6E766A73706D706E6B6B6D6969696D646868736870
6E716C6C63706E696C6E6A6C616B686869656469656C695B636D69666A666D67666D6066
6B6A6668655E646464625E646463676760626161626960616362605E636168645E63615C
635E645C605A605C5C5B5B5D5E665E5E5F5E61675F5D5E6662605E5F61615E5E5E5D625C
5C695B5E5E5D5E5C595C5D605B6165605C636462606669696E646B686A69636C68616E60
6B676762655D5C575D645B5E5E5E5E5A565B5D59615359585B5A5B5C6458535B59535954
4D53515C4E5B55AC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E0626461655D6167636363666166616667615E616461636862696765666C6C616460696D
63686369636864626366685F6264696661636C6866606B6A61616B6666685E5D62626767
63676E67646B606966626C696B646C636E6868636B6A6C6F636A66626C6D666F6A6C6768
6C68696970676B62686768687166636464626B6E6863636768696C6D6E6C6B6E696A6F6E
696B666E686E6E71716E696776726C6B706F69657076716873766C70716E6B7574786972
6C717072736F766D71746B6D757073706F6C7471706D6E6F73716B6E767C71716F707373
6E7170787283767379716F6F7479767175757B777477757C747270706F6C65736F6B6E6E
6E716C72716C766B6E70727470736A786A776C706E716E6C716E6D6C646D6F6C70706E6E
6F70696469766B646B636D726F74756B6A6B6C696A70736F69666B6E6961616A6461686D
69685D6A65677269656D686E6A65696763716664666A6661616D61646768626969716869
6B6567646664606261646162686C6464616364645F615E5E68626866696067605D5F6865
63605E5B615A62605E5B6068655B665E61605F6366566060646863595963625B615E5E5F
64596360605C615E5B605C62585E5B606463625E60676161666D69646B706D716E6C746A
6B6E63636060605E636063605D5E5C5F5C605A575E5B5E585A5D595E575D5852565B5654
545B5A53585352A600000000000000000000000000000000000000000000000000000000
000000000000000000000000
DE61665D645F6565606B646266666B6B6B6967686668646861616261626B64625E666164
64686A66686768636864686C696668625C6A61685D64636162685D686767626860646268
666865686868646A6A6864686669676B696D62606B686969616869686B666861676D6769
696866696A606868696C67696E6868666B6B6A69696B68666573666B6A6B656B6E706468
6B646971686E706E70717371746D736E71666C726C6E6D696A6E766E736B6F72736C6B73
7171796F6B76707376746F78786D6C707074736F71746E6D6E73717470726E78726D6E6C
69736E787069756C7371727172767975736C747171747A6D74756C72716B70726C696771
727066716A6C6E676E6C726C726C7069666D7172716C6B716B6E6F67646B6F6B65736C6C
6970717171686E636E666B746E7170686A6E666D716E6D726E69726F6A7163696C69686B
686E6662686E6F696468696A6968666266616B6B67666C676863666A66666B6362676068
686B69626264685E63606464666561655E61635D5F666561636663645F69585F615E6468
605B605C59645E5C64595D5954606160605B585E6060605C635E5F5D636066595C5D5C64
5E585C585B5C645C5963635C606060626963616268656769687269696E6C716E6C736B70
6C69686B6266616362615E63635656645A5A5B5A565B56545A55545C5B595C575651595B
5855585850594FAC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
DE6366615C626067616369676666626A5E6561636460686F65686A6261666E5E68606160
6368696562636864626166606A6669676461616565625C66656560686366696363656B6E
6666656766646068686860636A6768685F69636D696468646A686A686374686C6C6F686E
6F6B71666B696E6967656666666A606769666664646968676762746968696D6E70675F67
68696B6B6870626B746A6B6E6E726E716A736D71756E6B746E6D6E736F6B6D726C70756E
7470707270716E6F7171687072766E7668777473757770716F7375718073716E736B6B76
747373706C747476726E716F69717D70737B74756C786E736C6B6C6E696C6F6C71657268
6A6C726F6B74676E6A6E6A74716B6C746E7072736D6B706B6E74746B6E6E64696F69666F
666E6B6B6F6F606C6A6F67626E666D686B687170666C6C6C6C6E626C6963696C6A636868
6168686770696F69696B646B666B66666667666866656466646969656B6C67656863696C
616C6467636969666662635C626264686466606368595C68645D6662625A685E60605A5C
645B5F616262606060635C5F64635960595F5E5B5C5C645F675F5B68616159585C5C5F5E
5E5E596064625E5E5A5E59595B5C616561616668646271696B6C7168687270776A747371
686B6463666B5E63616165615E63545B5D5B5D5559585B545A59595656555C5B5D555C56
5459594E594D54AC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
DE6A5E696163646668616468605C6362696169634C566663676B6065696464636B65635E
6361666469646362656664646368606462696866696963646A6361635F62676364606364
626B636867676969646861645D646E676D66696A6B6A64656969656D70646C666F686566
68716B686C67696A646E696A6869676F695E706967676A66686E6466696E6568676C6C6D
636C686A6A6B6E666D776C6A736876687274746B6B71717173677270706E7069706F7170
686863736D6D6A7071646E706E6971736F6C737173736B716E71746C706C6F6E76697175
6C6870706C737B6D7173746A7072727A74737472726C6E706A77686D6B7072716969746D
706C71696D736E686B6D716C7071736B6E726C6E706B6D6C6E6F6F69706C686E6A696D6E
6A706869686E736B686968716E707170716E68706F6B73716E6D70725E68676461666964
6E636868686F6B685F686B6B6A6668646266656766646464636664686666616D64646A61
6363696C696765696568666965636164635D5F5C695B6068675B675C5B63615A5C62675D
625D5E625D64665E5D6161605C5E60615C5F5C605E5F5C66645F5D5B635F616263525E5A
59605F585E5B5A5C5B5B595F606268626068666660656F7366687170747878746B6F6D74
716C6D6B6964646861685863565E5D59576159505B5959595B56545C5C595C5356595456
5352535455564EA600000000000000000000000000000000000000000000000000000000
000000000000000000000000
DE5E685E686166646663615F645E6164616C65615B6164636966676E6B68636661636261
6365676164646662616966646166636463695D695C636863645C5C646263676862686167
66635E656969666164616B65616D626770666B6B6865636168696967636464676D67716B
6964636B70636369706C6668686F6B726E686A6967676266656A696763646F6D6E696C6D
736C6868706C72666E6E6E71736F74696E6B707570696D6B6B6F736F6E70706D6F6B7173
76716E6E6D716B6E7373716C736F71706F6C6E6C696C707474736C76756C766E6B6C706F
6E73716E736C706B6F706A6968707070666D6E736C726B6E706E74697069716F696E706B
6C746C696B676E6971746C686E686D71696B70696C6C686D6B7371646E6A6F616B696768
6D6F646E6D6A686D6B67656968756C716C6B706B6B726469697066666F62686D68656766
66676C666E6371716969666E636466616363645F6B6066686464696A6D666463676C6366
63666E65646565636165656364666461666466675C635B5F5C645C645B635D5B60665C61
6459616259655B615C5D635B615F565D585B5B5E5C615E64625A605F63665C5B5E585E60
5E5E5A5E5A5B5F585C5C5E655B61665E635E64656A66686B686A6D717874777374737C74
7675746F6967636A5D616056665E5C605460595A5C605B5B515B565D5C5B565659565956
5759544E5957539D00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E1615C5E655F666666696563656462636569666B6B6868675C6866646564636960656763
5E6362665E6763615E6C6B64686C6364696B6A685F69676D615F6363626864696667646B
6368636C66666A6B666568686B62685F66686B646967637162656864646766686B6E6B68
6B6862686B6E6F6D6B6467686C6F696864696C6C6D6966626A6B6B6A616E666A68666D6A
70706A6B6966696C6C6B6A6C7076736F706D756974706E73686870706E64716E71706E6F
75686C716E6A72707771706C6E756974746971766C736E736C6C716974746F7368717373
6F7971706B6C736B74716E6E746F78707971786E716D706973686D6C696B686C6A696F70
6E696C6E70736C6C6D6E66726C706C6C7170676E646D6B6B6E6E6F6E696E6B646866746B
6C666B666C6D7468636B716C6E6B6E696F73666B6C70706F6E7169666C646E6969696369
626464646E686363666766646965686367646D69646464675E6363646667646A63615E63
666565696A61656366636B5A6860616360655E5B635A615A5B626162605E65615B596165
615B6362635B5E5C6362605E63575B5F5C61616263636C636460625E605E5E5E5F5E595F
5E64545B5B615A60605C5C5E5B6358635D67646463696566736F746E7A777079737C7870
7C7C6E71786D70676B6364625C6361575C545F5C60565C55585860605B5B5D5357545959
59505558514E56A600000000000000000000000000000000000000000000000000000000
000000000000000000000000
E4596C616564676766695F655C64696869636F6668665E676466635F5C5F60636866665E
686365686A617163665E636365676661636169666C6569635D63625E645E696364666666
615C6465666762616864636064666569616367636766686565646164696A696863646663
7369636C67686D68676C696469706D6E666A6C6B66686C706C5F636C6964646C6E68696E
6F696C6D697070686869686D736771706E6B707A7169686E73746F6D6B6971746B6B6E6C
6F736B7B70677374777670717274696A766F70737975786C7474746B6C7274716C6B786C
706C696B6D70766C6D69717074726D706C6E6C706A74756A6E71746B6C6E70716B686E68
786B6D6C6E676B6864716F66716D706A6A6A686C6A706B6A696D716968646B6F666A6C66
6C69716E706E69716C746F716B706D716670716B6969686B6C686A64686E6C6B6D696662
636369696A6668686568646963666466646E61626964606864666E656B6966675F616665
6C695D675F676664665F67686E5F5E616361636061656061495C5E6663636660615E6063
62675F545A5E605D5964605C5C5E6156585A5D6160645D646661635A5D5E5C5D58535F59
5D5E5D5B5C5C595F5760605C5B6462655B626368686C6B6B6A76697073768077777B897C
80817B7C746D6C666B6361645D64635C605C61595859585C535457515957555855565656
4B555C59555954AD00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D8555C6763656169685F666066626167656160616962636164616A61606766676D6A6165
6266685F636366666362646463666163686463666261616C695C6764667063636460656A
63686762636664686463636666645E67686C6E65686A6467676666656C6A6F758B717471
68616366626163666870676668646C6466667068666B64606369666B64646D6A666B6968
68706B69696968696D696C6C6C666C726871706C74766B7069747472676C686E6C6B6B70
7070716666716E6B6B6B6D706A6F716F716C74716F736F6E6E736E70696A737776747169
6E6F696B6F70696F6F6F746D6E71736F75676F75746C6C6971706F7173746E6D686E6C6C
736C666D746B696D6C6C6B716C7777736D6F666C6E6869666B71686A656D6869666E6E72
716C676D6864646E6C6C716E71726E6B706D687069706F6C666D6A666C69676463676468
6664636A616B6B636B6868636465645C6673696B6B656860686B61646165685F636E636C
6565666869646167646A686566636360635D6561625C66675C6163675C646062645E615E
6160605A5E5F5B685B5D5B5C5E5C5356625C5D5E62666663625464605A625B615C595456
555C5655565E5B5C5D5E585E565E60616B6969656F676B6B70706D7370717A8188878286
8C818882787E79716A6B67646865655C5960595056595B595C585A585C5654545A52534F
535856564E5554A900000000000000000000000000000000000000000000000000000000
000000000000000000000000
DB6866666668635F6865636368636767666161606D626167656C63656364606360666664
606065666460636368606062616064656E6668696763646A625C635C6365636869656564
636B5E696369696863636D5F68666364616064646B6968636664676766686C7488696B65
67706D696964696969696B64686465656A6868696C747063636568616E666166706C6C6A
737364716E6D6A696E70716C6E676F696E6E736E6F7470706D706D6B6C6E666C6C706C6B
686F70716E686E686A6C77746D74736C6C76737376736F7670716C686F756E6E72737272
716C6D70697270716D716C6970746C726B726E756E6A6E68716B6B70716C6F696E6C7073
706869756C696C706F6E737674747D737369706E7071756B6C6B6D6B6B696B6B6B6A6B6B
626B6A6961657469706A6D6E6762687465726F696E666B706F6B6B696865716964605E64
64636C5B6564686C66665F69636267695C666469606E6466626666666667636364646C63
686864606F60646863635E616B63666663646866645F66605C635C6460635E6460605F5E
5C5A5C62615D5E62605A60605D605C5D575C62565E63635C5D635B5F645C63615B585B5D
59565C636159635C5B56646358585F5C6460616261686870716C7A72787F818484898D95
9298918B897C787070646B606A62635E5E615B585D60575F585E56585860595C5A52504D
545555544E534EAA00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D46860656467696661686A66666162656466636468676364656863616964696860606163
6A66676A616769635E6360636666666868646061616A66635862686566686E6962646468
6566646361686363676B6A676A6467676B61686867676463666466686A6E686B6E63686F
686C6567636C646C6969626866646D6A666968686C6C69706A6C6E636E6B69696D6B6C6B
67676F6C706E6A6E6F7076786E6B716A746A73716E6C736B6C6E69686E7166756E6A7270
73706D716E6C7472746F6E70716F6D6C70776570726D716D6C72756A706C70686E648072
6E736C666A6E696972736F6C7172757070736C6C746A6B70736976736B68706B6C676964
6C6F7671696869726B756C72756C6F6B6A6D65666A6D68726B6C6864696A6E6868636969
6B66606F6E6C676F6E6A636D67646B6C676F6B6D70696C616C6A5E6E69646466656C5E62
6166606163606161635A655F5E605B64676E66646466666A656968666965686661626365
626B63616164686166645D615D5C646260615D66645F5D5B63625C5C62635D5D62635E63
6154585C5B5E59625F5C5C5D5D525E5966645D6463636166616361615B5E565B60565A61
565D5F585F59605C605C63636163655F5D64646B68616F646E6D7171787D848489919CA3
A3A8A09D978D867974706764656565615B605B615C595C5F5D62565657565B5B55555954
535552595A5456AC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
DC68676A646A63645D646463606D7063676569696168646361626067666D5D6868606D63
636661646862636268636361685F62636364646A6765646364666061635C6162636B6164
6B645960695D6B686763636461636A696A6669686667657163636863676E686E6E6B7266
7166686C6A666869636B646B6A61696468636D696966696C6B6B66656B6B6A6B6C6B6A70
6C69646965686667706E6C6B70686E7369716B6C6E696E69656D6B73716F6B6D686C7171
72726377716F6275726E706E70706A6C736E717670716C6B76766F716D6C746C6F796C73
696C716E746E716B6E69707372706D6C7174706E71736C707073656F6A75746B666A6C6B
766C676A6E6F706C6973706E716A6E706C6E6B706E6B6C6C6A68746C68666B706E6C7069
6B6874706C696B6D6E6E6668686B746C6A666A6967696A6B696E68666A6E6C6661646068
6563686360616061606162626665636164636563686C6061666C6B676866656268636063
656468696A6364605D60615D67606163675F60645E635F5C615F6060636161615E605E5F
5D585E5963615B64615E5C5B5D60625D5D5A6859605D5C5C57646060595B5E5D585A5E58
5C5D5B5A57595B605B5D566056605E5D60666C6268646C6B67696F6771798185919EA9B1
C0C1B7B3A3948E7C796E696B66615E5C5B61605C595B585C5E5A545757585455535A5B54
52565B57504F58AA00000000000000000000000000000000000000000000000000000000
000000000000000000000000
DE64646760645D615D6968676B6366606B63676364605F686664616265606B6260636269
6E63636665636B645B61686163656B6669636163665D626863616A68636467625B606668
646C6469676967666C6B687061615F64606C6064696460646368686B6C606A6C6E6E706B
6F68675D686F685B6869686F666E6A646667656B6A696B696B6C6F6661696D646F646666
6C696966686670686966666468696F666A6B6A6B676E686968706A6E6B6B6C68766F6C77
6C6E6B72697368706C6F6E787972716E776A6B6473736973716F6C6C68716C6B6F69696F
6C7168737170736E6C6E636A767169706F716C726A7275686F70707475786775666E6B69
6B716C7174666C6C636B69716E6F716E716C746B73696E686E6B6B69696D6B66666E666D
67666763686E71686A6F6E6B6F71716C69686B6D6D6B626D6B696D696767666468616264
67656366686060666760636064646264616662675C6362616C6C70626066616A6561626B
63685C5C6167686961626360685F5A615C6165635C6262615F63605B5B5C625C61616462
5E605B5E565C5A5A605E605661615D605C59596061655C5C5B605B5A59595B595E585F5E
5A575C595E5C5C5E5861666061615E625E60626165646363716A6F67767A7C8999A1B3C3
DBD5D6CDB5A992827A74706968606263605B615E5B5B5A5C5D595B5A58595B595558585B
58575B545C5858A300000000000000000000000000000000000000000000000000000000
000000000000000000000000
D6646963695D626D696863686369645E6A73686366616B61646266676363646964636267
66615F686062646864616B676361705C6161635B606465685D605E616466635D61646966
626A666362636A64667162636365696C606362696668645E63686B6B6C7064716A686C66
6C6B696A646466666A636C6864666668686568686460686374686460686969666C696E68
686963616364666B646D6E6C6A7470686B706C6C6B6A656E6D6C6A6D696B6E6D6C6B6B71
6B6C706F766E6C75707375706E706D68726B7372736F6A736D6B71706E616F6F74707176
716E78716A72766E6E693C616E69727469716C6C73766F716E70707070706866726E6871
6C6C657366716E746E6E6F6E6C6C686C6A6C71696868696E6E706E6B6869697066696E6D
6B686B6B6B666C716A6E706F6E626C6D686C6E706C67686B696C6E686B6E6E6C68646064
6B6863686665605F5C606B6363666264656A636F6663666460646860656B636566696366
6466636860646161625D666163666363606160685C5E61605C605C63656360666167635B
59615A575662576064595E5C585E5B59535E5B5E5D5B5B5C635D595B5B5C575E5A5E5C5B
5B5B535D5D5B5861585A615E5E595F6061636064666467696C707275767C8290A1ABC4D3
EBF3F4E6C9B8A78E8276786C676463615E565C545C595B5C59585E5455585C5459565656
59565458544E51AB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D661646368605E68635F666167665E61606D656C686160586B6767606E66646168666263
666160655F6459696064636461626466606B61596666676A616667605D635E6869666868
6B645D656563646E686C65686669605F69616B64656A6460646269636A636E6A6E666C68
6C716566656B695E61686563636468626668666A6466686D6668646C66686165635C615E
6362635F626461606068696C68676C6C6B6A69696C696E716A64696C6E6F6B756F6E7071
707370716D73706E6B70626C70796C6D776C6E696C6E716C706C6B6E6E71746E74696A6C
7773706B746A71716E6C6B6D7377736F79686E706C6D706B6E6E6C717378686C6E6B716B
6B6A716C6F686E6E6B726B6C716E6B69706D71666A6A7072696C6E6C6B696D69696E666A
6E6F716C6C686969696E626F6A6A697171696E6664696D6866696A6C6C686B6A696E686E
6E5D616B5C64635E5F625C666661696A6667636863696566615E60636362696966616369
65676660625D5C5C6566645B626161675E5C615D5E596064665E615E616160635E5D615C
5C5A616361635A5B61605F575C615D60625B6063606160595E59555E5F5C5C5E5E55595C
565D59615C5D5A5A5E68595958585E6462655E645C64696D6C6C696A737C83939EB8D4F0
FFFFFFFFE0C1A48E8177756B64686263615B57585E5E5D5C505B5B525658515C56535A5B
5E525958535153B200000000000000000000000000000000000000000000000000000000
000000000000000000000000
DC6361695C63616564646364686161656761686A65616B685E63656363686163625F6461
64645B665E66615E63656464615E6965635D615D5B646069686266645F6366696360605E
64636A6866646166696460646260676669626569686A606669675E66636C6F6B6A6D6668
6461656E66636862646467646965696A62655D60616D6A6B6962616165676365615F5E5C
5F5758595F5E5F6464636466696C6D696A716D6C6A6B6A6D706C6D6D6D66656669727071
6F6A6C6C736D70706E75746D736A737369696B6F737868747169756E727076746F746F74
716D6A6C6E6E707170706A71747471696D6E716A6A786F73736B7073716F716F6D696469
676B686B6D666C6C6F7069696471696B66666C6C726E6F646762676C6D706C6E716E6871
6B6966716C6B66686A66706E6C706C6C6B637166666B6B6D6D6C6B6868616B6A6F676969
656A63665F6B68666367656468616B6763606B636963636362685B6D6D615E65605F6166
635A645D606664615C6165605E666A6165665C66626064545C61655C5D5663615E636160
615B5C5B5B5A5D6359605C585C5B63595F595F586157565B595D5A5E5E605855565C6356
5E58605D5C5A60595E6060615F5D605F5E60636363646668626D6870727B8594A3B3D8F4
FFFFFFFFE7D2AE948A7F7073696B6568686754615957575E5C5B57565A585C5856535A5C
56575350555753AE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
DB63636665696360636B6C6367635E646A645F5E5C685D6765616664646664645C605E61
5C60606361635E6363616564665E61645E606366635F606366695E6368655E6064686364
63625F6863635F666365656668606560606463656861616466656766696F6E6B6B6A6367
6C676264675E5F616B6268665E6C6361686C64695E646363596267605964595E5C585E57
5A56595C595E5E5E61615E626A6A686A6E69706A6B686B6B706B60686C706D7164727771
716F72756B707869727168716E6B716E71726C746F696F686F72696B726C706F6F6C6F76
6B6B726C68706A666E667672706E70696A6B736F6F67716E716D7174716E6E6A71717063
6C6E686E6C6F6E6C746E6E696A686F666D6A69686B6F6868696A656D676D636A68686569
6C69666B68666C696869666B6A696668746E6F6C6E626C6C60686466666E63666F626566
6B6866636A616163686D616B5E666661635E65666C6563646466615E675F68645F636863
606768646168645F61625C5F61665F62686967625C5F5D625C5E5E5B5C5C6361615C6061
59615B5D605E58595C5C55575C635E5B5C5A5E525960595C5C6560585D545A6061585B60
5F605C6059575D595C5A5C5E5A5F5B605F5D6461615A6A6A64686C7168788493A1BCDEFF
FFFFFFFFE4C8A795837E7D6F6C69616061615B5B5C5C5E5C605E59585856505B585C584E
5858545C525355AE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
E16664616168606160666161626C666467665E606166636963646C65615F6563675E6664
5B67646365666364666A67635E6163645C5E605F616163646166616A61606468605F665B
6064646B64675B626A6A62626163616466646668695C69666862636B6363686666636863
6861636866686363646B6065636163656361616C695D63605E6661625D5C5B585D5E5956
565853575856585255665761605F6A626E706B6C6C68696C6D697373646B6E706B6E6B6D
6E69746E6E6B717670736F6F70726F726C70726F72686E696F6B6C6F7373706D6E737078
676C706E696A656E646C656E7373736C6C696B6A736F6F7076717070766D716C716E666D
6E736B646C6B6D6E686C6C6168706666676C67686B6D6C73696C69666B6B68676E6B6B71
6E696B6D666E6B69636B65676A676869716369686C6A6C6B6E676B6B6869636B60636C61
6C64666664646961686B6B66606069636B616560656A67685E6367676B60605E63606363
6269616260625B656562686266646A66616663606462605C60665A63605E66615D64605E
60605E595A585F5E5E5E59585A5D625A5C5E5E5C5B5E5E545D5E5D595C5B5B5C5B565B58
5F5C5C585B5958515F5B5B5B585E5C61635C62695F5B66636C6B657171767A8C9DBEDBFC
FFFFFFF9E0BC9C8E8E8278757165646165605D585B59585B5359595E545252515C545458
53575C5759535DAC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
DE6464686362646568696B5E6766646163606B5C6461606663615E6462646E6165666660
62585E60615F5F63645E6065695E605D6662636364656060636363646767646566666461
666067636A636A6160665F6963636964666B625E6261696164666363676362666763656C
65626F6968666664656968636660636066606969646967606864646B5E5E5E59565F544C
58534C5157595A55545B5D5E6661616B65696C696B6C6C68676969716C6B686E686C6A6C
666F6E676E6F6E67726C7076706E71706F716D697173706D736E766C7166716F6E71756C
706F676B686B6D7067686C7470636C6873716870716C6E70736A6C7067716C766B6B6867
696C666E6969706E71666B6B6B726A6569746F69676E64676D6C6C6E68696767636A6870
6669666B616C74686E66696B6663696B696B636E6C686B6E6A69636A6E66676962636D61
68646669666F6A6C66686466646265606164696163606964676768646862615F615C6160
645C5F62636367636661626970646B6E636661635D64615C605E60606060655F565B6164
615C5D5D5D5A5B616457605C5C5B605654606060585B5F5B605A5B5C6156595F58585C58
54605B5F5A6559645B65565B6360605D5A60606864606B6D6466636E73747F889CB4D3E1
FEFFFFDED2B4A2918784756C6F6C606A5F615B585E5A585B55525B515F555B5A56595853
55585556515651B400000000000000000000000000000000000000000000000000000000
000000000000000000000000
DB695F6161656365615E63635E66646566665F675F5C7064656666685F696069665E6163
6168626060666063625C616661666368636461615C61606760626364655D6662685E6469
5662666664615C626769606468656466656D63656363656167616463686C6860656A686A
6868666E685E65616A61656167625E646461655F6563636C616666645D5E595D5C564F55
5D4C56544B5154565453595B626067686B6B6E716C6568686B656C69716C6C6266706666
6C686B6F6E716B6C716D6B676C716F6E716D726C6D6C6F696E6E72746E6E6C6A6E6F6E64
6C6769696A726A6A686C69686E686C6D6C70666C686E7369746C74706E6D726E6E6B706B
676B6D686E6D6A716E686B67676E6E6C706D686C6C6B69696B6E62656F6E6C6F6D6C6F68
6A6769696A67696563686C6F6B6B686B666D6871726B67667069686D636864606A6C6668
696B63605C6A6A666969665F6B64646C6C686064666B61606965666C6861616463626760
60626D5F605C665C635969646A666C68666461615C655C615E66656762605B666662585E
595C5B5F5D5E58645E6056615D585E585E6260675E61635958595D5E5B58596056605660
605E60615C595E555E5E5E59585959606064615D5E63636564686C726D7C787E98A3BED1
E3ECD5C5BEAC9B8F8B81806C71686A5F5D625D645B595B5B57595B56595B565550585553
565B5D52545458B000000000000000000000000000000000000000000000000000000000
000000000000000000000000
D4686664666C6C656860625E665F666363676C65696969646C6265686666686263686365
656561616462606560646165666266615E5A6163666461625A5F60646169686662666561
6463626166646469625F62676661636068636361605F685E60686463675E6064686C6169
6C656F716A64676C666669645B6064666166606866615A5B62686468645E5B5951575C56
4F544F535150515A595356535B5C5B655D696569646F6B6F6E6B706B6B716B6F706E7168
6E6B6E7070737170726C6E6F716E6C6B6A6C6C6D696D76716C6368706E6F6E696E6A676C
6B6C696F71716B6968686B70676D6E686F67666E6B766C71726C6C6B6D6E6B6C6E6D6B72
6B6463636D6E6C6B6E686C6874686B706C6B68636C696E666E676E686E6D7470696F686A
626469696865646863696865696B6C6966656A696E65686666696A6368676B6867686268
5E67646E666966655C69686E6461686166696566646068626368686C5C66665B60636660
64616264616069685F69686263696467646165626056616360595D655E66625C5C645F5D
636263605D5E625F5B5B5D5457545F6064566060595459635C6157525959615C5B575B5C
56555D575C6059585C5A545D5D5C5E5C5B5D556162616262655B66676D727B778994ABAE
C4C3C0BCA9A194898E77767371666964635E645E5B5D615A5C5B56595C565953545A5B5A
5058555A4C4C52A600000000000000000000000000000000000000000000000000000000
000000000000000000000000
DF61696365635F636161636461606162635D5B5F6865665E646663686161686064636260
615D665F5F5F626364665F6761636365646767686662605F616366635C6061606D636061
635E646961616061686861686068636C61606064645F65676468635E6C6A656B64697167
65726A6C636563655D6661636164626861635E615E6364607066645C6159575958585458
5354565053585657545558595C5B5B60606A606D656469686E646C6D697069656F6C696E
6B6C776A6A6A6E6D6E736B707270706B6972716F746B716C7376736A687167736E6D686B
6B6E6C6E73666B6D6D6768736E71726D68766E6D696C6E6A6869676F6B6E6E6B736E6872
6B6B66696C72716A6E6D69676D696A686B67613B69666F6B656C6E6E68696B6866716765
6B6E676670606666696F6A6866686A676A6F6C6A696C68696B6968636565656366696463
646C6268646160636B6365685F6865676E5B67685E5E656866646361666562686B606761
6466646166665E616264616364686C6066645C5D61605D5A645F605F605E58605B5F5B5B
625E565B5E61565E606159575B67615E5B5B5963605E595C5A5C58605961556156595962
5B5E59535B60645C525B4A4C605F61605D5B6466616464635F626A636A68747C868D939B
AAA3A0A79E968985817D81716D65666B645C5D625D635B5A5A5960575C545758535A545E
525C535A595452AE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D85C646862616A60606260615E69616360646065646866635E616269605E696364646268
67696060605F6461675B6660646061636E5E5C65605E63646265646961605E5E6067686B
63606469616A68636268646664685F64645D6A6B6863606162646863615E696A625D6E75
6971696B686F6369635E6566636E61606566645B6868606468615E665B5B5954524F5456
545B545B6053585B5754545B5A56635E6068696769686D626B686A68716B6B6E6D61676A
6E6C756E69616E71696F6E716A6E73747268646771736A6C6A7173746B696E706E78686E
68686C6B6B70676E6F66666D7068696D69686E6E6F6C6B69696E71687066767171696B69
7165686D6C70696F686E6D626D6C676B6C6968656A6E6C696C6A6A6D70726C6B6B6E6161
6D69686B66676E6A696A6568676B706968616E646569686A646B66606C6366606C666868
656B6F69645E656967666A6C656A6565636E6D666061666168686661646666615E5A6463
61615E6364675E60625E616362616B676366586561605E6164625D635E585E625A5E5E68
605A615B645B5E5C5A5B54605E7C5B585D635B5C5F5C5B5C6057545A57635D58585B575C
575B5C5D5C5D535B5B5F50565D51555E5E5E63606561666464616B646D716E717683838C
8C91928B938C8485847B76736A6E686D61616164605D5B605B5E595A5051564E5359525B
5854525354534EA800000000000000000000000000000000000000000000000000000000
000000000000000000000000
D36164636361655E63645B66606563646663656266706868605E665F635E615C63646665
63685E5E5C5E6067615E6163655B616060605B5C5F65615E6459646468636460606C6863
63636365646566615D6164646B5F6366636A616063605B61646664665C695C64636C7079
7273736C6766615F67606A636469616361636A685E6B6A6664675B60615B53534D515659
5C565D565B53565F515B4C5A515A635960606167646E686C686B6B71696B6C6E6D70666B
6866676970706C70707170766E6D686C6F6C6F746E6B6C6A706D70706E6B6C716F636C6B
6B716F6C6E696E70786E76686C646C63696B6B6C706E736C716F6A6B716B706A686D6864
6C6269686A6B6A6E6C646673716E6B6C6E6C706A6E736D6D686C69646A686C6770676C69
6D716C6B656D6B66686C686A69716A6865646969666E6C666C656967686969605E666860
695E69686B696465675961646A635E68616161615E666064605E5C656963606663696068
646367616B635B5F6764606866606469616561605F645E635D5B67645B5F5C64515C5D63
5C5A585C5F5D5B5C5E6059635E5B575B5B6061575C59585E5B5C5A5959565C5C5D585C54
615B5A60565E595E595B5E615C5E5858655E606160606068646466646B64726C6E777C81
807D868B84847F80797A7A6C6C6964666461605C5E5E5C5B60545759565354585D555853
53515852525155A100000000000000000000000000000000000000000000000000000000
000000000000000000000000
E2636363635B66616263605F5E625F6059616064626B6364676369615F66636865605F64
63625E656364635B6267636863665F6064666661666961646160645F64605E61625F6A60
5E605C605E6161615D6461645F5B65665F645B6A666C62626B646B6364685E6A6E696B71
79746E6C695C5D64666164616968636B6063635F5E6864646C68645B6454535751545451
585C5B5B5966625A5754545A5655585E5C5E6568676B72706A6869666A6E6F6E696F6F68
6F706C706C70686C716E6B6B6C6C70746970706F6B6F6D706C736E6E716C6E67666C6966
656C68716B6F6D7170626F696D666E6B6F666B71676969686C686863736C6A6B6E706B68
676F666F6C6F636C6868696870686E6B6369666F676E6B6862666E6A6968696E6B636966
66656B6C69656863696C6C646B6965656769696E6B65686D6C6B615C6566696370616863
6166676A6664666C646463636761666C67636663686669615F6663635F69625B615E6766
666A6263665C63646369655E66636364626061635F62605D615F5B636364605C5E615E63
5C605C5D5D5C5A5B5E595B5E5B595B5C596060635E56565F60585A565961585257565D54
545B5856545A5E5B5B585B5A605B5E5863576162645F59645C6161656A6A63696B6F6F77
7977837A83747579707A7171686669716C64615C616156595C59585C5B555056545E5059
54564E54565454AD00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D161675E606868605F6361636B636660615F63645E67615F6863665B5D665F5F5C655B61
636466645E5E61635E675D64615E5E576460636B646D69635E6169685F69666160666166
606669636B64636160615D646463596464686363636660626760675D5F60646A686C7078
767876746F686C6A5C6166666459666C6468675C69616366635C645B595453484F515253
555B54595A615B59585950565650575B61616363646769646F646A69687273636E6B6A6A
68706D6C6E6D686D6E726E6E6C6E706E686F736372707370706D696A706869706C64636E
6B696F736C6B70666E786C66696A6B646F696E706C6961686570666C6569696A66666963
656365646C6C6461696C6B6E68647169666968676E716C686968646A66676C6968666C6A
67646C646C6A71646C696C686967666B66606967656D63668B806866646C60675D65646B
6663676663606764636660665C5E64666165615A6966645F5E62635F55616064665E625C
61656562595F6C686659636061605C5C63666664605E675E605C5C5D5E5C665860655E5D
565960605E625C5E5A59585D585D615963695E5C5E5C5D5A5958595A59575C5E595C5A58
5B545C5A5B5C595A5C5D61605B5E605D5C5D6060605E605E5F5B6364606C6962696A696F
71737779757D706E71786E6B6C64666968666262626057615B5F5D5B565B5B5C59565750
545859584E5555AA00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D85C6061595A5E5F606A6668635C5C5C6664605F6564636861636068696363625F606861
615D58635C64645D605E5E656B635B5E655F5C636167646765665D5E6760645B6661615C
6965625D605F64646660656061635E5E6B596461646368695D666666646162687066706D
746B6D6E6B676E636064696B6864605D615B645B60636364636461605856564C4C565459
54585C59635D5E5B5C6150544D4F525B5D5F64646471636B666069676D666B676C6E6C69
6B696F6B726968706B6B6E6F6C78756C6C656B6E706E68706D706E666B706F6B6B686970
646B636E6B6A66676B6D6A6E69696A666B717A6E6B6D67746E6F6D746B606E63706F656C
6B6D6967646966666269636C6C6871696966697269696B69686B676B6C7366696B6D6F6E
6C6E70686F72666968695D6267656C656A6A6469676672696A6C646163616C636866605F
6260646164615E65605F6360605C60656A626263655E68616B65616064655D625B5B6669
5C616663605F61615C655E615E625B605E625C5E5E6266655A63615D5F605C5E5D5C5F60
5F60565660595A5C5B5C62635D6060566661625A5B5E5F53555C585F595B5B63555A5B59
545B5C5D565B5C615B565D5E595E5B545C5A5D5E60615B5E64655E61636365656366666B
6C706A7576767573716F6C706B696B5F6663635665615E5C61595A565B555E5250585256
58555C51595550AE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D96064655959685E64626063616266635F685F605E646168675E5F645C6A5E656B5C5E5E
5C625C5F68616456605E6264645B60685E616C64646363656062656565696669605E665F
616866665F6864636061636061615E685F60635E616462635F645E685F6164646D656E69
6F6B70696660636164606A6B646365636262695E645E63655D665B5E584E4F524C545456
55605E61645E5E5361605256515556565C6267646562696C666867686B6972646A69696C
706C686E6E6A6C65736869656B66716F6E736B70696B6F666C6F74706C6C6A6E6A6B6269
68647071706E6B6468696C6A71696A6D6A6B6E6B716E696E6E68696C6D64686D6A666B68
6A7266646E6864696B6D6B6E6E68696B6C6E6D61666967696C63666E62666B686D656971
66696B6967666E676B66646A6A6469637062656965616B66716760686565646A6468636D
686167646B68636B656564646862596D6765646A5A5D636661685C6B6064685B6664635F
60625A6662615C60646463686363645F5E61596062625C5A63675D615959626364615F5B
555862585D585E5C5E5A5B635C615C595D615B5B5A5D57585A5A56565956595A5C595356
52586054595D5B605961595B5C565B5D615D585C615F605D59625C6761645E63636C646F
746C6D716B6F706C6E6968706F676461646367665C5C605D615D5C585B5B595854565754
59545350505654B100000000000000000000000000000000000000000000000000000000
000000000000000000000000
D36B58625E6362695D68645E616169616161695D5B655F636369665C61695C685F616156
57595D605D566164666364605D63606160615F646369655F6166615B605B5F5E6960626C
5E606066665F5E6165635D676861645E63585C5E5E62616463635D5B62665E6264676B66
6B64696465665E696669606465646667666362606260605C5E65585D53514A4C4F505054
5B5D635C5D655E56585556534D51585554616A686468646870706B636D6269686C676E69
6A6A6962726D6C6B676E6B6E696E6E67717069676B716E6B726D6E6D656B7369666A696B
6F6A706C69686C68696C6B68696C6E616C6C6A796D6B6B6C696A6666646F646F6B6C6F69
70696A6A68666A696666686D696E6C676D6C6B616E6F6E66616866696C636869686F696F
69666C6662666064716C6C65676665696A66646565706466646C666160685E6368686767
676464666760616462645B60686360696365655C666D5E6960695F61655C5E605F636666
6064655F6160615C696467615B60625F605E6260636161616160615C6160605E5C5D5B5B
5E535C5C5C5B605E59595D5B5E5A615E5F615B605E615C605A5C5B625C585E545B605B61
59585964585C5B5C5C5C5E545C66585B5E604C5C605D5C615A59665D6464605D64656369
5F68696467696B6B646B6E6E6C645F64636E646262595A5B605B59665A5B58595B554F58
5E5B5059564F54A400000000000000000000000000000000000000000000000000000000
000000000000000000000000
D85D69605B615E5D64666762646A685F6362666369606261635E64606268655F5F67615D
61605C5F5D5E636159615D616061625B5C60636364636B5D60646061627064686168635E
5C676766606465636368665F66645B626359645F6360616867606D686C64685E62656167
646B696364606460696E646969666569686064616164626566635B60534E4C46474C5858
565D5B5C62615B5C5B554E4D4B544E5C5B61616E6865606C6B6062686166696B666A6C6E
71697071746E6B6E686A6A6F6F716E706A696C636B696B706B6473686C6E6669736B6567
68686B6C696966716E6C6E6B66696B736C70766B6C6E686F6B6D6C666870696A6C6C736C
6968696666646B6E696E656D696E6B6A616E686868666B6768696669686C696A69646B64
6261616C6F6B6C656A64617162686C6B686D6273676468646562695E6C66666565666E61
606368686166616A665C62636A626465626463665A5E61606D606560606768615E5E5F67
6065625F63626463615F6368615D5C5B5C62625F625D5D63635C625F635E62635C63595C
5C615B60595F625C5E565E5954595D6360605C635D59545859585A60585B5D5C5E5A595C
5E546659575B5A5C565659595C5B5C596060585861615F5A5E605A5A616065635F646064
676668676963696866656765635F60696C616164625C5B5A585B5C585C5C5B5656515851
505156544F5256B000000000000000000000000000000000000000000000000000000000
000000000000000000000000
D05B5763615E596161616E5E6A66646A60605D615F615C695D62606A695F685D60606166
5E615D5E605F5863635B61645E5B63675E56535A5F69676166636463645A5E66615E6166
68635C646C5F5E6361605E63635E6B606162596560636661646460596867635E5D636463
5F64595E5E666163656864666C6363646360635F61615F635B605E5453514A49434C4B5A
58596161615C5963545A514A4B4C515F5D61656367686C6665626E686F766E6A686B6771
6C736A6D6966716869666E6B696D6D6D646D696D6C6A6B6B6E696A6D6E6D6E68696E6A6B
6A696D6964646B696169676464626E6772686C736671666A666968676A706F646B67686C
6568616C606E6F6C696D6D6E6B6E676C706E66636B75696369656A70646467666068716B
686C696D6E6865676B6768656A69646468696B63696669636864686667625C68625F6060
6B61636764666461686C645C5E626F686263646A5E6163625B615B615E6461615E616064
6065626161635F5F6361615F636364615E626162635E64666161605D5F5E60635859615F
56645E61645E605A5959555C5D5B5B5B5B5E59635C64595E5E5B58555E5861575A58585C
585A58585E585D57585E605C5B595C5B5C5E5E60635C5F5F5D56605A5F595C635E566A60
64636B61636A726C5C686B6863646F6160645B60695B645D54585E5E58555951565A5652
57555153525753B300000000000000000000000000000000000000000000000000000000
000000000000000000000000
D25A5D54625C605F626361655C6166605E595E5D5D62635C6363616661625E5A5C5D6060
5E5E6066615E5F615B655E62655D636164675E5E635C635E5F615B5C615C66616962635F
616063636161696066606364615E5E6260585D5C636462655F6161636667576161666964
635C6669635E646862666866676C6460616663636160625E665C63544F4D4F4948465053
58585B66605B5B595456515550575B56615F616369696671626D636C67696C6A69616B6A
716B626970726C736E706B6E71686C6C686B6B676C6772706E6B6668616E6C687071626E
656B6F67676A696664676867686B676D6E6E6C686E6B6868706A6A616C706C6E6C716272
6D7065686669666A666C696B6B666B686B6C646E6A686C6769636A756768696466675F69
64696C66646B63646466626669686F606A6B6363696C69656461656C69686B6163666065
6163636767615E62666264666663676066645C5C5B635F6368665E68685B625F5D625963
6360606461636964626163606663615D605E63645E5E5F5A5E5C5E625C635A5B585A5D62
615E565C5E616361645C5D5959565B5F5C5D5B5C5C615E5B61575C5C5C59565B5B5D5E62
5553565D5A5753585B5B59595B5C595F60605B5B5B5F555E5C5D61586160616462665961
6161686A636661646169685E666660606464605F5D6461555B5A5E615B5C595B595E5259
5A5A5954565450AF00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D05D6362596160605D62626866665F5C5F5B5E5B595D6163626462596469645B5F56605C
60575A5B6161665E5E6264645F63605E666065645F6063636663685E5C665F615A615C61
615F6562605C596162665D5E5B5B606263615F6463635F656563615F64605C6461596165
615E616466656061665E635B6967636466606464605E6767605A5F58574C4B49474C4E4E
585459595C5956535B56534C4E505960546164636A686B686B68686B6E6B686E65666966
6B6C6B6B6D666C696B64706E5F666D6472746F70696E656365706A696C66696A6C6B6868
69676C68686962686A646E6D6E6370716D69746A706968666F6D6C68686E68686865666A
68676961656669686B686E6B69676669656767695F696A696B6669696C6C6A6667616261
6E68646F6C64646B61706867666F6163686F66656A68636C666366616661626668665964
676C636064616165696363695D626269665D66626060685E5F606961646059625E5F5E62
68615E635C5D58636960655E615B6768635F5F616667635D605F60685E605C595F5D595D
5E635D5A605A5D58605E59595B5B5A5D5E5C60615E55525A5B565754595C55575C595E58
57565653565B6355555B5E596458595C62615C645D60585C6059585C5E5D5E5D58596862
5E5E61626362646661616765695D61605E615960585E5E5859545D5B55535B5859585353
5D555A54544F56AE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
C9606361585D5B5E68646060625F6060635C59605D6161646360696861615B5C61645C5C
5C59615C63605C5F5E6161585D5E5D61605B5C635E5F5D5D646161655D60605767626664
63636468585E635C635E605C5E6161625D635B605F6360595E61606461605C63655F605E
656B66646460646860666262636A6D65686660646264615960605E4E59524E4E4A474D50
5159536054565D514D54534E535350605E645E6868646E64606B676C6669687166696E69
6E6B666C6C6B686E7067646D6E6E6B68686B6F6B65696C6970706B6E6B6A656A6973686B
6F696E636A6666665F626B696E69696A6D6D69666D6B746E70647069636C696A6B6A676B
636C6668646B6B6865666866706A686C646B696974696A6F6B6C636C67686A64696A6968
676163636761606964666B70666469686E706964686C62696461646668636666656A5F66
665F635C5D6661686A665D6160606361605A67616663646459615B616065626364635D5D
675C60636363615E686361606A616467635E615C655E5E6163615C625B59605C5B565C4C
5A5C635C595D5C5C5F595B59645D5C5A5C5D5B5C5B615B585B615C5A5B585B605D5B5D5A
5A595E565A5E5B5C605960605960565B635E5E5B586851616059625F5B605B6061605C5B
5C606163636C655D5860646368636060605E5E635B65635E5B5C61585C565A5859595B59
5857575157514FAF00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D0615C635E5659636B5D616261535F6059626367615F6161646459665C6B6063635E5B65
60665E5E615C645E64645B59585C66616A6361615B5D60605F646758606160645E606360
656663606466646663635F5E6561605C66666362645F61666160605F6461606266635E57
60675D6069616660636460666567646969635E606468614D63645E5960504C504F4C494A
5056595659575951505757554E52545E5862626765655E6466666B64666961666663636A
6A64656B666A6C6668726E6E696B6D6A6B6F64647071676F686D6E69686E6A6A6A67666D
6E6C6669666966666A65636B6A696969656A676C6D6B636B6D756B71666A63636D6D6966
6D6D646371686E6B6E636B686969666C6963675E6B666D6B66706B6B6965646263676464
626471666267666B696A63696769646A696A6B67666A68666768685E5B61646661646360
615E656C6064675D65636369646A64645E5E676464665C6464635F5E5E60635C63606060
5F5C5E625E6163596463646860646B615E6363605D6C5D5D615F635E61605B56675C5B5F
5D605D60585A5E5F5B5E5B60595B625D615B5E5B5A625B5B5A5C5A5F5E595F5E5B615B63
585E5E585C605B5D5E5D5F555A625B62605E605C54575B58585A5B595B605D5A5C5B6163
605C5E5B59616066635E63676462645E5D5863605C5F5C5B615E5B61535C55595957565B
5D545B535A5754B400000000000000000000000000000000000000000000000000000000
000000000000000000000000
CF64605C5D5F645C6266615B61645B5E63606063636964635E6C5F60676160615D5A6168
5A635F6461666061615E5E5C645E5B5B5F5E605B60596364625B60615E60626963646464
615E5E63605E605F61595C61646065625C5E5C5D63636367685C69635E5666625E5E6160
625E6365646264656364626368625D6C65606061666363676660655852524E4E4E525249
555251485455545D4F504B4F54575C61646D61636360646A646868616C696C656668626B
666A6A6E6E636967676E64666A68626E6B6A6B646B6D6B6168736674686C6A69646C6969
6A6C70666C716E6C6E6D666A6C6F66686F736A6C6772646C686A686A6A6667636B646B69
64686B67686668646973686E696968696770615F68626871656361686D6963676065646C
68636A6C68686B64637063696E6B696A60645E6A66666866626463656A61625E615E6663
67626468666461616268595F68636065645E635C6163636471656264626061645E59605C
63656462635F5A6A63636B625E686061635F646361645C5E6061566162645D6056605B58
635D5A635E585560625A575F5F635F5B5E5C6361565A5E59545E61575959585C5B665E58
5A5A556158595C6156605A59555E5C565C585A5C59605C565E555F585C6059545B5E6158
6064605E665C64615D595D64635F5C605D56615C5E5E6258605A565A5A58535D5457585F
59575259514E53B000000000000000000000000000000000000000000000000000000000
000000000000000000000000
CB625E645C60645E5F5E5C605661575D5C63615F5C5C646E66655C5D645E6060605F6166
61605C636163635B5E5C6B5D5E615E625B58635C625D5D61675D66605F64645D665E5E60
626166646063605E5B5C60606161635E67636860635E5E5F63696463626460615A635C5D
5E626261685E66625E656065675B69625E61685E616860606566665E5A56515654595051
565258595A5C525153535853535A5E5D5F68686964686B666366666C6E64646B63696B68
6B6C706E6570686C66656466646A6E6E68686768676C686870656B6C6B696B686B6A6966
626A676F68656963736569676B6C6F696869646A656166696968636C6867666A6A6E7068
686B6E6B6C6C6B686C696B63666165626B6A6968636665686B6064656468606865646A64
645D66696C676469646E6C6969666660736469696868635B635E6A6664666662646D6469
64636561665D6666685C61675F63666365616367615F6967726560665A64586560635C60
6367595C606064666C6469676065635C615B5E5C625E62605E61615E54615D5E605D5D60
5A5B5A585E5B5C585E5C5B585D595E5E575B5B605E5C5B565B5D5B5C58555B6160595F5B
61585D595E5D5F5B5D565C605C565B605B645C5D605C585B555E596058635B5E60605960
5C5E555C59616061615E6561645B5B59655E5B5D5B5B575C5B5C5D595D5A555C56575957
55565658545853AD00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D06266606662605D595C615F5A595E5C605C5F6664605E5F6366645E5F5E626361605863
615D6262636660605C5E59615E616051635F63655C5C64616068665E636060636E645E5E
615B63645C66615F66666263635E565E66615B66616963675E5E5D6660615A6169626161
5D6566666864626264616064596861646B66686A63675E6161626264635B5D5356595D51
535758555259525D5351565C5B59625F65716C6866615F64686B6B69686B676770616C69
696D64696B6A6D70646C6C66696B6C6B6C6B66696E696E6C6A6B69696C6364676B6B6770
6A6E64616E646667686A64676C6F6A706966686966686A6769696569686866696E636A64
6665666768636C6E666065696864676569636367686A686D6C636A696B646E6567636460
63666862636464646B6B5F5D636B61656868695E646B69696669605B685F6164635B6866
5C6569686366646365665E625F61636C66606161645F6062605B645C60616261615C6063
645D60605C66645D6160616E69665E5E5D5B5E5E6365605B615D5A5E63565D5E61625E5F
5B5C6058595C615E5B5E5760575B59666059615C5C61605C605E5B585A5D5A5459585C5E
59585C5C56635B585D5856565E5457595B5B61595F5E605B5B605859585E58595A5F5961
59585B63625E5D605B5E5F61585D635E595F515B595E5B655F595E58585358575F515959
60615659555757A900000000000000000000000000000000000000000000000000000000
000000000000000000000000
CE5C61596161625F5E6565625D5C5D5B5B6065645E5F5E665E695E605F5D5C615A5B5F5E
6159636060646965606160625B5D5761615B58605E62565D675E665E5D5E5E6366675E60
5F5E5F5C635C60666367605C5B606465615F6062605E635B6064615E66635B69635E615E
5C61616667625D66665F6B64595E67636062645C665D6664606366645D60555C51545B54
5C58575758545856595953575C5C5A6965636369666664666763656A68686463666E686C
6F6662696968636E69666B6A66686468646B6967696D66696F696F676C676B666D646367
5F6B686C626E6869666B696D656569686E6A676662636B686B66676A666E66686469696A
676D636568685F69686869696366676E6C66666964616566646660646868696564636567
66636D6368666B6864626866616166646C65656A60645D616E6167646B5E64615E616161
63636762686166616161615F64645F656666605E6664615E5C6163685D5C625B5C655B61
5963616062605E6363666A6D68665F5A625C615A5E5459595E61595A615F5F5A585E605C
5F5B5D59605E5E5B615B5E5E5B5E5E5F5E5E5F60605B5E5B5B5E5C5E5556604F565E565F
59595D58525F555956595F5A605B58595D57595E56555E555C565D5E5C605C5A59595E5E
58605B54565E5C5F5B625E61625E615B635E5D5B5E60595B5D56535A565D5756545B5B51
515655515C5658AF00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D15E6163636064665E5F675A636B5A6064606262666164645B605F64645C66605E615E5C
615E55605E5E625D5A57605E5B6060595961605A63626057606360685F67615D5D5B6165
5B63656766666264606160635D64615F64635E66615E635C605E61646366616061606361
605C62635C60665E5E615B61656B6364676560676169605B63636360626265605F5B5C5E
5957605956604E545B59585C5E605F616B66686966636D68646E6A6471686A6765696E6A
646A696F706C6B64696367706D5F6F696E676E6466636D696E6C6A697066646E6962676B
69716B6E646B696B686B64616F6E666B6B6C6F6968696373666F66616162686D69706A66
6B666B69646870665F706C6969656E64696E6464686F6A5E6D68686C6E686E6765636461
6468626469636C666567666A696661656A6A646467616C6666626B6C6364696564646866
5F616166696062626E615E646561695E6B606161646564666663635B6364646461615E5C
6666626060605B5E66626368675B63685B5E6260595E5E5C5E58585A5F6160625F616054
5F5857625C555F615E60545A62585D5C625A5E5E5F5D6462595E5A59575A5B545E5F5B59
6161615C5C585B59565C59595B5D5858565E5A5C665E5D5E545957565B545A5A5A54575B
5A615B58615E595961595B5C665C60625F6058615B5959585E5C5E615A595F5555525A5A
5A564D56595656B100000000000000000000000000000000000000000000000000000000
000000000000000000000000
D06560645E6164646769665F60666069636A6664605F5E606464665D6459635B5A5E5B5D
636463615C5A6060615C5C5C595964605E625C596067616160656161635E616661606562
63695D5E64635E5D6264635C5D5E646C5E645E615E5C61616461636260625B6863636063
5E6160606266616165616B696162616366666368646B65606863696A62615E5D605C5E5D
535B54595C565F5D645C5D5B63616169656C6C6C6268626564665E6360686B6466727073
696361676469676E6E65686A6A64666B716E6C6A686B6E69696E68686866696A69696869
68666667686B6669616D6866676E696B68736C65646969666E64646B666E6A6167666766
6E6D6B666B66646C6164696C616669646861646B5C6F686561626363686C676B66656569
6664636C616970686C64636B66625E646B606A68656B646465646364625F615F6466675F
61646066666163686065676263645D6A6560615C64636864606361645E6660606166615E
5B5D5E5D636063645F6465615F625C5D5E645A68635F5C5A5F5D605E616060645D5B5E5C
5E5855615B5A5C5B5C5C5B5D5C63605E5C6A5D595C5E5E6060575A5E5953595D5B5B5D5C
5B5E5E5F5B5C595D595C5459585D5A5A5C5D5D5B5E6059565B5B5B535954585D595B5F59
5B595B555C5A605A615E5E605C5D5E61595C5956565A5D5957535B59596059635D5B5654
5A555B57565853B800000000000000000000000000000000000000000000000000000000
000000000000000000000000
C65F666864605E656963636061616969605A625C63645F5C605D5B60605C5F5E595D5E5E
5C6460635F5E5B5F64605D5F595D585E615B615C646960685E646064665E596266666163
61655F5E6C61685B6364605D605E5F625F61625F686360635C6364605E60645B645A6166
6363695E63616563606063685C6462636462605D5C64686965625B656263686160605C60
5A595E625E5C5D545C5F5B63646363645E6C636664696469636A6D696966656E686D685E
636A6C676366686969666E6C66726A6C6B686E66686B6D6B66636A67666D6669676B6969
616468696964626A696968696765646B736068666E696C68646069696666696E6B6B6A63
6B686266655F6465686866696869676764646E6670656A616169676769636B666361655F
6469676461666469656665686C6A66666866626464635F6961605E6161676461635D6465
63635F6B5D616265616163696364625D6460656462665B605C5C5B5463675C615E5E6160
63645F5D5B625D6462606063635D61605E5B62595E5F5E5C5B5E606060585C5A66525B56
64645858635C565D58595A5A5959625F5F565E5756595860595B585754625E5C57585264
615C5B5859535A595A595B5E565962535E5C5B60615B6059635E5E5D5E5C58615B5E615F
5B5959595F565B5C5A58595D605E5B615E635A59605160605F58635F5F575B5B5758615C
535956545E575BB600000000000000000000000000000000000000000000000000000000
000000000000000000000000
D4545E61655F64635E6760625F5D5C615C656164616964605E5E5F625D625E5E5A56605E
615B61615E606460615D5C5E5A65625C60616061635C6467605C60596856636966646761
696357606167615C5B645D5E645E635C5F5E655C615E5E5E65635D6461605E6460666463
64695F6266695E5F68666361615E6064606163686564686667616465605C616362605E5B
6061635C635F6060605B635E5B68696163646D676365636868696869626B646464657067
6067676968676B6D66686564606671646D646861666B6F666666666665676A6968666960
66686C6A6B6A6A646E6E6869666869686669626D6D606E6B6E696A73646C656C68686B71
656B6E666663656769656966666A61686068656D645F686C6B6B66646A6B64656364656C
61636663696258676569736D616C66646B66636E636A66625F65645F61666C6165616168
626263645C636863635D616263686763656762646264636361606660635B655E62606464
60615F5964615E5E63615E6164625C5E5A5B5E5C595B5B645C5E5E5E5C63585C565E5D54
56595859585B57665355605169595F5E5C585C565C5F5C59575E626060595B565D5C5F5A
5E5B5E605C5C5C5C61605B5B59605C5E5A5C5E59575F615E60545B585C5F5B4D5B585B59
5E5A615C5D5E5D6060605755605D55595B5360635E585B5F58605F59625D5C5B595B5C59
5E545B565B5651B300000000000000000000000000000000000000000000000000000000
000000000000000000000000
CC6664606364636167646468586261646361686162605D65646563655C5C695B595C5E5C
61565E625F5E5F5B60635E5B615C575C65606165616363606160606663616366645E625F
635F64625E61655E615E6058665E5E61605B5A5E5D5B5E615E64616168645B635A615B62
6563645E66685B63615C605C5F63646A68645F6064646863695C675F676561625D686163
63615C635F5C606460645E6563606463666B6063676668646E63696866686D6671696A67
6E656468686F6F706C6C6C6E6C696166646464686A6C6868706A69696A68646563666964
6C6A6666637069676E6A69675E6A646366636C666664666467686B5E6D6D6669666E6A64
69665E6B6865696060636D6E656C60686968696E6467686C666263636563656662606860
6B68666660666A64615F6266656B636666616365685E666563636064656466646466645F
63646463676A5C5B605E61615F5C615C616168666766625C6164625B615C626360633659
61635B5F6861606164625661606054606165605C595E5A5D605761565B5C545F635F5B62
5C565961595E625C545F53605B5E58615F625E5859615E5E5858585E5C60595E5F59545B
5C5E595B5C565C5E5A605C5C5B5A5B5C5A59595A5A5F5F5D58615F5C5E56595C54535656
5B585B505E5855615D595160615C595E5A5E60615B5C5C5F5D55605C565A605D59605259
55555A56565459B400000000000000000000000000000000000000000000000000000000
000000000000000000000000
CB68615E5C6468616665636263635F63636660655C6060636460605F5D5D615C5E5E5F5E
59606259615E5C5B635F5C5C5D5D5C5E645C6564645F605E61666169635E645E5B5E5F66
605A606159666468606361646060635C5D5E61615E59595E5D6264685B68616063615C5D
60675B64665D626065616060646B66686366646260616663615E635E6163616461646663
606160595D606B696A636B5F636666646360676861656668646869676B67696E6E666961
6A6B666E686668696B6B6669726C6C6C6D7064656A6B616370696C63686B68706B666568
70696564675E6664636A64697069686867666E6C676765646A6765656B676C6668686366
6B6A6D6F6663686B6C636B61686B656B6B656C6C61636666686666666960686F69696461
63666B6167686864636967666669615C67696A6162636568616F636863645F6264615F67
64675E6363616264676465606465636D6661615E64686B625E5B615B6061645C615D4B60
606161635E5C645E63605C65565F5B5C665B59605454605E5E58555E5E59605A62595A59
595E5A5E605A5C5F5C6059585B5C5758605C5E56545F5A6360585A57595E5C5D5A595C5B
5D60535B545B5E5B5959605B58605D5C605760585B5C5E575C58555A5B59515F5B58665E
53565C525C5C5A585B5D595B53585E635E605A5E62555C5C51595E545A5B54505956595C
5B615A56545853BA00000000000000000000000000000000000000000000000000000000
000000000000000000000000
CF645E64616261636465645F6564686465635E605B6356605B6163616B665B595B595E60
5E5B6261655E5A605B5D60605B60645D5E65615F616064615C61625F6660656466645B57
60636760616360645B63606360595A5F5763616161635C595D595C61615A636765645B62
606163625E686366655E635D6664636469636364636A6866685E64616066646161635B5E
635D606060635F6069666467666766656668646562696366666368645D646868616E6363
5D616467646A6B696769647066646868676B63666364666B68676B6E6B64686467696896
6C68706869695E646B666B6C6566646C666764686865666E61686465676166706A68646D
6366696B686669656566696B606164666766676F68686B626862675E6364696664636765
67646971636B6164686868646C6263666C6664685F636064686068606061626063616165
64605C686768606460606268635B5F6460655E62686464615E656164606067615F646066
63655B5E63626160605B59605A5C5B5E5D64605C565C5D59605C5B5F5D535D565B58605C
5B585B585E6059605E5358665958635B5C5A635C605C5D585B595F5B5C5E5C5A57605E5A
565C5B595C5C5E5F5F5F59545858565D62575D5C5C5C595E565A5B5159525C565B5C6159
585359565D58555B5F545B5E5A5B5F5B5B5C605D5F58635A5E57575C5857625E55595D5A
5A59565C51555BC000000000000000000000000000000000000000000000000000000000
000000000000000000000000
CA5E5F625D5B656366595B606B6464616660615F61636960605E66635F595D5B575E5960
625D5C61566061665C5A605F5E5964666466665B5F61636B645F65616366675E6364605B
626764596162605F6361625C625F5C60645E5F625F60616164615A60666062645D60645C
635C696A6465635E5B68565F5D6468686465666466616663636764656B6363696166635D
666962645C62656764676366655F6B6368636668645E64676466666B6C6B616069696B65
6C6467666B6468646C656A6469646C64626C6A636669696A6868646B6A66676A6864FFD6
7B69676A61696A6E6C616A63666163686C64636C606B6964696B66646466696866706A64
6D6865716B636968635E6668636463666D6A666863646861606C66616064646169626961
656C66645C646469666468636169645F6964605D65615D69566164605D6261636061625C
5E6B6366695D5C6B6B635E6666696463675D5B5E5E5E6461646166605B60635A685D695C
5B5E575C5C5D5A6669615D5E5B635E63595C5F5D59605E625B615E595D61605F5F5B5E5B
595B645D585E5657595E5D5C54615C5F585C5D5C605C5C5B545A605A58565E565960565C
5F5C5E5A565B54535B5D5B5B65635C615A5B5E665B56585D5959595C595B5E5C555A5F5E
595358595B5B55635E5C5860595C5E605F5A5A585C5B5D5B5B615F5C5B605A575B61595B
53575B5656585BB200000000000000000000000000000000000000000000000000000000
000000000000000000000000
D7645C62625E6C6263675C5D605C61635C64616064595E5E67616866605E625C5E5C615C
5659605C5E605E605966635C5E60655B61605960606160635E5C61635C625E60615E6259
646457605E615B5E6156615B60686464645E6B6056616862606061605B5C55615E5C645E
5D63606166615E61596B636963615E685E5A5F665C646260606B656161646660665E6061
5D606569655E646C6666685D6C606869625E5E60636368616C646666686570686B696564
6862686C66656B6A686865766C69696A686465636C62696066656B666B666667626B6864
656364686B666C6B656761696561636F696A6D6C6166625C65696568626866636A686B69
686A67686960676670646862666865666D6961636C6866606C6361606369606964666361
6A66666463636761646568605E68626664656B6C625E5E6561606764626061696162695E
61645E66626464616163625F6663635C6466605C62685E59635C5E615966635B5F5C5B61
665E6363635D5C60645E595A615D5B5B5D5E5B585F5C635A5D59615A5E5B565D5458605A
5B5D5E5F5D595F60585E5A5B555B5C5E645E5B5C5B58595C605C58615C5C5B5E59595A5B
58585962525658585C605859565C5C5E635B58605A5B5A545C5C575E5E5656505758515B
575958595C5661595854585E5F58625E605D5B605B5C5B64595C57605D5A565F5C58595A
595B5557575655B400000000000000000000000000000000000000000000000000000000
000000000000000000000000
D1695C60635B5E645F5B625B626E666460605A61606B5B5D5E60606B6461625961605D60
5D5C6A635E5A61595C586363635B5E66625E6663645E635E615C636B6061625A5F696161
66656361605E645E5960615B60685C635C5B6362635D606464636365615C615E5B626663
625C635B5C625E616163625960616769676661646162616564606260595E6367686C6363
6E645C6466686B686468626B666269616461616466636861696A6864676A686564606B66
6066746766676D696B625F666F646B6668626963626B6B696B6565656569686F6B6C686D
6E676A656566656D666666646868666368666C65646368676063636862676B5F69686169
6665676F6066675F635E666F69666862696B6461696E6268626365646163646664606066
686664626368666161686766675F62666C666064625E64625B635E616265645F69635E6D
61685E63606065606069615F606560616366606166676262605B615B6460596567606062
60645B636761605E5B6160605D615D5C595E5E585B615C5B605E5958565C595D58595B5A
5B61625D5B58625D615B595B5E5A575E58585B5B54605A645B595E5E5C59595B615F5B5C
5F56585757585D5F5C616058635D59535A5F615860515D5A545B5D545E585F5E615B575B
515E575B5859585A5F53545A5C5D5C5B5B5B5E605B59595C585C5F5D5E545660565B4F5C
58595657545759B300000000000000000000000000000000000000000000000000000000
000000000000000000000000
C65C665E635E6061615D6159635B72685E615C62666166605B6363635E615F66635F645D
5D595E60605E5C59636161635A5D64616B60635E5F5F606366635F636262615C66616067
5D5F5E5D5F595D635D6169615B5E5C5F636063605E5F5A5D66625B606160636156606166
6560615C67615E665E5858616064685C5F66676363645F6663645E646869606269636460
66616E60656969616A665F5D6E65666467646A6660696D6862646B696962666B6D666268
696C5D63697166696665646D67666A6C626B6963696367686A666D666F666868696F666E
696D6B686B6A696A6669626167696C68686C6D60606963636564636362666C6B69696665
676C6464686967626862696A5C616B64616C6864666F67626168696E6564686469646863
60636B66646B61646160696666626A6467607065665E61646668606763686762605F605E
585B5D635C6366646560616161655C5E6164606161656B625C5C666161686664645D6369
6164595E585B645B61595E5D605461605D5D5B61615E63595A5C5D5E6256585B605D5B5C
5A595C5F5A5D605C59605B5F575B596058605C5F5B5C5F5956565E6058585B5C635B5958
605C5E5B5E5C645C5C615F60605D5C5B5C565B5B5966615C5A5960545A575B5A5A59585B
5B5B6058595B545F5B5E5A595E585C5C5A60525B5E5C595C595659555A595A5653535658
59615854555952B800000000000000000000000000000000000000000000000000000000
000000000000000000000000
D85D5C635D646466605765615B6363646264605C61625E5E66605D6C6069615D615D5E5E
5D5E60615E5D5F6062615C5A5F5E61615E6366645F6163635F606460615E67625F616367
615F6461645E5C646463635E62635C5962605F5E5E636458635F67616461645D605F6958
6467625B5D5B635E636868636863696264605F64636B635E5C686361635F646860666460
6760605E66616566656165656A686463676B656468655D6669616B5F676C6B6D66686968
6C606F6C676663666A6A69696E68666E68656B6B676F686069686C686470646D666A6B6E
6869646C6863666569676868676667696166625C6C616466646969656B63656B63656961
63606264666664646461666368626766656961626A6C686A6A6963636263655F60626063
646E6169636C6569666365636A65666A6164686261606265685E6661615F645E66676160
646463605F6268635C5A63686162665F605C605F6061605F625C63665B5B605F565F5C66
63606761595B605864615E675A60585F5B5E5E5E5A5F60575B5B5C5B575963535C586160
605A5F615A636059615B5B5A595E5A56595A565B5B5C5E5C5A5E5655585A5F5B5B5A5C5C
5E55575D5B62605C5E63596058595E5B645A6060585D60575D5E5A5A5B5D575B51605958
5959545860595C5859585863585E5B59595C605A595E6056585E5D56615F56595B585C58
585A5D56515356B800000000000000000000000000000000000000000000000000000000
000000000000000000000000
CD625B5E615E5B5C645D5E5F5B645C5A615D625F606058615C5E6361636465625B606059
5D635E5F645E5E585A6163605B63645E66665E5E666767635C5D66645C686463655D5E5B
60616068606061575C635C68615F5C5D63615C5C6367635E5E6361635C5D60685E60635B
625E67646463635E5C6161635E625C616661606165675E636466595F606164606C5F6367
6669646A6867636C606668666A60646A60616B6368606263696A66626A6C65665E6B6068
63696269666B6E636B68676366696967676A67686C6C646C64686966716B69666468796C
686B736871696968645E6664616867646C6C6262656366666B6567646B645C6C68686266
6A686668676C676A66646468606B63706663646467606865696663696768695F65626065
69666C656A6160666D67646463686863666365636C60606463635F63636465675E606167
685E605E5F6467645D636061616160626361606065605D595E606669665B625D5E5E5861
5C6B625B575E5F61625B6A5A615B5D5C59565E605B58635B605967595B52545C5B5C5861
5B5A5F595B5A5E5D575F565B585E5C5D5E615E5E5F5D5659605C616156606163595C595B
605D5D605E585E5660555B5C5D5F596356625A5959565B595959596055505B5857555558
595B56595E5D56555B545E59535B5B5C5D5856595B5E5E5E615C5B585F58595F59585B5A
5B584F5859545ABC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D4605C615B61606460635C5B5A5E5C62575F606460666660635F60605E67625C6163605A
5A606364635E6664625B6163656060636160626568645F606361655F636066586263615F
6060665F615C5E6A69585A635E655C6264645D61635C635D5C5C605C585C5B5E5B5F6164
646367605D5E5E5C69685C616164645C645C60695A5F6360686061636565616165616165
645D61646868606766606063645D626668686B6460696D64646166665E686C6965626864
6861666469666465645F6B69696168636F64606D6D696E656B666C6666646A69686D6B69
696B626B676869666965606C6767636369696A6168616864635E686965616D6868616E63
6566626464626E616B666764636164606469646468646B626960686464695E6369636166
6163685C616A64626868606B68646C67696088615E5E5B635D646661605F6364646C5962
60685B606461636363666963645B6364606260665F636C6160636463586163646159605E
5C6060575D5C5C63645E605E665A61595B635A5C60595E605B58605E5B58605D595F5C5A
565E605C5E5F5A6259555E5B585E6054605B595F54585C595A5C53585C5C5A5C5858545B
59535E5B535B596058585D5E5E5755585B5E5860585C5758515D5E595B5A5F5C525E5755
5C56595A5658595A5D5A5D58545B5A525C5B60605B5D5C595E5658575C5C58535B5C5B53
5C5C5B555B5359B500000000000000000000000000000000000000000000000000000000
000000000000000000000000
C8646063666160615E565E615C605F60615C635D60605C5A646864615C66635C635E6066
616162666264605F5E615C5D626066626062625E5F6061606163626864666163635E605E
5C5966635C635E635A5C5F5C645A60625E5B5E6664616160656A5E5556605B5F56606360
645C6466636363595E5E61596860616164696561686661666666616763646469615E6063
635F5C6166695E636E696967615E676764666766665E6868696B69646A5E666A666F696D
6A696A6A6A66616367666E6766696365646B6B6C6C65686F6B626668666C6964696E6768
62646C6B6B6667676166666864666666666960646863676D6E5C6868656469656A686563
6366666862626869695F6966646C666E6869666166676B64606C5E676A62666966646468
64646363685F66686466695F685B6364676E7B646463635F63676664635E606462666761
6063625C5C665D615E606361635E64675E605D645D61636363665E5E615F59585D656268
5E605D5E5E645E5B5F646563615C5E60596360655E58615B5E5E58646459555750595D5F
5D5E5C615E565F575A5E59605853545B5C5C5C5C635D5A5C595955575E5B5759595E5E56
5C545854595C5C5A59595C575A575B5D59555C5A5B5860615C5E575F5B64555B5C5B595D
5A5B55515B5C5C5C58615961595658575E56545E585557595B59595D565E565B5A565C59
605E5658575253BD00000000000000000000000000000000000000000000000000000000
000000000000000000000000
CA605E625F615C6164685E635E5C5F5D635F615D60636661636168616C5F615E60655E54
5B5E63645C616162636060645D66605E605E646A5C5960636963645D66606168646C6664
606660646464636258616B615A65635F5E58666361635F5D59615E6060665E686368606B
5E5D645C6564605A60615D5D5B605D5E6664646360666861606265696364655E63636163
6463666664656E6364666066676462646B65666666636363686666696065646464646C65
6565636869646C6E646169636266696B666F6B676665696367676A67695F636667686864
69696C64696466666A65666B6A66666067666D6566636763686C666A696D616063626467
6869676E666C606569646968646464696461646966646662686663635E6666656966635E
656366646168656869666564666963655C64635E606366616668636463645F655D5C6260
615E645F5A655C6164646462636563616063685E666366615E5B60645E5A5C60605E6056
6067615F5E5C615C665F5E61635A615C5A60585C605A56595D5F595E6458555E615A525C
635861575667635F545C5C57515E595E5C5C5C5C5E585C565E59585E5B5854585461585D
575C595A545B5A5A59595C565960565C5F585754555A5D565E575A5E5B59605C5B615458
5E595E5A5856595C5F58595C5B5A5458595B605F5963585B59596159595D5E5E5B585958
5B585C5B5C5258B600000000000000000000000000000000000000000000000000000000
000000000000000000000000
CB5C5B5F5E675D5A5E60666662605F5F59616464605D656069616666615F616160586062
615D6463606464606362606060615E5C6066605F66686668656161686366646264665F5E
645F6361615C615A66615F5D525C625E615E605E585C655B615C5E5E5A5F605C5E635E5D
616061665B5D606161615E61635E66646A68646164646461685E645D5E6D64635E676568
6769675F6667696666636669655966656568665968636566676360616568686666686869
66666A63666C68656C6A69696368696B646766656C61696469696E66636B6A68696E6D66
61696B646765646363656361646664695968636C63636567676766666A68646464696463
636562625C6863646365616666616767656566616760606565605C6E6666696266656862
63666758626463645D69655E64676B6164685E665E645C65606067646B63666A6065545B
636362596366615E675A69635E6063606864605B6865615D5E59615F5E625E5F5E606062
5A665E59635C615A645C685E5D60575E595F6358615F5C5464595F6357645259595B5D61
5F5B53535A575C54615A5C5F5953595E5C585F5A5A5C5E5864585C555456555E6060565A
58515C565B565C56585754595B5E5A54575B5B5B59575C5653565D4F5B575E5B5C575B5C
595C5A5361505C5A57555C595B5E59595C555857595B5A535D665E545E5B56555B575960
5B595551535354BE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
CC5E635B5C60625E60636461615B5B5E63665D615D645E6263696E6861665C626A5D5E5B
65605A5B60605E6663615A60626A5F666362605F636362666162615B63615E5B62615E6C
645C5C606461596362685F615F605E61615C5D5F5B5F5F6360565B5F5D6067645C61615C
61625F61646764656564625B5D62606364605E616063616662636066696364606961666B
606463695E63645F5E61696963635F6664616260625E646663666B686A6A6961646C6964
6D66656A686B656869696B696C646B666361646A686769666368636466616C66636C6968
63666B6C6E636763636A6869656B646964646666686A69676062646861606A6562686565
61656868696464616566646B67645F68696764696463695B625D69656864656561646160
63666066616361666863666D69635B656A6264646163646364605969616460665E636159
615E5E6265665B5F6758605961615E6364595E656063665A626360605E6663636062635C
5E5E6059605E5C5B616560625D5B5E5A5C5C5D61625C5C5F5E6160635D625C595B5C615E
5B585B565A595A5C5B5C56545A595C5C5C5E6062565C56635F59625B565D5E605B595856
5F5D5E535E595A595A605758595E595B5E51585D5B5C5C5B5A5D585858595A5B58585D5C
5A5956575559585C605E5A5A5B5E545F595B59595953595A555D5A5C5B595B5E595D595B
56585A585D5B5EB500000000000000000000000000000000000000000000000000000000
000000000000000000000000
C05C5E5E5E5F5B6462605D5D5E5E61655F605E5C5964606861646267676762605B63665E
6263645D63665F5E616668616161636463675F625E63635F66605E5C665F606264645E6C
615C6164606361606560645D66605F5B605C5D5D6961625D616664635E645D645C615A5B
6161625E5E646258635F5E606466615F606164665E6163615F5A636362615F6B5D635E64
65625E6169625F686A61666866626B636569686964656963686C6665655C5C6963646767
5B646A6B65626A626B6863676966656E6C6C6A67616968666262676968686668696B6D64
716B6C675B6E66636866666768696B68646B66685E6B6B686463696C6C69666764696F6D
6866686B646A6F6A60686166626765646B6667656B616569665F6163636664636B696960
666163656B6365616965696064695B686C666364615E635A615B68696560616561686561
626160625763666060625C606760635F63605E6560625F635E605E636162606161646160
60665E5963555C6160625F636061615E625C60595B5B5C5E5C625B60605F5960615E575A
5D59615C5C5E5E5C5E5B61605B60585D565C5D5B5C605A5C60585E5A615F5B595B595856
5B5D5E575B5E515B5C54545C5B5654584B595D585A5E5B5954635D5859565B5B5D5C5458
545352585F575E545A5B5A5C565B5B53585956545758565B585E5B54545B535658565B5D
585B5656535953B300000000000000000000000000000000000000000000000000000000
000000000000000000000000
CB605B60646359675E675A5B64655C5F5C5B655F6060665C626C63646460605E65606164
61606363605E6665625D5B63665F61665F646464666360665F5B605D5B5E61666360615C
6562605A6263676061625D62685E5E5E5B645A595C5D595D61596164615B6161585E645C
635E605D61676966606762616871616161656168665D67676B64655B66626163695E6166
635E63636064666366665E655E645F63626866666362606663686B65606461636964606B
696E69695E666D6C6366656E636E6E656666696B6A64656963616666685F67646E6A6D63
636364666569616670646867676B63616A6B5E636969606960646C646666666164646663
6461616163635E6864686168615A6564616869666B636B61636861616466666963636467
686662645E626A63616266666566656A66675E60675E5E5E5C65655D5E61626B605B6163
66616866646462615E5E6760635E605E606463606B675E6B6063605B5B64595B64616461
6161595E6160645D61635E6060596061626660635D5B5D5C5C5B5D5B5D645E605E615A5E
615B5F5C5359595B555F5A5D5C615C5D5D605B605C635E5C595C5A635B54595A58585458
595956585E5E625D575E5B585B5B5E5A545E545A5857595C5B5952545C5A585B5E565457
555B5C5C535459575A5C5B56615C565E595D59605D6156565B5858535C595B555B56565C
5B545E5651584BB600000000000000000000000000000000000000000000000000000000
000000000000000000000000
D1645E5A5D5E60605B62605B615B616160625E5D6763605F5E666261635F616963625F62
5F5B5E5E6B665B64626163576166615C5E62635E626362635C62606661626462635C6361
63625E615D5E645B5E6060635E635E605B645B5F5B62605E5D6460606261606663655E5F
6063666162585E61605E645F5C6967615E6464616566636661615E61635E64606A636664
5A676462646765666065636266606765666467686663656463645F5C6961626969666468
666C6568636B696968606860666D6868646262606464666B656469686365656467686864
6B66666665646663616865665E66646661626667665D67676166686B6469636763666963
66646467606166616564606B686D606A64636660656464666C6466616B64615F63636B68
636266666764626169616068646A6261606860625C656066645F5D63645F5C61665C5B64
5B60636060596066666160645F67615D62625C666460655C6064635F616065685C5D5F5F
595A625E625E615C5B64665E646063615B605E5B5E625C605F5E5D5B596463615F5B5E5B
5A6459505E5E5C5B5A5E566151606154615B5A5A5F5961595C5E55585D58565F57536159
586063585C605758615C58555A585C54595B5A5C5B5460595B545D5C585B59585B5A5858
5F545C59565D5B61585856535E535D5B5B565E5B59605A59515A56585259565E565D5B5A
5C545C57615B53B300000000000000000000000000000000000000000000000000000000
000000000000000000000000
CE5C5C6161686059655B5C62636A5C615C595F675F645F606E6363606560605E645E5E60
6460616361625E5E5E5B616864636168626A686063666063656066695B615E5E6264615C
6163615C645B6162635B595860685E645F606160555F6056615F635F6162635B5E5F5B5E
5B615F5B5C5E61636163615D63646364605E636964636664626167655E64665E66646362
5B6167695E64625D62606B5E62685E5B6861675E6469636B686468616468666364686966
63656667605E616668646B686667686C6B646C686564656C686E626568676D636361636B
686B606968626862666470636364646169666366666068686363696E6B676961676B6869
66676466666565676D6861626266645C696066606367656E6A62616963656664606A6163
6864666A636362636462636C60676E6763635F6464625E6B5E65666361635C646056605E
5C675E5E5B5B61645F645F605B5E666459595F6163615F5E5C66665E636260616660605F
635E605B60645C61615B5C655D616160605F63685D6666606460635C5C605B615C615C5F
5D5C5C5E595C5C56625E615B61545859595D5B5F5B5E5B5E575C575B5E5B5B5B565B5A56
545B5D5B5A5759545F59585F59595353535D5B5B595A565C5B605C54595B575C54575358
5B5B565B575758595458565A5E545E59545B5B515759595A5B54555C595B5B585C5B5758
5B595B58535453BB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
CE5B605E615E64635F5B5B63595C5E5B5F5C6460616361646763685E5C646160625F5C61
605B605F5E606960615E615E645E645D5E626260665F646463665E6563615E6364615E5D
635C6261616061605C5B5C60615C635E635E5E625E615D615E5E5A605B595E61615A665C
605B615B5C665C5E5E5C6369646368646B5E616063676963605D61656367606668666C5F
616167636A605E68635C67696364666B6360606067615E62666762676B6262606667606C
616B6769666C64636C606C6C6465666367686669636B6C626166686C666A696464656967
6A636B656666666D64626464626069646764686C6961655F67646F636C6867676C696463
6A60616760666669635B636162656B6C6668686361636663636C666C66636F6A67636B60
646A6468606566655C676366646464686163695F64665D606463685D6165626B60626164
5F615E635E625F635E6361605C6860615F5C5F5E615F5B60595D5E63645C645C5E695E5C
5D646361605C5F6462636B5A615E68615F635C635F5C635C585F63615E64605F68605C5D
5E59615B615863565961595C6459635C645E635A5B5B5661585C535C5E585B5359585C58
5554585C62545E5B5E5D5660585C53555E5056615B57575B5A56555453595C5C5E545954
5C5C58595B53595A5B54565E5B594F5C595B5A5E50585C515857585C5D595456595A5755
5857535E585553B400000000000000000000000000000000000000000000000000000000
000000000000000000000000
CB59665962615D605C5F555C6B63636460615E5D6364665E63625B5C605E666461626062
5D5E6560696360605F6359616061616064646262645F60616461646165625B5B5C616360
615D5E5E655E5C565C60586061616864615C61615C5C6463635E605D5F6363685E676162
635E61645F5E625E61605D68596B60606A615E6463656065645E62686167686168615E6C
65616B665E61655F64605C64686462626762606663636B666C6561646463616A63696466
66666D646A6A6E64665E646573645F64666C6769616868696C6C6866676B676661666A68
71686263696C636C64666B666A646665676569615E5D636D63646069646B6768695D646B
6B646B6462646C636C61686166666B64676868686D66646164616861676464696467646E
6A6863666968676768696866666264636061606161685E5A615C605D5A5D585C615C605A
6164605A5D5E5F605D5E606B5C5E6156695E5E6361625E605F5E5B5D60605E5B635D5B61
615B64645F60625E63605E636661645D635F5E5C645F5C64645C5D645B5E5C5F5D605A5B
605860605F6356565E5E5C615E605E5C5D58595C5B5B59625B605B59575A5462565C5E61
5B5E58545656565C535C5C57595C6458615D5C62565A585E5A5A5E5D5A635658595C5956
615C5B5C605C5B5857595656595B5756595859565A5C575B5E5C56555B5758585B535B53
5C585954535653BA00000000000000000000000000000000000000000000000000000000
000000000000000000000000
C85E5961645C62595E616061615C5E615D5E5C61605F666760675C60615A605F60606167
62635E5B59605F605C625E5B6364635C616061575C625C5E615E60636164646463605B5E
5C5C5E575966595B615F5D5E635E5C56605C5B60605F5C5C6A615D645B645E675D625B63
5B625B63595D5F646366636C6661655B66615D5F5E6161636D5D64606363676366656664
675E645D6862655B66606465656661645F636766656762645E65685F6466626664666467
66696464656864666A616661676566686F6C62606A666664646867646767696966666668
69696964646B61656463685D66626363636A686668686960696867676770686668646964
68646B626460666961665B6C64696265636A696A6468635F5C686664675D666669666764
666360646361626A61615F62636A6861626466636460635F665F625F605E665E5A605F64
5C60665E635F6366605C6164616264645E605C5B626263645E61645E585D61645F5E5B5E
625D5C665F615D5A61645C675D635E5E63605D5762615C62625E61625962635F61646061
5C615C595C5E5C5D5C635E635A5B555A5861555E585C6457605D635C5B59585959585F5A
5B5A5C595855595B5958595E5B635E5E5857585A565F545B595C5A5F56585A595856525E
565955565153565A595C515753565455505B5C5856545858565C5453555C585D4E555653
59585558505857BC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
C45861605C5C5E615C5F5A6360635F5E6E5E64635E686B5C6661615B61615E5B6661635F
5E5F60615B5C5D65605D6C63625E625C615D6663636363645E666264646263645E63645C
5F5B62576054545C555B5B60575C5D605F5D5E6163585D606160615C6164615C5C60635D
625F5E6162665C58615E6362646461646864656266606360655F666066616364635F6664
616464636463655E685E6469636361645C5B5F64635F5E6569666268696264645C68675E
625F6967616B6E645E6E6C67686666605E6163676C6C6761676862646A6966646068686A
6163646B6F61666B656C696163666869636A6A6B64676464666463616B5B5E63665E6B65
686969686B6B64596B6D6664696866666C61636E66636468667162636866616463665E62
666A696166666061636E6365626E66656764636767606461666A5E6164646058605E5D5F
5E5E60685E5E5E5660596361605E5E6064606161595D5F60605E64596061605E67656163
5D5D605C5F635F5F6161615F6461636064605F62646068626660645F63605E5C5F5C6365
665F5C5D61615F61645D5B5B625F5B5B5B5B565659585C615A5C5A5C595059635E55595E
5E5E565B585B5861605B555A555C5C545F5A5D5B5A5854605B5C535C5456536056615A52
5E565A585A585953585859575D5B53565856535A595C5860575D5457565A535456535856
58585859545454BA00000000000000000000000000000000000000000000000000000000
000000000000000000000000
CB645F5C5D605C5D5F585B5F655D5F59605E5C5E605E665C6562675C5F646668565C6164
646460655E5E666361615F5E5F5C635F605F5E5F5860635E6264625F62606061615E655A
615B56585C59595D5F5C5C5B5B5C5F565D645963615E605C645D61605C5D5C6060626058
5E615A5D5D635D606164595B6163645F666160646065636166646263635C5D60675E615F
69625C65695C5D6460615E60615C616D5D676061675B6167696064616466696C63666462
666763666D6068616C61696469636B62636262666B636C6966656065696B706B64686463
6A656768636D69686963696C6B666B616A66616B6364646064646460696A65636B685D6B
6A6B6467686866625E666368615F6B666B696866676069655F6163636B63636567666166
646369645E6561646868616263616865665F69686464685F5C645F5F5B5E635E5C68635C
5C59605E5A605E60686562645C615C63625B5B66696A64635E605B64615F5E645C626061
615D5C5E615D6262615F605E5F65646560665A60615E56645A6661635E6060635E596059
636860625A615D5C61595C675B5C595A5A5D615E5B5C5F595B585C565E615D605B595959
545B64585659585B535C59585E54595B565B5B59595C5959565856565C5B5E5A58595F5C
5B5B5754635755606051585551615A545A535B545D59605356595C54565B5B5A585C5D54
505760535D5759B900000000000000000000000000000000000000000000000000000000
000000000000000000000000
C3595F65605D60635C63565B635D5E5B61565B615D5C615C5C5B5F5A5962605B60646161
6663615D69646463655D5C626063635B64615A6A60635D61606364605C645E5F5E65585B
5E5C605F595D585C5A60635C605C5E5E60635C5C6157626461605E5C60596265625E636F
6363645F665E63625E666566666463676663666568626462615F65676367666263636164
6568616463646363636064685E656066685C5E5C5F6466646A6B6C676668676864676362
6669646E68636A6361636666646169676868686E626A656669616C636C686A606164686B
69616766695C6F666966666C69645C666B6B6369635E64685B69666866656B66646B6465
6567606D696468676765616A666669636B656C60606066666867676871606B6364666268
6A656469606065616067666065635E65645C5F626463636860595E616169646560646066
666163615B5F6662626061635A596462626066636A5E61605E6063615C596057605E6360
605C5D64645E5B6363605F605E5D636162635B615C6462645B61605C60615D5F605E6458
6161625B5F64605E5D6060585E5958595A62565C5A565A5958545561595C5C5E58565D57
5B60595E5A54545B5A5C535B5C53585B57545C5860575C585B5B525960615659545D5855
5E5C5C5760595B5B515C595958585952595A594F565A5456575B5A59585650545653565B
53605655545159B600000000000000000000000000000000000000000000000000000000
000000000000000000000000
CA615A5B545861615D5D5C645F615F60605E5C5E5D5A625E5968605B64595E595B64605C
645E6567685F625B625C66645B61625E645D6165636463645F6361635D5C6665585E6260
5B5D5B645E57575E5D5C63585A625C5F61606361695D5B615F5E5F66635C5C5E61616460
635C605D5E665C63645E5C666768665E615E64685E60656A6A6C645D5D695F5E66606368
6864645C5B646266606466605F666761685A6161616B6E705B69646866646862606B6663
63696867695E6B66646C6B6D6C6C68696B6C646867656B65686462686463676467666169
606A686A6866696A6B63616B616E6761696069666A62686067675E6666635E6368686663
6A63685E6B666365666A6469646961656367666B6662666B60696666666868696C5F6869
656467606D616065636663616866645B60676563626564656466615C5C5F5E635C61645E
616961616061615C665C61645E59615A605D5B666366675B61645E635E5A666464615B5C
5A5C636165645B68615E5E595C605E59645F616061616261596360645A6061635A5C635E
655F675E6360665E615B61605C5C5E5A615E5B605C595A585A5959625C5E54565C545759
5756615E5A5A605B5C5B595B60635B555453565C595653575A545F575B53595556595959
5B555D5C575658585B5B5B565554544F56565454585C5D60586056595D565C595C585555
565E585B555350A200000000000000000000000000000000000000000000000000000000
000000000000000000000000
CC61615E5C5E605958595C606060636964615C5D665E5A5B5E5B5E645C6658615C5F6563
6664636564685C635F605A65616360605F5F63646360635D666068655B615E615D56595D
5B5D6263605D5B5F5D61605B605E615D5E5F655E63636661615A60616761636264636161
5E5964615D5F66595F5E68655D60626662616468646265645C6966656064646567636461
605E626A69645D5F66645E626363605C61675E5660665E5E66625B656467646466676869
676B636866676265686864686C656B65656667616564656F666B69685C6463686B696961
64646665666B66695D6C666563676D626369636A6067646367665F606769676166696666
626066646366676462696C69656963676864686361646965656161666361616666686360
6A65666160625C5F636C6161636B5E63665B5E6360636A60635B64686165606064606162
5B60645A61655E6062615F61605C66646663655E63695D5E5B5E605E625E5B6366655D61
5C5C5B645C626064605E5E69605F5D5C5C65606161615F5C5F5D63605C5A5F6060646163
60635C686459606466575F5E5E575C5B5F64565C5C5C5860575C605B615C5C5953606059
5858635C5C5B55515B5B5B61585E595C5C615A5D57595E4F56595C5F565E5C5954585C5C
53585D5D5E57565B55565656585C595854575B5959615D595E595A5958565C5853545C53
5B605C594E5055B300000000000000000000000000000000000000000000000000000000
000000000000000000000000
C960605E695E585E615E5A6364605E5F5C5C5963665C5E5E596066625D60615C625E6161
6067595E5E6363606464616163615C60605B656063616360625C69645C5E635C6063625C
555A6056685D625E5E6659605E5C555C5B595F68585C5C5963655A65606060666459635E
615E6062666666635F5C6066565C5B64656963686368646268685D665E5E6763686A6263
605C56686464606368645F665C6A655E626269575A64636465636669686967646B636866
696661646B6669636A61656B686B63656C656A6E676B6E63666B68686B6467666660615E
6567686269686464666B6666656A6069636466696C5E6B6664606565646A5B6866686160
67695C665F64666C6A6168616065666B6B69646866616466616564646167656869686462
66676160606264626864655C606461616061605E686263606162616462606463656A5E60
625E61615C6661645B5C5E5D63615B61605C646661666061605E6C645B5D595B66605E61
5B605E5E5E5B5C61646164606263645B636364565D615B6661625F5C625D5D5859635E5F
5C5B615D5F5D616064666366575D5F605C5B575F5B595E5C5C5B5B5B635C5D5B62595857
5F6066595E5F545D5C565458585D565C5C5F4457615B5E5A5A5C5C51535A5C5A5B575959
5E5F5C575D5B575D585659545855515B545456525C5D5D5450595C5E595E585457605657
594F5B54535D54BC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
CB615A605A615D685E605E605E605F615E5D5E5B635D595D66605B60685D60625C616460
5C5D5E6666666366666065625B636460615E6B645C625D63616054606365635E5E5E6162
595B5F5E5F6663605F595D595E5E605C555B625D61595E5B63605F5B61615B6162646060
5D61615E59645E5B66616864605D5E6863616161616458666363625C606B616660606269
5D666068685D64626263666869636760605E66615A63666665686564675F686464656362
63686566686763636167685F67686B67656E6666626A656268666566666964636A686465
67656964686D646C6A636365696664686B6C62656B6C6568646969696464626669656361
69666B6C6868696466686067676666666B636D666B63616266646761675E636764666669
6462655C6161675E6864696662656363676B6463635F646269615C6062615B665E666660
6164646364635C5D5E62685E6061605C6163635B5E5E5B63635E5D605E5C625E595E615C
625C635E6063615E5B635D62615E6361615D5D65645E5B5C6060615F5A615F5C58615A5C
5C6664585C545B5C635D605E68645A5C61605B5E615B5460665956585A615B5E5E575B58
5C5B5A5B58566051515C575C56575C61595B5F5C59565C5B5C59595A565A5B585C585C5E
5A5C51595B56535C5B5C5E55535559565A56565C565C5D5D605C595A54535863585A5D5B
5B59585B4F5453BA00000000000000000000000000000000000000000000000000000000
000000000000000000000000
CA605D5D5D625B5F615D5E5A5E5C5E585E5C685B5C5C65625C645F635D5F675E61675965
5E616366666166666461615F60626565615B5C6463645D63636460615C5C5C6461585662
5C605F5B5C5E605F686460615B58575B625C5B595F60636465665C625E6060635E61635E
6463646665645E69636B60636F66616771635E66676E6963675C606B5F5E5E64635F6466
616865605B63606263645C605D6166635F56606363696466636766696361606668636866
5F686660646166616466676166676864666B69676A6767666A6C6E616765656D646B6469
6D64676B606C645E5E696B6166636463626369606B68616668686364696C6563646B6367
66666064646469696967646F68615E686469616864666464626064656164606463626462
686560605D63656066625B6163615E646064606360666157606660646B695C5C5964665E
5E63656466656161645C63646066605E61606461625F5D5B615D58595C5D585B635F5B5B
6056585D5E61655C635F61655E5C5A60615E605863665D5E636064635B61665764645E61
5E5C5B64595B635F5F5B5B5659605C605C5F57615E615B615A56555D5C565F5E5960595C
5F595C5D5B5F535C5F605C5B6463595A585B6459565953545A57625C575C5B595C595F59
5B535D505D5959585C53585E55555D53595956596159565B525E5958595D54595B544E53
54564F55575951BE00000000000000000000000000000000000000000000000000000000
000000000000000000000000
CB605E5861646159606461605C61615C606161645B655E5C5E5C635E5A665E5B65686061
615E64645F64646264616668616365645E5C625E5E5E615D626759625B685E6F57636155
68635E67695E605B62615D5E5E5F615C5C5D5C5A5E6660635A635E665D685F615E5E6164
5E5B5D5D5F5B645B64615C636563695C5C6166646360636161686062646165625C625E64
615E6464615F686461636368656564665E666E63666768635E666465696E666166616A60
656663645F60636A6D62646C676B68696869696763696862696B636A646C66686B6B6270
626861636863606364666C616B68636B66676668606969666A676A66666866616B5C6669
60646463686D606663696B6A6662665E6467636C65636A635E69616462606969686E5E61
6465686366686968665E616466605B6366636468606167645D615F5F61605E6362635C61
616463615E6263585E63655E6860645E675C5F6161635E60625E64645B5B61625B61575D
605D615D5E61625960665E5C615F5D63635F60625F60635D605D5B61665D5D5E5A615A5B
5E5E665D5464625B535D57606162605C635B5C605B5C5A5F5E595C5E585659605B59595A
595C5A5A535653595A5B5E605853545B5C5F55585D59585C5D5C5A595E56595859535463
57575C5B5958585C545C565B5654595A5B5C585B5655565F595B5C595C5B58585453535C
5C555858555253BB00000000000000000000000000000000000000000000000000000000
000000000000000000000000
CA5E5962616362615E5B5E5B5E5E555C5C625E5E61616164635F6062655E63605C5B5E64
63646363615F5F676365605C615B605B5E645B62645E5F5C646463646060615C5C615C61
63616360665B66695D5C5A5C615360585B625D615A666664695C5D695C645B5D63616062
61615E5C64645C635E606867645E5E65625E68666764696663625E6464645C6569646361
5F626A5B61616665606364605D6462615F60665B64656868606663656164616760605F63
606563666162696F65696E6B676C7269696B66636467616361686469636663636E636466
6865686A676A6E676368676A636061606168695C6960646B5E6265616769666360666665
6663696A6664726A69666263695E656666636060626B6A6069636D66666065606462665F
6C6660605E66615F60606861626064555F6761596460635E6460626963626361635E625D
5A5F60606161645C616559615D645A606461615E615B5B60635C5F5862585E5D605C5B5E
645F665863665C5F63645E63615D6A5B61606062615B5B635E5C5D676154556058615E55
605B59595B5C5D6166606059595E62605C555B66595E54615E58605B55595C5A5B595B5B
5E5B5B5B5A575C5959595453595A595A545B5B54585E5B595D5C595A5958586050565453
5556605B5A6055595C5B545A5859515354545958585D5958595660615A605C59595A545E
5B595857525656C600000000000000000000000000000000000000000000000000000000
000000000000000000000000
C35E5D5C5E5B5B5E5D5B62665C675E5C5B645E5C61605D665B5C63666361686064606168
616165636368615E605C67625E645E60616366616469606061606068635E545C5E606659
655F625B635B5E6464676063635A5459585D6159605E63605E615B61646062605D5D6261
5E5C5E62626157616461666166616764696360636060495C5E5E61675D615F6760686460
605F60645B686664686163616366666164636161635D6362646B5D66666B66616B646466
696666676B615E63616264636A6866636C67686A6B656664676665636868676268636769
615F6862646866616C626768656269616B606666676665686A656664636B5D666B626561
6761666765686765667068646A6C6C67666969616D5F6A6167666268666460646C676465
64615E60675C636B616660665C666860616464646756646363635F666860636064615C62
5D636461615F5D676160665E6062645A585D5C5961635C5E66635B5D5C635E565E576357
5B5E5E63645D615E5E5C5F60675C60616261665F645F5B5F64615F5E5E5B615B5A60635D
5C635B606056625D5B5A605B615E5A585856565A585B625B5858595D5C5C565A595B565B
5B56585E56585A55545D5B585A5C5A5A63595B5C575A5D54615953545A5B54565D5C5A59
60585D565B59535658535654585856565E59595A575B595B5E5B585B5961605C5D565B59
59545B5E565450BC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
CB615E575963655E60655861605E635E5B585A6260605B5C5E645B636061646365676162
676062635E666C6D5F6363696164615F5966585F5E5A58606067666667665F5C59615B61
58645A67665C5C5E645D645E5D5C58605F5E596963606362655E5E6762605D5E66566564
5C645964605C59635F6261605C655E635D5E6562636161676363666168616166675B645D
5F6661626761655B6167616269625D635E645F61616468616363615F63616563636B665E
66686364686B5F6866606C6B66666368696B626E66686363696960606368696F606C6261
616869696765645E646B6268666A696C615E63635F68706164656B6D64636B626461666C
68616462666B6960666864646864666C6568646663605E6A6B6F696261636B695E676863
645964655E6368606568685D6561625B5E665D5B5D60605E5C5C58645F5E665E675E5E5C
645F5E5E5C5C60635E645B59645C64685C5B5E5F5D5D63646060605B5B5B5E61635C5E5E
616260635C636056615E5B5D60635E615E635B5C615D5B53586260625B605E5E5D5E6061
5B64615A6161615E58615960605960595E5F5B5D60596158595B5B5851585D5656555B59
5B57565F57545758585E5C58585A59585E635B56595B595652595753595A5E585B585857
59595B53585E5A5656565C5456595C565B5B5858565D5459555C58576058565755545156
565454565D5850BC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
CF61645A5C5661605C5B5C675B675E5E6061646060606065575C675B5D655C645C616760
63646166606C696B6264605E66606562686161615D5E5C665F6265616062595A655D615C
5A63615F6366655E5E5D5E5C5D5E59575B5C5C6160645F5E64655D5E635F6061585B6160
61615C625F695F64646162635C5D5C60675E6C6662586866626363646969685B66606566
61615D5E5D605962635E6A606458615F6060666760645C64626966616367636369666764
636269646164645F6169636568636867676661676863645D6B6966686364686467636868
66666966616164696D6863625E5F615E6A61686B6663676364696665686A68696B656664
666066686B6465686064656C6C696466646462676066696464606B616662635E68656964
60636163665F5E655F66655E606162665F62606465666066545D68635F5E6065635E5C5D
5B6860606460665D5E64635E615C5A5B5A5D5F5A645B57615D5E645B615E5E615C645B59
645853595F5D58635D62646061595B60605F5F605F5B5E5A59605F625D61635A5E5C645E
5E5A655C5C5D6060615B625D60615F5760585B585E5C595C625B605E5F5A575A5659625B
5B5A5B565B58545C58585E5E55565A5A585954595B61545F595858585C545B59595E5B56
5C585B545E614D54505C595358595B5E525C585452525757595D5E5C5959565B5A555A55
54585A525E5556B400000000000000000000000000000000000000000000000000000000
000000000000000000000000
CA5B61635E5D5E635D5B5C615B5B636466635E5D6259605C6A6461676460636365636360
5C6667636967646B64645C67695C5C5E63616259685E5E6561635D666263645B61665E66
63665C5D6462645D63625E5C615A5C56605E5C606261605C6B646463696059666060645E
5E635C626263636161685E66645F5C6863645864645B696464646166605D616665656465
6560605C63646164666061645B696460616666685B645F62696363606167635B6766696B
66606A65666D666961616D6E6666646561666B69636A636C62626C64645D666866656C69
6961676B68616E676B6466696163645C656C59636463615B6363676B6B6A685E64616261
66666566686A62666C6866616068696D666666696B6567616B606B606366615E66626568
635C5E686164685F615F6164615C685E645E645F6365635C645A5E5A5D62615E585C605E
6060665E5D63636963604360615A53565A5B61625F5F5D65615D5E5C636160615B5E5E5C
605A5E605B6264665E5C5E64615F6366625D5C6360605C5F695F645E636358595F5C6360
5D6463636564605D5F615E61605A62605E5C5E5E5F5C605861595A595C5E5B5C5B635A5D
5358595E61565A56615F5C59575B575A5B5E5C5A56605B5E525859555C5B535259545359
5B5B5A58575358565B545956535E5A565B5859565C565B5B5A5959585C5E565B62605959
52595C5B5C5956C000000000000000000000000000000000000000000000000000000000
000000000000000000000000
D45F5B5E606766595C5C5D5E5C6363666161605E5F5E66645E63685F66646261605E6668
636168696C676C7066665E5E6863646163635C655B63665C636665616460596365665C64
5E645C606060615E6161585E5B5C605D5E616160645E60615C625D5E65685E64615C655C
6563615F6161616563675E66626761666161655F5B6E63645D64606368615E656563656C
615E5F5E5F6063646660686461645C615B635E6167676163625F695C636A616263635E66
66666268666A69636464666B69696364646863716B69696B6B656863636C666663646B61
6866636B67696666636263656670615F645F686F66685C606663686D6661656467646268
686961625F6064646166666362626C64646B696A686369626461636A60696361666B6760
64615D6663645D64605C646863636066686161665E5B63665D5F60585D5E605E5C645E64
67655D5E6860666A685F605B685E5B585E636163615B6161635E5D5E5F5E605E5D555B56
5A5A60605E5A5C6468606064645E6063635C62626158675D63635C5B63615B605C5B5968
5C5E595E60636662605E5B585C5E5E5F60635B5B5E5F615D595B56595D565B565C595C5C
5B5C585F5B5A59615B535958635B565B53595B5B5B5E5A605A645C54595C5B55595C5D60
5B585657585B545E565F5B585E565E585E58565B5D596058565E595B615B546057595C5A
5B5659565D5659BC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
CD625E62625E676161615B5F5D655E5960615C5D62606260616360646366646063676265
646262636869666965585E635F61626161645E63656162605F61606464605E615E5F5C62
60606069646361655B5C5D615B5A5F54585F61605F64645C605E64675F5B61605D5B685E
5C625F5E6863695B60596966656663606964646369666A6164615D5E605D6160635C5862
646361685E675E605E65686463685A5B64625D645C62685E63636D6467665E6363686A60
6964636360676964675E6E6863686C6B6F6761656C626961626665656461616664685E68
6863636563695E616263615F6367606961616A636464686866686361676C696367696369
6668636661696368636665646569656461656B64646D68636D67646969665E6B63626664
6162615B586663646266636260616961665E665B5A615F5B5C605A696B595E5C5E59655E
5963635E68636061616B5F605F5B605E5B60625F5E66615C5A5E605E5E595C60605E5858
595A585E5C5B615C5C5F6663605C66606061625B5E605C5D5F645E63645D5C6863606064
5B60655D5A616165605E6063635E6256605A5D5E5C615B5B605F615F5A595E5756605C5B
605A5B595B595460555B5A595F595D5E5D5A555C555B5C59595A595D5654595562595659
5E665359565E59545859575652575C605B5D5F58585959565A5A5A5E565D585D565E565E
595B58555D5050C400000000000000000000000000000000000000000000000000000000
000000000000000000000000
CD605D5E5864645E62615F665D5D645F6360636261596063636165646368666460685F62
61676B6964666D6461676068615F5D676062615C5C63655F64676C64616563665E605959
605E63605F5B6355685D5D5B5B6059645E605E615F5C6364635C666461696360605E5D64
645C62656563626062606160685E61646865655C68606265606666655E6861625D60625C
6360605F62636164646660645E64615F645E60635C6460686466636665605E6368636965
636468666C66676464626C6768636464695E616F66696065716667636A61666C60656268
5C676263686B696768646B606563626860696B6461656B68656062696368696960616B63
686669686666676F6662686062646B6468646B68686867706864686B6866635F5C636263
6C606262655E6563606361636063616560625D59646266605C645C5E595D60635B60645D
5D6269656964615F646063666565645A61625E62615F62686159646456615A63605B5C58
4D4D525B605F5D61635D63666263635A615E5E5D5E5E5A61606363605E6B5C635B5F645E
635F5D5F5C616164615B605A636259655B6466605E555962605960555E585E5E56545659
595C5E535F5C55565854565959615A56595B5B605C5C5F5D58595957595E5B5E595C5B56
565D555959595B5B555E5A5C595B5B5C5A5B5656555E57585E5D5E5C585559625E5E5C50
5C545355565753B500000000000000000000000000000000000000000000000000000000
000000000000000000000000
CC6060615E615C63685C63585E615B5F5F646464626761615E63655E5F646665695F6564
6663655F68686463696664646260635D6A5B666060605E60655C6061615E5D6061606163
635C62645C605B645C595B5F5C5E5E65635D63685C63645C636263686161666361606661
61645D625C6063685E65666D5E6761665E6B68665F6166646464656658616061625E5E60
6460626161615E5F65666162636064656666646365666464636266686868616766676164
6965646968696863676369646B69696868666D686468616A686E6366615E686B68676464
6162646064686167606B5E606662606268646361646B626561676B6666606F6865645E64
656962686464696769646366696661666761696066615E6960696C6469606466645C6066
606068646363635B665F635F5E60655B615E5D5660595B5C585E595B60605B585E5E5E60
645D6161615E666467665E6063615A65666B5C64645C5B636564615E645C565B635C5E56
4316415054665A5B5F6363605E665E665E585D655D5E5B5F625D615C636661615F5C7062
605C605F6161605C5C61605E6060595C5E61595C655E62585B59585459565D5E58595A63
585E565B605E5A545A5E5F5F5D5A5C595A5B5C595C60525B5858585E5758595756585B5E
5B57545754595958565E5855595C5B5B605E585C5E5B5C575958565A5658605C5454595C
5C595654595751C300000000000000000000000000000000000000000000000000000000
000000000000000000000000
CE606162595F675C60636561615B6C615E5F5E5C615E605C64636266665C646069646460
636364636B5F61665E625F6569605B6064626A6360606066616566605E5C5F6B605F605D
5A595C5C645D5C54615F57615E5860605B5A65645F67696166646161666866656B645C64
636464646964635F6060626A6462686369616260646363646268615B5C6164685D64665B
6360666D6860615E61605C606863646159635F5E5B5E66676464615D646860616161685E
6464606863676968686B676864616B6168696C6569636066606466696868666567646C63
64665C6465606A6363656A6966625E6D665E626865606869676664696568656264686769
6666676B6F65686B6C6C66635F5C636B64636468635E666667625C636369646666645F61
6460675E686961566560615C616B5F685E5F5960606060576358645E5958635B5C60595F
6561666B6366626A636268606065676361636565665C62646B5D5E5D5F5F5C5E5E585349
3B0000001E60635F605E5E5A5661645C5C63615D645C6561645E6060595A5C605C5C5C5B
5F5C5E615C61595E635C5E615C5C675C645B625B5F5E5A5C5C5C5E5E5858595C5A5A5A57
5B585D5B60535E5A5B5F595A5A565C615B5E5B5B595A525C575B5C58575E565E57595658
595A5B5B5B58535A595956575D5B565A5D5B5B5B585B5D685C575C5D5E605F5E5855585A
535C5C56555C60C000000000000000000000000000000000000000000000000000000000
000000000000000000000000
CC6359635B606059626064616661645D5E68625F60626A616461655D5F6B5F6964666061
666063636564695E635F63606A6363635E636463635E5B6663695C616264636461626361
5D5E5B606162555E5E615B685C55645C615A575C6563626665656061636363696A616360
605F62635D66646460616664615C695F606960676689616161615C605E67636165635D60
67686463625F625860615E6862666160626068605E6366646360675F6760696468655F67
6368675D5E666B6B6E6E6B6A676867696B60675E68656A61636768676464626B63676168
6969685F6468616870636763606964635F63665E6C66646866656463666662646A636663
6769686361696864695E6A6760666264666A5B6D61696E6467645E655F68636461686864
5E615E5E616366655E6863616664686458665F64625F5C6159615C5F625E5B61645D615C
656668626464655C636868696858665C66636366645F626166615C615D5C6159605A5E46
000000000C565A5B5C62625C62595F615F656960615E5E5B6059605D60605E636564625E
6063605C5C5B615E5F615B635B625C595D625A5E54595D605E5A5B61605B585758636053
5B56595C5958595C5B5A5C585F545A53595E5758575358595C635C5B5C575A5C59605351
57585C565F585854595E6159595C5C565C5C595C5B5C58565E5C5D565D5559616063595E
5A5D515C5A565BBA00000000000000000000000000000000000000000000000000000000
000000000000000000000000
CE63635B6A625E69635C5E606460655E5F595E5E585E5C5F5A63665E64606B6964646466
63646866646464675D5F676166635F60636A66626A665E666362645E605F5F60645E625F
5E586063595C5C6063605F58625B6262616157636B61555B626966676C5C60695E616764
6065605F6368686063635E6D5E605C6A60606660647B675F61616165606B6663675D5E64
5F5F656363665D615E635E68676062686160646B635F5E685E61666A6361616566646969
69696867665E6C686668666965726E686462696964656662666B61666868627060636068
666865686660655F5F6366646E68646C67676667656B655C6866675E686863636964686B
62646268686E6866666E6473656B616862666268666A696964665F656065656B69656B63
6A65695E64636465656061615C676163635B595260625D645B5E5E61626064566264615F
5E5C665D62636163666061616869616463616760626164615E62625C63605B625E615654
180000035560585B5E665C605D5C6161635C625E5B5F5B585F5E635E5C5B665D665C6160
5A585E625E5D595A585E5D5A5C5C5D555B5F5B605E5E60635E615C5D5D585E5C5B565D5A
6054585B595E5B5C58525C60595B56595F5A545854585D53565E60535B5B5D545953565E
5660615E5658555A5958585C565E65565D605F595F595C5C56595B5F545854585A5C5959
59545959595E58BC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D6605B605D5F66646363665F5E625B625D5F5B5D60615C656662615F616661635E616069
68616264665E5E66675E5C5F615E63616961635E58666761656768616765636660646561
605E665D5C675E5B5C5B60615A60595E61625C6061665E5E6360606464605A65635D5E68
6463686063615F62686060646A5E636463625C6367606461616661666862616369656263
5E60636C5E645C6264636665635D60646364616460635F6065656367646264616A616367
65696463696466666763626265637068686B655F696366696C67656962626E6561656267
656D636664686260696C666463695F6360686266636B696863646067666469686B656463
6464666569636669685E69626B68665C64616669666663666861656663626167655E5E62
64676E686364636466616260626660615F5C5C665D5B6361605E5E606663595F5E5C5E5A
5E60615C62676966636B66695E61645D6366686C645E64636067626163646161605B6063
5A435F5858605D665D5E62636261665C63606062636657635E6261655F63625D5E665C61
605C615E665D61615764636061645D64605C5E5C5B5C5C5B5C5B5A5D5E61565A5E5C5556
5A605B5458575C5E565B5C5959585659595B595A5A585B5C61545E5C585A5258585B5459
565B555657595B56565C5A5E5C5D5965635756595C5A60605D585D55545658585C595B5D
605C5956515B56C100000000000000000000000000000000000000000000000000000000
000000000000000000000000
D45F60626160695E605E6066695E675C5F5A615F63605E6365616860605F6266646C6167
6360645C66666367625E5F5F616A645E5E5D6B646760616164606465685E615F5E646263
62606168615C62605C5F636266626164655E60606165636065635F6061675E675F615B61
63635D6163666A6666616C636861605C6066636665605B615C605E615E6B636663665E60
6468685C646561616268635F64646A6666636263665A635F656561636371706760646863
6B6866686966666563646C6A6A696669636D6662616468676469636367676B686664666C
696B616567606462696C606069626C6B5D68676466616563626764685D606C6163685E62
66706066646B696464686866686B6463626C6665666F67646463675E66685B5F68666662
65606264666166695C60656064625E605E5E5C5A6063615E6060655E6162655B5E696464
67615A6164606C696764675F696B6362666760646660635D645F5F68645E5E63615C5F63
66615E5E5A595E5C6766616460695C6059646264635E645E665C625C5B65655C64626162
5B595B685D62646051615D57645F5B5C5D5B59645E5E5D5A61605E5A5C5D5C59585E5858
5A59595C585C595A5F5B545D5A5B595E5B59605959555C5C5A5E5C5B54575D525856545B
59565B5A5A5E5B59595B5C5E595C5C5A5C5C666057605E595E5C5B595C595C565B5F5D56
5956595B585858C400000000000000000000000000000000000000000000000000000000
000000000000000000000000
CE64616261645D5F5E6365646163605E6066615C5864636564615B67615F5E6C68635C64
62645F606569615A645C646463696A606768625C675E62625B61636364616060615C605C
5C666761645E6361636264656263615D68645E615E61645F645F646660645E64665E6160
5F646664655E636A615B5E626460626164646961635B685E64615F5C666867606460645E
666161615E6961605C655D5C655D5B666060676A64646066675E62696168646A64666A62
6B6667666A67616467646965666463616C69696965656062686C6B5F66675E6460686763
626763646B6266666C65696263605F5F666469645F6665666069686A626B656E6965686C
68646E68716C68686668646C61676866676961655B616B686564596B6665675C67686461
66635E66666A6168635E5E58605D5E61605B5F5B5D635D655F6264636266656463656367
656A5C5E625C64686465685E66636463676668686662686A6A61595C635E615F655F5D61
61606368586063605E6760596259636661605F695E62605C5E5E596161635C605E60605B
615C5E63635E616161645E5F595B5B5D5956605C5F61605C595C5A5A5656575E5D5B5F5B
535E5B5A565858595B595B586059605453585D5F56545A5862565B59525B595D595F5B58
5A585854595F585D59575958606159685A5C5C535E6060605C5E5A5C5C595459595A5556
585E5958515B57C000000000000000000000000000000000000000000000000000000000
000000000000000000000000
CF60626268635E5F61605E5B626860635B5C626064696166626363645E5D645C61636362
64666365645E616962666462646664686663646668696061666561645E69645E5D695F68
69605B616067636163636062605F6461615C5F6766686B63626968626762646061686661
5F6260646964606B61636562616669606064606366666267635B6164675A61605E666669
60695E645C676061615F6066616163636362616166616A5B605E66666865686464655D62
6668666A636A6763636866696861626969675963696C65686163686764696962646B6663
67686B606364646C6668646869636661656863686C5B68616264646A636468686A676464
686967696966686665676369666C6B646A696E6168616B64646966646366616864655F64
64616267636963636763616E655F60605C60645C635C5C605E605C676364626360625E60
666664605E66615C63656E5F636864656564646864676169626766605C665F5E605B655E
675D5F635D5F5F64636161615E60665F5E6461606365635E60586464616162645C605C5E
5E5F615E595E5B5C5F5F586561605C5D625F5C605E595560535B5E5C5C63595F56595C5B
595F5C5B58515359635A555C595F586458585859555F5B5B57545B5E5E5C545660585854
5B526058585454585C5E59615B6067645D5E5A5B5D5D6159585C59635E585D5F545B5E5E
51565B585F5258C800000000000000000000000000000000000000000000000000000000
000000000000000000000000
D0606267645B64645D616660686068605F606366646065645C64646262665B5F6564626B
6367606A6361676468606161636068676666656664666A66635F645D666664636161605E
6663635E6565615D6364626760615E6357626266665B5C6361666461685D646060636465
6864666565606C5E68636663616866615B606367625E6860646564655D60646061666862
68685B646470686A646360626163616868675E6362666667616068696368636E6966666B
61656B6963687161676C6D666566666966666B6664686271686A6868666463676E636968
676463646563606069636B65646B65665F6464645B63616369696B6861666968656C6860
6868616668616E6963666A60646161666B6F6D66656366666861646B72636566695C6365
5A655C676C6666605D6466636A6566635E5D5A5E5D596365616966666664696769636463
60635F64626164676C6061636166606861676764646064685E666A5D695A616461666366
63615D5E6364606360606261625E6663645E635D695E63605E58635E5F5D5E5C5C645E63
60566364625F58605F635E5F665B55595B5D5E59605E595F5B5C5B5C585D595E5F5C5854
5B585E5C5E545B595A57595A595B5E535A5A59615C565D5B5F5A555362575A54585A5452
5B60605A5C57605E62505B54575B5962635D5E585C5B5C605F605955595E5E5C5F565659
5A60595B5D5450C500000000000000000000000000000000000000000000000000000000
000000000000000000000000
C8695F5C616368646664656359685F66636E5E5E6161665C5F60655D5B5E645C64656769
6A6963616165676964666168635E646B6A666963666562646461635E6364696461636961
626563676166666460606161605C616066685C5D686560685F6568606067636962666A62
6061615F6D616266635C656B61666168605E69636368635D6561646260615C5E62636663
626264615F656960645E615D5F636D61635F5E68696866656B6A676163676763685E5B5E
68666969636E6969606B68716C696666696B716F646C6B6362616667626864605B64666A
6161686265646068736C676963606867615F615E635E5D6363666368656663656A696865
686161656B6467636465646A676964666664636C6667626462626264646A66666A696460
6C646665636361646A6366635F66686062635B5E606363686461615E5F6C5E5E5F61605D
56605D5E6566676B6665666B606862666769686B686661636A63615D606167615F5B5F5B
61615E666368616459645D6362636663605D6160635A5E62685D665E635E605F605C5A5E
5E5E585C605C5C5E5E5660625F5E615C5A5F5D5C5C5C615E605B59575B60555D5C595C58
595D5C5C635851575C5658606059595F5B5A55535656615C59505959565A5A5E59545658
5B535C5A5B5B5C5960575B5D5D5A62645E605D5B5A5963615E5C6356585B585E51635B51
57545C5A595256B800000000000000000000000000000000000000000000000000000000
000000000000000000000000
D16167606261646664646D646C656464625E59635E606462646064566262606464606863
615E645E5F69656460646368665E61626761676A66685E65636760686761646865626368
605C6864646B665E625C6361616663636164615D5D5E68636A6561645F63636664665D58
5E6C686366666663646668636864635B64665E646060636160675B6061655F6763606160
6360636666625F6367685E625F5E5E6665616661625E635E68686760655B606266696768
6B6E69676463666D676861636C6768666B6964686A616568656C666B6663695E6869606B
5B6B61646B646461666466636965656B6761666963616860685E5E6265676C6169626964
61696B6666635F71646B63626F656A666963606B666B66636B636867625E686461606363
5C6165656662645F625B686264655D6364595D61605A665C6261696761646B5C60656160
5F5F6263616061676B6766626463646062616B6B63646464686B63636364666765605964
60655B655E5A5B635B615C566161605B5D5D59645F5D5D69675960655E6363615C5C605F
5E5D5C63605E6B615C5D5B61605B5E5E66596560565C5E5A5D5D5B625B5864595960555C
5D58585357595E545C585A595E5755555A5058575C565C5959565C635C5B5856575C565C
56585B585354595E585759585E60596060565F595B585C5A555C5C5B5C535B5858575959
5A5B5A5C595650C600000000000000000000000000000000000000000000000000000000
000000000000000000000000
D264636363645C6164665E63605E645C5D615F5E6B636366646761615A5F6362645E6F66
66686161656B67686267606163695F6A64635C636465646464686063635E666061646963
676664686266616661626062645E5F6361645E6161606465646C5B6E69656661625E635E
6566626A656B6464665C626363646761675B636468606368686065666163655C615D5B61
63695E646465636164616062655F6767625E646363645F5E64625E666869666161646864
606E68656669616966666B6C6466666C646B6D65606367656369606C636B666866655E64
656564686B695C606565626867636763646166646364656961666A66606667636A666568
666761687066675E716765636C64616B686B6967687366656A6164686469636869646168
60676362646E62656667686B616E63655B606060615960636368685C6669626261645E64
66615C626661656A695D61686068615F6369667069626E69666867686A675C605B686161
605F6461666368626062605E65625A5C5D5B60606163605E5B6561606163605B5E5F605B
6361625F5C5E605C5F5F5D5D595B605B5E5F5B5F5C60635E59595B555B57595E595C5E60
5B575454575C5E5C57595C5B5B5F595B5C59585A5A5859565858595958565C565A585854
57585E5D5D5857585B5B5C6058595E5B586259625C635B5C5D5B59565D585A585A595450
585B5C5851564EC100000000000000000000000000000000000000000000000000000000
000000000000000000000000
D961615F5C5F63666664646962616666616363636060685F646568646062606468646467
626C616863635F5C64666160645F6568686B616668676666646966676265646460666367
605E5F62625E62665F63626C605E5E655F6864606B665D636A5E636E6963636D64695E61
66625F5F626564646C6B65665F6361695C6E5E626864686161695D616861686567646262
656662696963646061645D59636061686967656966616465646A696763696465646B6671
646B646A6F70686A6C6B6C6A66716662686B646962666968616B6468666168685E636469
69696C6664606A6668606661636C6E606671646864606B6A6060606B676463646E666863
616B62646961696767716663696B6767656168636163636B6A6B67656768625A67686A5F
675F6269635E666862665E65636A6463666259615B615E6262595F61685E695C6460605E
585B615D616B65666066615F616061616865646169696A6D6861646465645D646666645D
5E5E5E6464645C5C63645C5E655D635F615F5F646060666364695D65655E63656161645E
5C62635C615C59595C5C5D5860636063615E5D5C5C5E585D59605C5D586158625B5C6058
5F595D61605960555A5B5858635C5D59585A5B5962535858545E59585A5A565C58555D5E
5A5F616057585E615C5E5E586056625E59565D56595D595E595A5C58585959595E565C58
575B6057535B52C700000000000000000000000000000000000000000000000000000000
000000000000000000000000
C45E5D6A635C635E65676663606663646062585E58635C64656968605E65626763626F68
65676365675C6268666666656960636164635D6C6666636C665E686667676B6264626564
5C6064675E6C5C6365685C646B5A63676766606A5D61655F606669666960645E65616C64
666B666665695F6568646661676A636468626366696265646767615F6468686962686165
626160685C64606562625E615E636664666C6461616968656167676C64686264675E6E69
6867686969676C6B69686B64696D6B6B646467616E6763636864676867696B6967606368
686368646163606463676960686164646761675E5F646769685E606B666A6D6869686467
6767646E6971636B5D63686C686E666B6A6B676D69606D696E616B636F6869646C68686B
686863676168696064666A6969686966605E5E5E5F615B5A695E5C685D65636163615F64
596761656661686264676561646665646D686964666A6C66626264656061646B615D6660
5C635C63605C5E61585E5E5E605E60616461615C5E62635E6061605F62665F5F5E65665D
605B5C5C6765605E655E595F59616563625E635F5D5B635D5A5C5D5F5C5E605B5E5C5B56
615D565A605B555A5A5C5A565756535A5C5C545C5859595A59595D585B5D5A5B54596056
5C5A5956575C60595B5B605A5D5A61585858545B625961585E565C61505A575964585E56
565E605D59525ABD00000000000000000000000000000000000000000000000000000000
000000000000000000000000
CF65656166625E60605B626066646068606865666366676361645F645E5A636363646468
6564665F62636C5C666164616466676763646A5F645B6C605C60626463646566625B605B
61606F5E6B5E626166695C5E5F615C656468635E5C6161606B666567647063686B636268
6A666769676D63666764696660635E6A68635B65696464665D616260616361675E686667
6463646366646A696864656764606164636267666066676461686E6368646D6C6860636C
676A6D6C61686E6C6A696768656369616C69606B646B606561616661616E646B63666365
64666360685D64646863655E6266686B6368676E5E66665C62686E69646364686C6E6969
68646464696C66706B647160685D6A62696468676B666C63616C66685E63616567636166
666164616466666260646561656461615B61585F635E585E61615F65675E65635D656464
5E5B61646467625D6463646368645F63646B666A64666666646264666460666E67676869
626362606162665C656160686A635A5C645C5F5B5C616061635B645C676069635E5E6061
605F606860575D615B5E605C5C5A5C5A605B5F56615E5B595E60615E5A565B5F605D5860
576156595B595B5B5C595B5C595E5B5A5856595955585C5B595658515853565660605659
5C5D5C5A585A585F595E5B605B5A515A61605758585C5E575D5C5B535D5E585860595E5B
5154595D5B5954CC00000000000000000000000000000000000000000000000000000000
000000000000000000000000
D55D596564656162616461616A6462636567616261616167645E615F6664606264696865
656469696E6B6B6A6B686363695D6168576C6668626E6365646467646361616368636163
6967616860636A6763626160566161605C6C5B616364666061635F6669606964626B5967
615B64646663645B6762636764626465636A645D6060636C6B6360616166676365646561
686963666164666966655F6263666869696962636667626465636A716A64666463686669
69696C6B696B686B6B6E6E64646067666E6368666761626366696864655E656B6B676965
686862676068696A6068676C66686B6765625F686868646162606C68646564696A686E66
696867646B64606660676861616A6E666C686B6A6369666664686667636163695E62696B
62686A686469676569656360606062645B60605C65595B5D60605F6061625C585E60635E
5E5D6061666766666E616660616964606B6364676366616865655E6162645C685B615B68
64636B64616660616061675E6663616261655E595E655E6561636164665B61605E5B6761
60605E5B5A5E5F5C5B59605C5B60605E61595758605C5B585C5E565E5B6857595A595B55
60615B595E585860615D565C575A59515C595755585651565E5E555B59596354565A5D5D
585B575660605E56605E585961585B5753515B575B595B58586156525B5860595F595E5C
5B5E56585E5C5CC300000000000000000000000000000000000000000000000000000000
000000000000000000000000
C8695F61676963665F6966685F68636A685F695E6660675F63605E636164616765626369
6B6D6B605E5B5E636964645D625B685C6165646468616462616663616462605E65616866
60686868666461696159645F5C6466605F5E67606260606364635F635F64685E66666265
6B69646068606161636663646867686967585C69645B6661646468666064686463645F62
6469686C64656A6261666966636469616B6264696465646663666D6B6B6A676E696E636C
64686E686A6669646169686B6D66696B6A63676161666B656D67636C686C68606468626B
63656D666469626963686369646860636968696A615D6364616966666465696567686B65
6962646964665E5F656563616667665E64606669686E686E6B64616B6B656A6B65646966
656369666A6B636364615E615E656464645C686662595B5E5E5B5C616464606361635961
60615C65606163646563676061646560685F666E69685E675D6064645E6466625F606564
605E636160666661646462665B60665C646761645E67625D6461625F626161595C676062
5E5F5F5D5E5C5961695B5C616264665E5B595F5C595E5D5A5E56595D5C5B5B565E595D59
5D565D585D5A5B5E5958605F5D575D5B555B5B535F5A625657615959545658565B585F5A
5A5B5D59565E575958575C565D5B56575C5B5B5B5A5859545A595E5A5651535B57605A5A
5C5D5D575D5152C500000000000000000000000000000000000000000000000000000000
000000000000000000000000
CE5D606666625F646660646468645E64696C6866636560646162635C6968636B6A636361
5E6466636D5E6564616463635B6664676B6360656664686065636264636663645B646860
5E65616761615E626260645B5C66676161616565655C5E694D635F5E636164646A5C6366
63676467646369666666656867666464645F5F686467646D626464676664676C62646167
6764616563626C6E60615E605C666A646163666468686169636B67686661676964686D71
67686567686B676D646665696B6B6E6867666668645C67636464726364646462656C666B
68646E69696668616068666C64636369686465636A6169686A66606D646368696D696469
68615F606B6F6C6F646466696969666864696B606B6366686B6C6969676966645E636560
606A64696566686861616761695E5C646260656C626059595E60585E5C5C5E62645C5B67
5B6161605C5E6864656463676964696068686C626E6769635E62615C635E636660646061
625E636462635E685F685E6364626D616066646168605A5E6162616469636666605E6061
5E635E5D56625960615D5F595F5C5D6261605D5C5B5B5F5F585960595E585F585B615E5E
605D58595459595C5B6160565C575C585E635C545C595958585559535A5C5C62575A5854
5B5E5D5A595B57565B5A585C5C5A555C63595E5C5C5D59505A5E5E54565953645C5B595B
635E5C58595A53B800000000000000000000000000000000000000000000000000000000
000000000000000000000000
CE695C6168696060646560615E63666067636564636B6766616466606A63636565606968
6363686666636563615C64606666636560636163646D6161616B635E615F60645F606763
5D63666760606563636A5D605B6369636261635F666E645F695D64696B5F686B5E656964
61646762606261676664666665665F636665626A606663686669635F5F5E645B64676168
616066606763666165636368655E6367685C666166666769686A6E636C69616B6E686F6C
72636B6D6C746B7164696766696A63646B666B6B5E696C6C695D696A66676A6364636A69
696364696966646366635C6E686864665C645F626766646865665F686869616463626368
63616C6A64666667666B636B636666636C5E4307635E64666E6669676867686564676A64
6466616864605C685C656B61626765696460625E5B5C5E61566464605C6162595A5E605E
6561696863636460605E655A6C6664636961696D6C68655E63615C6360615B5F66646060
6566666161616063636369626B606461646464615E5C6C5A5C6265626064616064636159
585D5A5E635C5C60615E5E5C606158595F65565C5D5B5C5E63595C5B5E59605E5A59595B
5B5E58595B62555C5A615B5B5C585C5C59565656585553555E52595E5D595C58595D5963
5B5C5B5E58565C5B535A5A585C595C5E595A54575E5C566564605D5C5D5E645854595D55
555A5359595D5AC000000000000000000000000000000000000000000000000000000000
000000000000000000000000
8C3B3B3B443B403D39343A3C433E3F3B3C363641383C413D383939393F3B383C363C3E3B
3735383F373A373B363C3B3A3C3339363A383B3E3E3D3C3B413C3E3B3628343B38383737
393737373C393D3B373E3B3838383B3F373C43433D373932383C343C413E393E3E39323E
3439373B3A39393E3C393B3E403F3C3C3E3A36373B3838383B393C393B39393D363F3F38
39403A3B3A3C38413D3E3C3C3E4338373C3E3B3C383D383C383E383F383A403C3D43393E
403C393E3E3E423D3E3F364040454140443A3C3C3C40373E3C393C3C3E3A3F4041433C3E
4141423B383A373C3E37383B3B3E3B38393B3D3E39383B3E3D363C413C3C3B3C413E3D41
3C43363D3D3C3D39353C3C3E39383B39393D00003B3B3B363B3F3D3B423C3A393C3C393D
3B39383A3D35393C383E393C3D39343D39383638313F3B35363E3538342F34373139363B
353F3B40373B363838373C343B383E343A3A3B3F383B3B3C3A38363930363A2D39383734
3C323C363C3B38343C3F393736363834323B39363839353A3C3C36383533393C31363935
36313432313833312E33333435393430363333383833363734353533343B31343B333632
333238333935312E3334332F292C3634353033302E32372F3534332F35352C2F33303031
332E3036333030302C332C2F313331313335302B2F31382B323630313331343730333030
2E2D33362C342C8000000000000000000000000000000000000000000000000000000000
000000000000000000000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{350, 324.625},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005N0001A2000`400?l00000o`00003oo`3IfMUO
0=WIf@00o`3IfMUO0=WIf@00o`3IfMUO0=WIf@00o`3IfMUO0=WIf@00o`3IfMUO0=WIf@006`3IfMT2
00000300fMWI1@0000020=WIf@800000103IfMT2000002X0fMWI100000030=WIf@800000103IfMT2
000002/0fMWI0P0000040=WIf@800000103IfMT2000002`0fMWI0`0000020=WIf@800000103IfMT2
000002X0fMWI0P0000040=WIf@800000103IfMT2000001l0fMWI000J0=WIf@040000003IfMT0fMWI
00000340fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@040000003IfMT0fMWI00000080fMWI
00<000000=WIf@3IfMT09`3IfMT00`000000fMWI0=WIf@030=WIf@040000003IfMT0fMWI00000080
fMWI00@000000=WIf@3IfMT00000:@3IfMT010000000fMWI0=WIf@0000020=WIf@040000003IfMT0
fMWI00000080fMWI00@000000=WIf@3IfMT00000;03IfMT010000000fMWI0=WIf@0000020=WIf@04
0000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT09P3IfMT010000000fMWI0=WIf@000002
0=WIf@040000003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT000007P3IfMT001X0fMWI00@0
00000=WIf@3IfMT00000<@3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00@000000=WIf@3I
fMT000000P3IfMT00`000000fMWI0=WIf@0X0=WIf@030000003IfMT0fMWI0080fMWI00@000000=WI
f@3IfMT000000P3IfMT010000000fMWI0=WIf@00000[0=WIf@050000003IfMT0fMWI0=WIf@000000
0P3IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI02L0fMWI1@0000001@3IfMT0
00000=WIf@3IfMT000000080fMWI00@000000=WIf@3IfMT00000:`3IfMT010000000fMWI0=WIf@00
00020=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT0703IfMT001X0fMWI00@0
00000=WIf@3IfMT00000<@3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00@000000=WIf@3I
fMT000000P3IfMT00`000000fMWI0=WIf@0Y0=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI02X0fMWI00@000000=WIf@3IfMT00000
0P3IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI02L0fMWI00@000000=WIf@3I
fMT000000P3IfMT010000000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI000002T0fMWI0P00
00030=WIf@040000003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT000007P3IfMT001X0fMWI
00@000000=WIf@3IfMT00000<@3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@0W0=WIf@040000003IfMT0fMWI00000080fMWI00@0
00000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@00000Y0=WIf@040000003IfMT0fMWI0000
0080fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@00000Z0=WIf@030000003I
fMT000000080fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@00000Y0=WIf@03
0000003IfMT0fMWI0080fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@00000N
0=WIf@006`3IfMT200000340fMWI0P0000040=WIf@800000103IfMT2000002/0fMWI0P0000040=WI
f@800000103IfMT2000002/0fMWI0P0000040=WIf@800000103IfMT2000002`0fMWI0P0000030=WI
f@800000103IfMT2000002X0fMWI0`0000030=WIf@800000103IfMT2000001l0fMWI003o0=WIfEl0
fMWI003o0=WIfEl0fMWI003o0=WIfEl0fMWI003o0=WIfEl0fMWI003o0=WIfEl0fMWI003o0=WIfEl0
fMWI000F0=WIfOl00000B00000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@090=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@090=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00T0fMWI0P0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI03H0fMWI00<000000=WIf@3IfMT0=P3IfMT00`000000fMWI0=WIf@0f0=WIf@030000003IfMT0
fMWI03H0fMWI00<000000=WIf@3IfMT0=@3IfMT00`000000fMWI0=WIf@0Q0=WIf@4000000@3IfMT0
01H0fMWI00<000000=WIf@3IfMT0o`3IfMU40=WIf@4000000@3IfMT000h0fMWI0P0000060=WIf@03
0000003IfMT0fMWI0?l0fMWIA03IfMT100000040fMWI000=0=WIf@040000003IfMT0fMWI000000D0
fMWI00<000000=WIf@3IfMT0o`3IfMU40=WIf@4000000@3IfMT000d0fMWI00@000000=WIf@3IfMT0
00001@3IfMT3000000<0fMWI00h0[Zj^04a<C01BDU80DU9B05IFEP1@D500CTi>05IFEP1BDU80F5QH
05IFEP1@D500E5AD051@D080F5QH00H0EEEE05QHF01BDU80EUIF05]KF`1HF5P305IFEP0E055AD@1E
EED0FEUI05IFEP1IFET0EUIF065QH@1EEED0Fe]K05IFEP1LG5`0EeMG05IFEP1KFe/0GEeM05EEE@1B
DU80Fe]K05QHF01FEUH0E5AD0080FEUI0180EUIF05eMG@1CDe<0E5AD05MGE`1LG5`0HV9R05mOG`1I
FET0Fe]K05UIF@1NGUh0Hf=S05aLG01NGUh0Hf=S061PH01IFET205iNGP0305]KF`1PH600GUiN0080
GEeM00@0Hf=S05aLG01PH600FUYJ0P1LG5`03P1MGEd0HF5Q05]KF`1LG5`0GUiN06=SH`1NGUh0I6AT
06IVIP1KFe/0FUYJ069RHP1HF5P0I6AT0P1SHf<0;@1PH600GEeM065QH@1MGEd0Hf=S065QH@1IFET0
I6AT05eMG@1PH600GemO05aLG01NGUh0J6QX061PH01RHV80J6QX06=SH`1UIFD0I6AT065QH@1XJ6P0
JFUY071`L01^KVh0IVIV06][J`1QHF40KVi^06UYJ@1[Jf/0Kfm_06MWI`1XJ6P0JVYZ06a/K01^KVh0
JVYZ06QXJ01/K6`0JVYZ06a/K01[Jf/0M7Ad06i^KP0206a/K00<079bLP1YJFT0LW9b06m_K`1cLg<0
MgMg07EeM@1cLg<0LG5a06UYJ@1^KVh0LW9b0`1`L7005P1fMWH0K6a/07=cL`1`L700KVi^06IVIP1`
L700K6a/06i^KP1[Jf/0Kfm_06IVIP1XJ6P0K6a/06][J`1_Kfl0J6QX06m_K`1fMWH0K6a/06i^KP1/
K6`206][J`0R06YZJP1VIVH0JFUY07=cL`1ZJVX0HF5Q075aL@1XJ6P0JFUY06=SH`1WIfL0LW9b06IV
IP1ZJVX0IFEU06MWI`1UIFD0IVIV06e]K@1QHF40Hf=S06][J`1UIFD0J6QX06ATI01/K6`0JFUY06][
J`1YJFT0IVIV06a/K01_Kfl0H61P065QH@80IVIV01h0Hf=S061PH01RHV80H61P06ATI01MGEd0HF5Q
06ATI01NGUh0HF5Q05aLG01MGEd0H61P05eMG@1RHV80FEUI05mOG`1HF5P0GUiN065QH@1KFe/0E5AD
061PH01HF5P0De=C05ADE01MGEd0H61P05ADE01JFUX205UIF@0905=CD`1@D500DU9B055AD@1DE5@0
DE5A05ADE01CDe<0DU9B00<0E5AD00L0F5QH05]KF`1DE5@0FEUI05YJFP1IFET0EUIF0080FEUI00H0
F5QH05IFEP1DE5@0D51@05ADE01HF5P205MGE`@0DE5A00T0EeMG05IFEP1ADE40D51@05ADE01CDe<0
EEEE05ADE01ADE405`0000040=WIf@<000000@3IfMT000d0fMWI00@000000=WIf@3IfMT000001@3I
fMT00`000000fMWI0=WIf@030=WIf@030<71`@1NGUh0Hf=S0080G5aL00<0H61P05IFEP1OGel00P1K
Fe/205eMG@04065QH@1PH600H61P061PH080HV9R00L0Fe]K06ATI01MGEd0I6AT05iNGP1PH600GemO
0080Fe]K00H0GUiN06=SH`1PH600GUiN061PH01XJ6P206=SH`0:05iNGP1WIfL0HV9R05UIF@1LG5`0
FEUI06QXJ01NGUh0J6QX061PH080HF5Q00L0G5aL065QH@1TI6@0JVYZ06IVIP1LG5`0JFUY0080HV9R
04D0IFEU06=SH`1QHF40J6QX06UYJ@1XJ6P0IfMW06UYJ@1VIVH0JFUY061PH01[Jf/0IVIV06UYJ@1P
H600JFUY06IVIP1SHf<0GemO06MWI`1XJ6P0HF5Q06MWI`1YJFT0H61P069RHP1VIVH0Hf=S06e]K@1`
L700K6a/06YZJP1TI6@0KFe]06][J`1]KFd0K6a/06EUI@1^KVh0Hf=S061PH01YJFT0KVi^06a/K01a
LG40J6QX06e]K@1[Jf/0Hf=S06m_K`1/K6`0JFUY06e]K@1[Jf/0LG5a071`L01_Kfl0LG5a06][J`1^
KVh0LW9b075aL@1cLg<0LG5a07MgM`1iNGT0L71`07=cL`1fMWH00P1`L7001@1/K6`0M7Ad07=cL`1a
LG40MGEe0080N7Qh0140Ng]k06UYJ@1gMgL0LG5a07UiN@1dM7@0OGem06e]K@1iNGT0MGEe075aL@1l
O7`0Lg=c07]kN`1nOWh0O7al07]kN`0207emO@0607YjNP1hN7P0N7Qh07YjNP1]KFd0NGUi0P1kNg/0
1`1iNGT0M7Ad07YjNP1hN7P0MGEe07QhN01aLG400P1dM7@01@1hN7P0NGUi07moO`1kNg/0MGEe0080
MgMg01@0Ng]k07QhN01fMWH0MWIf07alO01`L700MgMg06a/K01iNGT0LW9b07=cL`1gMgL0MWIf07Ad
M01aLG40Lg=c07AdM01^KVh0JFUY06e]K@80M7Ad0P1`L7003`1ZJVX0KVi^07=cL`1_Kfl0K6a/07=c
L`1hN7P0MGEe075aL@1`L700KVi^06][J`1]KFd0J6QX06UYJ@0206e]K@0706QXJ01RHV80HF5Q06AT
I01YJFT0IVIV06MWI`0206IVIP80IFEU02H0Jf][06MWI`1XJ6P0GUiN06UYJ@1PH600I6AT05iNGP1Q
HF40HV9R06IVIP1QHF40Hf=S05mOG`1UIFD0HV9R05iNGP1MGEd0Fe]K05aLG01HF5P0GUiN061PH01K
Fe/0EeMG05aLG01MGEd0EEEE06=SH`1PH600Fe]K065QH@1UIFD0GemO069RHP1PH600FEUI05QHF080
GUiN01@0GEeM05UIF@1IFET0H61P05YJFP1FEUH0H61P05aLG01PH600EEEE05aLG01CDe<0EUIF05UI
F@1FEUH0EEEE05ADE01NGUh0G5aL05iNGP80FUYJ5`0000060=WIf@4000000@3IfMT000d0fMWI00@0
00000=WIf@3IfMT000001@3IfMT00`000000fMWI0=WIf@030=WIf@030=?Cd`1OGel0H61P0080H61P
00H0Hf=S06ATI01TI6@0Hf=S05]KF`1TI6@206=SH`0806ATI01NGUh0J6QX06QXJ01KFe/0HF5Q06EU
I@1RHV8206=SH`0606ATI01VIVH0HF5Q065QH@1^KVh0K6a/0P1XJ6P0301YJFT0IfMW06IVIP1SHf<0
JFUY06IVIP1QHF40IVIV06=SH`1PH600I6AT06=SH`80IVIV0P1UIFD0301`L700J6QX06IVIP1YJFT0
L71`06UYJ@1ZJVX0JFUY06IVIP1`L700J6QX06][J`80K6a/00L0KVi^06a/K01[Jf/0K6a/06=SH`1[
Jf/0IfMW00<0Jf][01L0KFe]06i^KP1[Jf/0KFe]06QXJ01YJFT0K6a/06][J`1/K6`0JFUY071`L01X
J6P0K6a/06UYJ@1ZJVX0IVIV06YZJP1YJFT0Jf][06e]K@1cLg<0L71`075aL@0206][J`0e079bLP1^
KVh0LW9b075aL@1[Jf/0MGEe07=cL`1fMWH0K6a/06][J`1fMWH0Lg=c075aL@1_Kfl0L71`06][J`1_
Kfl0MWIf07QhN01aLG40K6a/07alO01fMWH0Kfm_075aL@1hN7P0Ng]k07=cL`1gMgL0N7Qh07]kN`1j
NWX0MWIf071`L01fMWH0NGUi07QhN01lO7`0NWYj07alO01hN7P0O7al07]kN`1iNGT0MgMg07QhN020
P800N7Qh07YjNP1hN7P0P82007]kN`1hN7P00P1iNGT03P21PH40Ph>307emO@1iNGT0Ph>307]kN`22
PX80Ph>307]kN`1oOgl0O7al07YjNP1kNg/0M7Ad0P1iNGT0401kNg/0MWIf07UiN@1mOGd0PH6108>3
P`1lO7`0PH6107]kN`1nOWh0N7Qh07UiN@1oOgl0MGEe07QhN01nOWh207QhN00?071`L01hN7P0MWIf
075aL@1hN7P0LW9b07QhN01iNGT0M7Ad07=cL`1eMGD0N7Qh07]kN`1fMWH0LW9b0080Lg=c00T0MWIf
07QhN01fMWH0Lg=c07UiN@1aLG40N7Qh06e]K@1aLG400P1^KVh01`1XJ6P0M7Ad075aL@1[Jf/0JFUY
06][J`1^KVh00P1ZJVX01@1TI6@0KVi^071`L01XJ6P0L71`0080J6QX00d0KFe]06IVIP1ZJVX0Jf][
06ATI01XJ6P0IVIV06UYJ@1UIFD0I6AT06EUI@1TI6@0Jf][0080JFUY00T0I6AT06QXJ01QHF40HV9R
05]KF`1UIFD0IfMW06QXJ01TI6@0101PH6004P1MGEd0EUIF05iNGP1TI6@0GUiN06=SH`1TI6@0GUiN
05YJFP1OGel0Hf=S06ATI01PH600G5aL06=SH`1NGUh0FUYJ05mOG`80FUYJ00@0FEUI05eMG@1LG5`0
E5AD0P1LG5`0201KFe/0H61P06ATI01JFUX0GUiN05UIF@1KFe/0EeMG5`0000060=WIf@4000000@3I
fMT000h0fMWI0P0000060=WIf@030000003IfMT0fMWI00<0fMWI01P0e]KF06=SH`1SHf<0I6AT065Q
H@1NGUh0HF5Q069RHP1VIVH0IfMW061PH01LG5`0I6AT05iNGP1[Jf/0K6a/06UYJ@1[Jf/0Hf=S06UY
J@1WIfL0Hf=S06QXJ01UIFD206IVIP0R06QXJ01/K6`0I6AT06YZJP1XJ6P0JFUY06QXJ01QHF40IfMW
06IVIP1[Jf/0LG5a06][J`1]KFd0JFUY06IVIP1XJ6P0H61P06][J`1SHf<0J6QX06MWI`1/K6`0Jf][
069RHP1[Jf/0KFe]06UYJ@1/K6`0KVi^06a/K01^KVh0L71`075aL@80K6a/00/0KVi^06m_K`1ZJVX0
LG5a06QXJ01`L700K6a/06=SH`1ZJVX0Kfm_06i^KP0206e]K@0:06UYJ@1]KFd0IFEU06e]K@1eMGD0
LG5a06][J`1^KVh0K6a/06IVIP80KVi^00h0JVYZ06QXJ01^KVh0MWIf071`L01^KVh0MWIf06e]K@1^
KVh0L71`07=cL`1`L700MWIf079bLP80LG5a00L0Lg=c075aL@1hN7P0MgMg071`L01fMWH0Jf][0080
M7Ad00X0MGEe079bLP1gMgL0MWIf07=cL`1hN7P0L71`07QhN01kNg/0OWin0P1hN7P05`1fMWH0QHF5
0820P01gMgL0Ng]k07QhN01kNg/0N7Qh0861P@1kNg/0O7al07YjNP20P800Ogmo07alO020P800Ogmo
08B4Q020P800OWin07]kN`1oOgl0PH610080Ph>30140Ng]k0861P@25QHD0PH6108>3P`25QHD0NWYj
08J6QP25QHD0PH6107inOP20P800NWYj07alO01kNg/0Lg=c08>3P`0307alO00B07emO@1lO7`0NGUi
08>3P`20P800MGEe0820P01kNg/0OGem0820P01eMGD0OWin07moO`23Ph<0OGem0820P01fMWH0OGem
0`1hN7P01@1dM7@0OGem07alO01jNWX0N7Qh0080Lg=c0180LG5a07=cL`1gMgL0M7Ad07UiN@1lO7`0
LG5a07QhN01gMgL0Lg=c07]kN`1eMGD0Lg=c07MgM`1aLG40Lg=c06i^KP1]KFd306i^KP0:071`L01g
MgL0LG5a06i^KP1]KFd0LW9b06a/K01^KVh0K6a/06ATI0<0Kfm_00D0IVIV06a/K01VIVH0JFUY06QX
J00206YZJP0;06][J`1XJ6P0Hf=S06e]K@1VIVH0JFUY06ATI01VIVH0GUiN05]KF`1RHV800`1SHf<0
1P1_Kfl0GEeM05iNGP1QHF40IfMW061PH080FEUI01l0HF5Q06=SH`1XJ6P0GUiN061PH01VIVH0GUiN
061PH01MGEd0GemO061PH01VIVH0Jf][05UIF@1JFUX0GUiN05mOG`1KFe/0F5QH065QH@1KFe/0GUiN
05aLG01GEeL0FUYJ061PH01MGEd0EeMG05ADE01NGUh0Fe]K01L000001P3IfMT100000040fMWI000F
0=WIf@030000003IfMT0fMWI00<0fMWI0100d=3@06UYJ@1PH600Fe]K06QXJ01PH600JFUY06IVIP1P
H600I6AT069RHP1UIFD0IVIV06YZJP1WIfL0JVYZ0`1WIfL04`1SHf<0K6a/06a/K01[Jf/0Hf=S06IV
IP1[Jf/0IVIV06MWI`1]KFd0I6AT06UYJ@1TI6@0IVIV06UYJ@1]KFd0GemO05eMG@1VIVH00P1SHf<0
1@1PH600IVIV06YZJP1WIfL0Hf=S0080JFUY0P1[Jf/04@1/K6`0Jf][06a/K01VIVH0MWIf06YZJP1[
Jf/0M7Ad06][J`1^KVh0LG5a06m_K`1`L700IVIV06m_K`1]KFd0LG5a0080Kfm_00d0K6a/06EUI@1c
Lg<0Jf][071`L01_Kfl0M7Ad06i^KP1_Kfl0Jf][06i^KP1ZJVX0KVi^0080Kfm_01T0L71`06a/K01^
KVh0JFUY07AdM01`L700MGEe06m_K`1gMgL0LG5a071`L01[Jf/0N7Qh075aL@1_Kfl0KVi^06e]K@1e
MGD0MgMg07=cL`1_Kfl0L71`07=cL`1hN7P0MGEe0080NGUi00<0N7Qh06m_K`1fMWH00P1iNGT03P1n
OWh0OGem07]kN`1lO7`0Ng]k07UiN@1eMGD0MgMg07YjNP1iNGT0OWin07alO01iNGT0P8200P1kNg/0
0`23Ph<0OWin07QhN00207inOP1G0861P@24Q8@0QHF50861P@1kNg/0P8200861P@20P800QHF508B4
Q023Ph<0P82008B4Q025QHD0PH6108J6QP1nOWh0Ph>307moO`27QhL0Rh^;08R8R020P800QHF50861
P@24Q8@0NWYj07IfMP1oOgl0OWin07moO`1hN7P0Ng]k07emO@1nOWh0Ph>307inOP20P800NWYj07Mg
M`21PH40Ogmo07UiN@1fMWH0Ph>30820P02:RXX0Ph>30861P@1iNGT0Ng]k07emO@1eMGD0NGUi07Ad
M01gMgL0Lg=c07alO01kNg/0O7al07inOP1kNg/0NWYj07IfMP1eMGD0MgMg07=cL`1gMgL0Lg=c07Ad
M01_Kfl0MWIf06m_K`1bLW80LG5a07emO@1aLG40O7al07AdM01kNg/0M7Ad07YjNP1`L700K6a/06i^
KP1/K6`0LG5a0080KVi^00/0LG5a06i^KP1_Kfl0L71`06][J`1^KVh0M7Ad071`L01^KVh0IfMW06UY
J@0206IVIP0R06][J`1XJ6P0K6a/06ATI01YJFT0J6QX06UYJ@1UIFD0GUiN06ATI01KFe/0HF5Q069R
HP1TI6@0Hf=S06MWI`1PH600J6QX061PH01NGUh0HV9R06EUI@1NGUh0HF5Q06=SH`1XJ6P0FUYJ06IV
IP1MGEd0GUiN06=SH`1VIVH0IFEU06UYJ@80IFEU0140G5aL069RHP1PH600FEUI061PH01RHV80Fe]K
061PH01KFe/0H61P05QHF01NGUh0FEUI05MGE`1HF5P0G5aL05=CD`0G000000H0fMWI0@0000010=WI
f@005P3IfMT00`000000fMWI0=WIf@030=WIf@0:0=cLg01UIFD0HF5Q06=SH`1QHF40IFEU05iNGP1U
IFD0IVIV06EUI@80IVIV01H0H61P06QXJ01WIfL0IVIV06EUI@1YJFT0J6QX06ATI01XJ6P0Hf=S06AT
I01ZJVX0J6QX06a/K01]KFd0HV9R06][J`1YJFT0Kfm_06][J`1VIVH0IfMW0P1VIVH00`1XJ6P0IfMW
06e]K@0206UYJ@0506ATI01[Jf/0IVIV06][J`1VIVH00`1YJFT02P1cLg<0K6a/06a/K01VIVH0J6QX
06m_K`1^KVh0Jf][06EUI@1[Jf/206QXJ00306m_K`1WIfL0LG5a0080K6a/01T0J6QX06a/K01/K6`0
KFe]06a/K01cLg<0K6a/07IfMP1^KVh0O7al06a/K01^KVh0Hf=S06a/K01ZJVX0M7Ad071`L01hN7P0
L71`06m_K`1^KVh0LG5a06m_K`1^KVh0Lg=c0080M7Ad00L0Kfm_079bLP1cLg<0Lg=c07AdM01jNWX0
KFe]0080MGEe00d0MgMg07AdM01fMWH0Kfm_07UiN@1gMgL0N7Qh075aL@1dM7@0MgMg0820P01mOGd0
MgMg0080OWin0380O7al07]kN`1hN7P0O7al07inOP1mOGd0NGUi06i^KP1jNWX0OWin08B4Q01kNg/0
Ph>307YjNP20P800OGem07alO01iNGT0OGem0861P@24Q8@0OWin0861P@1iNGT0OGem07inOP1jNWX0
P82008B4Q01iNGT0Q8B408^;R`22PX80QXJ607emO@1oOgl0R8R808:2PP1mOGd0Ph>30820P022PX80
OGem07]kN`23Ph<0NWYj0820P023Ph<0R8R807QhN080Ng]k0P23Ph<07022PX80O7al07alO01mOGd0
NGUi07moO`1iNGT0PH6107emO@24Q8@0Ph>308:2PP1nOWh0QHF507alO01eMGD0OWin07]kN`1lO7`0
Ng]k07alO01jNWX0Lg=c07UiN@1kNg/0MGEe07YjNP1gMgL207IfMP0507]kN`1mOGd0L71`07AdM01g
MgL00P1cLg<04020P800Ng]k07IfMP1cLg<0MWIf06YZJP1hN7P0M7Ad07=cL`1dM7@0MWIf07=cL`1[
Jf/0L71`06e]K@1gMgL206i^KP0:06e]K@1[Jf/0Kfm_06i^KP1aLG40Lg=c06i^KP1/K6`0I6AT06i^
KP80IVIV01X0JFUY06QXJ01`L700JFUY06QXJ01VIVH0K6a/06UYJ@1SHf<0I6AT05iNGP1LG5`0H61P
065QH@1TI6@0J6QX061PH01RHV80GEeM065QH@1PH600IVIV06ATI01PH600GUiN065QH@80H61P00@0
G5aL06ATI01XJ6P0IfMW0P1TI6@04`1YJFT0HF5Q05aLG01]KFd0HF5Q05aLG01KFe/0FEUI069RHP1K
Fe/0GUiN065QH@1GEeL0G5aL05]KF`1IFET0HF5Q05YJFP1PH6005`0000060=WIf@4000000@3IfMT0
01H0fMWI00<000000=WIf@3IfMT00`3IfMT04@3Kfm/0Hf=S069RHP1PH600HF5Q06=SH`1VIVH0GemO
06ATI01VIVH0JVYZ061PH01XJ6P0JFUY06MWI`1/K6`0Hf=S0080IVIV01/0JFUY06IVIP1VIVH0IFEU
06UYJ@1[Jf/0JFUY06ATI01VIVH0Hf=S06i^KP1TI6@0IVIV06ATI01UIFD0I6AT06UYJ@1XJ6P0IFEU
06QXJ01SHf<0KFe]065QH@1WIfL0JFUY06EUI@1]KFd00P1[Jf/02P1^KVh0Jf][06YZJP1]KFd0I6AT
06][J`1XJ6P0KVi^079bLP1YJFT206QXJ00B06EUI@1/K6`0K6a/06UYJ@1aLG40KVi^07QhN01[Jf/0
LW9b07=cL`1/K6`0KVi^06][J`1/K6`0MWIf07MgM`1aLG40J6QX0P1cLg<02@1^KVh0Jf][06UYJ@1c
Lg<0LG5a07MgM`1bLW80Lg=c06YZJP0206i^KP0;07=cL`1aLG40N7Qh06][J`1`L700Ng]k06i^KP1/
K6`0MGEe07=cL`1iNGT00P1dM7@02@1eMGD0Lg=c07QhN01fMWH0O7al06i^KP1aLG40M7Ad06i^KP02
07]kN`0R07YjNP1mOGd0N7Qh07]kN`1iNGT0Lg=c07UiN@1gMgL0Ng]k07moO`1nOWh0NWYj07QhN01f
MWH0PH6107moO`24Q8@0QHF507IfMP1lO7`0Ph>307]kN`21PH40R8R80820P021PH40PX:208R8R021
PH40P82007inOP25QHD0RHV908:2PP80PH6101P0P82008B4Q020P800Ogmo07emO@23Ph<0Q8B40861
P@24Q8@0QHF50861P@1mOGd0Ph>30820P01hN7P0P82007MgM`27QhL0Ph>307]kN`1nOWh0PH6107in
OP21PH4208B4Q00@08>3P`21PH40Ng]k07alO024Q8@0P82007emO@1lO7`0NGUi07YjNP1mOGd0NGUi
07]kN`1dM7@0NGUi0820P080O7al02P0OWin07QhN01iNGT0O7al07YjNP1fMWH0M7Ad07IfMP1gMgL0
M7Ad07=cL`1kNg/0MWIf07AdM01^KVh0L71`07AdM01_Kfl0LG5a06][J`1dM7@0JFUY06YZJP1`L700
KVi^06][J`1YJFT0NWYj07=cL`1bLW80Lg=c06a/K01WIfL0L71`07EeM@1/K6`0LW9b06QXJ01YJFT0
I6AT0P1YJFT01`1aLG40K6a/06IVIP1XJ6P0Jf][06UYJ@1[Jf/00`1WIfL206=SH`0<05iNGP1WIfL0
Fe]K06MWI`1XJ6P0GemO05YJFP1QHF40G5aL06=SH`1QHF40GemO0P1SHf<206ATI00J05mOG`1]KFd0
GUiN06EUI@1LG5`0IFEU05iNGP1PH600GUiN06IVIP1PH600HV9R05aLG01NGUh0GemO061PH01KFe/0
H61P05eMG@1LG5`0H61P05aLG01QHF40GUiN05UIF@1NGUhG000000H0fMWI0@0000010=WIf@005P3I
fMT00`000000fMWI0=WIf@030=WIf@040>?Sh`1KFe/0HF5Q06IVIP80Hf=S00/0IVIV061PH01YJFT0
I6AT05eMG@1VIVH0GUiN06i^KP1WIfL0J6QX065QH@0206IVIP0806UYJ@1VIVH0Jf][06ATI01VIVH0
KVi^06UYJ@1ZJVX206=SH`0?06QXJ01VIVH0JVYZ069RHP1NGUh0I6AT06IVIP1YJFT0L71`06MWI`1S
Hf<0Jf][06EUI@1[Jf/0IVIV00<0JVYZ00h0Hf=S06YZJP1^KVh0IVIV06m_K`1cLg<0L71`06UYJ@1^
KVh0LW9b06MWI`1XJ6P0LG5a06i^KP80L71`01D0K6a/06YZJP1aLG40KVi^06e]K@1ZJVX0Kfm_06e]
K@1^KVh0JVYZ06i^KP1aLG40K6a/06m_K`1bLW80JFUY07AdM01bLW80KVi^079bLP1aLG400P1cLg<0
6@1aLG40Kfm_075aL@1eMGD0L71`07=cL`1aLG40MGEe075aL@1fMWH0L71`07=cL`1jNWX0MWIf06m_
K`1hN7P0M7Ad07QhN01cLg<0N7Qh07]kN`1iNGT0N7Qh0820P01kNg/00P1lO7`07@1hN7P0Ph>308F5
Q@28R8P0MgMg07inOP24Q8@0OGem07UiN@1hN7P0P82007]kN`1lO7`0PH6107EeM@21PH40Ph>307em
O@23Ph<0PH610820P01jNWX0PX:20861P@23Ph<0Ng]k07moO`21PH40P8200080Q8B401@0PX:208>3
P`1oOgl0Rh^;08R8R020P800Ph>30820P028R8P0Q8B40861P@23Ph<0QXJ607emO@26QXH0Ng]k08J6
QP20P800PX:20820P080PX:200d0QhN707moO`21PH40P82008B4Q026QXH0PX:207]kN`20P800R8R8
08^;R`1jNWX0O7al0080Ogmo00<0OGem07inOP1lO7`00P1kNg/207UiN@0507inOP1fMWH0Ng]k07]k
N`1fMWH00P1kNg/0?01lO7`0P82007inOP1lO7`0MGEe07=cL`1hN7P0Ng]k07MgM`1lO7`0MGEe07Mg
M`1_Kfl0Lg=c06m_K`1dM7@0NGUi07IfMP1cLg<0N7Qh07IfMP1^KVh0KFe]06m_K`1YJFT0KFe]06a/
K01]KFd0Lg=c06a/K01`L700Jf][06e]K@1/K6`0MGEe06i^KP1/K6`0Jf][06QXJ01_Kfl0HV9R06EU
I@1[Jf/0J6QX06UYJ@1TI6@0Jf][06UYJ@1WIfL0Jf][06MWI`1TI6@0IfMW06ATI01QHF40H61P06MW
I`1RHV80Hf=S05iNGP80I6AT00l0HV9R065QH@1OGel0I6AT06EUI@1QHF40JFUY05eMG@1YJFT0Hf=S
05iNGP1UIFD0GUiN05eMG@1IFET00P1PH6002@1LG5`0GUiN061PH01SHf<0H61P05IFEP1LG5`0EUIF
05]KF`0205eMG@0605MGE`1HF5P0G5aL05iNGP1RHV80Fe]K5`0000060=WIf@4000000@3IfMT001H0
fMWI00<000000=WIf@3IfMT00`3IfMT02`3Cdm<0GemO06=SH`1VIVH0I6AT06=SH`1OGel0HF5Q06a/
K01VIVH0Hf=S0080I6AT0180IFEU06ATI01^KVh0I6AT06=SH`1[Jf/0Hf=S06MWI`1QHF40Hf=S06i^
KP1VIVH0Jf][065QH@1TI6@0IfMW06UYJ@1TI6@206][J`0306EUI@1YJFT0IfMW0080Jf][00H0J6QX
06ATI01QHF40HV9R06][J`1RHV8206][J`0F06ATI01^KVh0JFUY06a/K01[Jf/0L71`06QXJ01^KVh0
Hf=S075aL@1`L700KFe]07=cL`1`L700Kfm_06][J`1]KFd0Lg=c06QXJ01^KVh0L71`06e]K@80L71`
00`0N7Qh06UYJ@1[Jf/0MWIf07UiN@1cLg<0MWIf071`L01gMgL0Lg=c06m_K`1`L70307AdM00B07=c
L`1eMGD0KVi^07EeM@1fMWH0KVi^079bLP1dM7@0N7Qh07=cL`1XJ6P0Lg=c075aL@1^KVh0MGEe071`
L01bLW80LG5a0P1dM7@207IfMP0;07UiN@1jNWX0O7al0820P01dM7@0NWYj0820P01hN7P0Lg=c07Mg
M`1lO7`00P1iNGT04@25QHD0O7al07YjNP1iNGT0QhN70820P01fMWH0P82007emO@1iNGT0O7al07]k
N`1nOWh0NWYj08:2PP20P800Q8B40080Ph>300L0PH6107inOP23Ph<0P82008F5Q@23Ph<0RHV90080
Q8B40200Ph>308N7Q`22PX80Q8B408>3P`1oOgl0QXJ608Z:RP21PH40RHV908J6QP20P800OWin0861
P@20P800OWin0820P026QXH0PX:208R8R020P800NGUi0861P@20P800RHV907inOP29RHT0PH6108>3
P`1nOWh0Ogmo07inOP80Ng]k00h0PX:20861P@1nOWh0O7al08>3P`1nOWh0PH6108J6QP1nOWh0MWIf
07]kN`1jNWX0NGUi07alO0<0Ng]k00@0O7al07]kN`1oOgl0MgMg0P1nOWh0101iNGT0N7Qh07]kN`1b
LW8207EeM@0306a/K01^KVh0MGEe0080KVi^00/0M7Ad079bLP1hN7P0J6QX06MWI`1]KFd0JFUY079b
LP1aLG40IFEU07AdM00206i^KP04075aL@1^KVh0JFUY06e]K@80JFUY00T0KFe]06][J`1[Jf/0KVi^
06QXJ01/K6`0Jf][06IVIP1SHf<00P1VIVH01`1RHV80K6a/069RHP1QHF40Hf=S05eMG@1TI6@00P1Q
HF400`1SHf<0IVIV069RHP0206QXJ00O06EUI@1OGel0I6AT06i^KP1SHf<0I6AT065QH@1PH600IFEU
069RHP1TI6@0IVIV069RHP1MGEd0IFEU05EEE@1TI6@0IFEU05]KF`1NGUh0G5aL06UYJ@1PH600Fe]K
065QH@1KFe/0Hf=S05iNGP1QHF40H61P04e=C@0G000000H0fMWI0@0000010=WIf@005P3IfMT00`00
0000fMWI0=WIf@030=WIf@050<W9b@1LG5`0HF5Q06=SH`1TI6@00P1WIfL03@1YJFT0HV9R06IVIP1P
H600I6AT06i^KP1VIVH0IFEU06UYJ@1VIVH0J6QX061PH01]KFd00P1TI6@05@1YJFT0J6QX065QH@1[
Jf/0H61P06a/K01UIFD0Hf=S06QXJ01QHF40HV9R065QH@1XJ6P0HF5Q06MWI`1SHf<0K6a/06=SH`1W
IfL0H61P06IVIP0206][J`0806QXJ01SHf<0JVYZ06i^KP1TI6@0IFEU06IVIP1XJ6P206][J`0906AT
I01]KFd0K6a/06i^KP1[Jf/0L71`06QXJ01/K6`0KVi^0080K6a/00l0JVYZ06e]K@1XJ6P0IVIV06e]
K@1aLG40MWIf071`L01eMGD0MgMg06i^KP1`L700N7Qh06UYJ@1_Kfl00P1cLg<206i^KP0A06m_K`1/
K6`0LW9b07=cL`1jNWX0LG5a07IfMP1eMGD0M7Ad071`L01gMgL0NGUi06m_K`1^KVh0MWIf07EeM@1j
NWX00P1lO7`0101cLg<0M7Ad07QhN01jNWX207UiN@0C07MgM`1jNWX0Ng]k07]kN`21PH40OWin07al
O01kNg/0MgMg07inOP20P800Ng]k07YjNP1iNGT0P8200861P@1iNGT0MGEe07MgM`020861P@0707al
O01oOgl0Q8B40820P024Q8@0NGUi0820P00208:2PP0C08>3P`24Q8@0O7al07moO`22PX80QhN708J6
QP22PX80Ph>308R8R024Q8@0Rh^;0820P02<S8`0Rh^;08J6QP25QHD0R8R80820P00208>3P`0708F5
Q@27QhL0QhN708>3P`1lO7`0Q8B408J6QP020861P@0I07emO@26QXH0OGem08:2PP20P800Ph>307]k
N`26QXH0P82007inOP20P800Q8B408:2PP23Ph<0O7al0820P01lO7`0PX:207UiN@1hN7P0OGem07in
OP20P800MWIf07emO@0307]kN`0Z079bLP1fMWH0MWIf07moO`1gMgL0LW9b07QhN01dM7@0LG5a079b
LP1fMWH0N7Qh07UiN@1hN7P0Lg=c06i^KP1dM7@0Kfm_07=cL`1iNGT0L71`06UYJ@1UIFD0Jf][06i^
KP1]KFd0LW9b07=cL`1VIVH0K6a/07=cL`1[Jf/0LG5a06IVIP1cLg<0KFe]06i^KP1/K6`0LG5a06QX
J01VIVH0IfMW0`1YJFT0501VIVH0IFEU06MWI`1YJFT0J6QX06IVIP1WIfL0Hf=S065QH@1PH600HV9R
05aLG01KFe/0H61P06ATI01WIfL0I6AT06e]K@1SHf<0HF5Q0P1PH600101NGUh0Hf=S05aLG01QHF42
06=SH`0705iNGP1SHf<0GUiN065QH@1NGUh0I6AT05QHF00205aLG00;061PH01NGUh0H61P05ADE01I
FET0GUiN05YJFP1OGel0G5aL05]KF`1HF5P05`0000060=WIf@4000000@3IfMT001H0fMWI00<00000
0=WIf@3IfMT00`3IfMT07`3@d=00HF5Q06QXJ01[Jf/0JFUY06QXJ01RHV80JFUY06a/K01TI6@0IFEU
06IVIP1SHf<0J6QX06IVIP1XJ6P0HV9R06YZJP1YJFT0J6QX061PH01YJFT0IfMW06YZJP1XJ6P0JFUY
061PH01YJFT0I6AT06=SH`1PH6000P1TI6@04P1PH600IfMW06=SH`1TI6@0H61P05eMG@1XJ6P0Hf=S
06QXJ01OGel0K6a/06MWI`1XJ6P0Jf][06ATI01SHf<0K6a/06YZJP80L71`00@0KFe]06IVIP1/K6`0
N7Qh0`1/K6`09@1[Jf/0IVIV075aL@1XJ6P0KFe]06YZJP1^KVh0K6a/071`L01dM7@0MWIf07]kN`1i
NGT0MgMg075aL@1eMGD0KFe]06IVIP1_Kfl0LW9b06e]K@1hN7P0M7Ad07=cL`1`L700LW9b071`L01e
MGD0M7Ad075aL@1fMWH0L71`07UiN@1eMGD0MWIf07YjNP1dM7@00P1hN7P01`1iNGT0P82007emO@21
PH40NGUi079bLP1jNWX00P1fMWH0A`1eMGD0MWIf07]kN`1jNWX0PH6107=cL`1kNg/0Ph>307inOP1l
O7`0NWYj08>3P`1lO7`0NWYj07inOP1oOgl0Ph>307inOP23Ph<0Q8B40861P@1kNg/0O7al08J6QP24
Q8@0QHF50861P@28R8P0P82007inOP21PH40Rh^;07inOP21PH40QXJ608B4Q02:RXX0P82008B4Q01m
OGd0RHV908>3P`28R8P0P82008R8R023Ph<0Q8B40820P021PH40R8R807inOP29RHT0OWin0820P026
QXH0Ph>308V9R@28R8P0QXJ608^;R`1jNWX0OWin08^;R`26QXH0R8R808J6QP1nOWh0Ph>307inOP1l
O7`0NWYj0080OWin00<0Q8B407moO`1kNg/00P23Ph<20861P@0507moO`1kNg/0O7al07YjNP20P800
0P1kNg/0501mOGd0NGUi07=cL`20P800M7Ad07=cL`1fMWH0N7Qh07IfMP1lO7`0LG5a07IfMP1iNGT0
MGEe071`L01aLG40KVi^079bLP1]KFd0Lg=c0P1aLG401@1]KFd0Lg=c075aL@1QHF40L71`0080J6QX
00T0LG5a06QXJ01_Kfl0LW9b06][J`1^KVh0LW9b07=cL`1aLG400P1[Jf/0;`1^KVh0K6a/06a/K01T
I6@0KFe]06UYJ@1XJ6P0KFe]06][J`1XJ6P0Hf=S069RHP1VIVH0Hf=S06MWI`1SHf<0IVIV06QXJ01U
IFD0IfMW06IVIP1NGUh0GEeM061PH01SHf<0J6QX05aLG01VIVH0HV9R05iNGP1VIVH0HF5Q06=SH`1X
J6P0IVIV05iNGP1IFET0HF5Q069RHP1TI6@0HF5Q069RHP1PH600J6QX05mOG`1QHF40De=C0080G5aL
00L0GemO065QH@1MGEd0H61P05iNGP1DE5@0EUIF01L000001P3IfMT100000040fMWI000F0=WIf@80
0000103IfMT04`3De=@0IfMW06ATI01UIFD0I6AT06UYJ@1LG5`0IVIV06QXJ01/K6`0HF5Q06=SH`1P
H600JFUY06IVIP1KFe/0J6QX06=SH`1YJFT00P1SHf<03P1VIVH0L71`06EUI@1XJ6P0HV9R06MWI`1/
K6`0GemO061PH01QHF40G5aL05iNGP1SHf<0IVIV0P1WIfL02@1OGel0IfMW06ATI01VIVH0J6QX06IV
IP1XJ6P0I6AT06QXJ00206][J`0H06a/K01YJFT0Jf][06i^KP1[Jf/0I6AT06MWI`1/K6`0KFe]071`
L01[Jf/0L71`06QXJ01bLW80Kfm_06a/K01dM7@0IVIV075aL@1YJFT0L71`06i^KP1hN7P0LW9b0P1`
L7001`1cLg<0Kfm_06e]K@1eMGD0LW9b075aL@1^KVh00P1aLG40:01iNGT0N7Qh071`L01hN7P0KVi^
07MgM`1fMWH0M7Ad07UiN@1hN7P0MgMg07alO01_Kfl0O7al07]kN`1iNGT0LG5a07moO`1jNWX0L71`
07UiN@1mOGd0M7Ad07=cL`1jNWX0N7Qh07YjNP23Ph<0Ogmo0820P01aLG40Ph>307inOP1dM7@0O7al
0820P021PH40Ogmo07IfMP1cLg<207]kN`0407moO`23Ph<0PX:207UiN@<0P8200`23Ph<01@24Q8@0
Ph>307moO`21PH40Q8B40080PH6100D0Ph>307]kN`28R8P0QXJ608F5Q@0208B4Q080QXJ600L0P820
08N7Q`1lO7`0Q8B408Z:RP28R8P0QhN70080QXJ600@0Rh^;08J6QP21PH40PX:20P24Q8@01023Ph<0
QXJ608J6QP26QXH208>3P`0P08J6QP20P800S8b<07inOP24Q8@0Ph>308:2PP1jNWX0OGem08:2PP23
Ph<0R8R808:2PP1nOWh0Ogmo07inOP20P800OWin07=cL`1nOWh0N7Qh07inOP1fMWH0M7Ad07UiN@1h
N7P0OWin07IfMP1lO7`0NWYj07alO01aLG4207UiN@0607IfMP1iNGT0MgMg07=cL`1kNg/0LG5a0P1`
L7004@1dM7@0Lg=c07=cL`1cLg<0MgMg07AdM01WIfL0Jf][06YZJP1[Jf/0J6QX07AdM01aLG40LW9b
075aL@1XJ6P0M7Ad0080LW9b00H0LG5a06MWI`1[Jf/0JFUY06a/K01XJ6P206][J`0B06UYJ@1XJ6P0
IfMW06a/K01XJ6P0Jf][06ATI01XJ6P0LW9b061PH01QHF40I6AT065QH@1VIVH0HF5Q06IVIP1OGel0
I6AT0P1VIVH0101PH600Hf=S06EUI@1TI6@2069RHP0<05mOG`1RHV80G5aL06ATI01LG5`0HF5Q06AT
I01PH600GUiN065QH@1OGel0Fe]K0P1QHF401`1NGUh0HF5Q05iNGP1TI6@0G5aL061PH01RHV800P1K
Fe/00`1EEED000000000000E000000D0fMWI0P0000010=WIf@005P3IfMT00`000000fMWI0=WIf@03
0=WIf@0h0=SHf01VIVH0IVIV05]KF`1XJ6P0Hf=S05mOG`1TI6@0H61P06UYJ@1/K6`0Hf=S05aLG01S
Hf<0IVIV06i^KP1PH600I6AT06a/K01QHF40GemO06IVIP1UIFD0IVIV06QXJ01PH600Jf][06YZJP1R
HV80JVYZ065QH@1PH600FEUI06ATI01LG5`0JFUY061PH01TI6@0HV9R06ATI01]KFd0IVIV065QH@1N
GUh0JFUY06YZJP1^KVh0JFUY06QXJ01YJFT0Jf][06QXJ01ZJVX0KFe]06UYJ@1cLg<206MWI`0L071`
L01/K6`0JVYZ06m_K`1/K6`0M7Ad06m_K`1dM7@0IVIV075aL@1YJFT0L71`06a/K01aLG40L71`07=c
L`1aLG40Lg=c07QhN01fMWH0J6QX06][J`1_Kfl0M7Ad075aL@1[Jf/0N7Qh07IfMP80MGEe0`1hN7P0
5P1cLg<0L71`075aL@1eMGD0L71`07UiN@1fMWH0N7Qh07inOP1hN7P0MWIf07EeM@1jNWX0Ng]k07Ui
N@1mOGd0MWIf0861P@28R8P0NWYj0861P@27QhL207]kN`0307alO021PH40NWYj0080OWin0P1mOGd0
6@20P800Ph>307]kN`1fMWH0OWin07emO@1nOWh0PH6107inOP1lO7`0OWin08>3P`1kNg/0QHF508V9
R@26QXH0Ogmo08:2PP2<S8`0PX:208B4Q026QXH0R8R808F5Q@23Ph<00P29RHT08026QXH0Ph>308:2
PP2>SXh0OWin08B4Q023Ph<0P82008V9R@20P800PH6107moO`24Q8@0R8R80820P01nOWh0PH6107]k
N`26QXH0QHF507alO021PH40R8R808>3P`22PX80Ogmo08>3P`1lO7`0Ph>30861P@25QHD0Ph>30P24
Q8@00`23Ph<0Q8B40820P00307moO`0A07inOP1kNg/0Ng]k07YjNP1nOWh0O7al07inOP22PX80Ng]k
0820P01iNGT0M7Ad07QhN01fMWH0Ng]k07IfMP1eMGD00P1hN7P04@1aLG40NWYj06i^KP1/K6`0L71`
06i^KP1]KFd0LW9b07QhN01cLg<0JFUY06i^KP1_Kfl0IfMW06QXJ01YJFT0Jf][0080M7Ad01X0KVi^
061PH01_Kfl0KVi^07=cL`1iNGT0L71`06m_K`1XJ6P0K6a/06][J`1XJ6P0L71`06IVIP1XJ6P0KFe]
06UYJ@1TI6@0HF5Q06EUI@1XJ6P0G5aL06ATI01PH600IVIV06QXJ080JVYZ0`1PH6008@1UIFD0H61P
06QXJ01PH600GemO06][J`1PH600GEeM06=SH`1VIVH0Fe]K05iNGP1PH600G5aL05]KF`1NGUh0H61P
06IVIP1NGUh0G5aL065QH@1PH600GEeM065QH@1NGUh0GEeM061PH01IFET0HV9R05mOG`1PH600EeMG
055AD@0G000000H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0a0=3@d01Q
HF40Jf][061PH01RHV80IVIV06MWI`1^KVh0IVIV06QXJ01YJFT0HV9R05aLG01QHF40IfMW06=SH`1X
J6P0Hf=S06YZJP1UIFD0IVIV06ATI01SHf<0Jf][06ATI01UIFD0HF5Q05iNGP1PH600GUiN065QH@1T
I6@0GEeM061PH01LG5`0IFEU06][J`1TI6@0HF5Q06=SH`1YJFT0HF5Q06EUI@1VIVH0J6QX05eMG@1Z
JVX0Hf=S06UYJ@0206IVIP0606EUI@1/K6`0IFEU06QXJ01RHV80JFUY0P1_Kfl02@1YJFT0KFe]06a/
K01cLg<0IFEU06m_K`1XJ6P0LG5a07IfMP0207=cL`80L71`01D0MgMg07EeM@1aLG40Lg=c06i^KP1i
NGT0NWYj07MgM`1aLG40KFe]075aL@1cLg<0KVi^07alO01kNg/0NGUi071`L01dM7@0N7Qh07EeM@1h
N7P00P1gMgL05P1bLW80NGUi07QhN020P800O7al0820P01lO7`0MgMg07alO01nOWh0NWYj07]kN`1g
MgL0P82008N7Q`1lO7`0N7Qh07alO020P800N7Qh07emO@1kNg/407inOP80PH6100l0O7al07moO`20
P800PX:208B4Q01lO7`0MWIf07]kN`2>SXh0PH6108R8R024Q8@0QXJ608F5Q@24Q8@00P23Ph<208B4
Q00U07inOP21PH40Ph>308J6QP24Q8@0PX:208R8R023Ph<0QXJ60861P@26QXH0SXj>08Z:RP2=SHd0
Rh^;08V9R@2;Rh/0Shn?08>3P`29RHT0Q8B408:2PP21PH40R8R808>3P`24Q8@0QXJ60861P@26QXH0
O7al08J6QP25QHD0QXJ60861P@24Q8@0R8R80861P@0208B4Q00l08>3P`1nOWh0PH610861P@1gMgL0
PX:20861P@1hN7P0PH6107moO`1nOWh0P82007UiN@1nOWh0Lg=c07inOP1iNGT0Ogmo07QhN01nOWh0
N7Qh07UiN@1fMWH0N7Qh07emO@1hN7P0Ng]k07AdM01kNg/0MgMg07AdM01hN7P0Lg=c079bLP1XJ6P0
Kfm_079bLP1]KFd0LG5a06a/K01SHf<0KFe]06EUI@1WIfL0I6AT06a/K01_Kfl0J6QX075aL@1dM7@0
JVYZ071`L01^KVh0LG5a06][J`1^KVh0Jf][06QXJ01`L700IfMW0P1ZJVX01@1XJ6P0L71`06IVIP1W
IfL0JFUY0080Jf][01/0IfMW069RHP1/K6`0GemO06YZJP1SHf<0JFUY06][J`1TI6@0H61P06ATI01L
G5`0HF5Q05]KF`1SHf<0JFUY069RHP1SHf<0FUYJ06EUI@1MGEd0H61P05QHF01OGel0I6AT06=SH`1N
GUh00P1LG5`01P1KFe/0HF5Q061PH01NGUh0HF5Q05YJFP@0GUiN00<0Fe]K04m?C`0000005P000006
0=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0A`3<c<`0HF5Q05YJFP1XJ6P0
K6a/06MWI`1SHf<0IVIV05mOG`1VIVH0H61P06MWI`1XJ6P0HF5Q06IVIP1WIfL0GemO05eMG@1VIVH0
HF5Q05iNGP1WIfL0HF5Q05]KF`1TI6@0J6QX05mOG`1SHf<0Fe]K05IFEP1LG5`0Hf=S05iNGP1RHV80
Hf=S06EUI@1XJ6P0Hf=S05eMG@1VIVH0Hf=S06UYJ@1QHF40Hf=S06IVIP1[Jf/0Kfm_06MWI`1[Jf/0
JFUY075aL@1XJ6P0KVi^06a/K01UIFD0IVIV06i^KP1UIFD0J6QX06a/K01`L700LG5a06UYJ@1`L700
J6QX06m_K`1/K6`0L71`06m_K`1bLW80MgMg0080LG5a0140KVi^07QhN01aLG40L71`06m_K`1dM7@0
MWIf07MgM`1hN7P0L71`07AdM01hN7P0Ng]k07UiN@1cLg<0LG5a06i^KP0207=cL`80MWIf00h0P820
079bLP1aLG40MWIf07emO@1fMWH0OGem0861P@1jNWX0PH6107inOP1lO7`0NWYj07emO@80Ng]k00h0
OGem07alO01mOGd0OWin0820P01jNWX0Ng]k07QhN01mOGd0O7al07inOP24Q8@0Ng]k0861P@80OWin
00H0P82007moO`1nOWh0PH6108V9R@1lO7`208B4Q00@08>3P`1oOgl0PX:208J6QP29RHT0Q8B408J6
QP22PX80P82008>3P`2;Rh/0Ph>308n?S`22PX80QXJ608B4Q080S8b<00<0QXJ608V9R@24Q8@00P28
R8P03@2:RXX0PH6108R8R02?Shl0QXJ608^;R`23Ph<0R8R808B4Q023Ph<0S8b<08V9R@1lO7`00P24
Q8@05`26QXH0Q8B408J6QP1mOGd0QHF507UiN@21PH40QHF508>3P`20P800RXZ:08>3P`1oOgl0PX:2
07UiN@1dM7@0Ng]k07moO`28R8P0MgMg07IfMP1nOWh0P8200080OWin00@0Lg=c07UiN@20P800MgMg
0P1hN7P01@1dM7@0MWIf08>3P`1lO7`0PX:20080OGem00D0P82006i^KP1^KVh0KFe]06i^KP0207Ad
M009071`L01XJ6P0Jf][06m_K`1TI6@0J6QX06i^KP1VIVH0J6QX0080K6a/0P1dM7@0801eMGD0MgMg
071`L01aLG40L71`06YZJP1XJ6P0K6a/06=SH`1ZJVX0I6AT065QH@1/K6`0KVi^06QXJ01PH600J6QX
06i^KP1[Jf/0J6QX06IVIP1XJ6P0IFEU065QH@1VIVH0H61P05mOG`1VIVH0H61P06=SH`1TI6@0IFEU
0P1QHF40601TI6@0Hf=S05aLG01OGel0IVIV06ATI01VIVH0Hf=S06QXJ01UIFD0IVIV05]KF`1OGel0
Fe]K05iNGP1VIVH0GUiN05]KF`1LG5`0EeMG05mOG`1MGEd0GUiN05YJFP80Fe]K00<0F5QH00000000
00005@0000060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0303AdM40IVIV
06ATI01PH600Hf=S05mOG`1SHf<0JFUY06IVIP1TI6@0JVYZ06QXJ0<0IVIV0P1SHf<02P1PH600IFEU
06EUI@1WIfL0IVIV06QXJ01UIFD0H61P05aLG01HF5P205iNGP0805aLG01MGEd0HF5Q05eMG@1RHV80
Fe]K06IVIP1PH602065QH@03061PH01SHf<0GemO0080I6AT01@0HF5Q06][J`1]KFd0KVi^07AdM01S
Hf<0Jf][06ATI0000000D51@06ATI01WIfL0K6a/071`L01cLg<0Jf][06EUI@1ZJVX0I6AT06a/K080
KVi^01L0M7Ad07=cL`1/K6`0M7Ad06e]K@1bLW80MWIf079bLP1`L700J6QX07IfMP1^KVh0LG5a07Ui
N@1eMGD0Kfm_07=cL`1aLG40MGEe07MgM`1]KFd0P82007IfMP0207UiN@0=06m_K`1iNGT0NGUi07]k
N`1eMGD0Ph>307YjNP1mOGd0O7al07YjNP1mOGd0Ng]k08J6QP020820P00<08J6QP28R8P0N7Qh08>3
P`1kNg/0OWin07alO026QXH0PH6107UiN@20P800R8R80P21PH404@1kNg/0QXJ607]kN`23Ph<0RHV9
08:2PP21PH40Ogmo08:2PP23Ph<0RXZ:07inOP23Ph<0QHF508^;R`28R8P0Ogmo0080Ph>302H0R8R8
08B4Q026QXH0RXZ:08R8R020P800RHV908^;R`28R8P0Ph>308B4Q021PH40QXJ608j>SP26QXH0S8b<
08>3P`26QXH0QhN708b<S02@T900Q8B408Z:RP27QhL0PH6108>3P`2<S8`0Q8B408^;R`25QHD0SXj>
08^;R`27QhL0SXj>08:2PP2<S8`0RXZ:08V9R@80Q8B40P26QXH08@28R8P0PH6108j>SP21PH40QHF5
0820P01oOgl0NGUi0820P021PH40QXJ607inOP20P800OWin07emO@1lO7`0NWYj08>3P`1jNWX0Ph>3
07UiN@20P800N7Qh07alO023Ph<0QhN708b<S02ATI40SXj>07inOP1kNg/0MWIf06IVIP0206a/K007
06][J`1aLG40Jf][075aL@1gMgL0Jf][06a/K00206YZJP0@07=cL`1^KVh0LG5a06QXJ01`L700MWIf
071`L01]KFd0L71`06a/K01aLG40K6a/06i^KP1TI6@0KVi^06e]K@80Kfm_00h0IVIV07=cL`1TI6@0
IFEU06MWI`1RHV80HF5Q06=SH`1VIVH0GEeM06UYJ@1XJ6P0G5aL06ATI080HF5Q0P1TI6@04@1PH600
GEeM06ATI01[Jf/0H61P06=SH`1VIVH0Hf=S061PH01QHF40H61P06IVIP1KFe/0GUiN06ATI01VIVH0
Hf=S0080H61P00/0HF5Q059BDP1PH600HF5Q05eMG@1KFe/0H61P05mOG`1XJ6P0F5QH05ADE00G0000
00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@040=?Cd`1QHF40IVIV065Q
H@80IVIV00`0Hf=S05iNGP1TI6@0IVIV06YZJP1SHf<0IfMW06UYJ@1WIfL0HV9R05iNGP1OGel2065Q
H@0B061PH01YJFT0IVIV06][J`1SHf<0GUiN065QH@1RHV80GemO061PH01SHf<0H61P06QXJ01NGUh0
Hf=S05]KF`1SHf<0JVYZ0P1QHF402@1VIVH0GUiN06=SH`1VIVH0HV9R06UYJ@1/K6`0KVi^06UYJ@02
06ATI00B06i^KP0j>SX0KFe]071`L01YJFT0LG5a06i^KP1/K6`0Lg=c06UYJ@1/K6`0JVYZ06][J`1`
L700K6a/07=cL`1^KVh0JFUY0P1dM7@04@1aLG40KVi^06m_K`1iNGT0K6a/079bLP1iNGT0MWIf07Ee
M@1fMWH0LG5a07=cL`1gMgL0O7al07UiN@1^KVh0MWIf0080N7Qh00D0OGem07IfMP1fMWH0M7Ad07al
O00207UiN@0c07=cL`1iNGT0O7al07UiN@1nOWh0QXJ608B4Q020P800QhN707inOP20P800OWin07Mg
M`1iNGT0P82007QhN026QXH0P82007moO`1nOWh0PH6107moO`1iNGT0P82008B4Q01mOGd0QHF508>3
P`1nOWh0PH6108:2PP24Q8@0Ph>30861P@22PX80R8R808B4Q025QHD0OWin08J6QP20P800PX:208B4
Q02>SXh0RXZ:08>3P`29RHT0Ph>3096AT@2>SXh0QhN70080SXj>00H0Q8B408j>SP2:RXX0Q8B408N7
Q`2:RXX208R8R00:08V9R@2;Rh/0SHf=08>3P`24Q8@0Ph>308b<S02;Rh/0R8R808>3P`80RHV900X0
S8b<08B4Q024Q8@0P82008F5Q@27QhL0QHF508:2PP29RHT0Q8B40P1nOWh01020P800Ng]k07emO@1k
Ng/208>3P`0L08:2PP21PH40PX:208>3P`21PH40P82007inOP1hN7P0OWin08J6QP20P800NGUi07Qh
N01kNg/0NWYj07QhN01nOWh0PX:209JFUP2ATI40W9bL09NGU`21PH40OWin06a/K01dM7@0LG5a06UY
J@80KVi^01T0Lg=c07QhN01_Kfl0I6AT06YZJP1YJFT0J6QX07=cL`1ZJVX0Jf][075aL@1`L700JVYZ
075aL@1^KVh0M7Ad06m_K`1[Jf/0L71`06a/K01RHV80IVIV06UYJ@1XJ6P0IfMW0080J6QX01h0Jf][
06IVIP1SHf<0I6AT069RHP1XJ6P0JFUY06=SH`1LG5`0IFEU06][J`1QHF40H61P06YZJP1YJFT0HF5Q
061PH01TI6@0GemO06IVIP1NGUh0Hf=S05iNGP1SHf<0HV9R06=SH`1LG5`0IVIV069RHP1XJ6P2065Q
H@0605aLG01PH600GUiN05iNGP1UIFD0GemO0P1LG5`01P1OGel0Fe]K06ATI01GEeL0G5aL05]KFaL0
00001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI03H0eMGE065QH@1QHF40
GEeM06QXJ01ZJVX0J6QX06=SH`1VIVH0IfMW061PH01RHV80I6AT05mOG`1XJ6P0IFEU06UYJ@1QHF40
IVIV06=SH`1XJ6P0IFEU05mOG`1UIFD0Kfm_06=SH`1[Jf/0IVIV069RHP1SHf<0JFUY069RHP1SHf<0
HV9R061PH01NGUh0HV9R05eMG@1SHf<0GemO06=SH`1UIFD0HV9R06YZJP1bLW80IfMW06m_K`1[Jf/0
L71`06i^KP1/K6`0KFe]06MWI`1[Jf/2075aL@0?06UYJ@1[Jf/0IVIV06m_K`1dM7@0Kfm_075aL@1_
Kfl0Jf][06i^KP1hN7P0KVi^06UYJ@1ZJVX0LG5a0080K6a/00P0LG5a06e]K@1`L700M7Ad07alO01`
L700MgMg07QhN080LW9b00@0Lg=c07emO@1hN7P0LW9b0P1fMWH04`1eMGD0MWIf07EeM@1lO7`0NGUi
079bLP1lO7`0MWIf07YjNP1hN7P0O7al0820P01nOWh0QhN70820P01lO7`0Ng]k07QhN01gMgL0101k
Ng/0501nOWh0P8200820P023Ph<0PH6107]kN`1nOWh0NGUi07inOP25QHD0OGem07alO01jNWX0O7al
07]kN`21PH40Q8B407]kN`29RHT0P8200P27QhL0202<S8`0Q8B408B4Q01nOWh0SHf=08:2PP2;Rh/0
R8R80P29RHT02P23Ph<0T92@08B4Q02;Rh/0RXZ:0861P@2;Rh/0Shn?08F5Q@2;Rh/208j>SP0508N7
Q`2;Rh/0Rh^;08N7Q`2=SHd00P28R8P0A02DU9@0S8b<08V9R@2@T900QXJ609FEU@26QXH0Q8B40861
P@28R8P0QhN708B4Q02:RXX0R8R808N7Q`26QXH0OWin08B4Q01oOgl0Rh^;0820P01oOgl0PX:207al
O01iNGT0P82008>3P`1kNg/0PH6108J6QP1hN7P0QXJ60861P@1jNWX0N7Qh07]kN`23Ph<0NWYj08:2
PP1fMWH0O7al0820P028R8P0VIVI0:FUY@2QXJ40SXj>07emO@1jNWX0M7Ad06i^KP1eMGD0LG5a06m_
K`1dM7@0LG5a06m_K`1hN7P0LG5a079bLP1/K6`0Jf][06QXJ01/K6`0JFUY06i^KP1cLg<0KVi^0P1a
LG403@1]KFd0Lg=c06m_K`1]KFd0L71`06][J`1/K6`0IfMW06UYJ@1XJ6P0IFEU06MWI`1PH6000P1V
IVH0201WIfL0I6AT06][J`1YJFT0Hf=S05mOG`1XJ6P0K6a/0P1QHF40101XJ6P0I6AT05iNGP1RHV82
06=SH`0<06e]K@1QHF40Fe]K05]KF`1RHV80G5aL05mOG`1PH600HF5Q05QHF01PH600GemO0P1QHF40
1`1TI6@0HF5Q05iNGP1JFUX0HF5Q05eMG@1QHF400P1RHV80101SHf<0I6AT05mOG`1DE5@G000000H0
fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0@0=_Kf`1NGUh0GUiN069RHP1V
IVH0HF5Q06UYJ@1VIVH0J6QX06=SH`1OGel0IVIV06QXJ01UIFD0J6QX06UYJ@80HF5Q01P0J6QX06=S
H`1SHf<0HV9R065QH@1WIfL0L71`06YZJP1[Jf/0M7Ad06a/K01SHf<0IfMW06UYJ@1UIFD0G5aL06EU
I@1SHf<0HF5Q05iNGP1QHF40GemO06=SH`1XJ6P2065QH@0:06UYJ@1ZJVX0JVYZ06e]K@1`L700Lg=c
06YZJP1TI6@0Kfm_06ATI080Kfm_02d0Jf][075aL@1_Kfl0L71`06a/K01ZJVX0IVIV075aL@1bLW80
LG5a071`L01]KFd0LG5a06a/K01_Kfl0Lg=c06QXJ01bLW80MGEe075aL@1/K6`0KFe]07MgM`1aLG40
O7al07QhN01dM7@0LG5a07=cL`1eMGD0MgMg07alO01`L700LG5a07]kN`1gMgL0L71`07alO01mOGd0
O7al08:2PP20P800NGUi07AdM01lO7`00P1kNg/05`1nOWh0P82007inOP23Ph<0OWin07alO01oOgl0
OWin07YjNP22PX80Ph>30861P@20P800Q8B408J6QP27QhL0OWin08R8R020P800QXJ608>3P`21PH40
OWin0080Ph>300H0Q8B408F5Q@24Q8@0PH6107moO`26QXH208^;R`0308B4Q027QhL0Rh^;0080RHV9
0340QhN708V9R@28R8P0Q8B408R8R024Q8@0PH6108N7Q`28R8P0Q8B407inOP2BTY80R8R808V9R@2<
S8`0SXj>08B4Q02>SXh0RHV908b<S029RHT0Shn?08j>SP28R8P0Rh^;08n?S`2=SHd0QhN709:BTP27
QhL0QXJ608B4Q026QXH0QhN708F5Q@23Ph<0R8R80861P@29RHT0S8b<0820P023Ph<0OWin08>3P`26
QXH0Ng]k08B4Q023Ph<0Q8B40080MgMg00D0OWin07alO01dM7@0Ph>308:2PP0208>3P`0308F5Q@28
R8P0Ng]k0080PH6100/0OWin08R8R02HV9P0Vi^K08Z:RP25QHD0NGUi07]kN`1aLG40Kfm_06][J`02
071`L008075aL@1bLW80JVYZ079bLP1aLG40KVi^07UiN@1YJFT206][J`0:06a/K01YJFT0Kfm_07Ad
M01cLg<0KVi^06UYJ@1dM7@0Jf][071`L080IfMW01`0K6a/06UYJ@1[Jf/0Kfm_069RHP1YJFT0IVIV
06][J`1SHf<0IfMW06QXJ01[Jf/0Hf=S061PH01/K6`0I6AT06MWI`1RHV80Hf=S05eMG@1QHF40J6QX
065QH@1SHf<0IVIV06ATI01VIVH0I6AT0P1LG5`01P1[Jf/0HF5Q05mOG`1RHV80HF5Q06UYJ@<0Hf=S
00d0GemO06IVIP1TI6@0H61P05eMG@1RHV80Fe]K06=SH`1KFe/0G5aL06EUI@1OGel0EeMG01L00000
1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00H0e]KF065QH@1^KVh0I6AT
06EUI@1RHV8206ATI00406UYJ@1QHF40I6AT06IVIP80J6QX01@0JFUY071`L01ZJVX0I6AT06IVIP1X
J6P0IVIV061PH01UIFD0K6a/06QXJ01ZJVX0MWIf07EeM@1`L700JVYZ06IVIP1TI6@0IFEU06ATI080
GUiN00L0Fe]K05UIF@1KFe/0I6AT06QXJ01[Jf/0J6QX0080IVIV00L0Hf=S06][J`1XJ6P0IFEU075a
L@1^KVh0J6QX0080KVi^01/0IVIV071`L01bLW80J6QX06UYJ@1/K6`0JVYZ06][J`1dM7@0JFUY06][
J`1_Kfl0LW9b06e]K@1`L700K6a/06MWI`1`L700K6a/07=cL`1gMgL0M7Ad07IfMP1eMGD0Kfm_079b
LP1hN7P00P1eMGD02P1hN7P0MWIf0861P@1fMWH0MGEe07QhN01cLg<0Ng]k075aL@1nOWh207]kN`0<
07IfMP1mOGd0Lg=c07QhN01oOgl0Ng]k07UiN@22PX80QXJ608F5Q@1nOWh0MWIf0P1nOWh02@1mOGd0
P82008N7Q`24Q8@0QXJ608V9R@21PH40Ogmo0861P@0208>3P`0;08J6QP27QhL0OWin07inOP23Ph<0
P82007UiN@29RHT0QHF508R8R029RHT00P28R8P08@27QhL0R8R808R8R024Q8@0R8R808^;R`2>SXh0
Ph>308j>SP24Q8@0S8b<08R8R027QhL0RHV908J6QP23Ph<0S8b<092@T02?Shl0SXj>08B4Q029RHT0
S8b<09FEU@24Q8@0UIFE09RHV02<S8`0Q8B408b<S02=SHd0TI6A08j>SP0208Z:RP0808V9R@26QXH0
S8b<08Z:RP2;Rh/0RXZ:0861P@29RHT208B4Q080R8R800h0QHF508>3P`23Ph<0RHV908B4Q02<S8`0
OGem07alO023Ph<0Ng]k07YjNP24Q8@0O7al08:2PP80Ogmo00<0Ph>307]kN`1mOGd00P1kNg/05P24
Q8@0OWin07alO022PX80Q8B40861P@2?Shl0R8R807QhN01nOWh0NGUi07]kN`1cLg<0KFe]07=cL`1^
KVh0Lg=c07AdM01aLG40M7Ad07MgM`1fMWH206e]K@0=06][J`1^KVh0L71`06a/K01gMgL0Lg=c06e]
K@1/K6`0Kfm_079bLP1[Jf/0LW9b07=cL`02071`L00J06YZJP1WIfL0K6a/05mOG`1WIfL0JVYZ06m_
K`1^KVh0JVYZ06QXJ01WIfL0J6QX06ATI01SHf<0IVIV065QH@1VIVH0JFUY06QXJ01YJFT0HF5Q06IV
IP1SHf<0H61P06=SH`1LG5`205iNGP0G05UIF@1VIVH0I6AT05mOG`1NGUh0H61P05eMG@1QHF40IVIV
065QH@1TI6@0H61P06ATI01RHV80I6AT06=SH`1VIVH0GemO06ATI01VIVH0I6AT05IFEP1DE5@05`00
00060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT02P3@d=00I6AT06IVIP1V
IVH0HF5Q06IVIP1QHF40I6AT069RHP1PH60206=SH`0306YZJP1XJ6P0IFEU0080Hf=S00<0JFUY065Q
H@1TI6@00P1XJ6P03`1MGEd0I6AT06MWI`1YJFT0OGem07=cL`1^KVh0Hf=S061PH01NGUh0HF5Q06=S
H`1TI6@0GEeM065QH@0205iNGP0306IVIP1TI6@0JFUY0080J6QX00/0IfMW071`L01_Kfl0KVi^06UY
J@1[Jf/0JVYZ06m_K`1/K6`0Jf][06UYJ@0206i^KP0;06][J`1ZJVX0JVYZ07=cL`1TI6@0MGEe06=S
H`1/K6`0Jf][06i^KP1dM7@00P1]KFd0101cLg<0M7Ad07IfMP1eMGD207IfMP07079bLP1aLG40MgMg
07UiN@1bLW80MWIf07alO00207UiN@0?07]kN`1gMgL0OGem07inOP1kNg/0O7al07EeM@23Ph<0O7al
07]kN`1lO7`0Ng]k07=cL`1kNg/0MWIf0080Ng]k00D0Ogmo07alO01iNGT0Ng]k08>3P`0207inOP0Q
08:2PP1fMWH0OWin07moO`23Ph<0PH6107UiN@28R8P0Ng]k08>3P`21PH40P82007]kN`1mOGd0NGUi
07inOP22PX80Ph>308F5Q@1mOGd0Q8B408J6QP2<S8`0QXJ608R8R02>SXh0Rh^;09:BTP2:RXX0Rh^;
08V9R@2>SXh0Ph>30080Rh^;00D0QXJ608N7Q`2@T900Ph>308R8R00208b<S00/08Z:RP2>SXh0TI6A
08b<S02;Rh/0SXj>08Z:RP28R8P0QXJ608R8R02<S8`0TI6A08^;R`28R8P0S8b<08J6QP24Q8@0RHV9
08B4Q02;Rh/0S8b<08^;R`28R8P0SHf=08^;R`2:RXX0QXJ60861P@2=SHd0QHF508R8R024Q8@0Ph>3
08B4Q01iNGT0PH6108J6QP23Ph<0QXJ607inOP23Ph<0Q8B407inOP21PH420820P00H0861P@24Q8@0
Q8B407alO022PX80O7al07]kN`1lO7`0OWin0820P02;Rh/0O7al07YjNP1dM7@0NGUi0820P01hN7P0
LG5a06i^KP1[Jf/0Kfm_07IfMP1/K6`0M7Ad0P1^KVh00`1cLg<0KVi^06a/K00206m_K`0906][J`1b
LW80LG5a075aL@1]KFd0K6a/07=cL`1bLW80KVi^0080KFe]0100Kfm_06e]K@1`L700IVIV06EUI@1X
J6P0K6a/06][J`1XJ6P0Jf][06IVIP1[Jf/0J6QX06MWI`1SHf<0K6a/0P1YJFT01@1TI6@0JFUY065Q
H@1LG5`0HF5Q0080G5aL0P1TI6@01@1XJ6P0I6AT05iNGP1QHF40Hf=S0080H61P0100HF5Q061PH01T
I6@0J6QX06=SH`1VIVH0Fe]K061PH01KFe/0GEeM05aLG01MGEd0Hf=S06EUI@1OGel0H61P0P1HF5PG
000000H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0B0=3@d01JFUX0HF5Q
06ATI01QHF40IVIV05mOG`1^KVh0Jf][065QH@1TI6@0JFUY069RHP1XJ6P0IVIV06UYJ@1`L700I6AT
0P1PH6001@1SHf<0H61P065QH@1SHf<0K6a/0080JFUY00P0Jf][06MWI`1TI6@0IVIV06=SH`1KFe/0
IVIV061PH080G5aL01X0I6AT06EUI@1QHF40GUiN06][J`1XJ6P0HV9R06YZJP1/K6`0I6AT06a/K01Z
JVX0J6QX06m_K`1ZJVX0KFe]06i^KP1XJ6P0L71`06MWI`1^KVh0KFe]06m_K`1^KVh0LG5a06UYJ@80
K6a/0140KVi^06e]K@1`L700MGEe07AdM01`L700N7Qh07AdM01jNWX0LW9b07IfMP1dM7@0LG5a07Yj
NP1hN7P0M7Ad06a/K00207=cL`80LW9b0P1gMgL02`1kNg/0NGUi08:2PP22PX80PH6107AdM01hN7P0
O7al07EeM@1hN7P0L71`0080MWIf00X0MgMg07alO01iNGT0Ng]k0820P01nOWh0PH6107IfMP1nOWh0
OGem0P1nOWh03`23Ph<0Ogmo08>3P`2;Rh/0Ng]k08B4Q023Ph<0Rh^;07moO`21PH40QhN708b<S023
Ph<0RHV908f=S@0208B4Q00B08V9R@2<S8`0Ti>C08b<S02:RXX0R8R808V9R@26QXH0TI6A08j>SP26
QXH0Rh^;08R8R026QXH0Rh^;08R8R029RHT0PH610P27QhL01P2FUYH0S8b<092@T029RHT0S8b<09>C
T`80SXj>01D0RHV908b<S02>SXh0SHf=08Z:RP2BTY80Shn?09FEU@28R8P0QXJ608B4Q029RHT0S8b<
092@T024Q8@0SXj>08n?S`2@T900Ph>307alO02=SHd00P2;Rh/0202:RXX0QHF507UiN@27QhL0Ogmo
09FEU@2?Shl0Q8B40P29RHT03P1oOgl0Q8B407]kN`21PH40Ph>307inOP1mOGd0Ng]k07alO023Ph<0
Ng]k07alO01jNWX0OWin0P1jNWX03P1iNGT0O7al06][J`1oOgl0MgMg07inOP1`L700Kfm_07=cL`1/
K6`0KVi^06m_K`1aLG40Lg=c0P1_Kfl07`1^KVh0L71`06i^KP1^KVh0K6a/07IfMP1/K6`0M7Ad06a/
K01^KVh0M7Ad07=cL`1]KFd0MGEe06a/K01`L700JVYZ07=cL`1YJFT0Jf][06QXJ01/K6`0JVYZ071`
L01[Jf/0HV9R06YZJP1]KFd0K6a/065QH@1XJ6P00P1/K6`08`1UIFD0Hf=S065QH@1KFe/0GUiN05mO
G`1TI6@0H61P06QXJ01PH600GEeM061PH01XJ6P0HF5Q06ATI01VIVH0HV9R065QH@1SHf<0Fe]K06AT
I01VIVH0G5aL061PH01OGel0IFEU06=SH`1VIVH0GemO06=SH`1LG5`0GUiN05eMG@1LG5`0IFEU01L0
00001P3IfMT100000040fMWI000F0=WIf@800000103IfMT04@39bLT0I6AT06ATI01PH600JFUY05aL
G01UIFD0HF5Q06UYJ@1UIFD0Hf=S06ATI01_Kfl0IVIV061PH01YJFT0HF5Q0080IFEU01X0HV9R065Q
H@1LG5`0HF5Q06UYJ@1TI6@0HF5Q079bLP1PH600IfMW06EUI@1OGel0G5aL05eMG@1KFe/0IFEU05UI
F@1UIFD0Hf=S06e]K@1ZJVX0Jf][06QXJ01TI6@0IfMW071`L080JFUY00l0KVi^06e]K@1SHf<0JVYZ
06][J`1^KVh0Jf][06YZJP1[Jf/0Kfm_08V9R@1aLG40KVi^06a/K01hN7P00P1^KVh09P1gMgL0N7Qh
06ATI01_Kfl0L71`07]kN`1`L700MgMg07QhN01bLW80MWIf07emO@1hN7P0LG5a06i^KP1hN7P0M7Ad
079bLP1`L700Lg=c079bLP1fMWH0N7Qh07MgM`1kNg/0P82007alO020P800MgMg07UiN@1gMgL0MGEe
07=cL`1^KVh0M7Ad079bLP1aLG40LW9b0P1lO7`0401kNg/0Ogmo07inOP23Ph<0QXJ608B4Q023Ph<0
RHV907inOP1lO7`0Ph>308:2PP24Q8@0QXJ608N7Q`20P80408V9R@80QXJ601<0Q8B408J6QP2<S8`0
S8b<08Z:RP2;Rh/0QXJ608V9R@27QhL0Rh^;08f=S@26QXH0TI6A08b<S02;Rh/0QhN708j>SP2FUYH0
Rh^;0080RHV900`0SXj>08J6QP2BTY80V9RH08V9R@2ATI40Shn?08f=S@2CTi<0Rh^;09RHV02CTi<2
08j>SP0608R8R02IVIT0TI6A09:BTP2=SHd0S8b<0P2>SXh00`2ATI40RHV909>CT`0208V9R@0308Z:
RP2?Shl0TI6A0080QXJ600H0Ph>308V9R@28R8P0S8b<08F5Q@29RHT308J6QP0<0820P025QHD0S8b<
07inOP21PH40P82007moO`26QXH0QHF50820P021PH40P8200P1mOGd03`1kNg/0NGUi0861P@1nOWh0
Q8B407UiN@1oOgl0N7Qh08>3P`1eMGD0M7Ad07MgM`1eMGD0M7Ad06i^KP02075aL@0O06][J`1^KVh0
LG5a075aL@1`L700Lg=c06][J`1iNGT0J6QX06e]K@1_Kfl0KVi^07=cL`1_Kfl0LW9b06YZJP1/K6`0
KVi^065QH@1XJ6P0L71`07=cL`1`L700K6a/071`L01ZJVX0HV9R065QH@1YJFT0IVIV06][J`0206UY
J@0M06YZJP1[Jf/0IVIV06m_K`1LG5`0H61P06MWI`1KFe/0JFUY069RHP1OGel0J6QX06IVIP1QHF40
JFUY065QH@1NGUh0J6QX06=SH`1IFET0HF5Q05iNGP1SHf<0I6AT06MWI`1SHf<0HF5Q061PH01RHV80
0P1SHf<0201QHF40I6AT06ATI01NGUh0HF5Q05iNGP1IFET0EUIF5`0000050=WIf@8000000@3IfMT0
01H0fMWI00<000000=WIf@3IfMT00`3IfMT0703De=@0H61P06IVIP1KFe/0KFe]06IVIP1SHf<0IVIV
06=SH`1PH600JVYZ06IVIP1QHF40H61P06IVIP1TI6@0JFUY06QXJ01QHF40J6QX06YZJP1SHf<0IVIV
06QXJ01/K6`0HF5Q06ATI01QHF4205iNGP05065QH@1SHf<0GEeM065QH@1OGel00P1TI6@01P1XJ6P0
JFUY06UYJ@1TI6@0IfMW06=SH`80JFUY0P1/K6`0201`L700Lg=c06YZJP1/K6`0L71`06][J`1]KFd0
L71`0P1aLG40:@1UIFD0KVi^06UYJ@1`L700LG5a07]kN`1aLG40JFUY07=cL`1aLG40KVi^06][J`1`
L700Ng]k07EeM@1dM7@0N7Qh071`L01hN7P0K6a/07emO@1eMGD0LG5a07UiN@1`L700NGUi075aL@21
PH40M7Ad08>3P`1eMGD0MgMg07EeM@1aLG40Lg=c07AdM01_Kfl0IVIV06][J`1WIfL0HV9R0080Jf][
0140M7Ad07EeM@1_Kfl0M7Ad07IfMP1hN7P0Q8B408R8R01nOWh0OGem07]kN`1oOgl0P82007emO@20
P800PH6108V9R@0208>3P`0608V9R@2;Rh/0Ph>308Z:RP24Q8@0SXj>0P20P800902ATI40S8b<08F5
Q@29RHT0SHf=08V9R@28R8P0Shn?08b<S028R8P0QhN708b<S027QhL0QXJ609:BTP2;Rh/0TI6A09BD
U02FUYH0Shn?09>CT`2@T900UYJF08V9R@2@T900TI6A08j>SP28R8P0TY:B09>CT`2ATI40S8b<08j>
SP2JVYX0Ti>C08f=S@<0T92@0180SXj>08^;R`29RHT0Ph>3092@T029RHT0Ti>C08Z:RP2;Rh/0S8b<
08>3P`29RHT0Q8B408^;R`29RHT0Q8B408^;R`22PX8208V9R@0<08J6QP28R8P0OWin08R8R01oOgl0
QHF50861P@28R8P0Ph>308J6QP21PH40P8200P29RHT01P20P800OGem07QhN021PH40NWYj07]kN`80
PH610P1lO7`01P1jNWX0OWin07UiN@1dM7@0Ng]k07AdM080LW9b02T0Kfm_06e]K@1_Kfl0M7Ad079b
LP1dM7@0KVi^071`L01_Kfl0MgMg071`L01bLW80JVYZ06i^KP1cLg<0KVi^075aL@1^KVh0JVYZ06IV
IP1cLg<0IFEU06m_K`1/K6`0JFUY06QXJ01]KFd0Jf][06EUI@1TI6@0IFEU06MWI`1[Jf/0I6AT06QX
J01`L700Jf][06a/K01UIFD0KVi^06UYJ@0206IVIP0906EUI@1PH600J6QX061PH01ZJVX0I6AT065Q
H@1SHf<0JFUY0080GEeM01<0Hf=S06MWI`1TI6@0H61P06IVIP1OGel0HV9R06MWI`1PH600IfMW05eM
G@1YJFT0HF5Q06=SH`1VIVH0GUiN05eMG@1TI6@0GUiN01L000001P3IfMT100000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI00<0dM7A06QXJ01VIVH00`1QHF4206QXJ00J06e]K@1PH600HF5Q
05eMG@1TI6@0JVYZ06QXJ01[Jf/0HF5Q061PH01KFe/0JVYZ06EUI@1SHf<0IVIV06MWI`1UIFD0IfMW
05iNGP1RHV80IVIV061PH01SHf<0HV9R06=SH`1WIfL3065QH@0306QXJ01^KVh0Hf=S0080KVi^00l0
M7Ad06a/K01YJFT0JFUY06i^KP1dM7@0JFUY075aL@1/K6`0Jf][06i^KP1`L700IfMW06a/K01[Jf/0
0P1]KFd02P1_Kfl0KVi^06i^KP1XJ6P0N7Qh06][J`1]KFd0L71`07EeM@1^KVh207AdM00/07UiN@1`
L700M7Ad07IfMP1hN7P0M7Ad07EeM@1lO7`0Ng]k071`L01aLG40K6a/07]kN`1aLG40M7Ad07UiN@20
P800O7al07inOP1`L700LW9b06m_K`1TI6@0IVIV065QH@1PH600IVIV06MWI`1fMWH0LG5a07=cL`21
PH40K6a/07]kN`1oOgl0P82008J6QP20P800PX:207]kN`1lO7`0Ogmo07alO01jNWX207inOP0F07al
O01mOGd0Q8B408:2PP29RHT0QhN708J6QP27QhL0S8b<08J6QP2;Rh/0RHV908b<S029RHT0QhN70861
P@29RHT0SHf=092@T029RHT0Ti>C08^;R`80RHV901`0Ph>308^;R`2>SXh0R8R808^;R`2ATI40R8R8
08f=S@2?Shl0S8b<09:BTP2HV9P0VIVI08j>SP2LW9`0U9BD09NGU`2;Rh/0R8R8092@T02<S8`0TI6A
09NGU`2;Rh/0TI6A08j>SP2ATI40Ti>C0P2BTY808P2?Shl0Rh^;08^;R`2<S8`0T92@08b<S02;Rh/0
T92@08R8R02>SXh0PX:208N7Q`28R8P0S8b<08R8R01nOWh0Q8B408^;R`2<S8`0NWYj08B4Q021PH40
QhN708B4Q020P800OWin08:2PP21PH40N7Qh08:2PP23Ph<0OGem0861P@24Q8@207alO00P07IfMP1l
O7`0OGem07QhN01nOWh0N7Qh07UiN@1gMgL0Lg=c07inOP1_Kfl0LW9b07]kN`1gMgL0N7Qh071`L01c
Lg<0LG5a06i^KP1aLG40MgMg075aL@1bLW80KFe]06a/K01^KVh0K6a/06YZJP1cLg<0JFUY071`L01W
IfL206][J`0306a/K01YJFT0L71`0080IFEU00X0J6QX06UYJ@1UIFD0Jf][06i^KP1/K6`0J6QX075a
L@1[Jf/0I6AT0`1QHF40201TI6@0IFEU06MWI`1QHF40GemO065QH@1OGel0I6AT0P1NGUh05P1PH600
KFe]065QH@1LG5`0GemO069RHP1UIFD0GUiN06EUI@1NGUh0Hf=S06QXJ01WIfL0HF5Q06EUI@1TI6@0
G5aL065QH@1OGel0F5QH06IVIP1PH60G000000H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI
0=WIf@030=WIf@0?0=7Ad@1PH600IFEU069RHP1KFe/0GUiN06YZJP1QHF40Hf=S061PH01SHf<0JVYZ
05]KF`1TI6@0IFEU0080HF5Q00h0GUiN06ATI01PH600IVIV06MWI`1XJ6P0JFUY069RHP1XJ6P0H61P
069RHP1QHF40Hf=S05mOG`80HF5Q0P1XJ6P00`1UIFD0Jf][061PH00206=SH`0307=cL`1^KVh0KVi^
0080L71`00`0Lg=c071`L01`L700Kfm_06YZJP1/K6`0Kfm_079bLP1]KFd0K6a/06e]K@1aLG4206a/
K00606][J`1_Kfl0KVi^079bLP1dM7@0NGUi0P1hN7P0201dM7@0Lg=c07QhN01[Jf/0MWIf071`L01a
LG40MgMg0P1aLG4307IfMP0707EeM@1dM7@0MgMg07IfMP1dM7@0MWIf07AdM00307]kN`03075aL@1[
Jf/0K6a/0080EUIF00T0E5AD05iNGP1QHF40J6QX06a/K01XJ6P0JVYZ071`L01eMGD00P1nOWh01020
P800O7al07moO`1hN7P207UiN@0G07QhN01gMgL0QXJ608:2PP1hN7P0O7al08F5Q@20P800QhN708V9
R@28R8P0Q8B408J6QP28R8P0SXj>08>3P`28R8P0SXj>08N7Q`2<S8`0SXj>08V9R@2>SXh00P2;Rh/0
4027QhL0T92@08f=S@2BTY80Ti>C09JFUP28R8P0Shn?096AT@2BTY80TI6A09BDU02BTY80SXj>08f=
S@2>SXh208^;R`0U09NGU`2ATI40UYJF09RHV02?Shl0Rh^;08f=S@2FUYH0Shn?09:BTP2ATI40U9BD
08^;R`2ATI40S8b<09BDU02=SHd0RXZ:08b<S02CTi<0SHf=08B4Q02>SXh0Rh^;08b<S028R8P0RHV9
08R8R02>SXh0SHf=08^;R`27QhL0RHV908N7Q`24Q8@0RHV908J6QP0208B4Q0050820P022PX80PH61
08R8R01oOgl00P21PH404`1kNg/0OWin08B4Q01iNGT0OWin07YjNP1oOgl0NGUi07emO@1fMWH0Ogmo
07IfMP1iNGT0OGem07MgM`1_Kfl0O7al07YjNP1fMWH00P1iNGT03`1^KVh0Kfm_075aL@1cLg<0MWIf
071`L01dM7@0Kfm_06][J`1^KVh0LW9b06e]K@1^KVh0LG5a06i^KP0206][J`0306a/K01bLW80JVYZ
0080JVYZ00@0K6a/071`L01QHF40Jf][0P1/K6`01@1[Jf/0HF5Q06=SH`1[Jf/0I6AT0080J6QX00<0
Hf=S06][J`1VIVH00P1TI6@02@1QHF40GUiN069RHP1QHF40Hf=S065QH@1YJFT0IVIV06MWI`0206=S
H`0<06EUI@1OGel0Hf=S065QH@1/K6`0IVIV06EUI@1XJ6P0KVi^06EUI@1NGUh0IVIV0P1UIFD0101N
GUh0FUYJ06=SH`1PH60G000000H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WI
f@090=3@d01YJFT0IFEU06IVIP1/K6`0GemO05aLG01UIFD0GUiN0080J6QX00P0I6AT06QXJ01VIVH0
J6QX06EUI@1ZJVX0IVIV05iNGP80IFEU00<0JVYZ06=SH`1PH6000P1QHF404P1XJ6P0Fe]K06YZJP1U
IFD0HV9R06UYJ@1[Jf/0IVIV06][J`1_Kfl0JVYZ06UYJ@1_Kfl0K6a/06UYJ@1XJ6P0Lg=c075aL@80
KVi^00L0JFUY071`L01iNGT0J6QX071`L01bLW80L71`0080KVi^0P1`L7002@1^KVh0MgMg06m_K`1Y
JFT0N7Qh07MgM`1ZJVX0M7Ad079bLP0207MgM`0807AdM01UIFD0NGUi06i^KP1fMWH0LW9b07=cL`1a
LG4207IfMP0307]kN`1fMWH0MGEe00<0NGUi0140NWYj07UiN@1mOGd0O7al07EeM@1fMWH0Jf][06UY
J@1QHF40G5aL05=CD`1HF5P0Fe]K05iNGP1YJFT0L71`07=cL`0206YZJP0<07=cL`1eMGD0OWin07al
O01jNWX0Ng]k07YjNP1gMgL0Ogmo07]kN`1lO7`0Q8B40P1kNg/01@21PH40OWin08R8R028R8P0RXZ:
0080RHV900X0SXj>08^;R`26QXH0RHV908^;R`2<S8`0UYJF08f=S@28R8P0QXJ60P29RHT01`28R8P0
U9BD08j>SP2BTY80T92@09NGU`2@T9000P2;Rh/0102BTY80S8b<08Z:RP2BTY83096AT@0<08V9R@2B
TY80TI6A09JFUP2ATI40Ti>C08^;R`2ATI40R8R808n?S`2<S8`0U9BD0P2ATI40102FUYH0U9BD09NG
U`2<S8`2096AT@0P08V9R@2@T900Rh^;08j>SP2FUYH0Rh^;08n?S`2@T900RXZ:08b<S02ATI40R8R8
08b<S026QXH0QhN708j>SP23Ph<0SXj>08Z:RP23Ph<0QXJ60861P@24Q8@0Rh^;08V9R@23Ph<0PX:2
07moO`22PX80Ph>307inOP22PX820820P00>07emO@20P800MgMg07QhN01iNGT0Ng]k08:2PP1cLg<0
NWYj07]kN`1iNGT0MgMg0820P01fMWH207MgM`0H07]kN`1nOWh0M7Ad07alO01eMGD0Lg=c07AdM01i
NGT0M7Ad06a/K01[Jf/0M7Ad071`L01dM7@0KVi^06QXJ01VIVH0L71`075aL@1^KVh0LW9b06m_K`1X
J6P0Kfm_0P1VIVH0201XJ6P0Jf][06QXJ01/K6`0IFEU06UYJ@1[Jf/0K6a/0P1YJFT02P1TI6@0L71`
06=SH`1TI6@0IVIV06=SH`1PH600J6QX061PH01]KFd2065QH@0405iNGP1XJ6P0H61P06ATI080H61P
00l0HF5Q06ATI01YJFT0IVIV06i^KP1NGUh0IVIV06UYJ@1NGUh0HV9R05iNGP1WIfL0I6AT05iNGP1J
FUX05`0000060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT04`3=cLd0IFEU
061PH01VIVH0I6AT05iNGP1ZJVX0Hf=S061PH01TI6@0Hf=S06UYJ@1QHF40I6AT06MWI`1TI6@0IVIV
05iNGP1[Jf/00P1VIVH01@1RHV80J6QX065QH@1YJFT0I6AT0080KVi^00T0Jf][06QXJ01ZJVX0J6QX
06MWI`1VIVH0JVYZ06][J`1^KVh00P1YJFT01P1UIFD0K6a/06UYJ@1/K6`0M7Ad071`L080LG5a00D0
Lg=c06i^KP1YJFT0JVYZ06MWI`0206][J`03071`L01[Jf/0Jf][0080L71`02H0K6a/06i^KP1bLW80
Kfm_075aL@1cLg<0L71`07AdM01^KVh0MWIf07YjNP1_Kfl0MgMg07IfMP1^KVh0NGUi07IfMP1mOGd0
N7Qh07=cL`1fMWH0O7al07IfMP1eMGD0NGUi07EeM@1kNg/0MWIf079bLP1eMGD0KVi^05iNGP1/K6`0
GUiN061PH01MGEd0J6QX059BDP80JVYZ00@0Kfm_079bLP1`L700L71`0P1dM7@02`1iNGT0MWIf07em
O@1eMGD0NWYj07=cL`1fMWH0OGem07]kN`21PH40S8b<0080RHV900X0P82008J6QP22PX80PH6108V9
R@2@T900RXZ:08N7Q`29RHT0TI6A0`2>SXh07@2=SHd0RXZ:08b<S02>SXh0TI6A08b<S02ATI40UYJF
08R8R02EUID0U9BD08n?S`2DU9@0RXZ:09>CT`2BTY80SXj>09VIV@2GUiL0VIVI09FEU@2IVIT0UYJF
08f=S@2@T900Ti>C09BDU02EUID0Shn?0080U9BD00<0TI6A08b<S02CTi<00P2DU9@03P2FUYH0UiNG
08n?S`2ATI40TY:B08n?S`2>SXh0TY:B08b<S02BTY80V9RH08f=S@26QXH0SXj>0P2;Rh/0B02@T900
P82008N7Q`24Q8@0QXJ608N7Q`26QXH0PH6108F5Q@24Q8@0RHV908J6QP23Ph<0P82007inOP29RHT0
Q8B407inOP21PH40Ogmo08B4Q023Ph<0PX:207alO01hN7P0PH6107]kN`1lO7`0PH6107alO01iNGT0
Ng]k07=cL`1_Kfl0Lg=c07IfMP1hN7P0MWIf06i^KP1jNWX0MGEe07IfMP1`L700MWIf07QhN01fMWH0
K6a/079bLP1fMWH0LW9b06][J`1`L700KVi^07=cL`1aLG40MWIf06a/K01]KFd0Lg=c06i^KP1bLW80
KVi^06QXJ01`L700LG5a06QXJ01[Jf/0IfMW06][J`1YJFT0IVIV06YZJP80I6AT0P1[Jf/206UYJ@0H
06QXJ01UIFD0IVIV06i^KP1OGel0HV9R05eMG@1LG5`0IVIV065QH@1SHf<0HF5Q06=SH`1TI6@0HV9R
06ATI01XJ6P0Hf=S069RHP1VIVH0J6QX069RHP1QHF40G5aL0P1TI6@0101QHF40G5aL05iNGP1BDU8G
000000H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@030<c<c01LG5`0I6AT
0080HF5Q0100GUiN065QH@1QHF40I6AT06EUI@1TI6@0IFEU06QXJ01VIVH0JFUY069RHP1VIVH0H61P
065QH@1PH600K6a/0P1TI6@04P1QHF40IFEU06IVIP1[Jf/0K6a/06IVIP1WIfL0Jf][06=SH`1`L700
KVi^06QXJ01QHF40LG5a06i^KP1]KFd0J6QX06UYJ@80Jf][00h0Hf=S06i^KP1^KVh0M7Ad06UYJ@1/
K6`0KFe]07EeM@1YJFT0K6a/06][J`1^KVh0Kfm_06i^KP80L71`01<0LG5a07IfMP1/K6`0MgMg075a
L@1_Kfl0Lg=c071`L01cLg<0Ng]k07=cL`1hN7P0K6a/07AdM01lO7`0MWIf07QhN01gMgL0NGUi00<0
MWIf00<0OWin07UiN@1fMWH00P1jNWX0>01eMGD0N7Qh07=cL`1^KVh0GUiN06IVIP1OGel0H61P065Q
H@1VIVH0De=C07EeM@1`L700KVi^06UYJ@1dM7@0LG5a071`L01fMWH0Lg=c08>3P`1cLg<0O7al07Ad
M01iNGT0OGem07UiN@1oOgl0R8R808F5Q@29RHT0QXJ608>3P`21PH40P82008f=S@24Q8@0Shn?08V9
R@2>SXh0T92@08Z:RP29RHT0SHf=08b<S02>SXh0Ti>C096AT@2BTY80Ti>C08f=S@2ATI40Ti>C08^;
R`2EUID0SXj>0P2FUYH2092@T00@08f=S@2>SXh0VIVI08j>SP2CTi<0UYJF096AT@2CTi<0UYJF09FE
U@2LW9`0SHf=09JFUP2@T900WIfM09BDU080T92@03@0UiNG09VIV@2JVYX0U9BD096AT@2DU9@0UiNG
08b<S02@T900TI6A09FEU@2BTY80Shn?08N7Q`28R8P0SXj>08Z:RP2ATI40Rh^;08n?S`2@T900Rh^;
08V9R@23Ph<0RHV908N7Q`28R8P0Ph>308N7Q`20P800QhN708:2PP29RHT0QHF508>3P`20P800QHF5
0820P026QXH0P8200861P@20P800O7al07emO@1kNg/0MGEe07]kN`1gMgL0OGem07YjNP1kNg/0M7Ad
0`1hN7P0401fMWH0N7Qh07alO01iNGT0N7Qh075aL@1eMGD0N7Qh07=cL`1fMWH0KFe]071`L01cLg<0
KVi^07=cL`1_Kfl307=cL`0J071`L01TI6@0JFUY06e]K@1bLW80K6a/06UYJ@1XJ6P0Jf][06a/K01Z
JVX0IVIV06a/K01TI6@0HF5Q06IVIP1QHF40Hf=S06ATI01VIVH0H61P06ATI01ZJVX0HV9R06=SH`1U
IFD206=SH`0I06EUI@1SHf<0I6AT06][J`1TI6@0HF5Q06ATI01QHF40GUiN06IVIP1MGEd0IfMW06QX
J01NGUh0J6QX06IVIP1UIFD0Hf=S065QH@1SHf<0GemO069RHP1OGel0F5QH05UIF@0G000000H0fMWI
0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@040=?Cd`1SHf<0Fe]K06IVIP80IfMW
01L0J6QX06ATI01VIVH0H61P06UYJ@1UIFD0Hf=S06ATI01[Jf/0IVIV06ATI01XJ6P0I6AT06IVIP1N
GUh0J6QX06][J`1VIVH0JFUY06=SH`1TI6@0J6QX06][J`0206ATI00306IVIP1/K6`0J6QX0080JFUY
00<0Jf][06i^KP1[Jf/00P1[Jf/0601TI6@0IVIV07=cL`1[Jf/0MgMg079bLP1/K6`0L71`06i^KP1a
LG40IfMW06m_K`1XJ6P0JFUY071`L01[Jf/0L71`07=cL`1fMWH0K6a/071`L01fMWH0L71`07]kN`80
N7Qh02P0MGEe07]kN`1nOWh0MWIf075aL@1^KVh0Kfm_07AdM01kNg/0O7al0861P@1kNg/0MgMg07If
MP1aLG40Ng]k07MgM`1kNg/0PH6107QhN01eMGD0L71`06=SH`1YJFT0IVIV06=SH`1TI6@0K6a/071`
L01kNg/0O7al075aL@1_Kfl0KFe]06QXJ01^KVh0Jf][06i^KP1kNg/0O7al0P1jNWX0201lO7`0P820
08B4Q021PH40P82008>3P`26QXH0Rh^;0P24Q8@02@21PH40PX:208V9R@2:RXX0SXj>08b<S02=SHd0
S8b<08F5Q@0208j>SP0709NGU`2@T900Shn?08j>SP2@T900UIFE09RHV00209BDU00=092@T02BTY80
Ti>C08b<S02EUID0TI6A092@T02<S8`0U9BD09JFUP2DU9@0TY:B09VIV@0209BDU00309:BTP2IVIT0
TI6A0080TI6A00<0SXj>09BDU02HV9P00P2ATI4209RHV00Q09JFUP2GUiL0V9RH09BDU02:RXX0TY:B
09JFUP2CTi<0T92@08j>SP2FUYH0TY:B09NGU`2=SHd0S8b<08^;R`2LW9`0Rh^;08b<S027QhL0RHV9
08j>SP2;Rh/0RHV907inOP25QHD0OWin08J6QP27QhL0Ph>308^;R`23Ph<0O7al0080QXJ600<0P820
08V9R@22PX800P23Ph<208B4Q00507moO`1nOWh0NGUi07IfMP29RHT00P1cLg<02P1iNGT0N7Qh07Ee
M@1jNWX0O7al07UiN@1fMWH0LW9b07MgM`1dM7@207UiN@0F071`L01aLG40LG5a07moO`1dM7@0LG5a
07=cL`1_Kfl0LW9b075aL@1ZJVX0K6a/079bLP1^KVh0JVYZ071`L01_Kfl0Jf][06a/K01]KFd0Hf=S
06UYJ@80IfMW0`1YJFT00`1]KFd0JVYZ06IVIP0206=SH`0406YZJP1LG5`0I6AT06][J`80Hf=S01P0
H61P069RHP1QHF40HF5Q06=SH`1YJFT0GUiN06=SH`1UIFD0HF5Q05iNGP1TI6@0IFEU065QH@1TI6@0
GemO06EUI@1ZJVX0J6QX06ATI01OGel0I6AT065QH@1RHV8205UIFAL000001P3IfMT100000040fMWI
000F0=WIf@030000003IfMT0fMWI00<0fMWI01X0bLW9061PH01IFET0HF5Q05iNGP1UIFD0JVYZ061P
H01RHV80Hf=S065QH@1TI6@0IVIV06UYJ@1WIfL0Hf=S06EUI@1RHV80JVYZ06MWI`1[Jf/0IVIV06][
J`1/K6`0L71`06YZJP80IfMW00P0H61P071`L01TI6@0JFUY06YZJP1XJ6P0Kfm_06YZJP80Jf][00h0
K6a/06QXJ01/K6`0KFe]071`L01^KVh0JFUY06YZJP1]KFd0Jf][06i^KP1`L700JFUY06QXJ080KVi^
0P1`L7000`1[Jf/0Lg=c07=cL`0206i^KP0P075aL@1^KVh0Lg=c07UiN@1`L700KVi^071`L01fMWH0
MGEe07emO@1jNWX0M7Ad07QhN01iNGT0M7Ad07QhN01kNg/0NGUi07alO01hN7P0MgMg08:2PP1hN7P0
KFe]08>3P`1hN7P0Lg=c075aL@1`L700KVi^06UYJ@1ZJVX206e]K@0B07EeM@1kNg/0OWin07=cL`1[
Jf/0JFUY06][J`1SHf<0J6QX06i^KP1kNg/0NGUi08F5Q@20P800Ogmo07UiN@23Ph<0Rh^;0`2:RXX0
302;Rh/0PH610861P@21PH40Rh^;08B4Q02BTY80R8R808j>SP2:RXX0RHV909BDU080UiNG00/0TI6A
09:BTP2IVIT0UYJF09BDU02LW9`0U9BD09RHV02>SXh0V9RH09NGU`0209>CT`0B08j>SP2GUiL0UYJF
092@T02<S8`0T92@096AT@2FUYH0S8b<092@T02KVi/0WIfM09bLW02JVYX0U9BD09JFUP2KVi/0UIFE
0P2FUYH01`2DU9@0SXj>09>CT`2HV9P0W9bL09RHV02FUYH00P2@T900=02EUID0VIVI08j>SP2KVi/0
T92@08b<S02GUiL0RHV909FEU@2BTY80S8b<08V9R@2;Rh/0SXj>092@T02?Shl0Q8B408n?S`25QHD0
S8b<07alO029RHT0P82008R8R026QXH0QhN708:2PP24Q8@0PH6108>3P`20P800Ph>307alO026QXH0
P82007alO021PH40OGem08>3P`1mOGd0O7al08>3P`1iNGT0N7Qh07UiN@1jNWX0NGUi07emO@1cLg<0
O7al07IfMP1kNg/207alO080MgMg01X0K6a/06m_K`1bLW80KVi^079bLP1^KVh0LG5a07AdM01aLG40
KVi^06IVIP1^KVh0JFUY06YZJP1/K6`0JVYZ075aL@1QHF40J6QX06UYJ@1cLg<0I6AT06UYJ@1[Jf/0
H61P06][J`80IFEU00l0JVYZ06QXJ01VIVH0Hf=S06ATI01/K6`0GemO065QH@1TI6@0GUiN069RHP1W
IfL0GUiN06ATI01/K6`00P1SHf<04P1VIVH0HV9R061PH01PH600J6QX05mOG`1TI6@0HF5Q069RHP1T
I6@0IfMW06EUI@1ZJVX0HV9R05iNGP1MGEd0FEUI05aLG1L000001P3IfMT100000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI00D0c<c<06EUI@1QHF40GEeM05UIF@0206ATI00D065QH@1SHf<0
Jf][06][J`1LG5`0IFEU06QXJ01PH600GemO06MWI`1QHF40J6QX06MWI`1^KVh0IVIV069RHP1ZJVX0
IFEU07=cL`1[Jf/206a/K00A06QXJ01[Jf/0KVi^06a/K01YJFT0K6a/06m_K`1/K6`0Jf][06YZJP1/
K6`0Jf][06IVIP1]KFd0Jf][07=cL`1UIFD00P1[Jf/04P1SHf<0IfMW071`L01fMWH0KVi^06e]K@1Y
JFT0Kfm_075aL@1[Jf/0L71`07AdM01]KFd0N7Qh07AdM01XJ6P0K6a/07AdM080Lg=c01/0NGUi07=c
L`1hN7P0NWYj07AdM01mOGd0N7Qh07moO`1aLG40MgMg07inOP22PX80LW9b07MgM`1oOgl0OGem07Qh
N020P800MgMg071`L01ZJVX0IfMW075aL@1ZJVX0KVi^07QhN01dM7@00P1jNWX02`1cLg<0JFUY06a/
K01RHV80Hf=S06a/K01XJ6P0L71`0861P@20P800OWin0080Q8B40`26QXH02@28R8P0Rh^;08J6QP2;
Rh/0RHV908^;R`28R8P0SXj>07EeM@02092@T080Ti>C00P0U9BD08f=S@2ATI40T92@096AT@2:RXX0
TI6A092@T080V9RH04P0Ti>C09BDU02HV9P0UiNG09FEU@2HV9P0Vi^K09NGU`2LW9`0VYZJ09VIV@2F
UYH0T92@09VIV@2@T900SXj>09JFUP2>SXh0Vi^K09NGU`2DU9@0Ti>C09NGU`2HV9P0VIVI09NGU`2C
Ti<0U9BD08n?S`2JVYX0TI6A08j>SP2=SHd0U9BD09RHV02DU9@0UIFE08n?S`2BTY80U9BD096AT@2<
S8`0TI6A09FEU@2>SXh0RHV908R8R02ATI40SXj>08f=S@2;Rh/0UIFE08^;R`23Ph<0R8R809>CT`1l
O7`0Q8B408V9R@20P800Shn?08^;R`22PX80QhN708>3P`27QhL0PX:207]kN`28R8P0Ph>307alO024
Q8@208>3P`0708B4Q01lO7`0O7al07IfMP26QXH0Ng]k07MgM`0207moO`0@07QhN01lO7`0NWYj07Ui
N@20P800PH6107QhN01gMgL0LG5a07AdM01cLg<0MWIf06m_K`1aLG40L71`07AdM080L71`01D0M7Ad
06a/K01dM7@0MgMg06][J`1VIVH0KFe]06UYJ@1^KVh0K6a/06][J`1YJFT0IVIV06m_K`1^KVh0Jf][
06a/K01UIFD0IfMW06e]K@1TI6@00P1VIVH05@1QHF40JFUY061PH01VIVH0JVYZ05aLG01XJ6P0JFUY
05aLG01UIFD0K6a/06IVIP1TI6@0GUiN069RHP1SHf<0HF5Q06EUI@1NGUh0Hf=S06MWI`0205eMG@80
IVIV00H0HV9R06=SH`1XJ6P0Fe]K065QH@1OGelG000000H0fMWI0@0000010=WIf@005P3IfMT00`00
0000fMWI0=WIf@030=WIf@0C0<[:bP1SHf<0JVYZ06IVIP1OGel0I6AT061PH01YJFT0GUiN06=SH`1Y
JFT0IVIV06ATI01YJFT0IVIV06=SH`1PH600IVIV06=SH`0306IVIP0;06][J`1WIfL0Jf][06IVIP1a
LG40IVIV075aL@1XJ6P0KVi^06QXJ01[Jf/00P1/K6`02P1cLg<0LW9b06a/K01UIFD0IVIV06QXJ01V
IVH0IfMW06a/K01dM7@306a/K00Q06e]K@1aLG40K6a/06a/K01YJFT0I6AT06e]K@1YJFT0J6QX06e]
K@1cLg<0MGEe07=cL`1lO7`0Kfm_079bLP1cLg<0LW9b07AdM01aLG40P82007EeM@21PH40NGUi07Mg
M`1hN7P0Ng]k07MgM`1hN7P0OWin07QhN01iNGT0MWIf0080NGUi00<0NWYj07UiN@1gMgL00P1iNGT0
6`1^KVh0K6a/06m_K`1VIVH0KFe]06m_K`1hN7P0MWIf06i^KP1XJ6P0Jf][06e]K@1TI6@0GemO06MW
I`1/K6`0M7Ad07inOP28R8P0P8200861P@24Q8@0QhN708B4Q026QXH0Ph>308B4Q00308J6QP0N07in
OP2:RXX0Q8B408j>SP2DU9@0TI6A08^;R`27QhL0SXj>09VIV@2FUYH0VYZJ092@T02EUID0Vi^K09RH
V02DU9@0TI6A09RHV02DU9@0TI6A09ZJVP2GUiL0Ti>C09RHV02LW9`0UYJF09^KV`2LW9`0UYJF0P2D
U9@0202JVYX0Vi^K09^KV`2LW9`0UiNG09VIV@2MWId0XJ6Q0P2KVi/209>CT`0609BDU02MWId0U9BD
0:BTY02GUiL0UYJF0P2HV9P03@2CTi<0VIVI09FEU@2DU9@0S8b<096AT@2FUYH0SXj>09BDU02HV9P0
U9BD09:BTP2ATI400P2<S8`03P2;Rh/0UYJF096AT@20P800S8b<08V9R@26QXH0Ph>308R8R02=SHd0
P82008J6QP1kNg/0Ph>30P28R8P04P2;Rh/0Q8B408^;R`1nOWh0PX:20820P01oOgl0QXJ607inOP1f
MWH0NGUi07inOP1lO7`0N7Qh0861P@1iNGT0OWin0820P080O7al00h0OGem07alO01jNWX0N7Qh07mo
O`1aLG40LW9b07QhN01dM7@0MGEe07MgM`1fMWH0LG5a06e]K@80Lg=c00P0K6a/071`L01_Kfl0K6a/
06YZJP1aLG40Jf][07=cL`80JFUY00D0JVYZ06a/K01PH600IfMW06a/K00206IVIP0?06QXJ01ZJVX0
IFEU071`L01ZJVX0HF5Q06QXJ01PH600Hf=S06UYJ@1VIVH0HV9R06UYJ@1PH600IfMW0080IFEU01@0
IVIV05UIF@1LG5`0IfMW06=SH`1PH600GemO065QH@1YJFT0GUiN06QXJ01MGEd0HV9R06=SH`1ZJVX0
HF5Q05iNGP1KFe/0GemO05eMGAL000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI
00<0fMWI00H0dM7A06=SH`1QHF40HF5Q05eMG@1PH60305iNGP0906=SH`1NGUh0IFEU065QH@1VIVH0
J6QX06=SH`1RHV80J6QX00<0I6AT0`1VIVH01@1XJ6P0IFEU06QXJ01OGel0L71`0080KVi^0140Jf][
06QXJ01YJFT0J6QX06][J`1`L700M7Ad06IVIP1XJ6P0LG5a06i^KP1aLG40Kfm_071`L01ZJVX0Kfm_
06UYJ@0206][J`80K6a/00X0L71`075aL@1/K6`0KVi^06][J`1fMWH0LG5a07YjNP1aLG40N7Qh0P1`
L7002@1aLG40M7Ad075aL@1jNWX0Lg=c07MgM`1eMGD0MgMg07AdM00207UiN@0N07IfMP1hN7P0Ogmo
07alO01hN7P0Ng]k07UiN@1jNWX0Lg=c07inOP1fMWH0NGUi07EeM@1/K6`0Kfm_06a/K01bLW80MGEe
06i^KP1aLG40L71`06][J`1ZJVX0HV9R065QH@1[Jf/0K6a/071`L01fMWH0Lg=c0P20P8002024Q8@0
QhN70820P01kNg/0Q8B408V9R@26QXH0RHV90P23Ph<04`21PH40Q8B408V9R@24Q8@0S8b<08^;R`2I
VIT0RHV909BDU02JVYX0TI6A09BDU02GUiL0V9RH09FEU@2@T900UYJF09nOW`2HV9P00P2MWId03@2K
Vi/0UiNG09^KV`2LW9`0UiNG09bLW02HV9P0Ti>C09VIV@2SXj<0U9BD09JFUP2IVIT00`2DU9@02`2J
VYX0X:2P09fMW@2NWYh0UYJF09bLW02OWil0UiNG09RHV02KVi/0Shn?0080VIVI01D0UiNG09VIV@2H
V9P0U9BD09:BTP2HV9P0TI6A09NGU`2DU9@0SXj>09RHV02@T900TI6A092@T02?Shl0TI6A092@T02;
Rh/0SXj>092@T02;Rh/00`2<S8`02027QhL0SXj>08N7Q`29RHT0S8b<08Z:RP21PH40QXJ60P25QHD0
5023Ph<0S8b<08R8R028R8P0QXJ608B4Q022PX80P82008:2PP1hN7P0Ph>307emO@20P800Ogmo07al
O020P800Ng]k07QhN01kNg/0NGUi0P1kNg/02P1nOWh0MWIf07QhN01nOWh0N7Qh07IfMP1kNg/0Lg=c
07MgM`1hN7P2079bLP0C071`L01_Kfl0Kfm_071`L01WIfL0KFe]06QXJ01]KFd0KVi^071`L01/K6`0
IVIV071`L01VIVH0Kfm_07AdM01/K6`0N7Qh06e]K@0206QXJ00A06=SH`1RHV80IfMW061PH01XJ6P0
JFUY061PH01XJ6P0Hf=S061PH01MGEd0GUiN06][J`1TI6@0IVIV06EUI@1XJ6P00P1WIfL0401YJFT0
IVIV061PH01VIVH0I6AT06QXJ01VIVH0H61P05iNGP1RHV80HF5Q05iNGP1QHF40Fe]K06=SH`1QHF4G
000000H0fMWI0@0000010=WIf@005P3IfMT2000000@0fMWI00L0c/k>05aLG01QHF40Hf=S06IVIP1P
H600JVYZ0080IVIV0100Hf=S05YJFP1SHf<0I6AT06=SH`1VIVH0GemO06e]K@1TI6@0IfMW06=SH`1Q
HF40IVIV061PH01TI6@0Jf][0P1YJFT02@1^KVh0L71`06a/K01_Kfl0J6QX06ATI01]KFd0Jf][06e]
K@0206a/K00>071`L01bLW80LG5a06][J`1^KVh0Jf][071`L01]KFd0JFUY06QXJ01YJFT0L71`07al
O01/K6`207=cL`0=071`L01_Kfl0Lg=c07]kN`1`L700MgMg071`L01jNWX0M7Ad07UiN@1fMWH0Lg=c
07IfMP0207alO00307YjNP1hN7P0NWYj0080O7al00@0OWin07alO020P800O7al0P1kNg/01`1jNWX0
O7al07moO`1iNGT0O7al075aL@1iNGT00P1kNg/00`1cLg<0K6a/06UYJ@0206QXJ00506m_K`1/K6`0
Hf=S06][J`1YJFT00P1VIVH02`1iNGT0Ng]k07IfMP21PH40Q8B407inOP24Q8@0R8R808:2PP1nOWh0
P82000<0Ph>303<0Rh^;0861P@26QXH0Ph>308^;R`29RHT0TY:B096AT@29RHT0Rh^;096AT@2FUYH0
V9RH09VIV@2LW9`0V9RH09>CT`2ATI40U9BD09bLW02KVi/0UYJF09fMW@2KVi/0W9bL096AT@2DU9@0
WIfM09^KV`2MWId0W9bL09VIV@2HV9P0Vi^K09VIV@2DU9@0X:2P09fMW@2FUYH0Vi^K09jNWP2HV9P0
UYJF09VIV@2NWYh0X:2P09jNWP2KVi/0W9bL09VIV@2NWYh00P2JVYX02@2IVIT0UYJF09RHV02KVi/0
Ti>C09^KV`2IVIT0WinO09^KV`0209bLW00@09ZJVP2@T900S8b<08^;R`2?Shl0U9BD08j>SP2@T900
UIFE08b<S02;Rh/0T92@08N7Q`24Q8@0TY:B08J6QP80S8b<04<0SHf=08R8R020P800RHV908j>SP21
PH40PX:20861P@25QHD0P82008:2PP24Q8@0OWin0861P@1nOWh0QHF507inOP24Q8@0MWIf07UiN@1f
MWH0Ng]k07YjNP21PH40OWin07IfMP1lO7`0N7Qh07alO01gMgL0Ng]k07MgM`1dM7@0LW9b071`L01a
LG40MgMg07EeM@1dM7@0LG5a071`L01/K6`0KVi^07AdM01_Kfl0Lg=c06m_K`1]KFd0LW9b06][J`1U
IFD0H61P06QXJ01^KVh0Hf=S06e]K@1[Jf/0Kfm_06e]K@1YJFT0K6a/06IVIP1PH600KVi^06=SH`1V
IVH0H61P0080I6AT00X0HF5Q06ATI01NGUh0IVIV06UYJ@1XJ6P0Hf=S06EUI@1SHf<0IFEU0P1NGUh0
3@1QHF40HV9R06IVIP1QHF40Fe]K065QH@1SHf<0IFEU05iNGP1TI6@0EUIF05UIF@1LG5`05`000005
0=WIf@8000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0203?cll0Fe]K061PH01KFe/0
IVIV065QH@1KFe/0I6AT0P1QHF40301NGUh0Hf=S065QH@1UIFD0Hf=S06UYJ@1QHF40Hf=S06EUI@1I
FET0JVYZ06MWI`80IVIV00h0IfMW071`L01_Kfl0Jf][06YZJP1[Jf/0L71`07=cL`1/K6`0IVIV06i^
KP1]KFd0JFUY071`L0<0J6QX01P0K6a/06YZJP1ZJVX0Jf][07AdM01VIVH0JFUY06][J`1cLg<0K6a/
071`L01dM7@0K6a/06m_K`1/K6`0LG5a06i^KP1fMWH0L71`07IfMP1dM7@0MgMg075aL@1nOWh207=c
L`0>07IfMP1hN7P0NGUi07IfMP1eMGD0M7Ad07alO01gMgL0NGUi07emO@1dM7@0NGUi07]kN`1iNGT3
07alO0040861P@1kNg/0Ph>308:2PP80MWIf0140Kfm_06i^KP1aLG40J6QX06e]K@1`L700IfMW061P
H01VIVH0KVi^075aL@1iNGT0P82007]kN`23Ph<0Q8B408V9R@0208^;R`0708J6QP28R8P0O7al08J6
QP21PH40Ph>307moO`0208R8R00>08>3P`2<S8`0T92@09FEU@2HV9P0Ti>C09NGU`2BTY80Ti>C09VI
V@2ATI40VIVI09NGU`2MWId2096AT@0809VIV@2EUID0WYjN09jNWP2GUiL0Vi^K0:2PX02KVi/209RH
V00>0:6QX@2DU9@0WIfM09^KV`2OWil0W9bL09>CT`2OWil0UYJF09VIV@2DU9@0WYjN09^KV`2PX:02
09^KV`0709bLW02DU9@0WYjN09^KV`2DU9@0TY:B096AT@0209VIV@0:09bLW02OWil0X:2P0:BTY02K
Vi/0WYjN09JFUP2TY:@0WinO09^KV`80V9RH00`0W9bL09NGU`2FUYH0UIFE08n?S`2>SXh0TY:B08j>
SP2CTi<0SHf=09:BTP2>SXh208F5Q@0608V9R@1nOWh0Rh^;0861P@24Q8@0P8200P23Ph<01026QXH0
PH6108B4Q021PH4208B4Q080P82000/0Ogmo07YjNP25QHD0OWin07QhN01nOWh0Ph>307alO01oOgl0
Ng]k07emO@0207MgM`0407inOP1dM7@0Lg=c07UiN@80MWIf00L0Lg=c07AdM01aLG40Kfm_06i^KP1c
Lg<0LG5a0080Kfm_00d0L71`06a/K01`L700LW9b06m_K`1^KVh0JFUY06a/K01YJFT0J6QX06i^KP1_
Kfl0J6QX0080L71`0P1[Jf/02P1/K6`0J6QX06UYJ@1/K6`0Jf][06UYJ@1WIfL0Hf=S06EUI@1XJ6P2
06UYJ@0<06IVIP1TI6@0HF5Q06=SH`1YJFT0G5aL065QH@1RHV80Jf][06=SH`1TI6@0Fe]K0P1TI6@0
2@1LG5`0J6QX06IVIP1SHf<0I6AT06=SH`1MGEd0Fe]K05YJFP0G000000H0fMWI0@0000010=WIf@00
5P3IfMT00`000000fMWI0=WIf@030=WIf@0F0=3@d01OGel0HV9R065QH@1PH600IVIV06=SH`1QHF40
Hf=S06ATI01WIfL0H61P06MWI`1RHV80H61P06=SH`1YJFT0IfMW06][J`1XJ6P0HF5Q06QXJ080Jf][
00H0Hf=S06a/K01/K6`0JVYZ06][J`1^KVh206][J`0O06YZJP1/K6`0JVYZ06a/K01^KVh0J6QX079b
LP1]KFd0LG5a06i^KP1]KFd0JVYZ06a/K01ZJVX0HF5Q07AdM01/K6`0Jf][06a/K01aLG40K6a/06i^
KP1ZJVX0NGUi071`L01gMgL0MWIf07UiN@1dM7@0K6a/07IfMP0207AdM00K07inOP1kNg/0M7Ad07]k
N`1eMGD0OWin07MgM`24Q8@0NWYj07inOP1hN7P0NGUi07alO01nOWh0NGUi07alO020P800OWin07=c
L`1nOWh0PH6108:2PP21PH40O7al07emO@1aLG40LW9b0080K6a/01D0M7Ad06UYJ@1/K6`0J6QX071`
L01aLG40NWYj07alO026QXH0Rh^;092@T02ATI40Ti>C08Z:RP29RHT0PH6108>3P`28R8P0PH6108>3
P`22PX800P29RHT02@2CTi<0S8b<09>CT`2IVIT0UIFE09BDU02HV9P0T92@09FEU@0209RHV00N092@
T02OWil0T92@09JFUP2KVi/0WinO09JFUP2NWYh0VIVI09nOW`2PX:00U9BD09ZJVP2LW9`0Y:BT09RH
V02KVi/0V9RH09jNWP2CTi<0VYZJ09nOW`2SXj<0VIVI09^KV`2GUiL0WYjN09nOW`2EUID0WIfM0P2L
W9`0602CTi<0VIVI09bLW02JVYX0Vi^K09VIV@2OWil0Vi^K09fMW@2QXJ40V9RH09FEU@2KVi/0V9RH
09jNWP2QXJ40WIfM0::RXP2TY:@0WYjN0:2PX02IVIT0TI6A08n?S`80U9BD02L0V9RH096AT@2@T900
TI6A08n?S`2CTi<0S8b<08^;R`29RHT0Rh^;08B4Q026QXH0S8b<096AT@26QXH0R8R80861P@28R8P0
Q8B408J6QP24Q8@0QHF50820P01oOgl0QXJ608F5Q@1mOGd0P82007]kN`1mOGd0PH6107]kN`25QHD0
P82007QhN01lO7`0P82007emO@1jNWX00P1kNg/03`1hN7P0MGEe07AdM01eMGD0N7Qh07=cL`1bLW80
L71`06a/K01hN7P0MWIf06][J`1`L700Lg=c075aL@02071`L00O06m_K`1aLG40JVYZ06a/K01hN7P0
J6QX06m_K`1XJ6P0M7Ad06UYJ@1SHf<0JVYZ06QXJ01^KVh0JFUY06ATI01QHF40I6AT06IVIP1SHf<0
IVIV06UYJ@1XJ6P0Hf=S06UYJ@1RHV80J6QX06IVIP1TI6@0HV9R06ATI00206=SH`0406EUI@1VIVH0
Fe]K069RHP80Hf=S00P0GUiN065QH@1PH600Fe]K05iNGP1UIFD0H61P05aLG1L000001P3IfMT10000
0040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00X0d=3@05mOG`1LG5`0Hf=S06QXJ01TI6@0
HF5Q06IVIP1PH600Hf=S0`1PH6001P1SHf<0G5aL05mOG`1[Jf/0IfMW06ATI080HF5Q00/0JFUY06AT
I01QHF40Jf][065QH@1/K6`0KVi^06QXJ01^KVh0KFe]06][J`0206a/K00:06][J`1aLG40MGEe06e]
K@1`L700KFe]06a/K01YJFT0KVi^06a/K080Jf][00X0Kfm_06a/K01^KVh0LW9b07=cL`1/K6`0Jf][
075aL@1dM7@0KVi^0P1dM7@07`1eMGD0MgMg07QhN01lO7`0MGEe071`L01kNg/0MWIf07AdM01eMGD0
OGem07IfMP1hN7P0NGUi07AdM01lO7`0M7Ad08:2PP24Q8@0OWin07alO01oOgl0OGem08>3P`1dM7@0
PX:207QhN01nOWh0P8200861P@2<S8`00P20P8006@1nOWh0O7al07AdM01_Kfl0LW9b06i^KP1dM7@0
MgMg07emO@24Q8@0Rh^;08b<S02DU9@0Shn?08V9R@28R8P0SHf=08b<S025QHD0SHf=08V9R@27QhL0
Ti>C08V9R@2>SXh00P2;Rh/03@2FUYH0T92@09>CT`2GUiL0UYJF09>CT`2FUYH0VIVI09ZJVP2IVIT0
Vi^K09BDU02KVi/00P2QXJ403P2FUYH0VIVI0:BTY02HV9P0VYZJ09>CT`2OWil0WYjN0:6QX@2SXj<0
X:2P09JFUP2KVi/0TI6A0P2KVi/0302JVYX0X:2P09jNWP2LW9`0WIfM0:BTY02EUID0W9bL09jNWP2K
Vi/0W9bL09ZJVP80VIVI00X0WIfM0:2PX02NWYh0WIfM09bLW02OWil0VIVI0:>SX`2TY:@0WinO0P2S
Xj<00`2KVi/0Xj>S0:BTY0020:BTY00909jNWP2IVIT0Ti>C09RHV02BTY80TI6A09FEU@2CTi<0SHf=
0080S8b<01<0Rh^;08J6QP2<S8`0RHV90861P@2<S8`0RHV908:2PP23Ph<0Q8B407]kN`28R8P0QHF5
0820P023Ph<0RHV907inOP28R8P0PX:20080PH6100T0Ph>308B4Q026QXH0PH6108B4Q020P800PH61
08>3P`1iNGT00P1lO7`01@1nOWh0N7Qh07QhN01eMGD0NGUi0080MWIf0100Ng]k07QhN01lO7`0LW9b
06a/K01aLG40L71`06UYJ@1_Kfl0JVYZ06QXJ01cLg<0KVi^07=cL`1YJFT0Jf][0P1_Kfl206i^KP0T
06][J`1^KVh0IVIV06UYJ@1WIfL0Kfm_06UYJ@1ZJVX0JFUY075aL@1/K6`0JVYZ06e]K@1hN7P0JVYZ
065QH@1WIfL0KFe]06EUI@1TI6@0Jf][06EUI@1QHF40IfMW05iNGP1QHF40IVIV06=SH`1UIFD0Hf=S
06QXJ01NGUh0I6AT06YZJP1RHV80GemO0P1TI6@00`1SHf<0Fe]K05aLG00G000000H0fMWI0@000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@070=SHf01UIFD0GEeM05mOG`1VIVH0HF5Q06=S
H`02065QH@0406IVIP1QHF40GUiN05YJFP<0JFUY0P1SHf<04P1NGUh0IFEU065QH@1SHf<0K6a/06QX
J01YJFT0Jf][071`L01[Jf/0K6a/06UYJ@1/K6`0IFEU06a/K01aLG40MGEe075aL@80KFe]00h0JFUY
06YZJP1`L700MWIf06a/K01dM7@0MWIf07=cL`1gMgL0L71`075aL@1[Jf/0L71`06][J`80K6a/00l0
Lg=c06a/K01bLW80NGUi07=cL`1hN7P0Lg=c07MgM`1dM7@0MgMg07AdM01kNg/0MWIf07EeM@1jNWX0
0P1fMWH05`1lO7`0OWin07QhN01lO7`0N7Qh07MgM`1oOgl0MgMg0820P01nOWh0Ph>308:2PP25QHD0
Q8B408N7Q`20P800Ph>308B4Q023Ph<0QXJ608B4Q020P800PH610080P82000P0Lg=c08>3P`28R8P0
Ph>308N7Q`2<S8`0QhN708b<S080UIFE00<0V9RH09^KV`2DU9@00P24Q8@02026QXH0S8b<092@T02B
TY80U9BD096AT@2CTi<0V9RH0P2DU9@01@2JVYX0VIVI08f=S@2KVi/0VIVI0080VYZJ00/0W9bL09JF
UP2NWYh0V9RH09NGU`2PX:00V9RH0:FUY@2QXJ40YZJV0:6QX@030:2PX00409jNWP2JVYX0X:2P0::R
XP80Vi^K00`0X:2P0:6QX@2LW9`0Vi^K0::RXP2LW9`0XJ6Q0:>SX`2a/K40YJFU0:2PX02TY:@209jN
WP80X:2P0`2LW9`0:02NWYh0XJ6Q0:NWY`2OWil0Vi^K0:>SX`2QXJ40YJFU0::RXP2TY:@0ZZZZ0:b/
[02TY:@0VIVI09JFUP2HV9P0Vi^K09>CT`2HV9P0S8b<09>CT`2:RXX0UYJF09:BTP2;Rh/0SXj>08b<
S026QXH0Q8B408^;R`21PH40P82008Z:RP26QXH0PX:208B4Q022PX80MgMg0861P@24Q8@208>3P`05
08F5Q@1nOWh0Q8B408>3P`1kNg/00P1mOGd06022PX80O7al08R8R023Ph<0PH6107moO`1nOWh0MWIf
07inOP1hN7P0Ng]k07inOP1iNGT0Ng]k06i^KP1eMGD0Kfm_07YjNP1eMGD0Kfm_06i^KP1hN7P0K6a/
07QhN080JFUY00`0Kfm_06UYJ@1aLG40M7Ad06a/K01cLg<0M7Ad06i^KP1/K6`0JFUY06i^KP1/K6`2
06UYJ@0C06QXJ01TI6@0KVi^06MWI`1VIVH0H61P06QXJ01WIfL0JFUY065QH@1RHV80IVIV06a/K01L
G5`0GUiN06QXJ01VIVH0HV9R05]KF`0306ATI00=065QH@1SHf<0Hf=S069RHP1VIVH0JFUY061PH01L
G5`0H61P06=SH`1RHV80Hf=S05UIF@0G000000H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI
0=WIf@030=WIf@040<g=c@1TI6@0I6AT061PH080IfMW00P0HF5Q069RHP1WIfL0HF5Q06QXJ01VIVH0
HV9R06ATI080J6QX00H0HF5Q06QXJ01TI6@0Hf=S06ATI01/K6`206i^KP0606QXJ01TI6@0L71`06QX
J01/K6`0IFEU0P1/K6`04P1]KFd0Kfm_06a/K01dM7@0Kfm_07=cL`1[Jf/0KVi^071`L01cLg<0L71`
06][J`1`L700M7Ad06QXJ01bLW80MGEe06e]K@80Kfm_0180Jf][06e]K@1cLg<0KFe]07IfMP1jNWX0
Lg=c07MgM`1eMGD0OGem07]kN`1jNWX0LG5a07UiN@1gMgL0MWIf0861P@1lO7`207]kN`0F07inOP20
P800NGUi07IfMP22PX80PH6108>3P`1lO7`0N7Qh07inOP1kNg/0Ogmo07]kN`1lO7`0QHF507alO022
PX80QXJ608>3P`25QHD0Ph>308B4Q080O7al00T0RXZ:08j>SP2:RXX0P82008>3P`2@T900SXj>08f=
S@2:RXX00P2IVIT02@2;Rh/0Ti>C096AT@28R8P0T92@08R8R02;Rh/0UYJF09VIV@02092@T00309^K
V`2DU9@0Vi^K0080UiNG00l0WIfM09ZJVP2DU9@0VYZJ09RHV02FUYH0XZ:R09BDU02QXJ40VIVI09ZJ
VP2KVi/0Y:BT09jNWP2RXZ800P2PX:001`2VYZH0Vi^K09bLW02KVi/0VIVI0:6QX@2TY:@00P2OWil0
4@2TY:@0XJ6Q09jNWP2OWil0XJ6Q09VIV@2KVi/0Z:RX0:BTY02WYjL0VIVI0:BTY02UYJD0VIVI09bL
W02MWId0YJFU0080Xj>S00h0Vi^K0:>SX`2DU9@0W9bL0:>SX`2KVi/0W9bL0:>SX`2QXJ40Y:BT0:6Q
X@2PX:00W9bL09FEU@80UiNG00H0V9RH08n?S`2>SXh0Ti>C09VIV@2@T90209:BTP0909BDU02;Rh/0
TI6A08B4Q023Ph<0R8R8092@T01oOgl0SHf=0080P82000<0R8R808b<S021PH400P29RHT03@1nOWh0
T92@08:2PP1mOGd0PX:20861P@1kNg/0PX:207]kN`21PH40N7Qh08V9R@1nOWh00P1iNGT03020P800
N7Qh0861P@1hN7P0LG5a07QhN01dM7@0MWIf07EeM@1fMWH0LG5a07QhN080Lg=c0340M7Ad06a/K01Z
JVX0J6QX071`L01eMGD0LG5a06UYJ@1VIVH0LG5a07=cL`1^KVh0JFUY06e]K@1[Jf/0K6a/075aL@1_
Kfl0J6QX06UYJ@1WIfL0HF5Q06ATI01XJ6P0HV9R06][J`1SHf<0JFUY06QXJ01RHV80JFUY06=SH`1R
HV80H61P069RHP1YJFT0GEeM05iNGP1OGel0IVIV065QH@1NGUh0IVIV05YJFP1KFe/0HF5Q06=SH`1P
H600FUYJ0080HF5Q00<0Hf=S06IVIP1KFe/05`0000060=WIf@4000000@3IfMT001H0fMWI00<00000
0=WIf@3IfMT00`3IfMT0703Cdm<0L71`06ATI01XJ6P0Jf][05mOG`1SHf<0IVIV06][J`1TI6@0Jf][
06EUI@1VIVH0Fe]K05iNGP1OGel0H61P06IVIP1WIfL0L71`06QXJ01^KVh0JFUY06YZJP1[Jf/0JVYZ
06][J`1XJ6P206YZJP07075aL@1/K6`0KVi^06QXJ01cLg<0KVi^06a/K00206QXJ00K06UYJ@1XJ6P0
L71`06][J`1`L700Kfm_07EeM@1cLg<0KVi^075aL@1dM7@0NGUi06YZJP1cLg<0LG5a07YjNP1cLg<0
LG5a07AdM01hN7P0Ng]k07AdM01hN7P0MgMg07alO01cLg<0OGem0080N7Qh01h0W9bL07YjNP1mOGd0
O7al07MgM`23Ph<0P82007]kN`1iNGT0OWin0820P01kNg/0NWYj0820P01jNWX0R8R808>3P`24Q8@0
QhN707moO`23Ph<0PH610820P01nOWh0Rh^;08b<S028R8P0PH6108J6QP25QHD308^;R`0L09:BTP2@
T900RXZ:09>CT`2DU9@0Rh^;09^KV`2HV9P0UYJF09>CT`2<S8`0VIVI09jNWP2CTi<0UIFE09VIV@2J
VYX0UYJF09>CT`2IVIT0WYjN09BDU02IVIT0UiNG09nOW`2PX:00VIVI0:BTY0<0XJ6Q00<0WIfM09bL
W02TY:@00`2PX:004`2TY:@0WYjN0:ZZZP2MWId0Z:RX0:f][@2MWId0Z:RX0:BTY02QXJ40XZ:R0:FU
Y@2YZJT0Xj>S0:6QX@2[Zj/0XZ:R0:2PX02SXj<00`2PX:001@2UYJD0Vi^K09bLW02SXj<0X:2P0080
YZJV00P0WinO09bLW02PX:00V9RH09fMW@2QXJ40ZJVY09^KV`80Xj>S00@0W9bL09jNWP2OWil0V9RH
0P2CTi<02P2IVIT0Vi^K08n?S`2ATI40V9RH08^;R`2LW9`0TI6A092@T02>SXh2096AT@0908b<S02>
SXh0RXZ:08R8R02?Shl0SHf=07inOP28R8P0QXJ60080Q8B40P2:RXX00`26QXH0Q8B40820P0020820
P00@08N7Q`21PH40OGem07UiN@1mOGd0MgMg07inOP27QhL0P82007emO@1oOgl0P82007emO@1iNGT0
OWin07IfMP80N7Qh03L0KFe]07UiN@1hN7P0M7Ad07MgM`1hN7P0M7Ad071`L01WIfL0KVi^07AdM01c
Lg<0MWIf075aL@1XJ6P0IVIV07AdM01nOWh0IfMW07AdM01UIFD0K6a/06=SH`1aLG40KFe]06IVIP1_
Kfl0Hf=S06IVIP1`L700IVIV06a/K01`L700KFe]06UYJ@1]KFd0J6QX06IVIP1SHf<0J6QX06=SH`1R
HV80H61P06=SH`1VIVH0J6QX06IVIP1TI6@0IVIV06=SH`1LG5`0I6AT05YJFP1SHf<0H61P0080FEUI
00<0HF5Q061PH01NGUh05`0000060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3I
fMT03@3Bd]80IVIV065QH@1VIVH0J6QX05iNGP1PH600IFEU06IVIP1/K6`0GemO06=SH`1PH6000P1T
I6@05`1VIVH0Jf][06QXJ01WIfL0IVIV06UYJ@1]KFd0K6a/06UYJ@1SHf<0J6QX06UYJ@1dM7@0Hf=S
06e]K@1VIVH0K6a/07]kN`1cLg<0K6a/06QXJ01cLg<0KFe]0080JFUY0100Jf][06a/K01aLG40KVi^
07IfMP1cLg<0KVi^075aL@1cLg<0MWIf07EeM@1gMgL0Lg=c075aL@1bLW80L71`101iNGT0101cLg<0
MWIf07]kN`1cLg<207]kN`0;0820P01kNg/0RHV908B4Q023Ph<0OWin07UiN@22PX80N7Qh07alO01n
OWh00P20P8005@26QXH0OGem08b<S023Ph<0QhN708>3P`29RHT0Ogmo08R8R027QhL0OWin08F5Q@28
R8P0RHV908:2PP28R8P0OWin08Z:RP2;Rh/0RXZ:096AT@0208j>SP0U08^;R`2?Shl0UIFE09:BTP2K
Vi/0SXj>096AT@2CTi<0T92@09^KV`2ATI40UIFE09JFUP2IVIT0W9bL09NGU`2HV9P0VIVI09BDU02?
Shl0UIFE0:>SX`2IVIT0UiNG09VIV@2KVi/0X:2P0:NWY`2SXj<0Y:BT09jNWP2MWId0WinO0::RXP2Y
ZJT0XJ6Q0:^[Z`020:JVYP0?0:RXZ02VYZH0Zj^[0:>SX`2UYJD0XJ6Q0:FUY@2ZZZX0Zj^[0:BTY02V
YZH0XJ6Q0:BTY02VYZH0YjNW0080YZJV0P2KVi/04`2WYjL0ZJVY0:NWY`2RXZ80YZJV0:>SX`2ZZZX0
Y:BT0:JVYP2NWYh0X:2P09VIV@2HV9P0Xj>S0:6QX@2JVYX0X:2P09ZJVP2IVIT00P2MWId05`2JVYX0
XZ:R09ZJVP2GUiL0Ti>C09ZJVP2LW9`0SXj>09:BTP2<S8`0U9BD08f=S@2@T900UYJF092@T02RXZ80
T92@08F5Q@27QhL0Rh^;08J6QP28R8P0SHf=0080Q8B400T0PH6108>3P`25QHD0NWYj08V9R@2;Rh/0
PX:20861P@20P8000P23Ph<03@21PH40QhN707inOP1mOGd0P82008J6QP22PX80Ogmo07alO01iNGT0
M7Ad07]kN`1fMWH00P1iNGT02`1^KVh0MgMg06][J`1eMGD0KFe]07=cL`1aLG40Lg=c07UiN@1aLG40
Jf][0080L71`01l0Ng]k07=cL`1aLG40LG5a06UYJ@1XJ6P0K6a/075aL@1[Jf/0K6a/07=cL`1VIVH0
J6QX06][J`1UIFD0JVYZ06IVIP1[Jf/0JFUY065QH@1OGel0JFUY06][J`1XJ6P0JFUY06EUI@1RHV80
J6QX069RHP1[Jf/0H61P0080Hf=S00L0G5aL06=SH`1PH600HV9R05iNGP1KFe/0I6AT0080H61P00@0
FEUI06IVIP1HF5P0Hf=S5`0000060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3I
fMT07P3Cdm<0Hf=S06QXJ01YJFT0IVIV065QH@1[Jf/0HF5Q06ATI01XJ6P0IfMW06ATI01SHf<0JFUY
06ATI01XJ6P0JFUY06ATI01QHF40J6QX06MWI`1YJFT0Jf][06ATI01VIVH0IfMW06UYJ@1`L700JVYZ
06m_K`<0Jf][01h0I6AT079bLP1]KFd0IFEU06UYJ@1^KVh0J6QX069RHP1[Jf/0Kfm_06][J`1aLG40
Lg=c07AdM01cLg<0JVYZ075aL@1hN7P0MgMg075aL@1gMgL0Ng]k07AdM01gMgL0N7Qh07]kN`1bLW80
MWIf07QhN01kNg/207inOP0U08:2PP1nOWh0MgMg07emO@1gMgL0Ng]k07QhN023Ph<0O7al07emO@23
Ph<0Ogmo07]kN`1hN7P0NGUi08:2PP20P800OWin0820P028R8P0QXJ608:2PP23Ph<0T92@08B4Q028
R8P0Ph>308J6QP2?Shl0Q8B408^;R`29RHT0TI6A08^;R`28R8P0RXZ:08b<S00208n?S`0609JFUP2@
T900SXj>09^KV`2ATI40U9BD0P2HV9P02@2IVIT0UIFE09BDU02DU9@0UYJF0:2PX02HV9P0VIVI09nO
W`0209jNWP0309bLW02HV9P0VIVI0080WinO00T0XJ6Q0:2PX02NWYh0X:2P0:^[Z`2WYjL0YZJV0:BT
Y02YZJT00P2[Zj/02`2QXJ40Zj^[0:>SX`2XZ:P0XJ6Q0:^[Z`2SXj<0Vi^K0:VYZ@2VYZH0X:2P0080
XJ6Q00`0YZJV0:VYZ@2PX:00X:2P0::RXP2SXj<0Z:RX0:BTY02RXZ80YZJV0:FUY@2TY:@20:b/[00j
09^KV`2OWil0YJFU0:JVYP2RXZ80[:b/0:>SX`2OWil0YZJV09bLW02MWId0WYjN0:6QX@2NWYh0WinO
09NGU`2QXJ40UYJF09RHV02LW9`0V9RH09NGU`2ATI40WYjN08^;R`2DU9@0TY:B08V9R@26QXH0TI6A
0?ooo`2;Rh/0TI6A08B4Q02:RXX0Shn?08R8R02;Rh/0T92@08>3P`28R8P0RHV908^;R`28R8P0OWin
08B4Q022PX80R8R808>3P`1jNWX0Ng]k08Z:RP23Ph<0OGem08V9R@24Q8@0PH6107emO@<0NGUi00L0
NWYj07UiN@1jNWX0MgMg07]kN`1hN7P0M7Ad00<0N7Qh00D0K6a/07UiN@1hN7P0LW9b06m_K`02079b
LP0707=cL`1dM7@0L71`07AdM01`L700KFe]06QXJ00206m_K`0:06UYJ@1RHV80KFe]06UYJ@1VIVH0
J6QX06IVIP1ZJVX0KFe]06][J`80I6AT00/0IVIV06QXJ01YJFT0J6QX06][J`1SHf<0HF5Q06IVIP1T
I6@0H61P065QH@0206=SH`0=06QXJ01QHF40IVIV05iNGP1PH600GUiN05]KF`1SHf<0G5aL065QH@1L
G5`0H61P05]KF`0G000000H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@040=WIf@80
J6QX00T0IfMW06IVIP1SHf<0IFEU06MWI`1VIVH0H61P06ATI01LG5`00P1VIVH0101PH600JVYZ06IV
IP1QHF4206UYJ@0606a/K01VIVH0J6QX06UYJ@1VIVH0Jf][0P1XJ6P09`1NGUh0Jf][06UYJ@1UIFD0
K6a/06UYJ@1WIfL0KVi^071`L01PH600IVIV06e]K@1`L700IVIV06QXJ01bLW80KVi^06e]K@1cLg<0
MWIf06i^KP1`L700N7Qh07=cL`1/K6`0N7Qh07UiN@1fMWH0Lg=c071`L01jNWX0Ng]k07QhN01kNg/0
O7al08>3P`1nOWh0R8R807]kN`0207inOP0507UiN@1kNg/0OWin07]kN`23Ph<00P25QHD20820P00?
07emO@21PH40O7al08F5Q@1oOgl0QhN708:2PP25QHD0QhN708b<S024Q8@0Ph>308^;R`2?Shl0R8R8
0080S8b<00L0SHf=08N7Q`2;Rh/0SHf=092@T028R8P0Ph>300<0S8b<0P2FUYH03@2HV9P0TI6A08f=
S@2@T900UYJF09VIV@2FUYH0WIfM09VIV@2FUYH0VIVI09ZJVP2HV9P00P2PX:000`2KVi/0Xj>S0:>S
X`020:6QX@040:BTY02VYZH0XJ6Q0:FUY@80YZJV02D0ZJVY0:BTY02ZZZX0Z:RX0:ZZZP2TY:@0Zj^[
0:BTY02/[:`0Y:BT0:ZZZP2WYjL0Z:RX09jNWP2QXJ40Z:RX0:b/[02ZZZX0YJFU0:6QX@2RXZ80Z:RX
0:b/[02TY:@0ZJVY0:JVYP2[Zj/0YJFU0:BTY02[Zj/0XJ6Q0:f][@2[Zj/0Y:BT0:JVYP2QXJ40XZ:R
0080YZJV00P0WYjN0:6QX@2PX:00XJ6Q0:>SX`2QXJ40Xj>S09bLW080WYjN02L0WinO0:2PX02KVi/0
UYJF0:2PX02JVYX0TY:B08j>SP2GUiL0UYJF09RHV026QXH0UYJF07inOP2;Rh/0T92@09BDU02<S8`0
TI6A09:BTP26QXH0RXZ:08^;R`27QhL0QXJ608>3P`1nOWh0R8R808J6QP24Q8@0Ogmo08V9R@26QXH0
Q8B40861P@25QHD0R8R808F5Q@24Q8@00P20P8003@1iNGT0O7al07IfMP1fMWH0NGUi07]kN`1fMWH0
NGUi07emO@1nOWh0Rh^;07EeM@1iNGT00P1]KFd05P1dM7@0LG5a07IfMP1^KVh0LG5a07EeM@1_Kfl0
KVi^07QhN01^KVh0Jf][071`L01^KVh0J6QX06i^KP1`L700JVYZ06e]K@1`L700KFe]06ATI01`L702
06YZJP0306ATI01/K6`0K6a/0080JFUY00/0I6AT069RHP1^KVh0I6AT061PH01NGUh0H61P06IVIP1Y
JFT0I6AT06QXJ002065QH@0806QXJ01PH600HF5Q06IVIP1SHf<0I6AT05eMG@1PH60205iNGP0305aL
G0000000000001D000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00T0
hN7Q06i^KP1VIVH0K6a/065QH@1VIVH0LG5a06IVIP1QHF400P1TI6@05@1NGUh0IVIV06ATI01XJ6P0
IFEU06IVIP1ZJVX0J6QX06ATI01QHF40JFUY061PH01/K6`0Hf=S06QXJ01TI6@0J6QX06UYJ@1[Jf/0
L71`06EUI@0206][J`0306a/K01[Jf/0Jf][0080IVIV03<0Lg=c06YZJP1/K6`0LG5a06a/K01bLW80
KVi^06UYJ@1aLG40L71`06i^KP1hN7P0MWIf07MgM`1kNg/0N7Qh07MgM`1hN7P0MWIf07UiN@1dM7@0
MgMg07QhN01fMWH0O7al0861P@1iNGT0N7Qh08>3P`1lO7`0N7Qh07MgM`1cLg<0PH6107QhN026QXH0
P82007inOP20P800N7Qh07emO@21PH40P82008B4Q021PH40RHV90861P@22PX80PH6108j>SP25QHD0
0P2;Rh/01@2=SHd0T92@092@T024Q8@0S8b<0080SHf=03L0R8R809>CT`28R8P0TI6A092@T02ATI40
S8b<09^KV`2DU9@0VIVI09JFUP2?Shl0V9RH0:2PX02CTi<0XJ6Q09VIV@2LW9`0UiNG09bLW02JVYX0
X:2P0:ZZZP2XZ:P0YjNW0:BTY02OWil0[:b/0:2PX02QXJ40X:2P0:^[Z`2QXJ40ZZZZ0:BTY02SXj<0
[:b/0:^[Z`2/[:`0[Zj^0:JVYP2XZ:P0[Zj^0:RXZ02^[Zh0/;2`0:ZZZP2WYjL0X:2P0:NWY`2UYJD0
ZJVY0:j^[P2TY:@0YJFU0080ZJVY00H0Z:RX0:VYZ@2UYJD0YZJV0:RXZ02a/K420:ZZZP80[Zj^00X0
Xj>S0:6QX@2QXJ40Y:BT0:>SX`2OWil0Xj>S0:VYZ@2NWYh0WinO0P2PX:001`2RXZ80Y:BT0:f][@2A
TI40YZJV09JFUP2LW9`00P2IVIT05@2CTi<0W9bL09ZJVP2FUYH0VIVI09JFUP2JVYX0T92@09VIV@2A
TI40U9BD08f=S@2CTi<0T92@08b<S02ATI40Ti>C08j>SP2;Rh/0S8b<08B4Q00208^;R`0608Z:RP27
QhL0OWin0861P@2<S8`0QXJ60P21PH402`28R8P0Q8B408N7Q`20P800OGem07UiN@1lO7`0N7Qh07in
OP20P800Ng]k0080Ogmo0180NWYj07MgM`1lO7`0NGUi07]kN`1eMGD0LG5a06e]K@1aLG40M7Ad07Qh
N01/K6`0Jf][075aL@1bLW80K6a/06IVIP1^KVh206][J`0306i^KP1`L700GUiN0080Kfm_01T0J6QX
06YZJP1YJFT0KFe]06UYJ@1SHf<0IfMW06a/K01VIVH0Hf=S06UYJ@1PH600IfMW06IVIP1SHf<0J6QX
06ATI01RHV80IFEU06UYJ@1WIfL0J6QX061PH01YJFT0Hf=S0080H61P00P0GemO069RHP1MGEd0IVIV
06=SH`1MGEd0GUiN06ATI1L000001P3IfMT100000040fMWI000F0=WIf@8000001@3IfMT0601^KVh0
JFUY06IVIP1WIfL0HF5Q06IVIP1XJ6P0JVYZ06MWI`1ZJVX0Jf][069RHP1]KFd0IfMW06e]K@1cLg<0
KFe]06][J`1/K6`0I6AT06=SH`1RHV80JFUY06][J`80K6a/00L0IFEU06e]K@1^KVh0Jf][06a/K01V
IVH0IFEU0080J6QX00L0KFe]06ATI01/K6`0IVIV06UYJ@1_Kfl0K6a/0080KVi^00`0MGEe06e]K@1_
Kfl0KVi^07=cL`1eMGD0MgMg07QhN01dM7@0NGUi07IfMP1cLg<207UiN@0707QhN01fMWH0N7Qh0820
P01fMWH0OGem0820P00207]kN`<0O7al00`0Ng]k08R8R01jNWX0RHV90820P01iNGT0OGem07inOP1o
Ogl0P82008F5Q@27QhL20861P@0708V9R@21PH40R8R808b<S028R8P0SHf=08n?S`0208b<S00E08J6
QP2<S8`0R8R808^;R`2HV9P0SXj>08V9R@2>SXh0UIFE08n?S`2;Rh/0UYJF09BDU02PX:00TI6A09VI
V@2HV9P0XZ:R09NGU`2QXJ40V9RH0080Vi^K0200WIfM0::RXP2LW9`0XJ6Q0::RXP2PX:00YjNW0:2P
X02ZZZX0ZJVY09jNWP2QXJ40ZJVY0:6QX@2SXj<0[jn_0:VYZ@2XZ:P0/K6a0:b/[02[Zj/0[:b/0:>S
X`2^[Zh0YZJV0:ZZZP2TY:@0YZJV0:f][@2XZ:P0Zj^[0:b/[080YZJV00@0Y:BT0;>c/`2YZJT0/;2`
0`2/[:`0102[Zj/0/K6a0:JVYP2a/K420:VYZ@040;6a/@2^[Zh0WYjN0:RXZ080XZ:R00<0Z:RX0::R
XP2PX:000P2QXJ404P2MWId0WinO0:b/[02MWId0Y:BT09^KV`2TY:@0Zj^[0:>SX`2TY:@0UYJF0:2P
X02LW9`0X:2P09^KV`2IVIT0TY:B09ZJVP80U9BD00T0TI6A092@T02FUYH0T92@08f=S@2:RXX0Rh^;
08n?S`2BTY800P2CTi<01@26QXH0QhN708>3P`23Ph<0RHV90080QhN700h0PX:208N7Q`27QhL0R8R8
08N7Q`2;Rh/0Q8B407emO@1iNGT0PH6107YjNP1nOWh0OGem07YjNP<0O7al00<0MgMg079bLP1hN7P0
0P1fMWH0101dM7@0Ng]k07=cL`1fMWH206i^KP0H075aL@1dM7@0J6QX071`L01ZJVX0MWIf071`L01/
K6`0KVi^06UYJ@1`L700Lg=c07QhN01/K6`0Jf][071`L01^KVh0IfMW06YZJP1[Jf/0JVYZ06UYJ@1a
LG40Lg=c0`1VIVH206ATI00@06UYJ@1[Jf/0IVIV06YZJP1SHf<0IVIV05iNGP1TI6@0Hf=S06EUI@1P
H600HF5Q06ATI01PH600Fe]K05IFEP80GUiN00<0IFEU065QH@1PH6005`0000050=WIf@8000000@3I
fMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT01`3UiND0Hf=S05iNGP1XJ6P0Hf=S06ATI01YJFT0
0P1SHf<206UYJ@0I06=SH`1YJFT0IVIV06][J`1QHF40IFEU06UYJ@1WIfL0Jf][06e]K@1YJFT0Jf][
06QXJ01_Kfl0JVYZ075aL@1bLW80I6AT06e]K@1YJFT0KVi^071`L01/K6`0JVYZ06ATI00206UYJ@1C
06a/K01ZJVX0LG5a075aL@1/K6`0Lg=c06][J`1dM7@0Lg=c075aL@1`L700Kfm_07=cL`1_Kfl0N7Qh
07IfMP1dM7@0Ph>3075aL@1fMWH0NGUi079bLP1fMWH0NWYj07UiN@23Ph<0PH6107inOP20P800NGUi
07YjNP1_Kfl0NGUi07inOP26QXH0OWin0820P023Ph<0QhN707alO01mOGd0Ph>30861P@27QhL0RHV9
08N7Q`26QXH0Q8B408n?S`29RHT0QhN708b<S02EUID0QXJ6096AT@28R8P0SHf=08V9R@2:RXX0QhN7
09JFUP2@T900RHV908j>SP2KVi/0T92@09RHV02DU9@0TI6A09NGU`2KVi/0VIVI09ZJVP2SXj<0Vi^K
09:BTP2GUiL0WYjN09JFUP2EUID0WYjN0:RXZ02KVi/00P2YZJT0302TY:@0WYjN0:NWY`2PX:00YJFU
0:j^[P2YZJT0/K6a0:JVYP2WYjL0YZJV0:b/[080ZZZZ01D0/[:b0:j^[P2ZZZX0ZZZZ0:RXZ02ZZZX0
[:b/0:VYZ@2_[jl0/;2`0:VYZ@2`/;00Zj^[0:b/[02YZJT0[jn_0:VYZ@2`/;00]kNg0:^[Z`2/[:`0
0P2WYjL20:b/[080ZZZZ01@0/k>c0;Fe]@2_[jl0ZZZZ0:>SX`2[Zj/0Y:BT0::RXP2XZ:P0[:b/0::R
XP2UYJD0YZJV09^KV`2OWil0XJ6Q0:NWY`2QXJ40Z:RX0:2PX0<0WYjN00d0X:2P09NGU`2HV9P0U9BD
09NGU`2HV9P0Vi^K0:FUY@2@T900UYJF092@T02DU9@0SXj>0080Rh^;0100RHV909RHV02FUYH0S8b<
08J6QP29RHT0QXJ608N7Q`2;Rh/0Ph>308V9R@25QHD0PH6108V9R@20P800QXJ60`1oOgl00`1nOWh0
QXJ608>3P`0207inOP0=07]kN`1jNWX0QHF507AdM01nOWh0NGUi07IfMP1iNGT0N7Qh07=cL`1aLG40
NWYj07=cL`03071`L00T06a/K01_Kfl0Lg=c071`L01/K6`0KFe]06a/K01dM7@0LG5a06i^KP1aLG40
K6a/06i^KP1[Jf/0KVi^06][J`1ZJVX0LW9b06UYJ@1TI6@0JFUY06ATI01VIVH0I6AT071`L01TI6@0
Jf][06a/K01XJ6P0IfMW06ATI01YJFT0IfMW06YZJP1UIFD0IVIV0P1RHV802`1TI6@0HF5Q05mOG`1R
HV80HF5Q06QXJ01RHV80GEeM06IVIP1MGEd0FUYJ01L000001P3IfMT100000040fMWI000F0=WIf@03
0000003IfMT0fMWI00<0fMWI00D0i>CT06UYJ@1WIfL0HF5Q06e]K@0206IVIP0P069RHP1TI6@0I6AT
06IVIP1[Jf/0JVYZ06UYJ@1XJ6P0KFe]06UYJ@1QHF40JFUY06YZJP1UIFD0KFe]06a/K01UIFD0IVIV
06][J`1YJFT0LG5a06i^KP1VIVH0I6AT06][J`1_Kfl0KFe]06a/K01PH600HF5Q06QXJ01WIfL206UY
J@0>071`L01cLg<0LG5a06i^KP1YJFT0Kfm_07IfMP1eMGD0Lg=c071`L01dM7@0Ng]k07UiN@1hN7P3
07UiN@1607IfMP1lO7`0NGUi07]kN`1fMWH0M7Ad07QhN01jNWX0PH6107emO@1kNg/0PH6107emO@1o
Ogl0Q8B40861P@1nOWh0P82007UiN@21PH40Ogmo08>3P`1hN7P0R8R808>3P`24Q8@0PH6108V9R@23
Ph<0R8R808^;R`2FUYH0UIFE0:BTY02GUiL0U9BD08j>SP2DU9@0Rh^;096AT@2DU9@0Rh^;09FEU@2I
VIT0Ti>C09bLW02KVi/0V9RH0:2PX02NWYh0Vi^K09bLW02IVIT0TI6A09BDU02MWId0WinO09VIV@2S
Xj<0Vi^K0:>SX`2NWYh0ZJVY0:JVYP2SXj<0XZ:R0:b/[02RXZ80/K6a0::RXP@0[:b/0140Zj^[0;:b
/P2^[Zh0/K6a0:j^[P2h^;P0/K6a0;:b/P2XZ:P0];Bd0:j^[P2e]KD0YZJV0:ZZZP2YZJT0[jn_0;2`
/0020;Rh^00X0;2`/02h^;P0[:b/0;Zj^P2f][H0]KFe0;Vi^@2YZJT0/;2`0;:b/P2[Zj/0/k>c0:ZZ
ZP2_[jl0/k>c0:VYZ@2][Jd0Y:BT0:VYZ@2^[Zh0ZZZZ0:^[Z`2ZZZX0XJ6Q0:FUY@2/[:`0YZJV0:NW
Y`2[Zj/0YZJV0:RXZ02QXJ40X:2P09^KV`2NWYh0XJ6Q09JFUP2SXj<0Vi^K09VIV@80V9RH01D0TI6A
09:BTP2OWil0VIVI09:BTP2ATI40Shn?096AT@2=SHd0U9BD09RHV02=SHd0TI6A08R8R02;Rh/0TY:B
08Z:RP2<S8`0QXJ6096AT@22PX800P26QXH00`22PX80QHF507moO`020820P00608V9R@1kNg/0Ogmo
07IfMP1mOGd0PH610P1kNg/04@1fMWH0NWYj07IfMP1dM7@0Lg=c07]kN`1iNGT0M7Ad079bLP1aLG40
Lg=c07IfMP1aLG40L71`06a/K01^KVh0Lg=c0080KVi^00h0L71`079bLP1bLW80Lg=c06i^KP1]KFd0
IVIV06e]K@1XJ6P0K6a/06QXJ01VIVH0J6QX06EUI@80KVi^00L0IVIV06UYJ@1TI6@0JVYZ06UYJ@1^
KVh0J6QX0080IVIV0180HV9R06=SH`1SHf<0I6AT06][J`1NGUh0JFUY06=SH`1ZJVX0IFEU06=SH`1Q
HF40H61P065QH@1LG5`0GUiN061PH01WIfLG000000H0fMWI0@0000010=WIf@005P3IfMT00`000000
fMWI0=WIf@030=WIf@0Z0=gMg@1RHV80Hf=S06=SH`1PH600Hf=S06MWI`1VIVH0JFUY06m_K`1SHf<0
IFEU06QXJ01PH600I6AT06QXJ01VIVH0IfMW06a/K01^KVh0L71`06][J`1TI6@0K6a/06ATI01WIfL0
IVIV079bLP1ZJVX0K6a/07=cL`1^KVh0LG5a06][J`1SHf<0HF5Q06ATI01SHf<0K6a/071`L01XJ6P0
LG5a0P1YJFT0101`L700JFUY06][J`1hN7P207UiN@0F07=cL`1dM7@0O7al07]kN`1oOgl0MgMg07Yj
NP1`L700Ogmo07QhN01jNWX0Ng]k07AdM01iNGT0OWin08>3P`1lO7`0Ng]k0820P01jNWX0OWin07Ui
N@80PH6103<0Ng]k0820P01nOWh0PH6108:2PP1oOgl0QhN708>3P`26QXH0PX:208N7Q`25QHD0Shn?
096AT@2<S8`0U9BD09VIV@2KVi/0TY:B08V9R@2>SXh0UYJF08b<S02IVIT0Shn?09>CT`2<S8`0UIFE
09RHV02GUiL0W9bL09RHV02DU9@0Xj>S09RHV02FUYH0VIVI09FEU@2IVIT0V9RH09^KV`2FUYH0WinO
09FEU@2IVIT0WYjN0:2PX02UYJD0Xj>S0:JVYP2`/;000P2VYZH0H@2YZJT0XZ:R0:n_[`2WYjL0[jn_
0;:b/P2`/;00[Zj^0:n_[`2g]kL0/k>c0;2`/02XZ:P0/;2`0:j^[P2d];@0^KVi0:j^[P2/[:`0^[Zj
0;:b/P2/[:`0Y:BT0;Zj^P2`/;00[jn_0;Rh^02n_[h0][Jf0;Rh^02d];@0Zj^[0:j^[P2`/;00/k>c
0;2`/02b/[80/;2`0:n_[`2h^;P0/[:b0;Rh^02a/K40Y:BT0:b/[02^[Zh0[:b/0:NWY`2SXj<0XJ6Q
0:FUY@2TY:@0ZJVY0:2PX02ZZZX0YZJV09bLW02TY:@0WYjN09bLW02WYjL0WinO0:BTY02NWYh0Vi^K
09RHV02QXJ40UiNG09ZJVP2HV9P0W9bL08n?S`2CTi<0UYJF092@T02?Shl0UIFE08^;R`2DU9@0T92@
08R8R02:RXX0Rh^;096AT@24Q8@0Ti>C08j>SP2=SHd0SXj>08B4Q028R8P0OWin08B4Q020P800Ph>3
07YjNP1iNGT00P20P8005@1hN7P0OGem0820P020P800MWIf07alO01aLG40MGEe07UiN@1gMgL0M7Ad
06][J`1_Kfl0N7Qh07IfMP1`L700LW9b06m_K`1/K6`0KVi^075aL@0206i^KP04075aL@1/K6`0K6a/
075aL@80J6QX0180KVi^06a/K01UIFD0J6QX06][J`1TI6@0K6a/06QXJ01]KFd0K6a/06][J`1VIVH0
I6AT06MWI`1/K6`0IFEU06][J`1PH60206a/K00>06IVIP1TI6@0HF5Q06UYJ@1TI6@0IFEU061PH01Q
HF40I6AT05mOG`1NGUh0I6AT05iNGP1GEeL205iNGQL000001P3IfMT100000040fMWI000F0=WIf@03
0000003IfMT0fMWI00<0fMWI00@0hN7Q06ATI01TI6@0Hf=S0P1XJ6P09@1YJFT0KVi^06IVIP1YJFT0
HV9R06UYJ@1XJ6P0JVYZ06UYJ@1XJ6P0Hf=S06QXJ01YJFT0JVYZ06a/K01^KVh0Hf=S061PH01[Jf/0
K6a/06][J`1^KVh0IFEU06][J`1]KFd0LG5a071`L01UIFD0H61P06ATI01ZJVX0IVIV071`L01bLW80
Jf][07AdM01bLW800P1TI6@0=@1/K6`0L71`06a/K01]KFd0Lg=c07IfMP20P800O7al07QhN021PH40
Ng]k07UiN@1hN7P0O7al07emO@1lO7`0Ng]k07IfMP1oOgl0Lg=c07QhN021PH40Ph>30861P@20P800
Ng]k08>3P`25QHD0Ph>308N7Q`24Q8@0P82008>3P`2ATI40RHV908R8R026QXH0SXj>08>3P`29RHT0
QXJ608f=S@29RHT0TI6A09bLW02BTY80VIVI092@T02>SXh0Ti>C08Z:RP2>SXh0TI6A0080Ti>C01T0
Shn?08j>SP2FUYH0UYJF09FEU@2HV9P0UYJF09:BTP2<S8`0SXj>09NGU`2JVYX0UiNG09FEU@2FUYH0
Ti>C09jNWP2JVYX0U9BD09RHV02TY:@0XZ:R0:b/[02SXj<0ZJVY0080[Jf]00@0[Zj^0:b/[02[Zj/0
YjNW0P2^[Zh0102i^KT0/k>c0;Bd]02`/;020;6a/@0J0:j^[P2c/k<0/[:b0;>c/`2`/;00/k>c0;Zj
^P2YZJT0/k>c0;Vi^@2j^[X0/k>c0;Rh^02f][H0`L710;Bd]02`/;00]kNg0:f][@2^[Zh0_[jn0;Fe
]@2YZJT0][Jf0;Bd]02`/;020:b/[0090;>c/`2_[jl0ZJVY0;2`/02UYJD0/;2`0:f][@2ZZZX0[Jf]
00<0ZJVY00H0X:2P0:NWY`2QXJ40YJFU0:JVYP2[Zj/20:2PX0030:>SX`2PX:00WYjN0080Vi^K00D0
VYZJ09FEU@2NWYh0TY:B09^KV`0209RHV00F092@T02DU9@0RHV909ZJVP2IVIT0UiNG08^;R`27QhL0
RXZ:08V9R@2?Shl0PX:208J6QP2GUiL0Rh^;08j>SP2@T900PH6108^;R`25QHD0P8200861P@80P820
00<0O7al07]kN`1mOGd00P1nOWh01@20P800M7Ad07inOP1fMWH0Lg=c0080N7Qh00l0Ng]k07QhN01k
Ng/0Kfm_071`L01hN7P0MGEe071`L01bLW80MWIf06a/K01aLG40Lg=c06m_K`1^KVh00P1`L7004@1_
Kfl0Jf][071`L01]KFd0LW9b06IVIP1WIfL0J6QX075aL@1]KFd0JVYZ06UYJ@1ZJVX0JFUY06EUI@1S
Hf<0J6QX0080JFUY00D0K6a/06=SH`1XJ6P0JFUY06QXJ00206ATI00906QXJ01SHf<0J6QX05mOG`1M
GEd0H61P05mOG`1TI6@0H61P00<0G5aL00<0HF5Q0000000000005@0000060=WIf@4000000@3IfMT0
01H0fMWI00<000000=WIf@3IfMT00`3IfMT0?03Lg=`0JFUY06IVIP1VIVH0HF5Q06ATI01XJ6P0JVYZ
06EUI@1[Jf/0K6a/06][J`1VIVH0JFUY06][J`1/K6`0LG5a06=SH`1[Jf/0I6AT071`L01XJ6P0L71`
06QXJ01VIVH0JFUY06QXJ01]KFd0Jf][06i^KP1bLW80Kfm_06e]K@1TI6@0J6QX06UYJ@1SHf<0KVi^
06UYJ@1`L700Lg=c06MWI`1dM7@0KVi^06a/K01SHf<0Jf][07YjNP1lO7`0LG5a07AdM01iNGT0LW9b
07alO022PX80NGUi07QhN01gMgL0MWIf07MgM`80Ng]k0100O7al07inOP20P800Ogmo07inOP1kNg/0
N7Qh07UiN@1jNWX0QHF50861P@1nOWh0Ng]k07alO022PX80PH610P28R8P03025QHD0PH6108J6QP26
QXH0RXZ:08B4Q02:RXX0S8b<08j>SP2@T900S8b<092@T080TY:B00X0U9BD09RHV02ATI40UYJF09BD
U02JVYX0TI6A09RHV02KVi/0SHf=0`2KVi/00`2HV9P0T92@09:BTP0209>CT`0509FEU@2HV9P0UiNG
0:2PX02TY:@00P2RXZ80202MWId0W9bL0::RXP2VYZH0/k>c0:^[Z`2a/K40ZZZZ0P2[Zj/0502`/;00
];Bd0;:b/P2/[:`0Zj^[0;Jf]P2e]KD0][Jf0:n_[`2f][H0];Bd0;Vi^@2d];@0^;Rh0;2`/02a/K40
]kNg0;2`/02a/K40]KFe0P2j^[X0602n_[h0[Jf]0;>c/`2m_Kd0^;Rh0;Fe]@2f][H0_;bl0;>c/`2f
][H0Zj^[0;Zj^P2a/K40[:b/0;2`/02d];@0/K6a0:j^[P2][Jd0ZJVY0;2`/02^[Zh0ZJVY0:JVYP80
[:b/0P2[Zj/01@2PX:00[:b/0:JVYP2SXj<0YJFU0080ZJVY03@0X:2P09bLW02UYJD0Y:BT09jNWP2Q
XJ40U9BD09VIV@2SXj<0VYZJ09^KV`2>SXh0VIVI09:BTP2@T900WIfM09RHV02?Shl0Ti>C096AT@2>
SXh0Ti>C09BDU02:RXX0Ti>C08^;R`2<S8`0T92@09JFUP2HV9P0SHf=08b<S027QhL0Q8B407alO024
Q8@0NGUi07inOP20P800NGUi07emO@1nOWh0Ng]k0820P01kNg/0NWYj07UiN@1hN7P0MgMg07QhN01c
Lg<0NGUi0P1cLg<04@1fMWH0M7Ad07UiN@1dM7@0L71`075aL@1`L700KVi^06a/K01[Jf/0KFe]07=c
L`1/K6`0Jf][071`L01[Jf/0JFUY0080Jf][0180KVi^07EeM@1cLg<0IVIV06UYJ@1SHf<0IfMW069R
HP1WIfL0HF5Q06UYJ@1VIVH0KVi^06][J`1VIVH0H61P06ATI01QHF4206=SH`0606MWI`1NGUh0HV9R
05eMG@1^KVh0Hf=S0P1PH600101LG5`0HF5Q06=SH`1PH60G000000H0fMWI0@0000010=WIf@005P3I
fMT00`000000fMWI0=WIf@030=WIf@050=cLg01VIVH0Hf=S06ATI01YJFT00P1VIVH04P1[Jf/0I6AT
06MWI`1[Jf/0L71`06UYJ@1QHF40J6QX06=SH`1YJFT0IVIV06MWI`1VIVH0JVYZ06=SH`1UIFD0Jf][
06i^KP80L71`01D0Jf][06UYJ@1XJ6P0IVIV06m_K`1bLW80IVIV06QXJ01VIVH0L71`07=cL`1[Jf/0
Lg=c06a/K01^KVh0K6a/06i^KP1YJFT0Jf][075aL@1`L7000P1kNg/05@1jNWX0NGUi0861P@1hN7P0
OGem07alO01jNWX0OWin07QhN01mOGd0P82007AdM01mOGd0LG5a07]kN`23Ph<0Ng]k07MgM`1nOWh0
Ng]k07emO@020861P@0Q07alO020P800OWin0861P@22PX80PH6108R8R029RHT0R8R808N7Q`2=SHd0
Rh^;08R8R02ATI40TY:B08V9R@2@T900TI6A08f=S@24Q8@0UYJF08j>SP2BTY80UiNG09VIV@2>SXh0
T92@0:2PX02;Rh/0UiNG09>CT`2KVi/0Ti>C0080TI6A0140UIFE09>CT`2ATI40Ti>C09BDU02RXZ80
Xj>S0:BTY02SXj<0Y:BT0:JVYP2LW9`0WIfM0:2PX02[Zj/0/;2`0:b/[0020:j^[P030;>c/`2d];@0
[:b/0080^;Rh00@0^KVi0;2`/02e]KD0_Kfm0P2h^;P00`2j^[X0]kNg0;Bd]0030;Vi^@80/k>c00H0
];Bd0;bl_02i^KT0^[Zj0;no_`2g]kL20<?3``070;^k^`2g]kL0][Jf0;Fe]@2f][H0]KFe0;Jf]P02
0;Zj^P0>0;Vi^@2`/;00]kNg0;Ng]`2`/;00[Jf]0;2`/02^[Zh0][Jf0:b/[02[Zj/0/;2`0:f][@2Y
ZJT20:^[Z`060:j^[P2NWYh0Y:BT09NGU`2PX:00WYjN0P2TY:@02P2UYJD0WYjN09^KV`2QXJ40X:2P
09^KV`2GUiL0W9bL0:2PX02CTi<309RHV00L09>CT`2FUYH0S8b<08f=S@2ATI40S8b<08f=S@27QhL0
RHV9092@T02>SXh0QhN708^;R`2CTi<0TI6A09>CT`2@T900Shn?08:2PP26QXH0PH6108>3P`1nOWh0
PX:20820P023Ph<0O7al07emO@80O7al00/0L71`07]kN`1iNGT0Lg=c07]kN`1eMGD0O7al075aL@1d
M7@0LW9b071`L002075aL@0L07=cL`1fMWH0N7Qh07UiN@1eMGD0KVi^075aL@1/K6`0KVi^071`L01]
KFd0K6a/06e]K@1[Jf/0LG5a06i^KP1_Kfl0MWIf06ATI01`L700JFUY06=SH`1[Jf/0K6a/06UYJ@1Z
JVX0KFe]069RHP80I6AT0180K6a/06ATI01QHF40JFUY05mOG`1PH600IVIV065QH@1UIFD0Hf=S065Q
H@1PH600Hf=S05]KF`1SHf<0GUiN05]KF`1OGelG000000H0fMWI0@0000010=WIf@005P3IfMT00`00
0000fMWI0=WIf@030=WIf@030=_Kf`1PH600IfMW0080GemO00X0HV9R05mOG`1XJ6P0JFUY06QXJ01a
LG40I6AT06UYJ@1TI6@0HV9R0P1ZJVX0201LG5`0Kfm_06YZJP1^KVh0I6AT06EUI@1ZJVX0K6a/0P1`
L7001P1ZJVX0Lg=c06a/K01]KFd0M7Ad06i^KP80IVIV00@0J6QX06YZJP1^KVh0I6AT0P1^KVh02@1Y
JFT0JVYZ06][J`1^KVh0JVYZ075aL@1eMGD0O7al07IfMP0207QhN00>07=cL`1hN7P0LG5a07=cL`1k
Ng/0MgMg0820P01aLG40N7Qh07IfMP1lO7`0N7Qh07moO`23Ph<207inOP0>0820P024Q8@0O7al07Yj
NP28R8P0QHF507MgM`21PH40PX:208B4Q020P800Rh^;08J6QP2;Rh/208f=S@0A08R8R029RHT0SXj>
08^;R`2@T900QhN708n?S`2ATI40S8b<08j>SP2EUID0UiNG09BDU02HV9P0Ti>C096AT@2FUYH00P2E
UID05P2KVi/0U9BD09BDU02EUID0TY:B096AT@2CTi<0V9RH09JFUP2OWil0X:2P0:VYZ@2[Zj/0Xj>S
0:RXZ02QXJ40X:2P0:6QX@2YZJT0/k>c0:RXZ02^[Zh20;Bd]00=0;>c/`2a/K40]kNg0;Zj^P2d];@0
/k>c0;Fe]@2m_Kd0^KVi0;Bd]02k^k/0`L710;Rh^0020;Vi^@0I0;Zj^P2n_[h0/k>c0;6a/@2l_;`0
^KVi0;Ng]`2o_kl0];Bd0;Rh^030`<00aLG50;Rh^02n_[h0_Kfm0;:b/P2f][H0^;Rh0;jn_P2l_;`0
][Jf0;bl_02n_[h0ZZZZ0;^k^`020;Rh^00<0;2`/02n_[h0/K6a0;Bd]02[Zj/0[Zj^0;2`/02ZZZX0
[:b/0:RXZ02[Zj/0[Zj^0P2SXj<05@2UYJD0Zj^[0:BTY02UYJD0XZ:R09VIV@2NWYh0YJFU0:2PX02N
WYh0X:2P09ZJVP2LW9`0Vi^K096AT@2FUYH0Ti>C09NGU`2DU9@0UiNG092@T00209RHV00=09FEU@2>
SXh0Rh^;08N7Q`2@T900Q8B408Z:RP2GUiL0PX:209>CT`24Q8@0QHF50861P@0208B4Q01608N7Q`24
Q8@0Q8B408Z:RP1oOgl0OWin07YjNP1lO7`0MWIf07EeM@1kNg/0NGUi07QhN01iNGT0M7Ad07=cL`1j
NWX0LW9b07UiN@1fMWH0L71`075aL@1ZJVX0OWin06e]K@1`L700KVi^07=cL`1bLW80Lg=c06i^KP1a
LG40L71`07MgM`1^KVh0K6a/06MWI`1YJFT0K6a/075aL@1^KVh0Lg=c06m_K`1[Jf/0J6QX06i^KP1/
K6`0IFEU06IVIP1TI6@0JFUY06EUI@1VIVH0H61P06EUI@1XJ6P0I6AT05iNGP1YJFT0I6AT06QXJ01S
Hf<0GUiN06IVIP1IFET0IVIV061PH01VIVH0HF5Q061PH1L000001P3IfMT100000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI00L0d];B05UIF@1PH600GemO06UYJ@1OGel0I6AT00<0JFUY00H0
Jf][06MWI`1QHF40J6QX06EUI@1]KFd206QXJ00606][J`1XJ6P0Kfm_06MWI`1VIVH0KVi^0P1UIFD0
<`1SHf<0JVYZ06i^KP1YJFT0JVYZ06QXJ01`L700Jf][06i^KP1QHF40JFUY06IVIP1YJFT0KFe]06YZ
JP1YJFT0KVi^071`L01YJFT0KVi^07EeM@1fMWH0Ng]k07AdM01eMGD0LW9b07UiN@1cLg<0Ng]k07If
MP1dM7@0Q8B407YjNP1nOWh0P82007alO01hN7P0NGUi07inOP1lO7`0Ogmo07IfMP1nOWh0P82007in
OP20P800PH6108J6QP2;Rh/0OGem08B4Q00208J6QP0908N7Q`2=SHd0QhN708J6QP28R8P0T92@08V9
R@2=SHd0TI6A0080S8b<01h0R8R808f=S@2ATI40SXj>09VIV@2@T900Shn?09^KV`2FUYH0TI6A09RH
V02EUID0W9bL096AT@2HV9P0VIVI09RHV02LW9`0Ti>C09^KV`2HV9P0VIVI09ZJVP2QXJ40Z:RX0:FU
Y@2VYZH0ZJVY0:j^[P2IVIT20:>SX`0G0:^[Z`2WYjL0];Bd0:^[Z`2b/[80^;Rh0;>c/`2k^k/0^;Rh
0<30`02l_;`0_[jn0;Zj^P2f][H0^;Rh0;jn_P2h^;P0^k^k0;jn_P31`L40_[jn0;^k^`2h^;P00P2g
]kL06`2a/K40][Jf0;jn_P36a/H0`<300;jn_P2m_Kd0a/K60;bl_030`<00^k^k0;fm_@2f][H0_kno
0;Vi^@2n_[h0]KFe0;no_`30`<00];Bd0;Rh^030`<00/K6a0;Ng]`2f][H0/;2`0:ZZZP020;>c/`0f
0;Vi^@2[Zj/0/K6a0:f][@2XZ:P0YJFU0:VYZ@2/[:`0XJ6Q0:VYZ@2XZ:P0XZ:R09fMW@2UYJD0WYjN
09fMW@2IVIT0W9bL09>CT`2ATI40W9bL09fMW@2>SXh0VIVI09FEU@2IVIT0TY:B08n?S`2DU9@0T92@
08f=S@2<S8`0SHf=096AT@28R8P0SXj>092@T02>SXh0RXZ:08V9R@25QHD0T92@08N7Q`22PX80P820
08Z:RP21PH40Ph>308N7Q`1oOgl0O7al07IfMP23Ph<0OGem0P20P8004`1iNGT0MWIf07=cL`1hN7P0
MGEe07alO01cLg<0K6a/07UiN@1aLG40Kfm_07=cL`1aLG40Lg=c07IfMP1iNGT0LW9b06a/K01_Kfl0
0P1aLG40301/K6`0LW9b06UYJ@1/K6`0LG5a071`L01/K6`0J6QX07IfMP1iNGT0LG5a06IVIP80K6a/
00L0JFUY06IVIP1[Jf/0K6a/069RHP1TI6@0IVIV0080Hf=S00l0I6AT06=SH`1WIfL0GEeM06YZJP1S
Hf<0I6AT061PH01KFe/0H61P06QXJ01TI6@0HV9R06QXJ01PH6005`0000060=WIf@4000000@3IfMT0
00030=WIf@000000000000<000000P3IfMT2000000@0fMWI0P0000060=WIf@030000003IfMT0fMWI
00<0fMWI01L0f=SH05YJFP1LG5`0Hf=S059BDP1NGUh0GemO06UYJ@1[Jf/0IfMW06e]K@1XJ6P0JVYZ
06IVIP1[Jf/0J6QX06IVIP1UIFD0J6QX06UYJ@1cLg<0JFUY071`L00206UYJ@0306][J`1TI6@0K6a/
0080JVYZ01/0IVIV06i^KP1UIFD0K6a/06IVIP1ZJVX0KVi^06UYJ@1^KVh0IFEU06a/K01WIfL0K6a/
06e]K@1/K6`0Kfm_079bLP1aLG40NWYj07IfMP1kNg/0MWIf07alO01jNWX0MGEe07UiN@21PH400P1i
NGT07020P800NGUi075aL@1iNGT0Lg=c07alO020P800Ph>30861P@1lO7`0PX:20861P@25QHD0QXJ6
08V9R@24Q8@0QHF508J6QP23Ph<0S8b<08:2PP25QHD0RXZ:08V9R@28R8P0TI6A09>CT`2@T90208^;
R`0709VIV@28R8P0TI6A08V9R@2<S8`0T92@09BDU00209JFUP0A09bLW02GUiL0SXj>09RHV02=SHd0
V9RH09JFUP2KVi/0WIfM09nOW`2QXJ40VYZJ09jNWP2OWil0XJ6Q0:NWY`2YZJT00P2^[Zh07P2][Jd0
YZJV0:VYZ@2YZJT0YJFU0:^[Z`2e]KD0][Jf0;6a/@2l_;`0/;2`0;jn_P2i^KT0^;Rh0<30`02i^KT0
_[jn0<71`@34a<@0alO70;^k^`2f][H0`<300<K6aP33`l<0`<300<C4a030`<00_;bl0;jn_P80a<C4
02X0^k^k0<C4a033`l<0`L710;bl_02n_[h0`L710<;2`P2l_;`0^;Rh0;jn_P2k^k/0`L710<?3``2n
_[h0^KVi0;Rh^02d];@0`<300<71`@2g]kL0][Jf0;^k^`2c/k<0[:b/0;Bd]02c/k<0][Jf0;^k^`2[
Zj/0[jn_0:RXZ02WYjL0[:b/0:n_[`2OWil0Y:BT0:ZZZP2XZ:P0X:2P09jNWP2ZZZX20::RXP0o09RH
V02KVi/0VYZJ09VIV@2KVi/0V9RH09:BTP2FUYH0VIVI09JFUP2CTi<0U9BD08f=S@2>SXh0R8R808b<
S027QhL0Rh^;09>CT`2:RXX0Rh^;08>3P`2>SXh0QXJ608R8R029RHT0S8b<08N7Q`2;Rh/0RHV907al
O026QXH0PH6107UiN@1nOWh0PX:207inOP1lO7`0NGUi07IfMP1kNg/0MWIf07YjNP1kNg/0PX:207Ee
M@1dM7@0NGUi079bLP1`L700LG5a07UiN@1aLG40K6a/071`L01_Kfl0LG5a07QhN01^KVh0JFUY06i^
KP1_Kfl0MGEe0080L71`00X0KFe]06a/K01[Jf/0L71`06a/K01]KFd0IVIV06a/K01TI6@0IfMW0P1V
IVH02`1QHF40Hf=S065QH@1SHf<0IfMW06EUI@1YJFT0IFEU06ATI01LG5`0Hf=S0080IFEU00P0HF5Q
06IVIP1TI6@0H61P05]KF`1MGEd0I6AT06EUIAL000001P3IfMT100000040fMWI00030=WIf@050000
003IfMT0fMWI0=WIf@0000000P3IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT00`3IfMT05@3Jf]X0H61P06=SH`1RHV80IFEU05iNGP1TI6@0HF5Q
069RHP1SHf<0Jf][06IVIP1]KFd0K6a/06IVIP1XJ6P0K6a/06UYJ@1RHV80KFe]06MWI`0206i^KP04
06UYJ@1ZJVX0Jf][06a/K080Jf][00h0JFUY071`L01_Kfl0K6a/06][J`1XJ6P0IVIV06m_K`1WIfL0
KFe]071`L01YJFT0K6a/06][J`80LG5a01<0KVi^06m_K`1bLW80LW9b07UiN@1aLG40NGUi07moO`1a
LG40Ng]k07UiN@1jNWX0O7al07QhN01lO7`0MWIf07=cL`1kNg/0NGUi0080Ng]k00D0NGUi07QhN01l
O7`0O7al08>3P`0308V9R@0C08Z:RP2>SXh0QhN708f=S@2>SXh0QhN708R8R02;Rh/0RHV908J6QP2<
S8`0Shn?09>CT`2>SXh0UYJF08f=S@2IVIT0SXj>09BDU002096AT@80VIVI00d0VYZJ09RHV02FUYH0
XJ6Q09BDU02FUYH0XJ6Q09^KV`2VYZH0Y:BT09fMW@2SXj<0ZJVY0080W9bL0140YJFU0:VYZ@2/[:`0
[Jf]0:VYZ@2][Jd0Z:RX0:ZZZP2/[:`0ZZZZ0;>c/`2h^;P0^k^k0;Zj^P2i^KT0];Bd0;no_`020<71
`@070;^k^`2o_kl0_[jn0;^k^`2c/k<0_[jn0<;2`P020;jn_P050<71`@34a<@0a/K60;no_`39bLT0
0P2o_kl01`30`<00a<C40<C4a031`L40b<S80<c<c038b<P00`34a<@03@2k^k/0a<C40<C4a030`<00
`l?30;jn_P33`l<0^k^k0<K6aP33`l<0_Kfm0;^k^`2o_kl00P2f][H02P2d];@0/;2`0;Vi^@2^[Zh0
]kNg0;2`/02d];@0/k>c0:RXZ02c/k<20;2`/00R0:>SX`2ZZZX0/K6a0:VYZ@2TY:@0WYjN09nOW`2K
Vi/0XJ6Q0:BTY02[Zj/0Vi^K0:2PX02HV9P0X:2P09JFUP2CTi<0SXj>09>CT`2FUYH0V9RH09:BTP2?
Shl0TY:B08j>SP2=SHd0QhN708^;R`2>SXh0QhN708Z:RP2>SXh0QXJ608V9R@80QhN700H0RHV908^;
R`26QXH0QXJ607emO@21PH4207inOP0408B4Q01nOWh0MWIf07YjNP80O7al0280N7Qh07UiN@1gMgL0
N7Qh07]kN`1gMgL0N7Qh07AdM01aLG40L71`07=cL`1fMWH0Jf][07IfMP2NWYh0Lg=c07IfMP1bLW80
JFUY071`L01aLG40KVi^06a/K01`L700MGEe06QXJ01YJFT0K6a/07AdM01^KVh0LG5a06QXJ01TI6@0
K6a/0P1PH6004@1NGUh0JFUY06=SH`1SHf<0I6AT065QH@1WIfL0IFEU061PH01ZJVX0IFEU06m_K`1X
J6P0I6AT06IVIP1TI6@0HF5Q0080Hf=S00<0GemO06=SH`0000005P0000060=WIf@4000000@3IfMT0
00<0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@040000003IfMT0fMWI00000080fMWI00<0
00000=WIf@3IfMT00`3IfMT3000000<0fMWI02@0eMGE06MWI`1QHF40I6AT06a/K01QHF40I6AT06MW
I`1UIFD0K6a/065QH@1TI6@0IVIV06=SH`1YJFT0J6QX06=SH`1RHV80IFEU06UYJ@1/K6`0HF5Q06IV
IP1^KVh0J6QX071`L01ZJVX0K6a/071`L01bLW80L71`06UYJ@1[Jf/0K6a/06UYJ@1/K6`206i^KP07
06e]K@1_Kfl0MgMg079bLP1cLg<0Jf][07IfMP02075aL@80N7Qh00D0NGUi071`L01eMGD0Kfm_06e]
K@0207AdM080NGUi00D0MGEe07UiN@1mOGd0O7al07QhN00207UiN@070820P025QHD0N7Qh0820P027
QhL0QXJ608N7Q`0208J6QP0C08>3P`2:RXX0Q8B40861P@28R8P0S8b<092@T02>SXh0R8R808F5Q@2:
RXX0S8b<08j>SP2EUID0U9BD092@T02>SXh0QXJ609>CT`0209FEU@0708^;R`2FUYH0WYjN09:BTP2D
U9@0X:2P09fMW@0209VIV@0R09jNWP2TY:@0WYjN0:ZZZP2WYjL0XJ6Q09RHV02QXJ40VIVI09jNWP2V
YZH0Z:RX0:VYZ@2SXj<0/K6a0:^[Z`2`/;00/K6a0;Vi^@31`L40_;bl0;jn_P2c/k<0_[jn0;Vi^@2n
_[h0a<C40<K6aP3>c/h0_Kfm0<_;b`33`l<0b/[:0<71`@80alO700<0`/;20<O7a`2o_kl00P36a/H0
1031`L40_[jn0<k>cP34a<@20<K6aP0D0=3@d02n_[h0a/K60;no_`34a<@0`/;20;fm_@37alL0bl_;
0<C4a038b<P0a<C40<G5a@31`L40`<300;fm_@33`l<0^KVi0;^k^`33`l<20;Rh^080_;bl00D0^k^k
0;Bd]02f][H0^[Zj0:j^[P020:VYZ@0=0:b/[02XZ:P0/;2`0:VYZ@2/[:`0[Zj^0:^[Z`2LW9`0YZJV
0:2PX02ZZZX0XJ6Q0:>SX`0209^KV`0509JFUP2NWYh0Vi^K09bLW02FUYH00P2EUID09`2DU9@0TY:B
092@T029RHT0SXj>08n?S`2>SXh0Rh^;08j>SP2;Rh/0SHf=08b<S025QHD0R8R808f=S@28R8P0Q8B4
08R8R026QXH0PH6108B4Q027QhL0NWYj07]kN`20P800NGUi075aL@1kNg/0N7Qh07YjNP20P800NWYj
07QhN01aLG40Ng]k079bLP1eMGD0Lg=c07MgM`02075aL@0607UiN@1dM7@0MWIf071`L01gMgL0KFe]
0P1^KVh01`1XJ6P0K6a/06][J`1[Jf/0KFe]06MWI`1[Jf/00P1/K6`07@1VIVH0JVYZ07IfMP1`L700
I6AT06UYJ@1[Jf/0KFe]061PH01ZJVX0Hf=S06IVIP1]KFd0JFUY06a/K01LG5`0IVIV075aL@1^KVh0
LW9b06a/K01UIFD0JFUY05iNGP1XJ6P0H61P05]KF`1TI6@0HV9R01L00000103IfMT300000040fMWI
00030=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT010000000fMWI0=WIf@0000020=WIf@03
0000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT0703Lg=`0HV9R06ATI01SHf<0HF5Q
05iNGP1QHF40J6QX06=SH`1XJ6P0L71`06i^KP1ZJVX0Kfm_06UYJ@1XJ6P0IVIV06][J`1YJFT0J6QX
06e]K@1YJFT0JVYZ06IVIP1]KFd0Jf][071`L01ZJVX2071`L00?06IVIP1WIfL0KFe]07=cL`1ZJVX0
Jf][06IVIP1ZJVX0Jf][075aL@1[Jf/0L71`075aL@1^KVh0M7Ad0080N7Qh00L0L71`07EeM@1gMgL0
Ng]k06i^KP1aLG40MWIf0080NGUi00D0Ng]k07inOP1dM7@0Lg=c07]kN`0207emO@050861P@1lO7`0
Ng]k08>3P`24Q8@00`20P8001028R8P0Rh^;08Z:RP23Ph<208b<S00708>3P`28R8P0R8R808Z:RP2;
Rh/0SXj>08V9R@0508b<S00L08f=S@2<S8`0SXj>09FEU@2=SHd0T92@09FEU@2CTi<0WinO09bLW02H
V9P0WYjN08j>SP2HV9P0VIVI09bLW02TY:@0Xj>S0:6QX@2TY:@0W9bL0:6QX@2OWil0Vi^K0:6QX@2V
YZH0Z:RX0:b/[080/;2`00X0Z:RX0:FUY@2_[jl0[:b/0;Fe]@2k^k/0/K6a0;Rh^02i^KT0][Jf0P30
`<001034a<@0b<S80<71`@2n_[h30<S8b0040;jn_P38b<P0d=3@0<g=c@80alO700L0d=3@0<;2`P36
a/H0bLW90<G5a@3@d=00bl_;0080b<S80100a/K60<_;b`36a/H0a/K60<O7a`3;bl/0`/;20<k>cP3;
bl/0c/k>0;jn_P38b<P0bl_;0<30`037alL0`<300P2i^KT02P30`<00^;Rh0<;2`P2i^KT0];Bd0;Jf
]P2a/K40];Bd0;>c/`2a/K420;2`/00a0;6a/@2YZJT0Zj^[0:j^[P2UYJD0ZZZZ0:VYZ@2XZ:P0ZJVY
0:ZZZP2MWId0Xj>S09fMW@2OWil0VIVI09jNWP2DU9@0UYJF09^KV`2BTY80TI6A09>CT`2NWYh0Ti>C
092@T02KVi/0SHf=08j>SP2@T900U9BD08n?S`28R8P0RHV908f=S@2@T900RHV908^;R`26QXH0S8b<
08F5Q@21PH40Q8B40861P@23Ph<0PH610820P01kNg/0O7al07]kN`0207inOP0U07IfMP1jNWX0MgMg
07AdM01gMgL0Ng]k07MgM`1cLg<0MGEe06m_K`1cLg<0NGUi06m_K`1^KVh0MWIf06i^KP1hN7P0M7Ad
075aL@1`L700K6a/06i^KP1gMgL0Jf][07=cL`1XJ6P0LW9b06m_K`1cLg<0JFUY05eMG@1YJFT0J6QX
06][J`1XJ6P0GUiN06IVIP0206UYJ@0B06ATI01[Jf/0J6QX06IVIP1PH600IFEU06a/K01^KVh0KFe]
069RHP1XJ6P0GEeM06QXJ01TI6@0IfMW065QH@1SHf<0G5aL5`0000060=WIf@4000000@3IfMT000<0
fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@040000003IfMT0fMWI00000080fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@0?0=oOg`1UIFD0IFEU065QH@1PH600I6AT
06IVIP1PH600J6QX06=SH`1UIFD0J6QX06][J`1WIfL0K6a/0080KVi^00/0JFUY06][J`1_Kfl0IFEU
06i^KP1ZJVX0MWIf06EUI@1_Kfl0J6QX06YZJP0206][J`0806e]K@1[Jf/0JVYZ075aL@1`L700JFUY
075aL@1eMGD206i^KP0C07=cL`1aLG40KVi^07=cL`1aLG40N7Qh07AdM01gMgL0NWYj07AdM01^KVh0
Lg=c07MgM`1hN7P0OWin07UiN@24Q8@0PX:20820P00207]kN`0807alO01eMGD0PX:207]kN`20P800
OWin0820P01lO7`208>3P`0;08:2PP21PH40Ph>308f=S@29RHT0SHf=08j>SP26QXH0PX:2096AT@28
R8P00P29RHT05P2:RXX0TI6A08n?S`2>SXh0T92@08R8R029RHT0TI6A08n?S`2>SXh0UIFE08n?S`2F
UYH0WIfM09VIV@2KVi/0Xj>S09jNWP2JVYX0Vi^K0:>SX`2KVi/20:2PX00F0:RXZ02^[Zh0WYjN09jN
WP2KVi/0W9bL0::RXP2[Zj/0Z:RX0:j^[P2_[jl0[Zj^0;2`/02f][H0]kNg0;^k^`2n_[h0`<300<?3
``36a/H0_kno0;fm_@80a/K600P0_[jn0<W9b@34a<@0bl_;0<c<c034a<@0b/[:0<G5a@@0c<c<00T0
alO70<_;b`3@d=00d];B0=7Ad@3Fe]H0e=CD0<W9b@3<c<`00P39bLT01@37alL0`/;20<k>cP3?cll0
d=3@0080bl_;00P0a<C40<S8b03:b/X0_;bl0<71`@34a<@0_[jn0<C4a080`/;201X0`L710;Rh^030
`<00alO70;Jf]P2d];@0/k>c0:j^[P2b/[80/K6a0:f][@2^[Zh0Y:BT0:^[Z`2d];@0ZJVY0:ZZZP2Q
XJ40Zj^[0:VYZ@2XZ:P0YjNW0:>SX`2JVYX0XJ6Q0:JVYP80WinO00@0VYZJ09jNWP2GUiL0U9BD0P2G
UiL00`2DU9@0TI6A09FEU@0209FEU@0C09BDU023Ph<0V9RH08^;R`2ATI40QXJ608^;R`1kNg/0QhN7
08V9R@2:RXX0OGem0820P029RHT0PH6107inOP1mOGd0O7al08>3P`0207]kN`0=07alO01iNGT0MWIf
07emO@1iNGT0Lg=c07inOP1kNg/0MgMg07alO01iNGT0MGEe075aL@0207IfMP0306e]K@1dM7@0Jf][
0080LG5a00T0KVi^07=cL`1]KFd0KFe]071`L01bLW80KFe]075aL@1VIVH00P1YJFT0301XJ6P0IfMW
06ATI01SHf<0IVIV06=SH`1XJ6P0HV9R06=SH`1WIfL0IFEU06IVIP80Hf=S00h0JVYZ06=SH`1aLG40
IFEU06][J`1SHf<0GEeM06=SH`1OGel0H61P06IVIP1UIFD0H61P06ATI1L000001P3IfMT100000040
fMWI00020=WIf@800000103IfMT2000000@0fMWI0P0000060=WIf@030000003IfMT0fMWI00<0fMWI
0540h^;R06ATI01XJ6P0IVIV05QHF01LG5`0IFEU05mOG`1^KVh0Jf][06UYJ@1/K6`0IfMW06i^KP1Z
JVX0IVIV06a/K01cLg<0Jf][06a/K01[Jf/0Lg=c06YZJP1WIfL0JVYZ071`L01]KFd0JFUY06m_K`1c
Lg<0K6a/06m_K`1UIFD0L71`06UYJ@1]KFd0KVi^06UYJ@1`L700KFe]07AdM01`L700LG5a07AdM01`
L700N7Qh07AdM01YJFT0N7Qh06a/K01lO7`0LW9b07AdM01iNGT0NWYj07moO`20P800NGUi07QhN020
P800O7al07inOP1iNGT0PX:207alO020P800MgMg07alO023Ph<0Ogmo08J6QP23Ph<0PX:207moO`2;
Rh/0Ogmo08f=S@2;Rh/0QXJ608j>SP26QXH00P2<S8`01@27QhL0Rh^;08f=S@29RHT0T92@0080TI6A
00L0Rh^;08V9R@2>SXh0Shn?09JFUP2MWId0VIVI0080V9RH01X0W9bL0:>SX`2PX:00Y:BT0:JVYP2N
WYh0ZJVY0:>SX`2OWil0ZZZZ0:JVYP2UYJD0Zj^[0:6QX@2TY:@0Xj>S0:b/[02][Jd0/k>c0:n_[`2j
^[X0];Bd0;^k^`2i^KT0^[Zj0;Vi^@80b<S800T0_[jn0<O7a`3?cll0b/[:0<;2`P39bLT0bl_;0<S8
b03>c/h00P3;bl/04`3>c/h0c<c<0<o?c`3=cLd0bLW90<[:bP3?cll0b<S80=7Ad@3@d=00fm_K0=?C
d`3=cLd0bl_;0=CDe03>c/h0e]KF0=3@d03Cdm<0103;bl/0303@d=00bLW90<?3``3>c/h0aLG50;no
_`39bLT0a/K60<S8b031`L40bLW90<;2`P80`L7100H0`<300;jn_P2l_;`0_[jn0;>c/`2g]kL20;Jf
]P0N0;Bd]02f][H0/;2`0:n_[`2XZ:P0Zj^[0:NWY`2TY:@0ZJVY0:JVYP2XZ:P0YjNW0:RXZ02PX:00
W9bL09nOW`2NWYh0YJFU09ZJVP2HV9P0TI6A09JFUP2@T900V9RH09NGU`2MWId0VIVI08f=S@2EUID0
S8b<0P2ATI407`29RHT0TI6A08j>SP2ATI40R8R808N7Q`26QXH0Q8B408V9R@21PH40MWIf08B4Q01m
OGd0Ogmo0820P023Ph<0O7al07=cL`1fMWH0PH6107QhN022PX80N7Qh07=cL`1fMWH0OGem07MgM`1a
LG40NWYj075aL@1dM7@00`1cLg<03@1hN7P0MWIf07QhN01cLg<0MWIf075aL@1eMGD0K6a/079bLP1/
K6`0IVIV06EUI@1^KVh00P1XJ6P01P1/K6`0J6QX06][J`1[Jf/0Hf=S06i^KP80I6AT00@0K6a/06UY
J@1XJ6P0J6QX0P1UIFD03@1QHF40IVIV06QXJ01[Jf/0G5aL06=SH`1UIFD0IVIV05mOG`1TI6@0IVIV
06ATI01QHF405`0000060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT07`3S
hn<0Hf=S06QXJ01TI6@0K6a/05eMG@1RHV80Hf=S06][J`1TI6@0JFUY06ATI01YJFT0IVIV06EUI@1V
IVH0K6a/06QXJ01TI6@0MWIf06IVIP1ZJVX0J6QX06UYJ@1/K6`0Lg=c06YZJP1^KVh0Kfm_079bLP1X
J6P00P1/K6`03P1VIVH0Kfm_06UYJ@1aLG40IfMW071`L01^KVh0MWIf071`L01hN7P0M7Ad07=cL`1[
Jf/0M7Ad0P1eMGD2075aL@0307IfMP1iNGT0MWIf0080P82000X0Q8B407]kN`21PH40NGUi07=cL`1a
LG40OWin08>3P`20P800O7al0P1nOWh20820P00708:2PP28R8P0SHf=08B4Q026QXH0S8b<08B4Q002
08Z:RP0D08V9R@2ATI40T92@092@T02<S8`0T92@08f=S@2?Shl0RHV908f=S@2<S8`0Rh^;09BDU02M
WId0SHf=09FEU@2FUYH0WinO09jNWP2PX:020::RXP030:VYZ@2XZ:P0WinO0080X:2P00l0WYjN0:JV
YP2IVIT0XZ:R0:VYZ@2XZ:P0ZJVY0:RXZ02^[Zh0^;Rh0:n_[`2b/[80^;Rh0;Fe]@2n_[h00P32`/80
2P2l_;`0`/;20<C4a03;bl/0_kno0<30`033`l<0bLW90<S8b03>c/h30=3@d00C0=?Cd`3EeMD0dM7A
0<g=c@3De=@0dm?C0=[JfP3AdM40cLg=0=kNgP3De=@0eMGE0=OGe`3Jf]X0dM7A0=GEe@36a/H0fm_K
0=WIf@020=7Ad@060=3@d03AdM40e=CD0=KFeP3@d=00b<S80P3:b/X05`3GemL0bl_;0<k>cP35aLD0
bl_;0=3@d034a<@0b/[:0<;2`P2n_[h0`<300<C4a02m_Kd0`<300;jn_P2h^;P0^KVi0;Rh^02k^k/0
][Jf0;Fe]@2d];@0/k>c0080[:b/03@0/;2`0:VYZ@2[Zj/0Xj>S0:BTY02WYjL0XZ:R0:BTY02HV9P0
YZJV09FEU@2PX:00WYjN092@T02QXJ40UYJF09fMW@2NWYh0TI6A09:BTP2@T900RHV909>CT`2@T900
V9RH08^;R`2<S8`0Q8B408b<S02ATI40QHF508N7Q`2<S8`0QXJ608^;R`23Ph<0OGem07]kN`1iNGT0
O7al07UiN@1lO7`0Ph>307inOP1eMGD0P82007QhN01gMgL0OWin07QhN01aLG40L71`0P1dM7@02P1o
Ogl0L71`07=cL`1fMWH0LW9b07AdM01bLW80MGEe07AdM01gMgL306][J`0R075aL@1`L700Kfm_075a
L@1YJFT0IfMW07IfMP1[Jf/0J6QX06a/K01UIFD0Hf=S06][J`1TI6@0J6QX06IVIP1ZJVX0J6QX06AT
I01WIfL0Jf][06IVIP1WIfL0J6QX06EUI@1SHf<0JFUY069RHP1SHf<0HF5Q061PH01VIVH0J6QX069R
HQL000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00@0i^KV065QH@1T
I6@0GUiN0P1VIVH0201WIfL0J6QX06YZJP1SHf<0HF5Q06IVIP1^KVh0JFUY0P1VIVH06P1_Kfl0H61P
06QXJ01UIFD0IVIV06MWI`1ZJVX0KVi^06e]K@1XJ6P0Kfm_06a/K01^KVh0M7Ad06IVIP1/K6`0J6QX
06MWI`1TI6@0JFUY06e]K@1aLG40JFUY07IfMP1`L700Lg=c0P1dM7@0601`L700M7Ad07moO`1eMGD0
LW9b075aL@1_Kfl0N7Qh07alO01oOgl0P82007alO024Q8@0PH610820P01kNg/0NGUi0861P@1iNGT0
Ogmo0820P01lO7`0R8R807YjNP80OWin0140P82007]kN`2;Rh/0QXJ608V9R@27QhL0SHf=08j>SP24
Q8@0TI6A08R8R02>SXh0RHV9092@T02BTY80Q8B408N7Q`0208V9R@80SXj>01H0UIFE09JFUP2FUYH0
UiNG09bLW02GUiL0WIfM09JFUP2OWil0Z:RX0;>c/`2[Zj/0YjNW0:n_[`2PX:00YjNW0:^[Z`2SXj<0
ZJVY09fMW@2][Jd0XZ:R0P2a/K403@2e]KD0^[Zj0;Rh^02n_[h0_;bl0<30`02k^k/0][Jf0;Zj^P3@
d=00`L710<30`033`l<00P35aLD06P3@d=00dM7A0<c<c03<c<`0eMGE0<W9b@3<c<`0e=CD0=WIf@3L
g=`0emOG0=3@d03>c/h0fm_K0=7Ad@3Fe]H0dM7A0=KFeP3Hf=P0clo?0=OGe`3AdM40g=cL0=gMg@3D
e=@0fMWI0P3Hf=P02`3Cdm<0e]KF0=WIf@3@d=00c<c<0=7Ad@3@d=00c/k>0<W9b@3<c<`0b<S80080
`l?300X0alO70<?3``2k^k/0_[jn0<30`032`/80alO70;bl_02k^k/0^;Rh0P2j^[X09P2a/K40]kNg
0;:b/P2_[jl0];Bd0:FUY@2][Jd0/;2`0:NWY`2[Zj/0Xj>S0:VYZ@2SXj<0Y:BT0::RXP2XZ:P0WIfM
0:>SX`2HV9P0VIVI09bLW02KVi/0V9RH09BDU02HV9P0TY:B09JFUP2=SHd0S8b<096AT@28R8P0SXj>
09:BTP2@T900R8R808b<S02@T900QhN70P26QXH20820P080PX:200/0R8R808>3P`24Q8@0Ogmo07]k
N`1dM7@0NGUi07]kN`1jNWX0N7Qh07IfMP0207UiN@0306i^KP1aLG40OGem0080MgMg00`0L71`07Ad
M01eMGD0Lg=c075aL@1_Kfl0LG5a07YjNP1^KVh0J6QX075aL@1[Jf/206i^KP0306][J`1VIVH0KVi^
00<0J6QX00<0LG5a06=SH`1XJ6P00P1YJFT00`1ZJVX0IfMW06a/K00206IVIP0@06e]K@1ZJVX0IVIV
06a/K01TI6@0HV9R06MWI`1VIVH0J6QX06=SH`1WIfL0H61P06QXJ01WIfL0GEeM05iNGQL000001P3I
fMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00@0hn?S061PH01TI6@0KVi^0P1Q
HF405@1OGel0JFUY061PH01UIFD0I6AT06a/K01YJFT0JVYZ06EUI@1VIVH0I6AT06EUI@1TI6@0IVIV
06QXJ01^KVh0I6AT06UYJ@1/K6`0J6QX06YZJP04071`L00>06][J`1VIVH0Jf][06QXJ01/K6`0Kfm_
075aL@1^KVh0L71`075aL@1cLg<0Jf][07UiN@1bLW82075aL@0O06i^KP1dM7@0N7Qh071`L01^KVh0
MWIf07UiN@1kNg/0PX:207inOP1kNg/0NGUi07inOP1gMgL0Ng]k07AdM020P800OWin0820P023Ph<0
Ogmo0820P024Q8@0QhN70820P02=SHd0PH6108>3P`27QhL0Rh^;08n?S`02092@T00?08j>SP2JVYX0
Shn?08^;R`23Ph<0R8R808V9R@2@T900Rh^;092@T02DU9@0SXj>08n?S`2JVYX0WIfM0080VIVI00<0
W9bL0:NWY`2QXJ400`2/[:`0302e]KD0YjNW0:FUY@2SXj<0Zj^[0::RXP2XZ:P0[:b/0:f][@2/[:`0
][Jf0;Rh^080^KVi00<0^k^k0<30`032`/800P31`L40802n_[h0b/[:0<_;b`37alL0cLg=0=3@d03:
b/X0c<c<0<W9b@3<c<`0f][J0<c<c03De=@0e]KF0=SHf03Shn<0hN7Q0>?Sh`3Lg=`0h>3P0=[JfP3M
gMd0g=cL0=OGe`3Ti>@0hN7Q0=gMg@3Lg=`0fMWI0>7Qh@3Ng]h0j>SX0P3Ng]h06P3MgMd0h^;R0=OG
e`3IfMT0f][J0=gMg@3Cdm<0emOG0=7Ad@3>c/h0d=3@0=?Cd`3?cll0e=CD0<S8b03AdM40cLg=0<30
`034a<@0`<300<O7a`30`<00_Kfm0;bl_034a<@0^;Rh0P2f][H0102h^;P0[Zj^0:f][@2][Jd20:b/
[0060;:b/P2^[Zh0Z:RX0:RXZ02VYZH0[:b/0P2ZZZX02`2RXZ80WYjN09ZJVP2OWil0YJFU0:2PX02H
V9P0Vi^K09FEU@2BTY80Vi^K0080Ti>C00P0TI6A09FEU@2DU9@0Ti>C096AT@2;Rh/0S8b<096AT@<0
SXj>01L0Q8B408F5Q@1nOWh0PH6107moO`26QXH0NWYj07alO01nOWh0OGem07QhN01kNg/0OWin07Ui
N@1lO7`0LW9b07]kN`1`L700NGUi07AdM01`L700LW9b07=cL`02071`L00407IfMP1dM7@0MGEe06i^
KP80L71`00L0Kfm_07MgM`1_Kfl0L71`07AdM01bLW80L71`0080LG5a00D0Hf=S06MWI`1TI6@0J6QX
06][J`0206UYJ@0506a/K01XJ6P0J6QX069RHP1VIVH00P1XJ6P03`1TI6@0Hf=S06e]K@1VIVH0Kfm_
061PH01QHF40IVIV06MWI`1NGUh0Hf=S065QH@1VIVH0Hf=S069RHP0G000000H0fMWI0@0000010=WI
f@005P3IfMT00`000000fMWI0=WIf@030=WIf@0@0=OGe`1RHV80I6AT06ATI01YJFT0HF5Q06QXJ01[
Jf/0J6QX06UYJ@1VIVH0Jf][06=SH`1[Jf/0K6a/06IVIP@0Jf][01H0Kfm_06YZJP1XJ6P0IfMW07Ad
M01XJ6P0JVYZ06i^KP1`L700JFUY06EUI@1YJFT0HV9R071`L01/K6`0KVi^07=cL`1YJFT0I6AT06][
J`1^KVh0Lg=c0P1aLG409`1`L700MWIf075aL@1iNGT0LG5a07AdM01eMGD0M7Ad07]kN`1dM7@0MgMg
07QhN01iNGT0NWYj07moO`1kNg/0O7al07]kN`1iNGT0P82008>3P`27QhL0Q8B407inOP26QXH0Ph>3
07emO@24Q8@0PH6108b<S020P800SXj>08^;R`2?Shl0S8b<09>CT`28R8P0UIFE08j>SP0208R8R00:
09JFUP2ATI40SHf=08j>SP2<S8`0SXj>092@T02ATI40Vi^K09fMW@80WYjN0180V9RH0::RXP2VYZH0
ZJVY0::RXP2[Zj/0];Bd0:NWY`2/[:`0Y:BT0:JVYP2`/;00]KFe0;6a/@2^[Zh0/;2`0;bl_02n_[h2
0;bl_00T0<71`@2l_;`0`<300<O7a`3?cll0`<300<c<c02o_kl0bl_;0<W9b@3Cdm<0c/k>0<o?c`3F
e]H0g=cL0=WIf@3Hf=P0gmoO0>;RhP3Kfm/0g]kN0>?Sh`3Ph>00gMgM0>KViP3QhN40inOW0>3Ph03Q
hN40hn?S0>3Ph03Ti>@0inOW0>7Qh@3WinL0gmoO0P3QhN401`3Lg=`0fm_K0=kNgP3MgMd0h>3P0=kN
gP3Hf=P00P3MgMd0303Cdm<0d=3@0=kNgP3AdM40e]KF0=CDe03<c<`0b/[:0=_Kf`39bLT0`l?30<k>
cP80a<C400D0`/;20;jn_P2g]kL0^KVi0;Ng]`020;jn_P0>0;6a/@2b/[80/[:b0;Fe]@2^[Zh0/[:b
0;>c/`2/[:`0Y:BT0:RXZ02SXj<0[:b/0:NWY`2TY:@20:6QX@0=0:BTY02IVIT0WYjN0:6QX@2IVIT0
UYJF09RHV02JVYX0V9RH08j>SP2CTi<0U9BD08^;R`0208j>SP0508J6QP2>SXh0SHf=08^;R`2>SXh0
0P29RHT01@20P800QXJ60861P@28R8P0Ph>30080PH6100D0Ogmo07emO@20P800NWYj07emO@0207al
O00507YjNP1fMWH0M7Ad071`L01nOWh00P1bLW801P1eMGD0NGUi079bLP1eMGD0LW9b07=cL`80N7Qh
0180JVYZ07EeM@1[Jf/0Lg=c06MWI`1aLG40KVi^07EeM@1aLG40M7Ad071`L01WIfL0KVi^06UYJ@1^
KVh0K6a/06UYJ@1UIFD206UYJ@0=06ATI01UIFD0IfMW06UYJ@1TI6@0IfMW05iNGP1XJ6P0I6AT06IV
IP1SHf<0I6AT069RHP03061PH00305aLG01SHf<0I6AT01L000001P3IfMT100000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI00`0eMGE065QH@1QHF40IVIV06a/K01RHV80K6a/06UYJ@1[Jf/0
KFe]06][J`1UIFD206][J`0K06e]K@1[Jf/0L71`06IVIP1/K6`0JFUY075aL@1/K6`0Kfm_075aL@1[
Jf/0JFUY06][J`1ZJVX0J6QX06EUI@1SHf<0IVIV06e]K@1VIVH0L71`07=cL`1_Kfl0NGUi075aL@1/
K6`0Kfm_0080LG5a0P1`L700101_Kfl0LG5a071`L01lO7`207UiN@0:07IfMP1hN7P0N7Qh071`L01e
MGD0O7al07emO@1jNWX0O7al08F5Q@80OWin00@0PH6108:2PP25QHD0Ogmo0`23Ph<00`2;Rh/0S8b<
08V9R@0208b<S00K08Z:RP27QhL0T92@09>CT`2GUiL0SXj>092@T02=SHd0R8R808^;R`28R8P0SHf=
092@T02=SHd0TY:B09NGU`2JVYX0U9BD08j>SP2LW9`0UYJF09^KV`2SXj<0WYjN0:>SX`2UYJD0W9bL
0080ZZZZ0P2/[:`02`2c/k<0[:b/0;:b/P2g]kL0^KVi0;Bd]02k^k/0]kNg0;Jf]P2k^k/0_Kfm0080
`L7100X0a<C40<c<c03>c/h0c<c<0<W9b@3>c/h0dm?C0<g=c@3Hf=P0e=CD0P3@d=00303>c/h0dm?C
0=SHf03Lg=`0k^k^0>3Ph03emOD0j^[Z0>_[j`3Ti>@0h>3P0>KViP80jn_[00H0k^k^0>o_k`3/k>`0
l?3`0>k^kP3`l?020>_[j`030>KViP3Ti>@0i^KV0080i>CT00<0g]kN0=KFeP3Ph>000P3QhN401P3A
dM40g=cL0=oOg`3GemL0g]kN0=SHf0<0fMWI00L0cLg=0=CDe03;bl/0b/[:0<K6aP35aLD0clo?0080
`l?301<0^;Rh0<G5a@30`<00_[jn0;Rh^02d];@0/;2`0:n_[`2`/;00];Bd0;6a/@2[Zj/0XZ:R0:j^
[P2XZ:P0WYjN0::RXP2NWYh0Z:RX0080YZJV00<0WYjN0:BTY02OWil00P2IVIT02@2ATI40VIVI09RH
V02BTY80UiNG09:BTP2EUID0TI6A08n?S`0208j>SP0908^;R`2<S8`0RXZ:08R8R029RHT0QhN708f=
S@23Ph<0RXZ:0080P82000L0Ogmo08>3P`1lO7`0NGUi07alO01dM7@0Ng]k0080Lg=c02/0P82007Qh
N01iNGT0Lg=c071`L01dM7@0MWIf07AdM01kNg/0L71`079bLP1]KFd0NWYj07EeM@1cLg<0KVi^07Ee
M@1`L700N7Qh071`L01YJFT0K6a/06i^KP1YJFT0Kfm_06i^KP1[Jf/0JVYZ06UYJ@1^KVh0IVIV06a/
K01YJFT0IVIV065QH@1TI6@0GemO06UYJ@1/K6`0IfMW06YZJP1XJ6P0IFEU0080J6QX00P0IFEU06IV
IP1LG5`0IVIV06=SH`1QHF40J6QX06EUIAL000001P3IfMT100000040fMWI000F0=WIf@030000003I
fMT0fMWI00<0fMWI00D0hN7Q06QXJ01QHF40I6AT05mOG`0206UYJ@0<06QXJ01/K6`0H61P06e]K@1W
IfL0IFEU06QXJ01YJFT0IVIV071`L01VIVH0Jf][0P1VIVH07@1/K6`0J6QX07=cL`1YJFT0KVi^06YZ
JP1UIFD0J6QX06][J`1VIVH0J6QX06UYJ@1bLW80MWIf07AdM01`L700LG5a07AdM01aLG40KFe]075a
L@1jNWX0Lg=c079bLP1cLg<0Kfm_07AdM01cLg<0LW9b0080N7Qh00H0L71`075aL@1^KVh0KVi^07Ad
M020P80207UiN@0[07alO01oOgl0OGem0861P@1mOGd0Ph>30861P@1nOWh0QhN707inOP23Ph<0Rh^;
08B4Q02:RXX0Shn?08b<S02>SXh0Ti>C08b<S02;Rh/0Shn?08B4Q02<S8`0QXJ608f=S@28R8P0T92@
09:BTP2IVIT0SXj>09^KV`2CTi<0TI6A09>CT`2HV9P0UIFE09VIV@2SXj<0YjNW09jNWP2RXZ80Y:BT
0:VYZ@020:j^[P0F0;>c/`2^[Zh0/K6a0:j^[P2a/K40^;Rh0;jn_P31`L40][Jf0;bl_02i^KT0^;Rh
0<W9b@38b<P0_[jn0<71`@3?cll0c/k>0<_;b`3<c<`0bLW90=WIf@80f=SH02@0eMGE0=SHf03Kfm/0
emOG0=kNgP3]kNd0jn_[0>CTi03Xj>P0iNGU0=oOg`3[jn/0i>CT0>?Sh`3]kNd0m_Kf0>k^kP3/k>`0
i^KV0>OWi`3Ti>@0k^k^0>WYj@3^k^h0kno_0>?Sh`3[jn/0kNg]0>CTi03/k>`0jNWY0>_[j`3Kfm/0
gMgM0=cLg03Jf]X20=oOg`040=?Cd`3EeMD0fMWI0=3@d080cLg=02@0b<S80=7Ad@3;bl/0b<S80<k>
cP34a<@0`l?30<71`@35aLD0_Kfm0;Jf]P33`l<0][Jf0;bl_02i^KT0/K6a0;bl_02`/;00/k>c0:^[
Z`2`/;00Zj^[0:VYZ@2^[Zh0YjNW0:JVYP2UYJD0XZ:R0:NWY`2YZJT0X:2P0:FUY@2IVIT0X:2P09jN
WP2LW9`209NGU`03096AT@2HV9P0R8R80080T92@00<0RHV9092@T02FUYH00P2ATI403@2?Shl0R8R8
08B4Q024Q8@0Ogmo0861P@23Ph<0OGem07UiN@21PH40Ng]k07UiN@24Q8@00P1iNGT0<@1kNg/0P820
07AdM01hN7P0LG5a07QhN01dM7@0N7Qh07UiN@1dM7@0LG5a06][J`1/K6`0N7Qh079bLP1`L700KFe]
079bLP1`L700Jf][06UYJ@1^KVh0Hf=S06m_K`1]KFd0IVIV06YZJP1XJ6P0KVi^065QH@1XJ6P0Fe]K
06a/K01ZJVX0Hf=S06UYJ@1VIVH0Hf=S065QH@1TI6@0KFe]06][J`1^KVh0I6AT06QXJ01SHf<0HF5Q
061PH01QHF400P1VIVH0101TI6@0Hf=S05eMG@1QHF4G000000H0fMWI0@0000010=WIf@005P3IfMT0
0`000000fMWI0=WIf@030=WIf@0M0=gMg@1VIVH0JFUY06MWI`1VIVH0IfMW06][J`1aLG40JFUY06QX
J01bLW80I6AT06=SH`1VIVH0KVi^06YZJP1^KVh0Lg=c06ATI01/K6`0L71`06m_K`1]KFd0K6a/065Q
H@1WIfL0JFUY06e]K@1TI6@00P1]KFd01P1ZJVX0JFUY06e]K@1YJFT0LW9b06i^KP80M7Ad0P1`L700
201_Kfl0KVi^07EeM@1cLg<0NGUi07EeM@1iNGT0MGEe0P1fMWH01P1eMGD0LG5a071`L01dM7@0O7al
06i^KP80O7al00/0Lg=c0820P01nOWh0OGem08J6QP24Q8@0Ng]k08R8R023Ph<0RHV908N7Q`0208J6
QP0M08>3P`26QXH0R8R808N7Q`2@T900RHV908j>SP2=SHd0U9BD08n?S`2>SXh0TI6A08b<S02DU9@0
Ti>C09JFUP2CTi<0Vi^K09>CT`2LW9`0UiNG096AT@2BTY80Ti>C09fMW@2SXj<0ZZZZ0:BTY02ZZZX0
0`2XZ:P0J`2[Zj/0ZJVY0;>c/`2a/K40^;Rh0;Jf]P2c/k<0/;2`0<71`@2n_[h0`L710<K6aP32`/80
a<C40<o?c`36a/H0cLg=0<c<c03@d=00e=CD0=3@d03Jf]X0d=3@0=WIf@3MgMd0hN7Q0=kNgP3Ph>00
h^;R0>SXj03Ti>@0jn_[0>7Qh@3[jn/0k^k^0>WYj@3alO40kNg]0>k^kP3/k>`0jn_[0??cl`3alO40
k^k^0?Cdm03alO40n?Sh0>WYj@3^k^h0l?3`0>k^kP3[jn/0i^KV0>c/k03clo<0k>c/0?7al@3Xj>P0
jNWY0>3Ph03MgMd0g]kN0>KViP3Lg=`0g]kN0=cLg03Kfm/0g]kN0=_Kf`3Fe]H0f=SH0=_Kf`3AdM40
bl_;0<W9b@3:b/X0`/;20;no_`31`L40_Kfm0;bl_02k^k/0/K6a0<?3``2`/;00[Zj^0;Rh^02[Zj/0
[Zj^0:^[Z`2ZZZX0Z:RX0:^[Z`2^[Zh0Z:RX0:b/[02XZ:P0[Jf]0:2PX02VYZH0XJ6Q08^;R`2HV9P0
W9bL09>CT`2KVi/0T92@0080UYJF00<0U9BD09:BTP2FUYH00P2>SXh0202;Rh/0R8R808^;R`26QXH0
S8b<08^;R`28R8P0OWin0P21PH400`2<S8`0PH6107MgM`0207moO`0G0820P01gMgL0N7Qh07UiN@1n
OWh0MWIf07UiN@1kNg/0Lg=c07QhN01fMWH0N7Qh07EeM@1aLG40N7Qh07IfMP1/K6`0M7Ad07IfMP1g
MgL0K6a/06MWI`1cLg<00P1^KVh02@1eMGD0KVi^06][J`1^KVh0Kfm_06a/K01UIFD0Kfm_07AdM002
06QXJ00406YZJP1XJ6P0L71`06=SH`80IfMW00h0J6QX06][J`1/K6`0IfMW069RHP1VIVH0JFUY06MW
I`1[Jf/0HV9R06ATI01LG5`0HF5Q05aLG080Fe]K5`0000060=WIf@4000000@3IfMT001H0fMWI00<0
00000=WIf@3IfMT00`3IfMT00`3WinL0HV9R06=SH`0206][J`80K6a/0P1WIfL03@1[Jf/0IVIV06QX
J01[Jf/0I6AT06a/K01gMgL0KVi^06UYJ@1TI6@0Lg=c06UYJ@1/K6`00P1^KVh02@1XJ6P0JFUY06e]
K@1^KVh0K6a/06][J`1XJ6P0KVi^06QXJ002071`L00C079bLP1dM7@0KVi^07IfMP1aLG40M7Ad06QX
J01aLG40MWIf07AdM01aLG40MGEe07=cL`1/K6`0LW9b06i^KP1hN7P0KFe]075aL@0207=cL`0;07If
MP1`L700L71`07alO01jNWX0O7al0861P@1nOWh0OGem07inOP1mOGd00P20P8004@22PX80R8R808b<
S029RHT0PX:208R8R024Q8@0R8R808j>SP26QXH0V9RH08f=S@21PH40SHf=08j>SP2?Shl0R8R80080
V9RH00@0Vi^K092@T02MWId0UiNG0`2IVIT01P2NWYh0WIfM0:BTY02UYJD0ZJVY0::RXP80YJFU00L0
/K6a0:f][@2[Zj/0][Jf0:j^[P2b/[80^KVi0080^[Zj0340`L710<?3``31`L40`<300<W9b@35aLD0
c<c<0<k>cP3AdM40b/[:0=GEe@38b<P0eMGE0=KFeP3Lg=`0gMgM0>CTi03MgMd0jn_[0=SHf03Xj>P0
h^;R0>WYj@3dm?@0lO7a0??cl`3`l?00lO7a0?Cdm03]kNd0j^[Z0?7al@3gmoL0n?Sh0?clo03clo<0
n_[j0?Gem@3fm_H0m?Cd0?Win@3kno/0n?Sh0>g]k@3^k^h0lO7a0?Win@3fm_H0lo?c0080k^k^00L0
jNWY0>c/k03Shn<0hn?S0=cLg03Shn<0f][J0080f=SH0140f][J0<W9b@3Hf=P0clo?0=;BdP39bLT0
c<c<0<_;b`30`<00a<C40<K6aP2c/k<0_kno0<30`02l_;`0_kno0;fm_@020;>c/`0Q0;2`/02d];@0
/;2`0;:b/P2ZZZX0[:b/0:j^[P2ZZZX0YJFU0:j^[P2XZ:P0W9bL09jNWP2UYJD0VYZJ0:2PX02IVIT0
UIFE09ZJVP2CTi<0W9bL09^KV`2FUYH0UIFE092@T02IVIT0SHf=09:BTP28R8P0SXj>08^;R`29RHT0
R8R80080S8b<01H0P82008J6QP1lO7`0Ph>30820P01oOgl0P82007emO@1hN7P0MgMg07YjNP1lO7`0
N7Qh07alO01nOWh0M7Ad07YjNP1fMWH0N7Qh07IfMP1cLg<0LG5a0`1eMGD07P1`L700M7Ad07EeM@1]
KFd0JVYZ06a/K01`L700Kfm_071`L01cLg<0KFe]06UYJ@1/K6`0JFUY075aL@1/K6`0IVIV06YZJP1/
K6`0J6QX06UYJ@1NGUh0HF5Q06UYJ@1SHf<0GemO06UYJ@1TI6@0JFUY06ATI080Hf=S00P0H61P05aL
G01SHf<0HF5Q05aLG01SHf<0JFUY065QHAL000001P3IfMT100000040fMWI000F0=WIf@800000103I
fMT01@3Ti>@0IfMW06ATI01[Jf/0HV9R0080IVIV00D0Jf][069RHP1[Jf/0LG5a06e]K@0206QXJ00G
06e]K@1ZJVX0IfMW06i^KP1/K6`0Jf][06UYJ@1[Jf/0K6a/071`L01[Jf/0JVYZ06m_K`1`L700JVYZ
06i^KP1`L700JFUY07EeM@1VIVH0JFUY071`L01[Jf/00P1aLG406@1dM7@0Lg=c075aL@1bLW80KFe]
07AdM01^KVh0M7Ad06m_K`1cLg<0N7Qh06i^KP1fMWH0O7al07AdM01cLg<0Kfm_07IfMP1cLg<0MWIf
07QhN01lO7`0PH6107inOP1mOGd00P21PH401`27QhL0PH6108V9R@22PX80Q8B407moO`24Q8@00P26
QXH0402=SHd0RXZ:08>3P`29RHT0SXj>09RHV02CTi<0Q8B408n?S`2:RXX0VIVI09FEU@2CTi<0TI6A
0:6QX@2HV9P20:6QX@0308n?S`2IVIT0Vi^K0080X:2P00<0W9bL0:BTY02VYZH00P2VYZH0202d];@0
ZJVY0;2`/02a/K40/k>c0;Bd]02m_Kd0`<300P2l_;`07`2j^[X0alO70;bl_036a/H0d];B0=7Ad@3;
bl/0b/[:0<c<c03De=@0f][J0=oOg`3Ti>@0gmoO0>GUi@3Shn<0iNGU0>_[j`3UiND0l?3`0?7al@3`
l?00lO7a0?3`l03_knl0m_Kf0>k^kP3inOT0no_k0?Cdm03kno/00P3lo?`0303kno/0o_kn0?Ogm`3f
m_H0n_[j0?clo03inOT0no_k0?KfmP3lo?`0m_Kf0?3`l080oooo0100k>c/0??cl`3_knl0kNg]0>OW
i`3bl_80h^;R0>CTi03Rh^80hN7Q0>WYj@3Ogml0f=SH0>3Ph03De=@0fMWI0P3Cdm<20<_;b`040<o?
c`39bLT0b/[:0<C4a080`L7100/0_kno0<71`@2n_[h0_;bl0;Bd]02c/k<0][Jf0;>c/`2ZZZX0[:b/
0:VYZ@020:JVYP0>0:j^[P2TY:@0[:b/0:>SX`2TY:@0XJ6Q09^KV`2IVIT0WYjN0:>SX`2DU9@0VIVI
09^KV`2DU9@209NGU`0B09RHV02DU9@0Ti>C092@T02ATI40Rh^;092@T02:RXX0Ph>308R8R029RHT0
Rh^;08:2PP26QXH0OGem08V9R@22PX80Q8B40P21PH403P1iNGT0NWYj07]kN`1cLg<0NWYj07]kN`1f
MWH0LG5a07MgM`1cLg<0MGEe07AdM01`L700M7Ad0`1cLg<03`1eMGD0L71`06m_K`1^KVh0LW9b06m_
K`1dM7@0Kfm_07=cL`1/K6`0L71`06UYJ@1[Jf/0KVi^06a/K00206][J`0F06i^KP1TI6@0Hf=S06IV
IP1SHf<0H61P05QHF01QHF40G5aL05eMG@1YJFT0Hf=S05iNGP1PH600JFUY06ATI01LG5`0Hf=S06][
J`1PH600FUYJ06=SHaL000001@3IfMT200000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI
00P0j>SX06IVIP1UIFD0IVIV06a/K01]KFd0Jf][06YZJP80IVIV01/0IfMW079bLP1/K6`0J6QX06i^
KP1SHf<0Jf][06UYJ@1^KVh0Jf][06QXJ01aLG40Kfm_06MWI`1XJ6P0JFUY06][J`1^KVh0K6a/07If
MP1`L700LG5a06i^KP1_Kfl0KFe]06i^KP1hN7P00P1^KVh0;`1hN7P0L71`07QhN01`L700Jf][07Ui
N@1dM7@0MWIf07=cL`1dM7@0O7al07]kN`1eMGD0NWYj07]kN`1eMGD0MWIf07emO@1jNWX0N7Qh07Yj
NP21PH40O7al08:2PP1mOGd0RHV908:2PP24Q8@0Ng]k08R8R020P800RHV909>CT`2>SXh0SHf=09:B
TP26QXH0Rh^;092@T029RHT0TI6A09:BTP2DU9@0TI6A08b<S02GUiL0SXj>0080UiNG00T0T92@09BD
U02ATI40TI6A09fMW@2IVIT0Vi^K09jNWP2MWId00P2XZ:P08P2PX:00[Jf]0:j^[P2_[jl0[Jf]0:b/
[02a/K40^;Rh0;Ng]`2c/k<0_[jn0;Rh^02n_[h0a/K60<O7a`34a<@0aLG50;jn_P3@d=00clo?0<G5
a@3Bd]80dM7A0=KFeP3EeMD0e]KF0=gMg@3Xj>P0inOW0>KViP3YjNT0inOW0>k^kP3Vi^H20?KfmP04
0>g]k@3alO40lO7a0?Ogm`<0oooo00H0nOWi0?gmo@3no_h0oooo0?knoP3kno/30?ooo`080?_kn`3o
ool0oooo0?ooo`3hn?P0o_kn0?clo03no_h20?Ogm`0;0?;blP3^k^h0kNg]0?3`l03alO40kno_0>CT
i03Shn<0i^KV0>SXj03Vi^H00P3Ng]h0:P3QhN40f=SH0<o?c`36a/H0e=CD0=7Ad@3?cll0cLg=0<_;
b`3@d=00bl_;0<C4a030`<00`/;20;bl_02e]KD0^k^k0;Vi^@2g]kL0^;Rh0;>c/`2/[:`0/;2`0:b/
[02^[Zh0ZJVY0:BTY02c/k<0WYjN0:RXZ02TY:@0Vi^K09bLW02JVYX0VIVI09NGU`2QXJ40TY:B09RH
V02NWYh0Ti>C09ZJVP80T92@00h0TI6A092@T026QXH0S8b<08^;R`2=SHd0RHV90861P@20P800QHF5
08J6QP20P800OWin0861P@80P82000@0PX:207IfMP1iNGT0MgMg0`1hN7P307UiN@0B07]kN`1cLg<0
M7Ad07IfMP1hN7P0MWIf07UiN@1`L700Lg=c07AdM01/K6`0L71`06i^KP1aLG40Kfm_075aL@1/K6`0
L71`0P1/K6`05@1XJ6P0JVYZ06MWI`1]KFd0IFEU06MWI`1]KFd0J6QX06IVIP1YJFT0GUiN05=CD`1I
FET0GemO061PH01YJFT0HF5Q06=SH`1RHV80JFUY06=SH`0206ATI004069RHP1TI6@0J6QX06IVIQL0
00001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI01T0hn?S06QXJ01WIfL0
IfMW061PH01XJ6P0I6AT06][J`1VIVH0Jf][079bLP1YJFT0I6AT06=SH`1WIfL0K6a/06m_K`1WIfL0
L71`06IVIP1`L700KVi^06QXJ01RHV80Jf][0080K6a/00H0Jf][071`L01XJ6P0K6a/06YZJP1/K6`2
06][J`80K6a/00l0Lg=c075aL@1^KVh0MgMg075aL@1]KFd0Lg=c079bLP1cLg<0LG5a06UYJ@1jNWX0
MWIf07emO@1kNg/00P1lO7`09`1aLG40N7Qh07alO01iNGT0M7Ad07]kN`1eMGD0Q8B407emO@28R8P0
Ph>30820P01nOWh0P82008J6QP22PX80Q8B408N7Q`1oOgl0TI6A08b<S02BTY80Rh^;08b<S02?Shl0
R8R809>CT`2<S8`0TI6A09:BTP2ATI40V9RH09BDU02OWil0UiNG09VIV@2UYJD0VYZJ09BDU0020:2P
X00709bLW02QXJ40YZJV0:j^[P2WYjL0/K6a0:JVYP020:NWY`0S0;Jf]P2a/K40];Bd0;Bd]02g]kL0
b<S80;no_`33`l<0`L710<30`031`L40c<c<0<S8b03Cdm<0cLg=0=GEe@3Lg=`0e=CD0=WIf@3Lg=`0
fm_K0=kNgP3Ti>@0j>SX0>CTi03YjNT0l_;b0?7al@3/k>`0lO7a0?clo03moOd0lo?c0?Shn03fm_H0
4`3oool08`3fm_H0oooo0?Win@3no_h0nOWi0>o_k`3gmoL0lO7a0>k^kP3fm_H0l?3`0>[ZjP3Ti>@0
jNWY0>SXj03UiND0fm_K0=kNgP3Zj^X0dm?C0=KFeP3>c/h0dM7A0<c<c03:b/X0`/;20<c<c030`<00
a/K60<30`037alL0][Jf0;bl_02c/k<0Z:RX00@0/K6a01D0[:b/0:j^[P2XZ:P0Zj^[0:ZZZP2][Jd0
X:2P0:>SX`2NWYh0TY:B09RHV02LW9`0UiNG09RHV02NWYh0Ti>C09jNWP2EUID0SXj>096AT@2GUiL0
0P2?Shl01P2BTY80SHf=08B4Q02=SHd0R8R808f=S@80Rh^;00d0Q8B407inOP1lO7`0PH610820P01k
Ng/0M7Ad08N7Q`1eMGD0NGUi07alO01dM7@0MWIf0080Ng]k01@0L71`079bLP1fMWH0M7Ad07QhN01d
M7@0NGUi06m_K`1cLg<0MWIf075aL@1/K6`0Lg=c06m_K`1`L700M7Ad079bLP1`L700J6QX075aL@80
Jf][01L0IFEU06a/K01YJFT0KFe]06MWI`1ZJVX0I6AT06e]K@1QHF40GUiN02DU9@1DE5@0IVIV05UI
F@1NGUh0JVYZ06EUI@1ZJVX0GEeM06EUI@1TI6@0F5QH06ATI00306EUIAL000001P3IfMT100000040
fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00<0i^KV065QH@1[Jf/00`1XJ6P0301YJFT0Hf=S
06a/K01[Jf/0IFEU06m_K`1/K6`0Jf][06IVIP1XJ6P0JFUY071`L080Jf][00<0IFEU06][J`1aLG40
0P1XJ6P04`1[Jf/0KVi^06m_K`1^KVh0Jf][07IfMP1_Kfl0IVIV06a/K01UIFD0I6AT06][J`1VIVH0
Jf][07UiN@1_Kfl0L71`07IfMP1dM7@00P1fMWH00`1bLW80MgMg06m_K`0207QhN00907alO01fMWH0
M7Ad07EeM@1kNg/0M7Ad07alO01aLG40M7Ad0080Ng]k02<0O7al07inOP23Ph<0Q8B408V9R@21PH40
Rh^;08>3P`25QHD0RHV908N7Q`2DU9@0TI6A08R8R02<S8`0QXJ608j>SP2@T900Ti>C08^;R`2@T900
Rh^;08Z:RP2<S8`0V9RH092@T02HV9P0UIFE09BDU02IVIT0UiNG0:NWY`2QXJ40X:2P0:BTY0020:RX
Z00@0;2`/02][Jd0[Zj^0:n_[`2a/K40[jn_0:j^[P2a/K40^k^k0<71`@2h^;P0a/K60<W9b@37alL0
b<S80<[:bP80bl_;00d0c/k>0=CDe03De=@0dm?C0=cLg03QhN40gMgM0=SHf03Shn<0i>CT0>_[j`3a
lO40kno_0080lo?c00@0o?cl0?Win@3oool0nOWi0P3oool00`3emOD0oooo0?ooo`0C0?ooo`0D0?_k
n`3moOd0nOWi0?Gem@3fm_H0nOWi0?knoP3hn?P0lo?c0>g]k@3dm?@0kNg]0>CTi03Ogml0jn_[0=_K
f`3QhN40g]kN0=cLg03Kfm/20=?Cd`<0c/k>00L0bl_;0<O7a`36a/H0b<S80<71`@2h^;P0`l?30080
]kNg00P0^;Rh0;Jf]P2h^;P0];Bd0;6a/@2ZZZX0/[:b0:^[Z`80YZJV01T0XJ6Q0:>SX`2MWId0WinO
09VIV@2KVi/0V9RH09VIV@2GUiL0VYZJ09jNWP2CTi<0QhN709RHV02<S8`0Shn?08^;R`2@T900SHf=
08V9R@23Ph<0Q8B408j>SP23Ph<0QHF50080O7al01@0MgMg08>3P`1iNGT0Ng]k07QhN01nOWh0NGUi
07alO01hN7P0L71`08F5Q@1fMWH0KVi^07AdM01iNGT0N7Qh07AdM01eMGD0Ng]k07IfMP80L71`00@0
Jf][06a/K01aLG40MGEe0P1`L7002@1]KFd0JVYZ07EeM@1^KVh0Jf][075aL@1[Jf/0KFe]06UYJ@03
06IVIP0?06ATI01SHf<0IfMW06=SH`1MGEd0H61P05QHF01VIVH0GemO06ATI01^KVh0Hf=S06ATI01S
Hf<0J6QX0080IfMW00<0HV9R05aLG01VIVH05`0000060=WIf@4000000@3IfMT001H0fMWI00<00000
0=WIf@3IfMT00`3IfMT0103/k>`0J6QX06=SH`1`L70206][J`0G065QH@1XJ6P0J6QX06][J`1XJ6P0
IVIV06i^KP1YJFT0KFe]06QXJ01WIfL0LG5a06e]K@1[Jf/0JVYZ06ATI01`L700Lg=c06IVIP1]KFd0
Lg=c06IVIP1[Jf/00P1aLG40201YJFT0KVi^06QXJ01YJFT0KFe]06a/K01_Kfl0L71`0P1bLW805`1h
N7P0Kfm_07EeM@1lO7`0MWIf071`L01_Kfl0MWIf071`L01aLG40NGUi07MgM`1hN7P0NGUi07EeM@1c
Lg<0N7Qh07AdM021PH40NGUi07]kN`23Ph<0QHF50080S8b<00L0Q8B40820P026QXH0QXJ608>3P`2;
Rh/0S8b<0080SHf=00h0R8R808V9R@2ATI40RHV9092@T02ATI40Shn?08j>SP2CTi<0VIVI09FEU@2D
U9@0Ti>C09RHV080UYJF02<0VIVI0:6QX@2TY:@0YZJV0:FUY@2OWil0[:b/0:NWY`2XZ:P0YZJV0:RX
Z02][Jd0/[:b0;>c/`2n_[h0^KVi0<C4a030`<00bl_;0<K6aP3Cdm<0a/K60<c<c03;bl/0c/k>0<g=
c@3>c/h0fMWI0=?Cd`3Ng]h0f=SH0<k>cP3Ph>00inOW0>WYj@020>k^kP030?clo03hn?P0n?Sh0080
oooo00<0o_kn0?ooo`3oool06`3oool02P3jn_X0no_k0?ooo`3oool0lO7a0?knoP3dm?@0lO7a0>k^
kP3]kNd20>k^kP0O0>?Sh`3Xj>P0hn?S0=oOg`3Ph>00fMWI0=3@d03AdM40c/k>0<c<c038b<P0c/k>
0<g=c@34a<@0`<300<71`@2g]kL0_kno0;Jf]P2k^k/0][Jf0:j^[P2n_[h0[Jf]0:RXZ02_[jl0Y:BT
0:FUY@2TY:@0YZJV09nOW`0209RHV00C09fMW@2OWil0XJ6Q09RHV02MWId0V9RH09bLW02HV9P0UIFE
092@T02>SXh0RHV909>CT`2;Rh/0S8b<08j>SP29RHT0RXZ:0861P@0208:2PP0D07inOP22PX80OWin
07]kN`1mOGd0KVi^07alO01nOWh0N7Qh07inOP1iNGT0Ng]k07=cL`1aLG40MgMg07AdM01iNGT0M7Ad
06m_K`1cLg<307EeM@0<07AdM01aLG40M7Ad07UiN@1hN7P0LW9b075aL@1cLg<0LG5a06QXJ01YJFT0
Jf][0P1]KFd06@1dM7@0K6a/06MWI`1UIFD0J6QX06UYJ@1SHf<0H61P05UIF@1QHF40Hf=S05iNGP1R
HV80IfMW06EUI@1SHf<0HV9R06ATI01XJ6P0L71`061PH01SHf<0HF5Q06=SH`1VIVH05`0000060=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0203Vi^H0IVIV06=SH`1WIfL0IVIV
06a/K01YJFT0JVYZ0P1VIVH02`1[Jf/0JFUY06i^KP1aLG40L71`06a/K01^KVh0LG5a07EeM@1aLG40
LW9b0080I6AT02@0JFUY06][J`1^KVh0KVi^07=cL`1[Jf/0Lg=c06i^KP1ZJVX0MWIf07=cL`1dM7@0
KVi^075aL@1/K6`0NGUi07IfMP1dM7@0MGEe07=cL`1[Jf/0O7al07EeM@1hN7P0Ng]k06m_K`1eMGD0
MWIf075aL@1fMWH0N7Qh07MgM`1eMGD0O7al07QhN01cLg<207YjNP80OWin00d0PX:208>3P`25QHD0
P82007inOP2<S8`0T92@08b<S02>SXh0T92@08B4Q02;Rh/0S8b<0080Rh^;01L0RHV9096AT@2:RXX0
UIFE08j>SP2<S8`0U9BD09JFUP2CTi<0Shn?09^KV`2HV9P0WinO09BDU02LW9`0WinO0:2PX02UYJD0
ZJVY0:2PX02XZ:P0[Jf]0::RXP020:n_[`0K0:RXZ02c/k<0^;Rh0;^k^`2o_kl0`l?30<;2`P34a<@0
b<S80<o?c`3>c/h0c<c<0=CDe03Bd]80g=cL0=;BdP3Lg=`0inOW0>7Qh@3Ogml0jNWY0>o_k`3]kNd0
l?3`0?Shn03^k^h0n_[j00<0oooo00<0o_kn0?ooo`3oool07P3oool0303lo?`0oooo0?knoP3fm_H0
m?Cd0?3`l03clo<0jNWY0>?Sh`3[jn/0h>3P0>OWi`80h>3P00L0fMWI0=KFeP3IfMT0e]KF0=3@d036
a/H0bl_;0080a<C400T0_Kfm0;Zj^P2l_;`0_kno0<71`@2d];@0/[:b0;2`/02ZZZX00P2/[:`05P2`
/;00[Jf]0:BTY02[Zj/0YZJV0:FUY@2OWil0V9RH0:BTY02JVYX0UIFE09VIV@2FUYH0TY:B09JFUP2H
V9P0Shn?09:BTP2?Shl0UiNG08R8R026QXH208V9R@0A08J6QP21PH40R8R808R8R023Ph<0PH610820
P01kNg/0Ph>30820P01kNg/0NGUi07emO@1fMWH0PX:207]kN`1jNWX00P1/K6`01P1bLW80NWYj07Ee
M@1`L700M7Ad07UiN@80LG5a01@0LW9b06i^KP1`L700KFe]06YZJP1]KFd0LG5a07=cL`1XJ6P0KFe]
06IVIP1^KVh0Jf][06e]K@1[Jf/0K6a/06UYJ@1VIVH0Hf=S065QH@80JFUY0180I6AT05YJFP1SHf<0
I6AT065QH@1MGEd0JFUY06ATI01PH600KVi^065QH@1UIFD0JFUY06=SH`1NGUh0J6QX065QH@1YJFTG
000000H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0@0>WYj@1XJ6P0I6AT
06IVIP1WIfL0IVIV06UYJ@1RHV80KFe]06YZJP1WIfL0LG5a06a/K01`L700Jf][06MWI`80KVi^00P0
L71`06i^KP1[Jf/0KFe]06i^KP1WIfL0Kfm_06i^KP80Jf][03P0KVi^06a/K01^KVh0Lg=c071`L01h
N7P0Lg=c06m_K`1fMWH0LW9b075aL@1^KVh0LG5a07AdM01jNWX0Ng]k07emO@1iNGT0L71`07]kN`1a
LG40MgMg07=cL`1`L700KVi^075aL@1`L700M7Ad07inOP1fMWH0PH6107inOP1mOGd0Ng]k0820P01n
OWh0QhN708B4Q025QHD0RHV907moO`2;Rh/0QXJ608F5Q@29RHT0S8b<092@T02:RXX0SHf=08j>SP26
QXH0QHF509BDU02:RXX0V9RH08j>SP80T92@02`0Ti>C09JFUP2KVi/0Vi^K09bLW02MWId0Vi^K0::R
XP2TY:@0Z:RX0:>SX`2QXJ40ZJVY0:j^[P2XZ:P0YJFU0:VYZ@2d];@0/k>c0<30`02g]kL0bLW90<;2
`P39bLT0a/K60<_;b`3<c<`0bl_;0=3@d03De=@0dM7A0=WIf@3Ogml0f][J0=kNgP3WinL0lo?c0>_[
j`3]kNd0k^k^0>c/k03inOT0oooo0?OgmbP0oooo01`0n_[j0?ooo`3`l?00kno_0>c/k03^k^h0i^KV
0>;RhP3YjNT0h>3P0>KViP3Kfm/0fMWI0=kNgP3>c/h0dM7A0<g=c@3AdM40alO70<30`038b<P0`l?3
0<30`02l_;`0_[jn0<?3``2e]KD0/K6a0P2`/;002`2/[:`0/;2`0;2`/02VYZH0XJ6Q09^KV`2HV9P0
X:2P09VIV@2NWYh0W9bL0080U9BD00X0Vi^K09RHV02DU9@0Ti>C092@T02IVIT0S8b<08f=S@2:RXX0
T92@0P2?Shl01P23Ph<0Q8B40820P027QhL0PX:207emO@80Ph>300d0PX:207]kN`20P800N7Qh0820
P01kNg/0NGUi07inOP1cLg<0LW9b07IfMP1aLG40N7Qh0080M7Ad01h0KVi^07]kN`1_Kfl0JVYZ07Ad
M01]KFd0L71`07QhN01^KVh0Lg=c06][J`1dM7@0Kfm_06UYJ@1^KVh0Jf][075aL@1YJFT0IVIV06a/
K01TI6@0Hf=S065QH@1[Jf/0I6AT06IVIP1XJ6P0Hf=S069RHP1SHf<206IVIP0606QXJ01TI6@0IVIV
06IVIP1SHf<0IVIV0P1TI6@00`1WIfL0IVIV065QH@0G000000H0fMWI0@0000010=WIf@005P3IfMT0
0`000000fMWI0=WIf@030=WIf@0;0>g]k@1/K6`0I6AT06=SH`1WIfL0K6a/06IVIP1YJFT0Hf=S06a/
K01`L7000`1YJFT0501^KVh0K6a/06i^KP1YJFT0K6a/06UYJ@1/K6`0KVi^06m_K`1fMWH0J6QX071`
L01[Jf/0JFUY06i^KP1TI6@0Lg=c06UYJ@1[Jf/0JVYZ0P1^KVh02P1hN7P0NWYj07QhN01cLg<0LW9b
07AdM01iNGT0N7Qh07EeM@1jNWX207UiN@0507QhN01eMGD0L71`06i^KP1/K6`00P1fMWH0;@1gMgL0
NGUi07alO021PH40NGUi07alO025QHD0MgMg08>3P`26QXH0QhN707inOP29RHT0PX:208F5Q@26QXH0
SXj>08B4Q028R8P0RHV908>3P`2>SXh0Ti>C08^;R`2EUID0TY:B08b<S02HV9P0TI6A09RHV02IVIT0
X:2P09NGU`2OWil0VIVI0:>SX`2PX:00YZJV0:NWY`2YZJT0Z:RX0:JVYP2/[:`0XZ:R0:BTY0020:^[
Z`0>0:b/[02d];@0]KFe0;^k^`31`L40d=3@0<;2`P2i^KT0bl_;0<[:bP3AdM40e=CD0=?Cd`3UiND2
0=cLg00:0=oOg`3[jn/0hN7Q0>GUi@3Xj>P0jn_[0?knoP3hn?P0no_k0?gmoBX0oooo00T0no_k0?[j
nP3hn?P0l?3`0>_[j`3`l?00k^k^0?3`l03[jn/00P3Vi^H01P3Lg=`0h>3P0=KFeP3Cdm<0f][J0=CD
e080bl_;00`0b/[:0<K6aP34a<@0bl_;0;bl_02m_Kd0_;bl0<71`@2`/;00/k>c0;6a/@2c/k<20:b/
[00N0:^[Z`2YZJT0XZ:R0:2PX02TY:@0XJ6Q09^KV`2JVYX0Xj>S0:6QX@2DU9@0UYJF09VIV@2?Shl0
SXj>08Z:RP2KVi/0Shn?096AT@26QXH0SHf=08^;R`24Q8@0RHV907inOP2:RXX0Q8B408J6QP29RHT0
OWin0P20P8009@1kNg/0OWin07emO@1kNg/0OWin07MgM`1iNGT0OWin07emO@1hN7P0Lg=c075aL@1`
L700LW9b07IfMP1aLG40K6a/06i^KP1hN7P0KVi^07IfMP1XJ6P0K6a/075aL@1hN7P0Lg=c06m_K`1Z
JVX0KVi^06a/K01XJ6P0L71`06e]K@1/K6`0KVi^06ATI01[Jf/00`1TI6@00`1UIFD0J6QX06=SH`02
065QH@0;06QXJ01/K6`0I6AT061PH01RHV80JVYZ06UYJ@1KFe/0H61P06ATI01OGel05`0000060=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT02@3[jn/0IFEU06ATI01PH600I6AT
06QXJ01YJFT0I6AT061PH00206UYJ@0H06IVIP1dM7@0Jf][06][J`1bLW80HV9R06EUI@1VIVH0L71`
06][J`1`L700KVi^075aL@1`L700MWIf071`L01dM7@0K6a/06i^KP1bLW80IfMW079bLP1cLg<0L71`
0P1iNGT03P1aLG40MWIf07QhN01`L700MgMg07AdM01fMWH0M7Ad07alO01hN7P0MWIf08>3P`1eMGD0
KVi^0P1eMGD0;`1dM7@0MWIf07IfMP1hN7P0QhN707YjNP21PH40OWin07QhN01lO7`0QXJ60861P@2>
SXh0Shn?0861P@28R8P0QhN7092@T025QHD0RHV908>3P`2<S8`0Rh^;08n?S`2BTY80TI6A09>CT`2E
UID0TI6A09RHV02GUiL0WIfM09BDU02FUYH0VIVI09^KV`2NWYh0WinO09^KV`2OWil0Y:BT0::RXP2Z
ZZX0Xj>S0:b/[02ZZZX0[Jf]0080/[:b00@0^;Rh0;Jf]P2n_[h0_Kfm0P36a/H00`34a<@0b<S80<_;
b`020<k>cP0>0=_Kf`3De=@0f=SH0=CDe03Kfm/0hN7Q0>c/k03Vi^H0j^[Z0>_[j`3emOD0n_[j0?kn
oP3inOT/0?ooo`080?Cdm03lo?`0o_kn0?KfmP3gmoL0m?Cd0?7al@3YjNT20>[ZjP090=gMg@3IfMT0
gMgM0=7Ad@3GemL0f=SH0=3@d03Cdm<0d];B0080bl_;00/0a<C40;bl_02n_[h0^KVi0;Jf]P2k^k/0
[:b/0;Bd]02`/;00[:b/0:f][@020:VYZ@050:NWY`2YZJT0[jn_0:BTY02IVIT00P2QXJ40702LW9`0
TY:B09VIV@2MWId0SHf=08n?S`2>SXh0Shn?09>CT`2;Rh/0Ti>C08B4Q02>SXh0QhN708J6QP23Ph<0
QXJ608>3P`21PH40OWin08b<S01lO7`0PX:207alO01kNg/0OWin07emO@1kNg/207alO00706i^KP1m
OGd0NGUi07YjNP1cLg<0OGem079bLP0207]kN`0C079bLP1cLg<0Lg=c06YZJP1^KVh0Lg=c06m_K`1Z
JVX0K6a/07=cL`1^KVh0K6a/06QXJ01SHf<0Jf][06QXJ01UIFD0KVi^06EUI@0206QXJ00<06e]K@1^
KVh0IVIV06QXJ01/K6`0JFUY06][J`1SHf<0J6QX06MWI`1[Jf/0J6QX0P1PH6001@1UIFD0IVIV05iN
GP1QHF40Fe]K01L000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0100
j>SX065QH@1SHf<0K6a/06IVIP1YJFT0K6a/06MWI`1[Jf/0Kfm_06i^KP1[Jf/0KFe]06UYJ@1XJ6P0
K6a/0P1ZJVX02@1/K6`0J6QX06m_K`1VIVH0Kfm_071`L01^KVh0K6a/071`L00206e]K@0D07=cL`1`
L700LW9b06i^KP1eMGD0MWIf071`L01cLg<0MgMg06m_K`1dM7@0NWYj07]kN`1^KVh0NGUi07AdM01h
N7P0NGUi07YjNP1kNg/407=cL`07075aL@1hN7P0Ng]k07EeM@1hN7P0O7al07QhN00207UiN@80Q8B4
02X0QhN708F5Q@21PH40RHV908J6QP29RHT0SHf=08V9R@2;Rh/0TI6A09JFUP2BTY80RHV909FEU@2D
U9@0Ti>C09BDU02PX:00WIfM09NGU`2HV9P0X:2P09RHV02KVi/0VIVI0:6QX@2VYZH0XJ6Q0:^[Z`2V
YZH0[:b/0:JVYP2YZJT0[jn_0;>c/`2XZ:P0]kNg0;>c/`2g]kL0`/;20;jn_P2i^KT20<?3``0<0<;2
`P38b<P0a/K60=7Ad@3Ng]h0emOG0=gMg@3Fe]H0g]kN0=cLg03WinL0kNg]0P3^k^h00`3clo<0o?cl
0?ooo`0`0?ooo`0=0?knoP3dm?@0moOg0?knoP3Zj^X0jn_[0>k^kP3]kNd0iNGU0=gMg@3Kfm/0f=SH
0=3@d0020=CDe0070=3@d036a/H0c/k>0<?3``31`L40][Jf0;^k^`020;fm_@090;^k^`2h^;P0^k^k
0:j^[P2f][H0YZJV0:FUY@2NWYh0Z:RX0080Xj>S0P2QXJ401P2IVIT0UYJF09bLW02LW9`0UIFE09nO
W`80T92@00h0Ti>C08^;R`2>SXh0RHV909>CT`2=SHd0R8R808V9R@2;Rh/0PX:208B4Q01mOGd0SHf=
07UiN@<0Ng]k00<0PX:207]kN`20P8000P23Ph<00`1lO7`0LW9b07=cL`0207IfMP0907QhN01aLG40
Kfm_07=cL`1iNGT0MWIf06i^KP1_Kfl0K6a/0080LG5a00D0KVi^06e]K@1YJFT0L71`06i^KP0206a/
K00706MWI`1TI6@0KVi^06YZJP1RHV80I6AT06UYJ@0206YZJP0C06UYJ@1WIfL0IfMW065QH@1IFET0
HF5Q06IVIP1WIfL0HF5Q06UYJ@1VIVH0JFUY05iNGP1QHF40GUiN06IVIP1SHf<0HV9R06EUI@0G0000
00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@090>_[j`1TI6@0JFUY06YZ
JP1QHF40IVIV06][J`1XJ6P0KVi^0080J6QX01T0Kfm_06MWI`1ZJVX0KFe]06ATI01YJFT0J6QX06YZ
JP1XJ6P0JFUY06i^KP1[Jf/0K6a/071`L01aLG40L71`06UYJ@1aLG40L71`06QXJ01dM7@0Lg=c06i^
KP1dM7@0MWIf0080L71`00<0LG5a06e]K@1_Kfl00P1dM7@04`1cLg<0MWIf07emO@1oOgl0NWYj08>3
P`1lO7`0Ng]k07IfMP22PX80M7Ad07UiN@1nOWh0P82007inOP1dM7@0Ng]k07emO@1nOWh00P23Ph<0
9@29RHT0QXJ60861P@29RHT0T92@08N7Q`2:RXX0Rh^;08j>SP28R8P0SHf=08b<S028R8P0Shn?08^;
R`2=SHd0Shn?09JFUP2IVIT0WYjN09^KV`2HV9P0Y:BT0:6QX@2OWil0XJ6Q09nOW`2SXj<0WYjN0;6a
/@2b/[80ZJVY0;6a/@2VYZH0[Jf]0;:b/P2d];@00P2l_;`04P30`<00_;bl0;^k^`31`L40_[jn0<;2
`P34a<@0c/k>0<_;b`3@d=00dm?C0=kNgP3Ogml0fm_K0>KViP3YjNT0i>CT0>WYj@80k^k^00<0n_[j
0?ooo`3oool0;`3oool20?knoP0:0?ooo`3moOd0no_k0?Shn03fm_H0k^k^0>?Sh`3YjNT0inOW0=;B
dP80emOG00`0c/k>0<_;b`3<c<`0bLW90<30`034a<@0_;bl0;jn_P2m_Kd0`<300;Jf]P2e]KD20;6a
/@0N0:VYZ@2a/K40[:b/0:f][@2VYZH0X:2P0::RXP2NWYh0X:2P09nOW`2NWYh0WIfM09JFUP2DU9@0
TI6A09bLW02?Shl0V9RH09>CT`2HV9P0Ti>C08b<S02ATI40R8R808^;R`29RHT0P8200861P@27QhL0
Q8B40P21PH401@20P800Ogmo0861P@1kNg/0M7Ad0080P82000@0O7al07inOP20P800NGUi0P1hN7P0
401dM7@0Lg=c07UiN@1gMgL0Lg=c075aL@1cLg<0JFUY071`L01bLW80Lg=c06a/K01fMWH0LG5a06i^
KP1cLg<206QXJ00K06IVIP1RHV80J6QX06UYJ@1/K6`0Jf][06i^KP1WIfL0Kfm_05eMG@1SHf<0HV9R
06IVIP1QHF40IFEU069RHP1OGel0IVIV061PH01WIfL0IFEU05aLG01TI6@0IVIV06QXJ01IFET0H61P
01L000001P3IfMT100000040fMWI000F0=WIf@800000103IfMT09@3QhN40J6QX06i^KP1^KVh0JFUY
06][J`1bLW80IVIV06][J`1VIVH0KVi^079bLP1^KVh0JVYZ06ATI01dM7@0IVIV06i^KP1UIFD0Kfm_
06QXJ01UIFD0Lg=c06YZJP1/K6`0Jf][079bLP1XJ6P0LW9b06UYJ@1bLW80K6a/071`L01hN7P0NWYj
07AdM01iNGT00P1fMWH0701dM7@0KVi^07QhN01aLG40MWIf07UiN@1jNWX0O7al0861P@1fMWH0O7al
07YjNP1eMGD0M7Ad07QhN01nOWh0M7Ad07inOP1lO7`0NGUi07inOP1gMgL0Ogmo07inOP29RHT0Ph>3
08R8R02@T90208V9R@0@08b<S029RHT0RXZ:08V9R@28R8P0TI6A08j>SP2;Rh/0SXj>09ZJVP2GUiL0
W9bL09RHV02OWil0WYjN0:>SX`80U9BD00<0V9RH09bLW02SXj<00P2VYZH07P2YZJT0Y:BT0:ZZZP2/
[:`0];Bd0;>c/`2][Jd0^k^k0;fm_@2l_;`0`L710;bl_030`<00`l?30<S8b03=cLd0bLW90<[:bP3I
fMT0emOG0=KFeP3Lg=`0e]KF0>KViP3Shn<0inOW0>k^kP3/k>`0n?Sh0?Win@80oooo00<0o_kn0?oo
o`3oool0;P3oool0103no_h0oooo0?ooo`3no_h20?ooo`0G0?Win@3/k>`0inOW0>o_k`3Vi^H0hn?S
0=WIf@3Lg=`0emOG0=7Ad@35aLD0b/[:0<W9b@3:b/X0bLW90<o?c`2h^;P0_;bl0;Vi^@2d];@0/K6a
0:b/[02`/;000P2[Zj/0402TY:@0[:b/0:RXZ02SXj<0XZ:R09fMW@2QXJ40X:2P09bLW02NWYh0WinO
09VIV@2>SXh0V9RH09JFUP2HV9P2092@T00Y08N7Q`2DU9@0Rh^;07moO`29RHT0QXJ608F5Q@24Q8@0
PX:20861P@1aLG40Ogmo07alO01nOWh0Ng]k08>3P`1hN7P0NGUi07QhN01fMWH0Ng]k07=cL`1lO7`0
NGUi07emO@1iNGT0LW9b07=cL`1eMGD0Jf][06a/K01[Jf/0Lg=c071`L01aLG40KVi^06YZJP1`L700
JFUY071`L01VIVH00P1^KVh06P1[Jf/0IVIV06QXJ01WIfL0JFUY06a/K01XJ6P0Hf=S06QXJ01WIfL0
IVIV06=SH`1QHF40I6AT06a/K01QHF40IVIV06ATI01RHV80H61P06=SH`1LG5`0IVIV06MWI`1QHF40
HV9R5`0000050=WIf@8000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT04`3Xj>P0IVIV
06IVIP1TI6@0JFUY061PH01TI6@0Hf=S06ATI01WIfL0I6AT06][J`1WIfL0Jf][06a/K01YJFT0J6QX
06EUI@1XJ6P00P1^KVh03@1aLG40MWIf07AdM01dM7@0MWIf075aL@1^KVh0L71`07QhN01^KVh0K6a/
06i^KP1aLG400P1eMGD0201aLG40Lg=c07IfMP1fMWH0MgMg07UiN@1`L700KFe]0P1dM7@08`1hN7P0
NGUi0820P01iNGT0LW9b07IfMP1kNg/0NWYj07alO01kNg/0Ph>307inOP23Ph<0MGEe07]kN`1mOGd0
Ph>308J6QP29RHT0P82008R8R02;Rh/0S8b<08B4Q02;Rh/0RHV9092@T02=SHd0Rh^;096AT@2=SHd0
TI6A092@T02EUID0TY:B0080W9bL00D0Y:BT09>CT`2JVYX0V9RH09VIV@0209^KV`0P09jNWP2QXJ40
[Zj^0;Fe]@2WYjL0_;bl0:f][@2/[:`0/k>c0;Ng]`2o_kl0`<300;jn_P2m_Kd0`L710<W9b@3:b/X0
c<c<0<K6aP39bLT0dM7A0=KFeP3Ng]h0fMWI0>GUi@3[jn/0j^[Z0>c/k03]kNd0moOg0?knoP3moOdh
0?ooo`80no_k01`0l?3`0>_[j`3_knl0m?Cd0>WYj@3Jf]X0hN7Q0=_Kf`3Jf]X0dm?C0<k>cP3;bl/0
clo?0=7Ad@37alL0`<300<;2`P2l_;`0^k^k0;Jf]P2c/k<0/;2`0;6a/@2/[:`0/[:b0:VYZ@2[Zj/0
[Jf]0P2SXj<209jNWP0Q09ZJVP2IVIT0Vi^K09JFUP2DU9@0Ti>C092@T02ATI40T92@08j>SP2:RXX0
T92@08J6QP2:RXX0S8b<08V9R@28R8P0RHV90861P@1lO7`0PH6107]kN`1lO7`0PH6107moO`1jNWX0
OGem07YjNP1iNGT0O7al07MgM`1fMWH0NGUi00<0MWIf0140N7Qh06m_K`1cLg<0Ng]k06UYJ@1[Jf/0
JVYZ06a/K01dM7@0KFe]06IVIP1/K6`0J6QX06e]K@1[Jf/0Kfm_06i^KP0206IVIP0706YZJP1UIFD0
KVi^06ATI01SHf<0I6AT06QXJ00206ATI00?06QXJ01PH600IFEU069RHP1WIfL0H61P06QXJ01YJFT0
I6AT06MWI`1VIVH0H61P05mOG`1NGUh0FEUI01L000001P3IfMT100000040fMWI000F0=WIf@030000
003IfMT0fMWI00<0fMWI02D0j>SX06e]K@1aLG40IVIV06MWI`1YJFT0IVIV06][J`1VIVH0JFUY06e]
K@1[Jf/0IFEU06MWI`1YJFT0J6QX06i^KP1XJ6P0Jf][071`L01/K6`0L71`07QhN01[Jf/0L71`06i^
KP1`L700K6a/06e]K@1_Kfl0Lg=c06QXJ01aLG40LW9b07]kN`1cLg<0MWIf0080LW9b0P1cLg<01`1f
MWH0L71`07IfMP1hN7P0MgMg0820P01iNGT00P1fMWH02`1`L700N7Qh07YjNP1mOGd0M7Ad0820P01h
N7P0PX:20861P@1gMgL0Ng]k0080P82002<0SHf=092@T02;Rh/0Rh^;08Z:RP2<S8`0SXj>092@T029
RHT0QXJ608b<S02ATI40Rh^;08b<S02>SXh0UYJF092@T02FUYH0U9BD09RHV02IVIT0W9bL09JFUP2H
V9P0Vi^K0:2PX02TY:@0X:2P0::RXP2XZ:P0]kNg0;Bd]02WYjL0/[:b0;Ng]`020;Jf]P0F0;>c/`2h
^;P0`l?30;jn_P30`<00`l?30<k>cP3<c<`0alO70=7Ad@3@d=00dm?C0=_Kf`3Ogml0iNGU0>WYj@3`
l?00j>SX0>[ZjP3no_h0oooo0?knoSP0oooo00T0n_[j0?gmo@3/k>`0lO7a0>[ZjP3alO40h^;R0>WY
j@3MgMd00P3Kfm/03@3De=@0clo?0=KFeP3<c<`0b<S80<?3``31`L40a<C40;^k^`2l_;`0][Jf0;^k
^`2e]KD00P2c/k<06P2YZJT0YZJV0:n_[`2XZ:P0ZZZZ09jNWP2PX:00VYZJ09VIV@2MWId0VIVI09RH
V02CTi<0UYJF09>CT`2>SXh0TI6A08f=S@2;Rh/0S8b<08j>SP28R8P0SHf=08>3P`28R8P0OGem0P22
PX805021PH40OGem08J6QP1nOWh0OGem07inOP1mOGd0OWin07IfMP1nOWh0NGUi075aL@1iNGT0MgMg
07AdM01bLW80MGEe07QhN01^KVh0MWIf0P1/K6`06P1^KVh0Kfm_075aL@1[Jf/0L71`06i^KP1YJFT0
J6QX06a/K01XJ6P0HV9R06IVIP1_Kfl0K6a/06=SH`1QHF40K6a/06UYJ@1SHf<0J6QX06=SH`1VIVH0
IFEU06IVIP1]KFd0Hf=S0P1PH6001`1TI6@0HF5Q05iNGP1VIVH0HF5Q06IVIP1KFe/00P1SHf<G0000
00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@040>[ZjP1`L700K6a/06MW
I`80JFUY00T0IVIV06ATI01[Jf/0IVIV06YZJP1/K6`0JFUY06i^KP1`L7000P1[Jf/01@1^KVh0Jf][
071`L01^KVh0MWIf0080KFe]00L0J6QX06i^KP1/K6`0L71`06][J`1^KVh0Lg=c0080K6a/00D0JFUY
06i^KP1hN7P0NWYj07QhN00207=cL`0E07EeM@1dM7@0MgMg07AdM01jNWX0OGem075aL@1kNg/0MGEe
07]kN`1bLW80N7Qh07UiN@1oOgl0OGem07QhN022PX80O7al0820P01gMgL0Ng]k0080Ph>30140PH61
08b<S02EUID0Ph>3092@T02>SXh0Rh^;08b<S02>SXh0UYJF08b<S029RHT0R8R809:BTP2IVIT0UiNG
09VIV@0209JFUP0409>CT`2NWYh0TI6A09ZJVP80Ti>C00X0T92@09VIV@2RXZ80YJFU0:>SX`2b/[80
[Zj^0:^[Z`2h^;P0ZJVY0P2j^[X03`2n_[h0^[Zj0<;2`P2i^KT0`L710<W9b@3>c/h0clo?0<c<c03@
d=00e=CD0=cLg03MgMd0inOW0?;blP020>k^kP80n?Sh00<0no_k0?ooo`3oool0>@3oool0A@3moOd0
m?Cd0?clo03alO40jn_[0>CTi03`l?00g=cL0>_[j`3Shn<0h>3P0<g=c@3Lg=`0emOG0=7Ad@30`<00
`l?30<W9b@36a/H0_[jn0;^k^`2m_Kd0]KFe0;Rh^02`/;00/K6a0:b/[02SXj<0Z:RX0:NWY`2KVi/0
Z:RX0:FUY@2MWId0Z:RX09VIV@2MWId0UYJF09VIV@2DU9@0W9bL09JFUP2<S8`0Rh^;096AT@2EUID0
Shn?08V9R@2BTY80Rh^;08Z:RP20P800SXj>0861P@25QHD0P82007inOP1fMWH0OWin07IfMP1kNg/0
M7Ad07]kN`1hN7P0OWin07IfMP1eMGD0MWIf07=cL`0207QhN00I07AdM01fMWH0Jf][075aL@1lO7`0
LG5a06m_K`1^KVh0KFe]06UYJ@1aLG40IfMW06a/K01`L700Kfm_06QXJ01[Jf/0J6QX06][J`1_Kfl0
LG5a06][J`1VIVH0KVi^06ATI00206i^KP0406UYJ@1ZJVX0IVIV06][J`80H61P00P0I6AT06][J`1T
I6@0HF5Q06EUI@1SHf<0HF5Q05iNGQL000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0
fMWI00<0fMWI00d0h^;R06IVIP1OGel0JFUY06QXJ01UIFD0Hf=S06IVIP1UIFD0Kfm_06UYJ@1XJ6P0
LG5a0080K6a/00l0L71`06ATI01VIVH0KVi^071`L01^KVh0K6a/06][J`1`L700MgMg06i^KP1XJ6P0
JFUY07AdM01`L7000P1[Jf/05@1aLG40L71`071`L01fMWH0Lg=c075aL@1hN7P0MWIf07UiN@1bLW80
N7Qh07IfMP1eMGD0MWIf07QhN01kNg/0M7Ad07MgM`1oOgl0M7Ad07MgM`0207inOP0907QhN01mOGd0
OGem07YjNP1oOgl0MGEe08V9R@1kNg/0RHV90080QXJ600l0RHV908n?S`2<S8`0SHf=08b<S02>SXh0
QhN709:BTP2=SHd0T92@08n?S`2HV9P0WYjN09JFUP2ATI400P2DU9@08`2=SHd0T92@09VIV@2DU9@0
VIVI0:6QX@2LW9`0Vi^K0:2PX02QXJ40YJFU0:b/[02`/;00]KFe0;:b/P2^[Zh0][Jf0<30`02g]kL0
_;bl0;no_`37alL0bLW90<c<c03De=@0bl_;0=7Ad@3Ng]h0g=cL0>KViP3Hf=P0k^k^0>WYj@3dm?@0
o?cl03h0oooo00<0oOgm0?Win@3kno/00P3_knl03P3/k>`0i>CT0>[ZjP3Vi^H0e]KF0<k>cP3Fe]H0
bLW90<K6aP33`l<0bl_;0<O7a`2k^k/0^;Rh0P2l_;`05`2d];@0]kNg0:RXZ02WYjL0/;2`0:6QX@2T
Y:@0YZJV0:6QX@2HV9P0YjNW09bLW02PX:00UiNG09RHV02FUYH0Ti>C09NGU`2FUYH0T92@08n?S`28
R8P0QXJ60080RHV900P0R8R808b<S024Q8@0RXZ:07UiN@25QHD0OWin08F5Q@80P82000H0Q8B407al
O01lO7`0Ng]k07UiN@1kNg/2071`L00507=cL`1eMGD0MGEe07]kN`1gMgL00P1fMWH01`1^KVh0LW9b
06UYJ@1dM7@0Jf][06m_K`1^KVh00P1`L700501YJFT0J6QX06a/K01_Kfl0Jf][06e]K@1YJFT0Jf][
06=SH`1/K6`0HF5Q06QXJ01]KFd0L71`06QXJ01PH600Jf][06UYJ@1VIVH0JFUY0P1RHV8206IVIP07
05UIF@1RHV80HF5Q05eMG@1QHF40IfMW05eMG@0G000000H0fMWI0@0000010=WIf@005P3IfMT00`00
0000fMWI0=WIf@030=WIf@030>WYj@1PH600IFEU0080KVi^00P0JVYZ06UYJ@1XJ6P0KFe]06ATI01`
L700I6AT06e]K@80Jf][00P0JFUY06e]K@1YJFT0K6a/075aL@1[Jf/0Lg=c06QXJ080KVi^0180JVYZ
06UYJ@1]KFd0M7Ad06e]K@1cLg<0NGUi07=cL`1gMgL0N7Qh07emO@1dM7@0N7Qh07MgM`1`L700Ng]k
07=cL`1nOWh307IfMP0@07alO01cLg<0MGEe071`L01kNg/0OWin08F5Q@1lO7`0P82007]kN`22PX80
OGem07inOP20P800QhN70861P@80QhN70140SXj>08f=S@2=SHd0T92@09JFUP2=SHd0U9BD092@T02;
Rh/0TI6A08V9R@2FUYH0VIVI09JFUP2DU9@0VYZJ09^KV`0209RHV004096AT@2FUYH0VYZJ09BDU080
WinO00h0WIfM0:ZZZP2JVYX0W9bL0:JVYP2ZZZX0[Jf]0;Bd]02l_;`0/[:b0;Jf]P30`<00_[jn0<?3
``80`<3000<0bl_;0=?Cd`3@d=000P3Fe]H0103Ti>@0hN7Q0>CTi03[jn/20?7al@030?_kn`3jn_X0
o_kn03h0oooo00h0m?Cd0?ooo`3emOD0l?3`0>WYj@3clo<0j>SX0=_Kf`3Ph>00gMgM0<W9b@3Cdm<0
d];B0=KFeP80a/K601d0^[Zj0<71`@2o_kl0_;bl0;>c/`2e]KD0/k>c0:^[Z`2a/K40[Zj^0;2`/02P
X:00YZJV09JFUP2QXJ40WinO09JFUP2GUiL0X:2P09RHV02EUID0U9BD09:BTP2ATI40Vi^K08j>SP26
QXH0TY:B08R8R00208>3P`0508B4Q028R8P0OWin0820P01mOGd00P23Ph<06@24Q8@0Ph>307UiN@1m
OGd0Q8B407UiN@22PX80NWYj07moO`1hN7P0NGUi07AdM01iNGT0M7Ad079bLP1`L700MgMg07=cL`1f
MWH0Jf][071`L01^KVh0JVYZ06a/K01fMWH00P1XJ6P04P1ZJVX0KVi^06IVIP1/K6`0JFUY06][J`1a
LG40JVYZ06a/K01`L700IVIV06UYJ@1VIVH0Jf][06=SH`1TI6@0Hf=S06UYJ@80J6QX00D0GemO06AT
I01SHf<0IVIV061PH00205iNGP0306=SH`1TI6@0000001H000001P3IfMT100000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI00<0j^[Z06i^KP1YJFT00P1^KVh0101/K6`0KFe]069RHP1YJFT2
06][J`0M06QXJ01_Kfl0Jf][06a/K01aLG40IVIV06QXJ01eMGD0MWIf079bLP1aLG40K6a/06IVIP1X
J6P0L71`06i^KP1YJFT0L71`06UYJ@1gMgL0MWIf06m_K`1eMGD0MWIf07YjNP1dM7@0MWIf07QhN01f
MWH00`1jNWX02P1nOWh0Lg=c07]kN`1kNg/0MgMg07=cL`1dM7@0NGUi07YjNP1hN7P20861P@0;08B4
Q020P800S8b<07]kN`22PX80P82008B4Q01oOgl0RXZ:08b<S02;Rh/00P2>SXh0102BTY80RHV908Z:
RP2;Rh/208j>SP0408V9R@2FUYH0X:2P09ZJVP80Vi^K00X0V9RH09VIV@2FUYH0TY:B096AT@2GUiL0
YZJV09nOW`2UYJD0YZJV0`2PX:002@2VYZH0[:b/0:n_[`2n_[h0[jn_0;6a/@2i^KT0`<300;fm_@02
0<?3``0>0<k>cP39bLT0bl_;0=7Ad@3Hf=P0g]kN0=gMg@3]kNd0i^KV0>?Sh`3hn?P0o?cl0?Win@3j
n_Y00?ooo`0f0?Gem@3fm_H0m?Cd0>WYj@3bl_80i>CT0>3Ph03Jf]X0gmoO0>;RhP3;bl/0clo?0=CD
e039bLT0`l?30<30`036a/H0^KVi0;Jf]P2[Zj/0[jn_0:j^[P2k^k/0Z:RX0;2`/02XZ:P0ZJVY0:RX
Z02QXJ40XZ:R09nOW`2RXZ80V9RH09jNWP2IVIT0X:2P09>CT`2>SXh0Ti>C09:BTP2ATI40QXJ608F5
Q@28R8P0SHf=08>3P`20P800PX:207inOP1mOGd0O7al08>3P`1nOWh0PH610P23Ph<03@1nOWh0N7Qh
08:2PP1jNWX0MWIf07inOP1gMgL0M7Ad07QhN01iNGT0MWIf07EeM@1]KFd00P1aLG403@1`L700NWYj
07QhN01^KVh0L71`075aL@1eMGD0K6a/06e]K@1/K6`0MGEe06EUI@1PH6000P1XJ6P03@1[Jf/0JVYZ
06QXJ01UIFD0KFe]06QXJ01PH600IVIV065QH@1VIVH0JVYZ06UYJ@1RHV800P1SHf<0201XJ6P0JVYZ
06MWI`1SHf<0HV9R06ATI01PH600I6AT5`0000060=WIf@4000000@3IfMT001H0fMWI00<000000=WI
f@3IfMT00`3IfMT04@3_knl0IVIV075aL@1UIFD0JFUY05aLG01^KVh0Jf][06MWI`1UIFD0IVIV06YZ
JP1VIVH0K6a/06UYJ@1ZJVX0JFUY0080Kfm_02X0M7Ad06MWI`1ZJVX0K6a/071`L01bLW80Kfm_071`
L01VIVH0K6a/06QXJ01aLG40K6a/079bLP1eMGD0PX:207alO01cLg<0KVi^079bLP1hN7P0MWIf07Ee
M@1iNGT0Ogmo07QhN01eMGD0MWIf07alO01aLG40OGem07alO01fMWH0OWin07QhN01gMgL0PH6107em
O@1iNGT0O7al0820P01iNGT20861P@0808J6QP2<S8`0QXJ608f=S@2<S8`0UiNG08Z:RP2BTY8209FE
U@0308V9R@2FUYH0T92@00<0UYJF00T0WYjN09BDU02DU9@0UYJF08n?S`2HV9P0XJ6Q0:JVYP2ZZZX0
0P2UYJD20:JVYP0G0:^[Z`2XZ:P0[:b/0:f][@2h^;P0][Jf0<71`@2h^;P0_kno0<C4a03;bl/0cLg=
0<W9b@3IfMT0e]KF0=cLg03Kfm/0fMWI0>KViP3[jn/0jNWY0?Shn03[jn/00P3lo?a20?ooo`0e0?cl
o03WinL0lo?c0?;blP3[jn/0hn?S0=oOg`3Lg=`0fMWI0=SHf03=cLd0bl_;0<o?c`36a/H0c<c<0<C4
a02j^[X0_;bl0;Zj^P2d];@0/;2`0;Ng]`2a/K40ZJVY0::RXP2TY:@0YjNW09jNWP2PX:00VYZJ0:>S
X`2DU9@0W9bL09FEU@2PX:00V9RH09VIV@2NWYh0SHf=092@T029RHT0Rh^;08R8R029RHT0Rh^;08B4
Q02:RXX0RHV908J6QP21PH40N7Qh08N7Q`21PH400P1iNGT04P1oOgl0N7Qh07UiN@1kNg/0N7Qh07mo
O`1hN7P0LG5a07QhN01cLg<0MgMg07=cL`1iNGT0MWIf075aL@1eMGD0MWIf06i^KP<0L71`00d0LG5a
06e]K@1YJFT0IfMW06EUI@1[Jf/0JFUY06a/K01UIFD0JFUY06YZJP1XJ6P0JFUY0080KVi^0140J6QX
069RHP1[Jf/0LG5a061PH01TI6@0Hf=S06e]K@1UIFD0IVIV06=SH`1QHF40Jf][06EUI@1LG5`0HF5Q
05iNGP0G000000H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0@0>OWi`1Y
JFT0JFUY06YZJP1]KFd0I6AT06UYJ@1_Kfl0J6QX06IVIP1WIfL0J6QX06i^KP1/K6`0Jf][06m_K`80
IVIV00T0Lg=c06a/K01/K6`0KVi^06YZJP1QHF40Hf=S06YZJP1YJFT00P1`L700301dM7@0JFUY06YZ
JP1fMWH0OGem07UiN@1oOgl0M7Ad07UiN@1mOGd0Lg=c07UiN@<0O7al00T0OWin07UiN@1dM7@0N7Qh
07]kN`1lO7`0NGUi07QhN01lO7`00P1jNWX0=01kNg/0P82007moO`20P800QXJ608>3P`28R8P0Q8B4
08>3P`26QXH0R8R808J6QP29RHT0S8b<092@T02EUID0T92@08j>SP2IVIT0T92@09FEU@2KVi/0WinO
09VIV@2HV9P0VIVI09RHV02;Rh/0Shn?09VIV@2UYJD0Y:BT0:ZZZP2YZJT0Xj>S0:b/[02^[Zh0WYjN
0:JVYP2b/[80][Jf0;^k^`35aLD0`<300;Fe]@2n_[h0a/K60<_;b`36a/H0b/[:0=?Cd`3Bd]820=kN
gP060>?Sh`3Xj>P0k^k^0>g]k@3fm_H0m?CdAP3oool03`3/k>`0kno_0>o_k`3WinL0g=cL0>OWi`3P
h>00emOG0<S8b03AdM40d];B0<S8b036a/H0b/[:0<;2`P020;bl_0040;6a/@2d];@0[Jf]0:n_[`80
ZZZZ02<0YZJV0:>SX`2LW9`0Zj^[0:RXZ02SXj<0W9bL0::RXP2PX:00UiNG09JFUP2DU9@0V9RH096A
T@28R8P0Ti>C08N7Q`29RHT0SXj>08R8R02<S8`0PX:208R8R026QXH0Ph>30861P@1iNGT0M7Ad07al
O01jNWX0OWin0861P@1nOWh0NGUi07moO`0207UiN@0=07]kN`1jNWX0MGEe07=cL`1bLW80Ogmo07Qh
N01iNGT0MWIf071`L01cLg<0LG5a071`L00206a/K00A06m_K`1`L700Jf][06IVIP1cLg<0L71`06QX
J01YJFT0K6a/06ATI01RHV80IVIV06UYJ@1UIFD0I6AT06=SH`1TI6@00P1WIfL01@1VIVH0HF5Q065Q
H@1RHV80IVIV0080Hf=S0P1NGUh00`1TI6@0HF5Q06=SH`0G000000H0fMWI0@0000010=WIf@005P3I
fMT00`000000fMWI0=WIf@030=WIf@0Z0>GUi@1ZJVX0JFUY06YZJP1WIfL0K6a/071`L01TI6@0Jf][
06YZJP1[Jf/0L71`069RHP1`L700JFUY06e]K@1/K6`0KVi^075aL@1/K6`0Jf][05eMG@1XJ6P0JVYZ
06][J`1YJFT0LW9b06a/K01`L700K6a/06i^KP1_Kfl0Lg=c06m_K`20P800Lg=c07MgM`1iNGT0K6a/
07YjNP1fMWH0NWYj0P1iNGT0801oOgl0Lg=c07alO01bLW80R8R807inOP26QXH0Ng]k08J6QP1kNg/0
NGUi08>3P`22PX80PH6108B4Q01nOWh0QHF508V9R@2;Rh/0U9BD08B4Q02;Rh/0TI6A08^;R`2=SHd0
TI6A09>CT`2HV9P0SHf=08j>SP2ATI40Ti>C0P2HV9P09@2GUiL0TY:B09JFUP2LW9`0UYJF09NGU`2Q
XJ40WinO0:j^[P2YZJT0[Zj^0:6QX@2[Zj/0[Jf]09bLW02WYjL0[Jf]0;Fe]@2d];@0]kNg0<71`@39
bLT0a<C40<K6aP3<c<`0b<S80<k>cP38b<P0gmoO0=CDe03MgMd0i>CT0>SXj03Zj^X0m_Kf0?_kn`3m
oOd0A@3oool01`3jn_X0o?cl0?Win@3alO40i>CT0>?Sh`3YjNT00P3IfMT01P3Cdm<0dM7A0<W9b@3@
d=00b<S80<c<c080_Kfm0`2i^KT0402`/;00]kNg0;2`/02VYZH0Zj^[0:ZZZP2VYZH0W9bL09VIV@2Q
XJ40VYZJ09jNWP2LW9`0UiNG09^KV`2LW9`2096AT@0609BDU02FUYH0RXZ:08f=S@2HV9P0R8R80P2<
S8`20861P@0W08N7Q`24Q8@0NWYj08>3P`1oOgl0NGUi07AdM01aLG40Ng]k07MgM`1hN7P0Q8B407Qh
N01mOGd0MWIf07=cL`1iNGT0LW9b07]kN`21PH40NGUi07AdM01bLW80Lg=c079bLP1_Kfl0KFe]07If
MP1^KVh0K6a/07UiN@1]KFd0IfMW075aL@1`L700J6QX06UYJ@1/K6`0J6QX0080I6AT00H0JFUY06IV
IP1VIVH0JFUY06QXJ01VIVH206ATI00:06EUI@1TI6@0J6QX06ATI01QHF40Hf=S06QXJ01LG5`0Hf=S
06IVIQL000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI01D0jn_[06EU
I@1[Jf/0IVIV06ATI01[Jf/0KFe]06IVIP1SHf<0JFUY06][J`1XJ6P0K6a/06YZJP1WIfL0Kfm_075a
L@1`L700KVi^071`L01^KVh00P1`L7004P1dM7@0J6QX06MWI`1fMWH0Jf][06i^KP1_Kfl0J6QX06a/
K01]KFd0M7Ad07=cL`1dM7@0LG5a06UYJ@1fMWH0NGUi07AdM080NGUi0140Ogmo07AdM01lO7`0OGem
07]kN`1lO7`0Ogmo0861P@1mOGd0N7Qh08B4Q01hN7P0OWin07moO`1kNg/0P82007moO`020861P@0?
08B4Q021PH40QXJ608J6QP2@T900QXJ608^;R`2=SHd0Ti>C092@T02CTi<0RHV9096AT@2BTY80VYZJ
0080U9BD00L0TI6A09NGU`2FUYH0SXj>09RHV02CTi<0Vi^K0080YZJV00H0/[:b0:VYZ@2][Jd0Z:RX
0:^[Z`2][Jd20:^[Z`0B0;fm_@33`l<0a/K60<C4a039bLT0`l?30<k>cP36a/H0dm?C0=SHf03Vi^H0
f][J0>CTi03YjNT0inOW0?KfmP3`l?00mOGeAP3oool0:P3no_h0oooo0?7al@3[jn/0inOW0>SXj03S
hn<0h>3P0=[JfP3Fe]H0f][J0=7Ad@36a/H0c<c<0=7Ad@3;bl/0_kno0;jn_P2h^;P0][Jf0;Vi^@2`
/;00/K6a0:ZZZP2a/K40YZJV0:VYZ@2UYJD0W9bL0:JVYP2NWYh0WIfM09ZJVP2LW9`0TY:B09ZJVP2;
Rh/0TI6A08>3P`2<S8`0TY:B08Z:RP80S8b<02H0RHV908>3P`20P800Ph>308J6QP24Q8@0OWin07mo
O`1lO7`0Ogmo07alO01iNGT0OWin07AdM01iNGT0N7Qh07UiN@1mOGd0NGUi07IfMP1eMGD0M7Ad07in
OP1kNg/0LG5a07UiN@1aLG40L71`06m_K`1cLg<0LG5a06m_K`1`L700MGEe06YZJP1aLG40J6QX06MW
I`80KFe]00/0Jf][06e]K@1[Jf/0IVIV06=SH`1QHF40JVYZ06MWI`1UIFD0JFUY06a/K002065QH@03
05iNGP1PH600FEUI0080I6AT00D0HF5Q05iNGP1SHf<0GUiN05aLG00G000000H0fMWI0@0000010=WI
f@005P3IfMT00`000000fMWI0=WIf@030=WIf@0P0?3`l01VIVH0KVi^06QXJ01cLg<0LG5a06UYJ@1V
IVH0KVi^06YZJP1_Kfl0KVi^06a/K01[Jf/0JFUY06i^KP1YJFT0KFe]06UYJ@1]KFd0K6a/06QXJ01_
Kfl0K6a/06][J`1UIFD0Jf][07AdM01`L700JFUY06IVIP1YJFT206i^KP03079bLP1`L700NWYj0080
M7Ad101fMWH02`1iNGT0N7Qh07alO01]KFd0LG5a07emO@1lO7`0QHF507inOP23Ph<0OWin0080O7al
01T0Ph>307inOP23Ph<0SXj>08V9R@28R8P0QXJ608V9R@26QXH0SXj>08Z:RP2@T900Rh^;08j>SP2=
SHd0SXj>09BDU02GUiL0Shn?09nOW`2CTi<0V9RH09JFUP2KVi/0VIVI0080Vi^K00h0W9bL09BDU02Q
XJ40Zj^[0:BTY02UYJD0XJ6Q0:VYZ@2NWYh0ZJVY0:^[Z`2a/K40^;Rh0;bl_080^[Zj00l0a<C40<G5
a@36a/H0dM7A0<_;b`3Cdm<0eMGE0=[JfP3Fe]H0jn_[0?7al@3inOT0n?Sh0?Win@3gmoL0A`3oool0
5P3kno/0n_[j0?Cdm03hn?P0l?3`0>WYj@3QhN40gMgM0=_Kf`3Lg=`0d];B0=KFeP3;bl/0bLW90<k>
cP2l_;`0/k>c0;Vi^@2f][H0/;2`0;Bd]02][Jd20:b/[00?0:6QX@2SXj<0Vi^K09JFUP2VYZH0W9bL
0:BTY02LW9`0U9BD092@T02IVIT0Vi^K08b<S02EUID0Rh^;0080U9BD0100T92@08b<S02;Rh/0Ph>3
0861P@29RHT0O7al0861P@1hN7P0NWYj07QhN022PX80OGem07AdM01iNGT0N7Qh0P1kNg/0101lO7`0
NWYj07inOP1iNGT307QhN00>079bLP1eMGD0MGEe07AdM01]KFd0IFEU075aL@1]KFd0M7Ad075aL@1`
L700J6QX06a/K01ZJVX206m_K`0?07AdM01[Jf/0KFe]06MWI`1ZJVX0KFe]06YZJP1[Jf/0H61P06UY
J@1XJ6P0IVIV06ATI01ZJVX0H61P0080IVIV00@0HV9R05eMG@1PH600IVIV0P1QHF400`1OGel00000
0000000E000000H0fMWI0@0000010=WIf@005P3IfMT2000000@0fMWI0180jNWY06e]K@1`L700J6QX
07=cL`1YJFT0IVIV06YZJP1cLg<0JVYZ071`L01]KFd0JVYZ06a/K01^KVh0IVIV06e]K@1WIfL206UY
J@80J6QX0180JFUY06MWI`1[Jf/0KVi^06m_K`1`L700LG5a06e]K@1YJFT0K6a/06YZJP1^KVh0L71`
06YZJP1nOWh0NGUi07QhN01aLG4207]kN`0406e]K@1fMWH0M7Ad07MgM`80OWin0240PX:207YjNP29
RHT0QhN70820P01kNg/0OGem08J6QP1oOgl0QHF508V9R@24Q8@0QhN708R8R022PX80RXZ:08F5Q@26
QXH0U9BD08j>SP2?Shl0U9BD09>CT`2;Rh/0UIFE08V9R@2KVi/0Shn?09jNWP2QXJ40W9bL09ZJVP2K
Vi/00P2MWId0102PX:00UYJF09nOW`2LW9`20:6QX@0H0:RXZ02TY:@0Xj>S0:BTY02^[Zh0^k^k0;Zj
^P2h^;P0a<C40<71`@2n_[h0aLG50<c<c03Cdm<0c/k>0=7Ad@3Kfm/0g=cL0=oOg`3`l?00k>c/0?Wi
n@3dm?@0o?clB03oool03P3inOT0oooo0?Ogm`3fm_H0i>CT0>[ZjP3Vi^H0fm_K0=oOg`3De=@0f][J
0=SHf03De=@0bLW90P35aLD02@2h^;P0^KVi0<30`02l_;`0^;Rh0:n_[`2f][H0[Zj^0:b/[0020:JV
YP0=0:2PX02QXJ40W9bL09bLW02NWYh0WIfM092@T02JVYX0Vi^K096AT@2<S8`0T92@08j>SP0208R8
R00C08^;R`2CTi<0P82008F5Q@26QXH0Ph>308:2PP21PH40N7Qh07alO01nOWh0OGem07QhN01lO7`0
MGEe07QhN01kNg/0NWYj07IfMP0307AdM00J07EeM@1iNGT0Kfm_06i^KP1bLW80Kfm_06a/K01_Kfl0
LW9b07AdM01aLG40IfMW071`L01/K6`0Jf][06UYJ@1[Jf/0KFe]06i^KP1eMGD0KVi^06QXJ01VIVH0
J6QX06][J`1YJFT206QXJ00:065QH@1VIVH0J6QX06a/K01YJFT0Fe]K06IVIP1UIFD0Hf=S06ATI080
IVIV00<0GUiN069RHP0000005P0000050=WIf@8000000@3IfMT001H0fMWI00<000000=WIf@3IfMT0
0`3IfMT0403Zj^X0K6a/06YZJP1/K6`0Jf][06YZJP1^KVh0I6AT06][J`1VIVH0K6a/06i^KP1/K6`0
L71`06][J`1^KVh206][J`80KVi^0100IVIV06=SH`1TI6@0L71`06][J`1bLW80IfMW071`L01]KFd0
JVYZ06i^KP1]KFd0L71`075aL@1eMGD0N7Qh0`1cLg<03P1aLG40NGUi07IfMP1iNGT0M7Ad07MgM`20
P800Ng]k07UiN@21PH40Q8B407inOP25QHD0Q8B40P21PH40;P1jNWX0Ph>308B4Q023Ph<0R8R808j>
SP29RHT0T92@08f=S@28R8P0TI6A09:BTP2;Rh/0U9BD08j>SP2<S8`0V9RH092@T02JVYX0T92@09^K
V`2@T900VIVI09RHV02NWYh0XJ6Q09VIV@2MWId0XJ6Q09fMW@2LW9`0VIVI09RHV02OWil0Xj>S0:b/
[02^[Zh0[:b/0;Jf]P2l_;`0a<C40;fm_@39bLT0`l?30<C4a03<c<`20<K6aP080<o?c`3IfMT0gMgM
0=kNgP3Lg=`0jn_[0?3`l03inOT20?clo0030?Win@3oool0oooo04D0oooo01h0o_kn0?clo03lo?`0
lO7a0>GUi@3_knl0jn_[0>WYj@3De=@0e]KF0=WIf@3AdM40c/k>0=CDe03=cLd0aLG50;bl_031`L40
_Kfm0;Rh^02a/K40[:b/0:RXZ02][Jd0[:b/0;>c/`2PX:00Z:RX0:ZZZP2EUID209VIV@0809bLW02C
Ti<0T92@09VIV@2FUYH0SXj>09BDU02>SXh209BDU00H08Z:RP29RHT0QhN708R8R024Q8@0R8R80820
P022PX80Ng]k08B4Q01gMgL0OGem0820P01kNg/0MgMg07UiN@1nOWh0NGUi07=cL`1aLG40NGUi06a/
K01cLg<0Kfm_0P1eMGD0301dM7@0Lg=c071`L01cLg<0M7Ad07IfMP1dM7@0L71`06YZJP1]KFd0KVi^
06QXJ080Jf][0180IVIV06UYJ@1[Jf/0IfMW06UYJ@1XJ6P0JVYZ06IVIP1XJ6P0JVYZ06ATI01YJFT0
I6AT06UYJ@1TI6@0J6QX06IVIP1TI6@206EUI@0406QXJ01TI6@0I6AT061PH1L000001P3IfMT10000
0040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0340l?3`06ATI01[Jf/0KFe]06i^KP1ZJVX0
J6QX075aL@1]KFd0KVi^06IVIP1YJFT0KFe]06a/K01^KVh0JVYZ06IVIP1`L700MGEe06UYJ@1VIVH0
K6a/06UYJ@1[Jf/0Kfm_079bLP1]KFd0JVYZ06e]K@1`L700Kfm_06QXJ01aLG40L71`06][J`1cLg<0
LG5a07alO01`L700NGUi07=cL`1hN7P0Ng]k07YjNP1iNGT0OGem07alO01iNGT0QXJ60080P82000@0
PH6108B4Q01nOWh0Q8B40P1nOWh00`2;Rh/0QHF508^;R`0208V9R@0F08^;R`25QHD0SXj>096AT@2;
Rh/0RXZ:08b<S02=SHd0Shn?09^KV`2GUiL0T92@09^KV`2ATI40WYjN09VIV@2LW9`0WYjN09nOW`2L
W9`0WYjN09^KV`80V9RH01H0Y:BT0:6QX@2TY:@0Vi^K0:RXZ02[Zj/0/K6a0;Jf]P2j^[X0`<300;Bd
]032`/80bLW90<K6aP38b<P0bLW90=?Cd`3Fe]H0dm?C0=cLg03Ph>00fMWI0P3/k>`0103^k^h0o_kn
0?[jnP3kno]80?ooo`0D0?clo03no_h0j^[Z0>;RhP3WinL0hN7Q0=kNgP3EeMD0iNGU0=oOg`3@d=00
dM7A0<[:bP2o_kl0^k^k0<71`@2i^KT0[Zj^0;Jf]P2a/K420:j^[P040;2`/02d];@0Y:BT0;2`/080
XJ6Q00P0XZ:R09bLW02OWil0V9RH0:6QX@2GUiL0TY:B09>CT`80T92@00T0S8b<09BDU02@T900UIFE
08J6QP29RHT0QhN708R8R024Q8@00`21PH401P1mOGd0N7Qh07IfMP1eMGD0L71`0820P080MgMg00L0
OGem07AdM01cLg<0NGUi07QhN01cLg<0M7Ad0080N7Qh02H0L71`07MgM`1aLG40M7Ad07=cL`1bLW80
KFe]071`L01eMGD0J6QX06a/K01_Kfl0Jf][06e]K@1_Kfl0L71`06i^KP1WIfL0J6QX06e]K@1ZJVX0
Jf][06MWI`1`L700IfMW06e]K@1VIVH0HF5Q06IVIP1XJ6P0H61P06=SH`1YJFT0HF5Q061PH01NGUh0
HF5Q05]KFaL000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00H0jNWY
06a/K01VIVH0KVi^06QXJ01RHV8206a/K00T06ATI01YJFT0IfMW071`L01ZJVX0L71`06QXJ01/K6`0
J6QX06m_K`1aLG40L71`06IVIP1[Jf/0Hf=S06a/K01XJ6P0LG5a06i^KP1`L700Lg=c06i^KP1XJ6P0
IVIV06YZJP1^KVh0MGEe07=cL`1aLG40NWYj07AdM01hN7P0Ng]k07emO@1nOWh0N7Qh0P21PH402`1k
Ng/0PH6107QhN020P800NGUi07inOP21PH40Q8B407moO`1nOWh0PX:20080RHV901`0PX:208F5Q@26
QXH0QhN708^;R`2<S8`0QXJ609:BTP2=SHd0UYJF0:2PX02CTi<0UYJF096AT@2@T900W9bL09JFUP2A
TI40VIVI09bLW02IVIT0XJ6Q0:2PX02SXj<0YJFU0:2PX02QXJ40Y:BT0P2YZJT02@2XZ:P0/K6a0;Bd
]02^[Zh0_Kfm0:n_[`2m_Kd0_kno0<C4a0020<?3``040<[:bP3<c<`0d];B0=KFeP80fm_K00T0jn_[
0>SXj03Ti>@0lO7a0?Win@3emOD0moOg0?ooo`3no_h0B03oool01P3jn_X0lo?c0>g]k@3Zj^X0i^KV
0=kNgP80g=cL00<0e]KF0=3@d03>c/h00P38b<P01`2a/K40/k>c0:j^[P2e]KD0][Jf0:n_[`2f][H0
0P2^[Zh02P2g]kL0ZJVY0;:b/P2XZ:P0WinO0:>SX`2RXZ80YjNW09ZJVP2DU9@209JFUP0909RHV02F
UYH0Ti>C08j>SP2CTi<0S8b<08^;R`2>SXh0QXJ60080Rh^;01L0Q8B40820P01nOWh0Ph>307AdM01l
O7`0MWIf08:2PP1iNGT0Ng]k07YjNP1hN7P0Ng]k07EeM@1fMWH0FEUI06=SH`1iNGT0N7Qh06][J`1d
M7@0MWIf06][J`0207=cL`0D07QhN01cLg<0Kfm_06][J`1`L700Kfm_06UYJ@1/K6`0KFe]06][J`1_
Kfl0I6AT06IVIP1XJ6P0JFUY06i^KP1YJFT0L71`06][J`1]KFd206MWI`0<079bLP1[Jf/0IVIV06QX
J01ZJVX0IVIV06YZJP1WIfL0Jf][065QH@1XJ6P0I6AT5`0000060=WIf@4000000@3IfMT001H0fMWI
00<000000=WIf@3IfMT00`3IfMT07`3]kNd0LW9b06UYJ@1bLW80K6a/07IfMP1SHf<0IfMW06UYJ@1U
IFD0Hf=S071`L01[Jf/0KFe]06IVIP1[Jf/0IfMW06UYJ@1dM7@0LG5a06UYJ@1ZJVX0Jf][06=SH`1U
IFD0KFe]06UYJ@1`L700Lg=c06a/K01XJ6P00P1cLg<05`1]KFd0M7Ad07]kN`1dM7@0N7Qh07IfMP1i
NGT0MWIf07YjNP1nOWh0PH6107AdM024Q8@0Ph>307]kN`21PH40Ng]k08B4Q01oOgl0O7al0861P@28
R8P0PH610080QXJ602/0Ogmo08:2PP2;Rh/0QXJ608F5Q@24Q8@0R8R809BDU026QXH0S8b<09>CT`2A
TI40U9BD09JFUP2LW9`0TI6A09bLW02IVIT0W9bL09^KV`2FUYH0WIfM09jNWP2YZJT0WinO0:JVYP2Y
ZJT0Zj^[0:FUY@2WYjL0/;2`0:b/[02a/K40[Jf]0;Ng]`2k^k/0_[jn0<30`02h^;P0`/;20<K6aP39
bLT0clo?0080dm?C00X0fMWI0=gMg@3Ti>@0iNGU0>[ZjP3emOD0k^k^0?Ogm`3oool0nOWiB`3oool0
3@3no_h0i>CT0?KfmP3Vi^H0hN7Q0=cLg03Cdm<0eMGE0=3@d03;bl/0_[jn0;^k^`2d];@00P2l_;`2
0;Vi^@0A0:^[Z`2`/;00YjNW0:b/[02WYjL0Z:RX0:BTY02SXj<0X:2P0:JVYP2RXZ80Vi^K09nOW`2F
UYH0Vi^K096AT@2DU9@00P2GUiL01`2CTi<0TI6A08^;R`21PH40Ph>308B4Q023Ph<00P26QXH01@29
RHT0QXJ608R8R01jNWX0Ogmo0080NWYj01h0Ng]k07UiN@1lO7`0MWIf07=cL`1fMWH0N7Qh07=cL`1d
M7@0L71`07]kN`1dM7@0MWIf07UiN@1dM7@0LW9b06e]K@1hN7P0oooo071`L01fMWH0Hf=S06i^KP1`
L700K6a/06UYJ@1SHf<0Lg=c06IVIP1[Jf/206ATI00:06][J`1_Kfl0Kfm_06UYJ@1]KFd0IVIV06QX
J01UIFD0Jf][06QXJ080H61P00L0I6AT065QH@1SHf<0IVIV065QH@1UIFD0J6QX01L000001P3IfMT1
00000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00<0l?3`075aL@1WIfL00P1WIfL01@1Z
JVX0KFe]06YZJP1^KVh0IfMW00@0K6a/01h0HF5Q06QXJ01XJ6P0L71`06][J`1/K6`0Jf][06UYJ@1U
IFD0JVYZ06a/K01WIfL0JFUY06m_K`1/K6`0Jf][06m_K`1`L700M7Ad07=cL`1aLG40LW9b07YjNP1a
LG40KVi^07=cL`1gMgL0LG5a07alO01hN7P20861P@0<07AdM021PH40OGem07QhN020P800OWin0820
P021PH40Rh^;08B4Q020P800PX:20P24Q8@03P26QXH0Ph>308>3P`2:RXX0T92@08V9R@2;Rh/0TY:B
09>CT`2>SXh0UIFE096AT@2>SXh0T92@0P2DU9@0202NWYh0W9bL09jNWP2[Zj/0Y:BT0:VYZ@2IVIT0
Z:RX0P2VYZH01@2`/;00/[:b0;2`/02c/k<0/;2`0080];Bd00d0_;bl0;Ng]`35aLD0b<S80<?3``36
a/H0c<c<0<k>cP3GemL0e]KF0=;BdP3EeMD0hn?S0080k>c/00<0lo?c0?Cdm03lo?`0C@3oool00`3h
n?P0m?Cd0>o_k`020>WYj@0:0>7Qh@3MgMd0fm_K0<g=c@3@d=00a/K60;jn_P38b<P0_[jn0;Jf]P80
_;bl00P0Zj^[0:j^[P2^[Zh0[:b/0:FUY@2XZ:P0/K6a0:BTY080XJ6Q00@0XZ:R09FEU@2EUID0XZ:R
0P2LW9`04@2IVIT0TY:B08f=S@2GUiL0TI6A08j>SP2CTi<0R8R808V9R@2;Rh/0QhN708V9R@23Ph<0
PH6107]kN`1jNWX0N7Qh0080O7al00/0Ph>307UiN@1lO7`0MgMg07EeM@1hN7P0LG5a07IfMP1iNGT0
N7Qh07]kN`0207AdM00<07=cL`1iNGT0KFe]07AdM01fMWH0Kfm_075aL@1^KVh0JFUY079bLP1_Kfl0
K6a/0`1[Jf/0301XJ6P0Kfm_06][J`1ZJVX0I6AT06IVIP1/K6`0IFEU06YZJP1TI6@0Jf][06QXJ080
JFUY00T0IVIV06=SH`1ZJVX0I6AT06IVIP1XJ6P0HF5Q06ATI01NGUh05`0000060=WIf@4000000@3I
fMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT04`3^k^h0IVIV06i^KP1]KFd0JFUY075aL@1^KVh0
I6AT05mOG`1WIfL0MGEe06i^KP1/K6`0Jf][06m_K`1UIFD0K6a/071`L01^KVh00`1YJFT01`1/K6`0
LG5a06QXJ01XJ6P0K6a/06i^KP1dM7@00P1VIVH03@1aLG40L71`07=cL`1nOWh0MGEe07alO01_Kfl0
P82007IfMP1jNWX0Q8B407UiN@1gMgL00P1lO7`01@21PH40OGem08B4Q01iNGT0P8200080PH6100D0
Q8B408>3P`24Q8@0PX:208R8R0020861P@0508J6QP2=SHd0RHV908V9R@22PX800P2;Rh/03@2>SXh0
S8b<08V9R@2BTY80UYJF08j>SP2EUID0Ti>C09NGU`2EUID0VIVI09nOW`2SXj<00`2QXJ401P2TY:@0
[Zj^0:VYZ@2c/k<0ZJVY0:f][@80][Jf0P2a/K402P2c/k<0^k^k0;jn_P34a<@0clo?0<W9b@36a/H0
clo?0=?Cd`3Fe]H20=_Kf`060>GUi@3`l?00l?3`0?7al@3`l?00oOgmC@3oool09`3no_h0m?Cd0?Ge
m@3YjNT0hN7Q0=kNgP3IfMT0e=CD0=3@d039bLT0d=3@0<[:bP35aLD0b<S80<G5a@2l_;`0];Bd0;>c
/`2`/;00Xj>S0:n_[`2[Zj/0/K6a0:JVYP2TY:@0YZJV09fMW@2PX:00UYJF09ZJVP2GUiL0Vi^K09VI
V@2FUYH0SXj>09VIV@2>SXh0RXZ:08b<S00208V9R@0B08Z:RP2@T900P82008F5Q@20P800Ph>307Ui
N@20P800Ogmo07inOP1kNg/0OWin07EeM@1kNg/0M7Ad0820P01hN7P0NGUi0P1fMWH03`1lO7`0M7Ad
075aL@1hN7P0LG5a07=cL`1`L700Lg=c06m_K`1`L700Jf][06a/K01]KFd0K6a/075aL@0206MWI`0:
06][J`1YJFT0IfMW06UYJ@1QHF40Jf][06a/K01TI6@0KVi^06][J`80IfMW00d0JFUY065QH@1TI6@0
JFUY06ATI01XJ6P0Hf=S06m_K`1YJFT0I6AT05UIF@1PH600GUiN01L000001P3IfMT100000040fMWI
000F0=WIf@030000003IfMT0fMWI00<0fMWI00@0i>CT06UYJ@1ZJVX0KFe]0P1VIVH0401aLG40Jf][
06MWI`1`L700KVi^06UYJ@1bLW80JFUY075aL@1gMgL0JVYZ06i^KP1dM7@0K6a/075aL@1dM7@206][
J`0406UYJ@1/K6`0L71`075aL@80K6a/00h0KVi^07AdM01^KVh0M7Ad07QhN01_Kfl0M7Ad07QhN01d
M7@0MWIf07]kN`1hN7P0Ng]k07moO`80NGUi0200OWin07QhN01eMGD0OGem0861P@1lO7`0Q8B408F5
Q@27QhL0S8b<08>3P`26QXH0QHF508:2PP25QHD0Ph>308^;R`2?Shl0SXj>092@T02<S8`0T92@08f=
S@2KVi/0V9RH09NGU`2EUID0TY:B08j>SP2CTi<0UYJF09nOW`80XJ6Q00@0YJFU0:>SX`2[Zj/0Z:RX
0P2ZZZX00`2YZJT0[Jf]0:^[Z`020;Bd]00F0;Zj^P30`<00`l?30;fm_@34a<@0`L710<K6aP3De=@0
bLW90=?Cd`3GemL0e]KF0=GEe@3Lg=`0i^KV0>WYj@3/k>`0n?Sh0?Ogm`3moOd0oooo0?gmoD/0oooo
01H0mOGe0?7al@3_knl0i^KV0>CTi03Lg=`0i^KV0=KFeP3;bl/0c/k>0<S8b033`l<0alO70<G5a@30
`<00^k^k0<?3``2d];@0/;2`0;:b/P2`/;00[Zj^0P2[Zj/0102QXJ40XZ:R09jNWP2PX:020:6QX@08
09bLW02PX:00UYJF09BDU02@T900SXj>08b<S02ATI4208b<S00A08j>SP2?Shl0TI6A08V9R@23Ph<0
QHF507]kN`1dM7@0Ogmo07alO01iNGT0M7Ad06i^KP20P800MgMg07]kN`1iNGT00P1fMWH01@1dM7@0
Lg=c07UiN@1cLg<0L71`0080Lg=c00h0L71`07IfMP1bLW80K6a/075aL@1bLW80KVi^07QhN01aLG40
J6QX075aL@1YJFT0KVi^06a/K080KFe]00H0JFUY06QXJ01^KVh0IfMW06UYJ@1XJ6P206UYJ@80IVIV
0P1RHV801`1YJFT0I6AT06i^KP1YJFT0HV9R065QH@1TI6@00P1RHV8G000000H0fMWI0@0000010=WI
f@005P3IfMT00`000000fMWI0=WIf@030=WIf@090>WYj@1WIfL0JVYZ06i^KP1XJ6P0I6AT06][J`1T
I6@0IFEU0080Jf][00X0KVi^06][J`1`L700KFe]071`L01/K6`0KVi^07=cL`1[Jf/0JFUY0P1^KVh2
06UYJ@0?06i^KP1YJFT0KVi^06a/K01dM7@0KFe]075aL@1eMGD0Lg=c07emO@1gMgL0N7Qh07MgM`1i
NGT0Ng]k00<0O7al0280Ng]k0861P@1kNg/0PH6107]kN`1lO7`0NWYj0861P@22PX80Ogmo07inOP23
Ph<0QhN708V9R@28R8P0PH6108>3P`24Q8@0P82008^;R`26QXH0Rh^;08R8R02=SHd0Ti>C09BDU02@
T900VIVI09>CT`2DU9@0WYjN08V9R@2KVi/0XJ6Q0P2NWYh03P2RXZ80X:2P0:>SX`2VYZH0XZ:R0:n_
[`2QXJ40ZZZZ0;Jf]P2XZ:P0/k>c0;Fe]@2`/;00`<300P2i^KT01@33`l<0a<C40<C4a038b<P0bl_;
0080e=CD00P0hN7Q0=SHf03QhN40lo?c0?Win@3Xj>P0no_k0?KfmTl0oooo0240lo?c0>o_k`3Ti>@0
k^k^0=kNgP3Kfm/0f=SH0<_;b`3?cll0c/k>0;no_`33`l<0a<C40<W9b@36a/H0_;bl0;Vi^@2][Jd0
/k>c0:f][@2c/k<0[:b/0:VYZ@2VYZH0XZ:R0:>SX`2JVYX0WYjN0:6QX@2LW9`0U9BD09ZJVP2IVIT0
0P2>SXh0;P2@T900S8b<092@T02HV9P0SHf=08b<S024Q8@0P82008>3P`24Q8@0P82007QhN01mOGd0
Ogmo0861P@1kNg/0OWin07AdM01oOgl0MgMg07alO01aLG40NWYj07AdM01aLG40Ng]k06m_K`1fMWH0
LW9b06m_K`1fMWH0L71`07AdM01aLG40Jf][06UYJ@1_Kfl0JFUY07AdM01^KVh0JVYZ06i^KP1VIVH0
K6a/06m_K`1ZJVX206e]K@0?06=SH`1UIFD0JVYZ06ATI01XJ6P0IVIV06i^KP1ZJVX0IVIV06EUI@1Q
HF40Hf=S065QH@1PH600Hf=S0080IFEU00<0I6AT06=SH`0000005P0000060=WIf@4000000@3IfMT0
01H0fMWI00<000000=WIf@3IfMT00`3IfMT03`3[jn/0IFEU06][J`1/K6`0KVi^06YZJP1WIfL0K6a/
06ATI01[Jf/0IfMW06YZJP1dM7@0KFe]06IVIP02071`L00406IVIP1[Jf/0JFUY06m_K`80KVi^00D0
LG5a06a/K01YJFT0K6a/07EeM@02071`L008075aL@1/K6`0L71`07IfMP1kNg/0Lg=c07YjNP1iNGT2
07QhN00=07]kN`1nOWh0OGem08:2PP1fMWH0OGem07UiN@24Q8@0OWin0861P@1mOGd0P82007emO@02
08B4Q00308F5Q@24Q8@0RHV90080R8R801/0Ti>C08b<S024Q8@0SHf=09VIV@2HV9P0Rh^;09BDU02C
Ti<0Rh^;09>CT`2GUiL0VIVI092@T02CTi<0TY:B09>CT`2LW9`0YJFU0:VYZ@2PX:00Y:BT0:FUY@2R
XZ80Z:RX0;6a/@2YZJT00P2c/k<0502a/K40[Zj^0;6a/@2k^k/0`<300;jn_P31`L40bl_;0<G5a@3;
bl/0c/k>0=CDe03Fe]H0fMWI0=[JfP3WinL0h>3P0?Ogm`3clo<0mOGeD03oool07@3alO40nOWi0?;b
lP3/k>`0jNWY0=cLg03Jf]X0cLg=0<W9b@3:b/X0a/K60<O7a`2m_Kd0a/K60;bl_033`l<0];Bd0;2`
/02XZ:P0/[:b0:VYZ@2[Zj/0YjNW0:f][@2[Zj/0ZZZZ0:6QX@2JVYX0X:2P0080Vi^K0280T92@09NG
U`2OWil0Ti>C096AT@28R8P0SHf=08b<S024Q8@0RHV908>3P`29RHT0Ph>308B4Q020P800OWin08R8
R01nOWh0PH610820P01nOWh0MWIf07inOP1fMWH0Lg=c07QhN01eMGD0Lg=c079bLP1hN7P0Lg=c06][
J`1cLg<0MGEe0`1`L7008P1/K6`0M7Ad07MgM`1bLW80Lg=c06][J`1]KFd0K6a/06UYJ@1^KVh0J6QX
06YZJP1WIfL0K6a/06IVIP1XJ6P0I6AT06YZJP1YJFT0IVIV06UYJ@1VIVH0JFUY06EUI@1WIfL0K6a/
065QH@1XJ6P0G5aL065QH@1UIFD0I6AT069RHP1QHF4G000000H0fMWI0@0000010=WIf@005P3IfMT0
0`000000fMWI0=WIf@030=WIf@070>_[j`1YJFT0I6AT06i^KP1`L700K6a/06e]K@0306][J`<0I6AT
00l0LG5a06i^KP1_Kfl0M7Ad071`L01SHf<0JVYZ071`L01XJ6P0KVi^06a/K01aLG40M7Ad071`L01_
Kfl00P1cLg<0201iNGT0Kfm_07IfMP1`L700MGEe07QhN01_Kfl0N7Qh0P1lO7`02021PH40Ph>30861
P@1gMgL0Ng]k08F5Q@21PH40QXJ60P20P8005@1oOgl0PX:208:2PP2:RXX0QHF508>3P`21PH40Q8B4
08>3P`28R8P0P820092@T02;Rh/0UYJF092@T02ATI40VIVI08f=S@2HV9P0UYJF08b<S00208j>SP0L
09VIV@2GUiL0V9RH09bLW02KVi/0YJFU09RHV02LW9`0Y:BT0:^[Z`2QXJ40[:b/0:ZZZP2^[Zh0[:b/
0:VYZ@2g]kL0[Zj^0<30`02k^k/0_Kfm0<71`@33`l<0a/K60=3@d03>c/h0bLW90=7Ad@80hN7Q00L0
hn?S0=kNgP3Vi^H0l_;b0?7al@3`l?00m_Kf04h0oooo00l0n_[j0?Ogm`3clo<0kNg]0>KViP3Ng]h0
e]KF0=CDe03Hf=P0clo?0<71`@3;bl/0`L710<_;b`2d];@00P2n_[h02P2h^;P0];Bd0:n_[`2/[:`0
Zj^[0:b/[02XZ:P0[Zj^0:FUY@2VYZH20:2PX00J09JFUP2KVi/0U9BD09RHV02@T900TI6A09^KV`2:
RXX0TI6A08V9R@2?Shl0QHF508^;R`29RHT0OGem08^;R`21PH40Q8B407inOP1iNGT0N7Qh0861P@1d
M7@0OGem0820P01nOWh207]kN`0^07EeM@1iNGT0OWin0861P@1hN7P0MWIf071`L01_Kfl0Jf][06i^
KP1dM7@0KVi^06YZJP1fMWH0J6QX06UYJ@1[Jf/0J6QX06MWI`1YJFT0KVi^06UYJ@1/K6`0H61P06QX
J01]KFd0H61P06YZJP1[Jf/0KVi^069RHP1SHf<0I6AT06UYJ@1SHf<0IFEU065QH@1SHf<0J6QX06EU
I@1XJ6P0HF5Q061PH01SHf<0HF5Q069RHQL000001P3IfMT100000040fMWI000F0=WIf@800000103I
fMT04@3bl_80Kfm_06a/K01XJ6P0KFe]071`L01/K6`0KVi^06e]K@1YJFT0IFEU06a/K01YJFT0Jf][
06EUI@1/K6`0J6QX0080Jf][00<0L71`06m_K`1_Kfl00P1]KFd02`1/K6`0Jf][07MgM`1]KFd0Jf][
06QXJ01aLG40MGEe075aL@1iNGT0MWIf0080LW9b0100M7Ad071`L01eMGD0MWIf07UiN@20P800NWYj
07emO@1fMWH0Ng]k08R8R022PX80QXJ607emO@2:RXX0Ogmo0P23Ph<01`24Q8@0QXJ60820P025QHD0
S8b<08V9R@2>SXh00P29RHT01@2DU9@0Rh^;08j>SP2BTY80TI6A0080T92@00d0UiNG09VIV@2CTi<0
UiNG09VIV@2QXJ40Vi^K0:6QX@2OWil0YjNW0:b/[02^[Zh0XJ6Q0080[Zj^01P0/[:b0:b/[02d];@0
/K6a0;Fe]@2k^k/0`<300;bl_031`L40b<S80;bl_03<c<`0b<S80=?Cd`3Hf=P0e=CD0=[JfP3Hf=P0
hN7Q0>c/k03]kNd0lo?c0?Ogm`3no_i?0?ooo`0:0?Win@3`l?00k^k^0>c/k03Xj>P0hn?S0=WIf@3H
f=P0b/[:0=3@d080bLW900@0_[jn0<K6aP31`L40_Kfm0P2^[Zh01`2/[:`0Zj^[0;2`/02VYZH0[Zj^
0:RXZ02UYJD00P2LW9`01`2UYJD0Ti>C09^KV`2EUID0Ti>C09NGU`2FUYH00P2ATI42092@T080R8R8
00d0Rh^;08b<S023Ph<0S8b<08N7Q`1mOGd0PH6108B4Q02;Rh/0O7al07moO`1mOGd0P8200080O7al
01`0Ng]k07YjNP1cLg<0N7Qh07AdM01iNGT0LW9b075aL@1`L700LG5a07=cL`1dM7@0MWIf07EeM@1^
KVh0MWIf071`L01aLG40L71`075aL@1^KVh0LW9b06i^KP1YJFT0K6a/071`L01ZJVX0IFEU0P1XJ6P2
061PH00?06QXJ01VIVH0IFEU069RHP1YJFT0Hf=S06e]K@1UIFD0I6AT05aLG01XJ6P0FUYJ061PH01Y
JFT0GEeM01L000001@3IfMT200000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00`0lO7a
06][J`1fMWH0Jf][06UYJ@1XJ6P0Jf][06i^KP1`L700Jf][06MWI`1/K6`206IVIP0406][J`1`L700
JFUY071`L080KVi^0P1`L700:P1dM7@0IfMW079bLP1^KVh0LW9b06UYJ@1eMGD0KVi^079bLP1aLG40
M7Ad07IfMP1hN7P0MGEe07IfMP1aLG40P82007IfMP1iNGT0MGEe07emO@1nOWh0Ogmo07UiN@1fMWH0
OWin08>3P`1oOgl0Ph>30861P@28R8P0QXJ60861P@23Ph<0PX:208V9R@20P800QHF50861P@2<S8`0
R8R8096AT@80T92@00X0TI6A08N7Q`2?Shl0UYJF08j>SP2ATI40VIVI09JFUP2HV9P0WYjN0P2QXJ40
4P2NWYh0YJFU0:2PX02YZJT0YZJV0:b/[02YZJT0];Bd0:ZZZP2^[Zh0];Bd0;Zj^P2/[:`0][Jf0;Zj
^P2i^KT0`L710;fm_@80bl_;00P0d];B0<o?c`3De=@0g]kN0=_Kf`3QhN40jn_[0>SXj080lo?cD03o
ool04P3fm_H0o_kn0?Cdm03bl_80j>SX0>CTi03UiND0fMWI0=KFeP36a/H0e=CD0<[:bP2j^[X0_Kfm
0<71`@2o_kl0^KVi0;>c/`80/;2`00X0]KFe0;:b/P2`/;00ZJVY09jNWP2TY:@0YZJV0:BTY02IVIT0
VYZJ0P2FUYH0302ATI40U9BD09>CT`2HV9P0TI6A08b<S02;Rh/0R8R808^;R`26QXH0Rh^;08B4Q080
R8R800h0Ng]k07UiN@22PX80Q8B407emO@21PH40Ng]k07alO01dM7@0O7al07=cL`1hN7P0NGUi071`
L080NWYj00d0Ng]k06e]K@1gMgL0M7Ad07=cL`1]KFd0JFUY079bLP1YJFT0KVi^07=cL`1]KFd0Kfm_
0080KVi^00`0JVYZ05iNGP1YJFT0JVYZ06a/K01ZJVX0IVIV061PH01XJ6P0K6a/06=SH`1XJ6P206i^
KP0<061PH01UIFD0IfMW06UYJ@1ZJVX0FUYJ06EUI@1TI6@0Hf=S06IVIP1YJFT0HV9R5`0000060=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT00`3Zj^X0JVYZ06][J`0206e]K@06
06UYJ@1VIVH0Jf][06i^KP1/K6`0Hf=S0`1YJFT03P1_Kfl0Hf=S06a/K01aLG40J6QX075aL@1XJ6P0
MgMg075aL@1bLW80Kfm_075aL@1_Kfl0M7Ad0P1kNg/02P1eMGD0Lg=c071`L01dM7@0Kfm_07EeM@1d
M7@0Lg=c07UiN@1cLg<207MgM`0K071`L01eMGD0L71`07QhN01iNGT0NWYj08B4Q020P800R8R808:2
PP1nOWh0PH6107moO`23Ph<0S8b<08V9R@20P800QXJ608R8R029RHT0SXj>08V9R@2<S8`0RHV908j>
SP2<S8`0UiNG00<0U9BD00H0UiNG09JFUP2HV9P0V9RH09bLW02EUID20:2PX0030:j^[P2XZ:P0Vi^K
0080Y:BT00L0/k>c0;2`/02d];@0/;2`0;>c/`2`/;00];Bd0080`l?300l0alO70<S8b036a/H0b<S8
0=3@d03Cdm<0d=3@0=KFeP3MgMd0h>3P0>OWi`3/k>`0k^k^0??cl`3hn?P0CP3oool05@3no_h0oooo
0?ooo`3inOT0o_kn0>3Ph03Vi^H0j>SX0=oOg`3GemL0d=3@0<_;b`34a<@0`L710;Ng]`2n_[h0_;bl
0;2`/02^[Zh0/[:b0;>c/`020;6a/@0<0:^[Z`2VYZH0Zj^[0:>SX`2JVYX0YZJV09fMW@2FUYH0VIVI
08b<S02FUYH0Vi^K0P2BTY803`2>SXh0SHf=08j>SP2=SHd0UIFE08J6QP20P800QXJ607alO023Ph<0
O7al08>3P`1nOWh0O7al08:2PP0307alO00A07IfMP1kNg/0OWin07QhN01gMgL0MWIf07MgM`1iNGT0
M7Ad079bLP1[Jf/0MWIf06m_K`1bLW80L71`06i^KP1[Jf/00P1/K6`07P1VIVH0JFUY06m_K`1WIfL0
L71`06IVIP1_Kfl0L71`06QXJ01VIVH0Jf][06i^KP1_Kfl0I6AT06][J`1UIFD0IVIV06UYJ@1QHF40
J6QX06UYJ@1RHV80JFUY05iNGP1SHf<0IVIV065QH@1SHf<0GUiN065QHAL000001P3IfMT100000040
fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI01T0k>c/06][J`1YJFT0Jf][06YZJP1[Jf/0J6QX
06i^KP1/K6`0KFe]06a/K01UIFD0IfMW06YZJP1YJFT0K6a/06YZJP1cLg<0KVi^06m_K`1ZJVX0KVi^
06][J`1fMWH0K6a/0080L71`00P0M7Ad07EeM@1bLW80KFe]071`L01_Kfl0L71`07EeM@80MWIf00@0
M7Ad07MgM`1kNg/0MWIf0P1/K6`02P1_Kfl0MgMg07UiN@1lO7`0PH6108B4Q01lO7`0OWin08R8R02;
Rh/20861P@0407inOP20P800Q8B408^;R`80RHV901D0S8b<08B4Q01oOgl0QXJ608f=S@26QXH0Shn?
09VIV@2BTY80UIFE09BDU02HV9P0WYjN09:BTP2FUYH0WYjN0::RXP2HV9P0Xj>S0:2PX02YZJT00P2S
Xj<03@2YZJT0[jn_0:ZZZP2^[Zh0];Bd0:n_[`2g]kL0/[:b0;Vi^@36a/H0^[Zj0<C4a035aLD00P39
bLT02`3@d=00c/k>0=CDe03IfMT0fm_K0>c/k03[jn/0lO7a0>c/k03fm_H0o_kn04l0oooo00L0nOWi
0?[jnP3emOD0i^KV0>_[j`3UiND0fm_K0080fMWI00X0b/[:0<71`@2h^;P0`L710<G5a@2l_;`0^KVi
0:b/[02[Zj/0];Bd0P2`/;00202a/K40YZJV0:>SX`2XZ:P0X:2P0:>SX`2DU9@0UiNG0P2IVIT01@29
RHT0UYJF08j>SP2@T900RHV90080SXj>00l0RXZ:092@T029RHT0R8R807moO`23Ph<0P82008V9R@24
Q8@0Ph>308B4Q01nOWh0QHF507YjNP1fMWH00P1jNWX02020P800M7Ad07YjNP1_Kfl0LW9b07UiN@1k
Ng/0LW9b0P1`L7002@1bLW80Lg=c06i^KP1YJFT0Jf][075aL@1YJFT0M7Ad06UYJ@0206i^KP0906][
J`1]KFd0I6AT06MWI`1YJFT0K6a/06IVIP1YJFT0Hf=S0080I6AT00`0J6QX06MWI`1XJ6P0GUiN06EU
I@1WIfL0JFUY06YZJP1VIVH0JVYZ06UYJ@1NGUh206IVIP0306=SH`000000000001D000001P3IfMT1
00000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00/0jn_[06][J`1[Jf/0K6a/06=SH`1V
IVH0J6QX06IVIP1^KVh0JFUY06QXJ00306m_K`0306UYJ@1cLg<0K6a/0080Jf][00d0K6a/06m_K`1/
K6`0M7Ad06i^KP1]KFd0NGUi07IfMP1eMGD0NGUi079bLP1fMWH0L71`0080M7Ad00<0L71`07IfMP1e
MGD00P1eMGD02@1cLg<0Kfm_06UYJ@1cLg<0NWYj07=cL`1aLG40MWIf08B4Q00208>3P`0408V9R@20
P800R8R80861P@80Ph>300<0OWin08:2PP29RHT00P29RHT06@2:RXX0RHV908R8R02=SHd0TI6A08Z:
RP29RHT0TY:B08b<S02CTi<0U9BD09>CT`2ATI40UYJF09ZJVP2NWYh0U9BD0:>SX`2HV9P0ZJVY09nO
W`2SXj<0Y:BT0:JVYP2/[:`00P2^[Zh00`2_[jl0]KFe0;2`/0020;Rh^00?0;jn_P30`<00a<C40<_;
b`3Fe]H0cLg=0<_;b`3Fe]H0f=SH0>CTi03MgMd0hn?S0?Win@3`l?00moOg0540oooo00D0o_kn0?Ge
m@3^k^h0hn?S0>_[j`020>GUi@0b0=SHf03GemL0c/k>0<c<c038b<P0^[Zj0<O7a`2l_;`0/k>c0;Fe
]@2_[jl0^KVi0;Bd]02^[Zh0[Jf]0:j^[P2PX:00Y:BT09bLW02RXZ80V9RH0:2PX02JVYX0WYjN09JF
UP2EUID0Rh^;08b<S024Q8@0T92@09BDU02@T900R8R808j>SP29RHT0Rh^;08>3P`24Q8@0OWin08:2
PP1kNg/0NGUi07emO@22PX80M7Ad07alO01kNg/0MGEe079bLP1jNWX207QhN00307EeM@1bLW80MgMg
0080Lg=c0P1/K6`0201_Kfl0KVi^06a/K01[Jf/0LW9b075aL@1^KVh0IVIV0P1YJFT06P1`L700JFUY
071`L01[Jf/0L71`06a/K01ZJVX0J6QX06a/K01[Jf/0JFUY06ATI01VIVH0GUiN06IVIP1YJFT0IVIV
065QH@1ZJVX0IVIV05mOG`1PH600HF5Q06ATI01MGEd0FUYJ5`0000060=WIf@4000000@3IfMT001H0
fMWI00<000000=WIf@3IfMT00`3IfMT0103^k^h0K6a/06UYJ@1[Jf/206a/K00B06YZJP1]KFd0IVIV
06IVIP1[Jf/0IVIV075aL@1[Jf/0IVIV06UYJ@1_Kfl0K6a/07=cL`1bLW80KVi^06a/K01jNWX0LG5a
0P1`L7000`1aLG40N7Qh071`L00207EeM@0707UiN@1fMWH0OGem07IfMP1jNWX0Ng]k06a/K00307Ad
M080LW9b00T0MWIf07=cL`1hN7P0MGEe07alO01jNWX0OWin0820P01mOGd00P20P8009P23Ph<0QXJ6
08N7Q`2@T900QXJ608R8R022PX80SHf=08J6QP2?Shl0S8b<08R8R02ATI40SHf=09RHV02ATI40UYJF
09>CT`2DU9@0XZ:R08j>SP2NWYh0U9BD09^KV`2NWYh0WinO0:BTY02^[Zh0YZJV0:b/[02QXJ40ZZZZ
0;Bd]02k^k/0];Bd0;fm_@2h^;P0_;bl0P2o_kl03`36a/H0`L710<G5a@39bLT0clo?0=?Cd`3Ogml0
f=SH0=GEe@3Vi^H0k>c/0>k^kP3inOT0l?3`0?clo01?0?ooo`060?knoP3oool0n?Sh0>[ZjP3QhN40
i^KV0P3Ogml01@3Hf=P0dm?C0<c<c03Bd]80`/;20080`<3001P0`/;20<?3``2^[Zh0Z:RX0:b/[02d
];@0Zj^[0:BTY02YZJT0XJ6Q0:RXZ02NWYh0Vi^K09jNWP2HV9P0TI6A08n?S`2ATI40UIFE08j>SP2;
Rh/0T92@08n?S`2ATI4208V9R@80QXJ601D0SXj>08J6QP20P800Ph>307UiN@1lO7`0OWin07alO021
PH40Ogmo07alO01iNGT0MWIf07inOP1eMGD0Lg=c07IfMP1dM7@0LG5a06i^KP1gMgL00P1fMWH04`1W
IfL0KVi^071`L01`L700MGEe06m_K`1^KVh0L71`06][J`1/K6`0Hf=S06EUI@1`L700K6a/06][J`1S
Hf<0LG5a065QH@1SHf<00`1XJ6P0201YJFT0Hf=S06=SH`1SHf<0IVIV06QXJ01QHF40I6AT0P1XJ6P0
1@1SHf<0I6AT061PH01TI6@0HF5Q01L000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0
fMWI00<0fMWI00X0kno_06e]K@1YJFT0JVYZ06QXJ01^KVh0L71`06i^KP1hN7P0K6a/101XJ6P01`1^
KVh0Jf][06a/K01[Jf/0Kfm_075aL@1cLg<00P1`L70207IfMP07071`L01cLg<0M7Ad07MgM`1dM7@0
K6a/07QhN00207]kN`0N07EeM@1iNGT0Ng]k071`L01cLg<0Kfm_07UiN@1eMGD0LW9b07UiN@1jNWX0
M7Ad07MgM`1lO7`0Q8B408J6QP1jNWX0OWin08J6QP23Ph<0O7al08J6QP23Ph<0RHV9092@T02;Rh/0
Q8B408R8R024Q8@0TI6A0P2>SXh01@2DU9@0TY:B08V9R@2ATI40VIVI0080U9BD00l0XJ6Q09NGU`2J
VYX0WYjN0:6QX@2PX:00Z:RX0:6QX@2VYZH0ZZZZ0:RXZ02YZJT0Zj^[0;2`/02a/K400P2f][H04`2a
/K40^KVi0;^k^`34a<@0^k^k0<K6aP32`/80c<c<0<W9b@3GemL0f][J0=_Kf`3YjNT0j^[Z0>SXj03d
m?@0moOg0?clo03jn_X0D@3oool01@3gmoL0n_[j0>;RhP3[jn/0g]kN0080f=SH0100dM7A0=WIf@3?
cll0bLW90<O7a`35aLD0`L710;^k^`2f][H0];Bd0;>c/`2/[:`0YZJV0:ZZZP2YZJT0WIfM0P2RXZ80
202PX:00XJ6Q0:6QX@2DU9@0UiNG08n?S`2CTi<0TI6A0`2>SXh08`29RHT0Rh^;08J6QP28R8P0QXJ6
08b<S021PH40QHF508J6QP1_Kfl0OWin08B4Q01nOWh0MgMg07alO01hN7P0OWin07QhN01lO7`0N7Qh
07=cL`1dM7@0Lg=c07IfMP1cLg<0M7Ad07=cL`1eMGD0Kfm_06a/K01dM7@0LG5a071`L01^KVh0L71`
0080KVi^00X0Lg=c06i^KP1YJFT0IVIV06e]K@1YJFT0IfMW071`L01XJ6P0IVIV0P1TI6@02`1YJFT0
IVIV06YZJP1^KVh0JFUY06=SH`1XJ6P0HV9R06MWI`1TI6@0IVIV0080I6AT00<0IFEU05mOG`1PH600
5`0000060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0>`3Xj>P0Jf][06][
J`1XJ6P0K6a/07=cL`1[Jf/0K6a/06EUI@1]KFd0Jf][06a/K01dM7@0IfMW06i^KP1gMgL0LG5a06i^
KP1eMGD0N7Qh07AdM01cLg<0LG5a07AdM01^KVh0Lg=c075aL@1lO7`0MWIf07=cL`1dM7@0PH6107al
O023Ph<0MWIf07EeM@1`L700KVi^075aL@1cLg<0Ng]k07AdM01eMGD0O7al071`L01kNg/0NGUi07al
O01kNg/0Ogmo08>3P`1lO7`0PX:207alO02@T900QXJ608R8R023Ph<0Q8B40080S8b<00<0R8R808N7
Q`2>SXh00P2;Rh/0:P2@T900Ph>309BDU02>SXh0UYJF09FEU@2KVi/0U9BD09VIV@2MWId0XJ6Q0::R
XP2KVi/0WYjN0:RXZ02SXj<0YZJV0:>SX`2ZZZX0Zj^[0;Jf]P2a/K40/[:b0;Zj^P2i^KT0];Bd0;^k
^`30`<00c<c<0<S8b03De=@0b/[:0=7Ad@3Bd]80gMgM0>CTi03Lg=`0j>SX0>WYj@3Vi^H0m?Cd0?;b
lU40oooo00`0oOgm0?ooo`3^k^h0jn_[0>7Qh@3Kfm/0hN7Q0=_Kf`3EeMD0b/[:0=3@d03;bl/20<S8
b00;0;fm_@2j^[X0`l?30;Bd]032`/80Zj^[0;2`/02[Zj/0YjNW0::RXP2TY:@00P2SXj<0802FUYH0
UiNG09BDU02@T900SXj>09:BTP27QhL0UYJF08f=S@2ATI40RXZ:08b<S021PH40SHf=08Z:RP2;Rh/0
R8R808>3P`20P800G5aL07inOP1jNWX0Ng]k07moO`1jNWX0N7Qh07UiN@1eMGD0Ng]k07AdM01nOWh0
OGem0P1lO7`03@1aLG40L71`07]kN`1hN7P0IfMW07IfMP1/K6`0KVi^06a/K01]KFd0L71`06a/K01[
Jf/00P1`L700201[Jf/0K6a/06e]K@1YJFT0HF5Q06QXJ01/K6`0IfMW0P1XJ6P0101YJFT0K6a/06YZ
JP1TI6@206=SH`0:069RHP1PH600HV9R06ATI01MGEd0H61P06UYJ@1MGEd0J6QX065QHAL000001P3I
fMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0100l?3`06m_K`1[Jf/0KFe]06QX
J01VIVH0Lg=c07IfMP1^KVh0L71`075aL@1gMgL0LG5a06MWI`1[Jf/0Lg=c0P1[Jf/09@1fMWH0Kfm_
07MgM`1bLW80KVi^07QhN01`L700Jf][079bLP1/K6`0MGEe06m_K`1cLg<0OWin08:2PP1iNGT0N7Qh
06a/K01[Jf/0Lg=c075aL@1`L700O7al07YjNP1iNGT0MGEe07UiN@1cLg<0Ng]k07AdM01nOWh0PH61
07emO@1oOgl0PH6108^;R`1lO7`00P26QXH01021PH40Q8B408Z:RP20P80208V9R@0F08n?S`2;Rh/0
QhN708b<S02>SXh0TY:B096AT@2CTi<0TY:B09NGU`2IVIT0TY:B09VIV@2NWYh0T92@0:BTY02XZ:P0
Zj^[0:ZZZP2YZJT0Zj^[0:b/[080/K6a01D0^;Rh0;jn_P2i^KT0]kNg0;fm_@2n_[h0`l?30;no_`2n
_[h0`l?30=3@d03AdM40e=CD0=cLg03IfMT0i>CT0>OWi`3YjNT0mOGe0?Win@3hn?P0D@3oool00`3n
o_h0m_Kf0??cl`020>KViP0:0>WYj@3Ng]h0g]kN0=WIf@3<c<`0c/k>0<c<c037alL0bLW90<K6aP80
_[jn01`0/k>c0;Vi^@2[Zj/0/K6a0:ZZZP2TY:@0YZJV0:BTY02SXj<0WYjN09^KV`2HV9P0Shn?09JF
UP2JVYX0SXj>092@T02CTi<0RHV9092@T02=SHd0Ti>C08Z:RP2@T900RHV908B4Q025QHD0P8200P1n
OWh01020P800N7Qh07EeM@1lO7`207QhN00I07YjNP1iNGT0MGEe07QhN01cLg<0Ng]k07EeM@1lO7`0
KVi^07MgM`1iNGT0LG5a06i^KP1dM7@0Lg=c071`L01cLg<0Jf][07=cL`1hN7P0LW9b06UYJ@1/K6`0
JFUY06a/K00306][J`0E06i^KP1VIVH0J6QX06UYJ@1QHF40JFUY06][J`1QHF40JFUY05mOG`1SHf<0
GemO06a/K01WIfL0J6QX06][J`1QHF40Hf=S06MWI`1LG5`0HF5Q01L000001P3IfMT100000040fMWI
00000`3IfMT0000000000002000000<0fMWI0P0000040=WIf@8000001P3IfMT00`000000fMWI0=WI
f@030=WIf@0O0>GUi@1YJFT0GemO06MWI`1VIVH0Jf][06i^KP1TI6@0LW9b06m_K`1[Jf/0I6AT06UY
J@1bLW80KVi^06YZJP1aLG40MGEe06i^KP1cLg<0L71`075aL@1^KVh0Kfm_071`L01hN7P0LG5a07=c
L`1aLG40MGEe075aL@020861P@80O7al03L0N7Qh06][J`1`L700N7Qh07]kN`20P800N7Qh07moO`1d
M7@0NGUi07EeM@1iNGT0M7Ad07UiN@1eMGD0O7al0820P01nOWh0Ph>307moO`29RHT0PX:208B4Q02<
S8`0QXJ608Z:RP27QhL0SHf=08R8R02>SXh0T92@08b<S02ATI40Ti>C09bLW02@T900UYJF09NGU`2H
V9P0Vi^K09BDU02IVIT0X:2P0:FUY@2TY:@0Xj>S0:b/[02SXj<0XJ6Q0;:b/P2^[Zh0]kNg0;>c/`2`
/;00[:b/0080_;bl0140`<300<?3``37alL0b<S80<_;b`3Fe]H0d];B0=CDe03IfMT0g=cL0>KViP3R
h^80j>SX0??cl`3moOd0oooo0?clo01?0?ooo`0Y0?Win@3`l?00oooo0?7al@3^k^h0h^;R0>c/k03J
f]X0f=SH0<o?c`3Fe]H0cLg=0=?Cd`34a<@0`L710;jn_P2o_kl0`L710;no_`2e]KD0[jn_0;2`/02[
Zj/0Xj>S0:6QX@2VYZH0WYjN0:2PX02KVi/0W9bL09JFUP2HV9P0S8b<09FEU@2>SXh0T92@08f=S@22
PX80T92@08Z:RP28R8P00P29RHT02`24Q8@0P82008F5Q@26QXH0O7al0820P01kNg/0MgMg07inOP1f
MWH0N7Qh0080NWYj00d0O7al08>3P`1dM7@0OWin07IfMP1bLW80O7al07AdM01]KFd0JVYZ079bLP1]
KFd0L71`0080M7Ad01X0LG5a07AdM01^KVh0Lg=c07YjNP1bLW80L71`06YZJP1WIfL0JFUY079bLP1Y
JFT0IfMW06QXJ01[Jf/0LG5a06QXJ01UIFD0KFe]06a/K01XJ6P0HV9R06IVIP1PH600IVIV061PH080
IVIV00@0HF5Q069RHP1PH600I6AT5`0000060=WIf@4000000@3IfMT000030=WIf@000000fMWI00@0
fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@0000050=WIf@030000003IfMT0
fMWI00<0fMWI00`0gMgM07AdM01PH600I6AT06UYJ@1XJ6P0Lg=c079bLP1`L700KVi^06m_K`1UIFD2
06a/K00H071`L01^KVh0KVi^079bLP1aLG40L71`07IfMP1dM7@0LG5a079bLP1dM7@0LG5a06e]K@1`
L700MWIf07QhN01_Kfl0Lg=c07emO@1fMWH0N7Qh07IfMP1cLg<0MgMg0P1dM7@03@1cLg<0NGUi07=c
L`1nOWh0NGUi07IfMP1nOWh0O7al07MgM`26QXH0QhN707inOP21PH400P20P8007`28R8P0RXZ:08R8
R02@T900Q8B408J6QP2>SXh0Q8B408N7Q`26QXH0T92@08b<S026QXH0SHf=09VIV@2@T900W9bL08n?
S`2ATI40X:2P09fMW@2FUYH0VIVI09ZJVP2VYZH0ZJVY0:BTY02WYjL0Z:RX0:BTY02`/;000P2/[:`0
2@2f][H0^;Rh0;Jf]P2m_Kd0`<300;Rh^037alL0b<S80<c<c0020=3@d080f=SH00L0iNGU0>;RhP3S
hn<0hn?S0??cl`3no_h0o?cl0580oooo01L0m_Kf0>g]k@3[jn/0inOW0=cLg03QhN40gMgM0=3@d03Q
hN40dM7A0<k>cP39bLT0clo?0<30`031`L40_;bl0:n_[`2`/;00/k>c0;2`/02VYZH0Z:RX0:NWY`02
09bLW0090::RXP2KVi/0UiNG09BDU02GUiL0Rh^;09>CT`28R8P0SXj>0080Rh^;01L0R8R808^;R`2?
Shl0R8R808^;R`22PX80QhN70861P@1jNWX0O7al0861P@1lO7`0P82007alO01gMgL0M7Ad07emO@1d
M7@0Ng]k07inOP1kNg/0NGUi08>3P`0207IfMP0X06m_K`1dM7@0KFe]07IfMP1`L700Kfm_06a/K01c
Lg<0JVYZ075aL@1YJFT0L71`07AdM01bLW80M7Ad079bLP1`L700Jf][06UYJ@1UIFD0LG5a06ATI01`
L700J6QX06UYJ@1TI6@0IVIV06UYJ@1VIVH0J6QX06EUI@1XJ6P0I6AT06UYJ@1RHV80HF5Q05iNGP1Q
HF40H61P05eMGAL000001P3IfMT100000040fMWI00020=WIf@030000003IfMT0fMWI0080fMWI00@0
00000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@0000050=WIf@<000000`3IfMT01P3^k^h0
JFUY06][J`1[Jf/0HF5Q06i^KP80LG5a00D0L71`06e]K@1YJFT0M7Ad06YZJP03075aL@0906a/K01]
KFd0IVIV07AdM01aLG40Kfm_07=cL`1bLW80L71`0080KVi^00@0Lg=c07AdM01_Kfl0Ng]k0P1hN7P0
301aLG40NGUi075aL@1fMWH0K6a/071`L01lO7`0MWIf07YjNP21PH40Lg=c07QhN080LW9b00X0NGUi
0820P01jNWX0Ng]k0861P@1nOWh0Ng]k08J6QP20P800QhN70P24Q8@05P2;Rh/0Q8B408>3P`2:RXX0
R8R808B4Q02<S8`0T92@09BDU029RHT0UYJF09>CT`2KVi/0T92@09JFUP2RXZ80Xj>S09VIV@2RXZ80
Vi^K0:2PX02ZZZX20:JVYP0@0:^[Z`2/[:`0Zj^[0;Jf]P2YZJT0][Jf0;Ng]`2k^k/0]kNg0;fm_@2n
_[h0`l?30<[:bP37alL0a/K60=SHf080dM7A00H0emOG0>7Qh@3Ti>@0j>SX0>WYj@3clo<20?Shn500
oooo01T0nOWi0?Ogm`3clo<0jn_[0>WYj@3_knl0h>3P0=7Ad@3Shn<0eMGE0<;2`P3?cll0alO70;bl
_02h^;P0^[Zj0;Bd]02c/k<0/K6a0;:b/P2XZ:P0/k>c0:j^[P2TY:@0Xj>S0080Vi^K01X0Ti>C09jN
WP2@T900Shn?096AT@29RHT0Shn?08V9R@2<S8`0Q8B408>3P`2=SHd0QhN708n?S`27QhL0Rh^;08B4
Q01hN7P0MgMg07YjNP1kNg/0PH6107=cL`24Q8@0OWin07UiN@80Lg=c00<0M7Ad07=cL`1iNGT00P1h
N7P02P1nOWh0MGEe079bLP1`L700N7Qh06a/K01gMgL0KVi^06QXJ01aLG4206m_K`0606a/K01gMgL0
LG5a075aL@1lO7`0LW9b0P1VIVH01`1^KVh0IfMW06=SH`1SHf<0K6a/06=SH`1VIVH00P1TI6@03@1Y
JFT0IVIV06QXJ01VIVH0Hf=S06IVIP1/K6`0GUiN05eMG@1SHf<0HV9R05iNGP1LG5`05`0000040=WI
f@<000000@3IfMT000<0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@040000003IfMT0fMWI
00000080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@0;0>SXj01[Jf/0
I6AT06][J`1^KVh0L71`06YZJP1/K6`0Kfm_06i^KP1YJFT00P1`L7006@1bLW80L71`075aL@1`L700
Lg=c079bLP1hN7P0Jf][06m_K`1bLW80Kfm_079bLP1^KVh0LG5a07QhN01iNGT0L71`06m_K`1cLg<0
M7Ad07IfMP1bLW80LG5a06a/K01bLW800P1dM7@0<P1`L700M7Ad07UiN@1cLg<0MGEe07AdM01fMWH0
M7Ad0820P023Ph<0MgMg07QhN025QHD0PH6107alO020P800QHF508^;R`25QHD0QXJ608^;R`2>SXh0
RHV908F5Q@29RHT0Ti>C09:BTP28R8P0Shn?08b<S02BTY80Shn?09fMW@2LW9`0WYjN09ZJVP2PX:00
WIfM0::RXP2SXj<0YZJV09fMW@2[Zj/0XZ:R0:f][@2d];@0[Zj^0;6a/@2_[jl0_;bl0P31`L420;Rh
^00=0<S8b036a/H0alO70=7Ad@3De=@0e]KF0=7Ad@3IfMT0inOW0=cLg03Zj^X0l?3`0?Win@1A0?oo
o`0M0?knoP3moOd0m?Cd0?3`l03/k>`0j>SX0>7Qh@3Ti>@0e]KF0=?Cd`3@d=00a<C40<K6aP30`<00
^;Rh0;Zj^P2c/k<0/K6a0;Bd]02l_;`0/;2`0:b/[02[Zj/0YZJV0:NWY`2SXj<0VYZJ09^KV`2DU9@0
0P2IVIT0202:RXX0Ti>C09>CT`2ATI40UIFE08j>SP2BTY80QXJ60P2@T9005P2>SXh0R8R808:2PP1n
OWh0NGUi07inOP1fMWH0Ng]k08>3P`1nOWh0NGUi07moO`1nOWh0MWIf07]kN`1hN7P0NGUi07]kN`1j
NWX0NGUi06UYJ@1^KVh207IfMP0806i^KP1cLg<0M7Ad06=SH`1XJ6P0JFUY06a/K01^KVh207=cL`04
07QhN01lO7`0MgMg07AdM080J6QX00H0IfMW06YZJP1PH600K6a/06][J`1XJ6P2065QH@0906=SH`1V
IVH0I6AT06UYJ@1RHV80HF5Q06QXJ01RHV80GEeM0080Hf=S00<0Fe]K06=SH`1KFe/05`0000060=WI
f@4000000@3IfMT000050=WIf@000000fMWI0=WIf@0000000P3IfMT010000000fMWI0=WIf@000002
0=WIf@040000003IfMT0fMWI000000D0fMWI00<000000=WIf@3IfMT00`3IfMT05P3Kfm/0JVYZ06=S
H`1^KVh0J6QX06ATI01^KVh0K6a/06ATI01cLg<0KFe]075aL@1VIVH0JVYZ06i^KP1aLG40Lg=c075a
L@1VIVH0LG5a06][J`1bLW8207=cL`0@06i^KP1dM7@0MGEe07AdM01`L700NGUi07alO01gMgL0N7Qh
07UiN@1cLg<0L71`07]kN`1fMWH0Lg=c06m_K`80NGUi00<0Ng]k07QhN01jNWX00P1fMWH08P1hN7P0
O7al07]kN`21PH40R8R807]kN`26QXH0OWin0861P@28R8P0Rh^;08B4Q02;Rh/0QXJ608Z:RP21PH40
TI6A08b<S024Q8@0TI6A08^;R`2EUID0TI6A09RHV02EUID0UiNG09RHV02<S8`0VIVI09BDU02SXj<0
WinO09VIV@2PX:020:FUY@0>0:VYZ@2^[Zh0[:b/0;:b/P2`/;00[jn_0;6a/@2c/k<0_;bl0;^k^`2h
^;P0^k^k0<C4a036a/H30=7Ad@080=OGe`3Lg=`0fMWI0>3Ph03`l?00k^k^0?knoP3hn?Q@0?ooo`0Z
0?knoP3kno/0n?Sh0??cl`3]kNd0jn_[0>SXj03Lg=`0e]KF0=CDe03=cLd0`l?30<W9b@30`<00_[jn
0;fm_@2n_[h0[:b/0;Ng]`2c/k<0/;2`0:n_[`2ZZZX0/;2`0:6QX@2NWYh0XJ6Q09jNWP2GUiL0VYZJ
09FEU@28R8P0SHf=09^KV`2@T900S8b<08J6QP2ATI40S8b<08J6QP28R8P0Shn?0P23Ph<00`22PX80
Ng]k07inOP0207IfMP0508B4Q01hN7P0OWin07moO`1nOWh00P1jNWX02@1fMWH0M7Ad075aL@1iNGT0
MgMg07UiN@1fMWH0M7Ad07=cL`0207IfMP0@071`L01/K6`0MWIf07=cL`1bLW80KVi^079bLP1YJFT0
M7Ad075aL@1fMWH0KVi^06a/K01_Kfl0M7Ad06][J`80IVIV0180J6QX06UYJ@1UIFD0HV9R06=SH`1N
GUh0J6QX061PH01WIfL0IFEU06ATI01QHF40J6QX05iNGP1QHF40G5aL05iNGP1PH60G000000H0fMWI
0@0000010=WIf@000P3IfMT2000000@0fMWI0P0000040=WIf@8000001P3IfMT00`000000fMWI0=WI
f@030=WIf@040>CTi01YJFT0JFUY06EUI@80Jf][0P1ZJVX01`1/K6`0LG5a06a/K01YJFT0L71`06i^
KP1_Kfl00P1aLG4206a/K00?075aL@1_Kfl0JVYZ06][J`1aLG40KVi^07MgM`1^KVh0Kfm_079bLP1c
Lg<0KVi^07MgM`1^KVh0MWIf0080M7Ad00<0KVi^07AdM01iNGT00P1iNGT0401fMWH0N7Qh07moO`1b
LW80M7Ad07]kN`1nOWh0O7al07moO`24Q8@0QXJ608R8R023Ph<0Q8B408^;R`23Ph<208R8R00908f=
S@27QhL0QHF508R8R027QhL0Ph>308Z:RP2=SHd0QhN70080TY:B00`0TI6A09NGU`2DU9@0Ti>C09BD
U02XZ:P0W9bL0:>SX`2LW9`0XZ:R0:BTY02YZJT20::RXP80YZJV01H0[jn_0:f][@2`/;00][Jf0<30
`02i^KT0_kno0<C4a037alL0`<300<_;b`3:b/X0dm?C0<g=c@3AdM40g=cL0=kNgP3Rh^80h>3P0??c
l`3lo?`0nOWiD@3oool0403hn?P0nOWi0??cl`3Ti>@0h^;R0>3Ph03Ogml0eMGE0=3@d03>c/h0cLg=
0<G5a@31`L40^[Zj0;Rh^02g]kL20;6a/@0A0:VYZ@2[Zj/0[:b/09jNWP2UYJD0Y:BT0:2PX02IVIT0
X:2P09>CT`2FUYH0Ti>C092@T02?Shl0Ti>C08j>SP2?Shl00P29RHT00`2;Rh/0TI6A08F5Q@0207em
O@0F0861P@22PX80OGem07inOP24Q8@0OGem07inOP1kNg/0OWin07IfMP1kNg/0NGUi07]kN`1fMWH0
NGUi075aL@1gMgL0NGUi07=cL`1gMgL0KVi^07=cL`80K6a/00L0KFe]075aL@1fMWH0JVYZ06m_K`1`
L700KVi^0080MWIf00T0Lg=c075aL@1_Kfl0K6a/06ATI01XJ6P0Jf][06QXJ01NGUh00P1YJFT0401`
L700Hf=S061PH01OGel0H61P06IVIP1YJFT0I6AT06IVIP1XJ6P0GemO069RHP1QHF40GemO065QH@1D
E5@G000000H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@070>GUi@1[Jf/0
J6QX06a/K01[Jf/0K6a/06IVIP0206i^KP0706][J`1XJ6P0LG5a071`L01^KVh0Lg=c06i^KP02079b
LP0706i^KP1XJ6P0Lg=c07QhN01YJFT0MWIf07MgM`0207EeM@0607QhN01kNg/0KFe]07QhN01dM7@0
Lg=c0P1hN7P05@1fMWH0M7Ad07=cL`1jNWX0Lg=c07IfMP1gMgL0LW9b07UiN@1nOWh0L71`07=cL`1h
N7P0Ng]k08:2PP23Ph<0Ng]k0820P022PX80P8200861P@0208:2PP0308B4Q020P800RXZ:0080Q8B4
00<0S8b<08f=S@28R8P00P2<S8`01@27QhL0SHf=09VIV@2FUYH0V9RH0080VIVI01P0WIfM09VIV@2L
W9`0WYjN0:6QX@2NWYh0Zj^[0:6QX@2XZ:P0Xj>S0;:b/P2ZZZX0/;2`0;6a/@2e]KD0/;2`0;Vi^@2h
^;P0_;bl0<;2`P33`l<0alO70<C4a03<c<`20<k>cP040>7Qh@3Ng]h0hn?S0>k^kP80l?3`00<0nOWi
0?ooo`3oool0CP3oool0=@3jn_X0oooo0?7al@3fm_H0inOW0=kNgP3Hf=P0dM7A0=_Kf`38b<P0c/k>
0<_;b`34a<@0alO70=3@d02h^;P0];Bd0;Fe]@2XZ:P0[Jf]0;2`/02^[Zh0[:b/09nOW`2MWId0Xj>S
09VIV@2HV9P0Vi^K09RHV02GUiL0TI6A09FEU@2ATI40SXj>09RHV029RHT0QXJ608V9R@25QHD0Ph>3
0820P024Q8@0P8200861P@1kNg/0OWin08>3P`27QhL0PH6107QhN01lO7`0Q8B40080MWIf01L0Lg=c
07QhN01gMgL0NGUi07QhN01cLg<0KVi^079bLP1gMgL0Lg=c06m_K`1jNWX0Kfm_071`L01aLG40IFEU
06a/K01]KFd0Jf][06EUI@1/K6`0Jf][06a/K00206i^KP0406a/K01WIfL0IVIV06MWI`80IVIV00@0
JFUY06=SH`1PH600HF5Q0P1VIVH02`1PH600JFUY05iNGP1[Jf/0HV9R06=SH`1NGUh0H61P05iNGP1R
HV80GEeM01L000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0140jNWY
06IVIP1ZJVX0KVi^06UYJ@1`L700Jf][06a/K01VIVH0Kfm_06YZJP1XJ6P0Jf][07AdM01`L700N7Qh
075aL@0206a/K00?079bLP1aLG40Lg=c07=cL`1bLW80KVi^075aL@1`L700N7Qh071`L01hN7P0M7Ad
07=cL`1bLW80MGEe0080MWIf00@0Ng]k0820P01kNg/0MWIf0P1nOWh0201iNGT0MgMg07QhN020P800
OWin07]kN`1hN7P0Ogmo0P1lO7`05@1iNGT0QhN708:2PP26QXH0QHF507inOP24Q8@0Ph>308R8R026
QXH0Rh^;08N7Q`28R8P0Ti>C08R8R02>SXh0R8R808f=S@2BTY80UYJF09RHV00209bLW00409:BTP2K
Vi/0Z:RX0:BTY080Xj>S00H0YZJV0:b/[02UYJD0/K6a0:b/[02XZ:P30;Jf]P070;Ng]`30`<00_[jn
0<?3``2n_[h0a/K60<c<c0020<o?c`030=3@d03Lg=`0eMGE0080g]kN00D0jn_[0??cl`3no_h0n?Sh
0?knoP1?0?ooo`0@0?knoP3alO40kno_0?3`l03Rh^80f=SH0>7Qh@3IfMT0d];B0=?Cd`39bLT0a<C4
0<K6aP35aLD0_[jn0;Vi^@80/K6a00d0/[:b0:n_[`2ZZZX0[:b/0:^[Z`2PX:00Xj>S09BDU02PX:00
Vi^K09JFUP2EUID0TI6A0080U9BD01d0Ti>C096AT@2DU9@0SHf=092@T02<S8`0RXZ:08R8R02<S8`0
PH6108V9R@1lO7`0NGUi07QhN01lO7`0OWin07AdM01cLg<0QHF507IfMP1bLW80LG5a07]kN`1bLW80
M7Ad06i^KP1aLG40KVi^07=cL`02079bLP0>075aL@1`L700MWIf06i^KP1[Jf/0JFUY07MgM`1dM7@0
J6QX06m_K`1]KFd0K6a/06][J`1UIFD206i^KP0G06IVIP1[Jf/0Jf][06YZJP1UIFD0IVIV065QH@1X
J6P0JVYZ06UYJ@1SHf<0IFEU061PH01VIVH0I6AT061PH01WIfL0HV9R06QXJ01KFe/0IVIV05aLG01O
Gel05`0000060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT07@3[jn/0JVYZ
06UYJ@1^KVh0Jf][06QXJ01YJFT0JVYZ06m_K`1`L700Jf][07=cL`1_Kfl0Jf][07=cL`1VIVH0LW9b
06UYJ@1gMgL0M7Ad079bLP1[Jf/0M7Ad07alO01aLG40MWIf07=cL`1gMgL0L71`0080LG5a00D0Lg=c
07AdM01kNg/0N7Qh07YjNP0207]kN`0_08B4Q01iNGT0PH6107MgM`1jNWX0M7Ad07UiN@1nOWh0N7Qh
07]kN`1hN7P0P82007YjNP22PX80NWYj0861P@1oOgl0OWin08B4Q020P800Q8B408Z:RP26QXH0QhN7
08F5Q@24Q8@0Ph>308N7Q`26QXH0TI6A08Z:RP2CTi<0Rh^;08f=S@2IVIT0U9BD09^KV`2PX:00VIVI
09jNWP2VYZH0ZZZZ0:NWY`2VYZH0[jn_0:JVYP2b/[800P2a/K40102^[Zh0/K6a0;Bd]02k^k/20;Vi
^@80_[jn00<0c/k>0<W9b@3<c<`00P3Cdm<02@3QhN40h>3P0=cLg03Shn<0k>c/0?Shn03jn_X0oooo
0?knoP1@0?ooo`0@0?knoP3dm?@0l?3`0>o_k`3Ti>@0h^;R0<o?c`3@d=00cLg=0<S8b036a/H0`/;2
0<K6aP2c/k<0/K6a0;Rh^080/K6a0140ZJVY0;Bd]02TY:@0WinO09bLW02VYZH0X:2P09bLW02MWId0
UYJF09VIV@2ATI40UYJF092@T02CTi<0Rh^;092@T00208V9R@0608R8R026QXH0Rh^;08R8R026QXH0
Ph>30P1oOgl04P1jNWX0PH6107inOP1gMgL0NGUi07=cL`1nOWh0MgMg07IfMP1eMGD0Lg=c071`L01f
MWH0LG5a06a/K01eMGD0KFe]07EeM@80Lg=c00H0K6a/06m_K`1_Kfl0M7Ad06YZJP1eMGD206a/K080
J6QX0P1[Jf/05`1VIVH0IFEU06a/K01^KVh0KFe]06][J`1XJ6P0Lg=c06QXJ01TI6@0HF5Q069RHP1Y
JFT0IfMW05iNGP1SHf<0J6QX06e]K@1ZJVX0H61P05iNGP1VIVH0GUiN0080HF5Q5`0000060=WIf@40
00000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0103Xj>P0K6a/065QH@1VIVH206YZJP0E
06a/K01XJ6P0JFUY06][J`1eMGD0Jf][06a/K01[Jf/0L71`07=cL`1UIFD0MWIf079bLP1_Kfl0J6QX
07UiN@1lO7`0MgMg07=cL`1dM7@0MGEe0080N7Qh0P1aLG400`1fMWH0LG5a071`L00207IfMP0H07Ui
N@23Ph<0LW9b07inOP24Q8@0O7al07]kN`1lO7`0MgMg08:2PP24Q8@0Ogmo07QhN01lO7`0P82007Qh
N023Ph<0QhN708:2PP24Q8@0PH6108B4Q023Ph<0OGem0P24Q8@01@23Ph<0R8R808>3P`26QXH0Ph>3
0080R8R802L0Rh^;092@T02>SXh0W9bL09VIV@2JVYX0WYjN0:BTY02MWId0X:2P0:6QX@2RXZ80Xj>S
0:n_[`2TY:@0[:b/0:n_[`2YZJT0]kNg0:f][@2/[:`0/k>c0;^k^`2o_kl0_Kfm0;^k^`30`<00`l?3
0<_;b`3IfMT0d=3@0=;BdP3De=@0g=cL0>KViP3Ti>@0mOGe0?3`l03fm_H0D03oool0203lo?`0lo?c
0?3`l03fm_H0j>SX0>;RhP3Ogml0emOG0P3>c/h01034a<@0a/K60<G5a@2l_;`20;Rh^0030;>c/`2a
/K40/K6a0080ZJVY02/0Z:RX09jNWP2PX:00Xj>S0:2PX02DU9@0Xj>S09>CT`2NWYh0UIFE09ZJVP2C
Ti<0TI6A08b<S02=SHd0Rh^;08j>SP2;Rh/0PH6108f=S@2:RXX0QXJ608^;R`20P800PX:208B4Q01k
Ng/0OWin07QhN020P800M7Ad07]kN`1]KFd0N7Qh07IfMP1hN7P0MWIf07QhN01dM7@0LW9b06i^KP1d
M7@0LG5a0080MWIf01<0L71`07AdM01bLW80Jf][06=SH`1bLW80KVi^075aL@1UIFD0KVi^06YZJP1[
Jf/0K6a/06QXJ01UIFD0Jf][06ATI01]KFd0K6a/0080JVYZ0100K6a/06ATI01TI6@0IFEU05aLG01N
GUh0Hf=S06ATI01SHf<0GUiN05aLG01SHf<0I6AT05eMG@1LG5`0GemO5`0000060=WIf@4000000@3I
fMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT04P3Xj>P0IVIV06e]K@1/K6`0KVi^06YZJP1YJFT0
K6a/06QXJ01]KFd0JVYZ07AdM01^KVh0Lg=c06m_K`1aLG40LW9b06a/K080LW9b00X0L71`07=cL`1b
LW80L71`06m_K`1cLg<0MGEe06YZJP1fMWH0M7Ad0`1hN7P03`1`L700O7al07IfMP1iNGT0MgMg07Qh
N01kNg/0OGem07alO020P800NWYj0861P@1lO7`0OWin07]kN`0208>3P`0508J6QP21PH40R8R808:2
PP23Ph<00P26QXH04P24Q8@0P82007]kN`1oOgl0Rh^;08Z:RP26QXH0RHV909>CT`2;Rh/0R8R808f=
S@2:RXX0S8b<09VIV@2FUYH0X:2P09^KV`<0W9bL01l0XJ6Q0:BTY02SXj<0X:2P0:BTY02`/;00]KFe
0:b/[02^[Zh0/;2`0:RXZ02`/;00/[:b0;6a/@2d];@0^KVi0<K6aP39bLT0c<c<0<g=c@3>c/h0bLW9
0=KFeP3GemL0inOW0=_Kf`3YjNT0k^k^0?clo03fm_H0o?cl04l0oooo00/0m_Kf0?ooo`3emOD0i^KV
0>;RhP3Lg=`0g]kN0=3@d03:b/X0`l?30<71`@020<?3``0`0;fm_@30`<00];Bd0;Bd]02`/;00Zj^[
0:VYZ@2^[Zh0XZ:R0:b/[02^[Zh0WYjN09fMW@2SXj<0X:2P09VIV@2DU9@0TI6A09RHV02GUiL0T92@
08V9R@2@T900Rh^;08B4Q026QXH0QHF508R8R01oOgl0PX:208^;R`23Ph<0NGUi08R8R01fMWH0QHF5
07AdM01mOGd0OWin07AdM01gMgL0N7Qh07UiN@1dM7@0N7Qh07IfMP1hN7P0Jf][0P1`L7000`1^KVh0
L71`07EeM@02075aL@0606UYJ@1dM7@0K6a/06m_K`1YJFT0JVYZ0P1XJ6P06`1`L700LG5a06UYJ@1Y
JFT0K6a/06ATI01XJ6P0I6AT061PH01`L700KVi^065QH@1WIfL0J6QX065QH@1VIVH0Hf=S069RHP1Q
HF40IVIV065QH@1PH600Hf=S069RHP1NGUh0FUYJ05]KF`0G000000H0fMWI0@0000010=WIf@005P3I
fMT00`000000fMWI0=WIf@030=WIf@040>7Qh@1/K6`0IVIV06i^KP80J6QX00@0IfMW06a/K01cLg<0
LG5a0P1`L700101bLW80KVi^071`L01^KVh207=cL`0M07AdM01[Jf/0MWIf07=cL`1fMWH0KFe]07Ad
M01gMgL0NWYj07IfMP1eMGD0N7Qh07MgM`1cLg<0MWIf07EeM@1iNGT0P82007QhN01gMgL0Lg=c07in
OP1hN7P0M7Ad07UiN@1hN7P0P82007MgM`1nOWh00P1kNg/01P26QXH0Ogmo08>3P`2;Rh/0Ph>308F5
Q@80RHV900H0OGem07alO021PH40RHV908R8R02<S8`208R8R00408>3P`2<S8`0TI6A08N7Q`80SXj>
01H0R8R809JFUP2KVi/0X:2P09^KV`2NWYh0X:2P09bLW02RXZ80WinO0:2PX02TY:@0/K6a0:JVYP2^
[Zh0Zj^[0;Vi^@2/[:`0][Jf0;Fe]@2c/k<0a/K60P31`L402035aLD0a<C40=3@d03AdM40dm?C0=KF
eP3IfMT0fm_K0P3Xj>P00`3]kNd0nOWi0?_kn`1@0?ooo`070?knoP3dm?@0l_;b0>CTi03UiND0g]kN
0=KFeP020=?Cd`0F0<W9b@3;bl/0`L710<71`@2g]kL0^KVi0;>c/`2^[Zh0ZJVY0:RXZ02a/K40[Jf]
0:2PX02SXj<0X:2P09^KV`2OWil0Xj>S0:JVYP2GUiL0Ti>C09:BTP80W9bL02<0UYJF096AT@29RHT0
S8b<08J6QP2<S8`0T92@08b<S01kNg/0RHV907moO`22PX80Ph>30820P024Q8@0N7Qh0820P01lO7`0
MgMg071`L01kNg/0N7Qh07MgM`1hN7P0NGUi079bLP1dM7@0MgMg075aL@1dM7@0Lg=c06i^KP1_Kfl0
JFUY06][J`02075aL@0<06UYJ@1bLW80K6a/06][J`1VIVH0JFUY06][J`1SHf<0JFUY06QXJ01/K6`0
Hf=S0P1XJ6P03P1YJFT0I6AT05eMG@1NGUh0Jf][06QXJ01UIFD0J6QX06ATI01PH600HF5Q06QXJ01R
HV80Hf=S0P1PH6000`1NGUh0IFEU05aLG00G000000H0fMWI0@0000010=WIf@005P3IfMT00`000000
fMWI0=WIf@030=WIf@030>7Qh@1XJ6P0JVYZ0080Jf][0180LG5a06YZJP1cLg<0IfMW06e]K@1cLg<0
Kfm_071`L01^KVh0L71`07AdM01bLW80GUiN07=cL`1fMWH0LG5a06m_K`1bLW8206i^KP0407QhN01`
L700LW9b07UiN@80MWIf0P1dM7@00`1kNg/0M7Ad07]kN`0207QhN00>07AdM01mOGd0Ng]k07EeM@1l
O7`0N7Qh08>3P`1hN7P0PH6107MgM`25QHD0PH6108>3P`21PH4208V9R@0J0820P01mOGd0PH6107em
O@1jNWX0Ng]k08>3P`24Q8@0Rh^;08R8R027QhL0Ti>C08J6QP2<S8`0RXZ:08b<S02@T900UYJF09ZJ
VP2DU9@0UiNG09fMW@2LW9`0WIfM0:6QX@2MWId209jNWP090:>SX`2XZ:P0XJ6Q0:b/[02^[Zh0/K6a
0:n_[`2d];@0]kNg0080/k>c00/0_[jn0;fm_@30`<00dM7A0<W9b@3;bl/0d];B0=3@d03Ogml0f=SH
0=cLg0020>SXj0030?KfmP3[jn/0m?Cd04h0oooo0P3inOT04P3_knl0jNWY0>OWi`3Xj>P0g]kN0=_K
f`3De=@0b<S80<K6aP34a<@0`l?30<S8b02l_;`0^;Rh0;Bd]02`/;00[:b/0:JVYP80X:2P01D0YZJV
0:BTY02XZ:P0YJFU0:>SX`2[Zj/0VYZJ0:2PX02>SXh0Ti>C092@T02KVi/0SHf=096AT@2=SHd0R8R8
08n?S`26QXH0S8b<08B4Q02<S8`00P28R8P05021PH40MWIf08:2PP20P800NGUi07alO01oOgl0NGUi
07YjNP1iNGT0Jf][07EeM@1oOgl0NWYj075aL@1iNGT0N7Qh06][J`1kNg/0K6a/0P1YJFT0101/K6`0
L71`071`L01^KVh206UYJ@0@06a/K01aLG40Jf][06a/K01[Jf/0LG5a06i^KP1ZJVX0Jf][06UYJ@1T
I6@0JFUY06YZJP1RHV80IVIV065QH@80Hf=S00P0K6a/069RHP1UIFD0H61P05eMG@1NGUh0HV9R06=S
H`<0HV9R00<0Hf=S05UIF@0000005P0000060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3I
fMT00`3IfMT0103Lg=`0K6a/071`L01_Kfl206][J`0@06a/K01XJ6P0J6QX06QXJ01ZJVX0K6a/06QX
J01]KFd0N7Qh07EeM@1_Kfl0LW9b07AdM01_Kfl0M7Ad07=cL`80M7Ad00<0KVi^071`L01bLW800P1e
MGD04@1cLg<0MgMg075aL@1bLW80MWIf07emO@1hN7P0Ng]k06i^KP1hN7P0Ng]k07MgM`1dM7@0MWIf
07YjNP1eMGD0Ng]k0080Ogmo00H0P82008:2PP23Ph<0R8R808Z:RP28R8P208B4Q00A07UiN@24Q8@0
P82008:2PP26QXH0Q8B408R8R027QhL0QXJ608>3P`2DU9@0Shn?08N7Q`2?Shl0T92@08f=S@2FUYH0
0P2@T9001`2HV9P0WYjN09RHV02NWYh0Y:BT09fMW@2@T9000P2QXJ401@2RXZ80ZJVY0:^[Z`2`/;00
]KFe0080/K6a00L0^k^k0;Rh^030`<00`<300<;2`P37alL0c<c<0080dm?C00T0e=CD0=WIf@3IfMT0
g]kN0>;RhP3YjNT0kNg]0?;blP3lo?`00P3no_i;0?ooo`0<0?knoP3oool0l_;b0?Shn03gmoL0gMgM
0=kNgP3Kfm/0emOG0<k>cP3Hf=P0`l?30P2l_;`01`30`<00_;bl0;jn_P2_[jl0[:b/0;Jf]P2YZJT0
0P2/[:`20:6QX@80Y:BT02/0WIfM0::RXP2SXj<0VIVI09BDU02HV9P0Ti>C09JFUP2:RXX0UYJF09BD
U02=SHd0Ph>308B4Q026QXH0Q8B40861P@1oOgl0PX:207inOP23Ph<0P82007]kN`1fMWH0OWin0861
P@1hN7P0O7al07UiN@1dM7@0Ng]k07emO@1fMWH0NGUi07YjNP1kNg/0MGEe06e]K@1fMWH0Lg=c06YZ
JP1hN7P0JVYZ0080K6a/00h0JFUY06a/K01`L700LG5a06][J`1^KVh0KFe]06i^KP1WIfL0J6QX06=S
H`1WIfL0IFEU06IVIP<0HF5Q00D0JFUY05mOG`1TI6@0H61P065QH@0206ATI00506EUI@1[Jf/0J6QX
06ATI01KFe/00P1QHF400`1PH600F5QH0000000F000000H0fMWI0@0000010=WIf@005P3IfMT20000
00@0fMWI04<0h^;R06YZJP1]KFd0JFUY06i^KP1_Kfl0Jf][06m_K`1ZJVX0L71`06UYJ@1[Jf/0JVYZ
071`L01cLg<0LW9b07=cL`1`L700Lg=c079bLP1cLg<0KVi^075aL@1YJFT0NGUi06m_K`1kNg/0Kfm_
07EeM@1hN7P0K6a/07alO01bLW80Ng]k07QhN01cLg<0MGEe07UiN@1kNg/0N7Qh07YjNP1nOWh0NGUi
07MgM`1cLg<0O7al08:2PP1aLG40O7al0820P023Ph<0R8R808J6QP1nOWh0RXZ:07moO`23Ph<0Q8B4
08J6QP21PH40OGem0820P02=SHd0RXZ:08b<S023Ph<0T92@0080SHf=01/0U9BD09>CT`2CTi<0T92@
09fMW@2TY:@0X:2P09VIV@2KVi/0W9bL09FEU@2NWYh0X:2P0:6QX@2XZ:P0Xj>S0:RXZ02^[Zh0[:b/
0:RXZ02ZZZX0];Bd0:j^[P2b/[80^;Rh0<c<c02m_Kd00P34a<@0303AdM40c<c<0=?Cd`3De=@0e]KF
0>3Ph03Ogml0j>SX0>_[j`3fm_H0l?3`0?clo4h0oooo01X0k^k^0>SXj03_knl0k>c/0>7Qh@3Bd]80
cLg=0=?Cd`3;bl/0`l?30;Vi^@2l_;`0`<300;Vi^@2e]KD0][Jf0;>c/`2][Jd0Zj^[0:BTY02VYZH0
Xj>S0:2PX02XZ:P0Y:BT0:^[Z`80XJ6Q00/0UYJF09BDU02<S8`0TY:B096AT@2@T900SXj>08V9R@2=
SHd0Ph>308Z:RP0208F5Q@0H0861P@1lO7`0Q8B40861P@1mOGd0Ng]k08B4Q01kNg/0O7al07QhN01g
MgL0R8R807IfMP1dM7@0Lg=c07IfMP1aLG40KVi^07QhN01cLg<0KFe]075aL@1gMgL0KVi^0P1aLG40
4`1cLg<0IVIV07EeM@1^KVh0Jf][06QXJ01NGUh0KVi^06m_K`1[Jf/0J6QX06UYJ@1[Jf/0IVIV06a/
K01ZJVX0IVIV06EUI@1WIfL00P1[Jf/03`1TI6@0HF5Q06MWI`1YJFT0Hf=S06IVIP1TI6@0GEeM05YJ
FP1PH600IVIV05iNGP0F5QH0@41005QHF00G000000D0fMWI0P0000010=WIf@005P3IfMT00`000000
fMWI0=WIf@030=WIf@0E0>;RhP1TI6@0Hf=S06MWI`1^KVh0KFe]06UYJ@1^KVh0K6a/06][J`1_Kfl0
JFUY06a/K01cLg<0M7Ad06YZJP1_Kfl0MGEe071`L01iNGT0KFe]0080M7Ad00`0MWIf07AdM01_Kfl0
NWYj07UiN@1fMWH0MgMg07IfMP1_Kfl0O7al079bLP1eMGD207=cL`070861P@1iNGT0MgMg0861P@1k
Ng/0MWIf0820P00207]kN`0A07inOP1kNg/0NGUi07inOP24Q8@0Ogmo08:2PP23Ph<0PH6108R8R025
QHD0PH6108:2PP23Ph<0Rh^;07alO023Ph<00P28R8P01P29RHT0R8R808j>SP2;Rh/0SXj>08n?S`80
TI6A00X0UiNG09JFUP2HV9P0V9RH09bLW02QXJ40W9bL09jNWP2QXJ40Zj^[0P2VYZH06P2TY:@0[Zj^
0;>c/`2^[Zh0/[:b0;2`/02d];@0`L710;fm_@2g]kL0aLG50<C4a030`<00a<C40=7Ad@3Fe]H0eMGE
0=cLg03De=@0inOW0>WYj@3Ti>@0l?3`0>[ZjP3oool0oOgmBP3oool05P3inOT0o?cl0?Win@3alO40
lo?c0>WYj@3WinL0e]KF0=SHf03Fe]H0dm?C0<G5a@2n_[h0`l?30;Zj^P2k^k/0/;2`0;Bd]02f][H0
/K6a0:j^[P2[Zj/20:NWY`0?09nOW`2LW9`0YjNW0:6QX@2KVi/0X:2P09RHV02ATI40U9BD09JFUP2C
Ti<0Shn?07moO`2;Rh/0S8b<0080SHf=00@0S8b<08R8R027QhL0RHV90P23Ph<01024Q8@0OWin07in
OP1iNGT307]kN`0;07inOP1iNGT0MgMg06i^KP1fMWH0M7Ad06][J`1bLW80M7Ad07QhN01[Jf/00P1^
KVh0101`L700LW9b079bLP1[Jf/206QXJ00406m_K`1^KVh0Kfm_06a/K080JFUY0P1XJ6P01@1aLG40
K6a/06YZJP1TI6@0KFe]0080JFUY00@0K6a/06ATI01UIFD0IfMW0P1SHf<0301VIVH0Hf=S06MWI`1Q
HF40GUiN06EUI@1OGel0HV9R05mOG`14A4@0DE5A05EEEAL000001P3IfMT100000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI00D0i>CT06MWI`1XJ6P0KVi^06e]K@0206][J`0j06a/K01aLG40
JFUY06QXJ01YJFT0IFEU079bLP1WIfL0Lg=c075aL@1YJFT0M7Ad06i^KP1cLg<0MGEe07AdM01^KVh0
MWIf06i^KP1lO7`0MgMg075aL@1`L700NGUi07inOP1mOGd0MWIf06m_K`1`L700O7al07=cL`1dM7@0
Ng]k07YjNP1iNGT0Ogmo07UiN@1kNg/0NGUi07AdM01nOWh0Ph>307emO@1oOgl0Ph>30861P@1jNWX0
Ph>308B4Q021PH40OWin07moO`1iNGT0PX:20820P029RHT0UYJF08N7Q`80RHV90100U9BD09>CT`2;
Rh/0RXZ:096AT@2CTi<0UiNG09VIV@2SXj<0V9RH09fMW@2NWYh0YZJV0:BTY02VYZH0YJFU0P2SXj<0
102YZJT0/K6a0;:b/P2g]kL20;Jf]P0E0;fm_@2d];@0^KVi0;Rh^033`l<0`L710<G5a@3:b/X0f=SH
0=_Kf`3GemL0fm_K0=cLg03Xj>P0e=CD0>c/k03`l?00nOWi0?clo03no_h0nOWi04T0oooo00@0o?cl
0?ooo`3^k^h0m_Kf0P3Vi^H02P3Ti>@0emOG0=?Cd`3Fe]H0dm?C0<_;b`34a<@0`l?30<C4a031`L43
0;Ng]`0:0:b/[02VYZH0Y:BT0:BTY02MWId0YZJV0:RXZ02UYJD0WYjN09ZJVP80VIVI00L0U9BD09JF
UP2MWId0Ti>C09JFUP2>SXh0RXZ:0080RHV90P28R8P0102CTi<0PX:208J6QP22PX8208B4Q0030820
P025QHD0N7Qh0080MWIf01<0NGUi07alO01kNg/0N7Qh07IfMP1dM7@0LW9b06][J`1`L700KVi^071`
L01/K6`0N7Qh06i^KP1dM7@0L71`06a/K01aLG40KVi^0080Kfm_00L0Jf][06i^KP1[Jf/0JFUY06QX
J01/K6`0Jf][0080IVIV00d0JFUY06][J`1YJFT0IFEU06ATI01[Jf/0HF5Q06ATI01VIVH0HV9R06=S
H`1OGel0H61P00<0IVIV00L0J6QX06ATI01VIVH0F5QH06ATI01QHF40GUiN01L000001P3IfMT10000
0040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00/0k^k^06a/K01[Jf/0K6a/071`L01iNGT0
IFEU06][J`1^KVh0JFUY06][J`02071`L00806YZJP1`L700LG5a06i^KP1aLG40M7Ad075aL@1`L702
07=cL`0@06IVIP1cLg<0LW9b071`L01hN7P0M7Ad079bLP1iNGT0LG5a06a/K01gMgL0Ogmo07IfMP1h
N7P0NGUi07IfMP80NGUi00D0MgMg0861P@1hN7P0P82007inOP0207emO@0608B4Q01nOWh0OGem08J6
QP2:RXX0Q8B40`23Ph<02028R8P0PH6108J6QP2=SHd0RHV908R8R029RHT0QXJ60P28R8P01@2;Rh/0
RHV909RHV02BTY80SXj>0080TY:B01`0VIVI09ZJVP2MWId0WinO0:6QX@2TY:@0WYjN0:BTY02SXj<0
Zj^[0:j^[P2ZZZX0[Jf]0;6a/@2/[:`0Xj>S0;Fe]@2l_;`0^KVi0;bl_030`<00`/;20<S8b03;bl/0
dm?C0<K6aP3@d=00g=cL0P3Hf=P01`3Rh^80hN7Q0>CTi03Xj>P0jn_[0?clo03no_h0BP3oool0703n
o_h0oOgm0?Cdm03YjNT0j^[Z0>7Qh@3Ti>@0f=SH0=KFeP3<c<`0b<S80<C4a039bLT0a<C40;Bd]02l
_;`0^[Zj0;jn_P2a/K40];Bd0:b/[02VYZH0ZJVY09jNWP2UYJD0W9bL09fMW@2OWil209bLW00L092@
T02DU9@0TI6A09>CT`2DU9@0UYJF09:BTP28R8P0T92@09:BTP23Ph<0QHF508Z:RP29RHT0Ph>307em
O@28R8P0Ng]k08^;R`21PH40Ogmo07UiN@1gMgL0OWin071`L01fMWH0OWin07EeM@80MWIf0P1`L700
3`1^KVh0LG5a07IfMP1aLG40N7Qh079bLP1XJ6P0LW9b06i^KP1aLG40KVi^06UYJ@1XJ6P0LG5a06IV
IP0206UYJ@0706a/K01XJ6P0K6a/06EUI@1ZJVX0JFUY06e]K@0206UYJ@0506ATI01UIFD0IVIV06MW
I`1SHf<00P1XJ6P02`1RHV80H61P06=SH`1RHV80GEeM05mOG`1PH600GUiN05aLG01HF5P0FEUI01L0
00001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0180jNWY06ATI01VIVH0
Kfm_06QXJ01/K6`0J6QX06MWI`1`L700Kfm_06UYJ@1_Kfl0L71`06e]K@1^KVh0JFUY079bLP1`L702
07=cL`0407IfMP1cLg<0Lg=c07MgM`80N7Qh03/0MWIf075aL@1bLW80NWYj07=cL`1nOWh0MGEe07]k
N`1fMWH0N7Qh07IfMP1iNGT0Ng]k07alO01mOGd0MGEe07UiN@20P800NGUi08Z:RP22PX80QHF507in
OP23Ph<0PH6108J6QP28R8P0PH6108>3P`1oOgl0QXJ608b<S026QXH0Ng]k08V9R@25QHD0QhN708V9
R@28R8P0QHF508V9R@2=SHd0Rh^;08b<S02HV9P0U9BD09RHV02FUYH0T92@09VIV@2QXJ40UYJF09nO
W`2PX:00WIfM0:6QX@2][Jd0X:2P0:BTY0030:f][@060:b/[02b/[80/k>c0;Vi^@2l_;`0_[jn0P2o
_kl03@33`l<0alO70<k>cP30`<00cLg=0=SHf03EeMD0hn?S0>GUi@3Shn<0i^KV0>OWi`3alO40C03o
ool01P3emOD0n?Sh0?7al@3alO40jn_[0>CTi080fMWI0P3Fe]H07`39bLT0`L710<71`@31`L40^;Rh
0<71`@2b/[80/k>c0;Rh^02^[Zh0ZJVY0:ZZZP2XZ:P0Xj>S0:6QX@2HV9P0WIfM09NGU`2CTi<0UYJF
09ZJVP2CTi<0Shn?09NGU`2?Shl0Ti>C092@T027QhL0T92@08^;R`28R8P00P26QXH03@2?Shl0PX:2
07emO@1lO7`0Q8B407inOP23Ph<0OGem07alO01hN7P0Ng]k07inOP1lO7`00P1hN7P01021PH40MWIf
07MgM`1hN7P2075aL@0807YjNP1YJFT0L71`06i^KP1/K6`0M7Ad071`L01^KVh206][J`0@06i^KP1`
L700KVi^071`L01ZJVX0KFe]06i^KP1YJFT0KVi^06UYJ@1TI6@0IfMW06e]K@1YJFT0JVYZ06i^KP80
JFUY00h0J6QX06ATI01OGel0IFEU069RHP1/K6`0HV9R05]KF`1PH600HF5Q05mOG`1TI6@0HV9R065Q
HAL000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00h0kno_06a/K01c
Lg<0L71`06i^KP1cLg<0JVYZ06][J`1^KVh0LG5a06YZJP1[Jf/0Lg=c075aL@80Jf][01D0MWIf07Ad
M01[Jf/0Lg=c071`L01dM7@0LW9b06i^KP1hN7P0M7Ad075aL@1cLg<0N7Qh075aL@1cLg<0MGEe075a
L@1gMgL0O7al07QhN01jNWX00P1iNGT207emO@0@07alO01iNGT0OGem08>3P`1kNg/0OWin0820P021
PH40Ng]k07inOP21PH40QHF508J6QP1nOWh0MWIf08V9R@<0QXJ600`0RHV908J6QP2;Rh/0R8R808J6
QP29RHT0U9BD08j>SP2ATI40UiNG09:BTP2>SXh2092@T00A09>CT`2KVi/0VYZJ09^KV`2RXZ80V9RH
0:>SX`2VYZH0YjNW0:>SX`2YZJT0YZJV0:^[Z`2`/;00/K6a0:VYZ@2^[Zh00P2c/k<02P2h^;P0`L71
0<71`@33`l<0`<300<?3``39bLT0f=SH0<[:bP3IfMT20=gMg@070>;RhP3Shn<0i>CT0>k^kP3lo?`0
no_k0?;blP190?ooo`0K0?_kn`3gmoL0lo?c0?7al@3Shn<0hN7Q0=_Kf`3De=@0`l?30<W9b@36a/H0
a<C40<71`@2h^;P0^[Zj0;Bd]02f][H0[:b/0;6a/@2][Jd0/[:b0:>SX`2XZ:P0Xj>S09nOW`2SXj<0
XJ6Q00<0VYZJ01D0U9BD09nOW`2FUYH0W9bL08j>SP2?Shl0TI6A08^;R`2ATI40P82008B4Q01nOWh0
RHV908B4Q01nOWh0Ph>30861P@24Q8@0OWin0820P01iNGT00`20P8001P1nOWh0NGUi07]kN`1fMWH0
L71`07inOP80M7Ad00X0MGEe079bLP1fMWH0M7Ad07QhN01bLW80K6a/06i^KP1VIVH0KVi^0P1`L700
2P1YJFT0KVi^071`L01cLg<0JFUY06QXJ01`L700G5aL06EUI@1TI6@206UYJ@0606][J`1YJFT0IFEU
06IVIP1YJFT0K6a/0P1RHV80301VIVH0IfMW06EUI@1PH600Hf=S05eMG@1SHf<0H61P05iNGP1KFe/0
GEeM05aLG1L000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00H0j^[Z
06i^KP1/K6`0K6a/06e]K@1[Jf/206a/K00906e]K@1/K6`0L71`07AdM01_Kfl0LG5a06UYJ@1_Kfl0
JVYZ0080LG5a0280KVi^075aL@1^KVh0L71`07AdM01cLg<0L71`07=cL`1fMWH0NGUi07EeM@1jNWX0
MGEe07]kN`1`L700N7Qh07IfMP1hN7P0NGUi07IfMP1lO7`0N7Qh07UiN@1mOGd0NWYj08N7Q`1nOWh0
Q8B407emO@21PH40O7al08F5Q@1lO7`0QHF50P1lO7`02`29RHT0P82008J6QP26QXH0QhN708V9R@27
QhL0QXJ608R8R02<S8`0Rh^;0080QXJ602d0Ti>C08j>SP2<S8`0UYJF09bLW02HV9P0U9BD09VIV@2N
WYh0WIfM0:2PX02JVYX0Xj>S0:JVYP2UYJD0Z:RX0:JVYP2a/K40XJ6Q0:VYZ@2WYjL0Y:BT0;>c/`2n
_[h0]KFe0;Zj^P2n_[h0^;Rh0<C4a02l_;`0bl_;0<?3``3Cdm<0dM7A0=KFeP3Kfm/0g=cL0=oOg`3K
fm/0jn_[0?Gem@3inOT0o_kn0?ooo`3no_h0B03oool02`3hn?P0l?3`0?Gem@3WinL0i^KV0=gMg@3D
e=@0clo?0=KFeP3IfMT0`L710080a<C400<0/k>c0;Vi^@2`/;000P2d];@0502VYZH0ZJVY0:JVYP2P
X:00WIfM09bLW02IVIT0V9RH0:6QX@2HV9P0WIfM08n?S`2ATI40UIFE09NGU`2>SXh0S8b<09:BTP2>
SXh0Rh^;0P2>SXh09@29RHT0QhN708>3P`28R8P0P82008R8R021PH40O7al07inOP1mOGd0QhN707al
O01kNg/0O7al07]kN`1gMgL0PH6107QhN01aLG40MgMg07=cL`1bLW80Ng]k07IfMP1hN7P0LW9b075a
L@1iNGT0JFUY07IfMP1_Kfl0KFe]075aL@1TI6@0K6a/06][J`1`L7000P1ZJVX06`1[Jf/0KFe]06YZ
JP1SHf<0K6a/06UYJ@1`L700Jf][06ATI01[Jf/0IVIV06YZJP1VIVH0Hf=S05iNGP1SHf<0I6AT061P
H01SHf<0J6QX05iNGP1VIVH0FEUI05aLG01SHf<0HF5Q05]KF`0G000000H0fMWI0@0000010=WIf@00
5P3IfMT00`000000fMWI0=WIf@030=WIf@070>WYj@1aLG40J6QX06m_K`1/K6`0IFEU06IVIP0206i^
KP80Lg=c00D0L71`07=cL`1cLg<0Lg=c06i^KP02071`L00:079bLP1iNGT0KVi^06i^KP1hN7P0MGEe
07=cL`1hN7P0M7Ad06i^KP80Lg=c00d0M7Ad06i^KP1iNGT0NWYj075aL@1lO7`0N7Qh0820P01iNGT0
M7Ad07IfMP1kNg/0NGUi0080N7Qh00<0Ng]k07alO021PH400P1nOWh0101fMWH0Ph>30861P@1mOGd3
08B4Q00/08b<S024Q8@0RHV908V9R@2=SHd0Shn?08^;R`2>SXh0QXJ608R8R02=SHd0T92@08Z:RP2F
UYH0Rh^;09JFUP2HV9P0W9bL09RHV02EUID0W9bL09NGU`2RXZ80Xj>S09bLW02PX:00YZJV0:>SX`2P
X:00ZZZZ0:>SX`2/[:`0];Bd0;Ng]`2a/K40^;Rh0;Ng]`2n_[h0][Jf0;bl_033`l<0b<S80<k>cP3<
c<`20=?Cd`080>3Ph03Jf]X0hN7Q0=cLg03/k>`0j>SX0?;blP3clo=80?ooo`060?knoP3hn?P0m?Cd
0?Shn03[jn/0gMgM0P3QhN405@3Fe]H0c/k>0=KFeP38b<P0bLW90<K6aP33`l<0_[jn0;Bd]02`/;00
/K6a0:b/[02XZ:P0Y:BT0:^[Z`2VYZH0WYjN09fMW@2JVYX0V9RH09nOW`0209VIV@0E09JFUP2>SXh0
TI6A08b<S02DU9@0TI6A08n?S`2=SHd0Ph>308n?S`2=SHd0S8b<08B4Q021PH40Q8B40820P01oOgl0
P82008>3P`21PH40N7Qh0080OWin01<0Ogmo07inOP1iNGT0OWin07=cL`1iNGT0MGEe07UiN@1cLg<0
LG5a06m_K`1dM7@0KFe]07EeM@1^KVh0Jf][07IfMP1`L700Lg=c0080L71`00h0J6QX06i^KP1]KFd0
JVYZ06UYJ@1aLG40HV9R075aL@1XJ6P0Kfm_06QXJ01VIVH0I6AT06UYJ@80Jf][0140H61P06EUI@1S
Hf<0J6QX06EUI@1]KFd0IVIV06MWI`1UIFD0Hf=S065QH@1VIVH0Hf=S05eMG@1TI6@0FUYJ05eMG@0G
000000H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@070>OWi`1^KVh0IVIV
06e]K@1/K6`0KVi^075aL@0206a/K003071`L01/K6`0Jf][0080KVi^00L0K6a/06m_K`1[Jf/0KFe]
071`L01cLg<0LG5a0080L71`01@0K6a/07MgM`1^KVh0K6a/079bLP1cLg<0LW9b07=cL`1bLW80Lg=c
07alO01fMWH0MGEe07UiN@1jNWX0MGEe07QhN01iNGT0P82007YjNP80OWin00@0PH6107alO022PX80
NGUi0P1kNg/01`20P800QHF508J6QP20P800PH6108J6QP29RHT00P2;Rh/01021PH40SXj>08V9R@28
R8P208V9R@0609JFUP2@T900Ti>C09:BTP2?Shl0TY:B0P2CTi<04P2EUID0UYJF0:6QX@2RXZ80XJ6Q
09nOW`2HV9P0Y:BT0:JVYP2TY:@0YJFU0:>SX`2OWil0YjNW0:RXZ02^[Zh0[:b/0;6a/@80^;Rh00L0
]KFe0;Bd]032`/80]kNg0<k>cP3=cLd0d];B0080c<c<00T0eMGE0=SHf03Jf]X0hn?S0=kNgP3^k^h0
kNg]0?gmo@3no_h0A`3oool0903fm_H0l?3`0?Cdm03`l?00lo?c0>7Qh@3IfMT0fm_K0=OGe`3>c/h0
a<C40<o?c`33`l<0^KVi0;^k^`2i^KT0`<300;Bd]02g]kL0];Bd0;>c/`2`/;00Z:RX0:b/[02JVYX0
WinO09RHV02IVIT0VYZJ09RHV02FUYH0V9RH08j>SP2ATI40TY:B09BDU080TI6A00X0Ph>308b<S029
RHT0PX:208V9R@26QXH0R8R808>3P`27QhL0Ph>30P21PH405`28R8P0OWin08:2PP1kNg/0OGem07Mg
M`1iNGT0M7Ad07YjNP1iNGT0Lg=c07UiN@1bLW80KVi^06m_K`1dM7@0LW9b075aL@1`L700K6a/06QX
J01^KVh0K6a/0080LW9b0P1XJ6P0201`L700I6AT06YZJP1ZJVX0K6a/06QXJ01cLg<0JVYZ0P1XJ6P0
0`1ZJVX0IfMW06=SH`0306IVIP80I6AT00d0G5aL06QXJ01PH600Hf=S069RHP1QHF40G5aL06MWI`1J
FUX0I6AT05eMG@1LG5`0HF5Q01L000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI
00<0fMWI00P0j^[Z05mOG`1/K6`0LG5a06i^KP1YJFT0J6QX07AdM080L71`00H0Lg=c071`L01VIVH0
Lg=c06UYJ@1fMWH206a/K00307QhN01ZJVX0Kfm_0080Lg=c00H0L71`075aL@1fMWH0Kfm_075aL@1c
Lg<207IfMP0807UiN@1hN7P0MWIf07]kN`1bLW80MWIf07AdM01kNg/207YjNP0707emO@1fMWH0PH61
07inOP1hN7P0OWin07alO00207inOP0g0861P@20P800Ogmo08B4Q029RHT0QhN708b<S029RHT0PH61
08b<S024Q8@0SXj>08V9R@2>SXh0QXJ6092@T02=SHd0Rh^;08j>SP2=SHd0Vi^K09JFUP2>SXh0WinO
09ZJVP2LW9`0WYjN0:6QX@2SXj<0WinO0:RXZ02QXJ40XZ:R0:>SX`2HV9P0Y:BT0:^[Z`2YZJT0[:b/
0;2`/02][Jd0];Bd0;6a/@2e]KD0/K6a0;Rh^02m_Kd0`l?30<S8b039bLT0bl_;0<W9b@3Hf=P0h>3P
0=kNgP020>7Qh@050>3Ph03alO40iNGU0?;blP3moOd0A`3oool05@3lo?`0m_Kf0?;blP3alO40hN7Q
0>?Sh`3Kfm/0e]KF0=3@d03?cll0c<c<0<W9b@33`l<0_kno0;^k^`2d];@0/;2`0;Fe]@2c/k<0[Zj^
0:VYZ@020:6QX@0@0:BTY02MWId0VIVI09bLW02OWil0VIVI09JFUP2GUiL0U9BD09JFUP2CTi<0TI6A
08b<S02>SXh0R8R8096AT@80Q8B400d0Rh^;08J6QP29RHT0PH6108R8R023Ph<0Q8B407emO@1lO7`0
N7Qh07alO01fMWH0OGem0080NGUi00l0Ng]k07alO01kNg/0M7Ad07EeM@1iNGT0MGEe07=cL`1gMgL0
LG5a06m_K`1aLG40KFe]075aL@1_Kfl00`1^KVh01@1[Jf/0KFe]06QXJ01/K6`0HV9R0080JFUY01/0
Hf=S06EUI@1VIVH0J6QX06EUI@1YJFT0IFEU065QH@1XJ6P0JFUY06ATI01SHf<0J6QX069RHP1XJ6P0
IfMW061PH01VIVH0HV9R05iNGP1VIVH0Fe]K06ATI01PH600GUiN05aLG01DE5@05`0000060=WIf@40
00000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT01P3Ti>@0KVi^06a/K01XJ6P0JVYZ06UY
J@80LG5a00H0K6a/07=cL`1bLW80Jf][07MgM`1bLW8207=cL`0F07AdM01cLg<0Jf][07AdM01^KVh0
Jf][06UYJ@1eMGD0M7Ad07]kN`1^KVh0MWIf07AdM01fMWH0O7al07MgM`1eMGD0M7Ad07IfMP1cLg<0
MGEe07YjNP80MGEe00X0P82007MgM`1hN7P0Ng]k0861P@1bLW80M7Ad07alO01iNGT0O7al0P1nOWh2
08B4Q00I07inOP2;Rh/0PX:208B4Q026QXH0Ph>308F5Q@2:RXX0QhN708R8R02ATI40Rh^;08j>SP2;
Rh/0T92@096AT@2HV9P0UiNG09BDU02CTi<0Vi^K09RHV02CTi<0VYZJ0:6QX@0209^KV`<0XJ6Q00T0
ZJVY0:BTY02a/K40XJ6Q0;6a/@2`/;00]kNg0;Bd]02a/K400P2d];@01`2i^KT0^k^k0<;2`P39bLT0
b<S80=?Cd`3>c/h00P3@d=002P3De=@0g=cL0>3Ph03Ph>00j>SX0>7Qh@3]kNd0n?Sh0?ooo`3lo?a4
0?ooo`0a0?clo03jn_X0k>c/0>c/k03Vi^H0g=cL0=oOg`3IfMT0dm?C0<o?c`39bLT0b/[:0<C4a02l
_;`0^k^k0;jn_P2o_kl0`/;20;Vi^@2c/k<0[:b/0:VYZ@2d];@0ZJVY0:BTY02MWId0U9BD09bLW02P
X:00UYJF09BDU02LW9`0UYJF08j>SP2CTi<0UIFE09>CT`2?Shl0SXj>08^;R`2=SHd0SXj>08J6QP23
Ph<0R8R808B4Q01hN7P0PH6107inOP020820P00H0861P@1oOgl0PH6107inOP1jNWX0Ng]k07IfMP21
PH40Ng]k07alO01fMWH0LG5a07inOP1^KVh0LG5a07AdM01aLG40LW9b075aL@1^KVh0MWIf06UYJ@1/
K6`0L71`0P1[Jf/206QXJ00N06][J`1VIVH0Jf][06][J`1]KFd0IVIV06YZJP1VIVH0JFUY06ATI01P
H600HF5Q05mOG`1SHf<0I6AT065QH@1XJ6P0HF5Q06ATI01QHF40IfMW06=SH`1KFe/0GEeM05YJFP1T
I6@0FEUI051@D01KFe/0G5aL5`0000060=WIf@4000000@3IfMT001H0fMWI0P0000040=WIf@1P0>_[
j`1_Kfl0K6a/071`L01^KVh0KFe]06i^KP1bLW80M7Ad079bLP1/K6`0MWIf075aL@1dM7@0L71`06i^
KP1`L700Kfm_06i^KP1]KFd0LG5a07MgM`1^KVh0L71`07=cL`1/K6`0M7Ad07YjNP1fMWH0KVi^07=c
L`1eMGD0Lg=c07MgM`1kNg/0MgMg07IfMP1gMgL0MWIf07YjNP1iNGT0M7Ad07emO@1kNg/0P82007]k
N`1dM7@0P82008>3P`1mOGd0O7al08V9R@26QXH0OWin08Z:RP2;Rh/0SXj>08V9R@1nOWh0PH6108B4
Q02;Rh/0QhN708f=S@29RHT0Shn?08V9R@2ATI40SXj>09>CT`2:RXX0Ti>C09NGU`2KVi/0Ti>C09^K
V`2PX:00WinO09jNWP2TY:@0V9RH09bLW02SXj<0Y:BT0::RXP2OWil0YjNW0:b/[02`/;00YjNW0;:b
/P2^[Zh0/K6a0;2`/02j^[X0[Jf]0P2n_[h03`38b<P0a<C40<c<c038b<P0c/k>0<W9b@3Fe]H0f=SH
0=cLg03Shn<0g]kN0>WYj@3[jn/0l_;b0?Ogm`030?ooo`030?knoP3oool0oooo03d0oooo00X0o_kn
0?Shn03alO40mOGe0>KViP3Ph>00iNGU0=cLg03Ng]h0emOG0P3Bd]820<C4a00B0;no_`2k^k/0`L71
0;bl_02f][H0/K6a0:ZZZP2`/;00/k>c0:FUY@2ZZZX0Xj>S0::RXP2NWYh0VIVI09:BTP2DU9@0VIVI
0P2@T9004P2DU9@0SXj>09VIV@2>SXh0Shn?08Z:RP29RHT0Shn?08F5Q@27QhL0QXJ608f=S@28R8P0
QhN708B4Q01oOgl0Ph>308B4Q080OWin00<0NGUi07emO@1nOWh00P1jNWX01@1hN7P0L71`07QhN01f
MWH0LG5a0080L71`02d0K6a/075aL@1_Kfl0MgMg07IfMP1dM7@0NGUi06i^KP1gMgL0Jf][07=cL`1X
J6P0KFe]06IVIP1ZJVX0Kfm_06MWI`1[Jf/0KFe]06ATI01]KFd0Hf=S06IVIP1YJFT0H61P06ATI01X
J6P0I6AT06IVIP1TI6@0Hf=S06MWI`1XJ6P0Fe]K061PH01XJ6P0EeMG05UIF@1OGel0GUiN06ATI01N
GUh0Fe]K05iNGP1KFe/05`0000050=WIf@8000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3I
fMT06`3QhN40IFEU06ATI01^KVh0IVIV071`L01hN7P0Lg=c06a/K01fMWH0L71`07=cL`1eMGD0LG5a
06a/K01YJFT0KFe]06QXJ01^KVh0K6a/07=cL`1aLG40MgMg075aL@1cLg<0O7al07MgM`0207QhN00T
07MgM`1aLG40NGUi07YjNP1kNg/0MWIf07YjNP1kNg/0MgMg07YjNP1aLG40NGUi07IfMP1iNGT0NWYj
07]kN`1hN7P0P82007emO@1iNGT0Ng]k07inOP1lO7`0MWIf08J6QP23Ph<0RHV908J6QP20P800OGem
08R8R026QXH0Rh^;092@T026QXH0SHf=0P27QhL0102;Rh/0UIFE09BDU02CTi<2096AT@0809jNWP2H
V9P0U9BD09JFUP2MWId0Vi^K09VIV@2QXJ420:2PX00809RHV02SXj<0XZ:R0:>SX`2ZZZX0Y:BT0:b/
[02_[jl20:^[Z`0;0;Jf]P2h^;P0/[:b0;Zj^P2l_;`0_[jn0<71`@38b<P0alO70<W9b@3Cdm<00P3F
e]H02@3Kfm/0g]kN0>3Ph03MgMd0jn_[0?7al@3dm?@0oooo0?_kn`100?ooo`060?_kn`3inOT0n?Sh
0>OWi`3`l?00j^[Z0P3Shn<05@3IfMT0e]KF0=gMg@3:b/X0c<c<0<[:bP33`l<0b/[:0;bl_02g]kL0
`<300;Ng]`2`/;00Zj^[0;bl_02VYZH0ZZZZ0:2PX02RXZ80WYjN0:6QX@0209^KV`08096AT@2@T900
TI6A09ZJVP2;Rh/0T92@09:BTP2<S8`208^;R`0I08n?S`2<S8`0RHV908>3P`2:RXX0QXJ608V9R@28
R8P0Ng]k08B4Q025QHD0NWYj08>3P`1cLg<0O7al07emO@1kNg/0MWIf07]kN`1nOWh0M7Ad07EeM@1d
M7@0L71`07IfMP0207AdM00F071`L01gMgL0M7Ad06i^KP1hN7P0Kfm_06a/K01^KVh0LW9b06QXJ01]
KFd0JFUY06YZJP1VIVH0IFEU06][J`1WIfL0I6AT06IVIP1WIfL0IFEU06MWI`80I6AT0`1VIVH206QX
J00?06=SH`1LG5`0GUiN06IVIP1QHF40H61P05iNGP1TI6@0IVIV065QH@1MGEd0HF5Q06ATI01RHV80
FEUI01L000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI01P0hN7Q06i^
KP1VIVH0Kfm_06QXJ01]KFd0K6a/075aL@1YJFT0KVi^06e]K@1aLG40Kfm_07QhN01^KVh0Lg=c06][
J`1cLg<0K6a/06m_K`1aLG40Lg=c06i^KP1cLg<207IfMP0607MgM`1eMGD0MGEe06][J`1hN7P0LG5a
0P1fMWH08@1cLg<0O7al071`L01lO7`0NWYj07emO@1iNGT0N7Qh07IfMP1eMGD0RXZ:0861P@1fMWH0
OGem0861P@1fMWH0PH610820P01nOWh0QXJ608N7Q`26QXH0Q8B408R8R02@T900RHV908B4Q028R8P0
TI6A08V9R@2<S8`0SXj>08J6QP0209BDU00;09FEU@2ATI40VIVI09VIV@2@T900TI6A09^KV`2GUiL0
X:2P09ZJVP2IVIT00P2LW9`08@2SXj<0W9bL0:6QX@2ZZZX0Y:BT09ZJVP2/[:`0ZJVY0:f][@2XZ:P0
[:b/0:j^[P2f][H0];Bd0;Ng]`36a/H0`l?30<K6aP3@d=00a/K60<O7a`3>c/h0d];B0=gMg@3Ph>00
h^;R0>?Sh`3UiND0kno_0?knoP3clo<0n?Sh0?knoP110?ooo`0X0?clo03clo<0l?3`0>o_k`3Xj>P0
inOW0>7Qh@3MgMd0fMWI0=3@d039bLT0c<c<0<K6aP39bLT0`l?30<71`@30`<00^[Zj0;Vi^@2c/k<0
/;2`0;>c/`2^[Zh0Z:RX0:ZZZP2TY:@0YZJV0::RXP2HV9P0UIFE09RHV02BTY80T92@09VIV@2?Shl0
U9BD08j>SP2<S8`0SXj>092@T080Q8B400@0QXJ608>3P`28R8P0R8R80P21PH401@29RHT0P82007in
OP1mOGd0OWin0080N7Qh00P0Ogmo07QhN01iNGT0LW9b06i^KP1fMWH0Lg=c07emO@80MgMg00D0M7Ad
06i^KP1dM7@0LG5a07EeM@0207IfMP0H075aL@1`L700KVi^075aL@1bLW80IVIV06YZJP1PH600HF5Q
06a/K01[Jf/0I6AT06UYJ@1TI6@0JFUY06ATI01NGUh0JFUY061PH01SHf<0H61P06ATI01VIVH0GUiN
0P1TI6@03@1QHF40IVIV06QXJ01UIFD0F5QH06IVIP1NGUh0FUYJ06EUI@1NGUh0F5QH05]KF`1MGEd0
5`0000060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0303Zj^X0IfMW071`
L01[Jf/0J6QX06IVIP1aLG40KVi^071`L01^KVh0K6a/075aL@80Lg=c0P1`L700201ZJVX0LG5a06a/
K01bLW80KFe]06a/K01bLW80MWIf0P1cLg<01`1fMWH0LW9b075aL@1kNg/0NGUi07AdM01iNGT00P1f
MWH02@1hN7P0MgMg07UiN@1lO7`0Ng]k07UiN@1kNg/0MWIf07QhN00207UiN@0:07inOP1iNGT0Ogmo
07inOP21PH40QHF508B4Q01mOGd0RHV908>3P`80R8R801@0QHF508J6QP2;Rh/0QXJ6096AT@29RHT0
Rh^;08b<S029RHT0RXZ:092@T02FUYH0SXj>08f=S@2JVYX0U9BD09RHV02KVi/0VIVI09bLW080VYZJ
00D0VIVI09fMW@2YZJT0XJ6Q09fMW@020:>SX`0=0:BTY02VYZH0Xj>S0:RXZ02a/K40Zj^[0:f][@33
`l<0^KVi0;Jf]P34a<@0`/;20;jn_P020<W9b@0=0<S8b034a<@0e=CD0=CDe03Lg=`0fMWI0>?Sh`3X
j>P0g]kN0>_[j`3hn?P0oOgm0?7al@100?ooo`80no_k02P0l?3`0>k^kP3[jn/0j>SX0=kNgP3QhN40
fm_K0=OGe`3@d=00bl_;0<C4a036a/H0_kno0<30`035aLD0/[:b0;Ng]`2f][H0/K6a0:^[Z`2XZ:P0
Zj^[0:ZZZP2WYjL0YZJV09nOW`2PX:00VYZJ09RHV02BTY80W9bL08b<S02IVIT0S8b<096AT@2;Rh/0
U9BD092@T027QhL0SHf=0P26QXH02P2;Rh/0QXJ60820P029RHT0QXJ607UiN@1nOWh0P82008N7Q`1i
NGT207IfMP0:0820P01dM7@0Ng]k07MgM`1fMWH0O7al079bLP1/K6`0KVi^071`L080Lg=c02`0JFUY
06i^KP1^KVh0L71`06e]K@1[Jf/0L71`075aL@1/K6`0JVYZ06a/K01SHf<0K6a/06IVIP1XJ6P0Hf=S
06UYJ@1XJ6P0HF5Q06UYJ@1UIFD0HF5Q06IVIP1TI6@0Jf][06ATI01QHF40I6AT06][J`1XJ6P0IVIV
05iNGP1QHF40IFEU06ATI01RHV80Hf=S06ATI01MGEd0H61P05aLG01QHF40EeMG065QHAL000001P3I
fMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0300l?3`06YZJP1YJFT0Kfm_06QX
J01YJFT0Kfm_06UYJ@1bLW80LG5a06QXJ01cLg<0K6a/075aL@1_Kfl0Jf][06i^KP1YJFT0L71`07Ad
M01]KFd0Kfm_07=cL`1^KVh0LG5a07AdM01XJ6P0Lg=c075aL@1kNg/0O7al07IfMP1_Kfl0N7Qh07in
OP1kNg/0MgMg07UiN@1gMgL0M7Ad07]kN`26QXH0Ng]k07QhN01oOgl0O7al07MgM`22PX8207emO@03
07alO01nOWh0OWin0080QXJ600H0O7al08R8R021PH40P8200861P@2;Rh/208b<S00:08N7Q`2@T900
Ti>C08J6QP2@T900U9BD092@T02=SHd0Rh^;08n?S`80UiNG00`0VIVI09NGU`2HV9P0WYjN0:6QX@2N
WYh0W9bL09jNWP2VYZH0X:2P0::RXP2VYZH20:2PX0050:f][@2YZJT0ZZZZ0;:b/P2/[:`00P2c/k<0
4`2i^KT0_;bl0<30`02j^[X0a<C40<O7a`3;bl/0a/K60=?Cd`3Lg=`0d=3@0=WIf@3QhN40hn?S0>KV
iP3Ti>@0k>c/0?7al@3fm_H00P3oool00`3jn_X0oooo0?ooo`0i0?ooo`080?Win@3no_h0jn_[0?Cd
m03[jn/0l?3`0>7Qh@3IfMT20=kNgP0?0=CDe03=cLd0a/K60<K6aP33`l<0a/K60;^k^`2o_kl0^KVi
0;Rh^02c/k<0]KFe0;2`/02][Jd0Y:BT0080ZJVY00H0WinO0:6QX@2HV9P0W9bL09jNWP2DU9@209>C
T`0>096AT@2<S8`0SHf=08b<S02@T900Shn?08V9R@26QXH0Rh^;096AT@2<S8`0RXZ:08b<S023Ph<2
08J6QP0=07emO@21PH40PX:207emO@1iNGT0OWin07QhN01fMWH0OWin07EeM@1aLG40Lg=c071`L002
07IfMP0L079bLP1^KVh0MGEe075aL@1bLW80L71`075aL@1_Kfl0LG5a07AdM01^KVh0J6QX06UYJ@1a
LG40J6QX06ATI01XJ6P0JFUY06=SH`1[Jf/0IFEU06MWI`1[Jf/0IVIV065QH@1NGUh0Hf=S05mOG`80
K6a/00P0IVIV06ATI01XJ6P0H61P06IVIP1LG5`0IfMW061PH080HF5Q00P0GUiN065QH@1PH600GUiN
06=SH`1QHF40EUIF05eMGAL000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0
fMWI01<0kNg]06IVIP1ZJVX0KFe]06i^KP1VIVH0KVi^06IVIP1`L700Jf][071`L01ZJVX0M7Ad06e]
K@1`L700KFe]075aL@1_Kfl0KVi^0080Lg=c00<0MgMg06m_K`1dM7@00P1aLG40301`L700MGEe07=c
L`1kNg/0LG5a07YjNP1iNGT0LG5a071`L01bLW80MWIf07inOP80NGUi00T0Ng]k07inOP1nOWh0O7al
07moO`1jNWX0PH6107UiN@1kNg/00P1nOWh02P26QXH0Ph>308F5Q@26QXH0P82008F5Q@24Q8@0Rh^;
08B4Q029RHT208j>SP0f08b<S029RHT0R8R80861P@2FUYH0SHf=092@T02=SHd0T92@096AT@2DU9@0
VIVI09^KV`2IVIT0TY:B09nOW`2KVi/0X:2P09VIV@2PX:00Z:RX09bLW02KVi/0XJ6Q09nOW`2YZJT0
Z:RX0;2`/02YZJT0/K6a0;2`/02n_[h0^;Rh0;Jf]P2m_Kd0a/K60;Rh^037alL0`l?30<W9b@3<c<`0
dm?C0=;BdP3?cll0f=SH0=WIf@3AdM40i^KV0>_[j`3^k^h0o?cl0>g]k@3kno/0lO7a>`3oool0203k
no/0nOWi0?KfmP3alO40jn_[0>c/k03Ti>@0j^[Z0P3De=@03@3Fe]H0g=cL0=SHf03<c<`0c/k>0<30
`02m_Kd0][Jf0;Vi^@2e]KD0];Bd0;Fe]@2a/K400P2YZJT0502SXj<0Z:RX0:NWY`2RXZ80W9bL09JF
UP2NWYh0UiNG09RHV02JVYX0Ti>C096AT@2>SXh0SHf=08R8R029RHT0Rh^;096AT@2>SXh0Q8B40P23
Ph<0402<S8`0R8R808:2PP1hN7P0Ph>308R8R01kNg/0PH610820P01kNg/0P82007UiN@1kNg/0O7al
07EeM@1fMWH207UiN@0706a/K01cLg<0N7Qh07AdM01eMGD0Lg=c071`L00206a/K00306QXJ01VIVH0
KVi^0080LG5a0P1[Jf/0301PH600I6AT06EUI@1XJ6P0Hf=S06e]K@1RHV80HF5Q06=SH`1VIVH0H61P
06UYJ@80H61P00`0IVIV069RHP1UIFD0Jf][065QH@1SHf<0H61P06IVIP1NGUh0IFEU06IVIP1JFUX2
06=SH`06061PH01SHf<0H61P05QHF01KFe/0Hf=S5`0000060=WIf@4000000@3IfMT001H0fMWI00<0
00000=WIf@3IfMT00`3IfMT01`3^k^h0Kfm_06i^KP1[Jf/0JFUY06a/K01cLg<0101^KVh0201]KFd0
Jf][06][J`1aLG40IfMW07=cL`1`L700MgMg0P1`L7002P1/K6`0JFUY07QhN01eMGD0MWIf075aL@1d
M7@0NGUi07IfMP1]KFd4075aL@0E07IfMP1dM7@0LG5a07QhN01iNGT0P82007emO@1jNWX0NGUi07Yj
NP20P800NWYj07inOP1cLg<0O7al08F5Q@1kNg/0PX:207]kN`21PH40R8R80080Ph>30140Q8B408R8
R02<S8`0SHf=08V9R@2<S8`0R8R808j>SP2;Rh/0SXj>096AT@2FUYH0Rh^;096AT@2>SXh0WYjN09JF
UP0209RHV00H09jNWP2OWil0WYjN092@T02NWYh0U9BD0:>SX`2QXJ40YZJV09bLW02OWil0Z:RX0:BT
Y02[Zj/0ZJVY0:^[Z`2h^;P0/k>c0;6a/@2h^;P0/k>c0;Zj^P33`l<0_[jn0P36a/H20<W9b@060<o?
c`3Cdm<0dm?C0=;BdP3Shn<0inOW0P3Ti>@0103/k>`0j^[Z0?Cdm03hn?P20?clo3X0oooo00T0lo?c
0?Win@3Zj^X0jn_[0>WYj@3Ti>@0hn?S0=kNgP3Lg=`00P3AdM404`3<c<`0b<S80<o?c`36a/H0`<30
0;fm_@2h^;P0_;bl0;Bd]02e]KD0[Jf]0;6a/@2_[jl0ZZZZ0:BTY02XZ:P0YJFU09fMW@2OWil00P2K
Vi/0:`2DU9@0TY:B09NGU`2>SXh0Shn?08j>SP2@T900R8R808n?S`2ATI40RHV908Z:RP23Ph<0PH61
08>3P`24Q8@0Ph>308B4Q028R8P0Ph>30820P01nOWh0QXJ607inOP20P800Ogmo07YjNP21PH40O7al
07]kN`1fMWH0NGUi07AdM01eMGD0M7Ad06m_K`1YJFT0KVi^06a/K01YJFT0K6a/07QhN01aLG400`1[
Jf/0301ZJVX0LG5a06][J`1[Jf/0H61P065QH@1/K6`0IVIV06ATI01YJFT0F5QH06ATI0<0IVIV01D0
Hf=S06i^KP1VIVH0HV9R06ATI01VIVH0G5aL06MWI`1QHF40GEeM065QH@1PH600I6AT06UYJ@1QHF40
I6AT06=SH`1GEeL0I6AT05YJFP1PH6005`0000060=WIf@4000000@3IfMT001H0fMWI00<000000=WI
f@3IfMT00`3IfMT04@3Shn<0Jf][06=SH`1VIVH0LG5a06a/K01YJFT0IFEU06][J`1aLG40KVi^06UY
J@1/K6`0KVi^07AdM01_Kfl0M7Ad0080JVYZ00@0LG5a07AdM01bLW80NWYj0P1^KVh00`1`L700LG5a
07emO@0207=cL`0C07MgM`1eMGD0NGUi07]kN`1fMWH0M7Ad07YjNP1dM7@0OWin07UiN@1kNg/0MWIf
07AdM01oOgl0OWin07emO@1iNGT0PH610820P00207alO00807UiN@20P800P82007]kN`1mOGd0Ph>3
07alO028R8P20861P@0i08>3P`27QhL0TY:B08^;R`23Ph<0TI6A08b<S02?Shl0TY:B08j>SP2GUiL0
TI6A09FEU@2BTY80Vi^K096AT@2JVYX0SXj>09JFUP2LW9`0XJ6Q09VIV@2QXJ40WYjN0:BTY02QXJ40
WIfM0:RXZ02a/K40[jn_0:RXZ02^[Zh0/;2`0:^[Z`2`/;00/[:b0;no_`2i^KT0]kNg0<71`@2i^KT0
aLG50<C4a039bLT0d=3@0=KFeP3=cLd0c<c<0=_Kf`3Lg=`0gmoO0>WYj@3Zj^X0i>CT0>_[j`3alO40
k^k^03P0oooo00T0o?cl0?ooo`3fm_H0jn_[0>k^kP3clo<0hN7Q0=oOg`3QhN400`3Hf=P0303AdM40
d];B0<_;b`3:b/X0`L710<O7a`2i^KT0_[jn0;Vi^@2c/k<0]KFe0;:b/P80[Zj^00l0Zj^[0;Bd]02W
YjL0XZ:R0:6QX@2NWYh0VIVI09ZJVP2LW9`0TI6A092@T02<S8`0T92@09>CT`27QhL00P2<S8`02`2A
TI40Rh^;09BDU024Q8@0RXZ:08J6QP23Ph<0PX:20861P@1lO7`0PH610080P82000d0NGUi08:2PP1n
OWh0Ogmo07IfMP1eMGD0MWIf07YjNP1`L700Lg=c07IfMP1eMGD0M7Ad0080LG5a0180L71`06i^KP1Y
JFT0L71`06UYJ@1RHV80JFUY06i^KP1`L700KVi^06][J`1^KVh0JFUY06m_K`1WIfL0I6AT06IVIP1O
Gel2065QH@0406QXJ01SHf<0HF5Q06IVIP<0I6AT00`0JFUY065QH@1PH600Hf=S06UYJ@1HF5P0H61P
06=SH`1LG5`0I6AT06UYJ@1KFe/2065QH@80H61P00<0Fe]K061PH01IFET05`0000060=WIf@400000
0@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0203Shn<0KFe]06=SH`1ZJVX0Kfm_06UYJ@1Z
JVX0JFUY0P1/K6`0301]KFd0J6QX06m_K`1bLW80M7Ad07=cL`1_Kfl0KFe]06i^KP1aLG40L71`06m_
K`80MGEe00X0L71`06m_K`1^KVh0Kfm_075aL@1fMWH0Jf][07=cL`1`L700Lg=c0P1hN7P207YjNP04
07MgM`1iNGT0Q8B407IfMP80MgMg01D0N7Qh07inOP22PX80N7Qh07alO029RHT0NGUi08B4Q01kNg/0
Ph>30861P@24Q8@0PH6108J6QP24Q8@0Rh^;08n?S`2;Rh/0R8R808b<S026QXH00P28R8P0802<S8`0
Rh^;09BDU02ATI40UiNG09>CT`2DU9@0T92@0?ooo`2PX:00TI6A0::RXP2LW9`0VIVI09JFUP2LW9`0
WYjN0:JVYP2OWil0VIVI0:JVYP2UYJD0Xj>S0:FUY@2PX:00[Zj^0:ZZZP2c/k<0^;Rh0;Jf]P2a/K40
]KFe0P2n_[h05@31`L40a<C40<O7a`3>c/h0c<c<0<K6aP3AdM40bl_;0=cLg03Fe]H0i^KV0=_Kf`3Q
hN40i^KV0?3`l03Xj>P0kNg]0?;blP3oool0o_kn0?Win@0b0?ooo`090?_kn`3lo?`0n?Sh0?[jnP3a
lO40k>c/0>o_k`3Zj^X0iNGU0080gMgM00T0f=SH0=WIf@3AdM40dM7A0<W9b@37alL0`l?30<o?c`2i
^KT00P2d];@06`2b/[80/k>c0;2`/02XZ:P0/;2`0:VYZ@2ZZZX0Z:RX0:ZZZP2SXj<0Vi^K09VIV@2R
XZ80UiNG09bLW02;Rh/0SHf=08^;R`2CTi<0TY:B096AT@2>SXh0Ti>C08^;R`2<S8`0PH6108J6QP02
08B4Q00708N7Q`25QHD0OWin07inOP26QXH0QHF507inOP020861P@0=07alO01mOGd0O7al079bLP1i
NGT0M7Ad07IfMP1cLg<0LG5a07QhN01YJFT0K6a/06m_K`0207EeM@0I06e]K@1/K6`0K6a/06YZJP1/
K6`0L71`06m_K`1YJFT0JVYZ06IVIP1[Jf/0MWIf06IVIP1ZJVX0IfMW06a/K01^KVh0J6QX06UYJ@1V
IVH0J6QX06ATI01UIFD0GUiN069RHP0205iNGP0A06MWI`1YJFT0H61P06MWI`1SHf<0HV9R06ATI01R
HV80GemO05]KF`1NGUh0Hf=S05iNGP1MGEd0HV9R05YJFP1HF5P05`0000060=WIf@4000000@3IfMT0
01H0fMWI00<000000=WIf@3IfMT00`3IfMT01`3Xj>P0Jf][075aL@1ZJVX0KVi^06MWI`1aLG400P1^
KVh06@1/K6`0Jf][06UYJ@1bLW80KVi^071`L01cLg<0L71`07MgM`1aLG40L71`06a/K01iNGT0LG5a
07QhN01fMWH0M7Ad079bLP1aLG40M7Ad07YjNP1iNGT0L71`07AdM01fMWH00P1cLg<0401eMGD0Kfm_
07]kN`1dM7@0MWIf07QhN01iNGT0N7Qh07UiN@1lO7`0Ng]k07inOP1iNGT0O7al08>3P`1oOgl207]k
N`0W07alO01nOWh0PX:20861P@22PX80P82008V9R@23Ph<0RXZ:08b<S02;Rh/0SXj>09>CT`29RHT0
S8b<09JFUP2ATI40Vi^K08n?S`2GUiL0Rh^;096AT@2CTi<0UYJF092@T02EUID0WIfM09ZJVP2HV9P0
WYjN09nOW`2HV9P0X:2P0:FUY@2TY:@0XJ6Q0:RXZ02VYZH0[:b/0080/[:b00l0/k>c0;Jf]P2d];@0
^;Rh0;Ng]`2i^KT0`<300;Rh^02j^[X0_;bl0<k>cP34a<@0c/k>0=3@d03Kfm/00P3IfMT02`3Ti>@0
gmoO0>GUi@3UiND0j>SX0>c/k03YjNT0lO7a0?Cdm03no_h0o?cl0340oooo00D0moOg0?Win@3_knl0
l?3`0>g]k@020>CTi00A0=SHf03Ti>@0fm_K0=[JfP3Hf=P0dm?C0<S8b039bLT0aLG50<?3``34a<@0
`l?30<30`02h^;P0/k>c0;Bd]02b/[800P2_[jl20:RXZ00O0:BTY02UYJD0YjNW0:JVYP2OWil0TI6A
09BDU02;Rh/0Ti>C09JFUP2ATI40UIFE09>CT`2@T900RHV908F5Q@29RHT0S8b<08V9R@2;Rh/0R8R8
08J6QP27QhL0R8R808>3P`22PX80OWin08>3P`20P800PH6107emO@0207QhN00?0820P01fMWH0NGUi
075aL@1lO7`0MWIf075aL@1fMWH0Jf][07AdM01_Kfl0M7Ad075aL@1ZJVX0IVIV0080Jf][00`0J6QX
06][J`1cLg<0KVi^07=cL`1`L700JFUY06m_K`1[Jf/0L71`06QXJ01YJFT206QXJ006065QH@1^KVh0
Kfm_06EUI@1TI6@0Jf][0P1WIfL04@1TI6@0Hf=S05iNGP1VIVH0J6QX069RHP1TI6@0IFEU05mOG`1P
H600GemO065QH@1NGUh0IVIV05aLG01TI6@0GEeM0080GUiN5`0000060=WIf@4000000@3IfMT001H0
fMWI00<000000=WIf@3IfMT00`3IfMT01@3bl_80Jf][06e]K@1UIFD0J6QX0080IfMW01D0JFUY075a
L@1]KFd0KFe]07=cL`1VIVH0KVi^06][J`1^KVh0L71`07=cL`1`L700Lg=c06m_K`1aLG40N7Qh07=c
L`1`L700NGUi075aL@1cLg<00P1fMWH02@1bLW80O7al079bLP1mOGd0M7Ad07IfMP1jNWX0M7Ad07Mg
M`0207alO00307AdM01cLg<0NGUi0080N7Qh0100P82008:2PP1mOGd0Ng]k07moO`23Ph<0O7al08V9
R@26QXH0QhN708^;R`1lO7`0P82008>3P`26QXH0S8b<0P26QXH05@2:RXX0T92@08^;R`2ATI40RXZ:
09BDU02?Shl0RHV909^KV`2CTi<0TI6A09RHV02@T900W9bL09:BTP2LW9`0Vi^K09VIV@2HV9P0VIVI
09bLW0020:BTY0030:6QX@2SXj<0Z:RX0080ZJVY0200YjNW0:^[Z`2/[:`0/;2`0:n_[`2c/k<0^k^k
0;Bd]02i^KT0^;Rh0;bl_034a<@0`L710<_;b`38b<P0c<c<0<_;b`3@d=00fMWI0=cLg03Ph>00g=cL
0=kNgP3Vi^H0jNWY0>KViP3`l?00nOWi0?3`l03emOD0oooo0?Ogmb`0oooo0100o_kn0?ooo`3oool0
m?Cd0?_kn`3[jn/0lO7a0?Gem@3UiND0l?3`0=kNgP3Kfm/0g=cL0=CDe03AdM40clo?0P36a/H06035
aLD0b<S80<30`02m_Kd0aLG50;Ng]`2j^[X0^KVi0;bl_02e]KD0][Jf0:j^[P2YZJT0YZJV0:>SX`2L
W9`0WYjN0:2PX02KVi/0Ti>C09JFUP2GUiL0V9RH09:BTP80T92@00d0R8R8092@T02ATI40RXZ:08J6
QP29RHT0Q8B408f=S@23Ph<0PH6108>3P`1iNGT0QXJ60080O7al01/0Ogmo07YjNP1oOgl0Q8B407al
O01iNGT0MWIf07UiN@1cLg<0MWIf07AdM01gMgL0LW9b07IfMP1dM7@0KVi^07=cL`1ZJVX0LG5a071`
L01fMWH0M7Ad06QXJ01_Kfl0K6a/06i^KP1[Jf/00P1XJ6P05`1`L700JVYZ06YZJP1UIFD0Jf][06i^
KP1[Jf/0I6AT06EUI@1[Jf/0Hf=S065QH@1UIFD0IfMW069RHP1SHf<0JFUY06ATI01ZJVX0IVIV061P
H01MGEd0G5aL00<0HF5Q00<0F5QH06IVIP1DE5@00P1TI6@0101HF5P0G5aL05]KF`1SHf<G000000H0
fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@040>?Sh`1^KVh0JFUY06e]K@80
L71`00`0JFUY06][J`1cLg<0IVIV07IfMP1aLG40Kfm_071`L01^KVh0LG5a06m_K`1]KFd206i^KP1O
06UYJ@1gMgL0Kfm_07=cL`1kNg/0Lg=c07QhN01]KFd0MgMg07EeM@1aLG40Lg=c06i^KP1`L700NGUi
0861P@1hN7P0Lg=c07IfMP1cLg<0M7Ad07MgM`1nOWh0O7al07inOP1hN7P0Ng]k07YjNP25QHD0NWYj
07alO01kNg/0QHF508J6QP29RHT0Q8B40861P@29RHT0QhN708R8R02:RXX0RHV908R8R02CTi<0RHV9
08b<S024Q8@0Shn?08R8R02<S8`0SXj>08f=S@2<S8`0T92@09VIV@2DU9@0Ti>C09BDU02KVi/0VIVI
09JFUP2NWYh0Xj>S0:BTY02PX:00V9RH09nOW`2QXJ40ZJVY0:JVYP2ZZZX0YJFU0:n_[`2a/K40Z:RX
0:j^[P2c/k<0_[jn0;Jf]P2c/k<0^KVi0;^k^`2j^[X0_;bl0;jn_P3:b/X0d=3@0<c<c03=cLd0dM7A
0=SHf03Fe]H0dm?C0>7Qh@3Ph>000P3]kNd0203`l?00kNg]0?[jnP3oool0n_[j0?KfmP3no_h0n_[j
;P3oool02`3dm?@0lO7a0?7al@3YjNT0jn_[0>KViP3Ng]h0hn?S0=SHf03Cdm<0f=SH0080dm?C01P0
c<c<0<o?c`3;bl/0`L710<K6aP2m_Kd0^[Zj0;Vi^@2l_;`0ZZZZ0:n_[`2[Zj/0]KFe0:BTY02][Jd0
ZJVY09bLW02JVYX0Zj^[09jNWP2LW9`0WYjN09VIV@2HV9P209>CT`0B08f=S@2DU9@0Rh^;092@T029
RHT0SHf=08V9R@21PH40Q8B408N7Q`28R8P0PH6108J6QP22PX80Rh^;0820P021PH40Ng]k0P1nOWh0
1`1lO7`0Ng]k07UiN@1fMWH0NWYj07QhN01iNGT00P1kNg/07P1fMWH0LG5a06QXJ01^KVh0L71`06YZ
JP1cLg<0L71`06QXJ01`L700LG5a07=cL`1VIVH0LG5a06YZJP1/K6`0KVi^06YZJP1`L700IVIV05iN
GP1^KVh0JFUY065QH@1VIVH0JFUY05mOG`1TI6@0JFUY05aLG080I6AT01@0IFEU065QH@1XJ6P0J6QX
05mOG`1QHF40H61P06ATI01XJ6P0Hf=S065QH@1TI6@0HF5Q05YJFP1PH600HF5Q05eMG@1PH600GEeM
061PH1L000001P3IfMT100000040fMWI000F0=WIf@800000103IfMT0303^k^h0I6AT06IVIP1YJFT0
Kfm_06MWI`1XJ6P0IVIV075aL@1jNWX0L71`06QXJ080L71`01H0Lg=c06][J`1XJ6P0KVi^079bLP1[
Jf/0IVIV06][J`1`L700MgMg071`L01cLg<0K6a/07=cL`1[Jf/0LG5a07alO01cLg<0MWIf07YjNP1b
LW80M7Ad0P1iNGT05P1eMGD0MWIf07emO@1nOWh0NWYj07]kN`1gMgL0N7Qh07IfMP1dM7@0Ng]k07Qh
N01lO7`0Q8B408F5Q@22PX80OWin0861P@1nOWh0PX:208^;R`25QHD208V9R@0@08J6QP2<S8`0PX:2
092@T02=SHd0Q8B408V9R@2<S8`0TI6A08J6QP2?Shl0QHF509JFUP2EUID0TI6A09>CT`80W9bL01H0
WYjN09ZJVP2DU9@0WIfM09nOW`2KVi/0V9RH09jNWP2KVi/0YZJV0:n_[`2XZ:P0YJFU0:ZZZP2YZJT0
[jn_0;2`/02a/K40[Jf]0;Fe]@2i^KT0_;bl0P31`L401036a/H0`l?30<W9b@36a/H20<_;b`080=;B
dP3<c<`0f=SH0=cLg03QhN40g=cL0>GUi@3Ti>@20>k^kP070>OWi`3`l?00l_;b0>;RhP3clo<0o?cl
0?knoP0Y0?ooo`030?[jnP3^k^h0oooo0080l?3`01T0kNg]0>[ZjP3Jf]X0g=cL0=gMg@3Fe]H0c<c<
0=CDe038b<P0c<c<0<k>cP37alL0_[jn0<71`@2k^k/0^KVi0;Zj^P2e]KD0^;Rh0;Jf]P2e]KD0];Bd
0:RXZ02[Zj/0[jn_0080Xj>S01l0W9bL0:>SX`2KVi/0W9bL09NGU`2IVIT0UYJF09BDU02?Shl0SXj>
09JFUP2?Shl0Rh^;08J6QP2?Shl0Ph>308R8R029RHT0R8R808B4Q028R8P0Ph>307moO`26QXH0NGUi
07YjNP1mOGd0OWin07emO@1kNg/0MgMg0080P8200`1hN7P01P1bLW80MWIf079bLP1jNWX0LW9b06a/
K080KVi^00X0JFUY06a/K01dM7@0KFe]06IVIP1XJ6P0KVi^06QXJ01UIFD0JFUY0P1[Jf/00`1SHf<0
IfMW06a/K00206QXJ00906IVIP1TI6@0J6QX06a/K01PH600J6QX06=SH`1UIFD0H61P0080HF5Q01<0
I6AT06=SH`1VIVH0J6QX05aLG01TI6@0H61P05YJFP1MGEd0HF5Q06=SH`1PH600I6AT06=SH`1LG5`0
Fe]K05mOG`1FEUH0GUiN01L000001@3IfMT200000040fMWI000F0=WIf@030000003IfMT0fMWI00<0
fMWI00X0kno_06][J`1YJFT0KFe]06i^KP1VIVH0JFUY06ATI01XJ6P0L71`0P1^KVh206e]K@0806i^
KP1]KFd0LG5a07=cL`1dM7@0Lg=c05mOG`1[Jf/207=cL`0807EeM@1cLg<0L71`079bLP1dM7@0LG5a
07IfMP1gMgL207=cL`0407MgM`1eMGD0MgMg07QhN080MWIf00@0MgMg07AdM01hN7P0M7Ad0P1fMWH0
1P1kNg/0M7Ad07MgM`1oOgl0Ng]k07YjNP<0PH6102L0QHF508J6QP29RHT0QHF508f=S@26QXH0R8R8
08f=S@27QhL0Rh^;08F5Q@28R8P0RHV908f=S@28R8P0QHF508R8R02@T900Rh^;08b<S02DU9@0TI6A
09BDU02JVYX0UYJF09^KV`2IVIT0WinO09RHV02NWYh0X:2P0:>SX`2JVYX0Vi^K09RHV02SXj<0X:2P
0:BTY02a/K400P2`/;006P2[Zj/0];Bd0;Jf]P2g]kL0/k>c0;Ng]`3:b/X0`/;20<71`@33`l<0b<S8
0:^[Z`3AdM40bLW90<k>cP3Lg=`0emOG0=kNgP3Kfm/0hN7Q0>CTi03Shn<0k>c/0>SXj03Shn<0k^k^
0P3dm?@01@3alO40n?Sh0?ooo`3kno/0oOgm02@0oooo00<0o_kn0?ooo`3alO400P3`l?007`3Xj>P0
j^[Z0>_[j`3YjNT0fMWI0=[JfP3Lg=`0e]KF0=WIf@3De=@0e]KF0<W9b@3:b/X0bl_;0<c<c03>c/h0
_[jn0;bl_02i^KT0][Jf0<71`@2d];@0/;2`0:j^[P2][Jd0Xj>S0:FUY@2WYjL0Z:RX0:JVYP2HV9P0
0P2MWId01`2NWYh0V9RH096AT@2HV9P0UYJF092@T02EUID00P2@T90208b<S00308^;R`2:RXX0T92@
0080Q8B40100PX:20861P@1mOGd0PH6107]kN`26QXH0PX:207alO01kNg/0N7Qh07inOP1gMgL0NGUi
07IfMP1lO7`0Lg=c0P1kNg/01P1_Kfl0M7Ad06e]K@1YJFT0J6QX065QH@<0L71`01D0M7Ad06QXJ01]
KFd0I6AT06QXJ01VIVH0IfMW06e]K@1/K6`0IVIV06i^KP1VIVH0KVi^06][J`1XJ6P0Hf=S069RHP1Q
HF40IVIV05aLG01SHf<00P1UIFD0101YJFT0J6QX065QH@1VIVH2069RHP0806UYJ@1QHF40GUiN05aL
G01RHV80GemO05YJFP1TI6@206=SH`0605]KF`1NGUh0G5aL05iNGP1PH600EUIF5`0000060=WIf@40
00000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT00`3QhN40J6QX06][J`0206UYJ@80K6a/
01D0J6QX06i^KP1[Jf/0KVi^06=SH`1[Jf/0MGEe06QXJ01dM7@0LG5a06i^KP1`L700KVi^06YZJP1V
IVH0K6a/07=cL`1^KVh0M7Ad06a/K01fMWH00P1dM7@0601bLW80LG5a07QhN01lO7`0NGUi07IfMP1k
Ng/0O7al07QhN01lO7`0MWIf07QhN01iNGT0PH6107inOP1iNGT0Lg=c07QhN020P800O7al07inOP1g
MgL0OGem08:2PP80Ng]k00/0OWin08>3P`21PH40OGem08V9R@2:RXX0Rh^;08B4Q028R8P0Rh^;08B4
Q00208b<S00Q09:BTP2ATI40T92@08Z:RP2>SXh0TI6A09RHV02@T900UYJF09NGU`2MWId0W9bL09NG
U`2MWId0WYjN09fMW@2QXJ40UIFE0:FUY@2LW9`0XJ6Q0:>SX`2PX:00Y:BT0;6a/@2f][H0/;2`0:j^
[P2/[:`0]kNg0:n_[`2m_Kd0^[Zj0080^KVi01<0^[Zj0<71`@38b<P0`L710<W9b@3>c/h0a/K60<k>
cP3Hf=P0dm?C0=OGe`3MgMd0fm_K0>3Ph03Lg=`0iNGU0>?Sh`3YjNT0iNGU0080lo?c00<0m_Kf0?Cd
m03kno/00P3inOTS0?ooo`080?knoP3^k^h0n?Sh0?Gem@3/k>`0lO7a0>GUi@3/k>`20>3Ph00?0=_K
f`3Fe]H0emOG0=CDe03<c<`0a<C40<c<c038b<P0bLW90<O7a`30`<00aLG50;jn_P31`L40a<C40080
];Bd0240]KFe0;2`/02VYZH0Zj^[0:BTY02OWil0Y:BT0:>SX`2TY:@0VIVI0:6QX@2GUiL0VIVI09JF
UP2LW9`0VIVI09>CT`2=SHd0QhN708V9R@25QHD0SXj>08^;R`2<S8`0Q8B408J6QP24Q8@0Ph>308B4
Q01lO7`0QhN70820P01hN7P00P1iNGT02021PH40NGUi07alO01hN7P0MWIf07inOP1lO7`0MgMg0P1f
MWH01@1iNGT0N7Qh071`L01cLg<0K6a/0080J6QX0P1/K6`0401XJ6P0K6a/06][J`1XJ6P0Hf=S06][
J`1XJ6P0Hf=S06UYJ@1[Jf/0L71`06QXJ01^KVh0KFe]06IVIP1UIFD2065QH@80I6AT00X0Hf=S061P
H01VIVH0Jf][06UYJ@1QHF40Jf][065QH@1LG5`0IVIV0P1QHF403@1OGel0GEeM069RHP1NGUh0Fe]K
06ATI01OGel0H61P05eMG@1LG5`0H61P05=CD`1HF5P05`0000060=WIf@4000000@3IfMT001H0fMWI
00<000000=WIf@3IfMT00`3IfMT01P3Ti>@0IVIV071`L01[Jf/0Kfm_06ATI080JFUY0P1[Jf/0>01b
LW80IfMW071`L01]KFd0KVi^07EeM@1aLG40N7Qh07=cL`1eMGD0JFUY06i^KP1gMgL0LW9b07AdM01a
LG40Lg=c07]kN`1aLG40LW9b07UiN@1fMWH0LW9b07=cL`1hN7P0NGUi07QhN01eMGD0MWIf07MgM`1h
N7P0NGUi07MgM`1hN7P0NGUi08>3P`1hN7P0OWin07AdM021PH40N7Qh08:2PP21PH40PX:207IfMP21
PH40OGem08>3P`28R8P0PH6108B4Q027QhL0Q8B407inOP25QHD0Rh^;0P2:RXX01@2DU9@0Ti>C08b<
S02>SXh0V9RH0080T92@00L0Ti>C08b<S02ATI40Ti>C09^KV`2LW9`0Ti>C0080UYJF00`0V9RH0:2P
X02PX:00Vi^K09bLW02YZJT0YZJV0:>SX`2TY:@0Xj>S0;6a/@2/[:`20:j^[P0R0;Rh^02c/k<0/K6a
0:n_[`2g]kL0^;Rh0;:b/P2o_kl0_[jn0<71`@3:b/X0a<C40<S8b03@d=00dM7A0=[JfP3Ph>00fMWI
0>CTi03Ph>00g]kN0>CTi03Rh^80gMgM0>o_k`3Xj>P0iNGU0?Win@3YjNT0n?Sh0?Cdm03hn?P0oooo
0?knoQ`0oooo00T0o_kn0?ooo`3oool0oooo0?KfmP3alO40m_Kf0>c/k03YjNT00P3/k>`03`3Kfm/0
g=cL0=3@d03IfMT0dm?C0=kNgP3Fe]H0d=3@0=CDe03@d=00b/[:0<S8b039bLT0`<300<?3``020;fm
_@080;:b/P2j^[X0^k^k0:j^[P2c/k<0[Zj^0;:b/P2SXj<20:BTY00;0:6QX@2MWId0XJ6Q0:FUY@2T
Y:@0VYZJ09RHV02CTi<0UYJF09RHV02@T9000P2>SXh208b<S00;08F5Q@26QXH0Rh^;08V9R@2>SXh0
R8R808F5Q@24Q8@0OWin07emO@1iNGT00P20P800301mOGd0Ogmo0820P023Ph<0Ng]k07QhN01lO7`0
Lg=c07UiN@1dM7@0MgMg07AdM080N7Qh00`0L71`06YZJP1XJ6P0JVYZ06EUI@1`L700J6QX06MWI`1Q
HF40JFUY06EUI@1/K6`206i^KP0D06IVIP1/K6`0KVi^06UYJ@1VIVH0J6QX06MWI`1[Jf/0J6QX06YZ
JP1QHF40J6QX069RHP1TI6@0Hf=S065QH@1PH600JVYZ06=SH`1UIFD206IVIP80HV9R00T0H61P05iN
GP1QHF40HF5Q069RHP1TI6@0HV9R065QH@1LG5`00P1KFe/00`1JFUX0Fe]K0000000F000000H0fMWI
0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@090>GUi@1TI6@0J6QX06e]K@1aLG40
JFUY06m_K`1aLG40Hf=S0080IVIV00T0K6a/06][J`1YJFT0JFUY07=cL`1[Jf/0K6a/07MgM`1bLW80
0P1_Kfl0101`L700LG5a06a/K01eMGD2075aL@0:06i^KP1hN7P0Kfm_06a/K01dM7@0Ng]k0820P01]
KFd0Ng]k06e]K@80NGUi00d0MgMg07]kN`1fMWH0MWIf07alO01kNg/0O7al07UiN@1lO7`0OGem07Qh
N01iNGT0MWIf0080O7al00<0PH6107alO020P8000`23Ph<09@25QHD0PH6108N7Q`25QHD0QXJ608R8
R02;Rh/0Ti>C08b<S02BTY80RHV9096AT@29RHT0Ti>C08b<S02CTi<0Shn?08^;R`2FUYH0UiNG09RH
V02FUYH0Ti>C09:BTP2IVIT0YZJV09jNWP2OWil0Y:BT0:JVYP2XZ:P0YjNW0:>SX`2QXJ40Xj>S0:RX
Z02/[:`00P2[Zj/07@2a/K40/;2`0;Ng]`2b/[80][Jf0<G5a@34a<@0c<c<0<W9b@36a/H0c<c<0<k>
cP3<c<`0b<S80<c<c03De=@0emOG0=WIf@3Kfm/0g=cL0>7Qh@3Ti>@0jNWY0?3`l03Vi^H0i>CT0>?S
h`3^k^h0lO7a0080m?Cd0P3oool0103no_h0oooo0?Win@3no_hG0?ooo`0A0?knoP3clo<0m?Cd0?Kf
mP3gmoL0jn_[0>k^kP3[jn/0iNGU0>_[j`3Ogml0g=cL0=KFeP3Hf=P0fMWI0=KFeP3>c/h00P3AdM40
2P38b<P0bLW90<W9b@34a<@0b<S80<[:bP2j^[X0^;Rh0;Zj^P2g]kL20;Jf]P0E0;Bd]02_[jl0YjNW
0:b/[02XZ:P0Xj>S0:6QX@2[Zj/0WinO0:>SX`2LW9`0UiNG09fMW@2FUYH0W9bL096AT@2DU9@0UIFE
08j>SP2ATI40Shn?0080S8b<00H0QXJ609BDU023Ph<0PH6107moO`1kNg/208>3P`0B07QhN024Q8@0
QXJ607]kN`20P800QXJ607inOP1iNGT0OGem07UiN@1hN7P0NGUi07QhN01eMGD0Lg=c07MgM`1eMGD0
N7Qh0P1bLW803`1YJFT0KVi^06MWI`1YJFT0IfMW06a/K01XJ6P0KVi^06EUI@1TI6@0JFUY071`L01W
IfL0Jf][061PH00306QXJ00O06][J`1TI6@0KVi^06QXJ01PH600Hf=S069RHP1SHf<0HF5Q06ATI01I
FET0FUYJ06ATI01QHF40H61P06=SH`1NGUh0FEUI06IVIP1SHf<0GUiN065QH@1MGEd0GemO061PH01L
G5`0GUiN05YJFP1KFe/0H61P05eMG@0G000000H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI
0=WIf@030=WIf@0E0>_[j`1WIfL0Jf][06IVIP1`L700Jf][07AdM01/K6`0Hf=S06m_K`1[Jf/0KVi^
06EUI@1/K6`0L71`07AdM01`L700Kfm_07=cL`1/K6`0L71`0080M7Ad0100KVi^07=cL`1YJFT0K6a/
075aL@1hN7P0MgMg071`L01/K6`0MWIf071`L01hN7P0LG5a079bLP1fMWH0MgMg0P1iNGT0101lO7`0
NGUi07=cL`1lO7`207moO`0408B4Q01hN7P0PH6107]kN`80O7al00/0PX:207moO`1kNg/0PH6107Ui
N@1jNWX0Rh^;06IVIP24Q8@0QXJ608>3P`0208^;R`<0QhN700/0TI6A08^;R`25QHD0S8b<08R8R02;
Rh/0S8b<08n?S`2DU9@0X:2P09BDU002096AT@0:09ZJVP2LW9`0UIFE0:>SX`2RXZ80Y:BT09nOW`2T
Y:@0Z:RX0:FUY@80YZJV00H0Y:BT0;Ng]`2YZJT0[:b/0;6a/@2^[Zh20;2`/00@0:RXZ02h^;P0];Bd
0<C4a02n_[h0a/K60<?3``32`/80a<C40<71`@3;bl/0`<300<C4a03=cLd0c<c<0=CDe080fMWI00`0
j>SX0=[JfP3Rh^80i>CT0>g]k@3Shn<0iNGU0>SXj03`l?00jn_[0??cl`3fm_H20?_kn`030?knoP3o
ool0oooo00@0oooo00<0nOWi0?ooo`3oool00P3oool01`3inOT0oooo0?ooo`3oool0o_kn0?_kn`3e
mOD00`3oool0103^k^h0nOWi0?KfmP3no_h20?clo0060>k^kP3dm?@0l?3`0>WYj@3Ph>00j>SX0P3V
i^H00`3QhN40i>CT0=kNgP020<o?c`040=3@d038b<P0bl_;0<c<c080a/K601<0bLW90<O7a`30`<00
^k^k0<30`02e]KD0][Jf0;2`/02c/k<0[jn_0;Ng]`2[Zj/0Z:RX0:b/[02VYZH0WYjN0:BTY02UYJD0
Vi^K0080VIVI01l0W9bL09RHV02JVYX0V9RH08^;R`2DU9@0S8b<09JFUP28R8P0SHf=08J6QP28R8P0
SXj>08V9R@23Ph<0QHF508N7Q`21PH40Q8B407moO`29RHT0PH6107alO01nOWh0M7Ad07=cL`1nOWh0
M7Ad07]kN`1bLW80Ng]k0080MWIf03P0MgMg07QhN01dM7@0KVi^07AdM01^KVh0L71`07=cL`1YJFT0
KVi^06QXJ01WIfL0JFUY06][J`1WIfL0JVYZ06QXJ01ZJVX0J6QX06a/K01QHF40L71`06][J`1YJFT0
J6QX06YZJP1WIfL0HF5Q06IVIP1YJFT0K6a/06ATI01RHV80HF5Q06=SH`1WIfL0I6AT06IVIP1TI6@0
GEeM061PH01QHF40IfMW061PH01IFET0H61P069RHP1TI6@0GemO05iNGP1QHF40GUiN05]KF`1IFET0
EEEE05MGEaL000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00D0inOW
06IVIP1UIFD0KVi^06QXJ00206][J`0806a/K01`L700JFUY071`L01^KVh0L71`06IVIP1kNg/206i^
KP08075aL@1fMWH0Kfm_06i^KP1]KFd0KVi^071`L01bLW82075aL@0@06i^KP1aLG40Jf][07EeM@1d
M7@0MWIf071`L01jNWX0MgMg07AdM01aLG40Kfm_07IfMP1cLg<0MgMg07=cL`80NGUi00<0O7al07mo
O`1cLg<00P1iNGT0A@1hN7P0Q8B407emO@1fMWH0Ph>307]kN`1mOGd0O7al08>3P`26QXH0Ph>308B4
Q025QHD0Ogmo08>3P`1mOGd0QhN708j>SP23Ph<0R8R808^;R`2=SHd0S8b<08^;R`2ATI40U9BD08b<
S02CTi<0RXZ:09bLW02CTi<0XJ6Q09JFUP2RXZ80UIFE09^KV`2SXj<0V9RH09fMW@2UYJD0Xj>S09ZJ
VP2`/;00YJFU0:>SX`2UYJD0^KVi0:j^[P2_[jl0[Zj^0:f][@2e]KD0/k>c0;Jf]P2h^;P0_kno0<71
`@2m_Kd0^;Rh0<?3``2m_Kd0aLG50<C4a037alL0bLW90<C4a03Fe]H0bl_;0=3@d0020=_Kf`080=cL
g03Ng]h0k>c/0>CTi03Xj>P0i>CT0>WYj@3Xj>P20>WYj@040>o_k`3bl_80jn_[0?Win@80oooo00<0
o_kn0?ooo`3kno/00P3oool0103hn?P0n_[j0?KfmP3no_h40?ooo`080?Shn03oool0oooo0?ooo`3h
n?P0oooo0?Shn03inOT20?7al@050?;blP3alO40l?3`0?3`l03]kNd00P3^k^h08P3Lg=`0hN7Q0=kN
gP3IfMT0g=cL0=3@d03?cll0dM7A0<c<c038b<P0alO70<?3``3=cLd0]kNg0<71`@30`<00^;Rh0;^k
^`2l_;`0a<C40;Jf]P2[Zj/0/K6a0;Jf]P2[Zj/0/k>c0:BTY02XZ:P0ZJVY0:BTY02OWil0XJ6Q09JF
UP2IVIT309jNWP0X09JFUP2DU9@0TY:B092@T02>SXh0RXZ:096AT@2;Rh/0QXJ608^;R`23Ph<0R8R8
08V9R@1oOgl0P82008:2PP1hN7P0QXJ607inOP22PX80OGem07alO026QXH0O7al07emO@21PH40O7al
07YjNP1nOWh0MgMg07IfMP1`L700Lg=c06m_K`1bLW80L71`07=cL`1eMGD0NGUi06i^KP80K6a/02L0
JVYZ06UYJ@1ZJVX0I6AT06UYJ@1ZJVX0IFEU06e]K@1YJFT0L71`06MWI`1]KFd0Jf][06UYJ@1[Jf/0
IfMW06IVIP1QHF40HV9R06YZJP1/K6`0Hf=S06ATI01NGUh0IVIV065QH@1MGEd0GemO06IVIP1PH600
IVIV065QH@1TI6@0H61P05aLG01XJ6P0FUYJ06ATI01OGel00P1TI6@0101VIVH0FEUI05eMG@1GEeLG
000000H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@030>;RhP1/K6`0IVIV
0080JFUY00P0I6AT06][J`1^KVh0KFe]06m_K`1^KVh0Lg=c06a/K080L71`01P0NGUi075aL@1YJFT0
K6a/079bLP1YJFT0LW9b06YZJP1aLG40L71`06i^KP1`L700Jf][071`L01cLg<0L71`07=cL`1bLW80
Lg=c071`L01eMGD0NWYj07]kN`1fMWH2071`L080MGEe00H0N7Qh07IfMP21PH40O7al07inOP1gMgL2
07QhN00<07moO`1hN7P0OGem07inOP1kNg/0Ph>30861P@26QXH0Ph>308N7Q`21PH40OWin0P24Q8@2
08>3P`030861P@26QXH0S8b<00@0Rh^;00l0QXJ608j>SP2=SHd0U9BD08f=S@2FUYH0Ti>C09bLW02G
UiL0Vi^K09bLW02QXJ40X:2P0:6QX@2MWId00P2KVi/0=`2JVYX0XJ6Q0:2PX02`/;00XZ:R0:RXZ02T
Y:@0ZJVY0:ZZZP2][Jd0[Zj^0;2`/02m_Kd0];Bd0;^k^`2n_[h0`/;20;Zj^P32`/80a<C40<S8b039
bLT0`<300;Jf]P34a<@0`<300;no_`3EeMD0e]KF0=OGe`3QhN40h>3P0>CTi03Shn<0g=cL0>GUi@3Q
hN40jn_[0>KViP3`l?00jn_[0>SXj03bl_80k^k^0?;blP3kno/0oOgm0??cl`3inOT0o?cl0?7al@3i
nOT0l?3`0?_kn`3dm?@00P3fm_H00`3inOT0oooo0?Win@020?Shn00@0?Gem@3clo<0mOGe0>k^kP3]
kNd0inOW0?3`l03/k>`0jn_[0>g]k@3Shn<0jNWY0>;RhP3Jf]X0j>SX0=gMg@80e]KF01<0dM7A0=SH
f03?cll0cLg=0=7Ad@2n_[h0`L710<C4a033`l<0_[jn0<K6aP2f][H0^;Rh0;Jf]P2a/K40^k^k0;Bd
]02/[:`0[jn_0080Zj^[0P2WYjL0402XZ:P0[Jf]0:>SX`2VYZH0Y:BT0:>SX`2MWId0W9bL09VIV@2B
TY80S8b<08Z:RP2@T900SXj>09>CT`2<S8`208V9R@0308^;R`27QhL0R8R80080Ph>30180QhN707al
O01nOWh0Q8B408>3P`20P800Ph>307moO`1kNg/0NWYj07IfMP1kNg/0N7Qh079bLP1dM7@0MWIf07Qh
N01fMWH207AdM00F07MgM`1dM7@0N7Qh079bLP1aLG40Jf][07AdM01cLg<0L71`075aL@1ZJVX0KVi^
06QXJ01QHF40Jf][06MWI`1[Jf/0J6QX06][J`1PH600IfMW06IVIP80J6QX0P1UIFD04P1[Jf/0J6QX
069RHP1UIFD0J6QX06IVIP1XJ6P0EeMG06IVIP1RHV80H61P05QHF01IFET0Hf=S05iNGP1QHF40H61P
05iNGP80HF5Q00D0IFEU05QHF01PH600FEUI05iNGP0205aLG00305UIF@000000000001D000001P3I
fMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI01l0j>SX079bLP1XJ6P0L71`06a/
K01_Kfl0M7Ad075aL@1VIVH0KFe]071`L01_Kfl0Lg=c06][J`1dM7@0JFUY07AdM01aLG40J6QX07If
MP1^KVh0Jf][079bLP1YJFT0L71`07QhN01dM7@0NGUi06i^KP1YJFT0Lg=c0080LG5a02P0LW9b07Ee
M@1eMGD0M7Ad07IfMP1eMGD0LW9b075aL@1hN7P0NGUi079bLP1hN7P0O7al07moO`1hN7P0MGEe07Qh
N01lO7`0Ng]k07IfMP1iNGT0Ph>307IfMP21PH40P82007inOP20P800O7al07UiN@1oOgl0P82007Yj
NP23Ph<0PX:20861P@1oOgl0RHV908B4Q025QHD0R8R80P2@T900202<S8`0UIFE092@T02BTY80VYZJ
09>CT`2IVIT0VYZJ0P2FUYH01`2GUiL0UIFE09^KV`2PX:00Vi^K0::RXP2QXJ400P2VYZH03P2YZJT0
YZJV0:>SX`2XZ:P0YJFU0;2`/02d];@0^;Rh0;Fe]@2`/;00][Jf0;no_`2i^KT0]kNg0P2l_;`03@2i
^KT0^[Zj0<?3``33`l<0bl_;0<71`@37alL0b/[:0<S8b03@d=00fm_K0<k>cP3Vi^H00P3Hf=P00`3I
fMT0gmoO0>CTi0020=kNgP0C0>SXj03Ogml0i>CT0>KViP3Xj>P0lO7a0>WYj@3alO40k>c/0>k^kP3b
l_80l?3`0>_[j`3fm_H0n?Sh0?;blP3]kNd0lo?c0>_[j`020?7al@0E0>c/k03emOD0jNWY0?Gem@3`
l?00k>c/0>g]k@3YjNT0hn?S0>SXj03Lg=`0fm_K0=kNgP3Ogml0hn?S0=kNgP3Jf]X0e=CD0=3@d03C
dm<0e=CD0080c/k>01D0bl_;0<71`@36a/H0`/;20<30`038b<P0`/;20<71`@2l_;`0_Kfm0;6a/@2d
];@0/;2`0;6a/@2j^[X0ZJVY0:NWY`2SXj<0X:2P0:NWY`2PX:000P2TY:@06P2LW9`0WYjN09bLW02D
U9@0UiNG09FEU@2;Rh/0T92@09>CT`2GUiL0T92@08^;R`2ATI40RHV90861P@29RHT0S8b<08f=S@26
QXH0Q8B407]kN`26QXH0RHV907alO023Ph<0N7Qh0P22PX807@21PH40MWIf07QhN01nOWh0O7al07If
MP1gMgL0NGUi07]kN`1aLG40LW9b07IfMP1_Kfl0KVi^06][J`1bLW80K6a/079bLP1^KVh0LG5a071`
L01WIfL0K6a/075aL@1]KFd0K6a/06=SH`1`L700IVIV0080IFEU00l0K6a/05iNGP1YJFT0KVi^065Q
H@1SHf<0GUiN06QXJ01[Jf/0IVIV06ATI01UIFD0JVYZ06UYJ@1KFe/00`1QHF400`1TI6@0HF5Q06=S
H`02061PH00<05mOG`1JFUX0IfMW05UIF@1QHF40G5aL05MGE`1OGel0GUiN061PH01IFET0F5QH5`00
00060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT00`3Xj>P0JVYZ06UYJ@02
06][J`0H06a/K01^KVh0KVi^06e]K@1dM7@0L71`06e]K@1/K6`0Jf][07AdM01^KVh0L71`07AdM01Y
JFT0Kfm_06UYJ@1XJ6P0LG5a079bLP1gMgL0M7Ad071`L01^KVh0KFe]0P1`L70207AdM00D06a/K01b
LW80L71`07inOP1eMGD0MWIf075aL@1gMgL0O7al07IfMP20P800NGUi07YjNP1cLg<0N7Qh07IfMP1e
MGD0OGem07UiN@1jNWX207]kN`80OWin00`0Ph>307moO`1nOWh0C4a<07emO@23Ph<0PH6108>3P`28
R8P0P82008F5Q@24Q8@208^;R`0508b<S01oOgl0T92@08J6QP2@T9000`2>SXh02`2DU9@0Ti>C09JF
UP2GUiL0UIFE09bLW02KVi/0X:2P0:6QX@2HV9P0WinO0080WYjN00L0XZ:R0:>SX`2SXj<0Z:RX0:JV
YP2SXj<0[Zj^0080YZJV01T0[Zj^0:f][@2^[Zh0][Jf0;:b/P2k^k/0][Jf0;Fe]@30`<00`L710<30
`02n_[h0]KFe0;no_`30`<00_[jn0<;2`P2l_;`0a/K60<O7a`3GemL0e]KF0=?Cd`3IfMT0e=CD0080
fMWI02D0h>3P0=oOg`3YjNT0fMWI0>7Qh@3Ti>@0hn?S0>SXj03Ti>@0jn_[0?3`l03YjNT0j>SX0>_[
j`3UiND0kNg]0>WYj@3Zj^X0l?3`0??cl`3YjNT0kNg]0>CTi03alO40l_;b0>c/k03Lg=`0l?3`0>_[
j`3Vi^H0g]kN0=_Kf`3Lg=`0gMgM0=OGe`3IfMT0i^KV0080h>3P00L0b/[:0=?Cd`3IfMT0dM7A0<S8
b036a/H0alO70080`<3000@0`l?30;Zj^P34a<@0][Jf0P2h^;P04P2i^KT0_;bl0;6a/@2^[Zh0]kNg
0;:b/P2h^;P0/;2`0:ZZZP2UYJD0X:2P0:JVYP2TY:@0Vi^K0:>SX`2LW9`0Xj>S0:BTY0<0UIFE00@0
V9RH08R8R029RHT0TI6A0P2@T9000`2BTY80RXZ:08V9R@0208J6QP80RXZ:01<0Q8B408V9R@26QXH0
PH6107IfMP23Ph<0OWin0820P01kNg/0OWin0820P01eMGD0N7Qh07UiN@1lO7`0Lg=c06m_K`1/K6`0
KVi^0080L71`00P0NGUi06e]K@1[Jf/0MgMg06e]K@1[Jf/0IVIV07AdM080Jf][0180L71`06IVIP1V
IVH0IVIV06QXJ01SHf<0K6a/06ATI01XJ6P0IVIV06EUI@1XJ6P0JFUY06][J`1XJ6P0JVYZ06=SH`1[
Jf/206UYJ@0706ATI01/K6`0HF5Q05eMG@1TI6@0HF5Q05iNGP0206=SH`0306IVIP1OGel0F5QH0080
H61P00X0IVIV05aLG01LG5`0G5aL05iNGP1LG5`0H61P05iNGP1EEED0FUYJ5`0000060=WIf@400000
0@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0103WinL0JFUY06e]K@1TI6@206QXJ00406UY
J@1ZJVX0KVi^06a/K080L71`101YJFT0301ZJVX0K6a/071`L01XJ6P0IVIV07AdM01YJFT0N7Qh06m_
K`1dM7@0KVi^06a/K080LG5a01<0Jf][079bLP1[Jf/0M7Ad079bLP1cLg<0MWIf07]kN`1^KVh0L71`
0820P01mOGd0LW9b07IfMP1cLg<0MWIf07QhN01jNWX0MGEe0080Ng]k00L0Ogmo07]kN`1iNGT0NWYj
07MgM`1nOWh0NWYj0080PH6101d0N7Qh07UiN@25QHD0Rh^;0820P02:RXX0R8R808B4Q025QHD0Q8B4
08^;R`22PX80S8b<08V9R@2=SHd0UIFE08b<S02>SXh0TI6A09NGU`2FUYH0U9BD09^KV`2HV9P0UYJF
09nOW`2NWYh0UiNG09^KV`0209bLW00<09^KV`2NWYh0YZJV0:VYZ@2SXj<0Z:RX0:ZZZP2^[Zh0ZZZZ
0:VYZ@2[Zj/0/K6a0P2[Zj/0302_[jl0][Jf0;2`/02a/K40^;Rh0;Ng]`2l_;`0^;Rh0<71`@33`l<0
^KVi0<C4a080`<3000`0_kno0<K6aP3IfMT0e]KF0=;BdP3?cll0dm?C0=WIf@3AdM40gMgM0=KFeP3I
fMT20>3Ph00S0>?Sh`3UiND0lO7a0>SXj03UiND0i^KV0=gMg@3Ng]h0inOW0?;blP3Rh^80gMgM0?Og
m`3YjNT0jn_[0>WYj@3Ng]h0k^k^0>_[j`3dm?@0i^KV0?3`l03Shn<0jNWY0=gMg@3Vi^H0emOG0=WI
f@3Ng]h0h>3P0=cLg03Fe]H0f][J0=_Kf`3Cdm<00P3@d=00=03>c/h0b<S80<O7a`34a<@0a/K60<71
`@2o_kl0`<300;jn_P2j^[X0];Bd0;jn_P2a/K40[Jf]0;>c/`2`/;00/k>c0:^[Z`2^[Zh0ZJVY0:b/
[02VYZH0Y:BT09bLW02KVi/0XJ6Q09NGU`2HV9P0Vi^K09>CT`2BTY80Shn?08j>SP27QhL0T92@09>C
T`2>SXh0RXZ:08j>SP2;Rh/0S8b<08^;R`26QXH0PX:208R8R01oOgl0RXZ:0820P021PH40Ogmo07Qh
N01jNWX208:2PP090861P@1iNGT0PX:208:2PP1lO7`0NGUi07AdM01fMWH0NGUi0080Lg=c00d0KVi^
07QhN01[Jf/0L71`079bLP1cLg<0MWIf06i^KP1aLG40JFUY06a/K01_Kfl0Jf][0080K6a/00D0IVIV
069RHP1XJ6P0IVIV06=SH`0206UYJ@0:05iNGP1QHF40I6AT06][J`1VIVH0Jf][06YZJP1[Jf/0IFEU
06IVIP80HF5Q00D0HV9R06UYJ@1VIVH0FUYJ06IVIP02061PH080I6AT00d0H61P05aLG01SHf<0HF5Q
06=SH`1PH600Fe]K06=SH`1[Jf/0HF5Q05=CD`1GEeL0G5aL01L000001P3IfMT100000040fMWI000F
0=WIf@800000103IfMT05P3WinL0JVYZ071`L01/K6`0LG5a06i^KP1dM7@0JFUY06YZJP1_Kfl0K6a/
07AdM01^KVh0IVIV06a/K01aLG40J6QX071`L01^KVh0LG5a07MgM`1`L70206i^KP0R07AdM01aLG40
LG5a06e]K@1aLG40KVi^075aL@1bLW80Lg=c07]kN`1bLW80MWIf071`L01hN7P0KVi^071`L01iNGT0
Lg=c075aL@1gMgL0O7al07]kN`1jNWX0O7al07inOP21PH40Lg=c07QhN01kNg/0NGUi07YjNP1kNg/0
P82007YjNP80P82000X0N7Qh07IfMP1kNg/0OWin07YjNP23Ph<0Rh^;0820P029RHT0Q8B40P28R8P0
1@2=SHd0SXj>08b<S02>SXh0QXJ60080UIFE02l0TI6A09RHV029RHT0UIFE08N7Q`2NWYh0UYJF09bL
W02DU9@0TY:B09bLW02NWYh0W9bL0:6QX@2MWId0Y:BT0:b/[02YZJT0WYjN0:VYZ@2SXj<0ZZZZ0;2`
/02][Jd0[Zj^0;2`/02f][H0];Bd0;bl_02i^KT0];Bd0;fm_@2f][H0_;bl0;^k^`36a/H0^[Zj0;Vi
^@2f][H0^;Rh0<71`@2n_[h0a<C40=3@d03=cLd0c<c<0=KFeP020=?Cd`0V0<k>cP3Hf=P0e]KF0=KF
eP3>c/h0h^;R0>3Ph03QhN40g]kN0>?Sh`3Cdm<0f=SH0>3Ph03Rh^80g=cL0>[ZjP3Shn<0k^k^0=gM
g@3Xj>P0hn?S0=cLg03Shn<0g=cL0>?Sh`3WinL0iNGU0>7Qh@3YjNT0g]kN0>SXj03Ng]h0g=cL0=WI
f@3Kfm/0dm?C0=CDe03Hf=P20<W9b@0C0<_;b`36a/H0b<S80<S8b02m_Kd0`/;20<G5a@2n_[h0]kNg
0;bl_02k^k/0];Bd0;Vi^@2d];@0^KVi0:n_[`2a/K40[:b/0:FUY@020:ZZZP030:FUY@2YZJT0Xj>S
0080WYjN00D0W9bL0:6QX@2MWId0WIfM09ZJVP0209JFUP0809NGU`2FUYH0TI6A092@T02DU9@0TI6A
08^;R`2<S8`208R8R00O08b<S01mOGd0PH610861P@24Q8@0QXJ608B4Q022PX80Ph>308F5Q@1oOgl0
Q8B40861P@23Ph<0OWin07alO01iNGT0M7Ad07IfMP1cLg<0N7Qh07AdM01iNGT0Lg=c06e]K@1dM7@0
KFe]075aL@1_Kfl0LG5a06m_K`02075aL@0<05iNGP1/K6`0L71`06ATI01/K6`0J6QX06UYJ@1VIVH0
HV9R06IVIP1[Jf/0KVi^0P1XJ6P05@1YJFT0Jf][06UYJ@1TI6@0IfMW06a/K01YJFT0GUiN06ATI01X
J6P0IFEU06=SH`1QHF40FEUI06=SH`1PH600J6QX05mOG`1LG5`0IVIV061PH00206IVIP0:05]KF`1V
IVH0FEUI06ATI01KFe/0GemO05aLG01HF5P0GemO05iNGQL000001@3IfMT200000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI00H0j>SX07=cL`1YJFT0Jf][06MWI`1XJ6P206][J`0406QXJ01_
Kfl0KVi^06m_K`80JFUY00<0Lg=c06UYJ@1cLg<00P1dM7@08`1_Kfl0Jf][075aL@1cLg<0KVi^06e]
K@1cLg<0LG5a06e]K@1VIVH0Jf][07QhN01YJFT0MGEe071`L01gMgL0Kfm_07=cL`1iNGT0N7Qh07]k
N`1hN7P0LG5a07AdM01hN7P0NGUi079bLP1hN7P0LW9b07UiN@1gMgL0NGUi07QhN01oOgl0PH610080
M7Ad00H0OWin07alO01mOGd0N7Qh08:2PP1hN7P208J6QP0<0820P024Q8@0Q8B408J6QP2:RXX0QHF5
08j>SP26QXH0QhN708j>SP2?Shl0RHV90P2@T9002@2ATI40S8b<096AT@2EUID0U9BD08N7Q`2MWId0
V9RH09FEU@0209BDU00H09:BTP2SXj<0Vi^K09^KV`2NWYh0Xj>S09bLW02UYJD0X:2P0::RXP2LW9`0
YZJV0:^[Z`2a/K40/;2`0:RXZ02g]kL0];Bd0:^[Z`2h^;P0/;2`0;Jf]P2l_;`0^KVi0P2k^k/03@2i
^KT0_;bl0;Rh^02`/;00][Jf0;Fe]@2i^KT0^;Rh0<C4a03GemL0bl_;0=CDe03AdM400P3Hf=P01P3?
cll0dm?C0=CDe03Fe]H0hN7Q0=kNgP80fMWI02T0dm?C0=OGe`3@d=00e]KF0>KViP3Shn<0i>CT0>OW
i`3[jn/0g=cL0=_Kf`3Shn<0f=SH0>[ZjP3Xj>P0g=cL0=OGe`3QhN40f=SH0=[JfP3AdM40eMGE0=cL
g03Jf]X0emOG0<o?c`3Hf=P0clo?0<O7a`3?cll0a<C40<S8b03AdM40`L710;Vi^@32`/80^KVi0<30
`02n_[h0];Bd0;bl_0020;Bd]080Zj^[00l0/k>c0:NWY`2WYjL0[:b/0:^[Z`2WYjL0XJ6Q0:JVYP2Q
XJ40WinO0:>SX`2PX:00TY:B09jNWP2HV9P00P2JVYX01`2BTY80UiNG08j>SP2CTi<0TY:B08R8R02<
S8`00P2;Rh/02`28R8P0P82008R8R024Q8@0OWin07]kN`23Ph<0QXJ608N7Q`1nOWh0P8200080Ogmo
00D0NGUi07inOP1lO7`0OGem07inOP0207]kN`0G07UiN@1fMWH0L71`07MgM`1cLg<0NGUi06a/K01a
LG40N7Qh075aL@1YJFT0L71`075aL@1]KFd0I6AT065QH@1XJ6P0KVi^06m_K`1YJFT0J6QX069RHP1^
KVh00P1YJFT0801TI6@0IVIV05aLG01PH600HV9R061PH01ZJVX0J6QX065QH@1VIVH0IFEU06=SH`1X
J6P0IFEU05eMG@1JFUX0H61P065QH@1NGUh0F5QH06=SH`1NGUh0IVIV05iNGP1OGel0Hf=S05UIF@1P
H600GEeM05aLG01NGUh0G5aL0P1IFET00`1PH600E5AD05UIF@0G000000H0fMWI0@0000010=WIf@00
5P3IfMT00`000000fMWI0=WIf@030=WIf@040>[ZjP1^KVh0L71`06i^KP80LG5a00H0KVi^06][J`1Z
JVX0JFUY06][J`1^KVh206][J`0;06e]K@1ZJVX0JVYZ07=cL`1ZJVX0Lg=c071`L01cLg<0KVi^07Ui
N@1`L7000P1_Kfl0601]KFd0KVi^07MgM`1^KVh0LG5a07IfMP1eMGD0Lg=c075aL@1gMgL0NWYj06m_
K`1`L700OGem07AdM01lO7`0Lg=c07UiN@1eMGD0Ng]k07alO01eMGD0Lg=c07QhN080NGUi0`1kNg/0
2@23Ph<0P82008>3P`1jNWX0Q8B407moO`23Ph<0QXJ607alO00208>3P`0C07moO`28R8P0Ph>308j>
SP24Q8@0QXJ608j>SP23Ph<0R8R808j>SP2BTY80S8b<09>CT`2@T900S8b<09:BTP2HV9P0UIFE09^K
V`0209NGU`0>09^KV`2JVYX0VYZJ09jNWP2FUYH0VYZJ0:2PX02VYZH0Z:RX0:JVYP2TY:@0YjNW0:b/
[02^[Zh20:^[Z`0<0:JVYP2i^KT0/[:b0;6a/@2b/[80[:b/0:j^[P2_[jl0/[:b0;Bd]031`L40^;Rh
0P2d];@0:`2f][H0/k>c0;>c/`2c/k<0^KVi0<30`03>c/h0b<S80<[:bP39bLT0c<c<0=3@d03Fe]H0
bl_;0=;BdP3EeMD0clo?0>;RhP3GemL0c/k>0<[:bP3De=@0d=3@0=KFeP3Vi^H0e]KF0=[JfP3GemL0
h>3P0=[JfP3Ph>00hN7Q0=cLg03Hf=P0g]kN0=gMg@3Lg=`0dm?C0=;BdP3Cdm<0d];B0=CDe03EeMD0
0P3AdM402035aLD0c<c<0<;2`P39bLT0b/[:0<_;b`36a/H0]kNg102n_[h20;^k^`0>0<30`02h^;P0
]KFe0;6a/@2c/k<0/[:b0:JVYP2[Zj/0Xj>S0:6QX@2[Zj/0Y:BT0:VYZ@2/[:`20:6QX@0O09jNWP2I
VIT0Y:BT09RHV02ATI40UYJF09RHV02<S8`0Ti>C08j>SP2ATI40QhN708j>SP2?Shl0Ph>308R8R029
RHT0OGem0861P@26QXH0QHF508>3P`21PH40PX:20861P@20P800NGUi07emO@1lO7`0OGem08:2PP02
0861P@0?08>3P`1fMWH0MWIf07UiN@1hN7P0NWYj06m_K`1hN7P0Kfm_07MgM`1iNGT0JVYZ06i^KP1a
LG40Lg=c00<0L71`02D0KVi^06UYJ@1VIVH0HF5Q06UYJ@1ZJVX0J6QX06IVIP1WIfL0IVIV06ATI01U
IFD0JFUY06QXJ01TI6@0JFUY06IVIP1QHF40I6AT06=SH`1XJ6P0H61P06QXJ01VIVH0I6AT06IVIP1U
IFD0HF5Q06ATI01UIFD0GUiN061PH01UIFD0G5aL05iNGP1LG5`0HF5Q0080G5aL00P0HF5Q05EEE@1I
FET0G5aL061PH01NGUh0EeMG055ADAL000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0
fMWI00<0fMWI00L0jNWY06UYJ@1`L700M7Ad06QXJ01^KVh0JVYZ0080JFUY01P0J6QX06e]K@1_Kfl0
L71`06i^KP1bLW80JFUY06a/K01bLW80Jf][06UYJ@1cLg<0KVi^07AdM01/K6`0LW9b07=cL`1VIVH0
Lg=c06][J`1aLG40KVi^07IfMP1bLW8206i^KP0707=cL`1bLW80MgMg07MgM`1hN7P0MGEe075aL@03
07=cL`0607YjNP1cLg<0MGEe07QhN01mOGd0NGUi0P1hN7P01`1gMgL0Ng]k07moO`1iNGT0Ng]k08f=
S@22PX800P23Ph<01@1nOWh0PH6108B4Q01lO7`0P8200080Q8B400@0RXZ:08>3P`2@T900SXj>0P28
R8P0A`2?Shl0SHf=09:BTP2@T900SXj>096AT@2=SHd0Vi^K096AT@2<S8`0UYJF09bLW02KVi/0TI6A
09bLW02IVIT0VYZJ09jNWP2ZZZX0Y:BT0:JVYP2OWil0YJFU0:ZZZP2WYjL0Zj^[0:JVYP2/[:`0YZJV
0:VYZ@2a/K40/;2`0;:b/P2ZZZX0/K6a0:b/[02WYjL0Zj^[0;Zj^P2f][H0]kNg0;^k^`2a/K40][Jf
0;Rh^02b/[80/k>c0:j^[P31`L40`<300<[:bP3;bl/0c<c<0<O7a`3<c<`0dM7A0<W9b@3?cll0c/k>
0=WIf@3AdM40fm_K0=OGe`3<c<`0f=SH0=7Ad@3De=@0e]KF0=CDe03@d=00fm_K0080g=cL00P0e]KF
0=7Ad@3IfMT0g=cL0=[JfP3Hf=P0c<c<0=GEe@80dm?C0180cLg=0<W9b@36a/H0dM7A0<S8b03@d=00
cLg=0<_;b`33`l<0a/K60<C4a039bLT0a<C40;Rh^02l_;`0^k^k0;Jf]P2e]KD20;bl_00?0;Zj^P2^
[Zh0/K6a0;2`/02_[jl0Z:RX0:FUY@2a/K40[:b/0:JVYP2TY:@0Xj>S09jNWP2VYZH0Vi^K0080WYjN
00@0UYJF0:2PX02EUID0Rh^;0P2ATI402@2?Shl0Ti>C096AT@2DU9@0RHV908B4Q026QXH0Ph>308N7
Q`0208b<S00807emO@26QXH0NWYj0820P02;Rh/0PH6107inOP2;Rh/207QhN00907inOP1iNGT0Ng]k
07inOP1jNWX0OWin079bLP1lO7`0N7Qh0080MWIf00T0Jf][075aL@1_Kfl0J6QX06m_K`1dM7@0JFUY
07EeM@1[Jf/00P1YJFT05`1[Jf/0J6QX06][J`1ZJVX0GemO06ATI01WIfL0I6AT06QXJ01UIFD0IVIV
06UYJ@1VIVH0K6a/06EUI@1WIfL0HV9R06QXJ01NGUh0HF5Q05eMG@1LG5`0GemO0080HV9R0P1PH600
101MGEd0H61P05eMG@1QHF42061PH00>06ATI01NGUh0H61P069RHP1QHF40GUiN06IVIP1FEUH0IVIV
05]KF`1QHF40F5QH05=CD`1DE5@G000000H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WI
f@030=WIf@070>?Sh`1YJFT0L71`06a/K01[Jf/0Lg=c06][J`02071`L00>06a/K01`L700K6a/06i^
KP1YJFT0JVYZ06i^KP1`L700LW9b07]kN`1_Kfl0L71`075aL@1`L70206a/K080LG5a01L0KFe]07=c
L`1cLg<0KVi^07AdM01hN7P0MWIf071`L01lO7`0MWIf07QhN01nOWh0NGUi07=cL`1dM7@0N7Qh07Ad
M01bLW80NGUi07]kN`1cLg<0MgMg07inOP0307alO00F07inOP1iNGT0PX:207alO022PX80PH6107al
O020P800Ph>307inOP20P800O7al08:2PP25QHD0PH6108V9R@2=SHd0S8b<08>3P`2>SXh0Shn?08V9
R@80R8R801<0RXZ:08^;R`27QhL0Ti>C092@T02>SXh0Ti>C09BDU02CTi<0T92@09^KV`2DU9@0Vi^K
09BDU02HV9P0TI6A09VIV@2HV9P0Vi^K0080XJ6Q0140WIfM09jNWP2VYZH0X:2P0;2`/02RXZ80XJ6Q
0:n_[`2a/K40Zj^[0;Bd]02SXj<0YZJV0:f][@2SXj<0YZJV0;Jf]P020;2`/00a0;Bd]02f][H0][Jf
0;2`/02a/K40^;Rh0;Zj^P31`L40`l?30<O7a`38b<P0c/k>0<G5a@3>c/h0d=3@0<c<c038b<P0d=3@
0<K6aP3:b/X0c<c<0<g=c@3@d=00eMGE0=;BdP3Cdm<0eMGE0=_Kf`3EeMD0dm?C0=CDe03Hf=P0cLg=
0<[:bP3@d=00dm?C0=KFeP3Cdm<0bl_;0<W9b@3:b/X0dM7A0<c<c03AdM40c/k>0<_;b`3:b/X0b<S8
0<[:bP020<G5a@050<?3``38b<P0`L710;fm_@31`L400P2h^;P01`34a<@0/K6a0;Fe]@2f][H0ZJVY
0;>c/`2[Zj/00`2XZ:P0:@2VYZH0ZJVY0:BTY02WYjL0ZZZZ0:6QX@2UYJD0XJ6Q09bLW02PX:00Vi^K
09>CT`2>SXh0UYJF096AT@2BTY80QhN708J6QP2>SXh0Shn?08Z:RP29RHT0T92@08J6QP2<S8`0Ph>3
08F5Q@28R8P0P82008N7Q`24Q8@0O7al0861P@22PX80QXJ60820P01iNGT0Ng]k07inOP1jNWX0OGem
0080M7Ad00<0Lg=c07]kN`1eMGD00P1bLW801@1eMGD0L71`06i^KP1dM7@0KVi^0080LG5a0`1^KVh0
101`L700Hf=S06e]K@1OGel206][J`0<06a/K01UIFD0IVIV06][J`1YJFT0J6QX06ATI01VIVH0I6AT
06EUI@1KFe/0Hf=S0P1QHF4206=SH`0C06][J`1RHV80GemO05eMG@1RHV80GEeM061PH01LG5`0HF5Q
06=SH`1QHF40H61P069RHP1NGUh0F5QH05iNGP1PH600Hf=S06ATI00205mOG`0306=SH`1JFUX0FUYJ
0080Fe]K5`0000060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT02`3WinL0
Lg=c07EeM@1bLW80KFe]06ATI01XJ6P0KVi^06a/K01dM7@0JVYZ0080Jf][00@0LG5a071`L01`L700
K6a/0P1^KVh01P1]KFd0LG5a06m_K`1`L700K6a/06UYJ@80Lg=c00L0L71`06YZJP1fMWH0LG5a06a/
K01fMWH0LW9b0080L71`00`0Lg=c07QhN01dM7@0M7Ad075aL@1hN7P0M7Ad07inOP1jNWX0L71`07Ad
M01aLG4207]kN`0<07YjNP1kNg/0MWIf07QhN01nOWh0P82008V9R@20P800Ogmo07UiN@1jNWX0PX:2
0P23Ph<0;01lO7`0PX:208V9R@23Ph<0S8b<08J6QP24Q8@0SHf=08R8R025QHD0S8b<09>CT`2>SXh0
QHF508j>SP2;Rh/0QhN709>CT`2@T900UYJF09>CT`2ATI40U9BD09>CT`2GUiL0S8b<092@T02IVIT0
WYjN09VIV@2OWil0WYjN0:2PX02DU9@0Xj>S09jNWP2MWId0YZJV0:b/[02YZJT0[Zj^0:JVYP2YZJT0
YjNW0P2/[:`20:>SX`0A09jNWP2VYZH0[Zj^0:ZZZP2/[:`0][Jf0;Ng]`2n_[h0[Zj^0;6a/@2i^KT0
_[jn0;Bd]02l_;`0a/K60;jn_P30`<000P35aLD03@39bLT0dM7A0<k>cP38b<P0bl_;0<S8b034a<@0
d=3@0<g=c@3<c<`0bl_;0=7Ad@3Cdm<00P3;bl/01@3AdM40eMGE0=7Ad@3AdM40eMGE00<0c/k>0140
alO70<k>cP3@d=00`l?30<S8b036a/H0c<c<0<S8b033`l<0_kno0<C4a036a/H0a<C40<;2`P37alL0
aLG50;Jf]P020;Rh^00C0;Vi^@2_[jl0/k>c0;Ng]`2e]KD0/[:b0;6a/@2c/k<0Y:BT0:RXZ02VYZH0
Zj^[09jNWP2TY:@0YZJV0:NWY`2OWil0Y:BT09jNWP020:2PX00409VIV@2LW9`0TI6A09JFUP80U9BD
01@0V9RH096AT@2<S8`0TI6A08V9R@2<S8`0Q8B408V9R@23Ph<0OWin08b<S023Ph<0QXJ607alO01i
NGT0PX:207emO@25QHD0OWin08V9R@80OWin00l0MgMg07]kN`1iNGT0NGUi07QhN01jNWX0NGUi07Qh
N01fMWH0NWYj075aL@1eMGD0LW9b06i^KP1eMGD00P1^KVh09P1]KFd0LG5a071`L01^KVh0J6QX06=S
H`1QHF40JFUY061PH01VIVH0HF5Q06][J`1NGUh0KVi^06a/K01VIVH0HV9R06MWI`1SHf<0H61P06UY
J@1RHV80HF5Q05iNGP1^KVh0FUYJ05iNGP1LG5`0GUiN06=SH`1VIVH0HF5Q069RHP1OGel0G5aL05iN
GP1TI6@0Hf=S0P1QHF40301NGUh0H61P06ATI01LG5`0FEUI061PH01IFET0Fe]K05UIF@1LG5`0GUiN
05IFEQL000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0100m?Cd071`
L01aLG40KVi^06a/K01aLG40L71`06][J`1WIfL0KVi^06e]K@1`L700K6a/06i^KP1_Kfl0LW9b0P1a
LG40:01^KVh0Lg=c07EeM@1dM7@0Jf][06i^KP1jNWX0Jf][071`L01cLg<0N7Qh06i^KP1_Kfl0NGUi
07alO01`L700M7Ad07]kN`1dM7@0MWIf07EeM@1fMWH0PH6107AdM01hN7P0NGUi07alO01kNg/0MGEe
07=cL`1gMgL0NGUi07IfMP1hN7P0NGUi07alO01iNGT0Ng]k07alO01mOGd207moO`0;07YjNP21PH40
Q8B408>3P`21PH40Q8B408Z:RP26QXH0Ph>308R8R02<S8`00P29RHT0=@2@T900S8b<08^;R`2<S8`0
TI6A08j>SP2CTi<0RHV908b<S02:RXX0T92@08b<S02LW9`0RHV90:6QX@2EUID0U9BD096AT@2HV9P0
UYJF09RHV02JVYX0WYjN09^KV`2HV9P0YJFU0:RXZ02JVYX0Z:RX0:JVYP2XZ:P0Zj^[0:BTY02ZZZX0
[Zj^0:JVYP2TY:@0ZJVY0::RXP2NWYh0ZZZZ0:RXZ02ZZZX0/k>c0;Ng]`2c/k<0/K6a0;jn_P2f][H0
]KFe0:j^[P2_[jl0^;Rh0080_[jn01H0aLG50<?3``36a/H0a<C40<71`@38b<P0`L710<c<c039bLT0
a/K60<k>cP37alL0d];B0<c<c03Cdm<0dM7A0<W9b@3?cll0c<c<0<S8b03Cdm<0alO70P38b<P01@3B
d]80b<S80=7Ad@3:b/X0a<C40080a/K601/0bLW90<C4a038b<P0`L710<S8b031`L40`l?30<71`@2h
^;P0/k>c0;Jf]P2n_[h0^k^k0;6a/@2f][H0^;Rh0;6a/@2YZJT0];Bd0:JVYP2`/;00YjNW0:VYZ@2T
Y:@0[:b/0:FUY@2LW9`00P2OWil0602UYJD0WYjN0:VYZ@2JVYX0WYjN09fMW@2FUYH0VIVI09^KV`2@
T900Rh^;08j>SP2<S8`0TY:B08b<S029RHT0QhN708^;R`22PX80QXJ608R8R026QXH0RHV907UiN@80
Ph>30240Q8B408:2PP24Q8@0PH6107AdM01kNg/0Ph>307YjNP1iNGT0OGem07=cL`1eMGD0NGUi07Ee
M@1hN7P0MgMg079bLP1dM7@0LW9b07QhN01`L700KVi^06m_K`1]KFd0LW9b065QH@1dM7@0MgMg06YZ
JP1/K6`0IVIV06ATI01VIVH00P1/K6`0301TI6@0IfMW06QXJ01/K6`0IFEU065QH@1KFe/0J6QX06=S
H`1TI6@0HF5Q061PH080Hf=S00L0HV9R06=SH`1PH600J6QX065QH@1VIVH0F5QH0080H61P01<0Hf=S
05iNGP1PH600H61P065QH@1KFe/0H61P05EEE@1KFe/0H61P05]KF`1TI6@0FEUI05iNGP1PH600EEEE
055AD@1@D500Fe]K01L000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI
00h0oooo07=cL`1[Jf/0Jf][06UYJ@1[Jf/0Kfm_06i^KP1YJFT0Jf][06a/K01_Kfl0K6a/06e]K@80
K6a/00<0L71`075aL@1aLG400P1^KVh2071`L00=06m_K`1aLG40L71`06][J`1/K6`0MgMg07]kN`1_
Kfl0LG5a07AdM01aLG40MGEe07MgM`0207UiN@0407QhN01iNGT0MgMg07QhN080NGUi04X0MWIf07Ad
M01fMWH0MWIf07AdM01lO7`0Lg=c07alO01kNg/0OGem07=cL`1iNGT0NWYj0820P023Ph<0PX:207Ui
N@1mOGd0PH6107inOP2;Rh/0OWin08V9R@23Ph<0P82008R8R029RHT0Q8B408b<S02;Rh/0SXj>08B4
Q02:RXX0T92@08f=S@29RHT0TI6A09RHV02KVi/0RXZ:08b<S02DU9@0TI6A09RHV02FUYH0WinO09BD
U02>SXh0TY:B09FEU@2HV9P0XJ6Q0::RXP2QXJ40WinO0:JVYP2QXJ40Z:RX0:^[Z`2LW9`0WIfM0:VY
Z@2RXZ80Z:RX0;Ng]`2^[Zh0Z:RX0:6QX@2LW9`0WYjN0::RXP2YZJT0/;2`0:j^[P80/;2`00D0/K6a
0;:b/P2d];@0/[:b0;6a/@020;Bd]00F0<30`02f][H0`l?30<C4a031`L40a/K60;jn_P33`l<0a<C4
0<W9b@38b<P0bl_;0<71`@3<c<`0alO70=3@d03?cll0a<C40<S8b03EeMD0alO70<[:bP80bl_;01D0
clo?0<k>cP3?cll0c<c<0<;2`P3;bl/0a<C40<G5a@36a/H0`/;20;^k^`2j^[X0`L710<G5a@2n_[h0
^k^k0;Vi^@2k^k/0/;2`0;Bd]02h^;P00P2k^k/01`2d];@0ZJVY0:n_[`2d];@0[Zj^0;2`/02[Zj/0
0P2VYZH01`2UYJD0Xj>S0:6QX@2MWId0W9bL0:2PX02SXj<00P2NWYh04@2LW9`0WYjN09bLW02DU9@0
VYZJ09JFUP2BTY80TI6A09:BTP2>SXh0Rh^;08f=S@2;Rh/0RXZ:08J6QP21PH40Rh^;0080Q8B400L0
PX:208>3P`23Ph<0Ogmo08B4Q01lO7`0Ph>30080O7al01/0M7Ad0820P01lO7`0M7Ad07alO01jNWX0
Ogmo07MgM`1iNGT0Ogmo07AdM01bLW80Lg=c071`L01/K6`0M7Ad06i^KP1_Kfl0J6QX071`L01_Kfl0
K6a/06YZJP1VIVH0IFEU06a/K01TI6@00P1_Kfl05P1[Jf/0IfMW06EUI@1YJFT0I6AT06=SH`1QHF40
JFUY06][J`1VIVH0HF5Q06=SH`1XJ6P0GUiN06EUI@1TI6@0Hf=S06ATI01SHf<0FEUI06=SH`0@4102
05eMG@0;061PH01QHF40HV9R05eMG@1OGel0F5QH05eMG@1KFe/0GEeM065QH@1HF5P00P1IFET01@1M
GEd0FEUI055AD@1FEUH0Fe]K01L000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI
00<0fMWI00/0oooo07IfMP1aLG40JFUY06][J`1/K6`0JFUY06][J`1cLg<0Jf][06IVIP02071`L00D
06IVIP1/K6`0Kfm_06UYJ@1VIVH0Kfm_07IfMP1_Kfl0J6QX06a/K01[Jf/0LG5a06a/K01ZJVX0KVi^
07=cL`1[Jf/0KVi^07UiN@1dM7@207UiN@0<07IfMP1dM7@0MGEe07QhN01cLg<0M7Ad07IfMP1hN7P0
M7Ad07=cL`1aLG40O7al0P1cLg<207QhN00B07IfMP1hN7P0P82007YjNP1nOWh0O7al08B4Q025QHD0
Ph>307alO023Ph<0NWYj08B4Q027QhL0PX:20820P02;Rh/0TY:B0P25QHD04@1lO7`0QhN708J6QP28
R8P0S8b<08^;R`27QhL0Ti>C08n?S`2@T900Ti>C09JFUP2ATI40SXj>09BDU02>SXh0T92@0080TI6A
02@0UYJF09BDU02EUID0Shn?0:2PX02NWYh0VYZJ09^KV`2PX:00W9bL0:2PX02XZ:P0[:b/0:^[Z`2X
Z:P0XJ6Q0:VYZ@2SXj<0]KFe0;2`/02ZZZX0Xj>S0:BTY02QXJ40WYjN0:j^[P2ZZZX0Zj^[0;2`/02^
[Zh0[:b/0;Jf]P2][Jd0[jn_0;Ng]`2c/k<20;jn_P80`L7100X0bLW90<[:bP34a<@0`<300<C4a02n
_[h0d=3@0<O7a`31`L40_[jn0P34a<@03P39bLT0aLG50;no_`36a/H0bl_;0<S8b034a<@0bl_;0<71
`@3>c/h0a<C40<O7a`32`/80bLW90P33`l<04@2n_[h0^k^k0<C4a031`L40^;Rh0;jn_P2g]kL0/[:b
0;2`/02c/k<0^[Zj0;Fe]@2d];@0_;bl0;Bd]02[Zj/0/K6a0080[jn_00/0];Bd0::RXP2/[:`0[:b/
0:RXZ02VYZH0ZJVY09fMW@2QXJ40WYjN0:FUY@020:2PX00N0:JVYP2PX:00W9bL09JFUP2@T900W9bL
09RHV02DU9@0SHf=08j>SP2;Rh/0RXZ:08n?S`26QXH0SXj>08V9R@2BTY80QXJ608V9R@26QXH0PH61
08>3P`21PH40Ng]k08:2PP1oOgl0PH6107QhN022PX80PH610P1nOWh06`1hN7P0M7Ad07]kN`1aLG40
MgMg07UiN@1dM7@0L71`079bLP1mOGd0LG5a07=cL`1`L700M7Ad07=cL`1^KVh0KFe]07AdM01/K6`0
L71`06a/K01NGUh0JFUY06QXJ01[Jf/0Hf=S06YZJP0206UYJ@0G06ATI01QHF40IVIV06UYJ@1UIFD0
IfMW06YZJP1TI6@0H61P069RHP1VIVH0HF5Q069RHP1LG5`0HV9R05iNGP1ZJVX0I6AT06=SH`1NGUh0
H61P065QH@1TI6@00P1NGUh03`1SHf<0I6AT06ATI01PH600G5aL05iNGP1VIVH0EUIF061PH01KFe/0
FEUI05IFEP1OGel0F5QH05ADE00G000000H0fMWI0@0000010=WIf@000P3IfMT2000000@0fMWI0P00
00040=WIf@8000001P3IfMT00`000000fMWI0=WIf@030=WIf@080?ooo`1cLg<0IVIV071`L01_Kfl0
Jf][06i^KP1_Kfl206a/K00R06e]K@1`L700Kfm_06e]K@1PH600Jf][071`L01[Jf/0K6a/06i^KP1a
LG40JVYZ06MWI`1^KVh0Lg=c06i^KP1YJFT0KFe]075aL@1[Jf/0LW9b06UYJ@1^KVh0N7Qh071`L01d
M7@0LG5a07=cL`1hN7P0LW9b071`L01cLg<0L71`07EeM@80N7Qh00X0M7Ad07QhN01`L700MWIf07in
OP1kNg/0N7Qh07moO`23Ph<0QHF50P1nOWh04@1lO7`0M7Ad07]kN`20P800NWYj07UiN@26QXH0QHF5
08b<S022PX80Q8B408N7Q`22PX80QHF508Z:RP26QXH0QhN700<0QXJ600<0Ph>308V9R@2;Rh/00P2;
Rh/0<@2DU9@0Rh^;092@T02DU9@0SXj>09JFUP2IVIT0Ti>C09BDU02=SHd0W9bL09BDU02SXj<0VIVI
09^KV`2LW9`0WYjN0:RXZ02OWil0XZ:R0:2PX02[Zj/0X:2P09nOW`2ZZZX0X:2P0:n_[`2/[:`0XJ6Q
0:n_[`2LW9`0XJ6Q0:f][@2WYjL0/[:b0;Bd]02TY:@0ZJVY0:j^[P2/[:`0[Zj^0;6a/@2b/[80][Jf
0;no_`33`l<0`<300<?3``2n_[h00P2l_;`0@036a/H0^[Zj0<[:bP31`L40^[Zj0<K6aP2m_Kd0`L71
0<C4a02n_[h0a<C40<30`033`l<0`<300<K6aP2k^k/0alO70<C4a02n_[h0`<300<K6aP33`l<0^KVi
0;^k^`30`<00^KVi0;Zj^P31`L40/;2`0;Jf]P2[Zj/0^KVi0;Fe]@2b/[80^;Rh0:j^[P2_[jl0/k>c
0:j^[P2][Jd0[:b/0:j^[P2[Zj/0YJFU0:^[Z`2YZJT0YZJV0:RXZ02NWYh0YZJV0:>SX`2JVYX0X:2P
09nOW`2QXJ40Y:BT09fMW@2LW9`0XJ6Q09bLW02FUYH0Ti>C09:BTP2;Rh/208j>SP0N08^;R`2<S8`0
RHV908R8R029RHT0S8b<08^;R`28R8P0Rh^;08R8R024Q8@0N7Qh0861P@1lO7`0P82007YjNP20P800
O7al07inOP1lO7`0Ng]k08>3P`1jNWX0N7Qh07YjNP1lO7`0LW9b075aL@1dM7@0Lg=c0P1`L7002P1c
Lg<0L71`06e]K@1`L700Lg=c06e]K@1ZJVX0Lg=c06][J`1_Kfl206QXJ00606ATI01^KVh0JFUY06][
J`1TI6@0IVIV0P1SHf<306IVIP04065QH@1PH600IVIV06=SH`<0I6AT00H0Jf][065QH@1LG5`0H61P
05eMG@1PH602065QH@06061PH01NGUh0I6AT05]KF`1LG5`0Hf=S0P1LG5`03@1IFET0HF5Q05iNGP1N
GUh0HF5Q05UIF@1FEUH0I6AT05UIF@1PH600EeMG05YJFP1KFe/05`0000060=WIf@4000000@3IfMT0
00050=WIf@000000fMWI0=WIf@0000000P3IfMT010000000fMWI0=WIf@0000020=WIf@040000003I
fMT0fMWI000000D0fMWI00<000000=WIf@3IfMT00`3IfMT00`3oool0L71`06a/K00206a/K00706][
J`1^KVh0KVi^071`L01[Jf/0K6a/06e]K@0206][J`0806e]K@1^KVh0Jf][06][J`1VIVH0KVi^06a/
K01ZJVX206e]K@09075aL@1_Kfl0JFUY06m_K`1dM7@0K6a/07QhN01aLG40M7Ad0080KFe]00<0Kfm_
07QhN01dM7@00`1cLg<01@1bLW80LG5a07=cL`1dM7@0MGEe0080MWIf00P0MGEe07UiN@1kNg/0MWIf
07inOP1hN7P0MgMg08B4Q080O7al00h0Ng]k07YjNP20P800Ph>30861P@22PX80P82008B4Q022PX80
Ph>308F5Q@23Ph<0QXJ608^;R`80R8R801@0OWin08J6QP2=SHd0Ph>308R8R02=SHd0R8R808^;R`2<
S8`0SXj>08f=S@2;Rh/0Ti>C08j>SP2BTY80T92@09JFUP2CTi<0S8b<09FEU@80V9RH00D0WIfM09bL
W02NWYh0U9BD0:FUY@0209bLW00A0:FUY@2MWId0YJFU0:6QX@2SXj<0ZZZZ0:JVYP2YZJT0Xj>S0:VY
Z@2RXZ80Y:BT09jNWP2UYJD0YZJV0;2`/02b/[800P2ZZZX07@2/[:`0[Zj^0:b/[02[Zj/0^;Rh0;bl
_02d];@0a<C40;bl_02k^k/0ZZZZ0;Bd]02n_[h0`L710;jn_P2f][H0`<300;:b/P2n_[h0^KVi0;^k
^`2l_;`0_kno0<?3``36a/H0a<C40<71`@30`<00^;Rh0080`<3000T0_;bl0;Ng]`2h^;P0][Jf0;Rh
^02l_;`0^[Zj0;jn_P2c/k<00P2d];@07`2f][H0[jn_0;Ng]`2l_;`0Zj^[0:b/[02b/[80XJ6Q0:j^
[P2XZ:P0YZJV0:>SX`2XZ:P0Xj>S0:BTY02YZJT0Vi^K0:JVYP2PX:00V9RH0::RXP2MWId0WYjN09bL
W02KVi/0VYZJ09VIV@2EUID0Ti>C09BDU02>SXh00P2EUID06@2>SXh0TI6A096AT@2:RXX0RHV908J6
QP2<S8`0QHF508R8R026QXH0RHV908N7Q`24Q8@0QXJ608>3P`26QXH0O7al07QhN01fMWH0O7al0820
P01iNGT0M7Ad07IfMP1eMGD00P1hN7P01@1lO7`0MgMg07IfMP1dM7@0LG5a0080N7Qh00/0KVi^07=c
L`1`L700J6QX075aL@1fMWH0L71`06i^KP1cLg<0JVYZ06ATI00206][J`0;06YZJP1^KVh0FEUI06YZ
JP1XJ6P0HF5Q06IVIP1UIFD0HF5Q06ATI01PH6000P1VIVH04@1SHf<0HV9R05eMG@1VIVH0FEUI06AT
I01UIFD0Hf=S061PH01MGEd0IFEU065QH@1TI6@0G5aL069RHP1QHF40GEeM0080HF5Q00@0FUYJ065Q
H@1LG5`0Fe]K0`1JFUX0201SHf<0G5aL05aLG01KFe/0EeMG05iNGP1KFe/0E5AD5`0000060=WIf@40
00000@3IfMT000<0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@040000003IfMT0fMWI0000
0080fMWI00<000000=WIf@3IfMT00`3IfMT3000000<0fMWI00H0m?Cd06i^KP1VIVH0KVi^06UYJ@1`
L70206UYJ@80J6QX02D0KVi^06][J`1XJ6P0KVi^06e]K@1/K6`0JFUY06i^KP1RHV80K6a/06MWI`1a
LG40K6a/06IVIP1`L700KFe]06a/K01_Kfl0KVi^06a/K01`L700LG5a07AdM01`L700LG5a071`L01f
MWH0LW9b075aL@1cLg<0K6a/07QhN01`L700LW9b07MgM`1`L700NGUi0080NWYj01L0N7Qh07UiN@1h
N7P0NGUi0820P021PH40O7al07UiN@1lO7`0NGUi07QhN023Ph<0PX:208>3P`1nOWh0Ng]k08R8R024
Q8@0RHV907emO@26QXH0PH6108J6QP0208>3P`0<08B4Q028R8P0RXZ:08J6QP28R8P0QHF508V9R@2@
T900Ogmo08V9R@2?Shl0TY:B0P2>SXh0502;Rh/0UIFE092@T02HV9P0VYZJ09^KV`2DU9@0VIVI092@
T02HV9P0VIVI09RHV02PX:00XJ6Q09ZJVP2NWYh0ZJVY09jNWP2MWId0XJ6Q0P2PX:00202[Zj/0[Zj^
0:VYZ@2XZ:P0YjNW0:2PX02NWYh0Z:RX0P2TY:@0=`2[Zj/0ZZZZ0;>c/`2[Zj/0/K6a0:VYZ@2d];@0
_;bl0;>c/`2f][H0_[jn0<30`02d];@0^KVi0;bl_02k^k/0];Bd0;Vi^@2n_[h0][Jf0;Fe]@2k^k/0
`<300;Vi^@2f][H0`l?30<30`02k^k/0`l?30;Jf]P2n_[h0`/;20;no_`2h^;P0_Kfm0;>c/`2a/K40
][Jf0;6a/@2g]kL0]KFe0;Vi^@2k^k/0/;2`0:^[Z`2][Jd0/;2`0:b/[02`/;00Zj^[0;6a/@2d];@0
Z:RX0:NWY`2SXj<00P2XZ:P05@2VYZH0Z:RX09^KV`2RXZ80X:2P0:>SX`2LW9`0UYJF09VIV@2JVYX0
X:2P0::RXP2PX:00V9RH09^KV`2@T900S8b<09BDU02<S8`0T92@09JFUP02092@T00G08Z:RP2?Shl0
QHF508J6QP22PX80R8R808>3P`2@T900Ph>30820P024Q8@0O7al07IfMP23Ph<0OGem07UiN@1nOWh0
Ng]k07emO@1^KVh0Ng]k07IfMP1nOWh00P1kNg/207YjNP0Q06i^KP1dM7@0Lg=c07=cL`1dM7@0KVi^
075aL@1cLg<0J6QX06UYJ@1cLg<0KFe]06YZJP1aLG40IfMW06UYJ@1]KFd0Kfm_06MWI`1QHF40IVIV
06YZJP1TI6@0J6QX06IVIP1TI6@0JVYZ06][J`1OGel0JFUY06QXJ01SHf<0HF5Q0080HV9R0P1NGUh0
6`1QHF40H61P065QH@1TI6@0Fe]K061PH01NGUh0EUIF05MGE`1SHf<0G5aL061PH01NGUh0GEeM065Q
H@1MGEd0Fe]K05iNGP1CDe<0G5aL05IFEP1PH600HF5Q05iNGP1KFe/0GEeM05ADE00G000000@0fMWI
0`0000010=WIf@00103IfMT010000000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI00000080
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@0T0?Ogm`1XJ6P0J6QX06i^
KP1/K6`0Lg=c06YZJP1aLG40L71`06IVIP1]KFd0K6a/06UYJ@1XJ6P0KFe]06QXJ01VIVH0L71`06i^
KP1]KFd0IfMW06a/K01cLg<0Kfm_06e]K@1aLG40Jf][06UYJ@1^KVh0K6a/075aL@1YJFT0M7Ad06QX
J01cLg<0JFUY0P1cLg<0201aLG40K6a/07EeM@1dM7@0MGEe07QhN01bLW80MWIf0P1iNGT0401dM7@0
PH6107alO01iNGT0O7al07IfMP20P800MWIf07inOP1hN7P0Ng]k07QhN01lO7`0OGem07IfMP28R8P2
08>3P`0707alO01oOgl0RHV90861P@20P800QXJ608F5Q@0208>3P`0U08R8R024Q8@0O7al08Z:RP24
Q8@0R8R808F5Q@2;Rh/0RHV9092@T02ATI40S8b<08Z:RP2@T900R8R809JFUP2HV9P0T92@09JFUP2<
S8`0TI6A09nOW`2HV9P0VIVI0:BTY02LW9`0UYJF09nOW`2RXZ80Vi^K09jNWP2MWId0ZZZZ0:6QX@2V
YZH0WYjN0:RXZ0020:JVYP0`0:RXZ02RXZ80UYJF0:BTY02VYZH0[Zj^0:6QX@2WYjL0Zj^[0:j^[P2_
[jl0YZJV0;6a/@2d];@0^;Rh0;>c/`2l_;`0/[:b0;Vi^@2f][H0_kno0;Bd]02l_;`0];Bd0;Vi^@2g
]kL0^KVi0<30`02j^[X0a/K60;Rh^02d];@0_;bl0;no_`31`L40^k^k0;no_`2j^[X0/k>c0;bl_02i
^KT0][Jf0;6a/@2_[jl0/K6a0;:b/P2/[:`0];Bd0P2`/;00102XZ:P0/K6a0:VYZ@2g]kL20:b/[007
0:JVYP2a/K40[:b/0:>SX`2RXZ80YJFU0:2PX00209^KV`080:6QX@2IVIT0X:2P09^KV`2OWil0TY:B
09jNWP2IVIT209^KV`0Z09JFUP2BTY80TY:B09VIV@2@T900UYJF09BDU02FUYH0T92@08^;R`2@T900
RXZ:08V9R@24Q8@0S8b<08:2PP23Ph<0QXJ608:2PP2;Rh/0RHV90820P024Q8@0OWin07alO024Q8@0
O7al07]kN`1iNGT0MGEe0861P@1fMWH0MgMg07UiN@1fMWH0M7Ad07inOP1aLG40MWIf07=cL`1dM7@0
N7Qh0P1YJFT0801[Jf/0M7Ad06i^KP1[Jf/0L71`06a/K01YJFT0JVYZ06i^KP1[Jf/0K6a/06QXJ01V
IVH0Jf][06IVIP1/K6`0HV9R06EUI@1WIfL0HF5Q06][J`1UIFD0IVIV06UYJ@1RHV80Hf=S061PH01Q
HF40IFEU06ATI01UIFD0J6QX0P1NGUh02`1MGEd0G5aL061PH01OGel0Hf=S06EUI@1VIVH0GEeM069R
HP1LG5`0H61P0080GUiN00@0GemO05QHF01TI6@0EeMG0P1PH6001@1LG5`0F5QH05=CD`1CDe<0FEUI
01L000001P3IfMT100000040fMWI00001@3IfMT000000=WIf@3IfMT000000080fMWI00@000000=WI
f@3IfMT000000P3IfMT010000000fMWI0=WIf@0000050=WIf@030000003IfMT0fMWI00<0fMWI01H0
jNWY06QXJ01ZJVX0JVYZ06a/K01VIVH0JFUY06YZJP1]KFd0M7Ad06i^KP1XJ6P0KVi^06QXJ01YJFT0
KVi^06m_K`1^KVh0KFe]06ATI01^KVh0KFe]0P1aLG40101cLg<0N7Qh07EeM@1^KVh2075aL@0806m_
K`1bLW80MWIf079bLP1^KVh0LG5a06m_K`1aLG4207=cL`0;07IfMP1^KVh0NWYj07QhN01lO7`0Ng]k
07=cL`1nOWh0NWYj07AdM01oOgl00P1nOWh04`25QHD0Ng]k07YjNP1hN7P0P82007alO01mOGd0OWin
0820P01lO7`0Ng]k07MgM`1iNGT0OWin08N7Q`1lO7`0R8R808:2PP27QhL00P26QXH02`1mOGd0Q8B4
08F5Q@28R8P0T92@08V9R@28R8P0RXZ:08b<S025QHD0T92@0080Q8B400<0RHV908j>SP2FUYH00P2@
T9001@29RHT0T92@096AT@2DU9@0SXj>00<0VIVI00L0WYjN09fMW@2JVYX0Vi^K0:6QX@2KVi/0U9BD
0080Vi^K00`0Y:BT09jNWP2SXj<0ZZZZ0:b/[02YZJT0WYjN09VIV@2LW9`0Z:RX09^KV`2VYZH20:VY
Z@030:RXZ02[Zj/0];Bd0080/K6a04<0][Jf0;>c/`2e]KD0][Jf0;Vi^@2][Jd0^k^k0;Jf]P2h^;P0
][Jf0;6a/@2e]KD0]kNg0;Bd]02n_[h0^KVi0;Jf]P2g]kL0/[:b0;fm_@2b/[80][Jf0;Rh^02e]KD0
^;Rh0;Bd]02_[jl0]kNg0;6a/@2^[Zh0/;2`0:b/[02f][H0[Zj^0:b/[02c/k<0[jn_0;6a/@2RXZ80
ZJVY0:^[Z`2XZ:P0Zj^[0:JVYP2QXJ40ZJVY09fMW@2SXj<0YJFU0:JVYP2TY:@0X:2P09bLW02NWYh0
X:2P09nOW`2HV9P0WYjN09NGU`2HV9P0UIFE09RHV02JVYX0T92@09:BTP2GUiL0TI6A0080RHV901`0
T92@09JFUP2ATI40QhN7092@T02;Rh/0Ph>308^;R`1nOWh0RHV908>3P`2:RXX0Ogmo08>3P`24Q8@0
OWin07]kN`1iNGT0MWIf07alO01iNGT0MgMg07EeM@1fMWH0M7Ad07QhN01iNGT0MWIf0P1iNGT207Ee
M@0M07=cL`1`L700M7Ad06a/K01]KFd0L71`06a/K01_Kfl0J6QX07QhN01]KFd0KVi^075aL@1`L700
KFe]06IVIP1XJ6P0IVIV06][J`1OGel0J6QX05mOG`1QHF40GemO06IVIP1SHf<0I6AT06QXJ01JFUX0
0`1QHF400`1UIFD0G5aL05iNGP0205eMG@0D06=SH`1NGUh0GUiN061PH01OGel0GEeM05iNGP1LG5`0
GEeM06=SH`1LG5`0HV9R05iNGP1JFUX0GUiN05]KF`1OGel0GEeM05iNGP1RHV8205]KF`0305IFEP1G
EeL0Fe]K01L000001P3IfMT100000040fMWI00020=WIf@800000103IfMT2000000@0fMWI0P000006
0=WIf@030000003IfMT0fMWI00<0fMWI00<0i^KV06IVIP1]KFd00P1YJFT0501^KVh0L71`061PH01Y
JFT0Kfm_075aL@1XJ6P0Hf=S06][J`1ZJVX0KVi^06UYJ@1]KFd0KVi^06QXJ01[Jf/0JFUY06m_K`1[
Jf/0JFUY0P1[Jf/00`1]KFd0KVi^06][J`0206a/K007079bLP1cLg<0KVi^07MgM`1kNg/0LW9b06a/
K002071`L00H07MgM`1bLW80M7Ad07AdM01fMWH0Lg=c07IfMP22PX80Q8B408Z:RP22PX80PH6107Ad
M01kNg/0P82007alO020P800PH6107QhN01nOWh0O7al07IfMP1oOgl0QXJ60P21PH405`27QhL0OGem
08J6QP1oOgl0R8R808V9R@2<S8`0PH6108J6QP20P800SXj>08Z:RP28R8P0Q8B408V9R@2:RXX0RHV9
08j>SP2CTi<0TI6A092@T02>SXh0VIVI0080UIFE0P2?Shl04@2@T900Shn?09JFUP2CTi<0UYJF09BD
U02LW9`0VIVI0::RXP2JVYX0WIfM09ZJVP2SXj<0WinO09^KV`2VYZH0YJFU00<0XJ6Q00L0YJFU0:BT
Y02QXJ40[jn_0:BTY02WYjL0[:b/0080Y:BT00T0ZJVY0:6QX@2`/;00/;2`0:VYZ@2c/k<0[Zj^0:^[
Z`2`/;000P2^[Zh0202h^;P0][Jf0:n_[`2e]KD0[jn_0;Vi^@2l_;`0[jn_0P2f][H01`2c/k<0][Jf
0;>c/`2[Zj/0_[jn0;Bd]02l_;`00P2c/k<08P2[Zj/0YZJV0:f][@2a/K40Zj^[0:j^[P2i^KT0/k>c
0:VYZ@2`/;00YJFU0:b/[02[Zj/0[Zj^0:BTY02MWId0YZJV09jNWP2SXj<0XJ6Q09jNWP2KVi/0X:2P
0:NWY`2PX:00Y:BT09bLW02MWId0VIVI09nOW`2CTi<0SXj>09VIV@2HV9P4096AT@0309BDU02;Rh/0
Rh^;0080V9RH00D0RHV9092@T02>SXh0U9BD08>3P`0208^;R`0608J6QP2:RXX0Q8B408^;R`20P800
QhN70P1lO7`08`1fMWH0OWin08>3P`1hN7P0Ng]k07MgM`1mOGd0P82007MgM`1hN7P0MGEe075aL@1`
L700NGUi07=cL`1iNGT0L71`075aL@1WIfL0M7Ad071`L01bLW80K6a/06UYJ@1cLg<0JFUY06][J`1c
Lg<0MWIf06i^KP1`L700Hf=S06i^KP1UIFD0JVYZ00<0JFUY01/0Hf=S06ATI01TI6@0IVIV06][J`1U
IFD0I6AT06][J`1NGUh0HV9R06QXJ01SHf<0JFUY06ATI01PH600HF5Q05IFEP1QHF40Fe]K061PH01N
GUh0I6AT065QH@1IFET0Hf=S069RHP1JFUX00P1MGEd205aLG00405]KF`1MGEd0HF5Q05aLG080H61P
0P1IFET00`1JFUX0Fe]K05YJFP0G000000H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WI
f@030=WIf@0:0>7Qh@1YJFT0JVYZ06MWI`1[Jf/0K6a/06UYJ@1_Kfl0KVi^06UYJ@80Kfm_00P0J6QX
06][J`1/K6`0KVi^06UYJ@1ZJVX0K6a/06][J`<0JFUY00/0Jf][06e]K@1fMWH0MGEe07=cL`1/K6`0
Kfm_06][J`1lO7`0M7Ad071`L00206m_K`0407IfMP1`L700M7Ad079bLP80MGEe00X0Lg=c079bLP1c
Lg<0LW9b07MgM`1fMWH0O7al07inOP22PX80Ph>30P1nOWh0101lO7`0NGUi0820P01jNWX207]kN`0B
07inOP20P800O7al07emO@1jNWX0Ogmo07alO021PH40P82008B4Q01lO7`0QXJ608R8R020P800RHV9
08J6QP25QHD0Rh^;0P24Q8@01`28R8P0S8b<08V9R@2;Rh/0S8b<09>CT`29RHT00P2@T9003`2DU9@0
SXj>08b<S02@T900S8b<08n?S`2DU9@0T92@09^KV`2<S8`0VIVI09bLW02IVIT0TI6A09fMW@0209VI
V@0M0:>SX`2LW9`0Xj>S0:2PX02GUiL0X:2P0:BTY02PX:00WinO0:2PX02QXJ40Xj>S0:FUY@2SXj<0
[:b/0:^[Z`2/[:`0YZJV0;2`/02^[Zh0Z:RX0:n_[`2YZJT0];Bd0:j^[P2c/k<0Zj^[0;:b/P2VYZH0
0`2a/K400`2/[:`0/k>c0;Vi^@020;Jf]P040;Rh^02e]KD0];Bd0;6a/@80^;Rh02D0^KVi0;:b/P2b
/[80^;Rh0;>c/`2/[:`0[Zj^0;:b/P2QXJ40[jn_0:f][@2XZ:P0[:b/0:n_[`2^[Zh0XZ:R0:VYZ@2/
[:`0Zj^[0:BTY02YZJT0YjNW0:6QX@2VYZH0Vi^K0::RXP2SXj<0Y:BT0:6QX@2SXj<0WYjN09RHV02K
Vi/0VYZJ09NGU`2ATI40V9RH0080U9BD01<0WYjN09^KV`2=SHd0SXj>09JFUP2ATI40SXj>08N7Q`2B
TY80SHf=08J6QP2?Shl0SHf=0861P@25QHD0R8R80820P021PH40P8200080Q8B400L0P82007inOP1m
OGd0Ph>307]kN`1gMgL0P8200080NGUi01T0OGem07AdM01iNGT0OGem07alO01fMWH0Lg=c06a/K01`
L700MGEe071`L01dM7@0LW9b071`L01_Kfl0L71`07AdM01aLG40LW9b06UYJ@1`L700K6a/06e]K@1W
IfL0K6a/0080IfMW00L0LG5a06a/K01UIFD0Jf][061PH01SHf<0IfMW0080Hf=S02D0IVIV065QH@1S
Hf<0JVYZ061PH01RHV80IFEU065QH@1VIVH0IFEU06IVIP1TI6@0Hf=S05eMG@1ADE40Hf=S05=CD`1I
FET0GUiN05YJFP1TI6@0GEeM065QH@1OGel0H61P06=SH`1HF5P0GUiN05eMG@1NGUh0Fe]K06ATI01Q
HF40G5aL05UIF@1NGUh0FUYJ01L000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI
00<0fMWI0140g]kN06IVIP1XJ6P0JFUY06i^KP1VIVH0LG5a06i^KP1YJFT0IVIV075aL@1[Jf/0LG5a
06YZJP1[Jf/0L71`06][J`0206e]K@05079bLP1WIfL0L71`06m_K`1YJFT00P1aLG40401hN7P0KVi^
06i^KP1`L700M7Ad07=cL`1fMWH0LG5a07EeM@1aLG40LW9b071`L01cLg<0N7Qh07EeM@1bLW82071`
L00506a/K01fMWH0Ng]k07IfMP1eMGD00P23Ph<04@20P800Ng]k07]kN`1nOWh0P82007YjNP1nOWh0
O7al07inOP1kNg/0OWin0820P01nOWh0NWYj08>3P`20P800QhN70080PH6101<0OWin08>3P`24Q8@0
PH6108B4Q026QXH0Q8B408J6QP28R8P0P82008V9R@26QXH0UYJF08^;R`2DU9@0QXJ608Z:RP2<S8`0
TY:B0080TI6A00H0Ti>C092@T02>SXh0T92@09>CT`2?Shl209VIV@0F09FEU@2HV9P0UIFE092@T02L
W9`0WIfM09bLW02IVIT0WYjN0::RXP2NWYh0WinO0:2PX02KVi/0WinO0:>SX`2JVYX0Xj>S09jNWP2Q
XJ40YZJV0:>SX`80Z:RX00@0XJ6Q0:VYZ@2SXj<0[Jf]0P2WYjL08@2VYZH0ZJVY0:j^[P2TY:@0/K6a
0:VYZ@2b/[80[jn_0:^[Z`2/[:`0ZJVY0;6a/@2/[:`0[Zj^0;Fe]@2/[:`0/k>c0;6a/@2`/;00[Jf]
0:^[Z`2k^k/0[Jf]0;:b/P2a/K40Zj^[0;2`/02TY:@0ZZZZ0:j^[P2XZ:P0Zj^[0:ZZZP020:RXZ004
0:JVYP2a/K40Y:BT0::RXP80X:2P00D0XZ:R09VIV@2JVYX0YZJV0:BTY00209bLW00709^KV`2NWYh0
TI6A09ZJVP2ATI40V9RH09BDU00209JFUP0509VIV@2BTY80UIFE09FEU@2ATI400P2@T900702ATI40
Rh^;09BDU028R8P0RHV909>CT`26QXH0SXj>08J6QP25QHD0RHV908>3P`29RHT0OGem0820P01lO7`0
Ng]k07moO`1mOGd0Ng]k07MgM`1nOWh0M7Ad07YjNP1hN7P0MWIf07]kN`1cLg<207QhN00P07UiN@1a
LG40M7Ad07AdM01eMGD0M7Ad06][J`1YJFT0K6a/06][J`1_Kfl0Jf][06i^KP1hN7P0KVi^06QXJ01T
I6@0LG5a06i^KP1YJFT0I6AT06IVIP1YJFT0I6AT06=SH`1aLG40JFUY06EUI@1VIVH0IfMW061PH01T
I6@206=SH`0406EUI@1YJFT0HF5Q05eMG@80HF5Q00@0GUiN065QH@1PH600G5aL0P1PH6004@1IFET0
GemO061PH01NGUh0HF5Q05UIF@1MGEd0Hf=S05mOG`1PH600FUYJ05eMG@1JFUX0HF5Q05aLG01OGel0
GEeM0080FUYJ00<0E5AD05YJFP1DE5@05`0000060=WIf@4000000@3IfMT001H0fMWI00<000000=WI
f@3IfMT00`3IfMT01P3Shn<0Hf=S06][J`1TI6@0Kfm_06ATI0<0K6a/01L0L71`06MWI`1ZJVX0Jf][
06i^KP1/K6`0KFe]06IVIP1UIFD0L71`06][J`1YJFT0IFEU079bLP1_Kfl0Jf][07AdM01XJ6P0K6a/
071`L01_Kfl0NGUi07AdM00207QhN00807MgM`1eMGD0LG5a075aL@1dM7@0MWIf079bLP1aLG4206i^
KP80MWIf00h0OWin07EeM@23Ph<0OWin08>3P`1hN7P0Ng]k075aL@1fMWH0O7al07QhN01kNg/0OGem
07UiN@80P82001<0OWin07alO01jNWX0Q8B408>3P`22PX80OWin07]kN`22PX80P82007inOP24Q8@0
PH6108V9R@21PH40PX:208R8R025QHD0PH610080QXJ60280R8R808J6QP28R8P0Q8B408R8R02DU9@0
T92@09BDU02;Rh/0S8b<092@T02>SXh0Ti>C09JFUP2DU9@0Ti>C09JFUP2BTY80UiNG0:6QX@2IVIT0
WinO09bLW02IVIT0X:2P09fMW@2LW9`0V9RH0:ZZZP2QXJ40WIfM0:2PX02TY:@0VYZJ0P2TY:@0202V
YZH0Xj>S0:6QX@2/[:`0Zj^[0:VYZ@2TY:@0Zj^[0P2YZJT01P2ZZZX0[jn_0:BTY02`/;00YZJV0:NW
Y`80Zj^[00`0YJFU0;>c/`2_[jl0ZJVY0;Ng]`2/[:`0[Jf]0;>c/`2VYZH0YjNW0;>c/`2h^;P20;2`
/0070;:b/P2c/k<0[Jf]0:VYZ@2ZZZX0Zj^[0:JVYP020:^[Z`0:0:ZZZP2YZJT0XJ6Q0:^[Z`2RXZ80
YZJV0:RXZ02UYJD0X:2P0:JVYP80WYjN00d0VIVI0:6QX@2KVi/0WYjN09RHV02FUYH0U9BD09jNWP2J
VYX0V9RH09^KV`2DU9@0VIVI00<0Ti>C01D0TY:B096AT@2ATI40S8b<092@T02>SXh0S8b<08^;R`2<
S8`0QXJ608F5Q@2=SHd0RHV908j>SP29RHT0Ph>308J6QP23Ph<0QXJ60861P@1kNg/00P21PH400`1m
OGd0MgMg07YjNP0207]kN`0607MgM`1dM7@0MgMg079bLP1fMWH0LG5a0P1`L700101_Kfl0MWIf07Ee
M@1fMWH207AdM00:06a/K01[Jf/0M7Ad06YZJP1[Jf/0J6QX06m_K`1[Jf/0MGEe06a/K080JFUY00T0
IVIV06MWI`1TI6@0J6QX06YZJP1UIFD0IVIV06ATI01XJ6P00P1VIVH05P1RHV80JFUY06MWI`1XJ6P0
G5aL061PH01SHf<0EUIF05iNGP1LG5`0HF5Q05QHF01TI6@0EUIF061PH01QHF40G5aL06UYJ@1XJ6P0
GUiN05aLG01QHF4306ATI00=06=SH`1NGUh0GUiN065QH@1IFET0GemO069RHP1QHF40GUiN05mOG`1D
E5@0F5QH05ADE00G000000H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@05
0=oOg`1/K6`0Jf][06UYJ@1UIFD00`1WIfL04`1[Jf/0JFUY071`L01XJ6P0JVYZ07=cL`1[Jf/0JVYZ
069RHP1/K6`0J6QX06UYJ@1aLG40K6a/06UYJ@1^KVh0IFEU07UiN@1bLW800P1cLg<03P1VIVH0NGUi
07QhN01fMWH0NGUi07AdM01cLg<0KVi^06m_K`1cLg<0L71`07AdM01bLW80L71`0P1dM7@02@1eMGD0
LG5a07YjNP1hN7P0P82007moO`1gMgL0O7al07inOP0207]kN`0607inOP1gMgL0Ph>307alO01nOWh0
PH610P1hN7P06`1kNg/0OWin0861P@23Ph<0OWin07alO021PH40PX:20861P@2;Rh/0Ph>308V9R@2<
S8`0Q8B408J6QP29RHT0RXZ:08:2PP26QXH0Q8B408N7Q`25QHD0RHV908j>SP2=SHd0SXj>08>3P`03
08j>SP0:096AT@2<S8`0RHV909BDU02FUYH0Ti>C09NGU`2ATI40U9BD09^KV`80UYJF00`0VIVI09^K
V`2NWYh0TI6A0:6QX@2JVYX0Z:RX0:6QX@2NWYh0VIVI0:FUY@2RXZ8209nOW`80X:2P00H0Zj^[0:6Q
X@2SXj<0Xj>S0:n_[`2SXj<20::RXP0<0:RXZ02YZJT0Zj^[0::RXP2[Zj/0YJFU0:b/[02`/;00ZJVY
0;6a/@2_[jl0Zj^[0P2a/K408P2`/;00[:b/0:ZZZP2ZZZX0[:b/0:f][@2/[:`0[Zj^0;Bd]02a/K40
ZZZZ0:2PX02YZJT0Xj>S0:NWY`2_[jl0XJ6Q09nOW`2QXJ40ZZZZ0:>SX`2TY:@0YjNW09bLW02KVi/0
VYZJ09VIV@2GUiL0U9BD09^KV`2DU9@0X:2P09VIV@2PX:0209bLW00409BDU02HV9P0SXj>09RHV080
Ti>C01<0VIVI09bLW02>SXh0TI6A09>CT`2;Rh/0SHf=08n?S`2>SXh0S8b<08V9R@2>SXh0QhN708V9
R@2;Rh/0RHV908N7Q`1oOgl0OWin0080QXJ600L0QHF507alO023Ph<0OWin07QhN01`L700NGUi0080
N7Qh0P1fMWH05`1hN7P0MWIf07emO@1lO7`0XJ6Q08B4Q01jNWX0LG5a079bLP1YJFT0N7Qh07=cL`1]
KFd0KVi^06UYJ@1[Jf/0K6a/06UYJ@1cLg<0J6QX06][J`1ZJVX0K6a/00<0IVIV00X0JFUY06IVIP1S
Hf<0J6QX06IVIP1XJ6P0Hf=S05mOG`1VIVH0I6AT0P1UIFD0101RHV80GUiN06=SH`1RHV8205iNGP0G
06EUI@1RHV80HF5Q05aLG01OGel0GUiN06EUI@1RHV80GemO05IFEP1EEED0I6AT05aLG01FEUH0Fe]K
05eMG@1LG5`0H61P05]KF`1HF5P0G5aL05UIF@1LG5`00P1HF5P0101CDe<0FUYJ05QHF01CDe<G0000
00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0D0>WYj@1XJ6P0I6AT075a
L@1^KVh0JFUY06=SH`1^KVh0J6QX06][J`1bLW80IVIV06][J`1cLg<0Jf][06UYJ@1`L700IVIV06i^
KP1ZJVX206e]K@0B06][J`1cLg<0IVIV06e]K@1^KVh0MGEe071`L01cLg<0Ng]k07UiN@1cLg<0Ng]k
07YjNP1cLg<0KFe]075aL@1cLg<0M7Ad0P1aLG403@1^KVh0M7Ad07AdM01fMWH0Ng]k07IfMP1hN7P0
NWYj0861P@1iNGT0P82007QhN01eMGD00`1kNg/05022PX80O7al07alO01hN7P0NGUi07alO01mOGd0
NWYj07alO025QHD0Ph>308B4Q01kNg/0Ph>307inOP2;Rh/0Ph>308N7Q`29RHT0QhN70P26QXH01@24
Q8@0PH6108V9R@28R8P0PX:20080Ph>300X0RHV908b<S028R8P0QXJ608B4Q02<S8`0R8R8096AT@2I
VIT0TI6A0P2<S8`0302ATI40UYJF09>CT`2IVIT0XJ6Q09fMW@2KVi/0WIfM09bLW02NWYh0VYZJ09jN
WP80VIVI00P0XZ:R09fMW@2SXj<0XJ6Q0:>SX`2NWYh0X:2P0:RXZ080XZ:R00h0V9RH09JFUP2YZJT0
X:2P0:JVYP2ZZZX0/;2`0:6QX@2PX:00[jn_0:JVYP2[Zj/0YZJV0:NWY`80ZZZZ00h0Y:BT0:ZZZP2Z
ZZX0Zj^[0:JVYP2YZJT0[:b/0:^[Z`2/[:`0[jn_0:>SX`2a/K40/k>c0:2PX080XJ6Q0300YjNW0:ZZ
ZP2YZJT0Xj>S0:JVYP2LW9`0WinO0:6QX@2TY:@0WYjN0:6QX@2NWYh0XZ:R09VIV@2NWYh0VIVI09jN
WP2QXJ40WYjN09^KV`2DU9@0W9bL09JFUP2EUID0V9RH09>CT`2DU9@0Ti>C09VIV@2@T900TI6A09^K
V`2@T900SXj>08b<S02>SXh0RHV909BDU02CTi<0S8b<08j>SP2=SHd0P82008B4Q02;Rh/0OWin07mo
O`23Ph<208J6QP0:0820P01iNGT0OWin07moO`1eMGD0P82007UiN@20P800NGUi07alO080OWin00D0
NWYj07IfMP1cLg<0MWIf079bLP02075aL@0K071`L01cLg<0NGUi07UiN@1^KVh0Lg=c071`L01dM7@0
KVi^06QXJ01VIVH0J6QX06UYJ@1aLG40Jf][06=SH`1WIfL0Kfm_06=SH`1PH600L71`069RHP1TI6@0
KFe]06][J`1SHf<0JVYZ0080Hf=S00d0HV9R065QH@1TI6@0JVYZ069RHP1OGel0J6QX06ATI01JFUX0
IFEU05iNGP1PH600I6AT0080G5aL00<0Fe]K065QH@1LG5`00P1PH6002@1QHF40Hf=S05iNGP1KFe/0
HF5Q05UIF@1LG5`0FEUI05iNGP0205MGE`0306=SH`1LG5`0GemO0080F5QH00<0EEEE05IFEP000000
5P0000060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0403Ogml0IVIV06UY
J@1aLG40KVi^075aL@1SHf<0Jf][075aL@1[Jf/0L71`06UYJ@1XJ6P0JVYZ075aL@1`L70206m_K`07
06e]K@1aLG40KVi^06a/K01YJFT0Jf][06YZJP0207AdM00D071`L01^KVh0L71`07=cL`1_Kfl0MWIf
075aL@1dM7@0MWIf071`L01eMGD0KVi^079bLP1`L700KFe]07=cL`1kNg/0Lg=c075aL@1eMGD207em
O@80Ng]k00@0MGEe08B4Q01nOWh0OGem0P1fMWH01`1dM7@0NWYj07inOP21PH40OWin07EeM@1hN7P0
0P1iNGT02P1jNWX0Ng]k0820P01nOWh0PH6108:2PP1oOgl0PH6108J6QP1oOgl208B4Q00>08J6QP24
Q8@0P8200861P@1mOGd0O7al08B4Q029RHT0QXJ608b<S02DU9@0Shn?08^;R`2>SXh2092@T00F08V9
R@2>SXh0Rh^;08n?S`2@T900UIFE09:BTP2IVIT0TY:B08j>SP2EUID0TI6A09>CT`2PX:00WYjN09>C
T`2LW9`0V9RH09JFUP2UYJD0VIVI09bLW080XJ6Q00/0WYjN09^KV`2TY:@0ZJVY0::RXP2LW9`0Vi^K
0:>SX`2RXZ80YJFU0:BTY0020:JVYP0D0:FUY@2[Zj/0ZJVY0:VYZ@2MWId0Y:BT0;2`/02VYZH0[Jf]
0:VYZ@2XZ:P0XJ6Q0:RXZ02PX:00Xj>S0:n_[`2/[:`0YJFU0:6QX@2PX:020:>SX`0H0:BTY02RXZ80
Y:BT0:RXZ02NWYh0XZ:R09jNWP2/[:`0WYjN0:>SX`2IVIT0YZJV0:>SX`2KVi/0XJ6Q09RHV02MWId0
VYZJ09JFUP2IVIT0Xj>S09NGU`2TY:@0W9bL0P2HV9P02@2IVIT0UiNG09JFUP2HV9P0UiNG092@T02A
TI40S8b<08f=S@03092@T00409NGU`2<S8`0R8R809BDU080T92@00`0U9BD08b<S026QXH0Rh^;08V9
R@22PX80Q8B407moO`1mOGd0O7al08>3P`1nOWh207YjNP0508F5Q@1fMWH0Ng]k07inOP1iNGT00P1c
Lg<0501oOgl0M7Ad07AdM01dM7@0MWIf06i^KP1aLG40KVi^06e]K@1eMGD0Kfm_075aL@1cLg<0Jf][
06e]K@1VIVH0JFUY06MWI`1TI6@0J6QX0P1/K6`01@1TI6@0IVIV06UYJ@1MGEd0JVYZ0080Jf][00d0
Hf=S06][J`1LG5`0I6AT06IVIP1TI6@0H61P06ATI01QHF40IVIV06EUI@1QHF40IFEU0080GUiN01d0
FUYJ05aLG01LG5`0H61P06IVIP1TI6@0GUiN061PH01KFe/0GUiN05]KF`1QHF40GUiN065QH@1OGel0
I6AT061PH01HF5P0HF5Q059BDP1LG5`0F5QH061PH01MGEd0G5aL05eMG@1KFe/0EUIF05QHF00G0000
00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0E0>WYj@1ZJVX0IfMW06IV
IP1YJFT0J6QX06UYJ@1/K6`0L71`06UYJ@1[Jf/0I6AT075aL@1cLg<0LW9b06i^KP1_Kfl0L71`06i^
KP1`L700JFUY0080L71`0140LW9b06a/K01^KVh0LG5a071`L01bLW80K6a/06i^KP1aLG40M7Ad06i^
KP1aLG40L71`06i^KP1aLG40Lg=c06i^KP02071`L00P075aL@1fMWH0MWIf075aL@1cLg<0LG5a07Mg
M`1hN7P0NWYj07]kN`1iNGT0M7Ad07IfMP1kNg/0NWYj07UiN@22PX80P82007IfMP1jNWX0O7al0820
P01jNWX0O7al07inOP20P800NGUi07AdM01mOGd0PH6108J6QP23Ph<208V9R@80QhN700D0OGem08>3
P`21PH40Ph>308J6QP0208>3P`80RHV900h0QHF5092@T02?Shl0TY:B08Z:RP2;Rh/0SHf=08V9R@2>
SXh0Ti>C09:BTP2<S8`0Vi^K092@T080S8b<00h0TY:B09NGU`2ATI40Ti>C09BDU02NWYh0WIfM09JF
UP2DU9@0W9bL09VIV@2MWId0X:2P0:>SX`80WinO01@0V9RH09^KV`2GUiL0Xj>S09jNWP2IVIT0WIfM
09^KV`2SXj<0ZJVY0:>SX`2QXJ40YJFU0:>SX`2MWId0Xj>S0:ZZZP2SXj<0WYjN0::RXP80Y:BT01@0
Xj>S0:BTY02ZZZX0Y:BT0:RXZ02ZZZX0X:2P0:JVYP2QXJ40YZJV09jNWP2TY:@0XZ:R0:RXZ02KVi/0
WYjN0:JVYP2TY:@0WYjN0:JVYP80X:2P00T0XJ6Q09bLW02FUYH0VIVI09^KV`2MWId0Vi^K09jNWP2H
V9P00P2LW9`0102JVYX0Rh^;09ZJVP2IVIT309JFUP0k09FEU@2ATI40Shn?096AT@2GUiL0Ti>C09BD
U02ATI40TY:B08B4Q02<S8`0SHf=096AT@2>SXh0QXJ6092@T029RHT0Rh^;08>3P`2:RXX0QHF50861
P@22PX80P82007inOP21PH40Ogmo0820P01fMWH0NWYj07QhN01fMWH0M7Ad07UiN@1eMGD0Lg=c071`
L01iNGT0MgMg07AdM01fMWH0L71`06i^KP1`L700JVYZ075aL@1XJ6P0LW9b071`L01^KVh0K6a/06MW
I`1]KFd0J6QX06a/K01fMWH0IVIV06QXJ01WIfL00P1XJ6P206UYJ@0<06EUI@1TI6@0IFEU06=SH`1[
Jf/0FEUI06IVIP1TI6@0IVIV06ATI01YJFT0GemO0P1TI6@02`1SHf<0G5aL05mOG`1MGEd0HF5Q05UI
F@1KFe/0GUiN065QH@1PH600I6AT0080HF5Q0140I6AT05QHF01PH600G5aL05iNGP1LG5`0HF5Q05eM
G@1KFe/0HF5Q05UIF@1LG5`0Fe]K05QHF01IFET0EeMG05IFEP0205QHF00304m?C`000000000001D0
00001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00T0hn?S06][J`1/K6`0
K6a/06MWI`1_Kfl0IVIV06][J`1YJFT00P1`L7002@1bLW80Lg=c07EeM@1hN7P0KFe]07AdM01fMWH0
M7Ad06YZJP0206UYJ@0]06e]K@1ZJVX0LW9b06e]K@1eMGD0L71`075aL@1`L700LG5a06m_K`1^KVh0
L71`06i^KP1aLG40JVYZ06][J`1cLg<0MGEe071`L01]KFd0M7Ad079bLP1jNWX0OWin079bLP1nOWh0
NGUi07AdM01mOGd0M7Ad07QhN01eMGD0NGUi07QhN01gMgL0NGUi07inOP1iNGT0N7Qh07alO01kNg/0
NWYj07emO@1jNWX0Ng]k0080OWin01H0O7al0820P01iNGT0Ogmo08R8R01hN7P0Ph>307inOP25QHD0
QhN70861P@29RHT0MGEe08B4Q022PX80P82008:2PP27QhL0QXJ60861P@2;Rh/0Shn?0P29RHT06P2@
T900TY:B08j>SP2@T900SXj>096AT@2=SHd0UYJF08f=S@2BTY80T92@08j>SP2IVIT0U9BD09FEU@2F
UYH0W9bL09^KV`2GUiL0WIfM09VIV@2HV9P0WIfM09jNWP2ATI40W9bL0P2QXJ40102KVi/0WYjN0:ZZ
ZP2PX:0209bLW00:0:6QX@2JVYX0WYjN0:6QX@2WYjL0WinO0:BTY02KVi/0XJ6Q0:BTY0<0X:2P00@0
VYZJ0:>SX`2XZ:P0XJ6Q0P2TY:@04`2LW9`0WYjN0:2PX02QXJ40X:2P0:^[Z`2OWil0Vi^K09JFUP2T
Y:@0W9bL0:JVYP2RXZ80W9bL0:FUY@2SXj<0Y:BT0:6QX@2BTY800P2KVi/0102IVIT0WYjN09^KV`2P
X:0209^KV`0R09fMW@2HV9P0Vi^K09>CT`2GUiL0Ti>C09BDU02BTY80UYJF09>CT`2ATI40SHf=09BD
U02BTY80T92@08j>SP26QXH0R8R808J6QP22PX80Q8B408^;R`2@T900RXZ:08F5Q@24Q8@0Ph>307in
OP25QHD0OWin0861P@1lO7`0Ph>307alO080P82000H0O7al07YjNP1cLg<0Lg=c07IfMP1eMGD207Yj
NP0307]kN`1cLg<0MgMg0080LW9b0P1iNGT03P1]KFd0LW9b06][J`1cLg<0KVi^07EeM@1_Kfl0HV9R
06MWI`1XJ6P0IfMW06a/K01_Kfl0IVIV0`1XJ6P01`1[Jf/0JFUY06IVIP1/K6`0IfMW061PH01XJ6P0
0P1VIVH206=SH`0Q065QH@1TI6@0Fe]K06IVIP1SHf<0IFEU06ATI01IFET0Hf=S05aLG01QHF40G5aL
06=SH`1IFET0FUYJ06=SH`1XJ6P0G5aL061PH01MGEd0G5aL06=SH`1QHF40EeMG05eMG@1JFUX0GUiN
06ATI01MGEd0FUYJ05]KF`1PH600G5aL0080Fe]K00@0DE5A05ADE01HF5P0EUIF5`0000060=WIf@40
00000@3IfMT001H0fMWI0P0000040=WIf@0/0>?Sh`1QHF40K6a/06UYJ@1_Kfl0I6AT07UiN@1/K6`0
KVi^07=cL`1aLG40MGEe07AdM01oOgl0O7al08:2PP1kNg/0M7Ad071`L01^KVh0J6QX06MWI`1YJFT0
K6a/071`L01/K6`0JFUY06m_K`1^KVh0MGEe06i^KP1]KFd0LG5a07MgM`1_Kfl0LW9b06m_K`1dM7@0
L71`07EeM@1bLW80O7al075aL@1`L70207alO00707AdM01iNGT0NGUi07]kN`1mOGd0NGUi071`L002
07MgM`0/07IfMP1dM7@0OGem07inOP1hN7P0Q8B407=cL`1kNg/0NWYj07UiN@1lO7`0MGEe0820P01i
NGT0Ph>307QhN01iNGT0Ogmo08>3P`1nOWh0O7al0861P@20P800MGEe07YjNP22PX80Ph>308F5Q@21
PH40Ogmo08:2PP23Ph<0Ogmo0861P@24Q8@0SXj>08^;R`2?Shl0QhN708f=S@2?Shl0UIFE08b<S028
R8P2096AT@0=09:BTP26QXH0TI6A09>CT`2@T900UiNG09BDU02JVYX0Ti>C09:BTP2HV9P0U9BD09FE
U@0209bLW00709nOW`2NWYh0XZ:R09fMW@2IVIT0X:2P09fMW@020:2PX00g0::RXP2SXj<0WIfM0:>S
X`2LW9`0X:2P0:JVYP2SXj<0XZ:R0:2PX02TY:@0XJ6Q0:BTY02PX:00Y:BT0:FUY@2TY:@0X:2P0:>S
X`2XZ:P0WYjN0:BTY02QXJ40Y:BT0:6QX@2MWId0Xj>S0::RXP2JVYX0UiNG09JFUP2LW9`0VIVI0:2P
X02NWYh0YJFU0:2PX02VYZH0V9RH0:2PX02KVi/0TY:B09VIV@2@T900Vi^K09RHV02IVIT0WIfM09JF
UP2IVIT0Shn?09:BTP2IVIT0VYZJ08j>SP02092@T00H09>CT`2:RXX0TI6A096AT@2=SHd0S8b<08f=
S@2<S8`0RHV908N7Q`21PH40R8R808b<S027QhL0QHF508B4Q029RHT0Ph>308J6QP23Ph<0PX:208J6
QP1iNGT0N7Qh0`1lO7`04P21PH40Ng]k07]kN`1^KVh0Ng]k07UiN@1dM7@0NGUi07EeM@1/K6`0N7Qh
075aL@1^KVh0JFUY06m_K`1aLG40Jf][07AdM080KVi^02T0LG5a06i^KP1ZJVX0Jf][06a/K01[Jf/0
I6AT06a/K01UIFD0IVIV06YZJP1cLg<0IVIV06MWI`1UIFD0I6AT06QXJ01SHf<0JFUY05eMG@1VIVH0
HV9R05mOG`1TI6@0JFUY06IVIP1UIFD0Fe]K05eMG@1VIVH0Hf=S05QHF01KFe/0GemO05aLG01NGUh0
Hf=S061PH01CDe<0F5QH05aLG002061PH00C05]KF`1FEUH0J6QX05mOG`1MGEd0H61P05QHF01JFUX0
GEeM05aLG01MGEd0F5QH05iNGP1KFe/0De=C05QHF01LG5`0EUIF051@D00G000000D0fMWI0P000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0;0>7Qh@1@D500J6QX06a/K01`L700JVYZ06QX
J01WIfL0Kfm_07EeM@1dM7@00P28R8P00`2IVIT0Z:RX09bLW00208>3P`03079bLP1dM7@0IVIV0080
JVYZ00@0N7Qh06i^KP1/K6`0KVi^0`1cLg<01P1]KFd0Kfm_07=cL`1[Jf/0MWIf07=cL`80KVi^0P1a
LG405P1iNGT0Lg=c075aL@1lO7`0LW9b07QhN01aLG40NGUi07EeM@1nOWh0N7Qh07AdM01iNGT0LW9b
07MgM`1jNWX0MgMg07QhN01jNWX0LG5a07IfMP1iNGT207AdM00307UiN@20P800N7Qh0080Ng]k01h0
P82008J6QP1fMWH0Ph>307alO025QHD0Ogmo07QhN01fMWH0Ng]k0820P026QXH0PH6108N7Q`23Ph<0
RHV90861P@23Ph<0PH6108N7Q`2;Rh/0TI6A08R8R02;Rh/0TI6A08B4Q02@T900TY:B08R8R029RHT2
08f=S@08096AT@2?Shl0QXJ608j>SP2;Rh/0Ti>C08^;R`2>SXh209>CT`0609:BTP2FUYH0U9BD09VI
V@2QXJ40V9RH0P2IVIT00`2QXJ40UYJF0:6QX@020:6QX@0709VIV@2KVi/0VIVI09bLW02SXj<0W9bL
09fMW@0209jNWP0A0:6QX@2MWId0VIVI0:JVYP2MWId0W9bL09jNWP2LW9`0X:2P0:>SX`2IVIT0[:b/
09bLW02KVi/0XZ:R0:6QX@2MWId00P2KVi/209jNWP0P09NGU`2PX:00VYZJ09^KV`2QXJ40UYJF092@
T02FUYH0Vi^K09RHV02LW9`0WinO09VIV@2DU9@0WYjN09^KV`2DU9@0XJ6Q09JFUP2CTi<0UYJF09BD
U02@T900Ti>C096AT@2@T900RHV908b<S02>SXh0S8b<08j>SP28R8P208n?S`0;08^;R`27QhL0RXZ:
08:2PP2;Rh/0S8b<08J6QP21PH40QHF508N7Q`20P8000P21PH409024Q8@0Ng]k07inOP22PX80Ogmo
07=cL`1nOWh0OGem08>3P`1hN7P0O7al07MgM`1dM7@0LG5a07QhN01eMGD0LG5a07QhN01eMGD0Kfm_
06QXJ01cLg<0KFe]06m_K`1]KFd0Jf][06UYJ@1`L700K6a/06i^KP1ZJVX0Jf][06i^KP1bLW80JFUY
06EUI@80IVIV0100Hf=S05mOG`1/K6`0JFUY06][J`1RHV80Kfm_06QXJ01WIfL0HF5Q06ATI01LG5`0
HF5Q06MWI`1VIVH0J6QX0P1PH600101LG5`0Hf=S05mOG`1NGUh2061PH00:05iNGP1LG5`0EeMG065Q
H@1PH600FUYJ05]KF`1LG5`0Fe]K06ATI080Fe]K0100H61P05]KF`1KFe/0HV9R05UIF@1QHF40EUIF
05QHF01FEUH0EEEE05]KF`1IFET0GUiN05EEE@1KFe/0E5AD5`0000060=WIf@4000000@3IfMT001H0
fMWI00<000000=WIf@3IfMT00`3IfMT01P3YjNT0JFUY06a/K01ZJVX0IVIV06][J`80KVi^00H0JFUY
07]kN`22PX80VYZJ0;Bd]03alO420?ooo`0;0<30`02QXJ40OWin07AdM01`L700LG5a06EUI@1VIVH0
J6QX06][J`1^KVh00P1`L7005`1^KVh0LW9b071`L01dM7@0JFUY075aL@1^KVh0N7Qh071`L01^KVh0
N7Qh06a/K01fMWH0Kfm_07=cL`1hN7P0NGUi07=cL`1eMGD0LG5a07EeM@1nOWh0OGem0080MWIf0P1k
Ng/01`1iNGT0LG5a07moO`1dM7@0NGUi07QhN01dM7@00P1cLg<207]kN`0>07AdM01eMGD0Ng]k07Ui
N@1nOWh0PH6108>3P`24Q8@0OWin07YjNP1kNg/0OWin07alO01kNg/208B4Q00O08N7Q`1mOGd0O7al
07inOP1lO7`0Ng]k08V9R@2@T900SXj>08R8R02<S8`0Rh^;08Z:RP2@T900RXZ:08V9R@26QXH0RHV9
08^;R`2BTY80QhN708^;R`2EUID0Ti>C08j>SP2ATI40UYJF09BDU02LW9`0TI6A09FEU@0209BDU00=
09VIV@2LW9`0Vi^K09jNWP2ATI40V9RH09VIV@2CTi<0Y:BT09bLW02MWId0WinO09RHV00209^KV`0?
09RHV02FUYH0VYZJ09VIV@2OWil0YjNW09bLW02RXZ80WinO09^KV`2QXJ40X:2P09bLW02VYZH0VIVI
0080W9bL01@0WinO09jNWP2IVIT0VYZJ09jNWP2TY:@0W9bL09nOW`2DU9@0WIfM09^KV`2ATI40U9BD
09bLW02NWYh0UIFE09RHV02IVIT0Ti>C092@T080V9RH01P0VIVI09bLW02CTi<0SHf=09JFUP2KVi/0
SXj>096AT@2<S8`0Shn?09:BTP2:RXX0U9BD08^;R`2<S8`0TI6A092@T027QhL0R8R808^;R`28R8P0
Rh^;08F5Q@2<S8`208^;R`0K08F5Q@1kNg/0PH6107inOP1lO7`0PH6107moO`20P800Q8B407UiN@1_
Kfl0Ng]k07moO`1kNg/0N7Qh07IfMP1nOWh0Lg=c075aL@1eMGD0MgMg07IfMP1bLW80MGEe075aL@1c
Lg<0L71`0080KVi^00d0L71`06QXJ01]KFd0L71`06IVIP1UIFD0L71`06QXJ01aLG40JFUY06EUI@1Y
JFT0K6a/0080JFUY0100HV9R06MWI`1YJFT0Jf][06QXJ01OGel0I6AT065QH@1UIFD0Fe]K06EUI@1Y
JFT0J6QX069RHP1PH600G5aL0`1XJ6P0101OGel0Hf=S06IVIP1QHF4205iNGP0B05]KF`1QHF40F5QH
05iNGP1VIVH0GUiN061PH01RHV80Hf=S05EEE@1NGUh0G5aL05UIF@1PH600GEeM05aLG01NGUh0G5aL
0P1KFe/01P1HF5P0De=C05UIF@1GEeL0FEUI05EEEAL000001P3IfMT100000040fMWI000F0=WIf@03
0000003IfMT0fMWI00<0fMWI00d0hN7Q06QXJ01VIVH0JFUY06i^KP1[Jf/0KVi^07QhN01`L700NGUi
09^KV`3@d=00o?cl00@0oooo01L0`l?308N7Q`1lO7`0LG5a06e]K@1bLW80KVi^079bLP1XJ6P0LW9b
06UYJ@1ZJVX0Jf][06e]K@1aLG40JFUY071`L01[Jf/0M7Ad07=cL`1^KVh0Kfm_071`L002075aL@0@
07AdM01`L700Kfm_07]kN`1aLG40N7Qh07=cL`1iNGT0N7Qh07MgM`1fMWH0NWYj07AdM01lO7`0NGUi
07IfMP80MGEe00L0MgMg07]kN`1hN7P0OWin07=cL`1kNg/0NGUi0080O7al00`0NWYj0820P020P800
Q8B407UiN@29RHT0M7Ad07alO020P800O7al07YjNP1kNg/307alO00308:2PP20P800Q8B40080Ph>3
00T0QhN708R8R024Q8@0TY:B08R8R026QXH0Rh^;08V9R@24Q8@00P28R8P08026QXH0SXj>08f=S@2A
TI40R8R808Z:RP2?Shl0TI6A08^;R`2@T900Ti>C09BDU02ATI40V9RH08j>SP2JVYX0UiNG09^KV`2D
U9@0X:2P09VIV@2HV9P0WinO09ZJVP2KVi/0XJ6Q09NGU`2LW9`0UYJF09RHV02KVi/0Xj>S0P2LW9`0
B@2OWil0Vi^K09VIV@2LW9`0V9RH09ZJVP2SXj<0V9RH09ZJVP2MWId0VIVI09RHV02KVi/0UIFE08j>
SP2KVi/0XZ:R09>CT`2NWYh0W9bL09JFUP2OWil0UYJF09^KV`2NWYh0Vi^K09ZJVP2@T900VIVI096A
T@2CTi<0UIFE09>CT`2FUYH0V9RH09JFUP2HV9P0T92@09JFUP2HV9P0UiNG08b<S02@T900SXj>08R8
R029RHT0Rh^;08b<S02@T900TI6A092@T028R8P0Rh^;09BDU02:RXX0R8R808^;R`29RHT0Q8B40820
P024Q8@0Ph>307alO023Ph<0Q8B40820P024Q8@0O7al08J6QP1kNg/0NGUi0820P01nOWh00P1iNGT0
2020P800M7Ad07=cL`1hN7P0Ng]k07AdM01bLW80M7Ad0`1^KVh04@1YJFT0KFe]06YZJP1aLG40JFUY
06a/K01aLG40Jf][06IVIP1/K6`0J6QX06MWI`1UIFD0I6AT06EUI@1VIVH0HV9R0080I6AT00L0IFEU
06IVIP1PH600IVIV06ATI01LG5`0I6AT0080IVIV02/0HV9R05iNGP1VIVH0HF5Q061PH01XJ6P0Hf=S
061PH01QHF40K6a/069RHP1SHf<0G5aL06=SH`1PH600HF5Q05UIF@1SHf<0Fe]K061PH01TI6@0Fe]K
06IVIP1SHf<0GemO05eMG@1LG5`0GEeM065QH@1HF5P0HF5Q05]KF`1DE5@0EeMG05iNGP1FEUH0FEUI
059BDP1FEUH0G5aL05=CD`1ADE40EEEE01L000001P3IfMT100000040fMWI000F0=WIf@030000003I
fMT0fMWI00<0fMWI00/0h>3P06EUI@1SHf<0JFUY06a/K01YJFT0KVi^06YZJP1fMWH0PH610:RXZ006
0?ooo`080=GEe@2=SHd0Kfm_07AdM01]KFd0KVi^06m_K`1bLW82071`L009079bLP1YJFT0JVYZ07Ad
M01/K6`0L71`07QhN01[Jf/0L71`0080M7Ad00D0L71`06a/K01aLG40LW9b07IfMP0207AdM00A07Ee
M@1dM7@0LG5a07QhN01lO7`0LG5a07]kN`1iNGT0Ng]k07IfMP1iNGT0MWIf07AdM01aLG40N7Qh08N7
Q`1bLW800P1iNGT02@1gMgL0LG5a07QhN01cLg<0NGUi07moO`1jNWX0O7al07emO@0208B4Q00?08:2
PP1cLg<0N7Qh07inOP1lO7`0Ph>307inOP20P800O7al07inOP1hN7P0NWYj07alO020P800QhN70080
RHV900H0Q8B408J6QP2;Rh/0T92@08V9R@2;Rh/208V9R@80QXJ600l0Rh^;08Z:RP24Q8@0RXZ:09BD
U02@T900UYJF08b<S02HV9P0U9BD09VIV@2ATI40UiNG09:BTP2DU9@00P2IVIT06`2DU9@0UIFE09NG
U`2BTY80WYjN09^KV`2PX:00VIVI09^KV`2JVYX0WIfM08n?S`2FUYH0Vi^K09VIV@2HV9P0Vi^K09FE
U@2>SXh0UIFE09^KV`2MWId0V9RH096AT@2KVi/0UiNG09BDU00209^KV`0A09jNWP2HV9P0V9RH09:B
TP2LW9`0VIVI09RHV02IVIT0T92@09VIV@2DU9@0UYJF09bLW02JVYX0UYJF09bLW02ATI400P2<S8`0
2P2DU9@0T92@09JFUP2IVIT0SXj>096AT@2CTi<0TI6A08n?S`2ATI4208V9R@80QhN700/0Rh^;08f=
S@2>SXh0Rh^;08f=S@24Q8@0SXj>08F5Q@23Ph<0T92@08B4Q00208F5Q@0K08B4Q022PX80QHF507]k
N`23Ph<0PH6108J6QP23Ph<0MWIf07MgM`1jNWX0P82007alO01cLg<0OWin07]kN`1fMWH0MGEe079b
LP1gMgL0Lg=c07UiN@1mOGd0Ng]k07AdM01_Kfl0L71`0080KFe]01H0N7Qh075aL@1XJ6P0K6a/06YZ
JP1[Jf/0J6QX06UYJ@1UIFD0IVIV065QH@1YJFT0Hf=S06QXJ01ZJVX0KVi^06UYJ@1QHF40HV9R065Q
H@1RHV80Hf=S0P1UIFD01@1NGUh0Hf=S05]KF`1OGel0IfMW0080HF5Q00T0I6AT061PH01PH600H61P
05iNGP1MGEd0H61P065QH@1PH6000P1LG5`02@1PH600EUIF05]KF`1NGUh0G5aL065QH@1UIFD0GemO
06=SH`0205eMG@0605aLG01NGUh0GUiN05aLG01PH600FUYJ0P1PH6001`1LG5`0FEUI05UIF@1FEUH0
FEUI05IFEP1ADE405`0000060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0
1`3Ng]h0J6QX06MWI`1WIfL0K6a/071`L01YJFT00P1eMGD00`21PH40/;2`0?ooo`050?ooo`0>0<c<
c026QXH0N7Qh071`L01/K6`0KVi^071`L01^KVh0JFUY06i^KP1[Jf/0KVi^06IVIP1ZJVX2075aL@80
Jf][00P0LG5a071`L01cLg<0KFe]07AdM01cLg<0LG5a06i^KP80M7Ad0100NWYj079bLP1bLW80OWin
07YjNP1cLg<0N7Qh079bLP1gMgL0Ng]k07EeM@1aLG40MGEe07]kN`1lO7`0Ng]k0P1iNGT01@23Ph<0
MWIf07moO`1kNg/0MgMg0080NGUi0140O7al0861P@20P800PH6107inOP21PH40NWYj07UiN@1mOGd0
O7al08B4Q026QXH0OWin08>3P`21PH40OGem07moO`020820P080QXJ600h0Shn?08B4Q021PH40QXJ6
08B4Q027QhL0Rh^;08N7Q`23Ph<0QhN708f=S@2;Rh/0PH61079bLP80Rh^;0P2<S8`01@2BTY80Ti>C
09JFUP2HV9P0Ti>C0080TI6A00@0T92@09BDU02LW9`0W9bL0P2IVIT01@2FUYH0U9BD09JFUP2KVi/0
UIFE0080U9BD00P0V9RH096AT@2GUiL0UYJF09FEU@2GUiL0UYJF09NGU`80Vi^K00P0TI6A08n?S`2I
VIT0UiNG09bLW02GUiL0W9bL096AT@@0V9RH00H0RHV909>CT`2IVIT0UiNG08^;R`2IVIT209JFUP0@
09BDU029RHT0Shn?09:BTP2@T900UYJF09VIV@2>SXh0VYZJ09^KV`2>SXh0UIFE09RHV02<S8`0TI6A
09>CT`80TI6A00`0Shn?08R8R02;Rh/0S8b<08Z:RP21PH40Shn?08J6QP25QHD0Ti>C0861P@2<S8`3
08J6QP0908R8R025QHD0PH6108:2PP1kNg/0Ogmo07inOP1oOgl0MWIf0080O7al0P1hN7P207AdM00D
07inOP1kNg/0M7Ad07=cL`1WIfL0MWIf07AdM01^KVh0N7Qh07moO`1gMgL0LG5a07AdM01fMWH0J6QX
071`L01dM7@0KVi^06m_K`1/K6`206QXJ00506a/K01VIVH0Jf][06][J`1PH6000P1VIVH0301/K6`0
IFEU06ATI01]KFd0JFUY06YZJP1QHF40IVIV06ATI01XJ6P0GUiN06ATI080Hf=S00T0J6QX06ATI01Q
HF40Hf=S065QH@1NGUh0Fe]K05aLG01MGEd00P1QHF401`1MGEd0Fe]K05aLG01TI6@0FEUI05]KF`1L
G5`00P1OGel01@1QHF40Fe]K061PH01MGEd0GUiN0080Fe]K00h0H61P05]KF`1PH600HF5Q05aLG01N
GUh0GemO05iNGP1KFe/0FUYJ05UIF@1KFe/0E5AD05]KFaL000001P3IfMT100000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI00/0i^KV06UYJ@1XJ6P0I6AT075aL@1WIfL0N7Qh075aL@1kNg/0
R8R80;Fe]@050?ooo`090<W9b@2TY:@0R8R806e]K@1/K6`0Jf][06m_K`1^KVh0Kfm_0080K6a/00L0
KVi^06][J`1aLG40JVYZ075aL@1/K6`0KFe]0080Jf][00H0KVi^06a/K01^KVh0L71`06i^KP1ZJVX2
079bLP06071`L01iNGT0LG5a06m_K`1fMWH0LW9b0P1dM7@02`1hN7P0MWIf07EeM@1gMgL0N7Qh07Ui
N@1nOWh0MgMg07]kN`1hN7P0MgMg0080MWIf00h0N7Qh07moO`1hN7P0M7Ad07]kN`1fMWH0PX:207Ui
N@20P800NGUi07inOP1fMWH0N7Qh07IfMP80OWin00D0PH6108>3P`20P800OWin07UiN@0207inOP0E
08B4Q023Ph<0RHV908V9R@21PH40P82008R8R027QhL0Rh^;08B4Q025QHD0QXJ607alO02BTY80Q8B4
08N7Q`23Ph<0RXZ:096AT@24Q8@0RXZ:0080Ti>C00T0TI6A09JFUP2FUYH0V9RH09JFUP2;Rh/0U9BD
09:BTP2DU9@00P2HV9P01P2PX:00VIVI09RHV02IVIT0U9BD08n?S`80UIFE00d0Vi^K0:>SX`2DU9@0
V9RH09NGU`2ATI40T92@096AT@2LW9`0Vi^K09ZJVP2FUYH0SXj>0080T92@00@0UIFE09>CT`2DU9@0
UIFE0P2FUYH01@2KVi/0UYJF09JFUP2MWId0V9RH0080UYJF00H0VIVI09BDU02DU9@0U9BD08f=S@2D
U9@308j>SP0D096AT@2CTi<0Shn?09>CT`2ATI40RXZ:092@T026QXH0R8R808f=S@2>SXh0R8R808j>
SP2<S8`0T92@08n?S`1oOgl0SXj>092@T026QXH408B4Q0050861P@1kNg/0Ph>307alO01iNGT00P1n
OWh01@1kNg/0P8200820P022PX80MWIf0080N7Qh02L0OGem07IfMP1jNWX0MWIf07EeM@1fMWH0NWYj
07QhN01_Kfl0Ng]k07UiN@1`L700KVi^06a/K01_Kfl0Jf][06e]K@1dM7@0Jf][07QhN01]KFd0J6QX
06EUI@1^KVh0Jf][06UYJ@1VIVH0G5aL06ATI01VIVH0IFEU06ATI01UIFD0Jf][06UYJ@1XJ6P0JFUY
061PH01VIVH00P1PH60206UYJ@0[05eMG@1PH600H61P06=SH`1NGUh0IVIV061PH01TI6@0G5aL069R
HP1QHF40HV9R065QH@1TI6@0IFEU05iNGP1LG5`0I6AT05YJFP1HF5P0HF5Q061PH01QHF40H61P05EE
E@1NGUh0FEUI05EEE@1PH600HV9R05iNGP1PH600GEeM05iNGP1MGEd0EUIF05UIF@1OGel0GEeM059B
DP1CDe<0EUIF05=CD`0G000000H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WI
f@0;0=KFeP1TI6@0HF5Q06i^KP1/K6`0JFUY06][J`1^KVh0LG5a07QhN02UYJD0103oool06`3hn?P0
VIVI08R8R01kNg/0N7Qh06UYJ@1_Kfl0L71`06UYJ@1bLW80KVi^06UYJ@1[Jf/0KVi^06e]K@1ZJVX0
KFe]06QXJ01/K6`0Jf][06a/K01hN7P0KVi^071`L01_Kfl0L71`06i^KP02075aL@0906i^KP1bLW80
Lg=c075aL@1bLW80MGEe07IfMP1dM7@0Ng]k00<0L71`0180LG5a07MgM`1mOGd0Ph>307MgM`1hN7P0
NGUi07AdM01`L700M7Ad07]kN`1iNGT0OGem07alO01eMGD0N7Qh0820P022PX8307YjNP0Q07UiN@1h
N7P0M7Ad07IfMP1kNg/0O7al07YjNP1kNg/0O7al07UiN@1nOWh0Ph>308N7Q`28R8P0RHV908F5Q@2<
S8`0O7al08R8R024Q8@0RHV908B4Q02:RXX0S8b<08^;R`2@T900QXJ60820P027QhL0RHV908R8R02<
S8`0TI6A0080T92@00/0U9BD096AT@2BTY80SXj>09RHV02BTY80V9RH09JFUP2<S8`0V9RH09NGU`02
09>CT`0309VIV@2BTY80TI6A0080T92@00T0U9BD08j>SP2FUYH0UiNG09BDU02HV9P0TY:B096AT@2K
Vi/00P2DU9@01@2>SXh0U9BD09ZJVP2IVIT0Shn?0080UYJF00D0Vi^K08j>SP2CTi<0V9RH09BDU002
09JFUP0509RHV02CTi<0UYJF09BDU02CTi<00P2>SXh05P2@T900TY:B092@T02?Shl0SXj>092@T02>
SXh0Shn?09BDU027QhL0Ti>C092@T028R8P0T92@08R8R026QXH0R8R808^;R`24Q8@0Rh^;08V9R@2;
Rh/208V9R@0708J6QP27QhL0PH6108V9R@2;Rh/0R8R807]kN`0208R8R00N07inOP22PX80O7al07mo
O`20P800QHF50820P01mOGd0P82007inOP1hN7P0NGUi07AdM01kNg/0MgMg07]kN`1eMGD0NGUi07=c
L`1/K6`0N7Qh07IfMP1_Kfl0M7Ad06a/K01iNGT0K6a/06UYJ@1cLg<0LW9b0P1XJ6P07@1YJFT0L71`
06][J`1WIfL0J6QX06a/K01XJ6P0JFUY06][J`1SHf<0HV9R06IVIP1UIFD0J6QX06UYJ@1RHV80Hf=S
06ATI01NGUh0Fe]K069RHP1VIVH0IFEU06YZJP1NGUh0HV9R06=SH`1TI6@0Hf=S0080H61P0P1TI6@2
05aLG005061PH01MGEd0IVIV061PH01IFET00`1KFe/05@1NGUh0G5aL05UIF@1RHV80G5aL05iNGP1M
GEd0F5QH06ATI01MGEd0HF5Q05aLG01FEUH0Fe]K05UIF@1OGel0FEUI05aLG01IFET0EUIF05QHF00G
000000H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0T0=cLg01ZJVX0IVIV
06][J`1SHf<0Jf][06m_K`1cLg<0LG5a07UiN@2@T900^k^k0=CDe03_knl0d=3@09bLW028R8P0Ng]k
07IfMP1YJFT0JVYZ06=SH`1VIVH0L71`06a/K01YJFT0KFe]06i^KP1ZJVX0KVi^07EeM@1`L700Jf][
06a/K01WIfL0LG5a0P1^KVh04`1eMGD0Lg=c079bLP1hN7P0LG5a07IfMP1^KVh0Jf][071`L01iNGT0
Lg=c06i^KP1lO7`0N7Qh07IfMP1eMGD0MWIf07MgM`1iNGT00P1kNg/01`23Ph<0MWIf07]kN`1lO7`0
OWin079bLP1cLg<00P1iNGT01`1cLg<0NGUi07emO@1lO7`0OWin07alO01oOgl00P1iNGT0101hN7P0
NGUi07inOP1oOgl307inOP060861P@1kNg/0OWin07IfMP23Ph<0PH610P28R8P01`29RHT0PX:208N7
Q`23Ph<0OWin08>3P`1nOWh00P25QHD0F@2BTY80SXj>08Z:RP2ATI40RXZ:08^;R`2>SXh0R8R808^;
R`2=SHd0U9BD096AT@2EUID0TI6A08j>SP2=SHd0TI6A09JFUP2CTi<0VIVI09bLW02MWId0SXj>09>C
T`2DU9@0Ti>C092@T02FUYH0U9BD092@T02FUYH0V9RH09>CT`2HV9P0TI6A09VIV@2@T900Ti>C08b<
S02=SHd0TY:B08j>SP2FUYH0TI6A09BDU02GUiL0V9RH08^;R`2ATI40U9BD08b<S02FUYH0S8b<09^K
V`2DU9@0TI6A092@T02>SXh0TI6A09>CT`2<S8`0T92@09FEU@2KVi/0S8b<08j>SP2;Rh/0TY:B09NG
U`2>SXh0Q8B408V9R@2;Rh/0QHF508J6QP2<S8`0P82008N7Q`22PX80R8R808b<S024Q8@0PH6108R8
R029RHT0OWin08J6QP21PH40RHV90080Ph>301X0PH610820P021PH40Ng]k0820P01kNg/0N7Qh08>3
P`1nOWh0PH6107UiN@1eMGD0N7Qh07AdM01iNGT0N7Qh07UiN@1dM7@0Lg=c07QhN01dM7@0MWIf06i^
KP1cLg<0KVi^075aL@80M7Ad00H0Kfm_071`L01fMWH0IVIV075aL@1QHF4206i^KP0406EUI@1ZJVX0
K6a/06UYJ@80J6QX00`0GemO061PH01MGEd0Hf=S06IVIP1XJ6P0HV9R06QXJ01OGel0H61P06IVIP1N
GUh205aLG006069RHP1MGEd0IVIV069RHP1HF5P0G5aL0P1OGel02P1KFe/0GUiN061PH01NGUh0FEUI
05]KF`1OGel0FUYJ05aLG01OGel205iNGP0?05]KF`1LG5`0HF5Q061PH01LG5`0EUIF05eMG@1NGUh0
FEUI06=SH`1IFET0G5aL05QHF01NGUh0Fe]K0080FEUI00H0EeMG05eMG@1MGEd0E5AD05IFEP1GEeLG
000000H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@040=kNgP1VIVH0IVIV
06QXJ0<0I6AT00`0Jf][06QXJ01lO7`0Q8B409jNWP2YZJT0];Bd0::RXP2?Shl0N7Qh07AdM01fMWH2
06QXJ00P071`L01/K6`0K6a/071`L01YJFT0IFEU06IVIP1^KVh0JVYZ06QXJ01/K6`0L71`06YZJP1c
Lg<0IfMW07QhN01QHF40KVi^06a/K01[Jf/0L71`06m_K`1cLg<0MgMg06i^KP1`L700M7Ad07=cL`1n
OWh0MGEe07AdM01nOWh2075aL@0?07IfMP1hN7P0O7al07inOP1kNg/0NGUi07QhN01cLg<0N7Qh075a
L@1iNGT0OWin07QhN01fMWH0Lg=c00<0NGUi00@0O7al07]kN`1hN7P0N7Qh0`1lO7`0101fMWH0PH61
0820P021PH4207UiN@80OWin00T0PH6108B4Q02<S8`0Ph>308V9R@25QHD0RHV908:2PP2>SXh00P26
QXH06@25QHD0Q8B408:2PP2;Rh/0RXZ:08>3P`2;Rh/0QhN708B4Q028R8P0QXJ608b<S02@T900SXj>
096AT@2FUYH0RHV909BDU02:RXX0T92@09JFUP2@T900SXj>096AT@2OWil00P2CTi<05P2DU9@0UYJF
08n?S`2FUYH0T92@09JFUP2ATI40TY:B08j>SP2ATI40SXj>09>CT`2>SXh0S8b<08j>SP2BTY80Shn?
09:BTP2DU9@0TI6A08b<S02GUiL2096AT@0D08b<S02@T900T92@09JFUP2NWYh0SXj>09BDU02HV9P0
Shn?09BDU02<S8`0SHf=092@T02=SHd0Shn?08Z:RP29RHT0Ti>C08>3P`2=SHd208b<S00=08^;R`27
QhL0Rh^;08f=S@2:RXX0PH6108b<S023Ph<0R8R80820P023Ph<0PH6108N7Q`0208F5Q@060861P@23
Ph<0PX:208B4Q020P800Ogmo0P20P8005P1lO7`0N7Qh07IfMP1lO7`0OGem07QhN01dM7@0MWIf07=c
L`1eMGD0M7Ad07=cL`1ZJVX0MWIf07]kN`1fMWH0OWin07=cL`1bLW80MWIf079bLP1lO7`2075aL@06
07AdM01/K6`0M7Ad06IVIP1XJ6P0Hf=S0P1YJFT06@1XJ6P0IFEU06a/K01/K6`0Kfm_075aL@1^KVh0
IFEU061PH01NGUh0KVi^06YZJP1VIVH0GUiN06ATI01PH600IFEU06IVIP1KFe/0I6AT06EUI@1QHF40
I6AT061PH01MGEd00`1SHf<0901OGel0HF5Q06ATI01JFUX0G5aL05YJFP1LG5`0GUiN05eMG@1GEeL0
Hf=S05QHF01JFUX0Fe]K065QH@1FEUH0GUiN05aLG01HF5P0FEUI05]KF`1TI6@0Fe]K05mOG`1NGUh0
F5QH05=CD`1OGel0G5aL05IFEP1ADE40Fe]K05YJFP1EEED0G5aL051@D1L000001P3IfMT100000040
fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00h0cLg=06IVIP1^KVh0JVYZ06i^KP1[Jf/0JVYZ
06QXJ01`L700Jf][07UiN@1hN7P0PH6105QHF080NGUi0280L71`07=cL`1^KVh0LG5a071`L01YJFT0
LW9b06YZJP1`L700JFUY06a/K01gMgL0LG5a06][J`1^KVh0Jf][071`L01]KFd0Kfm_07AdM01`L700
LG5a06MWI`1^KVh0K6a/07IfMP1^KVh0MGEe079bLP1_Kfl0MWIf06][J`1iNGT0M7Ad0P1fMWH01P1b
LW80L71`07QhN01nOWh0Lg=c075aL@80MWIf0100Lg=c07IfMP1jNWX0LG5a07]kN`1fMWH0M7Ad07Ee
M@1lO7`0NWYj07]kN`1jNWX0O7al0820P01iNGT0N7Qh0P1iNGT207QhN00307]kN`1fMWH0Ng]k0080
NGUi00@0OGem07alO023Ph<0Ng]k0P1lO7`208J6QP0[08N7Q`22PX80Ogmo08V9R@24Q8@0QXJ6092@
T02;Rh/0R8R808J6QP28R8P0T92@08b<S02?Shl0QXJ608B4Q02>SXh0T92@08j>SP2@T900R8R808^;
R`2CTi<0Rh^;08f=S@2BTY80S8b<08^;R`2ATI40TY:B09BDU02=SHd0Rh^;08j>SP2=SHd0RXZ:08f=
S@2ATI40UIFE09ZJVP2FUYH0TY:B096AT@0209RHV00=08^;R`2ATI40U9BD09BDU02:RXX0U9BD092@
T02IVIT0SXj>092@T02<S8`0U9BD08j>SP0309>CT`0;09jNWP2DU9@0SXj>09>CT`2;Rh/0Shn?09^K
V`2;Rh/0U9BD096AT@2BTY800P2=SHd208b<S00408V9R@2;Rh/0P82009BDU080Rh^;00h0R8R808F5
Q@21PH40QXJ608R8R02<S8`0T92@08>3P`27QhL0P82007alO020P800QXJ607emO@80P8200P23Ph<0
4@21PH40N7Qh0820P01iNGT0P82007UiN@1kNg/0Ph>307UiN@1cLg<0M7Ad07YjNP1fMWH0M7Ad07Ee
M@1hN7P0MWIf0080M7Ad00L0Lg=c075aL@1dM7@0MGEe06a/K01`L700N7Qh0080K6a/00<0Kfm_07=c
L`1/K6`00P1YJFT0@@1WIfL0Hf=S06YZJP1WIfL0IVIV075aL@1UIFD0JVYZ06=SH`1VIVH0Hf=S065Q
H@1UIFD0IVIV06ATI01UIFD0JVYZ06QXJ01WIfL0HF5Q06=SH`1TI6@0Hf=S069RHP1TI6@0HV9R061P
H01QHF40Fe]K05eMG@1PH600Hf=S05eMG@1KFe/0HF5Q05aLG01PH600Fe]K065QH@1MGEd0FEUI061P
H01HF5P0H61P05eMG@1LG5`0EEEE05UIF@1NGUh0H61P05UIF@1OGel0H61P05YJFP1IFET0GUiN05=C
D`1FEUH0FEUI05IFEP1JFUX0GUiN05eMG@1HF5P0De=C01L000001P3IfMT100000040fMWI000F0=WI
f@800000103IfMT04`3De=@0Hf=S06EUI@1VIVH0Hf=S06QXJ01ZJVX0JFUY06ATI01^KVh0L71`06e]
K@1cLg<0MWIf06a/K01fMWH0NGUi06IVIP1]KFd00P1^KVh00`1]KFd0K6a/06QXJ002075aL@80J6QX
0P1^KVh04`1[Jf/0J6QX06][J`1YJFT0I6AT071`L01YJFT0M7Ad071`L01/K6`0LW9b07AdM01]KFd0
N7Qh06e]K@1dM7@0Lg=c07AdM01fMWH00P1^KVh05@1fMWH0LG5a07QhN01cLg<0Kfm_079bLP1nOWh0
LW9b07alO01^KVh0N7Qh06i^KP1iNGT0MgMg07=cL`1iNGT0N7Qh07UiN@1hN7P0NWYj07alO00307in
OP0T0861P@1lO7`0MWIf07AdM01eMGD0MgMg07YjNP1mOGd0N7Qh07]kN`21PH40OGem08>3P`20P800
S8b<07emO@29RHT0QXJ608B4Q02;Rh/0PH6108b<S026QXH0RHV908F5Q@26QXH0QhN708R8R02=SHd0
QXJ608Z:RP29RHT0QHF508R8R02DU9@0Q8B40P2@T90208b<S00308^;R`2>SXh0RXZ:00<0SXj>00P0
Shn?092@T02@T900SXj>09:BTP2?Shl0SHf=08b<S080T92@00<0RHV9092@T027QhL00P2>SXh03@2C
Ti<0SXj>09JFUP2;Rh/0SXj>08n?S`2EUID0S8b<09JFUP2;Rh/0TI6A09BDU02CTi<00P2>SXh00`2C
Ti<0S8b<09BDU002092@T00O096AT@25QHD0S8b<092@T027QhL0TI6A08j>SP25QHD0RHV908R8R026
QXH0SXj>08B4Q02;Rh/0SHf=08b<S024Q8@0P82008b<S01oOgl0PH6108R8R021PH40R8R808:2PP23
Ph<0R8R808B4Q023Ph<0OGem0820P00208>3P`0807inOP1cLg<0OWin08>3P`1oOgl0NGUi07emO@1g
MgL207UiN@0308:2PP1dM7@0P8200080OWin00@0NGUi075aL@1jNWX0K6a/0P1cLg<0701eMGD0Ng]k
079bLP1bLW80N7Qh06a/K01fMWH0Kfm_07=cL`1YJFT0MWIf06YZJP1[Jf/0KVi^06m_K`1VIVH0JFUY
05mOG`1YJFT0JVYZ06=SH`1ZJVX0Hf=S06UYJ@1QHF40Hf=S069RHP1TI6@306IVIP0406YZJP1XJ6P0
I6AT06IVIP80GUiN0P1OGel0:P1NGUh0Hf=S06UYJ@1KFe/0HV9R05aLG01NGUh0H61P069RHP1PH600
GEeM05YJFP1NGUh0GemO05iNGP1PH600GUiN069RHP1HF5P0FEUI05EEE@1GEeL0F5QH061PH01IFET0
GemO05]KF`1NGUh0H61P05UIF@1LG5`0GEeM05MGE`1NGUh0EUIF061PH01KFe/0F5QH05UIF@1KFe/0
EEEE05QHF1L000001@3IfMT200000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI01D0g=cL
065QH@1TI6@0IFEU06][J`1bLW80L71`06UYJ@1WIfL0LG5a06e]K@1[Jf/0KVi^06QXJ01`L700Lg=c
06YZJP1`L700KVi^06UYJ@1dM7@00P1VIVH00`1[Jf/0KVi^075aL@0206a/K00@06i^KP1]KFd0Jf][
06UYJ@1]KFd0LG5a07AdM01/K6`0M7Ad06i^KP1XJ6P0L71`075aL@1/K6`0KVi^071`L080KFe]0140
L71`06][J`1hN7P0MWIf079bLP1dM7@0MWIf07AdM01hN7P0L71`079bLP1fMWH0LW9b07QhN01fMWH0
L71`07AdM00207IfMP0<07MgM`20P800MWIf07EeM@1dM7@0NWYj07IfMP1iNGT0O7al07UiN@1nOWh0
N7Qh0P1iNGT0A@1hN7P0O7al07QhN01kNg/0O7al07moO`20P800NGUi08J6QP2;Rh/0PH6108B4Q020
P800Ph>30820P027QhL0RHV908N7Q`29RHT0QHF508R8R021PH40RHV908R8R026QXH0RHV908N7Q`2>
SXh0R8R8092@T02;Rh/0T92@08R8R02?Shl0R8R809BDU02:RXX0T92@08R8R02;Rh/0SXj>09:BTP2?
Shl0U9BD08V9R@2ATI40UIFE08n?S`2ATI40U9BD08^;R`2DU9@0V9RH08^;R`2>SXh0Ti>C08R8R02<
S8`0T92@08^;R`2=SHd0QXJ608b<S025QHD0Ti>C08n?S`29RHT0Shn?092@T00208j>SP<0S8b<00X0
Ti>C08^;R`2@T900SXj>08V9R@26QXH0RHV908^;R`26QXH0RHV90P2ATI4208R8R00708^;R`28R8P0
Shn?08>3P`27QhL0R8R80820P00308N7Q`0W0820P02:RXX0O7al08>3P`28R8P0QhN708J6QP23Ph<0
QXJ608B4Q01jNWX0Ogmo08>3P`21PH40P82007alO01hN7P0OWin0820P01dM7@0MWIf07QhN01aLG40
O7al07UiN@1kNg/0MWIf07]kN`1lO7`0MgMg07=cL`1dM7@0MWIf07AdM01iNGT0M7Ad075aL@1eMGD0
LG5a0080Lg=c00D0L71`075aL@1bLW80Jf][07=cL`02071`L00L06UYJ@1[Jf/0K6a/06YZJP1XJ6P0
H61P06=SH`1WIfL0Fe]K06MWI`1TI6@0J6QX065QH@1VIVH0I6AT06=SH`1JFUX0I6AT075aL@1LG5`0
H61P065QH@1SHf<0IVIV05eMG@1PH600Hf=S05]KF`80HF5Q0140J6QX05aLG01MGEd0Fe]K06ATI01I
FET0HV9R05YJFP1OGel0GEeM05mOG`1NGUh0G5aL069RHP1LG5`0FEUI05eMG@0205aLG00A05IFEP1N
GUh0Fe]K06=SH`1FEUH0Fe]K05UIF@1NGUh0GemO05aLG01IFET0GEeM04m?C`1JFUX0E5AD055AD@1K
Fe/05`0000060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT03@3Fe]H0IfMW
06QXJ01XJ6P0JFUY06QXJ01YJFT0JVYZ06QXJ01[Jf/0H61P06QXJ01/K6`00P1^KVh02P1/K6`0KVi^
06i^KP1XJ6P0Jf][06IVIP1UIFD0Jf][06m_K`1XJ6P206][J`0D079bLP1UIFD0HV9R075aL@1_Kfl0
L71`06a/K01aLG40L71`06i^KP1cLg<0K6a/06][J`1cLg<0KVi^075aL@1`L700IVIV07AdM01WIfL2
07AdM00407UiN@1WIfL0N7Qh07UiN@<0M7Ad0180Lg=c07IfMP1aLG40KVi^07AdM01fMWH0NGUi07Ad
M021PH40MGEe07UiN@1dM7@0Ng]k07IfMP21PH40OGem075aL@1lO7`207IfMP0407YjNP1kNg/0PH61
07moO`80Ng]k0100N7Qh08>3P`1kNg/0Ogmo08>3P`22PX80OWin08>3P`26QXH0PX:208>3P`24Q8@0
Ph>308Z:RP2BTY80Q8B40P26QXH05027QhL0RXZ:0820P02<S8`0PH6108>3P`28R8P0TY:B08V9R@2=
SHd0QhN708n?S`2CTi<0UYJF09BDU026QXH0R8R808n?S`2>SXh0RHV90P2ATI4208n?S`0308j>SP2;
Rh/0T92@0080SXj>0140T92@096AT@2ATI40S8b<08^;R`2CTi<0V9RH08b<S029RHT0T92@08V9R@2C
Ti<0SHf=08^;R`2FUYH0UiNG09>CT`0308j>SP0S092@T02GUiL0Ti>C08b<S029RHT0TY:B09bLW02@
T900S8b<08Z:RP2<S8`0U9BD08^;R`2<S8`0QhN708F5Q@2<S8`0QHF508>3P`27QhL0R8R809:BTP28
R8P0RXZ:08V9R@2;Rh/0Ph>308:2PP25QHD0Ph>307moO`1kNg/0P8200861P@22PX800P1nOWh02P24
Q8@0Ph>30820P01kNg/0PX:20820P01iNGT0P82007IfMP1nOWh207]kN`80NGUi00`0O7al071`L01c
Lg<0MgMg07alO01gMgL0MGEe079bLP1_Kfl0MGEe07UiN@1lO7`2075aL@0A06YZJP1^KVh0LW9b06i^
KP1_Kfl0L71`06YZJP1YJFT0KVi^06UYJ@1^KVh0J6QX06IVIP1SHf<0IfMW06=SH`1PH6000P1VIVH0
6@1WIfL0FUYJ06IVIP1SHf<0JFUY06IVIP1XJ6P0I6AT065QH@1XJ6P0G5aL065QH@1TI6@0Hf=S065Q
H@1PH600I6AT05eMG@1IFET0G5aL061PH01HF5P0IVIV05aLG01OGel00P1NGUh0201HF5P0GUiN05eM
G@1YJFT0I6AT05QHF01RHV80FUYJ0P1KFe/0201IFET0EeMG05]KF`1IFET0GUiN05eMG@1FEUH0GUiN
0P1LG5`01@1KFe/0De=C061PH01LG5`0FEUI0080F5QH00@0FUYJ05UIF@1NGUh0E5AD5`0000060=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT01`3MgMd0GEeM06UYJ@1UIFD0JFUY
069RHP1SHf<00P1XJ6P0?01[Jf/0JFUY06][J`1VIVH0KVi^06MWI`1]KFd0Jf][06YZJP1[Jf/0KVi^
06a/K01WIfL0J6QX06][J`1YJFT0Jf][06i^KP1/K6`0KFe]071`L01UIFD0JVYZ06a/K01ZJVX0LG5a
06MWI`1aLG40KVi^071`L01^KVh0MGEe06i^KP1/K6`0LW9b075aL@1dM7@0L71`06m_K`1^KVh0LG5a
07=cL`1`L700M7Ad07=cL`1eMGD0N7Qh07IfMP1hN7P0MWIf075aL@1`L700Lg=c075aL@1`L700Lg=c
07moO`1fMWH0NGUi07AdM080N7Qh00d0NGUi07=cL`1eMGD0NGUi07]kN`1fMWH0N7Qh07alO01hN7P0
NWYj07AdM01cLg<0O7al0080PH6100h0O7al0861P@20P800Ph>307moO`29RHT0P82008B4Q021PH40
N7Qh08^;R`20P800Q8B408J6QP80QhN702/0Ph>308B4Q023Ph<0R8R808j>SP27QhL0R8R808N7Q`2;
Rh/0TI6A08R8R02>SXh0R8R808V9R@24Q8@0RHV908b<S02=SHd0RHV908f=S@2:RXX0T92@096AT@2;
Rh/0U9BD08b<S028R8P0Ph>308B4Q027QhL0QHF5092@T02;Rh/0T92@08J6QP2:RXX0TI6A08b<S024
Q8@0RHV9096AT@2<S8`0Rh^;0080TI6A01`0RHV9092@T029RHT0R8R808J6QP2>SXh0S8b<092@T02A
TI40Rh^;08V9R@26QXH0SXj>08B4Q023Ph<0RHV908j>SP20P800R8R808F5Q@26QXH0R8R808B4Q022
PX80Q8B408N7Q`28R8P0RHV90P27QhL01P24Q8@0RHV90861P@1oOgl0OWin08:2PP80OGem00`0P820
07YjNP1mOGd0PH6107]kN`21PH40P82007YjNP1kNg/0OGem07UiN@1cLg<207UiN@0@075aL@1`L700
MWIf07alO01hN7P0M7Ad079bLP1iNGT0Lg=c07IfMP1hN7P0M7Ad07QhN01dM7@0Ng]k07AdM080Lg=c
00@0LW9b071`L01]KFd0M7Ad0P1]KFd01`1aLG40Jf][06IVIP1SHf<0IVIV06UYJ@1^KVh00P1NGUh0
4P1WIfL0GUiN06YZJP1[Jf/0Hf=S06][J`1SHf<0IFEU06ATI01ZJVX0GemO06EUI@1ZJVX0HV9R05]K
F`1MGEd0Hf=S069RHP80Fe]K0`1NGUh0201RHV80H61P065QH@1NGUh0Hf=S065QH@1RHV80I6AT0P1L
G5`00`1KFe/0G5aL05eMG@0205]KF`0@061PH01QHF40G5aL05]KF`1HF5P0G5aL05UIF@1LG5`0HF5Q
05IFEP1KFe/0GUiN05aLG01PH600GEeM05]KF`80F5QH00<0EUIF05ADE01OGel05`0000060=WIf@40
00000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT05P3Ph>00IVIV06QXJ01YJFT0I6AT06EU
I@1ZJVX0IfMW06ATI01/K6`0Hf=S06MWI`1ZJVX0Jf][06e]K@1VIVH0K6a/06QXJ01ZJVX0J6QX06][
J`1VIVH206e]K@0=06QXJ01/K6`0JVYZ06a/K01ZJVX0KVi^06QXJ01/K6`0LG5a06EUI@1aLG40K6a/
06m_K`02075aL@0606m_K`1[Jf/0KVi^07=cL`1aLG40Jf][0P1cLg<0:`1dM7@0JVYZ07MgM`1cLg<0
N7Qh07=cL`1TI6@0K6a/071`L01gMgL0M7Ad07QhN01kNg/0L71`07=cL`1hN7P0Ng]k07QhN01nOWh0
KVi^07YjNP1iNGT0MgMg07AdM01fMWH0MGEe07UiN@23Ph<0MWIf07MgM`1nOWh0P82007]kN`1dM7@0
PH610820P01hN7P0NWYj07emO@21PH40Ng]k08B4Q01nOWh00`21PH402026QXH0QhN708F5Q@29RHT0
QXJ60861P@24Q8@0Rh^;0`24Q8@03@1oOgl0Ph>308:2PP23Ph<0QXJ608>3P`2;Rh/0QXJ608V9R@2;
Rh/0S8b<08^;R`25QHD00P28R8P03@2@T900SHf=08^;R`2ATI40Rh^;08R8R029RHT0R8R808^;R`2>
SXh0RHV908R8R024Q8@00P23Ph<01024Q8@0O7al08N7Q`24Q8@208>3P`0808V9R@2<S8`0SHf=08V9
R@28R8P0RHV908Z:RP28R8P209>CT`0>09FEU@2:RXX0Ph>309BDU02;Rh/0T92@08f=S@2:RXX0RHV9
08j>SP2;Rh/0Q8B408J6QP27QhL208>3P`80Q8B400/0Ph>308B4Q020P800Q8B408V9R@2;Rh/0PH61
0820P026QXH0P82008J6QP0208>3P`0;0820P01jNWX0P82008>3P`1oOgl0PX:207alO01kNg/0M7Ad
07]kN`1cLg<00P1hN7P05@1fMWH0O7al07inOP1nOWh0O7al07UiN@1mOGd0M7Ad07EeM@1jNWX0P820
07]kN`1cLg<0MWIf07UiN@1jNWX0L71`07QhN01fMWH0KFe]06a/K00207AdM00M07=cL`1`L700MWIf
071`L01YJFT0IVIV071`L01aLG40K6a/06][J`1SHf<0JFUY06=SH`1YJFT0I6AT06EUI@1OGel0Hf=S
05eMG@1[Jf/0IVIV06UYJ@1NGUh0IFEU069RHP1TI6@0HV9R06IVIP1SHf<00P1QHF402`1RHV80GUiN
06UYJ@1SHf<0HF5Q05iNGP1LG5`0JFUY061PH01XJ6P0IfMW0080H61P00/0E5AD05aLG01TI6@0IFEU
05=CD`1KFe/0G5aL05IFEP1VIVH0FEUI065QH@0205UIF@0405aLG01GEeL0GUiN065QH@80H61P00<0
G5aL061PH01LG5`00P1LG5`01P1KFe/0GUiN055AD@1IFET0EUIF05QHF1L000001P3IfMT100000040
fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00H0f][J065QH@1TI6@0HV9R065QH@1^KVh306QX
J00406][J`1YJFT0JVYZ06][J`80JFUY00l0Jf][06QXJ01XJ6P0J6QX06e]K@1_Kfl0Jf][06i^KP1/
K6`0KVi^06a/K01^KVh0JVYZ075aL@1]KFd00P1_Kfl0201[Jf/0M7Ad06a/K01YJFT0KVi^06e]K@1/
K6`0LG5a0P1^KVh02P1cLg<0M7Ad07AdM01dM7@0LG5a06IVIP1bLW80Kfm_07IfMP1^KVh207=cL`0B
07EeM@1kNg/0NGUi071`L01gMgL0KVi^07IfMP1iNGT0N7Qh07=cL`1eMGD0NWYj07IfMP1iNGT0LW9b
07=cL`1hN7P0Ng]k0P1dM7@0201hN7P0KVi^07alO01nOWh0Ogmo07QhN020P800NWYj0P1nOWh01P24
Q8@0OWin08B4Q01iNGT0P82008>3P`80QXJ600<0PH6108V9R@1mOGd00P23Ph<03@25QHD0Ogmo08:2
PP24Q8@0Ogmo08J6QP28R8P0QhN708B4Q026QXH0RHV908J6QP29RHT00P2<S8`0:`2=SHd0RHV908F5
Q@29RHT0P82008B4Q02:RXX0RHV908>3P`25QHD0Rh^;08>3P`2?Shl0R8R808J6QP22PX80P82008>3
P`20P800O7al07IfMP1`L700KFe]07MgM`1eMGD0Ng]k07IfMP1kNg/0N7Qh07alO026QXH0S8b<09BD
U02<S8`0Shn?08b<S02@T900QHF508b<S026QXH0SXj>08J6QP28R8P00P2<S8`04`26QXH0QhN7092@
T026QXH0S8b<08B4Q020P800Shn?08:2PP26QXH0NGUi08N7Q`2:RXX0RHV90820P02;Rh/0OWin08B4
Q022PX800`23Ph<0201nOWh0QHF507moO`24Q8@0PH6107emO@1iNGT0O7al0P20P8001P21PH40NWYj
07=cL`1kNg/0NWYj07alO080N7Qh00P0MgMg07]kN`1dM7@0LW9b07IfMP1hN7P0M7Ad079bLP80M7Ad
00<0Lg=c071`L01eMGD00P1`L700201cLg<0LW9b06i^KP1bLW80N7Qh07=cL`1eMGD0M7Ad0P1cLg<0
201WIfL0HF5Q06][J`1XJ6P0Jf][06ATI01_Kfl0JVYZ0P1YJFT03@1XJ6P0JFUY061PH01UIFD0HV9R
065QH@1NGUh0JFUY069RHP1TI6@0HV9R05mOG`1KFe/00P1TI6@02P1PH600I6AT05aLG01TI6@0GEeM
05]KF`1NGUh0HV9R05mOG`1KFe/205eMG@0705UIF@1VIVH0GemO05aLG01PH600GUiN05]KF`0205UI
F@0;05MGE`1LG5`0GemO05iNGP1IFET0EEEE05UIF@1OGel0I6AT069RHP1PH6000P1MGEd02P1IFET0
EUIF05YJFP1IFET0GEeM05ADE01EEED0E5AD05UIF@1LG5`G000000H0fMWI0@0000010=WIf@005P3I
fMT00`000000fMWI0=WIf@030=WIf@080=CDe01RHV80JFUY06=SH`1XJ6P0Hf=S069RHP1VIVH206QX
J00706UYJ@1`L700IVIV06EUI@1`L700Hf=S06QXJ00406a/K080Jf][00<0IfMW075aL@1YJFT00P1[
Jf/01P1^KVh0J6QX06i^KP1XJ6P0Lg=c06i^KP80L71`00L0Jf][06e]K@1aLG40KVi^07EeM@1`L700
M7Ad0080LG5a00D0Kfm_07=cL`1aLG40M7Ad06i^KP02071`L01J07=cL`1dM7@0LG5a06i^KP1eMGD0
Lg=c071`L01dM7@0Lg=c06i^KP1`L700Lg=c06i^KP1dM7@0MWIf07MgM`1fMWH0NWYj06m_K`1`L700
Lg=c07YjNP1hN7P0MgMg07alO01dM7@0Ng]k07QhN020P800NGUi07]kN`1iNGT0PH6107]kN`1oOgl0
OGem08>3P`1nOWh0NGUi08F5Q@29RHT0Ng]k08N7Q`1lO7`0P82008R8R022PX80O7al08>3P`21PH40
QhN7092@T01mOGd0RXZ:08N7Q`23Ph<0Q8B408b<S025QHD0S8b<08>3P`26QXH0Ph>308V9R@2>SXh0
QXJ608V9R@2;Rh/0PH6108^;R`29RHT0Rh^;08V9R@2CTi<0TI6A0861P@1oOgl0OWin07AdM01eMGD0
L71`06][J`1VIVH0JVYZ05mOG`1_Kfl0LW9b07=cL`1mOGd0PX:20P24Q8@0202:RXX0T92@08f=S@2=
SHd0RHV908B4Q028R8P0Shn?0P28R8P03`29RHT0T92@092@T026QXH0T92@08J6QP27QhL0Ogmo08R8
R01oOgl0QHF50820P02>SXh0RHV908b<S00208:2PP0[08Z:RP27QhL0P82008:2PP1lO7`0OWin08J6
QP1cLg<0O7al07IfMP22PX80P82007inOP1fMWH0Ng]k07QhN01fMWH0PH6107QhN01kNg/0O7al07=c
L`1eMGD0NGUi07]kN`1cLg<0NGUi07IfMP1lO7`0Lg=c06m_K`1cLg<0N7Qh079bLP1kNg/0L71`07=c
L`1dM7@0LG5a07AdM01cLg<0K6a/06i^KP0307AdM00D07IfMP1cLg<0M7Ad06a/K01`L700J6QX071`
L01YJFT0K6a/06MWI`1ZJVX0IVIV06MWI`1XJ6P0KVi^06QXJ01YJFT0I6AT065QH@1WIfL206=SH`0Q
05iNGP1TI6@0HF5Q06ATI01NGUh0Hf=S05UIF@1QHF40IFEU05]KF`1SHf<0J6QX05mOG`1NGUh0IfMW
05aLG01OGel0IVIV065QH@1TI6@0Fe]K05iNGP1SHf<0H61P06=SH`1OGel0EUIF05QHF01MGEd0EUIF
05MGE`1IFET0GEeM0080G5aL00d0GEeM05]KF`1LG5`0GUiN05EEE@1MGEd0FEUI065QH@1PH600FEUI
05aLG01HF5P0EeMG0080F5QH00<0EEEE05]KF`0000005P0000060=WIf@4000000@3IfMT001H0fMWI
00<000000=WIf@3IfMT00`3IfMT09`3Hf=P0HV9R071`L01SHf<0IVIV065QH@1PH600IVIV06QXJ01V
IVH0J6QX069RHP1OGel0Hf=S06][J`1]KFd0IVIV06MWI`1XJ6P0Hf=S06a/K01aLG40IfMW06][J`1/
K6`0JFUY07=cL`1[Jf/0K6a/06][J`1ZJVX0KVi^06a/K01_Kfl0LG5a079bLP1/K6`0M7Ad06i^KP02
06a/K008071`L01XJ6P0L71`06][J`1/K6`0MGEe07AdM01eMGD207=cL`0706i^KP1bLW80K6a/07=c
L`1/K6`0M7Ad07EeM@0207=cL`0H06m_K`1gMgL0M7Ad071`L01dM7@0MWIf07MgM`1cLg<0N7Qh07Yj
NP1eMGD0N7Qh079bLP1gMgL0M7Ad07IfMP21PH40N7Qh07inOP1gMgL0QHF507QhN022PX80PH610P1n
OWh03P1jNWX0PX:207inOP22PX80Ph>30861P@25QHD0QXJ607YjNP27QhL0Ng]k07emO@25QHD0PH61
0`23Ph<01@24Q8@0OWin07emO@2:RXX0QXJ60080R8R80P2>SXh0:@29RHT0P82008^;R`26QXH0QhN7
08:2PP2;Rh/0RXZ:0861P@27QhL0QHF508V9R@2=SHd0QXJ608B4Q01lO7`0PH6107YjNP1gMgL0I6AT
06][J`1PH600Fe]K05YJFP1PH600J6QX069RHP1/K6`0NWYj07IfMP1kNg/0P82008V9R@23Ph<0S8b<
096AT@21PH40Q8B408b<S028R8P0Q8B40080Rh^;00/0QXJ60820P028R8P0Q8B408F5Q@24Q8@0QXJ6
07moO`1nOWh0Ogmo07alO00208>3P`0D08V9R@27QhL0Ph>308J6QP28R8P0QXJ60820P029RHT0Q8B4
07UiN@20P800O7al08B4Q023Ph<0PH6107inOP1iNGT0Ng]k07MgM`1iNGT207inOP0507]kN`1fMWH0
Ogmo07EeM@1aLG400P1kNg/02@1`L700LW9b071`L01lO7`0Lg=c07emO@1fMWH0N7Qh07AdM002079b
LP80Lg=c00L0LG5a07=cL`1aLG40M7Ad07UiN@1cLg<0MGEe0080Lg=c0100IVIV06UYJ@1/K6`0Jf][
06UYJ@1/K6`0KFe]06IVIP1/K6`0I6AT06YZJP1XJ6P0JFUY06IVIP1YJFT0I6AT0P1UIFD02P1SHf<0
H61P061PH01SHf<0G5aL061PH01VIVH0I6AT065QH@1NGUh2061PH00C05mOG`1XJ6P0Hf=S05eMG@1L
G5`0GEeM06QXJ01UIFD0GUiN05UIF@1JFUX0GUiN065QH@1LG5`0FEUI05iNGP1KFe/0H61P05UIF@02
05aLG00605IFEP1PH600F5QH05ADE01IFET0EUIF0P1IFET03@1JFUX0GemO05UIF@1IFET0IFEU051@
D01HF5P0EUIF05UIF@1NGUh0FUYJ05aLG01EEED05`0000060=WIf@4000000@3IfMT001H0fMWI00<0
00000=WIf@3IfMT00`3IfMT0303AdM40Hf=S06MWI`1YJFT0HF5Q06QXJ01SHf<0JFUY06IVIP1XJ6P0
JFUY06YZJP80J6QX00D0IfMW06][J`1YJFT0Jf][06UYJ@0206QXJ00?06MWI`1[Jf/0JFUY06i^KP1/
K6`0KVi^06UYJ@1]KFd0JFUY071`L01^KVh0L71`06i^KP1WIfL0Lg=c0080K6a/00h0KFe]06a/K01`
L700LG5a07IfMP1`L700J6QX07=cL`1/K6`0JFUY06i^KP1cLg<0KVi^071`L080Lg=c01X0Jf][07=c
L`1aLG40MgMg079bLP1jNWX0KVi^075aL@1fMWH0LG5a07IfMP1^KVh0Lg=c075aL@1eMGD0Ng]k07Qh
N01aLG40N7Qh07MgM`1lO7`0L71`07MgM`1iNGT0NWYj07]kN`80N7Qh00T0NGUi07AdM021PH40Ogmo
07=cL`1kNg/0OWin07QhN024Q8@00P21PH40301lO7`0Ng]k07]kN`1nOWh0OGem07inOP1iNGT0P820
08:2PP1kNg/0Ogmo08b<S080QhN700@0RXZ:08J6QP29RHT0QhN70P24Q8@00`2:RXX0Q8B40820P002
08R8R00D08V9R@27QhL0P82008n?S`1mOGd0Ph>308B4Q01oOgl0P82007YjNP1mOGd0MWIf06YZJP1_
Kfl0J6QX06UYJ@1PH600HF5Q05mOG`1SHf<206][J`0;079bLP1fMWH0O7al07alO020P800OWin08>3
P`28R8P0Ph>308Z:RP28R8P00P29RHT0302<S8`0R8R808b<S026QXH0QhN708V9R@2;Rh/0Q8B408n?
S`23Ph<0R8R80861P@80OWin00H0O7al08R8R027QhL0Ng]k08J6QP25QHD20861P@0907alO01kNg/0
PX:207moO`1fMWH0Q8B407UiN@1mOGd0Lg=c0080OWin00<0Q8B407IfMP1gMgL00P1iNGT0301kNg/0
MWIf07emO@1dM7@0MGEe071`L01cLg<0L71`07UiN@1dM7@0Ng]k06m_K`80MGEe01`0MWIf07=cL`1a
LG40NGUi06i^KP1]KFd0LG5a06i^KP1bLW80MgMg07]kN`1oOgl0MgMg071`L01cLg<0Jf][06i^KP1[
Jf/0KFe]06][J`1TI6@0IVIV06YZJP1TI6@0GUiN06QXJ01^KVh0IFEU0P1YJFT03@1VIVH0Jf][06AT
I01SHf<0HF5Q06ATI01VIVH0HF5Q06UYJ@1RHV80HF5Q05aLG01SHf<00P1PH6001@1SHf<0HF5Q05UI
F@1PH600G5aL0080HF5Q00<0IFEU05iNGP1PH6000P1IFET0401QHF40FUYJ061PH01HF5P0FEUI05QH
F01IFET0H61P05]KF`1HF5P0G5aL05UIF@1MGEd0FEUI061PH01NGUh205IFEP0805]KF`1NGUh0FUYJ
05UIF@1GEeL0FEUI055AD@1FEUH2059BDP0305MGE`000000000001D000001P3IfMT100000040fMWI
000F0=WIf@030000003IfMT0fMWI00<0fMWI01D0d=3@06ATI01ZJVX0I6AT06QXJ01ZJVX0I6AT06IV
IP1^KVh0IfMW06UYJ@1UIFD0GUiN06MWI`1PH600JFUY06IVIP1ZJVX0JFUY06e]K@1[Jf/00P1XJ6P0
6`1ZJVX0KVi^06IVIP1XJ6P0JVYZ071`L01_Kfl0IFEU071`L01YJFT0Kfm_06i^KP1YJFT0Kfm_06a/
K01`L700Jf][06m_K`1bLW80JVYZ06a/K01XJ6P0Jf][07=cL`1]KFd0IfMW06m_K`02071`L080LG5a
01/0MgMg07AdM01eMGD0LG5a071`L01cLg<0MWIf075aL@1`L700Jf][07AdM01ZJVX0L71`06YZJP1a
LG40Lg=c071`L01fMWH0L71`07YjNP1^KVh0N7Qh07UiN@1oOgl0LW9b07EeM@1gMgL00P1jNWX05`1k
Ng/0N7Qh07moO`1mOGd0NWYj07QhN01lO7`0OWin07alO01nOWh0Ng]k08:2PP1mOGd0MGEe07inOP1i
NGT0Ogmo0861P@1oOgl0PH6107alO020P800RHV90080QXJ600l0P82008^;R`28R8P0QHF508V9R@24
Q8@0PH6108B4Q02;Rh/0Q8B408Z:RP24Q8@0QXJ608R8R02=SHd00P20P8005P2>SXh0Ogmo079bLP1h
N7P0NWYj07IfMP1[Jf/0JVYZ06UYJ@1UIFD0JFUY06YZJP1aLG40K6a/075aL@1VIVH0Lg=c079bLP1e
MGD0PH6107emO@2>SXh208b<S0030861P@22PX80Q8B40080Q8B400/0RHV908N7Q`24Q8@0P82008J6
QP22PX80PH6108>3P`1lO7`0Ogmo08N7Q`0208J6QP0808:2PP29RHT0Ng]k07YjNP24Q8@0P82007in
OP1lO7`20861P@80NGUi01<0PH6107UiN@1kNg/0NGUi07alO01`L700Ogmo07]kN`1lO7`0P82007]k
N`1hN7P0M7Ad07IfMP1kNg/0P82007IfMP1kNg/0NGUi0080MWIf01D0M7Ad071`L01hN7P0JFUY071`
L01cLg<0MWIf075aL@1gMgL0MWIf07=cL`1_Kfl0Lg=c07AdM01^KVh0MgMg07AdM01`L700MgMg079b
LP1XJ6P00P1[Jf/03`1`L700Kfm_06e]K@1_Kfl0IVIV06][J`1/K6`0Hf=S06a/K01TI6@0K6a/06AT
I01/K6`0IVIV06m_K`02065QH@0=061PH01IFET0H61P05iNGP1PH600GemO065QH@1UIFD0HF5Q05aL
G01VIVH0H61P05eMG@0205iNGP0T06ATI01QHF40GEeM05iNGP1KFe/0GUiN061PH01KFe/0HF5Q05YJ
FP1LG5`0GemO05EEE@1ADE40FEUI05QHF01LG5`0EUIF05UIF@1HF5P0EEEE05]KF`1NGUh0Fe]K05UI
F@1MGEd0Fe]K05QHF01JFUX0De=C05QHF01DE5@0G5aL05UIF@1HF5P0FEUI5`0000060=WIf@400000
0@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0103Fe]H0IfMW069RHP1PH60206UYJ@0F06=S
H`1WIfL0Jf][06IVIP1WIfL0Jf][06QXJ01VIVH0Hf=S06UYJ@1/K6`0IFEU06IVIP1UIFD0JFUY06a/
K01[Jf/0Kfm_06][J`1YJFT0I6AT06i^KP80JVYZ01<0LG5a07=cL`1^KVh0J6QX06m_K`1VIVH0JVYZ
06UYJ@1dM7@0IfMW06m_K`1YJFT0K6a/06][J`1`L700KVi^06a/K01aLG40K6a/0080Lg=c00l0Jf][
06i^KP1dM7@0KVi^07alO01kNg/0Jf][079bLP1iNGT0LW9b075aL@1`L700M7Ad06i^KP1bLW800P1`
L7005P1hN7P0MgMg07QhN01`L700MgMg075aL@1gMgL0M7Ad07MgM`1iNGT0OWin07=cL`1kNg/0NWYj
07IfMP1kNg/0M7Ad07UiN@1nOWh0O7al07UiN@1nOWh207alO0060861P@1mOGd0QHF50820P01kNg/0
Ph>30P20P8006023Ph<0Ng]k0820P022PX80QXJ608R8R022PX80QHF508f=S@24Q8@0QHF508B4Q02:
RXX0S8b<08B4Q027QhL0Q8B40861P@2?Shl0QXJ608F5Q@2ATI40Rh^;08b<S080P82000@0O7al07Qh
N01bLW80L71`0P1/K6`0401aLG40KVi^07IfMP1`L700M7Ad07=cL`1^KVh0JVYZ06UYJ@1/K6`0L71`
07MgM`20P800PX:207moO`2;Rh/208Z:RP0G08>3P`21PH40Ph>308>3P`26QXH0R8R808>3P`20P800
R8R808J6QP1lO7`0P82008>3P`2:RXX0OWin0820P025QHD0PX:20861P@2>SXh0QHF507emO@20P800
0P21PH40=@1nOWh0O7al08>3P`20P800PH6107UiN@20P800Ng]k0820P01nOWh0NGUi07IfMP1oOgl0
LG5a07UiN@1hN7P0Ng]k07AdM01hN7P0MWIf07=cL`1mOGd0MGEe07IfMP1gMgL0KVi^075aL@1hN7P0
LG5a07EeM@1^KVh0Kfm_07QhN01`L700K6a/06][J`1^KVh0MWIf07=cL`1iNGT0M7Ad071`L01/K6`0
Kfm_07QhN01cLg<0Jf][06m_K`1XJ6P0KFe]06a/K01^KVh0Lg=c0080K6a/00D0JFUY06MWI`1bLW80
K6a/06YZJP0206IVIP0?065QH@1YJFT0GUiN06=SH`1RHV80HF5Q06=SH`1RHV80GUiN05aLG01SHf<0
IVIV05UIF@1QHF40HV9R00<0H61P00H0GemO05aLG01QHF40HV9R05UIF@1PH60205UIF@0E05QHF01F
EUH0H61P05UIF@1HF5P0HF5Q05UIF@1PH600GemO05MGE`1LG5`0F5QH05EEE@1NGUh0G5aL05iNGP1I
FET0F5QH05aLG01KFe/0F5QH0080E5AD0P1HF5P00`1EEED0F5QH05UIF@0G000000H0fMWI0@000001
0=WIf@005P3IfMT2000000@0fMWI01l0c/k>06=SH`1TI6@0IVIV06ATI01SHf<0Jf][06QXJ01PH600
KVi^06=SH`1YJFT0IfMW06YZJP1VIVH0I6AT06EUI@1VIVH0Kfm_06YZJP1XJ6P0IfMW06ATI01`L700
I6AT06QXJ01bLW80L71`06QXJ01ZJVX0Kfm_0080KVi^0100J6QX06m_K`1VIVH0Lg=c06i^KP1aLG40
IfMW075aL@1XJ6P0JFUY06a/K01aLG40JVYZ06EUI@1XJ6P0N7Qh0P1aLG40>P1^KVh0LW9b07UiN@1Z
JVX0Kfm_07=cL`1^KVh0M7Ad07QhN01cLg<0LW9b07=cL`1kNg/0MgMg079bLP1]KFd0MGEe07IfMP1h
N7P0LG5a07YjNP1gMgL0N7Qh07AdM01aLG40N7Qh079bLP1mOGd0L71`07IfMP1eMGD0OWin06m_K`20
P800M7Ad07YjNP20P800NGUi07YjNP24Q8@0N7Qh07alO022PX80OWin07alO01mOGd0NWYj08:2PP1l
O7`0Q8B40861P@24Q8@0PH6107emO@1iNGT0S8b<07inOP20P80208J6QP80QHF500P0Rh^;07alO023
Ph<0PH6108F5Q@1nOWh0Ogmo08R8R080QhN701<0OWin08B4Q01kNg/0MWIf07QhN01bLW80KVi^06YZ
JP1eMGD0IVIV07IfMP1iNGT0M7Ad079bLP1iNGT0M7Ad06i^KP1]KFd0LG5a0080M7Ad01L0P82007in
OP21PH40S8b<08N7Q`23Ph<0OGem08F5Q@20P800Q8B408b<S026QXH0S8b<08F5Q@26QXH0Ph>307al
O021PH40OWin08:2PP20P800O7al08J6QP020861P@80PX:20100P82007]kN`1gMgL0NWYj07alO01o
Ogl0O7al07]kN`20P800Ng]k07UiN@1kNg/0NGUi07]kN`1hN7P0OWin0P1kNg/06`1aLG40Ng]k07Ad
M01`L700N7Qh07inOP1kNg/0MWIf07UiN@1cLg<0L71`06e]K@1iNGT0MGEe07=cL`1`L700LW9b07Ee
M@1[Jf/0L71`06a/K01dM7@0LG5a079bLP1aLG40MWIf06UYJ@02075aL@0707UiN@1aLG40KFe]075a
L@1/K6`0KVi^06e]K@0206][J`0306QXJ01`L700KVi^0080Jf][0P1XJ6P206=SH`0306ATI01SHf<0
HF5Q0080H61P01D0HF5Q06ATI01XJ6P0HF5Q06EUI@1SHf<0HF5Q06UYJ@1NGUh0EUIF065QH@1MGEd0
HF5Q05aLG01QHF40GUiN05aLG01IFET0Fe]K05aLG01JFUX00P1FEUH05P1IFET0FUYJ05EEE@1JFUX0
GemO05eMG@1KFe/0FEUI05mOG`1IFET0F5QH059BDP1GEeL0GEeM061PH01KFe/0FUYJ05MGE`1NGUh0
De=C05UIF@1CDe<205aLG00305UIF@1HF5P0EUIF01L000001@3IfMT200000040fMWI000F0=WIf@03
0000003IfMT0fMWI00<0fMWI00P0e]KF06=SH`1`L700I6AT06UYJ@1RHV80Jf][06e]K@80IVIV00H0
HF5Q06UYJ@1XJ6P0I6AT06YZJP1/K6`206YZJP0]06a/K01[Jf/0Jf][06EUI@1VIVH0Jf][075aL@1]
KFd0LG5a06UYJ@1[Jf/0IVIV06][J`1_Kfl0Jf][06MWI`1^KVh0Jf][071`L01dM7@0KVi^06UYJ@1b
LW80KVi^06][J`1YJFT0Jf][06a/K01]KFd0MgMg06m_K`1aLG40JVYZ07=cL`1^KVh0Jf][06QXJ01Z
JVX0L71`06UYJ@1fMWH0L71`06m_K`1aLG40Kfm_0080MgMg00<0M7Ad07=cL`1dM7@00`1dM7@207=c
L`0307QhN01gMgL0M7Ad0080N7Qh00T0M7Ad07=cL`1bLW80MWIf07QhN01gMgL0PX:207inOP1`L700
0P1dM7@05`21PH40OWin07moO`20P800Ng]k07AdM01lO7`0OWin07emO@1iNGT0OGem07inOP1hN7P0
QXJ608F5Q@23Ph<0R8R808>3P`1nOWh0Ph>308R8R024Q8@0Ph>30080QXJ60180P82008B4Q026QXH0
OGem08F5Q@20P800R8R80820P021PH40QXJ60861P@1nOWh0MgMg075aL@1iNGT0L71`06UYJ@1/K6`2
06i^KP0>07EeM@1cLg<0O7al07EeM@1XJ6P0Jf][06QXJ01_Kfl0Lg=c07IfMP20P800Ng]k07IfMP21
PH420820P00B07moO`20P800Ng]k08>3P`1nOWh0PX:20820P025QHD0Ogmo07inOP22PX80PH6108:2
PP1kNg/0P82007alO023Ph<0P8200P21PH404@1bLW80PH6107alO01nOWh0OGem08B4Q01hN7P0P820
07]kN`1lO7`0MWIf07AdM01^KVh0MWIf07]kN`1lO7`0MgMg0080N7Qh01X0NWYj07AdM01aLG40M7Ad
07UiN@1eMGD0Lg=c075aL@1_Kfl0Lg=c07QhN01fMWH0KFe]071`L01ZJVX0Kfm_075aL@1/K6`0MWIf
075aL@1^KVh0HF5Q071`L01^KVh0Jf][06a/K0<0LG5a00@0MWIf06i^KP1`L700KVi^0P1_Kfl09@1/
K6`0KVi^075aL@1hN7P0KVi^06][J`1YJFT0JVYZ06UYJ@1[Jf/0IfMW06IVIP1^KVh0JFUY061PH01/
K6`0I6AT065QH@1OGel0IfMW061PH01NGUh0Hf=S05aLG01NGUh0Hf=S05iNGP1OGel0Fe]K06UYJ@1L
G5`0H61P06=SH`1UIFD0EUIF055AD@1NGUh00P1DE5@02@1FEUH0Fe]K05aLG01KFe/0HV9R05UIF@1K
Fe/0HF5Q05aLG00305UIF@<0FUYJ00d0H61P05UIF@1MGEd0FEUI05MGE`000000F5QH05MGE`1CDe<0
EeMG05QHF01FEUH0De=C01L000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0
fMWI0140fm_K065QH@1SHf<0Hf=S06ATI01ZJVX0IVIV06][J`1/K6`0Jf][06UYJ@1VIVH0Hf=S06a/
K01YJFT0IVIV06=SH`0206UYJ@80JVYZ00D0J6QX06a/K01_Kfl0Lg=c06e]K@0306a/K00O06][J`1T
I6@0IfMW06e]K@1`L700KVi^06QXJ01aLG40M7Ad06e]K@1YJFT0IVIV06MWI`1YJFT0LG5a07AdM01/
K6`0IfMW079bLP1cLg<0L71`06m_K`1^KVh0Jf][07UiN@1^KVh0Kfm_071`L01TI6@0Lg=c06][J`02
071`L00806][J`1cLg<0LW9b07AdM01cLg<0MWIf07AdM01aLG4207=cL`80LW9b01P0L71`07IfMP1h
N7P0Lg=c071`L01^KVh0MGEe07=cL`24Q8@0MGEe07YjNP20P800M7Ad07UiN@1jNWX0MgMg07YjNP1h
N7P0M7Ad07IfMP1lO7`0Ogmo07alO01fMWH307]kN`0508>3P`21PH40PX:207QhN01iNGT00P22PX80
2@26QXH0OWin08:2PP21PH40RHV908b<S026QXH0QHF507inOP0208B4Q00;07IfMP21PH40QhN708>3
P`22PX80Q8B40820P01fMWH0KVi^071`L01]KFd00P1SHf<206QXJ00506m_K`1^KVh0LG5a07=cL`1[
Jf/00P1WIfL03`1[Jf/0Kfm_07IfMP1lO7`0N7Qh08:2PP27QhL0OGem0861P@23Ph<0Ng]k07emO@1k
Ng/0P82008B4Q00208>3P`0>07UiN@20P800Ng]k0820P021PH40QXJ60861P@1iNGT0Q8B407YjNP1g
MgL0OWin0861P@20P80207alO00I07MgM`1mOGd0N7Qh07QhN01fMWH0OWin07=cL`1bLW80PH6107Qh
N01nOWh0LG5a07YjNP1_Kfl0LW9b07IfMP1/K6`0MGEe07QhN01cLg<0Jf][071`L01aLG40M7Ad06i^
KP0207=cL`07075aL@1dM7@0Kfm_07QhN01aLG40Kfm_07=cL`0206i^KP0F071`L01[Jf/0IVIV07If
MP1ZJVX0KVi^07AdM01^KVh0LG5a07AdM01^KVh0LG5a071`L01^KVh0K6a/06m_K`1]KFd0MWIf075a
L@1/K6`0IVIV071`L080J6QX00/0K6a/06IVIP1ZJVX0I6AT06YZJP1SHf<0HF5Q05]KF`1VIVH0GemO
05iNGP02061PH00C06=SH`1JFUX0G5aL05aLG01QHF40EeMG05eMG@1JFUX0Hf=S05mOG`1QHF40Fe]K
05QHF01ADE40EUIF05eMG@1KFe/0GUiN05mOG`0205QHF00405iNGP1KFe/0E5AD05IFEP<0GUiN00@0
EeMG05iNGP1LG5`0G5aL0P1NGUh02P1LG5`0DU9B061PH01IFET0EUIF05=CD`1JFUX0Fe]K05EEE@1H
F5PG000000H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@050<c<c01VIVH0
HV9R06ATI01UIFD00P1XJ6P02`1^KVh0J6QX06ATI01SHf<0IFEU06=SH`1TI6@0K6a/06QXJ01aLG40
IfMW0080JFUY0P1ZJVX04`1QHF40J6QX06YZJP1RHV80JFUY06IVIP1YJFT0K6a/06MWI`1^KVh0Kfm_
06IVIP1NGUh0M7Ad06][J`1/K6`0Kfm_06MWI`1[Jf/00P1`L7001@1YJFT0Kfm_07QhN01aLG40L71`
0080KVi^00<0L71`06i^KP1VIVH00P1`L7004@1dM7@0LG5a07=cL`1fMWH0KVi^071`L01[Jf/0LW9b
075aL@1dM7@0KVi^06QXJ01^KVh0K6a/079bLP1eMGD0N7Qh0080MWIf0340LW9b07UiN@1aLG40MGEe
07IfMP1nOWh0M7Ad079bLP1lO7`0Lg=c07inOP1gMgL0N7Qh07=cL`1hN7P0NWYj07MgM`1jNWX0NGUi
07emO@20P800PH6107inOP1kNg/0MWIf08:2PP1lO7`0OWin07alO01mOGd0P8200861P@1oOgl0OGem
08B4Q029RHT0QXJ608R8R024Q8@0Ph>30861P@24Q8@0PH6107emO@1nOWh0Q8B407inOP20P800O7al
0080Q8B400@0O7al07IfMP1cLg<0JVYZ0`1VIVH0;P1/K6`0JFUY06a/K01^KVh0IfMW06IVIP1WIfL0
IVIV06=SH`1ZJVX0IVIV07UiN@1kNg/0PH6107]kN`1mOGd0Ogmo07UiN@26QXH0Ogmo08J6QP21PH40
Ng]k0820P01lO7`0OWin08>3P`1kNg/0P82007alO021PH40QXJ608B4Q01oOgl0Ng]k08>3P`1hN7P0
OWin07alO01iNGT0QXJ607YjNP1fMWH0OWin07YjNP1nOWh207QhN003075aL@1kNg/0MGEe0080MWIf
00P0O7al079bLP1fMWH0Ng]k075aL@1cLg<0M7Ad07]kN`<0M7Ad00T0Lg=c06i^KP1cLg<0Lg=c07Qh
N01eMGD0M7Ad07=cL`1dM7@00P1`L7006@1XJ6P0L71`07=cL`1`L700MWIf06][J`1`L700JFUY06][
J`1_Kfl0K6a/071`L01bLW80Lg=c07AdM01jNWX0N7Qh07]kN`1^KVh0K6a/07=cL`1eMGD0Kfm_06e]
K@1/K6`00`1[Jf/01@1]KFd0J6QX06i^KP1TI6@0K6a/0080H61P01H0GUiN061PH01QHF40GUiN06AT
I01IFET0HF5Q061PH01LG5`0GUiN05MGE`1KFe/0G5aL065QH@1KFe/0F5QH05=CD`1JFUX0EeMG05UI
F@1KFe/0G5aL0`1KFe/00`1NGUh0G5aL05=CD`0205UIF@0705YJFP1CDe<0G5aL05IFEP1HF5P0EUIF
05YJFP0205IFEP0:05iNGP1MGEd0Fe]K05MGE`1EEED0F5QH05aLG01JFUX0EUIF05ADE1L000001P3I
fMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI01@0d=3@06IVIP1/K6`0GUiN06UY
J@1XJ6P0HF5Q06UYJ@1QHF40KVi^06IVIP1UIFD0I6AT06UYJ@1QHF40KVi^06IVIP1TI6@0KVi^06AT
I080JFUY00`0IfMW06UYJ@1WIfL0JFUY071`L01WIfL0KVi^06QXJ01`L700JVYZ06i^KP1fMWH206IV
IP0C06i^KP1[Jf/0IVIV06i^KP1/K6`0Jf][06UYJ@1ZJVX0Jf][079bLP1/K6`0L71`06QXJ01[Jf/0
KVi^06m_K`1^KVh0LG5a06e]K@04079bLP0<06m_K`1hN7P0LG5a07IfMP1cLg<0MWIf071`L01[Jf/0
NWYj06YZJP1bLW80KVi^0P1dM7@04P1/K6`0NGUi07IfMP1bLW80MgMg07QhN01fMWH0N7Qh07AdM01o
Ogl0MWIf07AdM01jNWX0O7al07AdM01eMGD0M7Ad07QhN080O7al00/0N7Qh07MgM`1fMWH0P82007al
O01gMgL0Ph>307emO@1kNg/0M7Ad07alO0020861P@0A07]kN`26QXH0Ng]k0861P@1lO7`0Ogmo08B4
Q023Ph<0Ng]k07=cL`1iNGT0OGem08N7Q`1oOgl0Ng]k07inOP23Ph<00`24Q8@0@`1lO7`0NGUi07Yj
NP1YJFT0H61P06MWI`1HF5P0G5aL05eMG@1QHF40GUiN06=SH`1XJ6P0IFEU069RHP1^KVh0L71`07al
O01gMgL0O7al07emO@1lO7`0Ph>307alO01nOWh0O7al07AdM022PX80O7al0820P01lO7`0QhN707]k
N`1hN7P0O7al07emO@20P800R8R807inOP1iNGT0N7Qh07emO@1kNg/0OWin07emO@22PX80MWIf07Qh
N01gMgL0M7Ad07alO01nOWh0N7Qh07IfMP21PH40Ng]k07IfMP1jNWX0Kfm_075aL@1cLg<0NWYj071`
L01hN7P0MgMg07]kN`1`L7000P1dM7@0101`L700LW9b07=cL`1aLG42071`L00707AdM01eMGD0Lg=c
06e]K@1/K6`0LW9b075aL@0206][J`0G06YZJP1`L700JVYZ079bLP1/K6`0IfMW075aL@1`L700M7Ad
079bLP1[Jf/0LG5a07=cL`1`L700MGEe07inOP1gMgL0PH6107]kN`1eMGD0NGUi079bLP1fMWH00P1`
L700601XJ6P0KVi^06UYJ@1[Jf/0JFUY065QH@1WIfL0HV9R06ATI01QHF40JFUY05mOG`1NGUh0Hf=S
05mOG`1HF5P0Hf=S065QH@1PH600GUiN06ATI01IFET0GUiN05mOG`80GEeM00@0F5QH05]KF`1EEED0
H61P0P1NGUh03@1KFe/0E5AD05]KF`1HF5P0D51@05UIF@1NGUh0FEUI05MGE`1KFe/0FEUI05QHF01F
EUH00P1IFET02@1KFe/0GUiN05eMG@1IFET0EUIF05aLG01ADE40E5AD05IFEP0G000000H0fMWI0@00
00010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@060=7Ad@1TI6@0GUiN06ATI01VIVH0I6AT
0P1VIVH02P1UIFD0I6AT06IVIP1ZJVX0J6QX06IVIP1XJ6P0Hf=S06][J`1XJ6P206a/K00806m_K`1/
K6`0Kfm_075aL@1bLW80IVIV06=SH`1XJ6P206][J`0506i^KP1_Kfl0KVi^06UYJ@1^KVh00P1XJ6P0
101]KFd0IFEU06MWI`1]KFd2075aL@0;07=cL`1VIVH0K6a/06UYJ@1XJ6P0KFe]06a/K01YJFT0KVi^
06a/K01_Kfl00P1fMWH02@1_Kfl0LW9b075aL@1aLG40MWIf06e]K@1/K6`0Lg=c06i^KP0207IfMP0@
07UiN@1_Kfl0L71`06e]K@1cLg<0MWIf07QhN01iNGT0KVi^07]kN`1dM7@0LG5a07AdM01cLg<0O7al
071`L080N7Qh00H0MWIf07EeM@1hN7P0Lg=c07QhN01cLg<207QhN080O7al01@0QXJ60820P01nOWh0
NWYj07MgM`1hN7P0PH6107emO@23Ph<0O7al07inOP25QHD0OWin07IfMP1iNGT0Q8B40820P01jNWX0
Ph>307YjNP80Ng]k01/0P82008B4Q022PX80P82008B4Q02;Rh/0R8R808B4Q01lO7`0OGem07UiN@1f
MWH0L71`06QXJ01SHf<0H61P05UIF@1NGUh0FUYJ05eMG@1FEUH0Hf=S06ATI01QHF40IFEU06m_K`1f
MWH00P1kNg/00`1mOGd0PX:207alO0020820P00[08B4Q022PX80N7Qh07AdM01jNWX0Ng]k07inOP21
PH40P82007UiN@23Ph<0PH6107]kN`1iNGT0P82007QhN01oOgl0MGEe07alO01mOGd0Ng]k07alO01m
OGd0N7Qh07=cL`1iNGT0Ng]k07inOP1fMWH0L71`07]kN`1iNGT0Lg=c07QhN01dM7@0MGEe079bLP1a
LG40K6a/075aL@1`L700LG5a07UiN@02071`L00Z06][J`1aLG40KVi^06YZJP1_Kfl0K6a/071`L01[
Jf/0Lg=c075aL@1cLg<0IfMW06e]K@1^KVh0JFUY06QXJ01cLg<0Jf][06a/K01dM7@0LG5a07=cL`1a
LG40LW9b07YjNP1eMGD0Ng]k07YjNP22PX80OGem08B4Q01mOGd0PH6107alO01mOGd0MGEe079bLP1d
M7@0LW9b06i^KP1[Jf/0KVi^0P1TI6@04@1[Jf/0IFEU06=SH`1RHV80F5QH06UYJ@1RHV80G5aL05iN
GP1VIVH0HV9R061PH01LG5`0F5QH05mOG`1KFe/0H61P0080Fe]K0200HF5Q05UIF@1MGEd0EeMG065Q
H@1DE5@0Fe]K05ADE01KFe/0FEUI05ADE01NGUh0Fe]K05UIF@1QHF40Fe]K05eMG@1DE5@0GemO05AD
E01IFET0G5aL05YJFP1DE5@0EUIF061PH01DE5@0FEUI05aLG01HF5P0FEUI05IFEQL000001P3IfMT1
00000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0100fm_K05aLG01NGUh0I6AT06UYJ@1U
IFD0K6a/06ATI01YJFT0J6QX06][J`1XJ6P0I6AT06IVIP1ZJVX0Jf][0P1TI6@00`1WIfL0Jf][06a/
K00206a/K00B06ATI01YJFT0IVIV06ATI01[Jf/0IfMW071`L01VIVH0LW9b06QXJ01OGel0IfMW06UY
J@1_Kfl0IFEU06e]K@1ZJVX0IFEU0`1YJFT05`1[Jf/0IVIV06a/K01^KVh0Hf=S07UiN@1/K6`0KVi^
06a/K01aLG40L71`07]kN`1VIVH0KFe]07AdM01`L700IVIV06][J`1_Kfl0IfMW071`L01]KFd0MWIf
0080Kfm_01H0L71`06YZJP1aLG40K6a/07EeM@1hN7P0LG5a07QhN01^KVh0M7Ad071`L01cLg<0MgMg
07AdM01jNWX0KVi^079bLP1iNGT0LW9b07EeM@1`L700MWIf0P1hN7P04@1jNWX0NGUi07UiN@1iNGT0
OGem0820P01gMgL0Ng]k07YjNP1hN7P0OWin07alO020P800Ng]k08>3P`21PH40Ng]k0080PH610P1l
O7`01`1oOgl0Q8B40820P01oOgl0OWin08>3P`1nOWh00P25QHD05021PH40OWin07UiN@1lO7`0MWIf
07MgM`1cLg<0J6QX065QH@1VIVH0G5aL05iNGP1LG5`0HF5Q06MWI`1OGel0Hf=S065QH@1bLW80Kfm_
0P1nOWh07P1hN7P0P82007]kN`1kNg/0PH6107alO024Q8@0Ng]k07alO01eMGD0O7al0861P@1kNg/0
PH6107MgM`1lO7`0NWYj07UiN@1hN7P0LW9b07UiN@1lO7`0MWIf07YjNP20P800MWIf07UiN@1eMGD0
Ng]k07IfMP80LW9b00X0N7Qh07AdM01nOWh0MGEe07=cL`1^KVh0NGUi07]kN`1cLg<0KVi^0P1`L700
2P1eMGD0L71`06i^KP1cLg<0Jf][06a/K01cLg<0L71`06a/K01^KVh207AdM005075aL@1cLg<0JFUY
06][J`1^KVh00`1bLW82071`L00R06m_K`1ZJVX0KVi^071`L01cLg<0M7Ad071`L01cLg<0Kfm_07in
OP1lO7`0PX:207]kN`28R8P0Ph>3096AT@2;Rh/0SXj>08b<S02;Rh/0R8R807UiN@1hN7P0L71`06UY
J@1^KVh0JFUY06IVIP1`L700IVIV071`L01PH600HV9R06IVIP80Hf=S00@0I6AT069RHP1RHV80H61P
0P1KFe/03P1OGel0G5aL05IFEP1SHf<0FUYJ05]KF`1NGUh0G5aL05]KF`1NGUh0Fe]K05IFEP1KFe/0
EeMG0P1IFET05P1NGUh0Fe]K05QHF01MGEd0F5QH05iNGP1KFe/0DU9B065QH@1CDe<0EUIF05EEE@1N
GUh0EeMG05IFEP1IFET0EEEE05=CD`1DE5@0EUIF05UIF@1BDU8G000000H0fMWI0@0000010=WIf@00
5P3IfMT00`000000fMWI0=WIf@030=WIf@080=KFeP1YJFT0Jf][06=SH`1VIVH0I6AT06QXJ01TI6@2
06UYJ@07065QH@1VIVH0IVIV06ATI01PH600IVIV06EUI@0206a/K00606][J`1_Kfl0IVIV06UYJ@1T
I6@0J6QX0P1VIVH0=P1/K6`0IVIV06IVIP1VIVH0LG5a06][J`1WIfL0J6QX06e]K@1YJFT0Jf][06m_
K`1bLW80L71`06UYJ@1^KVh0Jf][06i^KP1TI6@0IVIV06UYJ@1XJ6P0JFUY06a/K01^KVh0K6a/06YZ
JP1XJ6P0IfMW06a/K01dM7@0L71`06a/K01aLG40LW9b06UYJ@1_Kfl0JVYZ07AdM01_Kfl0Hf=S075a
L@1bLW80M7Ad079bLP1hN7P0KVi^07AdM01cLg<0LG5a07AdM01eMGD0NGUi075aL@80M7Ad00H0N7Qh
07inOP1fMWH0MGEe06][J`1gMgL207IfMP0707inOP1cLg<0MWIf079bLP1fMWH0O7al07]kN`0207al
O00H07]kN`20P800N7Qh07]kN`1iNGT0OGem07]kN`1mOGd0Ogmo08N7Q`1lO7`0NWYj08J6QP24Q8@0
NGUi08:2PP24Q8@0O7al08>3P`1kNg/0Ogmo0820P01mOGd0Ph>30P21PH40101lO7`0Ng]k07YjNP1a
LG4206i^KP0506YZJP1XJ6P0IfMW069RHP1XJ6P00P1TI6@00`1VIVH0K6a/07AdM00207QhN080P820
00<0OWin07AdM01nOWh00P1jNWX0501hN7P0MgMg07QhN023Ph<0PH6108:2PP20P800NGUi07]kN`20
P800Lg=c07moO`1fMWH0NGUi07alO01fMWH0Ng]k07IfMP1eMGD0OGem0P1iNGT0201dM7@0MgMg07=c
L`1hN7P0L71`07UiN@1dM7@0NGUi0P1fMWH01@1cLg<0M7Ad07QhN01kNg/0K6a/00<0Lg=c00`0KVi^
071`L01eMGD0MGEe075aL@1dM7@0Lg=c06e]K@1[Jf/0JVYZ06m_K`1`L70206][J`0=071`L01]KFd0
Lg=c07=cL`1dM7@0Lg=c06][J`1`L700Kfm_06i^KP1ZJVX0KVi^06a/K00307]kN`0307MgM`24Q8@0
PX:20080RHV901l0Ti>C096AT@2JVYX0UIFE09>CT`29RHT0R8R807UiN@1eMGD0L71`06m_K`1cLg<0
L71`06EUI@1XJ6P0KVi^06=SH`1QHF40IVIV061PH01UIFD0H61P06=SH`1OGel0IfMW06ATI01NGUh0
GEeM05IFEP1LG5`0GUiN0080G5aL0200FUYJ05aLG01EEED0EUIF05]KF`1FEUH0FEUI05aLG01IFET0
G5aL05UIF@1DE5@0De=C05UIF@1DE5@0FEUI05iNGP1PH600F5QH059BDP1CDe<0H61P05QHF01IFET0
EeMG05]KF`1QHF40EeMG05YJFP1HF5P0DU9B05IFEQL000001P3IfMT100000040fMWI000F0=WIf@03
0000003IfMT0fMWI00<0fMWI00X0d=3@06=SH`1VIVH0Hf=S06IVIP1XJ6P0HV9R06EUI@1RHV80H61P
0`1XJ6P0301/K6`0IVIV06=SH`1XJ6P0Hf=S06QXJ01YJFT0K6a/06YZJP1YJFT0Lg=c06EUI@80I6AT
00P0Jf][06EUI@1SHf<0KVi^06UYJ@1XJ6P0IVIV06=SH`80LG5a00D0J6QX06][J`1ZJVX0KVi^06a/
K00206IVIP0706i^KP1ZJVX0JFUY06][J`1QHF40Jf][06a/K00206i^KP0=06IVIP1/K6`0K6a/06IV
IP1cLg<0K6a/071`L01YJFT0KVi^07UiN@1aLG40Jf][075aL@02079bLP0806e]K@1dM7@0KVi^07Ad
M01cLg<0KVi^071`L01aLG42071`L00506i^KP1hN7P0N7Qh06i^KP1hN7P00P1fMWH04P1gMgL0MGEe
07UiN@1`L700MWIf07QhN01eMGD0Lg=c07QhN01`L700NGUi07EeM@1nOWh0Ng]k07AdM01fMWH0Ph>3
07QhN080NGUi0180Ng]k08>3P`1nOWh0P82008>3P`1nOWh0P82007moO`21PH40Ng]k0820P01lO7`0
P82007inOP27QhL0PH6107QhN01mOGd207alO00U07moO`1jNWX0N7Qh07EeM@1iNGT0N7Qh07=cL`1l
O7`0M7Ad06m_K`1[Jf/0JVYZ06MWI`1_Kfl0NGUi07=cL`1dM7@0LW9b07emO@20P800O7al07UiN@1m
OGd0O7al07IfMP1dM7@0NWYj07]kN`1^KVh0MGEe0861P@1mOGd0NGUi07alO01]KFd0N7Qh07]kN`03
07alO00@07IfMP1mOGd0LG5a071`L01kNg/0NWYj07alO01dM7@0P82006e]K@1jNWX0L71`07=cL`1l
O7`0MGEe07QhN080LW9b00D0L71`07MgM`1bLW80Kfm_06][J`0207=cL`0307AdM01^KVh0LW9b0080
K6a/00H0LG5a07AdM01fMWH0Lg=c07AdM01^KVh2071`L00707EeM@1/K6`0M7Ad075aL@1bLW80M7Ad
07IfMP02079bLP0G06m_K`1aLG40JVYZ075aL@1kNg/0Lg=c07inOP20P800NWYj08N7Q`1nOWh0PH61
08f=S@2KVi/0ZJVY0;Bd]038b<P0alO70;6a/@2d];@0U9BD08J6QP1nOWh00P1fMWH04`1bLW80L71`
06a/K01^KVh0IFEU06MWI`1UIFD0H61P06YZJP1NGUh0HF5Q061PH01SHf<0GUiN065QH@1MGEd0Fe]K
05iNGP1OGel00P1LG5`0501PH600G5aL05IFEP1HF5P0FUYJ05aLG01MGEd0EUIF05aLG01ADE40FEUI
05]KF`1RHV80FUYJ05EEE@1IFET0HV9R065QH@1MGEd0FEUI0P1GEeL00`1EEED0De=C05EEE@0205]K
F`0605aLG01JFUX0EUIF05UIF@1DE5@0EUIF5`0000060=WIf@4000000@3IfMT001H0fMWI00<00000
0=WIf@3IfMT00`3IfMT02@3De=@0J6QX05iNGP1PH600J6QX069RHP1TI6@0IVIV06ATI00206UYJ@0A
06=SH`1WIfL0HF5Q06i^KP1]KFd0Jf][065QH@1[Jf/0J6QX06MWI`1/K6`0I6AT06QXJ01[Jf/0I6AT
06QXJ01ZJVX00P1/K6`206m_K`0506UYJ@1^KVh0Jf][06a/K01^KVh00P1ZJVX01@1]KFd0IVIV06IV
IP1ZJVX0IVIV00<0JFUY01D0IVIV075aL@1/K6`0Jf][06YZJP1[Jf/0Hf=S06QXJ01aLG40Jf][075a
L@1`L700JFUY071`L01/K6`0JVYZ06][J`1WIfL0IVIV06UYJ@1`L7000P1^KVh08P1cLg<0L71`07If
MP1_Kfl0L71`06i^KP1eMGD0LW9b07MgM`1aLG40Lg=c07IfMP1^KVh0Lg=c06ATI01dM7@0MGEe07Ad
M01fMWH0MGEe07QhN01`L700OWin06m_K`1hN7P0OGem07UiN@1nOWh0MgMg07IfMP1iNGT0N7Qh07If
MP1lO7`20861P@0G07emO@1oOgl0O7al0820P01nOWh0N7Qh07alO020P800PH6108:2PP20P800NGUi
0820P01kNg/0Ogmo07]kN`1lO7`0QXJ608>3P`1fMWH0O7al07QhN01mOGd00P1hN7P0201jNWX0LG5a
079bLP1kNg/0LG5a07]kN`1lO7`0MGEe0P1iNGT01@20P800OGem07=cL`1hN7P0Ng]k0080MWIf00/0
PH6107QhN01nOWh0OGem07EeM@1nOWh0Ng]k07QhN01jNWX0LG5a07YjNP0207]kN`0607EeM@1lO7`0
OGem079bLP1fMWH0OWin0P1jNWX00`1aLG40M7Ad07emO@0207=cL`0?07IfMP1aLG40Lg=c07MgM`1`
L700Lg=c079bLP1`L700NWYj07MgM`1dM7@0L71`07QhN01bLW80JVYZ00<0M7Ad00h0LG5a071`L01`
L700L71`06i^KP1cLg<0L71`06][J`1cLg<0LW9b06][J`1^KVh0Lg=c06m_K`80KVi^00/0K6a/071`
L01]KFd0K6a/06ATI01]KFd0KVi^06e]K@1_Kfl0M7Ad07emO@0207alO00C08>3P`2:RXX0TY:B09BD
U02[Zj/0b<S80=SHf03dm?@0nOWi0>3Ph03>c/h0/K6a08n?S`20P800MGEe07=cL`1`L700JFUY06m_
K`0206UYJ@0;05iNGP1TI6@0Hf=S06ATI01XJ6P0I6AT069RHP1LG5`0GUiN069RHP1FEUH00P1SHf<0
1@1HF5P0EUIF061PH01LG5`0EeMG0080FEUI0100G5aL05UIF@1MGEd0GEeM05UIF@1KFe/0FUYJ061P
H01KFe/0FEUI05IFEP1KFe/0GEeM05YJFP1IFET0GUiN0P1FEUH02`1HF5P0G5aL05UIF@1JFUX0HF5Q
05]KF`1LG5`0DU9B055AD@1DE5@0EUIF01L000001P3IfMT100000040fMWI000F0=WIf@030000003I
fMT0fMWI00<0fMWI00d0c/k>06ATI01YJFT0IfMW06EUI@1VIVH0Hf=S06a/K01SHf<0J6QX069RHP1U
IFD0I6AT0080Hf=S00D0I6AT06QXJ01VIVH0HV9R06IVIP0206e]K@0406a/K01ZJVX0Kfm_06YZJP80
IVIV0100Hf=S06][J`1VIVH0IfMW06QXJ01UIFD0JVYZ06][J`1YJFT0L71`06ATI01cLg<0IVIV075a
L@1/K6`0IVIV0P1YJFT06@1ZJVX0K6a/06YZJP1/K6`0LW9b06UYJ@1WIfL0Jf][079bLP1[Jf/0J6QX
06i^KP1YJFT0Jf][07=cL`1XJ6P0KVi^06a/K01]KFd0Jf][06i^KP1aLG40IVIV07=cL`1]KFd00P1f
MWH02@1cLg<0JVYZ07EeM@1gMgL0KFe]07UiN@1eMGD0KVi^07UiN@02071`L00I079bLP1iNGT0MWIf
07YjNP1fMWH0MgMg07QhN01eMGD0MWIf075aL@1gMgL0N7Qh07IfMP1hN7P0PX:207]kN`1gMgL0OGem
07EeM@1hN7P0Ng]k07emO@1kNg/0Ph>307]kN`0207alO00?07EeM@1jNWX0OWin07UiN@1kNg/0O7al
0861P@1nOWh0N7Qh07alO01fMWH0Ogmo07inOP24Q8@0OGem0080NGUi00T0MgMg07UiN@1cLg<0N7Qh
07]kN`1iNGT0NWYj071`L01kNg/00P1dM7@02`1iNGT0NWYj07UiN@21PH40QHF507inOP1kNg/0O7al
07=cL`1lO7`0Ng]k0080MgMg0140MGEe07QhN01jNWX0MGEe07UiN@1dM7@0NGUi075aL@1jNWX0LW9b
07EeM@1dM7@0MGEe07UiN@1cLg<0O7al07YjNP0207IfMP0907UiN@1fMWH0MgMg079bLP1dM7@0MgMg
07]kN`1cLg<0MWIf0080LW9b00<0Ng]k075aL@1aLG400P1_Kfl0801`L700MGEe07AdM01_Kfl0LG5a
07EeM@1bLW80LG5a06m_K`1aLG40MWIf071`L01^KVh0Kfm_071`L01^KVh0JFUY06QXJ01_Kfl0JVYZ
06UYJ@1]KFd0Jf][06YZJP1[Jf/0KFe]071`L01_Kfl0LG5a071`L01cLg<0MGEe0P1jNWX01`1iNGT0
QXJ608j>SP2FUYH0]kNg0=[JfP3kno/00P3oool02`3fm_H0dm?C0:^[Z`2ATI40QHF50820P01nOWh0
L71`06YZJP1]KFd0IVIV0080IFEU00D0IfMW06ATI01TI6@0Hf=S069RHP0205QHF00305iNGP1RHV80
Hf=S0080F5QH01X0G5aL05]KF`1HF5P0EUIF05mOG`1HF5P0Fe]K05aLG01IFET0GUiN05ADE01PH600
G5aL065QH@1CDe<0EeMG05ADE01LG5`0EUIF05iNGP1QHF40FEUI05iNGP1LG5`0FEUI05YJFP80EUIF
00P0H61P05YJFP1FEUH0FUYJ05UIF@1EEED0E5AD05QHF1L000001P3IfMT100000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI01L0cLg=06IVIP1SHf<0HF5Q06MWI`1VIVH0IFEU05mOG`1VIVH0
Hf=S06MWI`1TI6@0JFUY06QXJ01WIfL0IVIV06][J`1ZJVX0J6QX06MWI`1TI6@0IfMW06UYJ@0206][
J`80JFUY00d0J6QX06EUI@1XJ6P0L71`06UYJ@1VIVH0KVi^06MWI`1ZJVX0K6a/06i^KP1[Jf/0JFUY
0080K6a/01/0IVIV069RHP1VIVH0IVIV06a/K01XJ6P0JFUY071`L01cLg<0Jf][06IVIP1]KFd0Jf][
06a/K01`L700KVi^06][J`1`L700LG5a06][J`1WIfL0Jf][06UYJ@1`L700LG5a06e]K@1_Kfl00P1]
KFd00`1`L700Lg=c07MgM`0207AdM00O075aL@1eMGD0NWYj07AdM01_Kfl0KVi^071`L01cLg<0LG5a
07=cL`1fMWH0LG5a07MgM`1cLg<0MgMg07UiN@1jNWX0L71`07emO@1fMWH0P82007]kN`1hN7P0O7al
07IfMP24Q8@0Ng]k07UiN@1hN7P0Q8B407alO00207QhN00C07emO@24Q8@0P82007IfMP1eMGD0P820
07]kN`1lO7`0Ogmo07emO@1lO7`0NGUi0820P01eMGD0OWin07YjNP1lO7`0NWYj07IfMP0207UiN@09
07]kN`1lO7`0MGEe07=cL`1hN7P0Ng]k07alO01cLg<0M7Ad0080NGUi0P1nOWh207]kN`0K07inOP21
PH40OGem07inOP1jNWX0MgMg07YjNP1fMWH0NGUi07YjNP1dM7@0OGem07QhN01kNg/0NGUi07alO01k
Ng/0Lg=c07alO01fMWH0MgMg07]kN`1gMgL0Ng]k07IfMP1^KVh0LG5a0080L71`0P1bLW808P1cLg<0
LG5a075aL@1bLW80L71`07IfMP1dM7@0LG5a071`L01cLg<0LG5a07inOP1bLW80L71`07IfMP1/K6`0
J6QX07=cL`1]KFd0M7Ad06e]K@1`L700Jf][06e]K@1[Jf/0Lg=c06a/K01cLg<0MGEe06a/K01iNGT0
Jf][06QXJ01`L70206][J`0@07IfMP1[Jf/0L71`071`L01bLW80Kfm_07]kN`1lO7`0MWIf07inOP29
RHT0UYJF0:>SX`32`/80i^KV0?gmo@80oooo00H0m?Cd0=[JfP2a/K40VIVI08J6QP1oOgl207QhN00@
06i^KP1YJFT0Kfm_06][J`1YJFT0IFEU069RHP1OGel0Hf=S05iNGP1QHF40H61P05iNGP1FEUH0H61P
05UIF@80GUiN00X0FEUI055AD@1OGel0Fe]K05iNGP1IFET0GemO05eMG@1JFUX0H61P0P1KFe/05`1H
F5P0EUIF05aLG01GEeL0D51@05iNGP1KFe/0FUYJ05eMG@1FEUH0FUYJ05QHF01KFe/0H61P05]KF`1J
FUX0EeMG05EEE@1FEUH0FEUI05MGE`1DE5@0EUIF01L000001P3IfMT100000040fMWI000F0=WIf@80
0000103IfMT0503>c/h0G5aL06=SH`1PH600Hf=S069RHP1XJ6P0Jf][06ATI01WIfL0I6AT06QXJ01Y
JFT0I6AT06a/K01WIfL0GemO06=SH`1XJ6P0Hf=S0`1YJFT00`1[Jf/0H61P06MWI`0206YZJP0n06a/
K01RHV80Jf][06=SH`1ZJVX0JFUY06m_K`1WIfL0JFUY06][J`1XJ6P0IfMW06][J`1XJ6P0IfMW06QX
J01ZJVX0Jf][06=SH`1WIfL0KFe]06i^KP1ZJVX0Jf][06IVIP1[Jf/0KFe]06][J`1bLW80KVi^06a/
K01ZJVX0Lg=c07AdM01hN7P0M7Ad06a/K01[Jf/0LG5a07IfMP1[Jf/0JVYZ06MWI`1/K6`0L71`06m_
K`1cLg<0M7Ad079bLP1aLG40Lg=c071`L01eMGD0NWYj07=cL`1bLW80MgMg079bLP1dM7@0K6a/07Ee
M@1aLG4207EeM@06075aL@1cLg<0Ng]k07IfMP1kNg/0NGUi0P1fMWH0B`1iNGT0NWYj07UiN@1cLg<0
N7Qh07inOP21PH40NGUi0861P@1nOWh0O7al07moO`1kNg/0Lg=c07QhN01lO7`0NWYj07=cL`1mOGd0
Ogmo08B4Q01nOWh0PH61079bLP1kNg/0O7al07EeM@20P800LG5a07alO01hN7P0Lg=c07IfMP1aLG40
N7Qh07alO01hN7P0OGem079bLP1cLg<0MWIf07alO01iNGT0O7al07emO@1eMGD0OWin0820P01fMWH0
O7al071`L01kNg/0NGUi07EeM@1dM7@0Ng]k07MgM`1`L700N7Qh07=cL`1^KVh0OWin07UiN@1bLW80
NWYj07moO`1fMWH0NWYj07IfMP1dM7@0Ng]k079bLP1aLG40MWIf07EeM@0207IfMP0K07=cL`1[Jf/0
LW9b06a/K01cLg<0LG5a071`L01[Jf/0MgMg071`L01ZJVX0LG5a07AdM01hN7P0M7Ad07UiN@1hN7P0
MGEe06i^KP1aLG40LW9b06a/K01aLG40K6a/06YZJP1/K6`0KFe]0080L71`00d0Jf][06UYJ@1_Kfl0
KVi^06QXJ01ZJVX0J6QX06a/K01aLG40K6a/07IfMP1aLG40NGUi0080MWIf00L0Ng]k0820P027QhL0
WIfM0;Jf]P3Kfm/0jNWY0080oooo0140fMWI0<?3``2WYjL0TI6A08R8R023Ph<0N7Qh071`L01^KVh0
K6a/06i^KP1XJ6P0JVYZ06QXJ01OGel0I6AT06QXJ00305iNGP0F06EUI@1HF5P0FUYJ061PH01KFe/0
Hf=S05iNGP1QHF40GUiN05EEE@1FEUH0Fe]K05IFEP1LG5`0E5AD05eMG@1PH600Hf=S05MGE`1KFe/0
F5QH05aLG080FEUI0140HF5Q05eMG@1KFe/0E5AD05MGE`1LG5`0EeMG05aLG01IFET0G5aL05MGE`1J
FUX0EUIF05]KF`1DE5@0F5QH05UIF@0G000000D0fMWI0P0000010=WIf@005P3IfMT00`000000fMWI
0=WIf@030=WIf@0;0=?Cd`1NGUh0IfMW06=SH`1YJFT0H61P05aLG01QHF40GemO06=SH`1VIVH00P1U
IFD04@1YJFT0Hf=S06QXJ01ZJVX0Hf=S06EUI@1`L700Jf][06a/K01TI6@0J6QX06IVIP1YJFT0I6AT
06UYJ@1VIVH0IfMW0080Kfm_01L0IVIV06ATI01`L700JVYZ06MWI`1YJFT0HV9R06QXJ01^KVh0JFUY
06YZJP1UIFD0JVYZ06=SH`1WIfL0K6a/06QXJ01/K6`0JVYZ06ATI01XJ6P0IVIV07IfMP02071`L00;
06a/K01YJFT0Jf][06][J`1^KVh0KFe]06YZJP1fMWH0K6a/06m_K`1cLg<00P1_Kfl0501eMGD0L71`
079bLP1^KVh0N7Qh07UiN@1bLW80L71`075aL@1fMWH0LG5a071`L01_Kfl0LW9b07AdM01^KVh0Lg=c
06e]K@1hN7P0KVi^0P1hN7P02`1jNWX0MWIf07=cL`1nOWh0Kfm_07AdM01`L700O7al07QhN01iNGT0
N7Qh0080NGUi0140O7al07EeM@1iNGT0NGUi07]kN`1lO7`0OGem07AdM01lO7`0NWYj07]kN`1mOGd0
OWin07alO01nOWh0OGem07UiN@0207]kN`080820P01fMWH0NWYj0861P@1kNg/0N7Qh07=cL`1mOGd2
07alO00]07IfMP1kNg/0Ng]k07MgM`1hN7P0NGUi07alO01mOGd0MWIf06a/K01fMWH0N7Qh07=cL`1h
N7P0NGUi07QhN01fMWH0N7Qh07alO01aLG40NGUi07YjNP1^KVh0MWIf07EeM@1hN7P0MGEe07]kN`1h
N7P0LW9b07EeM@1iNGT0Lg=c075aL@1bLW80LG5a071`L01cLg<0KVi^06m_K`1aLG40LW9b07AdM01a
LG40N7Qh0080L71`01T0KVi^07IfMP1eMGD0Lg=c06m_K`1cLg<0Kfm_06a/K01eMGD0Jf][06YZJP1f
MWH0M7Ad06i^KP1`L700Lg=c06YZJP1bLW80Kfm_06][J`1^KVh0K6a/06][J`1`L700Hf=S0080K6a/
0200IVIV06QXJ01_Kfl0KVi^06][J`1XJ6P0Lg=c06i^KP1dM7@0MWIf06e]K@1[Jf/0N7Qh07IfMP20
P800RHV908j>SP2PX:00`<300<71`@3Bd]80b<S80;>c/`2[Zj/0UYJF08R8R01oOgl0PH6107AdM01g
MgL0LG5a06e]K@80K6a/01L0GUiN06EUI@1WIfL0GUiN06UYJ@1OGel0HV9R05mOG`1PH600GUiN05]K
F`1NGUh0FEUI05eMG@1JFUX0De=C05QHF01PH600GUiN05aLG01KFe/0HF5Q05UIF@0206=SH`0?05UI
F@1MGEd0G5aL05MGE`1IFET0De=C05iNGP1JFUX0FEUI05iNGP1KFe/0GEeM05mOG`1MGEd0EEEE0080
Fe]K00L0G5aL055AD@1IFET0FEUI05EEE@1GEeL0FUYJ01L000001P3IfMT100000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI00X0dM7A061PH01TI6@0Hf=S06ATI01NGUh0IFEU06][J`1XJ6P0
L71`0P1YJFT03`1VIVH0IfMW06QXJ01YJFT0I6AT06IVIP1WIfL0LG5a06QXJ01[Jf/0IVIV06QXJ01^
KVh0KFe]071`L00206UYJ@@0J6QX00D0Lg=c06YZJP1OGel0KVi^06QXJ00206][J`0606IVIP1YJFT0
JFUY06][J`1VIVH0J6QX0`1YJFT04P1^KVh0Hf=S06UYJ@1[Jf/0IVIV06i^KP1[Jf/0L71`06MWI`1Y
JFT0Kfm_06e]K@1ZJVX0KVi^06][J`1fMWH0LW9b06QXJ0@0K6a/00<0LW9b07QhN01aLG400P1iNGT0
3`1/K6`0MWIf07AdM01cLg<0N7Qh07MgM`1hN7P0MgMg071`L01eMGD0M7Ad079bLP1hN7P0Lg=c07Qh
N002075aL@0306m_K`1iNGT0MgMg0080M7Ad00@0N7Qh07=cL`1iNGT0MWIf0P1aLG401P20P800MWIf
07QhN01aLG40M7Ad07MgM`80Ng]k00@0L71`07UiN@1hN7P0NGUi0P1gMgL02P1lO7`0N7Qh07=cL`1^
KVh0MgMg079bLP1iNGT0PH6107=cL`1kNg/307UiN@0:07IfMP1hN7P0MWIf07IfMP1aLG40M7Ad079b
LP1`L700NGUi07AdM080NGUi00<0N7Qh07IfMP1eMGD00P1fMWH02P1hN7P0MWIf07alO01mOGd0MWIf
07QhN01fMWH0M7Ad07QhN01gMgL207QhN00D07=cL`1bLW80OWin07YjNP1`L700NGUi07AdM01hN7P0
Lg=c07QhN01`L700MWIf07QhN01]KFd0MWIf07AdM01fMWH0LG5a071`L01bLW82071`L00706i^KP1d
M7@0LG5a06m_K`1aLG40MWIf06m_K`0207=cL`0607UiN@1_Kfl0L71`07MgM`1]KFd0J6QX0P1`L700
1P1[Jf/0L71`06UYJ@1]KFd0LG5a06a/K080Jf][00/0I6AT06][J`1^KVh0IfMW06a/K01YJFT0J6QX
06i^KP1aLG40Kfm_06e]K@0206i^KP0D071`L01kNg/0O7al07inOP28R8P0SHf=09ZJVP2GUiL0Y:BT
09RHV02DU9@0TI6A08j>SP26QXH0P82007]kN`1fMWH0L71`06][J`1ZJVX206a/K00C061PH01TI6@0
IVIV06=SH`1XJ6P0G5aL06=SH`1KFe/0G5aL05UIF@1MGEd0G5aL05iNGP1HF5P0EeMG05eMG@1KFe/0
FUYJ061PH00205iNGP0?05mOG`1PH600G5aL05mOG`1IFET0GUiN05aLG01FEUH0Fe]K06=SH`1JFUX0
HF5Q05mOG`1PH600EUIF00<0EEEE00X0HF5Q05]KF`1JFUX0Fe]K059BDP1NGUh0Fe]K05IFEP1KFe/0
EUIF5`0000060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT01P3Cdm<0IfMW
06=SH`1VIVH0I6AT06IVIP80Hf=S00D0HF5Q06UYJ@1QHF40JVYZ06][J`0206IVIP0A06=SH`1/K6`0
IVIV06QXJ01/K6`0HF5Q06MWI`1/K6`0GemO06a/K01XJ6P0JFUY06ATI01VIVH0Jf][06i^KP1PH600
0P1VIVH03P1ZJVX0IfMW06][J`1TI6@0IfMW065QH@1[Jf/0KFe]06IVIP1UIFD0IVIV06a/K01VIVH0
Jf][0P1ZJVX0101[Jf/0JFUY071`L01ZJVX206a/K00/071`L01/K6`0LG5a06e]K@1`L700KVi^07=c
L`1XJ6P0L71`06UYJ@1]KFd0Kfm_06QXJ01`L700KVi^07QhN01fMWH0K6a/07=cL`1aLG40JFUY07Qh
N01^KVh0Lg=c079bLP1dM7@0LG5a07=cL`1eMGD0LG5a07=cL`1aLG40N7Qh07AdM01iNGT0LG5a07If
MP1dM7@0Ng]k07IfMP1dM7@0OWin07EeM@1gMgL207QhN00807IfMP1iNGT0P82007AdM020P800OGem
07AdM01lO7`207QhN00307alO023Ph<0MWIf0080Ng]k00<0NWYj07UiN@1eMGD00P1hN7P03`1oOgl0
O7al07alO01iNGT0O7al07UiN@1jNWX0M7Ad07UiN@1jNWX0OGem07AdM01bLW80NGUi07MgM`0507If
MP0L075aL@1kNg/0MgMg07]kN`1fMWH0NWYj075aL@1dM7@0LW9b07QhN01nOWh0M7Ad075aL@1gMgL0
N7Qh07IfMP1kNg/0O7al07EeM@1fMWH0LW9b07QhN01gMgL0MGEe07QhN01fMWH0L71`07AdM080MWIf
00l0LG5a07alO01cLg<0MGEe07=cL`1fMWH0KVi^079bLP1dM7@0Kfm_06UYJ@1aLG40Lg=c06][J`1_
Kfl00P1aLG408`1/K6`0MGEe06YZJP1]KFd0L71`079bLP1_Kfl0KVi^07=cL`1YJFT0KVi^079bLP1[
Jf/0K6a/06UYJ@1WIfL0JVYZ06ATI01^KVh0Jf][079bLP1SHf<0LG5a06YZJP1/K6`0Lg=c06i^KP1X
J6P0K6a/075aL@1WIfL0LG5a06m_K`1fMWH0OWin0080PX:200D0RHV908^;R`2;Rh/0RHV90820P002
08j>SP0A07alO01gMgL0MgMg07MgM`1^KVh0JFUY06QXJ01UIFD0IVIV06UYJ@1ZJVX0I6AT069RHP1V
IVH0I6AT069RHP1NGUh00P1LG5`0201OGel0H61P061PH01MGEd0G5aL05]KF`1IFET0GEeM0P1SHf<0
7@1HF5P0G5aL05aLG01HF5P0G5aL05]KF`1LG5`0GUiN05aLG01KFe/0FUYJ05iNGP1JFUX0F5QH05UI
F@1EEED0G5aL05]KF`1HF5P0H61P05]KF`1GEeL0Fe]K04m?C`1QHF40EeMG05ADE01GEeL0De=C01L0
00001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00d0eMGE065QH@1PH600
HF5Q06ATI01/K6`0H61P06QXJ01YJFT0Hf=S06MWI`1RHV80JVYZ0080J6QX00T0Hf=S06QXJ01WIfL0
K6a/075aL@1]KFd0I6AT06IVIP1SHf<00P1^KVh0501VIVH0Hf=S06ATI01XJ6P0Hf=S06YZJP1WIfL0
J6QX06a/K01SHf<0JFUY06MWI`1PH600J6QX06MWI`1PH600KVi^079bLP1[Jf/0IVIV0`1[Jf/0301Y
JFT0LG5a06UYJ@1`L700J6QX079bLP1_Kfl0JFUY06QXJ01aLG40MGEe06UYJ@80Kfm_00<0LG5a06a/
K01YJFT00P1[Jf/207=cL`0306m_K`1[Jf/0KVi^0080Lg=c00P0LW9b07alO01/K6`0O7al07AdM01]
KFd0N7Qh06i^KP80LG5a00<0L71`07IfMP1aLG400P1`L7002`1aLG40LW9b07AdM01aLG40NGUi0861
P@1iNGT0Lg=c07QhN01dM7@0Ng]k00<0N7Qh02H0NWYj07UiN@1hN7P0NGUi07alO01aLG40Lg=c07Yj
NP1lO7`0N7Qh07UiN@1nOWh0MWIf07MgM`1nOWh0P82007emO@1hN7P0O7al07QhN01kNg/0MgMg07Ad
M01hN7P0PH6107QhN021PH40K6a/07emO@1`L700N7Qh07UiN@1nOWh0K6a/07=cL`1dM7@0NWYj07Qh
N080NGUi00X0MGEe075aL@1cLg<0Lg=c07AdM01^KVh0M7Ad07]kN`1`L700N7Qh0P1dM7@04@1iNGT0
NWYj07]kN`1gMgL0Lg=c07QhN01kNg/0LG5a07QhN01fMWH0NGUi07=cL`1`L700MWIf06YZJP1_Kfl0
K6a/00@0MWIf00X0M7Ad071`L01fMWH0L71`07IfMP1dM7@0L71`06a/K01[Jf/0Kfm_0P1aLG401@1^
KVh0LG5a06i^KP1cLg<0KVi^0080Jf][00D0K6a/075aL@1cLg<0Jf][06a/K00206m_K`0X06a/K01T
I6@0K6a/07=cL`1YJFT0L71`06UYJ@1SHf<0J6QX06ATI01`L700I6AT075aL@1[Jf/0L71`06m_K`1X
J6P0JVYZ06m_K`1`L700Kfm_07UiN@1nOWh0Ogmo07IfMP1kNg/0MGEe0820P01kNg/0OWin06m_K`1f
MWH0Lg=c07QhN01cLg<0L71`06QXJ01[Jf/0IVIV061PH0<0I6AT00L0EeMG06ATI01SHf<0HF5Q069R
HP1QHF40HV9R00<0GUiN00l0G5aL05iNGP1LG5`0GemO05aLG01TI6@0EEEE05iNGP1LG5`0H61P05MG
E`1NGUh0H61P05aLG01GEeL00P1MGEd205UIF@0;05iNGP1FEUH0F5QH05]KF`1GEeL0Fe]K05UIF@1C
De<0FUYJ05=CD`1GEeL00P1CDe<00`1GEeL0EEEE05=CD`0G000000H0fMWI0@0000010=WIf@005P3I
fMT00`000000fMWI0=WIf@030=WIf@0I0=kNgP1WIfL0IFEU06ATI01SHf<0IVIV06UYJ@1TI6@0IVIV
06EUI@1/K6`0JFUY06][J`1SHf<0J6QX069RHP1/K6`0IFEU06e]K@1VIVH0JFUY06YZJP1WIfL0JVYZ
06][J`0206MWI`09061PH01XJ6P0GUiN06m_K`1XJ6P0IVIV06YZJP1TI6@0JFUY0080JVYZ0P1XJ6P2
06][J`0P06YZJP1/K6`0JFUY06UYJ@1XJ6P0IFEU06QXJ01ZJVX0K6a/06][J`1aLG40IFEU06UYJ@1V
IVH0JFUY06a/K01WIfL0L71`06a/K01XJ6P0Lg=c075aL@1/K6`0Jf][06a/K01^KVh0K6a/071`L01d
M7@0KVi^06][J`1`L70206a/K00P07AdM01eMGD0LG5a071`L01YJFT0Jf][07IfMP1bLW80L71`06QX
J01^KVh0NGUi07IfMP1/K6`0L71`07alO01aLG40OGem07EeM@1`L700MgMg07AdM01oOgl0NGUi07em
O@1gMgL0MGEe07alO01^KVh0M7Ad079bLP1cLg<207AdM00;07EeM@1jNWX0N7Qh07inOP1mOGd0MWIf
07YjNP1kNg/0Lg=c07AdM01iNGT00P1fMWH05@1jNWX0N7Qh07]kN`1cLg<0N7Qh071`L01bLW80N7Qh
07EeM@1nOWh0MgMg07IfMP1dM7@0Lg=c07UiN@1fMWH0M7Ad07QhN01^KVh0LG5a06][J`0207AdM006
075aL@1bLW80Lg=c06m_K`1/K6`0MWIf0P1dM7@01P1bLW80K6a/07EeM@1nOWh0NGUi08>3P`80MGEe
00h0M7Ad07]kN`1eMGD0LG5a07alO01gMgL0KVi^075aL@1`L700MWIf06i^KP1/K6`0LG5a06][J`<0
M7Ad00H0LW9b07EeM@1_Kfl0MWIf07=cL`1gMgL3071`L00;06][J`1eMGD0JVYZ07=cL`1^KVh0Jf][
07=cL`1]KFd0K6a/06i^KP1[Jf/00P1WIfL03P1^KVh0IVIV07=cL`1/K6`0IVIV06a/K01[Jf/0K6a/
061PH01TI6@0IfMW06][J`1VIVH0I6AT0P1VIVH0101ZJVX0IfMW06EUI@1XJ6P206i^KP<0Lg=c00D0
LW9b06m_K`1aLG40Lg=c06IVIP0207AdM00J071`L01YJFT0L71`06IVIP1`L700KVi^06IVIP1RHV80
I6AT06YZJP1TI6@0IFEU06QXJ01UIFD0GemO05eMG@1VIVH0FEUI061PH01MGEd0GemO06ATI01MGEd0
H61P05]KF`1JFUX2061PH00?05QHF01KFe/0GUiN05MGE`1HF5P0EUIF05mOG`1FEUH0Fe]K05QHF01V
IVH0H61P05mOG`1IFET0GUiN0080Fe]K0`1DE5@02P1NGUh0EUIF055AD@1FEUH0FEUI05ADE01KFe/0
F5QH05IFEP1ADE4G000000H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0C
0=oOg`1TI6@0I6AT06m_K`1]KFd0I6AT06YZJP1UIFD0JFUY06QXJ01UIFD0IVIV06ATI01PH600Jf][
06=SH`1ZJVX0K6a/06e]K@0206][J`0506YZJP1SHf<0GUiN06IVIP1TI6@00P1WIfL09@1SHf<0JFUY
06][J`1QHF40Jf][06YZJP1MGEd0K6a/06QXJ01QHF40JFUY06ATI01^KVh0J6QX06MWI`1[Jf/0IVIV
06][J`1_Kfl0IVIV06UYJ@1WIfL0IVIV06EUI@1/K6`0J6QX06i^KP1`L700JFUY06IVIP1/K6`0JFUY
071`L01YJFT0JVYZ06EUI@1`L7000`1WIfL08@1aLG40M7Ad06a/K01iNGT0KVi^06m_K`1`L700Jf][
071`L01ZJVX0JFUY071`L01bLW80M7Ad07IfMP1dM7@0KFe]06m_K`1`L700Kfm_07=cL`1hN7P0MGEe
07AdM01/K6`0KVi^07AdM01fMWH0LW9b071`L01gMgL0M7Ad071`L00207QhN00:07]kN`1fMWH0N7Qh
07QhN01iNGT0O7al07UiN@1kNg/0MWIf07inOP<0Ng]k00L0PH6107inOP1iNGT0NWYj0820P01iNGT0
Ng]k0080MGEe00<0O7al07MgM`1eMGD00P1hN7P03P1aLG40MWIf07IfMP1aLG40Lg=c07UiN@1aLG40
KVi^07QhN01fMWH0LW9b075aL@1dM7@0Kfm_0P1fMWH05`1^KVh0NGUi07MgM`1iNGT0KFe]07alO01f
MWH0MGEe07AdM01`L700Lg=c075aL@1hN7P0M7Ad07=cL`1`L700NWYj075aL@1_Kfl0NGUi07=cL`1d
M7@0L71`0080MWIf0P1`L700201dM7@0Jf][075aL@1aLG40KVi^071`L01aLG40L71`0P1dM7@04`1a
LG40M7Ad07IfMP1fMWH0KVi^07=cL`1`L700M7Ad06a/K01gMgL0Kfm_06a/K01XJ6P0KVi^06UYJ@1Z
JVX0K6a/06][J`1XJ6P00P1[Jf/01P1]KFd0K6a/06][J`1QHF40L71`06UYJ@80J6QX0P1RHV801@1[
Jf/0K6a/06MWI`1dM7@0Hf=S0080JFUY00@0KVi^06UYJ@1ZJVX0Kfm_0P1]KFd03`1`L700Lg=c06i^
KP1`L700K6a/07IfMP1cLg<0JFUY06IVIP1/K6`0JFUY065QH@1VIVH0LG5a06IVIP0306QXJ00706=S
H`1PH600Hf=S06ATI01QHF40GEeM05aLG002065QH@0H05mOG`1RHV80FUYJ05aLG01MGEd0G5aL05iN
GP1HF5P0G5aL05eMG@1DE5@0FUYJ05]KF`1IFET0H61P05iNGP1MGEd0GUiN05MGE`1KFe/0De=C05aL
G01FEUH0FEUI0P1DE5@02`1CDe<0FEUI05IFEP1DE5@0F5QH05IFEP1HF5P0Fe]K05iNGP1CDe<0DE5A
01L000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0300hN7Q06IVIP1[
Jf/0IfMW065QH@1SHf<0I6AT06MWI`1TI6@0JFUY06IVIP1XJ6P0I6AT06QXJ01TI6@0G5aL06EUI@1X
J6P0JFUY06QXJ01RHV80LG5a06IVIP1XJ6P0I6AT06a/K01ZJVX0GUiN06ATI01PH600Hf=S06ATI01Z
JVX0I6AT05iNGP1WIfL0HF5Q06m_K`1SHf<0K6a/061PH01VIVH0JFUY06IVIP1YJFT0IVIV071`L01^
KVh206UYJ@07075aL@1^KVh0Hf=S06UYJ@1^KVh0J6QX071`L00206e]K@0P06EUI@1[Jf/0IVIV06m_
K`1YJFT0KFe]06a/K01YJFT0KVi^06QXJ01]KFd0KVi^071`L01^KVh0Jf][07=cL`1^KVh0M7Ad06UY
J@1hN7P0K6a/06i^KP1aLG40Lg=c079bLP1_Kfl0MGEe07UiN@1`L700MWIf07AdM01]KFd2075aL@0R
07IfMP1nOWh0Kfm_06e]K@1`L700M7Ad07EeM@1jNWX0MWIf07=cL`1hN7P0LW9b07emO@1lO7`0NGUi
07MgM`1eMGD0OWin07YjNP1eMGD0MWIf07]kN`22PX80Ng]k07MgM`1cLg<0MWIf07UiN@1hN7P0M7Ad
07EeM@1aLG40MgMg06m_K`@0N7Qh00h0L71`07UiN@1mOGd0MGEe07AdM01hN7P0LW9b06i^KP1iNGT0
LG5a07YjNP1gMgL0KVi^07=cL`80LG5a00L0MgMg07=cL`1dM7@0JVYZ07QhN01aLG40M7Ad00<0LW9b
01D0MWIf07QhN01hN7P0KFe]07alO01[Jf/0Lg=c071`L01aLG40L71`06a/K01ZJVX0M7Ad07IfMP1a
LG40NGUi07=cL`1aLG40MgMg06i^KP1bLW800P1lO7`0201cLg<0M7Ad07=cL`1aLG40KVi^06m_K`1d
M7@0LG5a0`1^KVh0901/K6`0JFUY06MWI`1cLg<0M7Ad06i^KP1_Kfl0LG5a06UYJ@1VIVH0K6a/06UY
J@1aLG40J6QX06i^KP1ZJVX0Jf][06QXJ01WIfL0KFe]06UYJ@1VIVH0Jf][06=SH`1/K6`0KVi^06][
J`1VIVH0JFUY06m_K`1YJFT0L71`06i^KP1/K6`0J6QX06e]K@80L71`00@0JFUY071`L01/K6`0Jf][
0P1XJ6P0701YJFT0GEeM06QXJ01RHV80IVIV06UYJ@1WIfL0Hf=S06IVIP1YJFT0JVYZ06MWI`1LG5`0
IVIV065QH@1NGUh0HF5Q06ATI01KFe/0GEeM06ATI01SHf<0H61P05UIF@1SHf<0EUIF05aLG01JFUX2
05aLG00A05IFEP1IFET0GEeM05]KF`1LG5`0GUiN061PH01JFUX0HV9R05iNGP1LG5`0FEUI05MGE`1M
GEd0EUIF065QH@1HF5P00P1BDU801`1JFUX0EeMG05eMG@1@D500DU9B061PH01EEED05`0000060=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT01@3@d=00HF5Q06EUI@1NGUh0GemO
0080Jf][00d0I6AT06UYJ@1QHF40IVIV06MWI`1XJ6P0JVYZ05iNGP1YJFT0I6AT06QXJ01WIfL0JFUY
0080Hf=S0P1VIVH03P1TI6@0JVYZ06i^KP1[Jf/0HV9R06UYJ@1UIFD0JFUY06EUI@1OGel0I6AT06UY
J@1VIVH0J6QX0P1/K6`206QXJ00J06YZJP1cLg<0Hf=S06YZJP1SHf<0K6a/06IVIP1WIfL0K6a/079b
LP1/K6`0IVIV06a/K01]KFd0Jf][075aL@1VIVH0JVYZ06a/K01aLG40IVIV06UYJ@1`L700K6a/075a
L@1cLg<2075aL@80JFUY0100L71`06][J`1cLg<0Kfm_07IfMP1cLg<0JVYZ079bLP1[Jf/0KVi^07=c
L`1]KFd0J6QX079bLP1_Kfl0JVYZ0P1dM7@2071`L00<075aL@1WIfL0Lg=c07alO01hN7P0KVi^07=c
L`1`L700M7Ad07UiN@1jNWX0M7Ad0P1hN7P0501^KVh0Kfm_07]kN`1iNGT0Lg=c07UiN@1kNg/0NGUi
07]kN`1iNGT0N7Qh08>3P`1oOgl0KVi^07=cL`1fMWH0Ng]k07=cL`1fMWH0OGem0P1cLg<0201eMGD0
Lg=c079bLP1jNWX0L71`07QhN01eMGD0MWIf0P1cLg<00`1hN7P0L71`07UiN@02071`L005075aL@1c
Lg<0LW9b075aL@1bLW800P1cLg<0101`L700MGEe06i^KP1cLg<2071`L00D07=cL`1aLG40MWIf07=c
L`1`L700Jf][07IfMP1_Kfl0MgMg07IfMP1`L700Jf][07=cL`1bLW80L71`07EeM@1cLg<0M7Ad07=c
L`1^KVh206m_K`0:06e]K@1aLG40N7Qh06m_K`1]KFd0M7Ad071`L01YJFT0KVi^079bLP80Kfm_00L0
JVYZ06i^KP1XJ6P0K6a/06ATI01/K6`0JFUY0080KFe]01h0LG5a06YZJP1[Jf/0IVIV06QXJ01VIVH0
Kfm_075aL@1SHf<0JVYZ06a/K01NGUh0L71`06a/K01XJ6P0KFe]069RHP1ZJVX0IfMW06QXJ01SHf<0
IVIV06UYJ@1WIfL0J6QX06UYJ@1^KVh0K6a/075aL@1TI6@506QXJ00F06IVIP1SHf<0H61P06EUI@1Y
JFT0Hf=S06QXJ01TI6@0Hf=S06IVIP1XJ6P0HF5Q06=SH`1RHV80Hf=S065QH@1LG5`0HV9R05iNGP1S
Hf<0IVIV06EUI@80GEeM01D0HF5Q05]KF`1MGEd0Fe]K05eMG@1LG5`0H61P06ATI01VIVH0FEUI055A
D@1PH600GUiN05mOG`1KFe/0EeMG05iNGP1LG5`0De=C05EEE@1JFUX00P1CDe<02P1HF5P0EUIF05]K
F`1OGel0EUIF05UIF@1JFUX0FEUI05QHF01DE5@G000000H0fMWI0@0000010=WIf@000`3IfMT30000
0080fMWI0P0000040=WIf@8000001P3IfMT00`000000fMWI0=WIf@030=WIf@0:0=OGe`1UIFD0KFe]
065QH@1XJ6P0IVIV06EUI@1VIVH0JFUY06=SH`80JFUY00T0GEeM061PH01/K6`0IfMW069RHP1aLG40
Hf=S06ATI01ZJVX00P1TI6@01@1WIfL0JFUY06i^KP1PH600J6QX0080I6AT00P0JVYZ06ATI01VIVH0
KVi^075aL@1XJ6P0IVIV06=SH`80JFUY0`1[Jf/0501XJ6P0IVIV06][J`1TI6@0IfMW075aL@1^KVh0
JFUY06][J`1/K6`0Lg=c065QH@1VIVH0Jf][06QXJ01VIVH0JVYZ071`L01[Jf/0K6a/0P1XJ6P05P1/
K6`0Jf][06i^KP1/K6`0L71`06YZJP1]KFd0Jf][06i^KP1_Kfl0LW9b06i^KP1/K6`0KVi^07=cL`1`
L700J6QX06m_K`1`L700Jf][06a/K01XJ6P206e]K@0^06i^KP1aLG40L71`075aL@1cLg<0MWIf07=c
L`1ZJVX0M7Ad075aL@1cLg<0MWIf079bLP1jNWX0LG5a07IfMP1gMgL0N7Qh07IfMP1aLG40MGEe06i^
KP1nOWh0Ng]k07inOP1cLg<0Ng]k07IfMP1hN7P0M7Ad07MgM`1fMWH0Lg=c07IfMP1hN7P0MgMg07=c
L`1gMgL0N7Qh07YjNP1aLG40N7Qh07EeM@1bLW80KVi^07EeM@80MgMg00`0J6QX07]kN`1iNGT0KVi^
07QhN01_Kfl0LG5a06i^KP1[Jf/0MGEe06UYJ@1aLG43071`L00G06a/K01aLG40JVYZ075aL@1gMgL0
Lg=c06][J`1^KVh0MgMg07UiN@1[Jf/0Lg=c06e]K@1aLG40L71`075aL@1cLg<0K6a/06e]K@1fMWH0
L71`07AdM01aLG400P1bLW801`1dM7@0K6a/07IfMP1eMGD0LW9b07=cL`1`L7000P1lO7`00`1iNGT0
N7Qh07UiN@0207=cL`0@06i^KP13@d<0KVi^06][J`1`L700MWIf071`L01aLG40JFUY06MWI`1YJFT0
KFe]06ATI01ZJVX0IVIV06UYJ@80IfMW00D0J6QX06a/K01QHF40L71`06YZJP0206][J`0I06UYJ@1U
IFD0Hf=S05eMG@1YJFT0H61P06ATI01PH600JFUY06][J`1^KVh0JFUY065QH@1/K6`0HF5Q061PH01X
J6P0HV9R05mOG`1UIFD0Hf=S06EUI@1TI6@0KVi^065QH@02061PH00805QHF01ZJVX0G5aL065QH@1T
I6@0JVYZ065QH@1SHf<206ATI00K05UIF@1NGUh0H61P05YJFP1NGUh0GemO06ATI01LG5`0HF5Q05mO
G`1QHF40H61P05YJFP1NGUh0HF5Q05iNGP1TI6@0F5QH05UIF@1MGEd0GUiN05QHF01KFe/0DE5A05MG
E`1DE5@0EUIF0080FEUI00T0EEEE05MGE`1IFET0HV9R05]KF`1MGEd0EUIF04m?C`1>CTh05`000006
0=WIf@4000000@3IfMT000@0fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@00
00020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT0203Bd]80H61P05eM
G@1SHf<0IFEU06UYJ@1RHV80GemO0P1XJ6P01`1TI6@0JFUY06EUI@1XJ6P0IfMW06i^KP1YJFT00P1/
K6`306][J`0H06=SH`1VIVH0IFEU065QH@1UIFD0J6QX069RHP1VIVH0HF5Q06QXJ01SHf<0I6AT06MW
I`1[Jf/0IVIV065QH@1SHf<0I6AT079bLP1/K6`0I6AT06UYJ@1/K6`0JFUY101XJ6P02@1WIfL0KFe]
06UYJ@1TI6@0Jf][06QXJ01UIFD0J6QX075aL@0206YZJP0=06MWI`1]KFd0Jf][06MWI`1/K6`0KFe]
071`L01YJFT0Jf][06a/K01^KVh0K6a/06][J`0206a/K00K06][J`1YJFT0Jf][06IVIP1/K6`0Kfm_
06YZJP1^KVh0M7Ad06IVIP1bLW80Lg=c07IfMP1XJ6P0Jf][07=cL`1[Jf/0LG5a07AdM01[Jf/0MGEe
07=cL`1dM7@0MGEe07UiN@1gMgL0LG5a00<0M7Ad0180NGUi07QhN01mOGd0NWYj07EeM@1fMWH0LG5a
07AdM01cLg<0M7Ad07UiN@1fMWH0N7Qh07emO@1gMgL0NWYj07UiN@1eMGD207QhN00407MgM`1kNg/0
MgMg071`L080M7Ad00@0MWIf07QhN01aLG40MgMg0`1cLg<2075aL@0807YjNP1fMWH0Lg=c07=cL`1^
KVh0MGEe07UiN@1]KFd207AdM00I07YjNP1dM7@0MgMg07MgM`1]KFd0K6a/07AdM01cLg<0M7Ad06m_
K`1dM7@0KVi^075aL@1dM7@0MGEe06][J`1cLg<0MGEe079bLP1`L700Lg=c06i^KP1aLG40MWIf079b
LP02071`L00E06e]K@1_Kfl0K6a/07=cL`1eMGD0Lg=c08F5Q@2@T900W9bL09>CT`1mOGd0LG5a071`
L01^KVh0J6QX07YjNP1cLg<0KVi^06][J`1/K6`0Jf][0080IVIV0180JFUY061PH01VIVH0IVIV06a/
K01PH600IFEU06MWI`1_Kfl0IVIV06UYJ@1PH600J6QX06IVIP1SHf<0K6a/061PH01/K6`206UYJ@0C
06QXJ01VIVH0J6QX06UYJ@1VIVH0J6QX069RHP1^KVh0GemO06EUI@1OGel0GUiN06UYJ@1WIfL0GemO
06ATI01XJ6P0H61P06=SH`0206IVIP0B061PH01RHV80HF5Q05]KF`1ZJVX0J6QX06UYJ@1TI6@0Hf=S
05EEE@1MGEd0IFEU05eMG@1SHf<0IVIV061PH01RHV80GUiN0P1SHf<0501NGUh0HF5Q061PH01LG5`0
EUIF061PH01LG5`0FEUI065QH@1KFe/0EeMG065QH@1NGUh0Fe]K05EEE@1LG5`0DU9B05UIF@1BDU80
EUIF0P1LG5`01`1HF5P0EeMG05EEE@1GEeL0EUIF05QHF01CDe<05`0000060=WIf@4000000@3IfMT0
00030=WIf@000000000000<0000000D0fMWI0000003IfMT0fMWI000000020=WIf@040000003IfMT0
fMWI000000D0fMWI0`0000040=WIf@0806UYJ@1PH600Hf=S06=SH`1TI6@0JVYZ061PH01OGel206YZ
JP0B06IVIP1NGUh0IVIV06e]K@1SHf<0HF5Q06][J`1OGel0JVYZ065QH@1[Jf/0HV9R061PH01TI6@0
Hf=S06EUI@1`L700IVIV0P1SHf<0301RHV80H61P06i^KP1TI6@0JFUY06ATI01[Jf/0IfMW071`L01U
IFD0K6a/06IVIP80IFEU00H0KVi^06][J`1ZJVX0J6QX069RHP1XJ6P206YZJP0o07AdM01VIVH0J6QX
06UYJ@1/K6`0GemO06QXJ01dM7@0KVi^071`L01_Kfl0Jf][07=cL`1^KVh0K6a/06e]K@1YJFT0J6QX
06][J`1dM7@0JVYZ06e]K@1XJ6P0KFe]06][J`1`L700LW9b06a/K01^KVh0LG5a06][J`1TI6@0Lg=c
06i^KP1[Jf/0JVYZ06a/K01`L700IFEU07=cL`1/K6`0L71`06a/K01aLG40KVi^07=cL`1dM7@0N7Qh
07AdM01kNg/0MgMg079bLP1jNWX0NGUi07]kN`1_Kfl0MWIf075aL@1gMgL0KVi^07UiN@1aLG40NGUi
0080N7Qh00@0Ng]k07YjNP1gMgL0Ng]k0P1iNGT04`1gMgL0NWYj07=cL`1dM7@0NWYj075aL@1cLg<0
LG5a07AdM01eMGD0KFe]06][J`1dM7@0LG5a07IfMP1cLg<0JFUY06e]K@1cLg<00P1aLG40201cLg<0
KVi^075aL@1cLg<0Kfm_07AdM01cLg<0LG5a0P1dM7@00`1aLG40K6a/07QhN00207EeM@0;071`L01a
LG40K6a/06m_K`1`L700KVi^079bLP1fMWH0KFe]071`L01aLG400P1cLg<04P1`L700M7Ad07AdM01`
L700K6a/079bLP1]KFd0Lg=c07MgM`1dM7@0PX:2092@T02WYjL0^KVi0;6a/@29RHT0N7Qh06i^KP80
JVYZ0`1`L7004P1XJ6P0LG5a06EUI@1WIfL0L71`06a/K01XJ6P0KFe]06QXJ01YJFT0Jf][079bLP1W
IfL0IFEU06IVIP1/K6`0Jf][06EUI@80J6QX00`0HF5Q06ATI01YJFT0JVYZ06ATI01QHF40IVIV06=S
H`1TI6@0J6QX06YZJP1WIfL206IVIP80IFEU00D0I6AT06IVIP1SHf<0HF5Q05mOG`02065QH@80Hf=S
00L0GemO06=SH`1XJ6P0I6AT065QH@1WIfL0HV9R0080I6AT00l0GUiN06IVIP1UIFD0HF5Q06ATI01V
IVH0I6AT05mOG`1KFe/0HV9R05mOG`1KFe/0H61P05eMG@1XJ6P00P1JFUX01@1LG5`0EeMG065QH@1M
GEd0F5QH00<0Fe]K0100EUIF05eMG@1JFUX0G5aL05YJFP1KFe/0F5QH05ADE01CDe<0F5QH05IFEP1A
DE40De=C051@D01FEUH0D51@5`0000040=WIf@<000000@3IfMT000050=WIf@000000fMWI0=WIf@00
00000P3IfMT010000000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI000000D0fMWI00<00000
0=WIf@3IfMT00`3IfMT02`3Ng]h0IFEU06=SH`1VIVH0K6a/06IVIP1/K6`0IVIV06QXJ01TI6@0Jf][
0080IVIV00L0JFUY06=SH`1XJ6P0IVIV06YZJP1RHV80I6AT0080K6a/01/0Jf][06IVIP1TI6@0IFEU
05iNGP1VIVH0HV9R065QH@1XJ6P0Fe]K05mOG`1SHf<0J6QX06IVIP1YJFT0GUiN069RHP1XJ6P0Hf=S
061PH01VIVH0IFEU06UYJ@1[Jf/0JVYZ061PH01YJFT00P1XJ6P0701WIfL0Jf][079bLP1TI6@0JFUY
06EUI@1/K6`0KFe]06UYJ@1PH600Jf][06IVIP1^KVh0IVIV06UYJ@1[Jf/0J6QX06i^KP1XJ6P0Kfm_
06i^KP1YJFT0Kfm_06a/K01TI6@0HF5Q06][J`1dM7@206e]K@0>07=cL`1bLW80KVi^06UYJ@1_Kfl0
J6QX071`L01bLW80N7Qh06a/K01dM7@0Kfm_071`L01_Kfl2071`L00706i^KP1dM7@0MWIf075aL@1`
L700MgMg07IfMP0207EeM@0E07moO`1jNWX0Lg=c075aL@1_Kfl0LW9b07UiN@1fMWH0LG5a07emO@1h
N7P0LW9b07inOP1cLg<0NGUi07]kN`1iNGT0M7Ad07=cL`1gMgL0N7Qh0080NGUi00X0Ng]k07IfMP1h
N7P0L71`07IfMP1jNWX0JFUY06e]K@1dM7@0LG5a0P1cLg<06@1]KFd0K6a/071`L01aLG40M7Ad071`
L01XJ6P0JVYZ06e]K@1gMgL0Lg=c06][J`1^KVh0Lg=c071`L01cLg<0K6a/07IfMP1dM7@0Ng]k07=c
L`1aLG40Lg=c06e]K@1^KVh00P1aLG402@1dM7@0NGUi07IfMP1dM7@0Kfm_07EeM@1/K6`0L71`06][
J`02071`L00=07UiN@1dM7@0M7Ad07QhN023Ph<0a/K60>c/k03oool0g=cL09VIV@1eMGD0M7Ad07If
MP0206i^KP06075aL@1XJ6P0JFUY06IVIP1YJFT0L71`0P1/K6`0501SHf<0K6a/06UYJ@1TI6@0IfMW
06=SH`1ZJVX0JFUY06][J`1ZJVX0Hf=S06IVIP1QHF40H61P06IVIP1UIFD0HF5Q069RHP1WIfL0IFEU
0P1[Jf/01P1QHF40IVIV06QXJ01WIfL0IVIV05]KF`80IVIV01l0Hf=S06QXJ01TI6@0HF5Q06=SH`1U
IFD0GemO065QH@1LG5`0HF5Q061PH01NGUh0Hf=S06QXJ01TI6@0Fe]K069RHP1QHF40H61P069RHP1O
Gel0GUiN06ATI01OGel0G5aL065QH@1TI6@0GemO06MWI`1UIFD0HF5Q0080H61P0P1KFe/00`1JFUX0
G5aL05YJFP0205iNGP<0G5aL00D0D51@05IFEP1CDe<0Fe]K05UIF@0205QHF00505YJFP1EEED0EUIF
05QHF01ADE400P1DE5@00`1=CDd0F5QH0000000F000000H0fMWI0@0000010=WIf@000P3IfMT00`00
0000fMWI000000020=WIf@040000003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT000001@3I
fMT00`000000fMWI0=WIf@030=WIf@0J0=SHf01PH600J6QX069RHP1UIFD0J6QX06IVIP1YJFT0Hf=S
06a/K01VIVH0IfMW06a/K01PH600Fe]K06][J`1LG5`0I6AT069RHP1VIVH0HF5Q06=SH`1TI6@0IVIV
06ATI01QHF4206IVIP0406e]K@1VIVH0IVIV06ATI0<0IVIV00D0JFUY06EUI@1SHf<0KVi^06UYJ@02
06EUI@0906ATI01YJFT0Jf][06QXJ01TI6@0J6QX06=SH`1YJFT0H61P0080K6a/01L0Jf][06UYJ@1T
I6@0IfMW06e]K@1[Jf/0LW9b06i^KP1ZJVX0KVi^06a/K01XJ6P0IVIV06a/K01TI6@0J6QX06][J`1Y
JFT0JVYZ06MWI`1/K6`0L71`06QXJ00206IVIP0D06e]K@1`L700JVYZ06i^KP1/K6`0Hf=S06e]K@1_
Kfl0L71`06e]K@1YJFT0KVi^06MWI`1[Jf/0LG5a06e]K@1aLG40LW9b06i^KP1cLg<206e]K@0@07Mg
M`1]KFd0OWin07MgM`1/K6`0N7Qh075aL@1jNWX0OWin07AdM01hN7P0K6a/07EeM@1mOGd0L71`07=c
L`80LG5a01L0MGEe07AdM01iNGT0Lg=c07AdM01/K6`0M7Ad07EeM@1nOWh0Ng]k07IfMP1iNGT0Ng]k
07UiN@1jNWX0Jf][075aL@1^KVh0LG5a07UiN@1`L700MWIf071`L00207=cL`06075aL@1]KFd0MWIf
07AdM01cLg<0MWIf0P1aLG403P1cLg<0MGEe075aL@1^KVh0M7Ad075aL@1/K6`0Kfm_07IfMP1^KVh0
LG5a07AdM01/K6`0MGEe0P1^KVh02`1aLG40L71`07=cL`1]KFd0Kfm_06a/K01`L700KFe]06YZJP1`
L700MGEe0080Kfm_00D0NGUi07AdM01nOWh0UIFE0=_Kf`020?ooo`030=3@d028R8P0N7Qh0080K6a/
00<0Kfm_06][J`1^KVh00P1^KVh01@1dM7@0K6a/06QXJ01[Jf/0HF5Q0080I6AT0100JFUY06IVIP1T
I6@0J6QX06YZJP1QHF40I6AT06IVIP1ZJVX0J6QX06=SH`1UIFD0Jf][05iNGP1YJFT0HV9R0P1NGUh0
3@1TI6@0H61P06EUI@1PH600Hf=S065QH@1LG5`0Hf=S061PH01JFUX0GUiN06IVIP1SHf<00P1VIVH0
3P1TI6@0Fe]K065QH@1JFUX0I6AT05iNGP1LG5`0H61P05aLG01IFET0HF5Q05iNGP1SHf<0GUiN0P1S
Hf<206YZJP0T05iNGP1LG5`0HV9R05QHF01QHF40Jf][069RHP1WIfL0I6AT065QH@1VIVH0G5aL05iN
GP1SHf<0EeMG061PH01LG5`0GUiN05EEE@1LG5`0H61P05UIF@1FEUH0De=C05QHF01FEUH0E5AD05UI
F@1EEED0F5QH05aLG01GEeL0FUYJ05ADE01CDe<0CTi>5`0000060=WIf@4000000@3IfMT000<0fMWI
0P0000030=WIf@800000103IfMT2000000H0fMWI00<000000=WIf@3IfMT00`3IfMT04@3Shn<0IFEU
05mOG`1TI6@0JFUY05UIF@1UIFD0Hf=S06ATI01LG5`0HF5Q06ATI01XJ6P0L71`06UYJ@1WIfL0Hf=S
0080J6QX00T0IfMW06ATI01ZJVX0KVi^06=SH`1XJ6P0IfMW06UYJ@1PH6000`1UIFD02@1VIVH0I6AT
05iNGP1ZJVX0J6QX06MWI`1TI6@0IfMW06UYJ@0206ATI00@06a/K01TI6@0JFUY06ATI01SHf<0JFUY
06IVIP1XJ6P0H61P06ATI01YJFT0Jf][06i^KP1TI6@0KVi^06a/K080IfMW00/0J6QX06YZJP1/K6`0
Jf][06a/K01ZJVX0J6QX06MWI`1XJ6P0Kfm_06UYJ@0206a/K006069RHP1YJFT0J6QX06UYJ@1QHF40
IfMW0P1/K6`05@1bLW80JFUY075aL@1[Jf/0IfMW07=cL`1^KVh0Kfm_07=cL`1YJFT0LW9b06m_K`1X
J6P0LW9b06a/K01`L700LG5a07AdM01_Kfl0L71`07=cL`0207IfMP0=0861P@1dM7@0M7Ad07IfMP1_
Kfl0OWin07QhN01kNg/0Lg=c07IfMP1aLG40MgMg07UiN@0207=cL`0B07MgM`1fMWH0Lg=c071`L01d
M7@0Lg=c06a/K01gMgL0Ogmo07alO01aLG40OWin07IfMP1`L700NGUi06e]K@1cLg<0KFe]0P1[Jf/0
6@1aLG40Lg=c07=cL`1cLg<0LG5a06i^KP1/K6`0KVi^07=cL`1dM7@0L71`07=cL`1]KFd0LG5a07=c
L`1^KVh0MGEe07AdM01[Jf/0L71`06UYJ@1fMWH0LW9b071`L01/K6`00P1^KVh0101aLG40K6a/07Ad
M01^KVh207MgM`80Jf][01L0KVi^075aL@1^KVh0LG5a07=cL`1^KVh0LG5a07UiN@1dM7@0UiNG0<S8
b03Zj^X0gMgM09^KV`1cLg<0L71`06YZJP1XJ6P0Fe]K06UYJ@1TI6@0K6a/06EUI@0206QXJ00306AT
I01VIVH0KFe]0080IVIV0P1YJFT01P1TI6@0J6QX06QXJ01aLG40IfMW06e]K@80Hf=S01@0JFUY06EU
I@1VIVH0JFUY05aLG01TI6@0GemO061PH01QHF40Hf=S06IVIP1LG5`0Hf=S05]KF`1NGUh0H61P06AT
I01OGel0HF5Q05eMG@80HV9R02`0G5aL061PH01TI6@0IFEU06ATI01KFe/0F5QH061PH01KFe/0Hf=S
069RHP1SHf<0H61P06=SH`1HF5P0IVIV05]KF`1LG5`0H61P065QH@1IFET0GEeM06EUI@1PH600JFUY
06=SH`1UIFD0I6AT065QH@1UIFD0Fe]K05MGE`1LG5`0IVIV05]KF`1NGUh0FUYJ061PH01EEED0HV9R
05mOG`1PH600Fe]K05iNGP80Fe]K00T0EEEE05]KF`1DE5@0FEUI05aLG01FEUH0E5AD05MGE`1DE5@0
5`0000060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT02P3MgMd0HF5Q06=S
H`1XJ6P0HV9R06=SH`1YJFT0Hf=S06IVIP1TI6@206QXJ00C06][J`1XJ6P0Jf][06=SH`1XJ6P0I6AT
061PH01YJFT0HF5Q05eMG@1ZJVX0HF5Q06IVIP1WIfL0J6QX06=SH`1UIFD0JFUY06a/K00206QXJ00A
06=SH`1]KFd0H61P065QH@1NGUh0J6QX06ATI01RHV80Hf=S06MWI`1VIVH0IfMW06e]K@1/K6`0IfMW
06UYJ@1ZJVX00P1XJ6P02P1VIVH0L71`06][J`1YJFT0Jf][06QXJ01^KVh0Hf=S06e]K@1_Kfl206UY
J@0D075aL@1/K6`0Lg=c05iNGP1aLG40KVi^06a/K01YJFT0IVIV06][J`1]KFd0M7Ad06i^KP1aLG40
JFUY06QXJ01ZJVX0IFEU06m_K`1VIVH506i^KP08075aL@1fMWH0KFe]06e]K@1_Kfl0KFe]06MWI`1a
LG4206i^KP07079bLP1dM7@0MGEe07EeM@1aLG40JVYZ07MgM`02075aL@0907QhN01jNWX0M7Ad071`
L01cLg<0NGUi07EeM@1gMgL0NGUi0080MgMg00H0M7Ad07QhN01hN7P0Ng]k06e]K@1/K6`207MgM`09
071`L01^KVh0NGUi06m_K`1cLg<0LG5a07AdM01`L700Jf][0080LG5a00L0LW9b075aL@1/K6`0K6a/
06QXJ01ZJVX0K6a/0080KVi^00/0KFe]075aL@1^KVh0LG5a06i^KP1aLG40J6QX079bLP1]KFd0K6a/
06UYJ@0306i^KP0T075aL@1XJ6P0Lg=c06MWI`1aLG40KFe]075aL@1/K6`0LG5a071`L01XJ6P0KFe]
071`L01[Jf/0JFUY06YZJP1aLG40Kfm_075aL@1ZJVX0L71`07MgM`24Q8@0][Jf0<30`02j^[X0QXJ6
06a/K01`L700JVYZ06EUI@1XJ6P0IfMW06a/K01[Jf/0I6AT0P1ZJVX206i^KP0306IVIP1TI6@0IVIV
0080IfMW00D0HV9R06a/K01/K6`0JVYZ06IVIP0206][J`0=06=SH`1WIfL0Hf=S065QH@1XJ6P0GUiN
061PH01TI6@0HV9R06EUI@1PH600IFEU06QXJ00206ATI00605mOG`1XJ6P0HV9R06=SH`1NGUh0HF5Q
0P1SHf<02`1PH600GUiN065QH@1JFUX0GEeM06ATI01IFET0HF5Q05]KF`1JFUX0I6AT0080H61P00<0
GEeM05aLG01MGEd00P1PH6006P1QHF40G5aL06=SH`1QHF40FEUI06QXJ01NGUh0H61P06][J`1PH600
IVIV06ATI01PH600J6QX06=SH`1QHF40G5aL065QH@1IFET0GEeM06EUI@1HF5P0EUIF05MGE`1IFET0
F5QH0P1IFET2055AD@0705MGE`1EEED0EUIF059BDP1EEED0D51@05=CD`0G000000H0fMWI0@000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0:0=cLg01SHf<0J6QX06=SH`1PH600JFUY06IV
IP1QHF40J6QX06IVIP80H61P00<0KVi^06=SH`1QHF400P1VIVH0901]KFd0JFUY06ATI01SHf<0KVi^
06a/K01YJFT0GUiN06UYJ@1aLG40IFEU06UYJ@1SHf<0K6a/06QXJ01]KFd0HF5Q06UYJ@1PH600IVIV
06ATI01UIFD0Jf][06MWI`1TI6@0IfMW06ATI01VIVH0IFEU06IVIP1RHV80IfMW065QH@1XJ6P0IVIV
071`L080KFe]00@0JFUY065QH@1TI6@0Jf][101/K6`0501[Jf/0K6a/06IVIP1XJ6P0JFUY06IVIP1^
KVh0Kfm_06UYJ@1`L700K6a/06IVIP1]KFd0L71`065QH@1`L700JFUY06m_K`1/K6`0IfMW0P1[Jf/0
201dM7@0Jf][079bLP1XJ6P0M7Ad06][J`1cLg<0L71`0P1]KFd01@1/K6`0KVi^06YZJP1iNGT0MWIf
0080LW9b00`0LG5a071`L01cLg<0M7Ad07YjNP1kNg/0N7Qh06][J`1hN7P0KVi^07YjNP1aLG4207=c
L`0A07QhN01oOgl0Lg=c07]kN`1gMgL0L71`07QhN01`L700NGUi07]kN`1jNWX0Lg=c07QhN01cLg<0
M7Ad06e]K@1eMGD00P1XJ6P01`1jNWX0LG5a06a/K01cLg<0MWIf06i^KP1bLW800P1aLG40101fMWH0
J6QX06i^KP1fMWH206i^KP80LW9b00L0KVi^06e]K@1`L700LG5a07=cL`1hN7P0Lg=c0080LG5a00/0
K6a/06QXJ01`L700Lg=c06m_K`1fMWH0LG5a06a/K01_Kfl0K6a/06][J`0206e]K@0@06UYJ@1aLG40
KVi^075aL@1dM7@0Kfm_06][J`1fMWH0Lg=c08>3P`2>SXh0RXZ:0820P01gMgL0IVIV06MWI`80JFUY
00@0Hf=S06UYJ@1VIVH0JVYZ0P1[Jf/206UYJ@0=06e]K@1XJ6P0K6a/06YZJP1UIFD0IfMW071`L01T
I6@0Hf=S06m_K`1TI6@0J6QX06MWI`0206=SH`03065QH@1TI6@0GUiN0080GUiN01d0I6AT06QXJ01S
Hf<0G5aL06IVIP1MGEd0IFEU06=SH`1VIVH0I6AT069RHP1PH600Fe]K05aLG01SHf<0JFUY05iNGP1I
FET0H61P065QH@1LG5`0GUiN05]KF`1PH600FUYJ05]KF`1XJ6P0HF5Q05aLG00205iNGP0605aLG01R
HV80J6QX05mOG`1UIFD0Hf=S0P1QHF40201UIFD0K6a/06a/K01WIfL0IVIV06UYJ@1SHf<0IVIV0P1Q
HF400`1PH600GEeM05UIF@0205aLG00A05=CD`1FEUH0Fe]K05UIF@1@D500FEUI05QHF01IFET0EUIF
05aLG01HF5P0EeMG051@D01FEUH0FEUI04i>CP1FEUH05`0000060=WIf@4000000@3IfMT001H0fMWI
00<000000=WIf@3IfMT00`3IfMT05@3Ph>00JFUY065QH@1SHf<0JFUY069RHP1YJFT0H61P069RHP1V
IVH0K6a/065QH@1]KFd0IVIV06=SH`1YJFT0J6QX065QH@1TI6@0IfMW06YZJP0206=SH`0406i^KP1V
IVH0IFEU061PH080JFUY01H0Hf=S06EUI@1ZJVX0IVIV06=SH`1QHF40IVIV06QXJ01VIVH0IFEU06MW
I`1OGel0J6QX065QH@1]KFd0IFEU06=SH`1/K6`0IVIV06YZJP1XJ6P0JFUY0P1XJ6P01P1QHF40Hf=S
06a/K01UIFD0IfMW06UYJ@80IVIV00H0J6QX06m_K`1/K6`0J6QX06a/K01`L70206UYJ@03075aL@1Y
JFT0K6a/00<0IVIV00L0Kfm_06UYJ@1ZJVX0Hf=S06UYJ@1/K6`0JFUY0080Jf][00d0I6AT07=cL`1^
KVh0Kfm_071`L01[Jf/0Kfm_07=cL`1ZJVX0Kfm_06i^KP1aLG40Kfm_0080Lg=c01<0JFUY07AdM01f
MWH0MWIf06m_K`1`L700K6a/07AdM01`L700MgMg06m_K`1[Jf/0KFe]07UiN@1dM7@0Kfm_071`L01g
MgL0M7Ad0080Lg=c00@0Kfm_079bLP1dM7@0Lg=c0P1kNg/0;`1fMWH0NGUi07EeM@1^KVh0L71`06][
J`1`L700KVi^075aL@1dM7@0LG5a07=cL`1^KVh0MGEe07MgM`1cLg<0KVi^071`L01bLW80K6a/07=c
L`1aLG40K6a/079bLP1aLG40MGEe06YZJP1[Jf/0MGEe07IfMP1WIfL0Lg=c06m_K`1[Jf/0K6a/06i^
KP1/K6`0LG5a07=cL`1XJ6P0K6a/07=cL`1aLG40KVi^06YZJP1[Jf/0KFe]0080K6a/00P0Lg=c06][
J`1[Jf/0KFe]079bLP1^KVh0K6a/06IVIP80MGEe00L0M7Ad06a/K01ZJVX0Jf][06i^KP1SHf<0IVIV
0080Jf][00L0JFUY06YZJP1WIfL0I6AT06m_K`1VIVH0HV9R0080I6AT02h0J6QX06=SH`1YJFT0IVIV
06ATI01^KVh0Jf][06i^KP1VIVH0Jf][065QH@1WIfL0Hf=S06ATI01VIVH0KFe]065QH@1LG5`0Fe]K
061PH01MGEd0HV9R05eMG@1QHF40I6AT05]KF`1LG5`0GemO06ATI01QHF40H61P065QH@1HF5P0GEeM
061PH01NGUh0HV9R05eMG@1KFe/0G5aL065QH@1HF5P0IVIV05YJFP1NGUh0Hf=S0P1RHV8205mOG`<0
HF5Q02<0IVIV06ATI01QHF40HF5Q06UYJ@1SHf<0LW9b06m_K`1YJFT0H61P06ATI01RHV80FEUI05eM
G@1PH600FUYJ05aLG01KFe/0G5aL05IFEP1GEeL0EUIF05EEE@1IFET0E5AD05aLG01ADE40GemO05IF
EP1EEED0Fe]K05IFEP1CDe<0DE5A051@D00G000000H0fMWI0@0000010=WIf@005P3IfMT00`000000
fMWI0=WIf@030=WIf@0B0=[JfP1SHf<0GemO06IVIP1TI6@0IVIV05iNGP1PH600K6a/06IVIP1XJ6P0
JFUY06ATI01UIFD0IVIV065QH@1SHf<0HF5Q0P1PH600401VIVH0JFUY06UYJ@1[Jf/0J6QX06][J`1/
K6`0HV9R06EUI@1SHf<0J6QX065QH@1TI6@0Jf][065QH@1SHf<406QXJ00306IVIP1UIFD0IFEU0080
IVIV00D0J6QX071`L01UIFD0GemO06QXJ00206ATI00=06MWI`1VIVH0I6AT06ATI01^KVh0J6QX06a/
K01XJ6P0JFUY06MWI`1YJFT0K6a/06MWI`0206YZJP0<071`L01UIFD0JVYZ06a/K01YJFT0IVIV06QX
J01WIfL0K6a/06YZJP1]KFd0KVi^0P1YJFT0101PH600JFUY06QXJ01/K6`206][J`<0K6a/00`0KVi^
075aL@1TI6@0Kfm_06i^KP1cLg<0LG5a071`L01^KVh0L71`07=cL`1^KVh307=cL`0906i^KP1dM7@0
LW9b07MgM`1dM7@0MGEe075aL@1`L700Kfm_0080Lg=c0P1aLG402@1cLg<0MWIf06QXJ01/K6`0LW9b
0820P01`L700K6a/07=cL`0207IfMP0:07YjNP1aLG40LW9b07AdM01aLG40MWIf07=cL`1eMGD0MgMg
075aL@80KVi^00<0K6a/06i^KP1WIfL00P1ZJVX00`1]KFd0Kfm_075aL@0207=cL`0606a/K01hN7P0
L71`06QXJ01_Kfl0Lg=c0P1/K6`01@1^KVh0JFUY06m_K`1/K6`0MgMg0080KVi^00l0K6a/07AdM01^
KVh0M7Ad06e]K@1cLg<0KVi^06YZJP1cLg<0KFe]06i^KP1[Jf/0KFe]06UYJ@1]KFd00`1XJ6P0601^
KVh0K6a/06a/K01`L700JFUY06i^KP1ZJVX0HF5Q06QXJ01YJFT0IFEU06UYJ@1/K6`0Fe]K06=SH`1Y
JFT0JVYZ06e]K@1WIfL0KFe]06IVIP1ZJVX0J6QX06EUI@80I6AT01@0GUiN06ATI01SHf<0IfMW069R
HP1QHF40HV9R061PH01SHf<0HV9R05iNGP1QHF40I6AT05iNGP1QHF40Hf=S06ATI01LG5`0FUYJ05aL
G080Fe]K0P1NGUh0201OGel0HF5Q06MWI`1MGEd0IVIV061PH01NGUh0HF5Q0P1NGUh00`1MGEd0G5aL
06UYJ@0305iNGP0F05UIF@1MGEd0H61P065QH@1PH600Hf=S06ATI01PH600JFUY06i^KP1TI6@0J6QX
06UYJ@1/K6`0J6QX06i^KP1[Jf/0IfMW06EUI@1MGEd0EeMG06ATI0<0GUiN0100EUIF05eMG@1IFET0
De=C05QHF01JFUX0Fe]K06ATI01CDe<0FEUI05=CD`1DE5@0De=C05aLG01>CTh0EEEE5`0000060=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT01P3Ph>00I6AT06EUI@1QHF40IfMW
06=SH`80IVIV00P0HF5Q06MWI`1NGUh0I6AT065QH@1XJ6P0JFUY06EUI@80K6a/0300I6AT06UYJ@1S
Hf<0J6QX06UYJ@1XJ6P0HV9R06=SH`1XJ6P0HV9R06UYJ@1VIVH0Hf=S06QXJ01PH600Jf][065QH@1[
Jf/0IVIV06QXJ01MGEd0HV9R06MWI`1SHf<0KVi^06ATI01PH600JFUY069RHP1YJFT0I6AT06=SH`1^
KVh0J6QX06][J`1/K6`0Kfm_06YZJP1RHV80KFe]06IVIP1ZJVX0IfMW06a/K01XJ6P0JFUY06MWI`1R
HV8206QXJ005075aL@1SHf<0I6AT069RHP1^KVh00P1SHf<0;01XJ6P0K6a/06i^KP1[Jf/0KVi^06YZ
JP1^KVh0Jf][06IVIP1XJ6P0KVi^075aL@1^KVh0IfMW079bLP1[Jf/0L71`06UYJ@1`L700LG5a06QX
J01fMWH0L71`06i^KP1[Jf/0M7Ad06UYJ@1/K6`0LG5a079bLP1_Kfl0KFe]075aL@1[Jf/0MGEe07=c
L`1_Kfl0K6a/075aL@1]KFd0Kfm_07=cL`1[Jf/0MWIf0P1aLG405@1`L700Lg=c075aL@1`L700LW9b
07IfMP1iNGT0LG5a06m_K`1iNGT0LG5a07EeM@1kNg/0M7Ad07EeM@1lO7`0LW9b071`L01/K6`0IFEU
06m_K`0206i^KP0706a/K01bLW80K6a/06][J`1`L700LW9b071`L00206YZJP0<07MgM`1`L700LG5a
06a/K01aLG40KFe]06ATI01_Kfl0K6a/071`L01^KVh0L71`0P1YJFT206][J`0306=SH`1bLW80M7Ad
0080Jf][01L0K6a/06YZJP1cLg<0JFUY06IVIP1^KVh0HF5Q06YZJP1TI6@0J6QX06UYJ@1MGEd0JVYZ
06MWI`1YJFT0KFe]06QXJ01ZJVX0JFUY06=SH`1aLG40I6AT06YZJP03065QH@0906MWI`1RHV80JFUY
075aL@1YJFT0IFEU06ATI01VIVH0H61P0080HF5Q00X0HV9R06a/K01TI6@0Hf=S06ATI01OGel0GUiN
06QXJ01RHV80IVIV0P1PH600601MGEd0J6QX06=SH`1NGUh0Fe]K05YJFP1PH600Fe]K061PH01UIFD0
IVIV065QH@1OGel0Hf=S05IFEP1PH600J6QX06=SH`1IFET0HV9R065QH@1NGUh0GemO05UIF@80H61P
01<0HF5Q05]KF`1LG5`0HV9R05iNGP1PH600Hf=S069RHP1PH600HF5Q06IVIP1]KFd0I6AT071`L01a
LG40KVi^07AdM01[Jf/0Hf=S0080H61P00@0GUiN061PH01PH600GEeM0P1LG5`03`1JFUX0EeMG05]K
F`1HF5P0GEeM05UIF@1GEeL0F5QH05IFEP1KFe/0E5AD05]KF`1CDe<0F5QH059BDP0G000000H0fMWI
0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0]0=kNgP1VIVH0G5aL061PH01WIfL0
Hf=S06MWI`1VIVH0HV9R05iNGP1QHF40I6AT061PH01_Kfl0J6QX069RHP1VIVH0KVi^06QXJ01QHF40
Hf=S06QXJ01UIFD0Hf=S06ATI01RHV80IVIV06YZJP1YJFT0IfMW065QH@1UIFD0HV9R05aLG01UIFD0
H61P06=SH`1VIVH0Hf=S06EUI@1^KVh0IVIV06EUI@1VIVH0H61P0080J6QX00P0Hf=S06MWI`1XJ6P0
GemO06=SH`1YJFT0J6QX06ATI080J6QX00L0M7Ad06QXJ01/K6`0J6QX06m_K`1[Jf/0IVIV0080JFUY
00h0IfMW06IVIP1VIVH0H61P06MWI`1VIVH0I6AT06UYJ@1XJ6P0IfMW07AdM01XJ6P0KFe]06i^KP80
IfMW02T0JFUY06][J`1XJ6P0HV9R07AdM01ZJVX0KVi^079bLP1aLG40JVYZ06e]K@1eMGD0Jf][07Ad
M01]KFd0Lg=c06][J`1]KFd0K6a/07EeM@1dM7@0L71`079bLP1aLG40Kfm_075aL@1XJ6P0LW9b06i^
KP1XJ6P0MgMg07=cL`1gMgL0LG5a06m_K`1eMGD0P820075aL@1^KVh0Jf][07IfMP0207=cL`0F06a/
K01dM7@0LW9b06i^KP1_Kfl0LG5a071`L01cLg<0M7Ad06a/K01^KVh0Lg=c06][J`1^KVh0K6a/06m_
K`1aLG40LW9b06YZJP1bLW80Kfm_07AdM080KVi^00H0JVYZ075aL@1/K6`0KVi^071`L01cLg<206][
J`0406i^KP1dM7@0KVi^06ATI080JFUY00T0Kfm_06i^KP1[Jf/0Kfm_061PH01ZJVX0Kfm_069RHP1V
IVH00P1XJ6P03@1aLG40IVIV06a/K01/K6`0KVi^06a/K01SHf<0K6a/06YZJP1XJ6P0HF5Q06QXJ01W
IfL00P1YJFT00`1[Jf/0I6AT06IVIP0206IVIP0:06MWI`1XJ6P0IFEU06IVIP1TI6@0JFUY06][J`1W
IfL0IFEU06=SH`80K6a/01/0IfMW06=SH`1YJFT0IVIV06=SH`1LG5`0HV9R06QXJ01VIVH0H61P06QX
J01LG5`0I6AT05eMG@1RHV80FUYJ05iNGP1PH600FUYJ06ATI01OGel0HF5Q069RHP1PH600Hf=S05aL
G01TI6@00P1IFET00`1NGUh0Fe]K05aLG00205mOG`0305]KF`1QHF40FEUI0080G5aL0P1NGUh0101P
H600I6AT05iNGP1JFUX205UIF@0B05aLG01UIFD0HF5Q06IVIP1TI6@0LG5a06][J`1/K6`0J6QX079b
LP1gMgL0JVYZ07=cL`1XJ6P0I6AT06IVIP1[Jf/0Hf=S0P1QHF401`1NGUh0E5AD05eMG@1MGEd0EEEE
05QHF01DE5@00P1IFET02@1FEUH0G5aL05eMG@1EEED0EUIF05UIF@1>CTh0FEUI05ADE00G000000H0
fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@080=kNgP1XJ6P0J6QX06IVIP1T
I6@0Hf=S05mOG`1NGUh2065QH@0D06EUI@1KFe/0HF5Q06=SH`1VIVH0KVi^06QXJ01SHf<0HF5Q069R
HP1SHf<0IFEU065QH@1TI6@0HV9R065QH@1VIVH0HF5Q06=SH`1TI6@206UYJ@0606=SH`1XJ6P0I6AT
05aLG01RHV80Hf=S0P1XJ6P01@1WIfL0IVIV05iNGP1YJFT0IVIV0080HF5Q00X0IFEU06e]K@1WIfL0
L71`06][J`1XJ6P0Hf=S065QH@1YJFT0IfMW0P1TI6@06`1]KFd0LG5a06UYJ@1TI6@0Jf][06=SH`1Y
JFT0L71`06IVIP1XJ6P0Jf][079bLP1XJ6P0JFUY06MWI`1RHV80IFEU06UYJ@1SHf<0Kfm_06e]K@1Y
JFT0KFe]06a/K01XJ6P0L71`079bLP0206i^KP04075aL@1_Kfl0JFUY06i^KP80L71`00@0KFe]06][
J`1_Kfl0Kfm_0P1`L700301_Kfl0LG5a07IfMP1aLG40KVi^075aL@1^KVh0Lg=c075aL@1cLg<0LG5a
06m_K`<0K6a/0P1dM7@03@1/K6`0MGEe07IfMP1^KVh0K6a/06m_K`1cLg<0LG5a07=cL`1`L700Kfm_
071`L01YJFT00P1`L700101VIVH0KVi^06a/K01[Jf/206i^KP80JFUY00<0LG5a06UYJ@1`L7000P1/
K6`0<01YJFT0IfMW06UYJ@1dM7@0K6a/06i^KP1]KFd0JFUY06][J`1YJFT0K6a/06e]K@1[Jf/0LG5a
06i^KP1_Kfl0HF5Q06UYJ@1XJ6P0Kfm_06ATI01]KFd0J6QX06][J`1WIfL0JFUY07EeM@1aLG40Jf][
071`L01[Jf/0I6AT06UYJ@1`L700IVIV069RHP1]KFd0J6QX06MWI`1VIVH0K6a/06IVIP1SHf<0LG5a
06UYJ@1VIVH0Hf=S06IVIP80Hf=S00T0GemO061PH01XJ6P0I6AT06UYJ@1]KFd0I6AT06=SH`1/K6`0
0P1VIVH03@1UIFD0I6AT06EUI@1QHF40IFEU06=SH`1VIVH0HF5Q06ATI01VIVH0G5aL05]KF`1LG5`0
0P1TI6@06@1SHf<0Fe]K061PH01LG5`0I6AT065QH@1RHV80IFEU065QH@1MGEd0Hf=S065QH@1FEUH0
F5QH05]KF`1NGUh0HF5Q06ATI01JFUX0H61P06=SH`1LG5`0GUiN05QHF01PH6000P1NGUh01P1JFUX0
GemO05aLG01NGUh0IFEU065QH@80GUiN01L0I6AT06YZJP1XJ6P0J6QX06YZJP1aLG40M7Ad07=cL`1d
M7@0O7al07IfMP1dM7@0JFUY06MWI`1ZJVX0HF5Q05IFEP1VIVH0G5aL05ADE01IFET0FUYJ061PH002
05]KF`0405IFEP1LG5`0EUIF05UIF@80EUIF00@0FEUI04i>CP1IFET0De=C5`0000060=WIf@400000
0@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT00`3Ti>@0K6a/06EUI@0206MWI`0306UYJ@1U
IFD0I6AT0080JFUY00D0Kfm_06QXJ01VIVH0IfMW06IVIP0205mOG`0<061PH01XJ6P0IVIV06QXJ01S
Hf<0J6QX065QH@1SHf<0IVIV06=SH`1UIFD0IVIV0P1QHF40201VIVH0IFEU06UYJ@1MGEd0HV9R06AT
I01NGUh0Hf=S0P1VIVH02P1QHF40I6AT06IVIP1RHV80HF5Q06ATI01PH600IVIV06UYJ@1QHF4206MW
I`0;06QXJ01UIFD0I6AT06ATI01ZJVX0JFUY06=SH`1VIVH0Lg=c06UYJ@1/K6`00P1XJ6P0201WIfL0
JFUY06UYJ@1]KFd0KVi^06YZJP1[Jf/0J6QX0P1/K6`0:01SHf<0JFUY06ATI01/K6`0J6QX06i^KP1Y
JFT0K6a/06UYJ@1`L700J6QX06UYJ@1]KFd0IfMW071`L01^KVh0L71`075aL@1XJ6P0KVi^07AdM01]
KFd0JFUY075aL@1[Jf/0KVi^06m_K`1cLg<0Ng]k06MWI`1dM7@0MgMg071`L01bLW80JFUY07IfMP1_
Kfl0Lg=c07EeM@1/K6`207AdM00406a/K01dM7@0LG5a06][J`80K6a/00P0JFUY06e]K@1fMWH0KFe]
06UYJ@1`L700LW9b071`L080K6a/0180JVYZ07EeM@1ZJVX0LG5a06][J`1^KVh0L71`06][J`1^KVh0
N7Qh06e]K@1/K6`0IfMW06QXJ01aLG40Kfm_075aL@1`L70206YZJP0O06a/K01`L700JVYZ06UYJ@1a
LG40J6QX06][J`1_Kfl0JVYZ06IVIP1YJFT0LG5a071`L01YJFT0K6a/07AdM01aLG40L71`075aL@1`
L700LG5a06UYJ@1XJ6P0K6a/06QXJ01TI6@0KVi^06][J`1]KFd0IVIV06=SH`0206UYJ@0506IVIP1X
J6P0J6QX06ATI01SHf<00P1TI6@03P1^KVh0HV9R06ATI01XJ6P0I6AT06i^KP1[Jf/0IVIV06MWI`1Q
HF40IFEU06UYJ@1WIfL0GemO0P1VIVH00`1WIfL0J6QX05mOG`02065QH@0F06=SH`1QHF40H61P04U9
B@1LG5`0IVIV06=SH`1PH600HF5Q061PH01RHV80GemO05ADE01NGUh0GEeM06ATI01PH600G5aL065Q
H@1HF5P0GEeM065QH@80I6AT01P0HF5Q06=SH`1MGEd0G5aL05QHF01CDe<0FEUI05iNGP1KFe/0G5aL
05UIF@1GEeL0H61P05aLG01TI6@0IFEU069RHP1SHf<0J6QX06][J`1ZJVX0MWIf071`L01fMWH207Mg
M`0<08V9R@20P800Ng]k07AdM01]KFd0IVIV06=SH`1TI6@0GEeM06=SH`1PH600HF5Q0P1IFET0101L
G5`0E5AD05MGE`1IFET205EEE@80EUIF00@0EEEE05UIF@1EEED0E5AD5`0000060=WIf@4000000@3I
fMT001H0fMWI0P0000040=WIf@0=0=SHf01LG5`0Hf=S065QH@1YJFT0GemO061PH01RHV80HF5Q06EU
I@1PH600JFUY069RHP03065QH@0@06MWI`1VIVH0KFe]065QH@1RHV80IVIV05mOG`1SHf<0IVIV06=S
H`1TI6@0Hf=S065QH@1SHf<0I6AT06IVIP80HF5Q04@0JFUY06MWI`1VIVH0L71`06=SH`1PH600JVYZ
06=SH`1WIfL0Hf=S06ATI01XJ6P0Hf=S06IVIP1TI6@0IfMW06QXJ01^KVh0J6QX06ATI01WIfL0IVIV
06EUI@1ZJVX0Kfm_08^;R`1dM7@0J6QX065QH@1VIVH0HF5Q06IVIP1XJ6P0IfMW06QXJ01/K6`0I6AT
06IVIP1XJ6P0Jf][06ATI01SHf<0IVIV06ATI01]KFd0JVYZ06][J`1XJ6P0L71`06][J`1YJFT0J6QX
06e]K@1YJFT0K6a/06IVIP1bLW80J6QX071`L01dM7@0Jf][071`L01dM7@0LW9b06a/K01XJ6P0K6a/
06][J`80L71`00H0IVIV075aL@1[Jf/0Jf][06e]K@1ZJVX2075aL@0306a/K01aLG40Lg=c00<0KVi^
00T0JFUY07=cL`1gMgL0M7Ad06UYJ@1_Kfl0JFUY06m_K`1YJFT00P1_Kfl09`1]KFd0LG5a06m_K`1e
MGD0Kfm_07AdM01/K6`0JFUY071`L01aLG40M7Ad06i^KP1XJ6P0K6a/07=cL`1VIVH0KFe]06][J`1]
KFd0K6a/06][J`1/K6`0MgMg06e]K@1_Kfl0K6a/06QXJ01VIVH0Jf][06QXJ01UIFD0J6QX06UYJ@1^
KVh0LW9b06a/K01WIfL0J6QX06ATI00206a/K00C06i^KP1bLW80Jf][06e]K@1XJ6P0JFUY06m_K`1V
IVH0KFe]06IVIP1YJFT0I6AT06=SH`1TI6@0IVIV06=SH`1ZJVX0Jf][06=SH`0206QXJ080I6AT00H0
IVIV07=cL`1[Jf/0IFEU061PH01XJ6P2065QH@0G06QXJ01OGel0KVi^06a/K01UIFD0J6QX06UYJ@1Q
HF40I6AT06QXJ01UIFD0Hf=S061PH01MGEd0IFEU069RHP1VIVH0G5aL065QH@1WIfL0I6AT069RHP1T
I6@00P1QHF406P1PH600FUYJ05mOG`1XJ6P0GEeM05]KF`1NGUh0De=C069RHP1MGEd0GUiN06IVIP1S
Hf<0E5AD06ATI01JFUX0Fe]K05aLG01IFET0EUIF05aLG01EEED0EUIF05]KF`1MGEd0F5QH0P1NGUh0
1@1QHF40JFUY06UYJ@1_Kfl0Jf][0080L71`00h0Lg=c075aL@21PH40R8R808:2PP2<S8`0R8R807Qh
N01nOWh0LG5a06][J`1TI6@0J6QX06EUI@80FEUI00h0D51@05UIF@1IFET0F5QH05YJFP1LG5`0E5AD
05YJFP1BDU80Cdm?05QHF01FEUH0CTi>05ADE1L000001@3IfMT200000040fMWI000F0=WIf@030000
003IfMT0fMWI00<0fMWI01/0e=CD061PH01TI6@0JFUY06IVIP1XJ6P0IVIV065QH@1RHV80I6AT06=S
H`1XJ6P0IfMW06ATI01XJ6P0HF5Q06ATI01YJFT0H61P065QH@1ZJVX0IVIV06YZJP1WIfL0Hf=S05iN
GP1PH6000P1VIVH03`1XJ6P0I6AT065QH@1ZJVX0IVIV05QHF01XJ6P0IVIV06QXJ01YJFT0I6AT06QX
J01UIFD0I6AT065QH@0206=SH`0>06][J`1WIfL0I6AT06MWI`1[Jf/0J6QX06MWI`1TI6@0Hf=S06AT
I01XJ6P0KVi^06QXJ01^KVh206QXJ00>06a/K01WIfL0K6a/06a/K01YJFT0HV9R06IVIP1]KFd0JVYZ
06UYJ@1XJ6P0K6a/06UYJ@1ZJVX206i^KP80JFUY0P1[Jf/0801WIfL0Kfm_071`L01ZJVX0Kfm_071`
L01hN7P0Jf][06YZJP1dM7@0Lg=c06i^KP1cLg<0Jf][06i^KP1XJ6P0LG5a06IVIP1^KVh0LW9b07=c
L`1`L700LG5a06a/K01bLW80M7Ad06i^KP1aLG40KFe]071`L01gMgL0L71`0P1]KFd03`1/K6`0MGEe
071`L01`L700J6QX06ATI01bLW80Lg=c06a/K01ZJVX0JFUY079bLP1cLg<0K6a/079bLP02071`L00[
06a/K01dM7@0Jf][071`L01YJFT0Lg=c06QXJ01`L700K6a/06UYJ@1/K6`0MWIf075aL@1XJ6P0LW9b
07EeM@1/K6`0MGEe06m_K`1ZJVX0KFe]06IVIP1]KFd0LW9b06][J`1XJ6P0JFUY06i^KP1XJ6P0Hf=S
06UYJ@1VIVH0H61P06i^KP1WIfL0KVi^06YZJP1]KFd0I6AT06a/K01_Kfl0Jf][071`L00206a/K00L
06YZJP1^KVh0I6AT06IVIP1UIFD0GUiN065QH@1PH600HF5Q061PH01QHF40FUYJ06EUI@1NGUh0Fe]K
06MWI`1^KVh0I6AT06IVIP1ZJVX0IFEU06QXJ01YJFT0J6QX06IVIP1RHV80IFEU06][J`80HF5Q01H0
J6QX06IVIP1MGEd0HF5Q05aLG01RHV80HF5Q05eMG@1TI6@0GEeM06=SH`1RHV80G5aL06=SH`1MGEd0
HV9R05iNGP1QHF40F5QH05aLG01NGUh0HV9R0P1LG5`04@1MGEd0GUiN06IVIP1MGEd0I6AT06=SH`1V
IVH0Hf=S065QH@1KFe/0EUIF061PH01FEUH0HF5Q05eMG@1HF5P0GemO0080H61P0`1SHf<04`1OGel0
I6AT06ATI01XJ6P0Kfm_06i^KP1]KFd0LG5a07emO@24Q8@0RHV909bLW02SXj<0X:2P09NGU`2=SHd0
NGUi071`L01TI6@00P1UIFD205]KF`07065QH@1IFET0GemO069RHP1FEUH0EeMG05]KF`0205EEE@05
05ADE01EEED0FEUI05YJFP1FEUH05`0000060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3I
fMT00`3IfMT07P3Ng]h0I6AT061PH01MGEd0HF5Q06UYJ@1WIfL0Hf=S06IVIP1[Jf/0IfMW06ATI01P
H600J6QX06ATI01RHV80H61P06][J`1PH600HV9R06i^KP1SHf<0IVIV06=SH`1TI6@0Fe]K06QXJ01S
Hf<0Jf][06IVIP80Hf=S00T0GEeM069RHP1SHf<0JVYZ06=SH`1TI6@0HV9R061PH01XJ6P00P1TI6@2
06MWI`0506IVIP1[Jf/0L71`065QH@1TI6@00P1PH6003P1YJFT0H61P06ATI01XJ6P0Jf][061PH01Z
JVX0KVi^071`L01_Kfl0J6QX05eMG@1_Kfl0Fe]K0P1XJ6P01P1VIVH0JVYZ06ATI01WIfL0Jf][06UY
J@80Jf][00<0Kfm_065QH@1]KFd00P1TI6@02P1VIVH0JFUY06UYJ@1XJ6P0L71`06UYJ@1VIVH0I6AT
06UYJ@1VIVH206YZJP0806MWI`1XJ6P0JFUY071`L01^KVh0Jf][06a/K01fMWH206a/K00;06i^KP1b
LW80Lg=c071`L01/K6`0KVi^07UiN@1aLG40MgMg06YZJP1TI6@00P1cLg<06P1aLG40K6a/06QXJ01/
K6`0Jf][06UYJ@1_Kfl0LG5a06QXJ01aLG40Lg=c06a/K01^KVh0JVYZ075aL@1`L700Kfm_06a/K01Z
JVX0MGEe06QXJ01`L700M7Ad07QhN01WIfL0IVIV0P1[Jf/01`1/K6`0LG5a06IVIP1/K6`0Jf][06UY
J@1^KVh00P1aLG406@1/K6`0Jf][06UYJ@1XJ6P0KVi^06][J`1YJFT0Jf][06IVIP1^KVh0KFe]06IV
IP1WIfL0J6QX075aL@1ZJVX0Kfm_06][J`1aLG40K6a/06QXJ01[Jf/0KFe]069RHP1[Jf/00P1YJFT0
8@1WIfL0I6AT06QXJ01RHV80IfMW06=SH`1VIVH0H61P06IVIP1PH600Hf=S06ATI01RHV80HF5Q06IV
IP1WIfL0Hf=S065QH@1/K6`0L71`061PH01QHF40JVYZ065QH@1[Jf/0J6QX05aLG01QHF40J6QX065Q
H@1SHf<0H61P05mOG`02065QH@0606EUI@1LG5`0HV9R05mOG`1SHf<0Fe]K0P1LG5`0A01QHF40I6AT
05iNGP1KFe/0GUiN05aLG01JFUX0GUiN061PH01QHF40GEeM05aLG01IFET0H61P06EUI@1LG5`0H61P
05]KF`1IFET0Fe]K05iNGP1HF5P0GUiN05MGE`1IFET0GUiN05aLG01HF5P0IVIV061PH01QHF40HV9R
061PH01RHV80IFEU06=SH`1aLG40JVYZ06MWI`1jNWX0RHV909VIV@2c/k<0fm_K0=KFeP2e]KD0ZJVY
08:2PP1dM7@0JFUY06QXJ01RHV80H61P065QH@1NGUh0Fe]K05aLG01IFET0Fe]K05QHF01KFe/0EEEE
05QHF01KFe/0EeMG05ADE01LG5`0F5QH5`0000060=WIf@4000000@3IfMT001H0fMWI00<000000=WI
f@3IfMT00`3IfMT0>03Fe]H0I6AT06QXJ01NGUh0J6QX05mOG`1QHF40IVIV05iNGP1PH600IFEU06QX
J01QHF40F5QH06MWI`1PH600IVIV06ATI01XJ6P0HV9R06IVIP1QHF40IFEU06ATI01YJFT0H61P06=S
H`1QHF40I6AT06IVIP1[Jf/0FEUI06IVIP1WIfL0HF5Q06MWI`1MGEd0Hf=S06QXJ01VIVH0J6QX06][
J`1MGEd0IFEU06ATI01^KVh0K6a/06QXJ01YJFT0GemO06UYJ@1[Jf/0IFEU06ATI01PH600HV9R0P1S
Hf<206i^KP80K6a/02L0LG5a06IVIP1[Jf/0GUiN065QH@1UIFD0Hf=S06QXJ01RHV80J6QX06YZJP1V
IVH0J6QX06IVIP1TI6@0IVIV065QH@1UIFD0G5aL05iNGP1RHV80Hf=S069RHP1QHF40H61P06QXJ01/
K6`0IfMW06a/K01[Jf/0JFUY06a/K01^KVh0LG5a06ATI01/K6`0Kfm_06][J`1_Kfl00P1`L700@01c
Lg<0LG5a07=cL`1^KVh0Jf][069RHP1`L700K6a/07MgM`1/K6`0JFUY06i^KP1/K6`0L71`06][J`1^
KVh0M7Ad06i^KP1YJFT0K6a/07=cL`1`L700M7Ad075aL@1^KVh0K6a/06e]K@1gMgL0Kfm_07UiN@1^
KVh0K6a/071`L01[Jf/0KVi^075aL@1hN7P0J6QX06i^KP1aLG40Jf][075aL@1/K6`0J6QX06i^KP1b
LW80Jf][075aL@1[Jf/0L71`06e]K@1VIVH0JVYZ079bLP1YJFT0KVi^06][J`1]KFd0JFUY06i^KP1Z
JVX0Kfm_075aL@1/K6`206UYJ@0P06i^KP1_Kfl0JVYZ075aL@1YJFT0KVi^06ATI01]KFd0IVIV06UY
J@1/K6`0J6QX06YZJP1YJFT0J6QX06i^KP1QHF40Jf][06ATI01NGUh0HV9R05aLG01VIVH0JFUY06IV
IP1WIfL0J6QX06UYJ@1VIVH0HF5Q061PH01SHf<206UYJ@0@065QH@1YJFT0IfMW061PH01RHV80G5aL
06EUI@1TI6@0Fe]K065QH@1WIfL0G5aL065QH@1NGUh0H61P06IVIP80GUiN00H0HF5Q06=SH`1NGUh0
HF5Q05aLG01QHF4206=SH`0905]KF`1PH600GemO05aLG01MGEd0HV9R061PH01SHf<0HF5Q0080FEUI
00/0EEEE05mOG`1LG5`0GUiN05EEE@1LG5`0GEeM065QH@1LG5`0FUYJ05iNGP0205UIF@0605QHF01T
I6@0IFEU05iNGP1LG5`0JFUY0P1/K6`01@1ZJVX0O7al09>CT`2NWYh0e=CD0080oooo00`0h>3P0<71
`@2>SXh0MgMg06][J`1TI6@0HV9R065QH@1GEeL0F5QH05iNGP1LG5`205]KF`0705IFEP1ADE40EUIF
05=CD`1KFe/0DU9B05QHF00205=CDaL000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0
fMWI00<0fMWI00D0g=cL065QH@1LG5`0HF5Q06EUI@0206ATI080HF5Q00D0IfMW06QXJ01UIFD0HF5Q
06QXJ00206=SH`0306QXJ01QHF40HV9R00<0I6AT0P1VIVH01P1NGUh0Hf=S06ATI01QHF40JFUY06EU
I@80GEeM00h0I6AT061PH01XJ6P0IVIV05mOG`1SHf<0JFUY061PH01NGUh0I6AT06YZJP1VIVH0HF5Q
06IVIP80I6AT01@0H61P06IVIP1YJFT0IFEU06QXJ01PH600IVIV06MWI`1VIVH0K6a/06m_K`1ZJVX0
IVIV06ATI01QHF40KVi^06=SH`1RHV80I6AT06MWI`80JFUY00h0JVYZ06EUI@1PH600KFe]06YZJP1Y
JFT0HF5Q06EUI@1SHf<0IFEU05mOG`1LG5`0EeMG05QHF080GemO00L0I6AT06=SH`1VIVH0K6a/06UY
J@1ZJVX0KFe]0080JVYZ00h0KFe]06a/K01]KFd0IVIV06EUI@1YJFT0L71`06m_K`1ZJVX0K6a/06e]
K@1`L700KVi^07AdM080Lg=c0P1YJFT01`1_Kfl0N7Qh07AdM01aLG40MGEe079bLP1fMWH00`1dM7@0
0`1]KFd0JVYZ06i^KP03071`L00G075aL@1dM7@0JFUY06e]K@1aLG40JVYZ06m_K`1cLg<0Jf][07=c
L`1_Kfl0LG5a06e]K@1TI6@0IfMW06QXJ01[Jf/0IVIV06a/K01`L700JFUY06ATI01YJFT00P1VIVH0
0`1/K6`0KVi^06ATI00206MWI`0T06e]K@1/K6`0KVi^06i^KP1aLG40JFUY06IVIP1/K6`0IVIV06YZ
JP1VIVH0KVi^071`L01/K6`0Hf=S075aL@1VIVH0Jf][06e]K@1/K6`0J6QX065QH@1ZJVX0Kfm_06UY
J@1UIFD0Hf=S06IVIP1[Jf/0IVIV06MWI`1UIFD0J6QX06][J`1SHf<0H61P0`1SHf<06P1RHV80Fe]K
06e]K@1NGUh0IFEU05mOG`1VIVH0FUYJ05eMG@1PH600I6AT05aLG01UIFD0H61P06IVIP1QHF40IVIV
05aLG01RHV80I6AT05aLG01QHF40G5aL05IFEP1QHF40GUiN0P1QHF401@1LG5`0Fe]K05YJFP1SHf<0
H61P0080G5aL01L0Hf=S05mOG`1OGel0F5QH05MGE`1KFe/0GEeM05YJFP1NGUh0F5QH05IFEP1LG5`0
EUIF05QHF01MGEd0G5aL061PH01NGUh0H61P065QH@1MGEd0GemO061PH00206=SH`0806IVIP1RHV80
KFe]071`L01kNg/0U9BD0:>SX`3Hf=P20?ooo`0G0>OWi`3Bd]80U9BD07moO`1cLg<0JFUY06EUI@1X
J6P0E5AD065QH@1GEeL0GUiN05]KF`1GEeL0FUYJ05aLG01FEUH0De=C05aLG01GEeL0D51@05EEE@1C
De<05`0000060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT08P3QhN40I6AT
065QH@1PH600HF5Q06IVIP1QHF40K6a/06IVIP1WIfL0GUiN065QH@1VIVH0JFUY06ATI01UIFD0GemO
06EUI@1WIfL0IVIV05]KF`1WIfL0Hf=S06IVIP1TI6@0IVIV06MWI`1NGUh0Hf=S06ATI01NGUh0GemO
065QH@1SHf<3065QH@05061PH01XJ6P0GemO05]KF`1PH6000P1TI6@01P1KFe/0HV9R06YZJP1RHV80
Hf=S06ATI080IVIV0P1YJFT01P1VIVH0HV9R06][J`1SHf<0J6QX06IVIP80J6QX00H0HF5Q06QXJ01X
J6P0Hf=S06ATI01PH60206=SH`0>06EUI@1QHF40K6a/05eMG@1SHf<0GUiN065QH@1MGEd0Fe]K05QH
F01NGUh0EUIF05QHF01CDe<205QHF00>05EEE@1VIVH0HF5Q05mOG`1RHV80KVi^06][J`1/K6`0JFUY
06a/K01YJFT0Lg=c06][J`1^KVh206][J`0M06i^KP1YJFT0KVi^06][J`1fMWH0L71`06m_K`1`L700
Kfm_06a/K01`L700Kfm_06QXJ01YJFT0Kfm_06a/K01cLg<0L71`06e]K@1cLg<0N7Qh06a/K01`L700
JFUY06EUI@1TI6@0K6a/06i^KP1cLg<00P1/K6`01`1[Jf/0Lg=c06m_K`1`L700LG5a071`L01]KFd0
0P1aLG401P1VIVH0KVi^06][J`1TI6@0Jf][06i^KP80K6a/00L0J6QX06IVIP1WIfL0K6a/06QXJ01]
KFd0Lg=c0080JFUY00/0Jf][06QXJ01WIfL0Jf][075aL@1YJFT0Jf][06IVIP1[Jf/0Hf=S06][J`02
06MWI`0306UYJ@1SHf<0JFUY0080K6a/00H0KVi^06MWI`1[Jf/0JFUY06][J`1PH60206a/K080IVIV
01X0I6AT065QH@1[Jf/0Jf][061PH01YJFT0Jf][065QH@1PH600JVYZ06QXJ01NGUh0IfMW06][J`1P
H600GUiN061PH01SHf<0JFUY069RHP1PH600Fe]K06EUI@1XJ6P0HV9R06ATI080IVIV00T0Hf=S06AT
I01PH600H61P06IVIP1SHf<0GUiN065QH@1MGEd00P1PH6000`1NGUh0FEUI05QHF00205iNGP0;05UI
F@1JFUX0HV9R05aLG01NGUh0G5aL05iNGP1DE5@0GUiN05eMG@1LG5`00P1KFe/01`1FEUH0F5QH05aL
G01HF5P0Fe]K05QHF01OGel00P1KFe/03@1NGUh0HF5Q05aLG01RHV80GemO06IVIP1/K6`0Jf][075a
L@1fMWH0S8b<09fMW@3Kfm/00P3oool0303Ph>00_;bl08j>SP22PX80MGEe075aL@1TI6@0IFEU05eM
G@1HF5P0FEUI05]KF`80FEUI00D0E5AD059BDP1LG5`0E5AD05QHF00205MGE`0305UIF@1MGEd00000
01H000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00X0fm_K05mOG`1Q
HF40Hf=S06EUI@1NGUh0Hf=S06IVIP1TI6@0IVIV0P1OGel01`1LG5`0I6AT06IVIP1XJ6P0JFUY061P
H01VIVH00P1QHF401@1XJ6P0H61P06IVIP1SHf<0HV9R0080HF5Q00<0Hf=S06QXJ01TI6@00P1QHF42
061PH00@06=SH`1UIFD0GEeM069RHP1NGUh0JFUY05IFEP1VIVH0I6AT05aLG01RHV80JFUY06ATI01U
IFD0IVIV06EUI@80Hf=S00L0IFEU065QH@1QHF40Hf=S06a/K01XJ6P0IFEU00<0J6QX00X0KVi^05iN
GP1QHF40JVYZ06EUI@1WIfL0GUiN06ATI01QHF40GemO0P1SHf<02P1QHF40IVIV05eMG@1IFET0GEeM
05IFEP1EEED0C4a<05IFEP1;Bd/205ADE00705=CD`1KFe/0H61P06QXJ01[Jf/0KVi^06a/K00206QX
J00406EUI@1YJFT0K6a/06a/K080IVIV00/0K6a/06QXJ01_Kfl0LG5a06a/K01aLG40Jf][06a/K01_
Kfl0LG5a06e]K@0206a/K00:06UYJ@1^KVh0LW9b06i^KP1/K6`0JVYZ06m_K`1TI6@0IfMW06UYJ@80
JVYZ02`0J6QX06a/K01XJ6P0J6QX06e]K@1/K6`0IVIV06QXJ01cLg<0JFUY06a/K01`L700KFe]079b
LP1^KVh0L71`06MWI`1]KFd0J6QX06e]K@1aLG40J6QX06][J`1WIfL0KVi^071`L01]KFd0K6a/06][
J`1YJFT0Jf][069RHP1_Kfl0K6a/06m_K`1/K6`0J6QX06MWI`1YJFT0JVYZ06UYJ@1SHf<0J6QX06m_
K`80Jf][02/0KFe]06QXJ01bLW80IfMW071`L01YJFT0KFe]06QXJ01PH600JVYZ06IVIP1YJFT0Hf=S
061PH01ZJVX0IVIV06UYJ@1VIVH0Jf][06ATI01/K6`0J6QX06ATI01[Jf/0H61P06UYJ@1VIVH0J6QX
065QH@1TI6@0HV9R061PH01RHV80GemO061PH01VIVH0Hf=S06UYJ@1TI6@0IVIV06QXJ01TI6@0HF5Q
0080G5aL00@0GUiN06IVIP1WIfL0H61P0P1VIVH02@1HF5P0FEUI05]KF`1OGel0GUiN06ATI01PH600
EUIF05eMG@0205iNGP03061PH01WIfL0HF5Q0080FEUI00@0GEeM05]KF`1IFET0EUIF0P1PH6000`1N
GUh0HF5Q05aLG00305iNGP80FEUI01D0H61P06ATI01QHF40GUiN06=SH`1TI6@0J6QX079bLP1lO7`0
OWin09RHV02n_[h0hn?S0=GEe@2n_[h0[:b/08n?S`21PH40K6a/075aL@1ZJVX00P1MGEd03P1TI6@0
FEUI05]KF`1IFET0Fe]K05UIF@1FEUH0D51@05QHF01CDe<0Fe]K059BDP1DE5@0F5QH5`0000060=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT05P3Ogml0JFUY06EUI@1OGel0Hf=S
065QH@1TI6@0H61P065QH@1SHf<0Fe]K06QXJ01UIFD0GUiN06IVIP1XJ6P0HF5Q06QXJ01TI6@0HV9R
065QH@1MGEd205mOG`0=06=SH`1TI6@0GemO065QH@1SHf<0IFEU06MWI`1XJ6P0HV9R061PH01QHF40
IVIV05aLG002061PH00706=SH`1QHF40Hf=S06ATI01QHF40H61P065QH@0306QXJ00?06a/K01QHF40
H61P06ATI01UIFD0IfMW06QXJ01NGUh0JVYZ06EUI@1TI6@0LG5a06EUI@1bLW80K6a/0080IFEU00h0
GEeM065QH@1QHF40HV9R06QXJ01SHf<0HF5Q06=SH`1TI6@0L71`06ATI01QHF40EeMG05UIF@80F5QH
00P0E5AD05IFEP1CDe<0EUIF05ADE01EEED0FEUI05]KF`<0H61P00/0IFEU06UYJ@1XJ6P0I6AT06e]
K@1`L700JFUY06m_K`1YJFT0Jf][06a/K00206YZJP0:06e]K@1^KVh0Jf][079bLP1`L700JFUY079b
LP1_Kfl0Jf][06a/K080Lg=c01D0J6QX06MWI`1cLg<0KFe]06][J`1^KVh0K6a/07=cL`1[Jf/0KFe]
06MWI`1cLg<0LG5a06e]K@1XJ6P0KVi^06UYJ@1^KVh0JVYZ06UYJ@1_Kfl00P1^KVh07@1cLg<0J6QX
06][J`1VIVH0JFUY079bLP1ZJVX0KFe]06UYJ@1]KFd0JVYZ06][J`1WIfL0>c/k06IVIP1[Jf/0IFEU
06i^KP1XJ6P0Jf][06QXJ01aLG40IFEU06i^KP1WIfL0L71`06IVIP1YJFT0Kfm_0080J6QX00/0IfMW
06m_K`1/K6`0JFUY06QXJ01[Jf/0JFUY06=SH`1UIFD0Hf=S06IVIP0206ATI003069RHP1XJ6P0HF5Q
0080Hf=S01d0IFEU05mOG`1UIFD0KVi^05]KF`1XJ6P0GUiN06QXJ01VIVH0Hf=S06IVIP1RHV80J6QX
061PH01QHF40IVIV065QH@1VIVH0GUiN069RHP1QHF40Hf=S06QXJ01PH600I6AT05aLG01QHF40GEeM
06ATI00205mOG`0A05iNGP1PH600Fe]K05]KF`1RHV80EUIF05]KF`1QHF40GUiN065QH@1IFET0Fe]K
065QH@1KFe/0FEUI06=SH`1NGUh00P1LG5`0<`1HF5P0FEUI05EEE@1FEUH0FEUI069RHP1NGUh0De=C
05]KF`1TI6@0DU9B04Y:BP1<C4`0GemO061PH01KFe/0I6AT065QH@1TI6@0GemO069RHP1SHf<0J6QX
07alO026QXH0Ti>C0:ZZZP2PX:00WYjN09JFUP25QHD0OGem075aL@1]KFd0IVIV06ATI01MGEd0HV9R
06=SH`1JFUX0FEUI061PH01LG5`0EeMG05=CD`1JFUX0GUiN05aLG01JFUX0FEUI059BDP0G000000H0
fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@090=SHf01TI6@0HV9R06YZJP1P
H600HV9R065QH@1YJFT0HF5Q0080H61P02H0I6AT06QXJ01SHf<0HF5Q06UYJ@1NGUh0JFUY06ATI01R
HV80IfMW06UYJ@1PH600GemO065QH@1WIfL0IVIV06ATI01QHF40Hf=S05iNGP1UIFD0GUiN06=SH`1R
HV80I6AT065QH@1PH600GUiN06MWI`1[Jf/0Hf=S06ATI01QHF40J6QX06=SH`1XJ6P0IVIV06QXJ080
I6AT02T0JVYZ06QXJ01PH600HF5Q06ATI01SHf<0GUiN06UYJ@1RHV80KVi^06UYJ@1aLG40Jf][06m_
K`1YJFT0Hf=S06EUI@1SHf<0HF5Q061PH01VIVH0Fe]K06QXJ01PH600J6QX05iNGP1KFe/0FEUI05AD
E01?Cdl0EUIF05]KF`1DE5@0H61P05QHF01GEeL0E5AD05]KF`1FEUH0GUiN061PH00206UYJ@0406e]
K@1RHV80J6QX06QXJ080Jf][0340KFe]06MWI`1^KVh0K6a/06i^KP1QHF40LG5a06UYJ@1^KVh0JVYZ
07=cL`1bLW80J6QX06MWI`1cLg<0K6a/06YZJP1cLg<0Jf][06i^KP1`L700N7Qh06i^KP1XJ6P0K6a/
06][J`1WIfL0Kfm_06IVIP1]KFd0J6QX06e]K@1YJFT0KVi^06m_K`1[Jf/0JFUY06i^KP1XJ6P0IVIV
07IfMP1aLG40Jf][075aL@1XJ6P0KFe]071`L01_Kfl0KVi^0080KFe]02P0IfMW06a/K01YJFT0IFEU
06i^KP1YJFT0K6a/06YZJP1`L700K6a/06][J`1^KVh0HF5Q06UYJ@1XJ6P0IVIV06i^KP1YJFT0JVYZ
06QXJ01[Jf/0JFUY065QH@1^KVh0IFEU06QXJ01TI6@0Jf][061PH01SHf<0H61P06a/K01XJ6P0IFEU
06m_K`1YJFT0GUiN06UYJ@1VIVH0JVYZ0P1UIFD00`1SHf<0KVi^06IVIP02065QH@0M06QXJ01VIVH0
I6AT06IVIP1QHF40FUYJ06=SH`1QHF40Hf=S06ATI01NGUh0HV9R065QH@1SHf<0HF5Q06MWI`1VIVH0
F5QH065QH@1NGUh0I6AT069RHP1SHf<0F5QH069RHP1JFUX0GUiN061PH01QHF400P1KFe/01`1LG5`0
Fe]K05ADE01NGUh0Fe]K05eMG@1KFe/00`1LG5`03`1GEeL0E5AD05MGE`1MGEd0F5QH05]KF`1LG5`0
Fe]K05eMG@1LG5`0De=C05]KF`1@D500EUIF055AD@0205iNGP0606=SH`1UIFD0IVIV06ATI01QHF40
I6AT0P1aLG402`1fMWH0Ph>308b<S02BTY80Ti>C08b<S025QHD0Ng]k07=cL`1ZJVX0J6QX0080HF5Q
00h0I6AT05eMG@1PH600GUiN05UIF@1@D500EUIF05=CD`1IFET0Fe]K05ADE01CDe<0E5AD04i>CQL0
00001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI01X0h^;R06=SH`1SHf<0
IVIV065QH@1SHf<0GemO069RHP1OGel0FEUI061PH01RHV80Jf][06ATI01SHf<0HF5Q06IVIP1SHf<0
IFEU05mOG`1SHf<0HV9R06EUI@1TI6@0Fe]K069RHP80Hf=S00D0GemO061PH01VIVH0HF5Q06UYJ@02
065QH@80I6AT00L0H61P065QH@1OGel0H61P05iNGP1LG5`0GUiN0080HF5Q0P1TI6@01@1KFe/0IVIV
05mOG`1KFe/0IVIV0080HV9R01D0I6AT06=SH`1XJ6P0GUiN06i^KP1[Jf/0NGUi07AdM01/K6`0G5aL
06ATI01VIVH0I6AT06UYJ@1SHf<0Jf][06=SH`1OGel0J6QX06ATI01/K6`00P1TI6@05`1CDe<0EeMG
05ADE01ADE40G5aL05]KF`1IFET0HV9R05MGE`1DE5@0FUYJ05EEE@1NGUh0G5aL06EUI@1WIfL0LW9b
071`L01XJ6P0IVIV06i^KP1_Kfl0JFUY0080Kfm_0`1`L7001`1/K6`0LG5a06][J`1/K6`0L71`06UY
J@1`L7000P1_Kfl05@1`L700K6a/06i^KP1aLG40KVi^06MWI`1/K6`0IVIV06a/K01XJ6P0Jf][06e]
K@1`L700HV9R06UYJ@1VIVH0Jf][06m_K`1[Jf/0IfMW06UYJ@0206QXJ00706=SH`1/K6`0JVYZ06i^
KP1[Jf/0IfMW06IVIP0206m_K`0<06a/K01XJ6P0JFUY071`L01^KVh0Hf=S06UYJ@1_Kfl0KVi^06QX
J01RHV80KVi^0P1YJFT0301^KVh0Hf=S06IVIP1UIFD0Jf][06UYJ@1XJ6P0JFUY06a/K01TI6@0JFUY
06EUI@80JFUY01<0Jf][06QXJ01/K6`0Jf][05aLG01VIVH0Hf=S071`L01XJ6P0HF5Q06MWI`1ZJVX0
I6AT06a/K01TI6@0Hf=S06MWI`1VIVH0IfMW0080Hf=S00`0IVIV065QH@1OGel0Hf=S05mOG`1RHV80
Fe]K05iNGP1VIVH0JVYZ06=SH`1VIVH206=SH`0=06EUI@1NGUh0Hf=S06ATI01PH600HF5Q05mOG`1P
H600HF5Q05mOG`1SHf<0I6AT05aLG00205iNGP80G5aL00@0GEeM05aLG01KFe/0FEUI0`1KFe/0401I
FET0H61P06=SH`1FEUH0GemO05QHF01JFUX0FEUI05QHF01GEeL0EUIF05ADE01KFe/0EUIF05ADE01N
GUh205]KF`0?05YJFP1KFe/0F5QH05MGE`1QHF40I6AT05UIF@1LG5`0HF5Q06EUI@1ZJVX0JFUY06][
J`1_Kfl0NGUi0080Ph>300X0M7Ad07UiN@1jNWX0LG5a06QXJ01YJFT0K6a/065QH@1LG5`0HF5Q0P1I
FET02P1HF5P0Fe]K051@D01DE5@0GUiN05UIF@1FEUH0E5AD05IFEP1DE5@G000000H0fMWI0@000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@070=SHf01PH600FEUI05iNGP1OGel0JVYZ06QX
J00205aLG00706IVIP1PH600IFEU06ATI01XJ6P0Hf=S06QXJ00206=SH`0J05mOG`1XJ6P0HF5Q05eM
G@1SHf<0I6AT05eMG@1PH600GUiN06][J`1KFe/0GUiN05mOG`1SHf<0IfMW06ATI01UIFD0GEeM06MW
I`1PH600Fe]K065QH@1LG5`0JFUY069RHP1PH60206ATI080H61P00<0Hf=S05iNGP1[Jf/00P1TI6@0
1P1XJ6P0JFUY06IVIP1VIVH0HF5Q069RHP80L71`00X0M7Ad06][J`1^KVh0IfMW06=SH`1PH600JFUY
06QXJ01PH600GEeM0P1KFe/306=SH`0@065QH@1HF5P0EUIF04a<C01FEUH0FEUI05QHF01LG5`0Hf=S
05iNGP1LG5`0HF5Q05ADE01?Cdl0Fe]K05eMG@80I6AT00H0Hf=S06][J`1PH600IfMW06IVIP1[Jf/2
06a/K00;06][J`1YJFT0Jf][06UYJ@1`L700Jf][06i^KP1/K6`0MGEe06a/K01UIFD00P1^KVh0:01`
L700KFe]06i^KP1[Jf/0Kfm_06][J`1XJ6P0L71`06][J`1SHf<0Jf][06IVIP1[Jf/0KFe]06i^KP1Y
JFT0IVIV06][J`1jNWX0Jf][06MWI`1dM7@0Kfm_07AdM01PH600KVi^071`L01UIFD0Jf][06UYJ@1W
IfL0JFUY06IVIP1YJFT0Hf=S06a/K01aLG40JFUY06IVIP1bLW8206UYJ@0606QXJ01WIfL0K6a/06IV
IP1YJFT0KFe]0P1^KVh01P1`L700Kfm_06IVIP1XJ6P0JFUY069RHP80IFEU00H0JVYZ06ATI01WIfL0
LW9b06YZJP1/K6`2065QH@0506=SH`1XJ6P0H61P069RHP1TI6@00P1QHF400`1UIFD0GemO06=SH`02
061PH00O06YZJP1RHV80Hf=S05iNGP1QHF40Jf][065QH@1TI6@0GEeM069RHP1KFe/0JFUY065QH@1S
Hf<0H61P065QH@1LG5`0GUiN065QH@1RHV80H61P069RHP1LG5`0GUiN06IVIP1JFUX0Hf=S05eMG@1P
H600GUiN05eMG@0205mOG`80EUIF01P0FEUI05aLG01LG5`0HV9R05eMG@1PH600IVIV069RHP1JFUX0
GUiN05=CD`1LG5`0F5QH05UIF@1KFe/0EEEE05YJFP1IFET0Fe]K05eMG@1FEUH0G5aL05]KF`1MGEd2
05iNGP0>05ADE01JFUX0GEeM061PH01KFe/0I6AT06EUI@1QHF40Hf=S06EUI@1SHf<0IVIV06a/K01Z
JVX207IfMP0307=cL`1_Kfl0L71`0080Jf][0100IVIV06=SH`1FEUH0HF5Q05aLG01IFET0FUYJ05]K
F`1NGUh0D51@05QHF01FEUH0EEEE055AD@1IFET0D51@5`0000060=WIf@4000000@3IfMT001H0fMWI
0P0000040=WIf@0M0=?Cd`1HF5P0GUiN069RHP1YJFT0J6QX05iNGP1QHF40JFUY065QH@1YJFT0Fe]K
06EUI@1SHf<0JFUY05aLG01YJFT0G5aL05mOG`1QHF40EeMG05UIF@1PH600EUIF06ATI01VIVH0I6AT
05eMG@1PH6000P1QHF400`1TI6@0JFUY06EUI@02065QH@0H061PH01KFe/0GUiN061PH01/K6`0GUiN
061PH01VIVH0GUiN065QH@1SHf<0IfMW065QH@1NGUh0Hf=S05aLG01NGUh0HF5Q06ATI01SHf<0Fe]K
06IVIP1NGUh0I6AT0P1[Jf/206ATI00806IVIP1YJFT0IVIV061PH01UIFD0IVIV06MWI`1SHf<3061P
H00B05iNGP1HF5P0De=C04Y:BP1<C4`0D51@05ADE01MGEd0Hf=S05eMG@1NGUh0F5QH05EEE@1CDe<0
DE5A05EEE@1DE5@0JVYZ0P1TI6@01`1XJ6P0L71`06=SH`1RHV80JFUY06a/K01^KVh00P1ZJVX0:01R
HV80KFe]06][J`1WIfL0Jf][06UYJ@1^KVh0LG5a071`L01WIfL0LG5a06][J`1bLW80KVi^06EUI@1c
Lg<0JFUY06YZJP1[Jf/0JVYZ071`L01YJFT0K6a/06UYJ@1/K6`0J6QX06a/K01QHF40K6a/06YZJP1]
KFd0Jf][06a/K01ZJVX0IVIV06m_K`1TI6@0Jf][06m_K`1`L70206YZJP0@06IVIP1YJFT0IVIV06QX
J01YJFT0K6a/06e]K@1/K6`0HF5Q06m_K`1VIVH0HF5Q06IVIP1/K6`0J6QX06UYJ@80Kfm_00`0IVIV
06a/K01RHV80H61P075aL@1/K6`0IFEU06IVIP1YJFT0IVIV06ATI01UIFD206ATI00506a/K01QHF40
J6QX06=SH`1XJ6P00P1WIfL00`1TI6@0IVIV061PH00206ATI00A05]KF`1XJ6P0H61P06=SH`1UIFD0
G5aL06e]K@1YJFT0H61P05mOG`1UIFD0GUiN061PH01SHf<0IVIV06ATI01OGel00P1QHF40201YJFT0
IfMW065QH@1PH600GemO05iNGP1RHV80Hf=S0P1QHF401`1PH600G5aL061PH01NGUh0G5aL05]KF`1N
GUh00P1LG5`0:P1KFe/0GUiN05UIF@1MGEd0GUiN065QH@1OGel0Fe]K061PH01QHF40H61P05aLG01K
Fe/0G5aL05iNGP1KFe/0H61P065QH@1HF5P0I6AT05QHF01KFe/0G5aL05iNGP1DE5@0IVIV05]KF`1P
H600C4a<061PH01LG5`0FUYJ05UIF@1MGEd0I6AT05eMG@1TI6@0Hf=S05mOG`1YJFT0IfMW06UYJ@80
Jf][00L0KVi^06a/K01OGel0Hf=S06ATI01RHV80FEUI0080Fe]K00X0FEUI05YJFP1HF5P0Fe]K05EE
E@1HF5P0Fe]K05UIF@1FEUH0E5AD5`0000050=WIf@8000000@3IfMT001H0fMWI00<000000=WIf@3I
fMT00`3IfMT04`3Hf=P0JFUY05]KF`1NGUh0GEeM06IVIP1RHV80JVYZ06QXJ01SHf<0IVIV06UYJ@1P
H600HF5Q05iNGP1PH600J6QX06EUI@1OGel00P1QHF402P1PH600GemO05iNGP1QHF40FEUI05eMG@1P
H600HV9R05]KF`1PH60206=SH`0506][J`1PH600H61P069RHP1`L7000P1XJ6P0601NGUh0G5aL06MW
I`1PH600IFEU06=SH`1XJ6P0GemO06ATI01RHV80Hf=S06ATI01SHf<0HF5Q06QXJ01PH600J6QX06AT
I01XJ6P0HV9R065QH@1TI6@0Jf][06=SH`80H61P01<0JFUY06ATI01YJFT0IFEU06UYJ@1PH600HF5Q
06ATI01RHV80IVIV05]KF`1CDe<0C4a<04I6AP1<C4`0F5QH05eMG@1KFe/0HV9R0080Fe]K0180EEEE
04e=C@1DE5@0G5aL05]KF`1QHF40J6QX061PH01/K6`0H61P06QXJ01VIVH0JFUY06IVIP1/K6`0LG5a
06UYJ@1aLG4206i^KP0T06QXJ01ZJVX0Kfm_06i^KP1ZJVX0JFUY06=SH`1YJFT0L71`06][J`1cLg<0
K6a/06IVIP1YJFT0Jf][06MWI`1XJ6P0Jf][06UYJ@1VIVH0KVi^06a/K01[Jf/0JFUY07=cL`1/K6`0
MWIf06a/K01XJ6P0Kfm_06e]K@1VIVH0L71`06UYJ@1/K6`0Lg=c0P1YJFT04@1VIVH0I6AT06i^KP1^
KVh0IFEU06UYJ@1[Jf/0HF5Q06i^KP1XJ6P0IVIV06MWI`1XJ6P0IVIV06QXJ01YJFT0JVYZ0080I6AT
0P1QHF403`1_Kfl0K6a/06YZJP1TI6@0LG5a06QXJ01[Jf/0KFe]069RHP1WIfL0J6QX06EUI@1RHV80
GUiN06IVIP0206EUI@0O06i^KP1PH600J6QX06QXJ01VIVH0JVYZ05aLG01RHV80JVYZ06ATI01RHV80
I6AT06IVIP1NGUh0H61P06e]K@1UIFD0H61P06QXJ01QHF40GUiN06MWI`1UIFD0GemO06=SH`1TI6@0
HF5Q06=SH`1XJ6P0GEeM05]KF`03069RHP0E05eMG@1SHf<0G5aL05mOG`1NGUh0Hf=S05aLG01IFET0
G5aL05]KF`1PH600GemO05aLG01FEUH0GUiN05ADE01MGEd0H61P05aLG01SHf<0FEUI0080F5QH00/0
FUYJ05QHF01MGEd0GUiN05YJFP1LG5`0E5AD05UIF@1GEeL0FUYJ05IFEP0205UIF@0B05]KF`1IFET0
H61P05QHF01QHF40GemO05iNGP1PH600FUYJ061PH01SHf<0GemO061PH01WIfL0J6QX06UYJ@1SHf<0
J6QX0P1UIFD0201SHf<0H61P06a/K01QHF40I6AT05aLG01JFUX0Fe]K0P1LG5`00`1KFe/0EUIF055A
D@02055AD@0305ADE01?Cdl0EUIF01L000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0
fMWI00<0fMWI00T0d];B05eMG@1RHV80H61P05mOG`1SHf<0IFEU065QH@1VIVH00P1NGUh02@1MGEd0
HV9R05aLG01SHf<0IVIV069RHP1NGUh0G5aL061PH00205iNGP0G06IVIP1NGUh0HF5Q05]KF`1NGUh0
IFEU06=SH`1QHF40IfMW05iNGP1LG5`0Hf=S05mOG`1KFe/0HF5Q05aLG01QHF40HV9R05mOG`1QHF40
Hf=S065QH@1YJFT00P1PH6007P1TI6@0GUiN069RHP1PH600GEeM06=SH`1RHV80IFEU065QH@1SHf<0
IfMW05MGE`1QHF40JFUY06=SH`1LG5`0JFUY05iNGP1XJ6P0HV9R06QXJ01WIfL0I6AT061PH01VIVH0
Hf=S061PH01RHV80IVIV06=SH`80Cdm?00`0BDU904I6AP1CDe<0F5QH05]KF`1PH600Fe]K05ADE01F
EUH0EEEE05MGE`1FEUH2065QH@0D06UYJ@1VIVH0LG5a06e]K@1/K6`0JFUY06a/K01YJFT0Jf][075a
L@1[Jf/0JFUY079bLP1cLg<0KVi^06][J`1aLG40K6a/06QXJ01[Jf/206MWI`0=071`L01^KVh0IVIV
065QH@1/K6`0J6QX075aL@1^KVh0Jf][06m_K`1WIfL0JFUY06ATI00206MWI`0506][J`1]KFd0KVi^
06a/K01^KVh00P1XJ6P00`1ZJVX0HF5Q071`L00206a/K008069RHP1]KFd0IFEU06QXJ01YJFT0JVYZ
06a/K01YJFT306][J`0:06a/K01^KVh0J6QX06MWI`1YJFT0JVYZ06MWI`1YJFT0I6AT06MWI`80JFUY
00@0K6a/06ATI01SHf<0I6AT0P1VIVH0101XJ6P0H61P06][J`1SHf<206UYJ@0;06ATI01QHF40K6a/
06QXJ01QHF40Hf=S061PH01QHF40Hf=S06MWI`1QHF400P1RHV801P1TI6@0IVIV06MWI`1VIVH0I6AT
05aLG080Hf=S01h0J6QX05iNGP1XJ6P0HV9R05mOG`1RHV80Hf=S061PH01TI6@0HF5Q06UYJ@1RHV80
Hf=S061PH01SHf<0GEeM05iNGP1SHf<0GUiN05mOG`1NGUh0G5aL069RHP1SHf<0Fe]K05QHF01MGEd0
HF5Q05IFEP1LG5`2065QH@0:05aLG01MGEd0FEUI05]KF`1LG5`0Fe]K05aLG01QHF40Fe]K05MGE`80
G5aL00T0EUIF05]KF`1MGEd0HV9R05=CD`1MGEd0FUYJ05=CD`1KFe/00P1IFET00`1LG5`0GemO061P
H00205]KF`0I05EEE@1LG5`0GEeM05QHF01PH600I6AT069RHP1IFET0HF5Q06QXJ01SHf<0IVIV06AT
I01YJFT0GUiN06IVIP1PH600I6AT061PH01OGel0I6AT05EEE@1JFUX0GUiN05]KF`0205UIF@0605iN
GP1IFET0FUYJ05ADE01FEUH0D51@5`0000060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3I
fMT00`3IfMT04`39bLT0Hf=S05QHF01KFe/0GUiN06ATI01PH600GemO061PH01SHf<0FEUI05eMG@1Q
HF40I6AT061PH01XJ6P0HF5Q05]KF`1QHF400P1LG5`01P1IFET0G5aL061PH01OGel0GUiN065QH@80
GEeM02/0HF5Q05]KF`1SHf<0GemO05eMG@1TI6@0HF5Q05eMG@1PH600EeMG069RHP1TI6@0Hf=S06AT
I01HF5P0Hf=S05aLG01NGUh0G5aL065QH@1RHV80GEeM05]KF`1OGel0H61P05UIF@1QHF40I6AT061P
H01LG5`0IFEU061PH01UIFD0Jf][06ATI01PH600J6QX061PH01RHV80Hf=S06e]K@1UIFD0IVIV0080
I6AT00@0HF5Q061PH01NGUh0FEUI0P1>CTh02`17AdL0D51@05UIF@1CDe<0E5AD05eMG@1=CDd0E5AD
04i>CP1CDe<0H61P0080GUiN00P0J6QX06i^KP1TI6@0Jf][06a/K01YJFT0J6QX06IVIP80KVi^00T0
Jf][06a/K01[Jf/0KVi^071`L01TI6@0KVi^06][J`1XJ6P00P1[Jf/206UYJ@0=071`L01[Jf/0Jf][
06EUI@1ZJVX0Lg=c06][J`1YJFT0KVi^06YZJP1VIVH0GemO069RHP0206UYJ@0G06YZJP1]KFd0JFUY
06e]K@1dM7@0KVi^06ATI01YJFT0K6a/06UYJ@1[Jf/0IfMW06=SH`1VIVH0J6QX06][J`1XJ6P0IVIV
06QXJ01`L700J6QX06ATI01[Jf/00P1YJFT0;P1_Kfl0Jf][06=SH`1WIfL0JVYZ06ATI01ZJVX0J6QX
065QH@1SHf<0IfMW061PH01TI6@0IVIV071`L01TI6@0J6QX071`L01YJFT0J6QX069RHP1TI6@0HF5Q
06IVIP1SHf<0IVIV06EUI@1OGel0IVIV06=SH`1LG5`0IVIV06QXJ01VIVH0GEeM061PH01SHf<0H61P
05YJFP1QHF40Hf=S06ATI01IFET0Fe]K061PH01RHV8206=SH`0M05eMG@1LG5`0Hf=S06=SH`1QHF40
J6QX065QH@1PH600HF5Q06MWI`1NGUh0HF5Q06EUI@1NGUh0Hf=S065QH@1RHV80FEUI05aLG01KFe/0
G5aL05YJFP1SHf<0G5aL05eMG@1LG5`0FEUI05]KF`1TI6@00P1LG5`01P1KFe/0G5aL065QH@1HF5P0
HF5Q05aLG080Fe]K00L0GEeM05]KF`1JFUX0FEUI05IFEP1JFUX0Fe]K00@0H61P00P0Fe]K05iNGP1N
GUh0F5QH055AD@1PH600FEUI05mOG`80H61P00X0HF5Q05aLG01LG5`0HF5Q06=SH`1/K6`0GEeM061P
H01SHf<0J6QX0P1PH600201NGUh0Hf=S06EUI@1NGUh0G5aL065QH@1LG5`0FUYJ0`1IFET0101GEeL0
DE5A05MGE`1?CdlG000000H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0H
0<o?c`1PH600GEeM06ATI01LG5`0IVIV05]KF`1TI6@0Fe]K06=SH`1PH600Hf=S06UYJ@1SHf<0K6a/
061PH01QHF40H61P05eMG@1QHF40FUYJ06=SH`1TI6@0IVIV0P1QHF403@1NGUh0I6AT05]KF`1KFe/0
GUiN05]KF`1IFET0Hf=S069RHP1PH600GUiN061PH01YJFT00P1TI6@02@1QHF40GUiN061PH01PH600
GemO05UIF@1QHF40H61P069RHP0205aLG080Hf=S01<0IfMW05aLG01SHf<0EUIF06IVIP1NGUh0HF5Q
069RHP1NGUh0IFEU069RHP1UIFD0Hf=S069RHP1XJ6P0GEeM06a/K01PH600HF5Q0080Hf=S00<0IVIV
06EUI@1BDU800P1>CTh0101BDU80BDU9059BDP1ADE4205ADE00D04m?C`1@D500Cdm?05MGE`1QHF40
I6AT065QH@1SHf<0I6AT06YZJP1XJ6P0HF5Q06UYJ@1/K6`0IVIV069RHP1VIVH0JVYZ06i^KP1SHf<2
06MWI`0B06ATI01ZJVX0HV9R06][J`1ZJVX0I6AT06e]K@1QHF40J6QX06IVIP1XJ6P0JVYZ06UYJ@1/
K6`0JFUY06a/K01`L700K6a/0P1^KVh02@1]KFd0JVYZ06m_K`1XJ6P0Kfm_06YZJP1WIfL0I6AT06a/
K00206YZJP0l06IVIP1WIfL0Jf][06][J`1TI6@0Jf][06MWI`1VIVH0I6AT07=cL`1XJ6P0JFUY06QX
J01WIfL0L71`05mOG`1RHV80LG5a06EUI@1QHF40KFe]06=SH`1WIfL0IFEU06a/K01SHf<0JVYZ06QX
J01[Jf/0Hf=S071`L01YJFT0Jf][06YZJP1TI6@0GUiN06IVIP1XJ6P0HV9R06ATI01UIFD0HF5Q05iN
GP1QHF40IVIV06MWI`1TI6@0J6QX06ATI01QHF40J6QX05UIF@1XJ6P0H61P06ATI01NGUh0G5aL06=S
H`1TI6@0LG5a0P1RHV804P1QHF40I6AT05UIF@1LG5`0IFEU069RHP1SHf<0FUYJ06=SH`1[Jf/0HV9R
06QXJ01QHF40GemO06ATI01QHF40G5aL061PH080HF5Q00/0I6AT061PH01FEUH0Fe]K06=SH`1JFUX0
Hf=S05QHF01PH600FUYJ05MGE`0205mOG`0P05iNGP1SHf<0HF5Q05YJFP1IFET0GUiN065QH@1IFET0
F5QH05]KF`1VIVH0F5QH05YJFP1QHF40F5QH05aLG01FEUH0FUYJ05UIF@1NGUh0EUIF05QHF01JFUX0
FEUI05aLG01NGUh0EEEE05QHF01PH600E5AD05]KF`1QHF42061PH00G06IVIP1LG5`0HF5Q05UIF@1T
I6@0Hf=S05aLG01MGEd0HF5Q05aLG01NGUh0F5QH05YJFP1FEUH0FUYJ05=CD`1DE5@0EeMG05mOG`1G
EeL0FEUI055AD@1CDe<05`0000060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3I
fMT0103;bl/0GUiN05aLG01TI6@205iNGP05061PH01QHF40EeMG05aLG01QHF400P1LG5`0101^KVh0
IFEU05eMG@1NGUh2061PH080HF5Q00H0H61P06=SH`1SHf<0Fe]K05iNGP1[Jf/205iNGP03069RHP1H
F5P0G5aL0080GEeM00T0IfMW06IVIP1OGel0I6AT05eMG@1NGUh0H61P069RHP1VIVH00P1PH600:@1N
GUh0G5aL061PH01QHF40GUiN06MWI`1XJ6P0Hf=S05iNGP1OGel0JFUY06=SH`1TI6@0H61P05YJFP1L
G5`0GUiN069RHP1QHF40GUiN069RHP1NGUh0H61P06MWI`1YJFT0HV9R065QH@1NGUh0J6QX061PH01U
IFD0IVIV05YJFP1ADE40EUIF05UIF@1ADE40DU9B05QHF01JFUX0DU9B00<0De=C00H0FUYJ05eMG@1O
Gel0J6QX06ATI01[Jf/206IVIP0406a/K01TI6@0I6AT06=SH`80Jf][00D0K6a/06i^KP1`L700K6a/
06IVIP0206ATI00706i^KP1XJ6P0J6QX06QXJ01/K6`0J6QX071`L00306][J`0V06QXJ01ZJVX0IVIV
06YZJP1WIfL0J6QX06UYJ@1cLg<0IFEU06MWI`1/K6`0JFUY06QXJ01TI6@0IFEU06IVIP1YJFT0J6QX
06a/K01WIfL0IVIV06YZJP1`L700J6QX06i^KP1[Jf/0K6a/06QXJ01YJFT0Jf][06IVIP1UIFD0Jf][
06YZJP1XJ6P0IVIV06QXJ01[Jf/206ATI007061PH01XJ6P0I6AT06ATI01MGEd0IVIV06a/K00206AT
I00706i^KP1YJFT0IVIV061PH01TI6@0JFUY06QXJ00206=SH`0405iNGP1VIVH0IVIV069RHP<0I6AT
01l0IFEU065QH@1MGEd0IVIV05aLG01QHF40GemO06IVIP1UIFD0HF5Q06MWI`1OGel0IfMW079bLP1P
H600FUYJ05QHF01UIFD0Hf=S061PH01WIfL0G5aL061PH01TI6@0K6a/06UYJ@1WIfL0IFEU05aLG01K
Fe/0GUiN0080HV9R00L0GUiN065QH@1NGUh0HF5Q05iNGP1PH600GEeM0080FUYJ02X0F5QH05]KF`1H
F5P0G5aL05]KF`1MGEd0GUiN05MGE`1KFe/0H61P05aLG01FEUH0GEeM05]KF`1HF5P0Fe]K061PH01I
FET0Fe]K05QHF01IFET0GUiN05mOG`1MGEd0G5aL061PH01FEUH0H61P06ATI01LG5`0H61P05QHF01E
EED0GUiN061PH01SHf<0GUiN061PH01IFET0G5aL05EEE@1IFET2065QH@0805iNGP1QHF40I6AT05]K
F`1UIFD0Fe]K05eMG@1KFe/205aLG080GEeM00P0EEEE05IFEP1GEeL0EeMG05IFEP1HF5P0E5AD05=C
DaL000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI01T0c/k>065QH@1Q
HF40HV9R05mOG`1UIFD0HV9R05aLG01MGEd0Fe]K06EUI@1NGUh0GemO06IVIP1YJFT0H61P05eMG@1L
G5`0FUYJ05mOG`1QHF40FEUI061PH01TI6@0IFEU0080H61P00h0Fe]K05MGE`1QHF40Fe]K061PH01R
HV80EUIF06MWI`1VIVH0GEeM05iNGP1SHf<0IfMW061PH080GemO00P0Hf=S061PH01VIVH0IfMW05aL
G01PH600IFEU065QH@80H61P00`0Hf=S05]KF`1TI6@0GUiN06=SH`1KFe/0Hf=S065QH@1LG5`0HF5Q
06IVIP1RHV8206IVIP0=06][J`1IFET0IfMW06=SH`1RHV80G5aL05eMG@1VIVH0H61P06IVIP1MGEd0
EEEE05aLG00205ADE00405QHF01GEeL0F5QH05QHF080FEUI01H0EeMG05aLG01YJFT0IFEU06=SH`1V
IVH0I6AT06IVIP1SHf<0JVYZ06QXJ01TI6@0IVIV06QXJ01_Kfl0IVIV06UYJ@1XJ6P0KVi^06UYJ@1[
Jf/0IVIV0P1TI6@0101[Jf/0IfMW06e]K@1YJFT206m_K`0g06a/K01[Jf/0IVIV06ATI01WIfL0Jf][
06QXJ01RHV80J6QX06IVIP1[Jf/0KFe]06EUI@1XJ6P0KVi^06MWI`1RHV80Jf][06QXJ01VIVH0JVYZ
06i^KP1VIVH0I6AT06UYJ@1WIfL0Hf=S06EUI@1XJ6P0JFUY06QXJ01YJFT0Hf=S06MWI`1/K6`0IVIV
06UYJ@1QHF40IVIV06ATI01PH600J6QX06UYJ@1UIFD0Hf=S06MWI`1SHf<0KFe]06QXJ01[Jf/0I6AT
069RHP1VIVH0HF5Q06ATI00206EUI@0<061PH01MGEd0KVi^065QH@1TI6@0GUiN065QH@1NGUh0HF5Q
06=SH`1WIfL0HV9R101QHF409P1TI6@0GemO06IVIP1VIVH0GUiN06ATI01NGUh0G5aL06=SH`1MGEd0
HV9R05]KF`1UIFD0HF5Q06=SH`1PH600HV9R05iNGP1SHf<0JVYZ06e]K@1VIVH0FUYJ05aLG01QHF40
GUiN05UIF@1NGUh0HF5Q05YJFP1OGel0FUYJ05QHF01PH600GemO05eMG@1IFET0GUiN0P1KFe/01P1N
GUh0Fe]K05iNGP1NGUh0GemO061PH080Fe]K03@0GUiN05aLG01EEED0H61P05IFEP1NGUh0GemO05UI
F@1HF5P0DU9B05EEE@1FEUH0GemO05YJFP1KFe/0FEUI05MGE`1IFET0EUIF05iNGP1LG5`0EUIF05iN
GP1PH600FUYJ05UIF@1NGUh0F5QH05]KF`1FEUH0GUiN05mOG`1RHV80HF5Q069RHP1QHF40Hf=S05eM
G@1KFe/0H61P05]KF`1FEUH0De=C05IFEP1GEeL0E5AD05]KF`1ADE40EUIF055AD@1LG5`0F5QH5`00
00060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT00`3@d=00H61P05iNGP02
06ATI00]06UYJ@1OGel0IVIV061PH01SHf<0IVIV061PH01OGel0H61P06ATI01MGEd0FEUI06=SH`1J
FUX0Fe]K06=SH`1TI6@0HF5Q05YJFP1PH600HF5Q05aLG01IFET0I6AT061PH01RHV80FEUI06MWI`1Q
HF40H61P065QH@1SHf<0GUiN06IVIP1PH600HV9R06=SH`1MGEd0I6AT05iNGP1MGEd0I6AT05aLG01N
GUh0K6a/00<0GUiN0`1QHF42069RHP0:05]KF`1SHf<0H61P05iNGP1QHF40H61P06IVIP1QHF40IFEU
06][J`80HF5Q01L0Hf=S06IVIP1XJ6P0Jf][06EUI@1XJ6P0JFUY069RHP1NGUh0GEeM05aLG01MGEd0
Fe]K05ADE01LG5`0GemO06ATI01LG5`0Fe]K065QH@1YJFT0IFEU06a/K002069RHP0;06EUI@1VIVH0
Hf=S06QXJ01[Jf/0IVIV071`L01YJFT0Hf=S06MWI`1YJFT00P1^KVh01`1XJ6P0JVYZ06IVIP1aLG40
KVi^06YZJP1[Jf/00P1YJFT206QXJ00406UYJ@1ZJVX0JFUY06UYJ@80IVIV0100J6QX06IVIP1QHF40
KFe]06IVIP1^KVh0Jf][06QXJ01/K6`0I6AT06UYJ@1VIVH0I6AT06][J`1^KVh0JVYZ0P1WIfL08`1^
KVh0Jf][06IVIP1VIVH0K6a/06ATI01YJFT0HF5Q06UYJ@1XJ6P0HF5Q06][J`1_Kfl0IFEU065QH@1S
Hf<0J6QX06MWI`1[Jf/0IFEU06UYJ@1TI6@0Hf=S065QH@1`L700K6a/06ATI01[Jf/0HV9R06ATI01P
H600JVYZ06EUI@1TI6@0IFEU0080I6AT0P1OGel04`1TI6@0IfMW065QH@1PH600IVIV065QH@1XJ6P0
IFEU06MWI`1SHf<0GEeM06EUI@1PH600G5aL06=SH`1TI6@0H61P065QH@1NGUh00P1PH600101VIVH0
GUiN05eMG@1MGEd206=SH`0?05mOG`1UIFD0HF5Q069RHP1MGEd0I6AT05YJFP1SHf<0G5aL05mOG`1M
GEd0GUiN061PH01TI6@0GEeM0080GUiN00l0EEEE065QH@1JFUX0Fe]K05aLG01KFe/0G5aL061PH01L
G5`0GEeM05UIF@1NGUh0H61P05MGE`1JFUX00P1IFET205]KF`0405aLG01NGUh0GemO05]KF`80FEUI
00@0E5AD05UIF@1MGEd0FUYJ0P1MGEd02@1NGUh0FEUI05]KF`1KFe/0De=C05ADE01MGEd0FEUI05mO
G`0205]KF`0705aLG01JFUX0FUYJ05iNGP1PH600G5aL05iNGP0205UIF@0505IFEP1JFUX0FEUI05=C
D`1KFe/00P1IFET01`1MGEd0Fe]K05ADE01EEED0EeMG05IFEP1CDe<05`0000060=WIf@4000000@3I
fMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0203De=@0GUiN06EUI@1TI6@0Hf=S06MWI`1RHV80
GEeM0P1LG5`2065QH@0306UYJ@1PH600GUiN0080HV9R00H0GUiN05YJFP1PH600HF5Q05]KF`1QHF42
061PH005065QH@1LG5`0FUYJ069RHP1LG5`00P1QHF402`1LG5`0I6AT061PH01PH600J6QX05IFEP1Y
JFT0I6AT065QH@1YJFT0EeMG0080HF5Q00P0G5aL06ATI01NGUh0GUiN05aLG01OGel0IFEU065QH@80
GUiN00D0Hf=S06ATI01PH600GUiN061PH00206ATI00E06UYJ@1RHV80JFUY05mOG`1XJ6P0Hf=S065Q
H@1PH600I6AT065QH@1XJ6P0I6AT06QXJ01WIfL0I6AT061PH01QHF40Hf=S061PH01KFe/0HF5Q0080
Hf=S0P1PH6001P1KFe/0GUiN06QXJ01QHF40Hf=S06e]K@80Hf=S00@0J6QX06UYJ@1YJFT0Jf][0P1T
I6@03P1`L700H61P06MWI`1YJFT0IfMW06e]K@1VIVH0IFEU061PH01aLG40KFe]06ATI01QHF40Jf][
0`1VIVH02@1UIFD0JVYZ06UYJ@1VIVH0H61P06QXJ01/K6`0Jf][06YZJP0206i^KP0]06UYJ@1XJ6P0
J6QX06IVIP1RHV80KFe]06i^KP1[Jf/0JFUY07=cL`1/K6`0IFEU06QXJ01[Jf/0IFEU06i^KP1VIVH0
Hf=S06MWI`1UIFD0JFUY06IVIP1QHF40H61P06QXJ01]KFd0GemO06a/K01[Jf/0IVIV06YZJP1TI6@0
IFEU06ATI01/K6`0Hf=S06IVIP1YJFT0F5QH06EUI@1YJFT0KFe]06a/K01TI6@0IVIV0080Hf=S00/0
IVIV05mOG`1UIFD0GemO06IVIP1QHF40IFEU065QH@1RHV80Hf=S06ATI00206=SH`0605eMG@1QHF40
Hf=S06MWI`1UIFD0IfMW0P1TI6@05P1SHf<0HF5Q06IVIP1SHf<0IFEU05iNGP1PH600I6AT065QH@1I
FET0I6AT05iNGP1SHf<0GUiN065QH@1RHV80GUiN05]KF`1NGUh0FEUI05]KF`1LG5`205iNGP0=06=S
H`1LG5`0EUIF05eMG@1FEUH0F5QH05UIF@1KFe/0IVIV05EEE@1PH600JFUY05mOG`0205aLG00<05IF
EP1OGel0FEUI05iNGP1RHV80H61P05]KF`1MGEd0G5aL05YJFP1KFe/0H61P0P1LG5`03P1QHF40Fe]K
05]KF`1PH600GUiN05aLG01NGUh0EeMG065QH@1PH600E5AD05QHF01OGel0CDe=0P1KFe/0101NGUh0
HF5Q05eMG@1NGUh2061PH00C05EEE@1PH600EEEE05]KF`1PH600Hf=S05QHF01OGel0H61P05mOG`1R
HV80G5aL05UIF@1KFe/0FEUI05ADE01FEUH0Fe]K055AD@0G000000H0fMWI0@0000010=WIf@005P3I
fMT00`000000fMWI0=WIf@030=WIf@0R0<_;b`1QHF40G5aL06QXJ01QHF40IFEU069RHP1SHf<0GemO
06=SH`1PH600G5aL061PH01SHf<0H61P05mOG`1MGEd0HF5Q05iNGP1OGel0FEUI061PH01IFET0GUiN
05]KF`1SHf<0G5aL05eMG@1LG5`0GUiN05aLG01TI6@0GemO061PH080HF5Q00D0Hf=S05iNGP1NGUh0
GUiN06IVIP02061PH00=05UIF@1TI6@0J6QX06=SH`1TI6@0H61P05aLG01MGEd0HF5Q05iNGP1IFET0
GUiN069RHP0206QXJ00C065QH@1SHf<0G5aL061PH01WIfL0I6AT05eMG@1PH600IFEU061PH01TI6@0
IVIV06QXJ01VIVH0HV9R065QH@1VIVH0HF5Q06=SH`02065QH@80I6AT00h0Hf=S065QH@1PH600GEeM
06][J`1ZJVX0Hf=S05mOG`1VIVH0I6AT06=SH`1WIfL0HF5Q06IVIP80J6QX0P1WIfL04`1YJFT0KVi^
06UYJ@1ZJVX0Jf][06i^KP1VIVH0JFUY06][J`1VIVH0LW9b06a/K01]KFd0L71`06EUI@1[Jf/0Hf=S
071`L01/K6`00P1XJ6P02@1`L700IVIV06QXJ01YJFT0IFEU06MWI`1VIVH0Hf=S06YZJP0206UYJ@0i
06QXJ01WIfL0KVi^06MWI`1UIFD0I6AT06MWI`1UIFD0IfMW06a/K01XJ6P0Hf=S06][J`1]KFd0Kfm_
06=SH`1[Jf/0Hf=S06][J`1XJ6P0IFEU06][J`1UIFD0K6a/06=SH`1VIVH0J6QX06IVIP1YJFT0J6QX
06m_K`1YJFT0HF5Q06IVIP1[Jf/0IfMW06QXJ01SHf<0JFUY06IVIP1YJFT0G5aL06UYJ@1ZJVX0HV9R
06EUI@1QHF40Kfm_06QXJ01TI6@0HV9R06ATI01OGel0I6AT05iNGP1SHf<0HF5Q0080I6AT04d0IFEU
06ATI01SHf<0IVIV065QH@1NGUh0J6QX069RHP1NGUh0HF5Q061PH01TI6@0G5aL05eMG@1PH600HF5Q
06=SH`1NGUh0I6AT06=SH`1LG5`0IFEU05mOG`1LG5`0Fe]K05UIF@1DE5@0H61P05iNGP1HF5P0GUiN
05UIF@1JFUX0HV9R05YJFP1IFET0FUYJ05iNGP1JFUX0GemO061PH01IFET0Fe]K05MGE`1PH600GUiN
05IFEP1OGel0Hf=S05QHF01JFUX0FEUI05aLG01JFUX0FEUI05]KF`1PH600Fe]K05ADE01NGUh0FEUI
061PH01KFe/0H61P05aLG01GEeL0H61P05]KF`1NGUh0G5aL05QHF01JFUX0FEUI05mOG`1KFe/0IVIV
05=CD`0305aLG00405QHF01MGEd0Fe]K05=CD`80GUiN00l0FUYJ05iNGP1EEED0G5aL05UIF@1NGUh0
FUYJ05ADE01IFET0EUIF05aLG01QHF40EUIF05ADE01CDe<05`0000060=WIf@4000000@3IfMT001H0
fMWI00<000000=WIf@3IfMT00`3IfMT03P3?cll0GUiN065QH@1QHF40Hf=S06EUI@1OGel0I6AT06QX
J01UIFD0GUiN05]KF`1SHf<0H61P0P1QHF400`1VIVH0Fe]K05]KF`0205iNGP0A05]KF`1QHF40GUiN
061PH01KFe/0H61P05]KF`1TI6@0GEeM06EUI@1OGel0H61P06ATI01LG5`0HV9R06IVIP1PH6000P1T
I6@01P1GEeL0H61P06MWI`1QHF40H61P06ATI080Hf=S00<0FEUI05mOG`1GEeL00P1QHF405@1LG5`0
FEUI05UIF@1QHF40FUYJ06=SH`1UIFD0Fe]K061PH01QHF40HV9R06QXJ01VIVH0IFEU06=SH`1VIVH0
Hf=S06ATI01SHf<0I6AT06YZJP0206QXJ00706ATI01PH600I6AT065QH@1SHf<0GUiN05eMG@02061P
H00305mOG`1YJFT0IVIV0080IfMW00L0IFEU06IVIP1TI6@0HV9R06=SH`1VIVH0Hf=S0080I6AT0180
J6QX065QH@1SHf<0GEeM065QH@1WIfL0JVYZ06UYJ@1WIfL0I6AT06IVIP1XJ6P0IfMW06][J`1VIVH0
I6AT06][J`1XJ6P206][J`0a06QXJ01TI6@0JFUY09JFUP1XJ6P0L71`06UYJ@1NGUh0Jf][06IVIP1/
K6`0IVIV06a/K01VIVH0I6AT06QXJ01VIVH0KVi^06QXJ01UIFD0HF5Q06IVIP1ZJVX0I6AT06=SH`1Y
JFT0Jf][06IVIP1UIFD0IVIV06UYJ@1PH600I6AT06MWI`1VIVH0Kfm_06QXJ01RHV80J6QX06MWI`1S
Hf<0JFUY06IVIP1SHf<0IFEU06ATI01YJFT0Hf=S065QH@0206QXJ00806ATI01RHV80IVIV06IVIP1T
I6@0GemO061PH01XJ6P2061PH006065QH@1PH600Hf=S065QH@1TI6@0G5aL0P1XJ6P09@1TI6@0H61P
069RHP1SHf<0GemO061PH01UIFD0HV9R06ATI01QHF40GUiN065QH@1PH600IfMW065QH@1TI6@0IVIV
06EUI@1NGUh0Hf=S065QH@1PH600FEUI061PH01LG5`0GUiN06ATI01PH600EUIF05eMG@1PH600G5aL
05mOG`1CDe<0EUIF05]KF`1PH6000P1KFe/02@1HF5P0H61P061PH01CDe<0F5QH05UIF@1SHf<0G5aL
06=SH`0205aLG00305QHF01IFET0GemO0080G5aL02D0EeMG061PH01JFUX0G5aL05UIF@1LG5`0GUiN
05mOG`1IFET0E5AD05QHF01MGEd0EeMG05eMG@1LG5`0FEUI05IFEP1JFUX0DE5A059BDP1FEUH0Fe]K
065QH@1HF5P0FEUI05eMG@1HF5P0Fe]K05ADE01NGUh0FUYJ05mOG`1KFe/0H61P05eMG@1HF5P0FUYJ
0080EeMG00T0F5QH069RHP1EEED0FEUI05YJFP1IFET0G5aL055AD@1KFe/05`0000060=WIf@400000
0@3IfMT001H0fMWI0P0000040=WIf@0G0=OGe`1LG5`0HV9R06a/K01RHV80IfMW05eMG@1LG5`0HF5Q
05aLG01QHF40I6AT05UIF@1NGUh0HF5Q06IVIP1NGUh0HV9R05iNGP1QHF40EUIF05UIF@1LG5`00P1P
H6001@1IFET0Hf=S05iNGP1UIFD0Fe]K0080H61P0140HF5Q061PH01NGUh0HF5Q05aLG01RHV80H61P
05iNGP1IFET0I6AT05MGE`1NGUh0Fe]K05iNGP1FEUH0Fe]K06QXJ00206ATI00406][J`1FEUH0J6QX
069RHP80H61P00H0G5aL05EEE@1NGUh0I6AT05eMG@1SHf<3065QH@0A05UIF@1SHf<0Hf=S05iNGP1X
J6P0FUYJ06IVIP1TI6@0HV9R061PH01UIFD0HF5Q06IVIP1PH600GUiN065QH@1PH6000P1UIFD0801T
I6@0IVIV06IVIP1MGEd0H61P06UYJ@1RHV80GUiN06=SH`1XJ6P0HF5Q06ATI01VIVH0IFEU071`L01[
Jf/0IFEU06QXJ01RHV80K6a/06EUI@1ZJVX0J6QX06EUI@1/K6`0JFUY06QXJ01TI6@0Hf=S069RHP1P
H600IVIV0P1[Jf/04`1VIVH0IfMW06][J`1TI6@0Hf=S06ATI01[Jf/0K6a/06EUI@1WIfL0JFUY065Q
H@1_Kfl0JFUY06e]K@1QHF40HV9R05aLG01YJFT00P1XJ6P0601VIVH0JVYZ06][J`1XJ6P0IfMW06QX
J01PH600IVIV06ATI01XJ6P0IVIV06EUI@1]KFd0JFUY06=SH`1XJ6P0H61P06a/K01QHF40Hf=S061P
H01YJFT0IVIV065QH@80IVIV02P0Hf=S06MWI`1TI6@0IFEU061PH01XJ6P0IVIV06EUI@1[Jf/0HV9R
05iNGP1QHF40H61P06ATI01PH600JFUY065QH@1YJFT0HF5Q05iNGP1VIVH0I6AT065QH@1SHf<0HV9R
06IVIP1SHf<0I6AT06IVIP1LG5`0J6QX05UIF@1SHf<0GUiN05UIF@1SHf<0Fe]K05aLG01QHF40GUiN
0P1SHf<07P1LG5`0I6AT05UIF@1JFUX0GEeM05]KF`1NGUh0Fe]K05mOG`1SHf<0GEeM05UIF@1JFUX0
Fe]K05eMG@1DE5@0H61P05]KF`1NGUh0GemO05UIF@1PH600GUiN05YJFP1EEED0G5aL06ATI01KFe/0
G5aL05QHF080G5aL00<0F5QH05aLG01KFe/00P1IFET0301KFe/0F5QH069RHP1BDU80F5QH05aLG01H
F5P0FEUI05aLG01NGUh0Fe]K05QHF080FUYJ0P1LG5`06`1NGUh0EUIF051@D01GEeL0DE5A05MGE`1H
F5P0G5aL05IFEP1IFET0E5AD05iNGP1OGel0HV9R061PH01KFe/0H61P05aLG01TI6@0G5aL05MGE`1M
GEd0EUIF05aLG01HF5P0FUYJ05]KF`0205MGE`0305EEE@000000000001D000001@3IfMT200000040
fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00h0a/K606IVIP1SHf<0H61P065QH@1MGEd0FEUI
05]KF`1bLW80GUiN05aLG01VIVH0HF5Q061PH080Hf=S01@0HF5Q05mOG`1SHf<0I6AT05eMG@1IFET0
H61P05iNGP1IFET0Hf=S065QH@1JFUX0I6AT065QH@1PH600GUiN05mOG`1PH600IVIV05mOG`80HV9R
00P0G5aL065QH@1WIfL0GEeM05iNGP1OGel0GEeM06=SH`80HF5Q00P0GUiN05mOG`1SHf<0Hf=S05iN
GP1JFUX0GEeM069RHP80H61P03L0Hf=S05IFEP1QHF40IFEU061PH01LG5`0HF5Q06IVIP1NGUh0F5QH
061PH01XJ6P0G5aL06IVIP1SHf<0I6AT05mOG`1SHf<0GUiN06QXJ01PH600HV9R06=SH`1PH600HF5Q
06i^KP1UIFD0JFUY06YZJP1VIVH0GEeM06EUI@1TI6@0IfMW06YZJP1PH600KFe]06QXJ01TI6@0JFUY
069RHP1VIVH0KFe]069RHP1YJFT0K6a/06=SH`1aLG40JFUY06IVIP1TI6@0IfMW06YZJP1RHV80Jf][
0080Hf=S00@0J6QX06YZJP1]KFd0Kfm_0P1XJ6P00`1_Kfl0KVi^06e]K@0206][J`0506UYJ@1VIVH0
JFUY065QH@1YJFT00P1XJ6P02`1]KFd0H61P06=SH`1SHf<0I6AT06=SH`1VIVH0K6a/06UYJ@1VIVH0
IfMW0080I6AT00l0JFUY069RHP1RHV80JFUY05aLG01[Jf/0HF5Q06a/K01TI6@0Kfm_069RHP1QHF40
JFUY06EUI@1XJ6P00P1TI6@206=SH`0A06][J`1TI6@0HF5Q065QH@1PH600IVIV069RHP1TI6@0H61P
071`L01VIVH0HF5Q06IVIP1XJ6P0IfMW06QXJ01RHV800P1PH6001P1HF5P0GEeM06=SH`1SHf<0I6AT
061PH080HF5Q04L0G5aL065QH@1TI6@0HF5Q06EUI@1RHV80G5aL06IVIP1QHF40IVIV06ATI01MGEd0
JFUY06ATI01NGUh0F5QH06ATI01QHF40GUiN05eMG@1DE5@0H61P05eMG@1KFe/0HF5Q06=SH`1JFUX0
G5aL05iNGP1FEUH0Fe]K061PH01KFe/0FUYJ05aLG01OGel0GEeM05aLG01PH600Fe]K05MGE`1IFET0
F5QH05aLG01OGel0G5aL05UIF@1FEUH0GUiN05QHF01KFe/0Hf=S05]KF`1HF5P0G5aL05]KF`1NGUh0
I6AT05aLG01OGel0H61P05eMG@1KFe/0EUIF05]KF`1IFET0HF5Q05YJFP1IFET0E5AD05MGE`0205YJ
FP0=05QHF01KFe/0H61P05UIF@1KFe/0GemO05iNGP1IFET0GUiN05aLG01JFUX0DU9B05]KF`0205aL
G00405IFEP1IFET0FUYJ05YJFP80De=C00D0F5QH065QH@1DE5@0EEEE059BDP0G000000H0fMWI0@00
00010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0;0<g=c@1KFe/0HF5Q05]KF`1LG5`0GEeM
05mOG`1TI6@0G5aL065QH@1RHV800P1PH6004`1QHF40GUiN065QH@1TI6@0IFEU05]KF`1PH600GEeM
06=SH`1OGel0GUiN05QHF01JFUX0Hf=S05]KF`1TI6@0GUiN06IVIP1NGUh00P1WIfL01`1LG5`0IVIV
05aLG01XJ6P0Hf=S05eMG@1KFe/00`1PH600201QHF40EeMG06=SH`1XJ6P0GemO05eMG@1SHf<0G5aL
0P1SHf<0401NGUh0Hf=S06=SH`1MGEd0H61P05iNGP1SHf<0HV9R05iNGP1TI6@0Hf=S05iNGP1LG5`0
HF5Q05iNGP1LG5`3065QH@0>06MWI`1NGUh0I6AT05UIF@1PH600I6AT061PH01OGel0IfMW06UYJ@1T
I6@0J6QX06=SH`1PH60206IVIP0>061PH01ZJVX0H61P06][J`1XJ6P0HV9R06=SH`1ZJVX0HV9R06a/
K01UIFD0GUiN061PH01SHf<206UYJ@0906][J`1SHf<0Jf][06MWI`1VIVH0JFUY06MWI`1ZJVX0J6QX
0080K6a/01<0I6AT06UYJ@1aLG40JFUY06IVIP1XJ6P0K6a/06][J`1cLg<0LG5a06UYJ@1TI6@0GUiN
06ATI01XJ6P0I6AT06a/K01RHV80IFEU0080IVIV00/0IFEU06ATI01TI6@0G5aL06QXJ01RHV80JVYZ
06IVIP1XJ6P0K6a/06YZJP0206ATI00F061PH01SHf<0IVIV06=SH`1TI6@0H61P06EUI@1YJFT0Hf=S
06MWI`1YJFT0GemO069RHP1UIFD0IVIV06a/K01ZJVX0H61P06e]K@1WIfL0I6AT06QXJ080Hf=S00<0
IFEU06a/K01PH6000`1SHf<01`1TI6@0IfMW05iNGP1QHF40J6QX061PH01NGUh00P1TI6@01P1SHf<0
H61P065QH@1PH600Hf=S065QH@80H61P01H0FEUI05iNGP1VIVH0IVIV069RHP1MGEd0GUiN065QH@1[
Jf/0Fe]K05MGE`1OGel0HV9R06YZJP1JFUX0Fe]K05aLG01FEUH0GUiN05]KF`1SHf<0H61P0P1IFET0
3@1BDU80G5aL05]KF`1HF5P0Fe]K05mOG`1IFET0FUYJ05eMG@1OGel0EUIF05QHF01LG5`00`1NGUh0
2`1MGEd0FEUI05aLG01QHF40EUIF065QH@1IFET0G5aL05]KF`1MGEd0H61P0080GUiN00T0H61P05]K
F`1LG5`0GemO06=SH`1RHV80FUYJ05UIF@1KFe/00P1IFET04@1PH600D51@05QHF01GEeL0EEEE05UI
F@1FEUH0GUiN05eMG@1EEED0E5AD05UIF@1CDe<0Fe]K05eMG@1FEUH0FEUI0080GUiN00<0G5aL05]K
F`1OGel00P1IFET01P1HF5P0FUYJ05QHF01HF5P0FEUI05YJFQL000001P3IfMT100000040fMWI000F
0=WIf@030000003IfMT0fMWI00<0fMWI00X0e=CD05aLG01KFe/0H61P06ATI01SHf<0Fe]K05iNGP1L
G5`0EeMG0P1PH600:01VIVH0H61P05mOG`1PH600IfMW069RHP1QHF40H61P05YJFP1PH600I6AT05iN
GP1TI6@0HV9R065QH@1UIFD0H61P06=SH`1PH600IFEU06ATI01OGel0Hf=S06EUI@1SHf<0H61P05QH
F01SHf<0GemO061PH01VIVH0HF5Q05iNGP1ZJVX0F5QH06=SH`1UIFD0HV9R06ATI01MGEd206=SH`04
05eMG@1LG5`0G5aL05aLG080Fe]K00X0HF5Q06ATI01SHf<0H61P05iNGP1LG5`0JFUY05aLG01QHF40
I6AT0P1LG5`01P1YJFT0GemO06=SH`1XJ6P0HF5Q06EUI@<0HF5Q01@0IFEU05eMG@1QHF40J6QX061P
H01VIVH0H61P06=SH`1MGEd0IVIV06QXJ01[Jf/0H61P06e]K@1TI6@0HF5Q06IVIP1XJ6P0K6a/06EU
I@80J6QX01L0HF5Q06ATI01VIVH0IFEU06ATI01[Jf/0JFUY06QXJ01_Kfl0I6AT06e]K@1YJFT0IFEU
06][J`1/K6`0IVIV06YZJP1YJFT0KFe]06UYJ@1[Jf/0HV9R06MWI`0206UYJ@0606EUI@1/K6`0IfMW
06=SH`1YJFT0JVYZ0P1XJ6P03`1TI6@0GUiN06UYJ@1QHF40KFe]06QXJ01^KVh0IFEU069RHP1TI6@0
HV9R065QH@1VIVH0IfMW06=SH`0206ATI00806UYJ@1TI6@0I6AT069RHP1YJFT0J6QX06ATI01NGUh2
06=SH`0506IVIP1SHf<0J6QX065QH@1TI6@00P1XJ6P02`1[Jf/0I6AT06MWI`1PH600R8R805iNGP1K
Fe/0GEeM06ATI01QHF40GemO0080I6AT0380FEUI061PH01KFe/0H61P065QH@1SHf<0IVIV06UYJ@1T
I6@0Hf=S061PH01RHV80IVIV06=SH`1QHF40H61P06ATI01HF5P0Hf=S06ATI01IFET0GUiN061PH01G
EeL0GEeM05aLG01TI6@0H61P05iNGP1JFUX0FEUI06=SH`1JFUX0H61P05iNGP1KFe/0F5QH05iNGP1H
F5P0GEeM05UIF@1LG5`0EUIF061PH01LG5`0GemO069RHP1EEED0GUiN05QHF080H61P00P0FEUI05mO
G`1HF5P0FEUI05aLG01CDe<0G5aL05YJFP80F5QH00/0Fe]K05=CD`1KFe/0De=C05UIF@1HF5P0GEeM
05iNGP1GEeL0F5QH05iNGP0205QHF00<05MGE`1ADE40GEeM05UIF@1JFUX0G5aL059BDP1GEeL0G5aL
05UIF@1FEUH0F5QH0P1JFUX0101HF5P0E5AD05YJFP1LG5`2061PH00=05eMG@1IFET0EUIF05QHF01L
G5`0F5QH05]KF`1LG5`0De=C05aLG01EEED0Fe]K05UIF@0G000000H0fMWI0@0000010=WIf@005P3I
fMT00`000000fMWI0=WIf@030=WIf@0=0<[:bP1NGUh0GemO05aLG01QHF40J6QX06=SH`1LG5`0GemO
06=SH`1QHF40H61P06=SH`03065QH@0=05mOG`1QHF40H61P05iNGP1KFe/0GUiN06ATI01QHF40HV9R
06=SH`1PH600GEeM061PH00205iNGP0:06YZJP1IFET0H61P06UYJ@1TI6@0IVIV061PH01XJ6P0K6a/
06ATI080H61P00<0I6AT06=SH`1RHV800P1QHF40801UIFD0GemO05iNGP1VIVH0HF5Q05mOG`1MGEd0
HF5Q061PH01VIVH0GUiN06=SH`1PH600GUiN05eMG@1LG5`0I6AT05YJFP1PH600GEeM05]KF`1MGEd0
GUiN06ATI01SHf<0IVIV06QXJ01PH600IFEU06=SH`1UIFD0GUiN0`1SHf<0101VIVH0I6AT06i^KP1T
I6@206IVIP80I6AT00<0Jf][06IVIP1VIVH00P1SHf<00`1VIVH0JFUY06EUI@0206ATI00a06a/K01U
IFD0IFEU06QXJ01TI6@0KVi^06ATI01YJFT0HV9R06UYJ@1VIVH0Kfm_06MWI`1UIFD0Hf=S06MWI`1Z
JVX0JFUY06=SH`1VIVH0J6QX06ATI01YJFT0K6a/06UYJ@1VIVH0JVYZ06EUI@1[Jf/0IVIV061PH01W
IfL0KFe]06IVIP1WIfL0Hf=S06a/K01ZJVX0KFe]065QH@1SHf<0I6AT06QXJ01WIfL0KVi^06a/K01U
IFD0I6AT06UYJ@0306ATI00G065QH@1YJFT0I6AT069RHP1XJ6P0Hf=S05iNGP1VIVH0IFEU06IVIP1N
GUh0Hf=S06IVIP1QHF40IFEU06UYJ@1VIVH0I6AT06UYJ@1UIFD0I6AT06=SH`1PH6000P1VIVH02`1X
J6P0I6AT06ATI01UIFD0GEeM069RHP1QHF40I6AT05mOG`1UIFD0HF5Q0080I6AT0P1SHf<09@1PH600
Hf=S05iNGP1SHf<0HF5Q05iNGP1PH600GUiN05aLG01PH600GUiN05IFEP1WIfL0GemO05iNGP1QHF40
IVIV05iNGP1QHF40FUYJ05aLG01PH600F5QH061PH01FEUH0GEeM05mOG`1NGUh0F5QH05iNGP1QHF40
DU9B06=SH`1QHF40EeMG06MWI`1OGel00P1LG5`00`1ADE40FEUI05aLG00205aLG00505QHF01FEUH0
FEUI05QHF01KFe/00P1DE5@05P1QHF40GEeM05aLG01JFUX0E5AD05YJFP1IFET0G5aL05IFEP1PH600
G5aL05QHF01GEeL0EEEE05eMG@1NGUh0EeMG05iNGP1IFET0G5aL05]KF`1DE5@205iNGP0A05QHF01F
EUH0G5aL05QHF01LG5`0Fe]K05ADE01IFET0H61P05mOG`1SHf<0Fe]K05UIF@1QHF40FEUI05iNGP1K
Fe/00`1HF5P00`1KFe/0G5aL05QHF00G000000H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI
0=WIf@030=WIf@070<c<c01SHf<0G5aL069RHP1NGUh0Hf=S065QH@0205]KF`0I06=SH`1MGEd0GEeM
06ATI01RHV80JFUY06QXJ01VIVH0G5aL06YZJP1NGUh0IFEU061PH01KFe/0H61P06IVIP1SHf<0FUYJ
069RHP1OGel0IVIV069RHP1OGel0Hf=S069RHP02065QH@0=06=SH`1QHF40Fe]K065QH@1/K6`0I6AT
05aLG01TI6@0FEUI06=SH`1XJ6P0HF5Q061PH002065QH@0905eMG@1KFe/0GemO06=SH`1FEUH0GemO
061PH01WIfL0G5aL0080HF5Q00<0HV9R065QH@1WIfL00P1UIFD06@1RHV80GEeM061PH01SHf<0H61P
065QH@1SHf<0HF5Q069RHP1PH600JFUY06ATI01PH600HF5Q06][J`1TI6@0Hf=S05iNGP1TI6@0GUiN
065QH@1YJFT0Hf=S06IVIP1TI6@00P1RHV805P1TI6@0IVIV06IVIP1XJ6P0JVYZ06UYJ@1TI6@0JFUY
06e]K@1VIVH0JVYZ06][J`1XJ6P0JFUY06][J`1/K6`0Jf][06=SH`1QHF40JVYZ06MWI`1VIVH206=S
H`0J06IVIP1/K6`0IVIV06a/K01XJ6P0IVIV06][J`1^KVh0IfMW06=SH`1ZJVX0JFUY06][J`1YJFT0
I6AT06IVIP1XJ6P0JFUY06MWI`1RHV80J6QX061PH01ZJVX0HV9R06EUI@1QHF4206QXJ00>06ATI01Q
HF40IVIV06ATI01WIfL0GemO06UYJ@1WIfL0JFUY06=SH`1KFe/0HV9R06UYJ@1XJ6P206EUI@0406AT
I01PH600IVIV061PH080HF5Q00P0J6QX06=SH`1]KFd0Hf=S06EUI@1RHV80I6AT065QH@80I6AT00D0
H61P06UYJ@1TI6@0IVIV05iNGP02065QH@0@05iNGP1RHV80IVIV05mOG`1HF5P0H61P065QH@1NGUh0
I6AT05UIF@1UIFD0Hf=S05YJFP1RHV80H61P05iNGP80Hf=S01H0HV9R05aLG01NGUh0FEUI061PH01L
G5`0HF5Q061PH01RHV80Fe]K05YJFP1LG5`0GEeM069RHP1LG5`0GUiN065QH@1SHf<0HV9R05UIF@1K
Fe/0HF5Q0P1KFe/01P1FEUH0FEUI05aLG01LG5`0EUIF05YJFP80G5aL00h0H61P069RHP1LG5`0Hf=S
05UIF@1RHV80EUIF05iNGP1KFe/0FEUI05IFEP1MGEd0De=C05iNGP80FUYJ01P0EeMG05QHF01NGUh0
Fe]K055AD@1HF5P0Fe]K05aLG01JFUX0GEeM05QHF01IFET0Fe]K05QHF01MGEd0FUYJ05IFEP1EEED0
FEUI05aLG01NGUh0FUYJ05]KF`1DE5@305UIF@0405=CD`1JFUX0GEeM05YJFP80Fe]K00<0FEUI05eM
G@1KFe/00P1HF5P00`1MGEd0GUiN0000000F000000H0fMWI0@0000010=WIf@005P3IfMT00`000000
fMWI0=WIf@030=WIf@040<_;b`1KFe/0I6AT05UIF@80IfMW00D0Fe]K06EUI@1LG5`0G5aL06EUI@02
061PH00305aLG01/K6`0I6AT0080H61P00`0IFEU065QH@1QHF40H61P06=SH`1NGUh0IFEU069RHP1K
Fe/0IVIV065QH@1VIVH206ATI00>06=SH`1PH600GemO061PH01KFe/0GUiN06IVIP1PH600G5aL06EU
I@1PH600HV9R06MWI`1PH602069RHP80GUiN01<0Fe]K05YJFP1LG5`0FEUI05eMG@1IFET0I6AT05]K
F`1QHF40F5QH06ATI01SHf<0GUiN05eMG@1WIfL0IVIV061PH01RHV80J6QX0080HF5Q00h0IFEU06QX
J01MGEd0IfMW06][J`1UIFD0IVIV065QH@1SHf<0GUiN06IVIP1NGUh0Hf=S061PH0<0IVIV01L0IFEU
06ATI01SHf<0HV9R06IVIP1SHf<0H61P06IVIP1XJ6P0IFEU06ATI01QHF40JFUY061PH01YJFT0KVi^
06UYJ@1VIVH0K6a/06=SH`1UIFD0Hf=S06i^KP0206IVIP0906][J`1TI6@0JFUY06=SH`1VIVH0J6QX
06MWI`1TI6@0JVYZ0080Hf=S00d0I6AT06EUI@1QHF40L71`06ATI01WIfL0Jf][065QH@1ZJVX0GUiN
06UYJ@1PH600JFUY0080I6AT0P1VIVH00`1TI6@0IVIV06ATI002065QH@0306=SH`1XJ6P0J6QX0080
HF5Q01<0IFEU065QH@1XJ6P0IVIV06=SH`1QHF40Hf=S065QH@1TI6@0IVIV06UYJ@1SHf<0IfMW06IV
IP1RHV80GUiN06YZJP1QHF40HV9R0080IVIV01@0JVYZ06MWI`1NGUh0IfMW05iNGP1LG5`0IFEU05eM
G@1QHF40Jf][061PH01QHF40IVIV06QXJ01VIVH0I6AT065QH@1NGUh0IfMW06=SH`80H61P00@0I6AT
061PH01WIfL0Jf][0P1PH6000`1KFe/0FEUI05]KF`03065QH@0:05iNGP1QHF40I6AT065QH@1NGUh0
H61P05UIF@1QHF40IVIV061PH080GEeM00h0G5aL05]KF`1KFe/0I6AT061PH01NGUh0FUYJ065QH@1O
Gel0G5aL05UIF@1KFe/0GemO05YJFP80G5aL00@0GEeM05]KF`1PH600Hf=S0P1LG5`00`1JFUX0Fe]K
05UIF@0305QHF00M05UIF@1HF5P0GUiN069RHP1GEeL0Fe]K05QHF01KFe/0FUYJ05iNGP1DE5@0F5QH
05UIF@1KFe/0FEUI05ADE01JFUX0Fe]K05iNGP1DE5@0EEEE05aLG01CDe<0E5AD05MGE`1LG5`0EUIF
065QH@1FEUH00P1IFET00`1PH600HF5Q05IFEP0205QHF00905aLG01KFe/0Fe]K05IFEP1LG5`0E5AD
05IFEP1ADE40Bd];01L000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI
00<0dM7A05iNGP1MGEd00P1PH6003P1RHV80Fe]K05]KF`1QHF40H61P05iNGP1WIfL0Hf=S05mOG`1V
IVH0HF5Q05mOG`1QHF40Hf=S0P1OGel01P1KFe/0GUiN06IVIP1TI6@0HV9R06=SH`80HF5Q00P0G5aL
069RHP1NGUh0Hf=S069RHP1LG5`0H61P065QH@80HV9R00P0G5aL065QH@1SHf<0GUiN05eMG@1TI6@0
Fe]K061PH080Hf=S0280H61P05]KF`1KFe/0Fe]K061PH01NGUh0I6AT061PH01QHF40H61P06=SH`1N
GUh0H61P06=SH`1QHF40F5QH065QH@1PH600I6AT05aLG01WIfL0HF5Q06ATI01QHF40IVIV06=SH`1Q
HF40GUiN06=SH`1TI6@0H61P06=SH`1TI6@0IfMW0P1TI6@02P1UIFD0H61P06EUI@1RHV80H61P06EU
I@1VIVH0IfMW06IVIP1UIFD206ATI00:05aLG01QHF40HV9R06UYJ@1TI6@0IVIV06a/K01XJ6P0Jf][
06UYJ@80J6QX00h0IVIV06QXJ01TI6@0HV9R061PH01TI6@0Jf][06EUI@1YJFT0Hf=S06EUI@1TI6@0
J6QX06ATI080IVIV00@0IFEU06IVIP1QHF40J6QX0`1VIVH00`1QHF40IVIV06IVIP0206MWI`0306IV
IP1[Jf/0JFUY0080Hf=S00@0JFUY06IVIP1TI6@0IfMW0P1QHF408`1TI6@0H61P06QXJ01PH600I6AT
06=SH`1PH600I6AT06IVIP1/K6`0IVIV06][J`1QHF40GemO06=SH`1XJ6P0HV9R06IVIP1WIfL0HV9R
06UYJ@1QHF40J6QX06YZJP1QHF40J6QX061PH01LG5`0H61P06ATI01OGel0Hf=S05mOG`1QHF40IVIV
0080Fe]K00P0Hf=S061PH01IFET0IVIV065QH@1PH600GemO065QH@80HV9R01@0IVIV061PH01LG5`0
H61P06=SH`1QHF40IFEU06QXJ01MGEd0GemO05YJFP1NGUh0HV9R065QH@1KFe/0IVIV05iNGP1PH600
HF5Q061PH080GUiN0100G5aL05mOG`1NGUh0Fe]K06ATI01QHF40GemO05iNGP1JFUX0FEUI051@D01N
GUh0Fe]K05iNGP1FEUH0DE5A0P1QHF4205YJFP80FEUI02`0GUiN05EEE@1MGEd0EUIF05MGE`1CDe<0
FEUI061PH01HF5P0G5aL05MGE`1QHF40F5QH05EEE@1HF5P0E5AD05]KF`1JFUX0Fe]K061PH01KFe/0
E5AD05aLG01KFe/0F5QH05]KF`1HF5P0GemO05aLG01FEUH0GEeM065QH@1HF5P0De=C05iNGP1MGEd0
Fe]K05iNGP1KFe/0H61P05UIF@1JFUX0EUIF059BDP80EUIF00H0GEeM05YJFP1DE5@0EeMG065QH@1C
De<G000000H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0G0<k>cP1PH600
HF5Q06ATI01SHf<0Fe]K06=SH`1LG5`0GUiN05mOG`1TI6@0HF5Q06=SH`1TI6@0Hf=S05iNGP1TI6@0
HF5Q069RHP1LG5`0H61P05]KF`1OGel00P1PH602065QH@80I6AT00h0GEeM069RHP1PH600GemO06AT
I01SHf<0GUiN06=SH`1QHF40Hf=S065QH@1MGEd0Hf=S069RHP80HF5Q00H0H61P05]KF`1PH600G5aL
05iNGP1SHf<205iNGP0905eMG@1QHF40GUiN061PH01IFET0GUiN065QH@1VIVH0H61P0080Fe]K00l0
IVIV05iNGP1NGUh0Hf=S06ATI01XJ6P0I6AT05iNGP1PH600IfMW06UYJ@1PH600HF5Q06=SH`1PH600
0P1VIVH03`1OGel0HF5Q06MWI`1ZJVX0GUiN06=SH`1LG5`0JFUY06ATI01[Jf/0Hf=S061PH01WIfL0
GUiN069RHP0206MWI`80HV9R00L0IVIV061PH01QHF40Jf][06UYJ@1/K6`0Hf=S0080K6a/0100I6AT
06IVIP1WIfL0J6QX06UYJ@1[Jf/0HV9R065QH@1XJ6P0IVIV06UYJ@1TI6@0IFEU06MWI`1SHf<0Jf][
0P1VIVH06`1TI6@0HV9R06ATI01PH600I6AT06MWI`1XJ6P0JFUY06EUI@1OGel0I6AT06=SH`1XJ6P0
IfMW06a/K01TI6@0JVYZ065QH@1WIfL0IVIV06UYJ@1KFe/0Hf=S069RHP1[Jf/0IVIV06QXJ00406=S
H`80IVIV01`0Kfm_06YZJP1SHf<0H61P06YZJP1TI6@0H61P06IVIP1LG5`0IfMW06IVIP1TI6@0J6QX
06=SH`1YJFT0I6AT05eMG@1TI6@0Hf=S05eMG@1UIFD0Jf][061PH01QHF40GemO05iNGP1SHf<0HV9R
0P1SHf<02P1QHF40G5aL061PH01OGel0G5aL05iNGP1OGel0H61P05UIF@1NGUh206ATI00Z05aLG01Y
JFT0G5aL06ATI01QHF40H61P05mOG`1RHV80Jf][05YJFP1NGUh0HF5Q06=SH`1LG5`0GemO06=SH`1H
F5P0GemO065QH@1TI6@0GemO06QXJ01LG5`0GUiN065QH@1KFe/0F5QH05IFEP1QHF40FEUI06ATI01S
Hf<0I6AT06=SH`1JFUX0Fe]K065QH@1LG5`0De=C05iNGP1KFe/0FEUI0P1HF5P00`1DE5@0G5aL069R
HP0205iNGP0X05IFEP1PH600G5aL05EEE@1@D500EUIF05]KF`1GEeL0FUYJ05IFEP1DE5@0FEUI05aL
G01NGUh0FEUI05aLG01HF5P0Fe]K05=CD`1JFUX0E5AD05iNGP1KFe/0Cdm?05UIF@1JFUX0GUiN05QH
F01ADE40EeMG05QHF01MGEd0E5AD05UIF@1JFUX0EEEE05MGE`1NGUh0F5QH05=CDaL000001P3IfMT1
00000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00D0b<S805UIF@1TI6@0HV9R05UIF@02
065QH@0605aLG01NGUh0GEeM05aLG01PH600GemO0P1WIfL0201PH600FUYJ061PH01PH600HF5Q069R
HP1SHf<0Fe]K0P1PH600301LG5`0GUiN06=SH`1SHf<0G5aL061PH01GEeL0HV9R05aLG01QHF40H61P
065QH@80I6AT00@0H61P05iNGP1LG5`0GUiN0P1IFET0201KFe/0GemO05iNGP1NGUh0EUIF061PH01K
Fe/0H61P0P1LG5`01@1QHF40I6AT06ATI01NGUh0GEeM0080Fe]K00@0HV9R06=SH`1MGEd0I6AT0P1S
Hf<01@1VIVH0IFEU05]KF`1QHF40GemO0080HF5Q01T0KFe]06ATI01SHf<0IfMW06=SH`1UIFD0I6AT
05iNGP1TI6@0J6QX06EUI@1VIVH0H61P06EUI@1VIVH0I6AT05mOG`1WIfL0IFEU069RHP1TI6@0IFEU
05mOG`1VIVH0HV9R0080I6AT00d0IVIV06UYJ@1TI6@0J6QX06IVIP1ZJVX0IVIV06MWI`1VIVH0Kfm_
06a/K01PH600IVIV0080I6AT0P1WIfL206UYJ@0:06IVIP1XJ6P0JFUY06UYJ@1TI6@0HF5Q06ATI01S
Hf<0GEeM069RHP80Hf=S0P1XJ6P01@1YJFT0H61P06QXJ01WIfL0L71`0080J6QX00/0JFUY06QXJ01[
Jf/0HV9R061PH01YJFT0IVIV05]KF`1TI6@0HV9R06=SH`0206YZJP0506QXJ01OGel0G5aL06IVIP1W
IfL00`1VIVH01@1TI6@0Hf=S061PH01SHf<0HV9R0080HF5Q00P0HV9R06YZJP1QHF40I6AT06IVIP1T
I6@0Hf=S06IVIP80GemO0P1NGUh0201JFUX0GemO05aLG01VIVH0GUiN05mOG`1VIVH0G5aL0P1QHF40
2`1TI6@0GUiN061PH01KFe/0HV9R06ATI01NGUh0I6AT05QHF01QHF40I6AT0080GUiN00l0GEeM06IV
IP1OGel0GEeM065QH@1LG5`0IfMW06=SH`1NGUh0H61P05eMG@1RHV80G5aL069RHP1NGUh00P1RHV80
0`1OGel0HF5Q061PH00205aLG00B05UIF@1NGUh0GEeM06=SH`1NGUh0FUYJ05EEE@1HF5P0EEEE05iN
GP1LG5`0EeMG05eMG@1SHf<0Fe]K05QHF01IFET0F5QH0P1JFUX00`1IFET0F5QH05UIF@0205UIF@0S
05iNGP1SHf<0GUiN05MGE`1HF5P0EUIF05ADE01IFET0G5aL05mOG`1HF5P0FEUI05QHF01BDU80EUIF
05EEE@1ADE40De=C05YJFP1LG5`0EeMG05=CD`1DE5@0D51@05aLG01HF5P0E5AD05QHF01LG5`0E5AD
05EEE@1HF5P0CTi>05EEE@1CDe<00P1HF5P00`1@D500EeMG0000000F000000H0fMWI0@0000010=WI
f@005P3IfMT00`000000fMWI0=WIf@030=WIf@0D0<_;b`1OGel0GEeM05aLG01MGEd0F5QH05mOG`1M
GEd0GemO061PH01LG5`0H61P05iNGP1LG5`0HV9R05aLG01TI6@0IVIV05IFEP1QHF4206ATI00406EU
I@1NGUh0Hf=S065QH@80GemO00H0Hf=S05mOG`1OGel0GemO061PH01SHf<3069RHP0F061PH01QHF40
GUiN05YJFP1QHF40EUIF05aLG01IFET0GEeM05aLG01KFe/0G5aL05IFEP1MGEd0FEUI065QH@1PH600
G5aL05eMG@1PH600GEeM05aLG080H61P02l0GUiN065QH@1MGEd0Hf=S061PH01QHF40FEUI065QH@1T
I6@0GemO065QH@1TI6@0IFEU06=SH`1VIVH0HV9R06=SH`1MGEd0H61P05iNGP1OGel0HV9R05aLG01Y
JFT0GEeM061PH01QHF40H61P05aLG01]KFd0GEeM061PH01WIfL0HF5Q06MWI`1PH600HF5Q06IVIP1Y
JFT0Hf=S06ATI01VIVH0IfMW06IVIP1PH600HF5Q06a/K00206UYJ@0@06][J`1SHf<0HV9R06IVIP1S
Hf<0JFUY06IVIP1PH600JFUY071`L01[Jf/0J6QX06=SH`1UIFD0IfMW06=SH`80JFUY01L0Hf=S06a/
K01VIVH0HF5Q06YZJP1QHF40Hf=S06ATI01PH600I6AT061PH01ZJVX0IFEU06][J`1MGEd0JVYZ06AT
I01WIfL0J6QX069RHP1VIVH0Hf=S065QH@0206][J`0906UYJ@1VIVH0H61P06EUI@1OGel0Hf=S06][
J`1SHf<0IFEU0080IVIV00@0Hf=S06UYJ@1NGUh0HF5Q0P1XJ6P02P1RHV80HF5Q06EUI@1OGel0JFUY
06ATI01XJ6P0G5aL06ATI01OGel205iNGP0505aLG01SHf<0G5aL061PH01NGUh00P1PH6005`1UIFD0
HV9R05aLG01LG5`0HV9R05]KF`1VIVH0JVYZ06=SH`1NGUh0Fe]K065QH@1NGUh0I6AT069RHP1QHF40
GEeM05iNGP1QHF40HV9R065QH@1PH600GUiN0080IFEU01h0IVIV05YJFP1QHF40EUIF05YJFP1VIVH0
Hf=S061PH01SHf<0GUiN061PH01SHf<0H61P069RHP1QHF40G5aL05UIF@1LG5`0Fe]K05UIF@1JFUX0
HF5Q05iNGP1LG5`0FEUI05QHF01LG5`0GUiN05eMG@1KFe/205UIF@0805]KF`1HF5P0EUIF05QHF01C
De<0FEUI05QHF01DE5@305]KF`80FEUI00l0EUIF05QHF01FEUH0Fe]K05YJFP1HF5P0GemO05]KF`1G
EeL0Hf=S05MGE`1PH600DE5A05EEE@1ADE400P1JFUX03`1KFe/0E5AD05UIF@1CDe<0FEUI05aLG01F
EUH0Fe]K05QHF01LG5`0E5AD05MGE`1CDe<0GEeM05UIF@0G000000H0fMWI0@0000010=WIf@005P3I
fMT00`000000fMWI0=WIf@030=WIf@040<?3``1OGel0H61P061PH080Hf=S00H0Fe]K05eMG@1NGUh0
HF5Q05]KF`1MGEd205aLG00305]KF`1JFUX0HV9R0080H61P01`0HF5Q06IVIP1SHf<0GEeM06ATI01S
Hf<0IFEU05aLG01PH600Hf=S05]KF`1QHF40JVYZ06=SH`1MGEd0H61P06ATI01LG5`0I6AT05mOG`1U
IFD0Fe]K05iNGP1PH600FEUI05QHF01LG5`0H61P0P1LG5`02@1NGUh0H61P05aLG01QHF40HV9R06AT
I01PH600G5aL05UIF@02069RHP<0Hf=S01D0GemO05iNGP1RHV80GUiN06EUI@1VIVH0Hf=S06MWI`1S
Hf<0IFEU069RHP1TI6@0HF5Q06EUI@1SHf<0IVIV069RHP1SHf<0I6AT06QXJ01QHF400`1SHf<04P1P
H600J6QX06EUI@1VIVH0J6QX05iNGP1OGel0IVIV06ATI01[Jf/0IfMW06QXJ01WIfL0I6AT06=SH`1V
IVH0JFUY06i^KP80Hf=S00@0HF5Q06IVIP1TI6@0JFUY0P1XJ6P0101^KVh0JVYZ06IVIP1YJFT206a/
K00>06YZJP1PH600I6AT06][J`1QHF40IfMW06UYJ@1_Kfl0JFUY06IVIP1/K6`0I6AT06IVIP1[Jf/2
06=SH`0606ATI01XJ6P0JFUY06QXJ01UIFD0Jf][0P1TI6@02`1UIFD0H61P06e]K@1TI6@0IfMW06EU
I@1QHF40IVIV06UYJ@1[Jf/0IFEU0080H61P01X0IVIV06QXJ01WIfL0LG5a06][J`1SHf<0IVIV06QX
J01UIFD0I6AT061PH01UIFD0H61P06MWI`1PH600Hf=S06EUI@1LG5`0GemO06ATI01SHf<0H61P05UI
F@1QHF40JFUY06EUI@80H61P01H0IVIV06=SH`1QHF40GemO069RHP1PH600HF5Q05YJFP1TI6@0HV9R
061PH01SHf<0GUiN061PH01NGUh0Hf=S05aLG01PH600EeMG05iNGP1PH600G5aL0P1TI6@05P1KFe/0
Hf=S05mOG`1PH600GEeM065QH@1SHf<0Fe]K05aLG01RHV80Fe]K065QH@1LG5`0HF5Q05mOG`1PH600
I6AT065QH@1RHV80Fe]K06ATI01NGUh2061PH00K05iNGP1HF5P0FUYJ05IFEP1LG5`0EUIF05UIF@1D
E5@0EEEE05UIF@1LG5`0F5QH05IFEP1GEeL0H61P05iNGP1JFUX0E5AD05YJFP1CDe<0Fe]K05=CD`1K
Fe/0E5AD05aLG01PH600G5aL0080Fe]K00d0FEUI065QH@1IFET0E5AD05QHF01NGUh0G5aL061PH01I
FET0Fe]K05aLG01IFET0F5QH00<0FEUI00h0Cdm?05YJFP1FEUH0Fe]K05YJFP1HF5P0D51@05IFEP1C
De<0Fe]K061PH01EEED0E5AD05UIFAL000001P3IfMT100000040fMWI000F0=WIf@800000103IfMT0
103<c<`0HF5Q05aLG01PH60205UIF@80H61P00D0Hf=S06ATI01LG5`0IVIV05iNGP0205]KF`0=06AT
I01VIVH0F5QH05aLG01UIFD0IVIV06ATI01UIFD0J6QX06=SH`1OGel0FUYJ065QH@02061PH00705mO
G`1TI6@0H61P06=SH`1VIVH0J6QX05]KF`02065QH@0A05IFEP1MGEd0Fe]K069RHP1PH600Fe]K05mO
G`1QHF40Fe]K05iNGP1MGEd0GUiN06EUI@1SHf<0IVIV065QH@1JFUX00P1QHF40901SHf<0I6AT065Q
H@1NGUh0FEUI065QH@1OGel0FEUI05mOG`1XJ6P0GEeM069RHP1VIVH0HF5Q06QXJ01RHV80IFEU05aL
G01VIVH0H61P06ATI01UIFD0Hf=S065QH@1NGUh0HV9R06UYJ@1MGEd0IVIV06ATI01RHV80Hf=S05aL
G01QHF40GUiN061PH080GUiN01`0HV9R06EUI@1WIfL0I6AT06IVIP1XJ6P0IfMW06][J`1XJ6P0IfMW
06EUI@1XJ6P0I6AT06a/K01[Jf/0IFEU06IVIP1QHF40I6AT06m_K`1VIVH0JFUY05aLG01SHf<0J6QX
06UYJ@1QHF40I6AT0`1VIVH01@1MGEd0K6a/06EUI@1WIfL0HV9R0080Hf=S00L0H61P06ATI01SHf<0
IVIV061PH01YJFT0IfMW0080IVIV00d0HV9R06IVIP1TI6@0IVIV06ATI01YJFT0K6a/06EUI@1SHf<0
J6QX06ATI01SHf<0I6AT0080IFEU0280HF5Q06=SH`1QHF40IVIV06QXJ01PH600IFEU06IVIP1PH600
G5aL06=SH`1/K6`0HF5Q06][J`1SHf<0Fe]K05iNGP1PH600JVYZ06=SH`1KFe/0J6QX06EUI@1PH600
I6AT065QH@1KFe/0I6AT05YJFP1UIFD0H61P065QH@1OGel0H61P0P1VIVH03P1SHf<0GUiN06UYJ@1N
GUh0Fe]K061PH01RHV80Fe]K06=SH`1UIFD0HF5Q05aLG01TI6@0G5aL0P1PH6001`1NGUh0JFUY05mO
G`1LG5`0IFEU061PH01QHF400P1OGel00`1MGEd0H61P05YJFP02061PH00<065QH@1PH600G5aL06QX
J01IFET0I6AT05MGE`1OGel0GUiN05aLG01OGel0EUIF0P1LG5`02@1PH600G5aL061PH01QHF40G5aL
05=CD`1PH600FEUI05QHF00205aLG00F05EEE@1KFe/0Fe]K065QH@1NGUh0G5aL065QH@1JFUX0EeMG
05iNGP1FEUH0FEUI05mOG`1NGUh0FEUI05ADE01LG5`0De=C05eMG@1NGUh0EeMG05]KF`80EUIF00H0
F5QH05UIF@1DE5@0Fe]K05UIF@1QHF4205UIF@0:05YJFP1HF5P0G5aL05=CD`1DE5@0De=C061PH01I
FET0CTi>05EEEAL000001@3IfMT200000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00D0
bl_;05YJFP1JFUX0GEeM06QXJ003061PH00405mOG`1NGUh0GUiN06=SH`80GEeM0P1PH6001P1MGEd0
H61P05aLG01TI6@0G5aL05eMG@@0IVIV00`0IFEU05]KF`1TI6@0H61P05iNGP1TI6@0HV9R05eMG@1Q
HF40E5AD06=SH`1UIFD205iNGP06069RHP1IFET0GemO05mOG`1SHf<0H61P0P1IFET05`1NGUh0G5aL
05EEE@1RHV80HF5Q05iNGP1KFe/0H61P05]KF`1QHF40Fe]K069RHP1PH600GEeM065QH@1NGUh0I6AT
05]KF`1VIVH0J6QX061PH01NGUh0J6QX0080HF5Q0140I6AT05QHF01SHf<0HV9R061PH01QHF40IVIV
061PH01YJFT0IVIV061PH01XJ6P0I6AT069RHP1SHf<0J6QX06=SH`02061PH00906IVIP1JFUX0IVIV
06IVIP1XJ6P0I6AT05mOG`1XJ6P0I6AT0080Hf=S01<0J6QX06IVIP1WIfL0Hf=S065QH@1XJ6P0IfMW
06][J`1UIFD0KVi^06IVIP1ZJVX0HV9R06QXJ01UIFD0IVIV06ATI01SHf<0J6QX0080IFEU00d0JFUY
06QXJ01TI6@0JVYZ06=SH`1UIFD0IVIV06QXJ01[Jf/0HV9R06][J`1UIFD0J6QX0080JFUY01<0I6AT
069RHP1YJFT0Hf=S06UYJ@1[Jf/0K6a/06QXJ01TI6@0J6QX061PH01WIfL0IVIV06][J`1SHf<0IVIV
06=SH`1RHV80IVIV0080IfMW01X0Hf=S06MWI`1VIVH0JFUY069RHP1UIFD0HF5Q06MWI`1XJ6P0I6AT
06IVIP1UIFD0Hf=S06][J`1TI6@0Hf=S06ATI01YJFT0HF5Q061PH01QHF40IVIV05iNGP1VIVH0HF5Q
06ATI080Hf=S00<0GEeM069RHP1XJ6P00P1PH600101QHF40Hf=S05]KF`1NGUh206=SH`0305eMG@1N
GUh0HV9R0080GUiN0P1LG5`0201NGUh0H61P065QH@1KFe/0GEeM069RHP1NGUh0HF5Q0P1MGEd07P1T
I6@0Fe]K061PH01PH600GemO065QH@1LG5`0F5QH05YJFP1LG5`0I6AT05QHF01DE5@0G5aL05eMG@1P
H600J6QX05YJFP1QHF40Fe]K05iNGP1KFe/0H61P05UIF@1FEUH0FUYJ05]KF`1NGUh0EeMG05QHF080
Fe]K00X0F5QH061PH01ADE40EeMG05aLG01GEeL0HF5Q05]KF`1OGel0FEUI0P1LG5`0101IFET0FUYJ
05YJFP1HF5P205aLG00405YJFP1ADE40Fe]K05IFEP80G5aL00D0EEEE05=CD`1IFET0FUYJ05IFEP02
05aLG00405eMG@1LG5`0FEUI05ADE080F5QH00H0FUYJ05]KF`1IFET0Fe]K04m?C`1CDe<G000000H0
fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@070<_;b`1NGUh0HF5Q065QH@1I
FET0I6AT061PH002065QH@04061PH01QHF40Fe]K06EUI@80G5aL00L0GUiN06IVIP1NGUh0IFEU061P
H01QHF40GUiN0080I6AT00L0HV9R06ATI01VIVH0HF5Q06EUI@1TI6@0G5aL0080GUiN0100HF5Q069R
HP1IFET0Fe]K06QXJ01_Kfl0Hf=S05EEE@1XJ6P0GUiN06UYJ@1PH600Fe]K065QH@1NGUh0GemO0`1L
G5`0301NGUh0H61P06=SH`1SHf<0IVIV06QXJ01OGel0GUiN065QH@1NGUh0Fe]K05eMG@80Fe]K00d0
I6AT05aLG01UIFD0JFUY05aLG01QHF40I6AT061PH01SHf<0HF5Q061PH01TI6@0IFEU0080HV9R0180
I6AT05iNGP1TI6@0HF5Q06QXJ01QHF40Hf=S06QXJ01UIFD0IVIV05iNGP1^KVh0IVIV06QXJ01SHf<0
IVIV06EUI@1^KVh206IVIP0906YZJP1UIFD0IVIV06ATI01PH600JVYZ06e]K@1TI6@0IfMW0080J6QX
01@0JFUY06MWI`1YJFT0HV9R06UYJ@1SHf<0I6AT06IVIP1XJ6P0Jf][071`L01XJ6P0HF5Q06QXJ01P
H600I6AT06IVIP1QHF40J6QX06][J`80IVIV0100H61P06UYJ@1VIVH0IfMW06IVIP1XJ6P0IVIV06][
J`1VIVH0H61P06ATI01SHf<0KFe]06IVIP1YJFT0Jf][0P1VIVH00`1TI6@0IfMW06a/K00206=SH`03
05iNGP1QHF40HV9R0080JFUY00X0KVi^065QH@1UIFD0J6QX06IVIP1YJFT0IVIV05iNGP1TI6@0H61P
0P1SHf<07P1TI6@0H61P06MWI`1MGEd0HF5Q05mOG`1PH600Hf=S069RHP1LG5`0HF5Q06=SH`1QHF40
HV9R05QHF01SHf<0IFEU06QXJ01TI6@0IfMW05aLG01QHF40Hf=S061PH01RHV80I6AT05]KF`1QHF40
HV9R065QH@<0GEeM0100GUiN069RHP1PH600GUiN05aLG01OGel0Hf=S05mOG`1PH600GemO06=SH`1P
H600GEeM065QH@1MGEd0GUiN0P1JFUX05`1NGUh0IVIV05eMG@1TI6@0Fe]K05eMG@1GEeL0HF5Q061P
H01SHf<0G5aL061PH01LG5`0GemO05UIF@1LG5`0F5QH05UIF@1KFe/0FEUI05YJFP1LG5`0FUYJ0080
De=C01@0FUYJ05iNGP1PH600De=C05]KF`1OGel0EEEE05eMG@1HF5P0GEeM05aLG01IFET0EUIF05QH
F01IFET0E5AD05MGE`1LG5`0FEUI05QHF080G5aL00T0Fe]K05IFEP1IFET0Fe]K05QHF01KFe/0EEEE
05mOG`1KFe/00P1LG5`0201HF5P0E5AD05=CD`1LG5`0EEEE05QHF01EEED0De=C5`0000060=WIf@40
00000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT01@3:b/X0FEUI065QH@1RHV80HF5Q0080
Fe]K00@0GUiN05EEE@1LG5`0GUiN0P1QHF405`1TI6@0GemO069RHP1NGUh0Hf=S05aLG01NGUh0Hf=S
06ATI01SHf<0GemO06MWI`1SHf<0H61P065QH@1PH600Fe]K06ATI01RHV80GUiN05mOG`1TI6@0Hf=S
0080H61P00<0G5aL065QH@1QHF400P1SHf<206IVIP0@06UYJ@1LG5`0G5aL05=CD`1HF5P0Fe]K05eM
G@1JFUX0IVIV06ATI01LG5`0JFUY06ATI01KFe/0Hf=S061PH080HF5Q01l0G5aL06ATI01SHf<0GUiN
06QXJ01TI6@0GUiN06EUI@1NGUh0IVIV06ATI01YJFT0Hf=S05iNGP1TI6@0G5aL06EUI@1TI6@0HF5Q
069RHP1ZJVX0HF5Q06IVIP1PH600Hf=S061PH01TI6@0HF5Q05mOG`1VIVH0I6AT0080J6QX01H0IVIV
06EUI@1TI6@0HF5Q061PH01OGel0H61P06EUI@1VIVH0HV9R06m_K`1UIFD0KVi^06MWI`1bLW80JFUY
06][J`1SHf<0IfMW06=SH`1QHF40I6AT101SHf<0201VIVH0IFEU06QXJ01WIfL0KVi^06=SH`1XJ6P0
JVYZ0P1PH6002P1QHF40JFUY06UYJ@1TI6@0Jf][069RHP1QHF40JFUY06IVIP1PH60206IVIP0H06UY
J@1ZJVX0I6AT06YZJP1VIVH0HV9R06UYJ@1UIFD0IVIV06=SH`1PH600Jf][061PH01YJFT0KFe]06IV
IP1UIFD0H61P069RHP1OGel0IVIV061PH01NGUh0HF5Q0P1PH6003`1QHF40H61P05EEE@1WIfL0HF5Q
06ATI01SHf<0I6AT061PH01YJFT0HV9R065QH@1SHf<0HV9R05YJFP02061PH00K065QH@1LG5`0IFEU
05UIF@1MGEd0FUYJ06ATI01QHF40GUiN05]KF`1PH600Hf=S05mOG`1RHV80GUiN05eMG@1LG5`0GUiN
05mOG`1HF5P0Hf=S05aLG01SHf<0GUiN06=SH`1MGEd0Fe]K0080H61P00X0HF5Q05]KF`1NGUh0G5aL
06MWI`1DE5@0H61P05QHF01NGUh0H61P0P1IFET04@1LG5`0HF5Q061PH01PH600FEUI069RHP1LG5`0
Fe]K06IVIP1NGUh0HF5Q05QHF01PH600EEEE05aLG01KFe/0FEUI00<0Fe]K00D0FUYJ05aLG01IFET0
E5AD05=CD`0205YJFP80Fe]K0280F5QH05]KF`1MGEd0G5aL05YJFP1HF5P0H61P051@D01DE5@0EEEE
061PH01JFUX0H61P05UIF@1KFe/0FUYJ05QHF01ADE40E5AD05UIF@1HF5P0GEeM05QHF01FEUH0H61P
05YJFP1LG5`0FEUI05YJFP1NGUh0FEUI05MGE`1BDU80EUIF5`0000060=WIf@4000000@3IfMT001H0
fMWI00<000000=WIf@3IfMT00`3IfMT02`3;bl/0GUiN05UIF@1UIFD0GUiN06EUI@1QHF40GUiN06=S
H`1KFe/0FUYJ0080H61P00h0G5aL06ATI01SHf<0HF5Q06ATI01UIFD0HF5Q06MWI`1PH600Hf=S06IV
IP1]KFd0GemO06=SH`80HF5Q00X0GemO06IVIP1OGel0FUYJ05QHF01PH600IVIV06MWI`1VIVH0G5aL
0P1QHF402`1HF5P0FUYJ06IVIP1LG5`0GUiN05eMG@1NGUh0G5aL061PH01OGel0FEUI0080Hf=S00P0
HV9R05iNGP1WIfL0H61P05eMG@1VIVH0IFEU05aLG080I6AT00T0G5aL06=SH`1OGel0HF5Q05aLG01N
GUh0Hf=S05iNGP1RHV800P1QHF403@1SHf<0IVIV06QXJ01QHF40IVIV05]KF`1MGEd0IVIV065QH@1W
IfL0IFEU065QH@1WIfL00P1RHV802`1SHf<0GUiN05mOG`1QHF40J6QX065QH@1SHf<0GemO065QH@1U
IFD0Hf=S0080IVIV01L0J6QX06ATI01[Jf/0J6QX06IVIP1/K6`0IVIV06=SH`1YJFT0Jf][06i^KP1X
J6P0Hf=S06UYJ@1PH600Hf=S06UYJ@1_Kfl0K6a/065QH@1XJ6P0JFUY06MWI`0206ATI00^06][J`1X
J6P0JVYZ06a/K01QHF40Hf=S05mOG`1`L700HF5Q06EUI@1]KFd0Hf=S06][J`1TI6@0IVIV06QXJ01T
I6@0HV9R06][J`1PH600J6QX06ATI01XJ6P0IVIV06EUI@1XJ6P0IVIV061PH01ZJVX0Jf][06UYJ@1Q
HF40Jf][06UYJ@1WIfL0Hf=S05UIF@1TI6@0GUiN06QXJ01UIFD0J6QX05eMG@1QHF40Fe]K06IVIP80
GEeM00@0H61P05aLG01LG5`0I6AT0P1NGUh00`1WIfL0GUiN06ATI00205iNGP0405aLG01SHf<0I6AT
05]KF`80I6AT00D0G5aL05]KF`1OGel0GEeM06ATI002061PH00C05]KF`1NGUh0HF5Q05aLG01NGUh0
HV9R06=SH`1LG5`0H61P065QH@1KFe/0GEeM06=SH`1QHF40Hf=S05]KF`1QHF40Fe]K05QHF002069R
HP0;061PH01NGUh0GEeM061PH01KFe/0HF5Q05YJFP1QHF40GUiN065QH@1IFET00P1PH6001@1NGUh0
Fe]K05eMG@1IFET0F5QH0080Fe]K00L0DE5A05eMG@1FEUH0EEEE05UIF@1GEeL0GemO0080EeMG00L0
F5QH05aLG01HF5P0FUYJ05QHF01SHf<0Fe]K0080FEUI00/0DU9B05UIF@1CDe<0FUYJ05QHF01KFe/0
F5QH05UIF@1KFe/0F5QH05iNGP0205IFEP0405ADE01FEUH0G5aL05]KF`80F5QH00d0GEeM05UIF@1L
G5`0F5QH061PH01FEUH0EEEE05ADE01FEUH0E5AD05IFEP1MGEd0D51@01L000001P3IfMT100000040
fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0200b/[:065QH@1NGUh0GUiN06=SH`1KFe/0HF5Q
05]KF`1SHf<0IVIV05iNGP1RHV80FEUI05aLG01TI6@0IfMW061PH01SHf<0IFEU06=SH`1LG5`0IVIV
06=SH`1WIfL0Jf][06ATI01LG5`0JFUY05aLG01NGUh0HF5Q05UIF@80GUiN00D0HF5Q05eMG@1RHV80
Hf=S05]KF`0206IVIP0H06=SH`1LG5`0I6AT06ATI01MGEd0HV9R05aLG01JFUX0EUIF061PH01LG5`0
HV9R061PH01LG5`0I6AT06=SH`1PH600FEUI061PH01TI6@0GUiN06=SH`1RHV80Hf=S0P1QHF40101N
GUh0I6AT05aLG01XJ6P206ATI00705]KF`1YJFT0I6AT065QH@1PH600HF5Q06IVIP0206EUI@80H61P
04@0Hf=S065QH@1VIVH0H61P06ATI01YJFT0H61P065QH@1VIVH0Fe]K05mOG`1RHV80Hf=S061PH01W
IfL0Hf=S06MWI`1YJFT0IVIV061PH01UIFD0KFe]06UYJ@1QHF40KFe]06IVIP1TI6@0HF5Q06IVIP1Y
JFT0JVYZ06a/K01RHV80K6a/06ATI01VIVH0J6QX06EUI@1YJFT0HF5Q06MWI`1XJ6P0KVi^06][J`1T
I6@0JFUY06=SH`1LG5`0IFEU05UIF@1TI6@0HF5Q05]KF`1SHf<0Jf][06YZJP1XJ6P0I6AT069RHP1V
IVH0IFEU06IVIP1ZJVX0IVIV06QXJ01VIVH0H61P06UYJ@80IVIV00<0JFUY06EUI@1QHF400P1[Jf/0
3@1SHf<0HF5Q05iNGP1RHV80J6QX05aLG01NGUh0HF5Q06QXJ01QHF40GemO06ATI01LG5`00P1NGUh0
101TI6@0Hf=S06=SH`1TI6@205YJFP03069RHP1NGUh0F5QH0080H61P01P0IVIV05iNGP1SHf<0JFUY
061PH013@d<0HF5Q05=CD`1JFUX0Fe]K069RHP1OGel0IFEU065QH@1NGUh0Hf=S061PH01QHF40GUiN
05aLG01JFUX0H61P05]KF`1TI6@205iNGP0?06ATI01OGel0IVIV05eMG@1LG5`0H61P05aLG01YJFT0
GemO05iNGP1SHf<0FEUI05mOG`1SHf<0GEeM0080Hf=S00H0I6AT05eMG@1QHF40GUiN061PH01RHV83
05iNGP0505aLG01HF5P0FEUI05YJFP1LG5`00P1KFe/08@1SHf<0GEeM05QHF01NGUh0HF5Q05YJFP1Q
HF40G5aL05UIF@1KFe/0FUYJ05iNGP1LG5`0EUIF05]KF`1BDU80F5QH05EEE@1KFe/0DU9B05UIF@1C
De<0Fe]K05YJFP1GEeL0De=C05IFEP1DE5@0EUIF05=CD`1JFUX0Fe]K05UIF@0205IFEP0705]KF`1I
FET0FEUI05aLG01FEUH0HV9R061PH00205UIF@0305]KF`1LG5`0EUIF01L000001P3IfMT100000040
fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00@0cLg=05iNGP1RHV80IfMW0P1QHF401P1OGel0
IFEU05iNGP1PH600G5aL069RHP80H61P00T0Hf=S06ATI01VIVH0I6AT06=SH`1RHV80I6AT069RHP1S
Hf<00P1YJFT0401UIFD0GUiN05mOG`1RHV80HF5Q06ATI01SHf<0HF5Q069RHP1OGel0H61P06ATI01P
H600HF5Q05mOG`1RHV82061PH00Y06ATI01QHF40IFEU05aLG01QHF40FUYJ05ADE01HF5P0HF5Q05mO
G`1TI6@0G5aL05iNGP1WIfL0Fe]K065QH@1MGEd0J6QX05aLG01RHV80GUiN06=SH`1KFe/0H61P06UY
J@1UIFD0Hf=S061PH01TI6@0Hf=S06IVIP1ZJVX0I6AT05eMG@1PH600HF5Q061PH01LG5`0HV9R06=S
H`1QHF400`1NGUh08P1UIFD0I6AT06QXJ01KFe/0I6AT05eMG@1LG5`0J6QX05iNGP1SHf<0I6AT06IV
IP1NGUh0Hf=S06YZJP1YJFT0I6AT06=SH`1WIfL0I6AT06MWI`1^KVh0Hf=S06a/K01_Kfl0IfMW06EU
I@1RHV80HF5Q069RHP1UIFD0I6AT065QH@1VIVH206QXJ0<0Hf=S00T0GUiN069RHP1SHf<0GemO06MW
I`1YJFT0HF5Q06YZJP1TI6@00`1XJ6P02`1QHF40K6a/06UYJ@1WIfL0Hf=S06IVIP1SHf<0IVIV06UY
J@1XJ6P0IVIV00<0IFEU01<0HF5Q06EUI@1TI6@0KFe]06=SH`1]KFd0I6AT06UYJ@1NGUh0Jf][069R
HP1TI6@0HV9R065QH@1HF5P0Hf=S069RHP1VIVH0HV9R0080HF5Q0140GUiN06IVIP1JFUX0GemO05aL
G01PH600JFUY05UIF@1LG5`0GUiN06EUI@1IFET0Hf=S05iNGP1SHf<0HF5Q06][J`0205mOG`0l061P
H01KFe/0H61P05mOG`1VIVH0G5aL05YJFP1PH600GUiN05aLG01PH600GUiN05QHF01JFUX0GUiN05aL
G01QHF40G5aL06IVIP1SHf<0G5aL061PH01QHF40HV9R05iNGP1LG5`0GemO06ATI01SHf<0GEeM06QX
J01SHf<0H61P05]KF`1UIFD0GEeM065QH@1UIFD0GUiN061PH01SHf<0HV9R061PH01MGEd0GUiN065Q
H@1KFe/0GemO065QH@1JFUX0GUiN05IFEP1PH600Fe]K05YJFP1IFET0Fe]K05ADE01EEED0FUYJ0P1I
FET06P1NGUh0FUYJ05EEE@1EEED0G5aL05UIF@1JFUX0GEeM05ADE01EEED0HV9R05IFEP1NGUh0De=C
05IFEP1NGUh0E5AD05UIF@1FEUH0DU9B05aLG01KFe/0GemO05QHF01IFET0EUIF0P1JFUX00`1FEUH0
F5QH05IFEP0205iNGP0405]KF`1EEED0GEeM051@D1L000001P3IfMT100000040fMWI000F0=WIf@03
0000003IfMT0fMWI00<0fMWI00T0cLg=05eMG@1HF5P0I6AT05iNGP1QHF40IVIV05eMG@1TI6@00P1S
Hf<09`1QHF40FEUI06=SH`1QHF40I6AT06QXJ01VIVH0H61P05mOG`1QHF40IfMW06UYJ@1VIVH0I6AT
065QH@1PH600HF5Q05eMG@1WIfL0HV9R05aLG01SHf<0IFEU06ATI01/K6`0HF5Q06EUI@1VIVH0H61P
05UIF@1PH600Hf=S05mOG`1SHf<0EEEE05eMG@1KFe/0H61P06ATI00205iNGP0N05mOG`1SHf<0I6AT
05aLG01TI6@0JFUY06=SH`1PH600GEeM06ATI01LG5`0IFEU06=SH`1PH600HV9R065QH@1XJ6P0HF5Q
06ATI01UIFD0G5aL061PH01RHV80H61P06IVIP1NGUh0HF5Q069RHP1PH600G5aL0P1PH600101RHV80
HF5Q06ATI01VIVH206ATI00605mOG`1TI6@0H61P05aLG01PH600J6QX0P1VIVH01P1PH600GUiN06QX
J01YJFT0Hf=S06ATI080IVIV0P1TI6@0;P1/K6`0J6QX06ATI01YJFT0GUiN06m_K`1YJFT0IFEU075a
L@1WIfL0JVYZ06IVIP1/K6`0IFEU06QXJ01WIfL0HV9R06QXJ01YJFT0J6QX06ATI01PH600Hf=S06QX
J01PH600Jf][065QH@1[Jf/0J6QX061PH01YJFT0J6QX06UYJ@1PH600Jf][06QXJ01YJFT0J6QX06IV
IP1_Kfl0HV9R06QXJ01RHV80Jf][06QXJ01TI6@206QXJ006071`L01XJ6P0J6QX06QXJ01SHf<0GemO
0P1SHf<01@1PH600HV9R06EUI@1UIFD0H61P00<0Hf=S01H0IFEU069RHP1MGEd0I6AT06IVIP1LG5`0
I6AT05iNGP1MGEd0Hf=S05]KF`1TI6@0GEeM06UYJ@1UIFD0I6AT05mOG`1PH600Hf=S06EUI@1TI6@0
HF5Q0P1RHV803@1OGel0J6QX065QH@1TI6@0EUIF05YJFP1SHf<0Fe]K05QHF01=CDd0Fe]K061PH01M
GEd00P1SHf<00`1VIVH0Hf=S05YJFP0305iNGP0H05YJFP1PH600Hf=S061PH01[Jf/0Hf=S05]KF`1T
I6@0Hf=S05eMG@1OGel0HF5Q06ATI01KFe/0H61P06=SH`1IFET0Fe]K06IVIP1PH600EEEE069RHP1I
FET0H61P0P1NGUh0301FEUH0E5AD05UIF@1LG5`0De=C05mOG`1EEED0F5QH05IFEP1IFET0HF5Q05IF
EP80Fe]K00D0G5aL05mOG`1HF5P0FEUI05MGE`0205iNGP0405UIF@1KFe/0EUIF05EEE@80FEUI00H0
Fe]K05iNGP1LG5`0FEUI05]KF`1JFUX205IFEP0605iNGP1HF5P0GEeM05iNGP1HF5P0FEUI0P1NGUh0
1@1@D500E5AD05EEE@1FEUH0De=C01L000001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0
fMWI00<0fMWI00T0c/k>065QH@1IFET0IfMW05aLG01SHf<0HF5Q05]KF`1/K6`00P1NGUh02@1QHF40
GUiN05aLG01SHf<0IVIV05aLG01TI6@0JFUY06ATI00306=SH`0905mOG`1VIVH0GUiN05mOG`1YJFT0
Fe]K061PH01RHV80Hf=S0080H61P01`0HF5Q06IVIP1NGUh0G5aL06][J`1OGel0GEeM05YJFP1LG5`0
I6AT05aLG01DE5@0GemO065QH@1HF5P0H61P05]KF`1UIFD0GemO06UYJ@1QHF40I6AT065QH@1XJ6P0
IVIV06][J`1LG5`0Hf=S0`1TI6@0201OGel0H61P069RHP1TI6@0J6QX06=SH`1QHF40H61P0P1SHf<0
2P1RHV80HF5Q05aLG01TI6@0J6QX06ATI01KFe/0H61P06IVIP1XJ6P2065QH@80H61P00d0Hf=S065Q
H@1IFET0GemO05]KF`1VIVH0IfMW06ATI01MGEd0J6QX061PH01QHF40J6QX0080I6AT04L0J6QX06MW
I`1XJ6P0J6QX06MWI`1TI6@0Jf][06QXJ01YJFT0IFEU06=SH`1VIVH0H61P06IVIP1XJ6P0IVIV06EU
I@1TI6@0Hf=S06IVIP1LG5`0IFEU06YZJP1SHf<0IFEU06UYJ@1RHV80KFe]06IVIP1RHV80IFEU06QX
J01YJFT0IVIV06UYJ@1XJ6P0IFEU06ATI01WIfL0IVIV06MWI`1[Jf/0IFEU06][J`1/K6`0IVIV05mO
G`1SHf<0I6AT06=SH`1XJ6P0GUiN06IVIP1WIfL0G5aL06=SH`1TI6@0IVIV06ATI01QHF40H61P06MW
I`1XJ6P0HF5Q06EUI@1PH600G5aL06][J`1XJ6P0GemO05UIF@02061PH00L06=SH`1HF5P0GUiN05QH
F01KFe/0G5aL05UIF@1UIFD0IVIV06][J`1VIVH0JVYZ069RHP1XJ6P0H61P06MWI`1QHF40Hf=S06EU
I@1LG5`0I6AT06][J`1NGUh0GemO05aLG01NGUh0F5QH04U9B@80000001007QhN06=SH`1PH600GUiN
05YJFP1QHF40G5aL06=SH`1QHF40I6AT06EUI@1TI6@0GUiN061PH01JFUX0H61P0P1LG5`03@1OGel0
GUiN065QH@1QHF40GUiN05aLG01NGUh0G5aL06MWI`1TI6@0HV9R05]KF`1NGUh00P1LG5`00`1NGUh0
F5QH05UIF@0205YJFP0A05MGE`1HF5P0Fe]K061PH01NGUh0Fe]K05UIF@1JFUX0EUIF065QH@1NGUh0
Fe]K05UIF@1BDU80EeMG05]KF`1HF5P00P1NGUh00`1GEeL0EUIF05UIF@0205]KF`0705QHF01JFUX0
FEUI05MGE`1MGEd0EUIF05eMG@0305]KF`0<06QXJ01GEeL0G5aL05iNGP1OGel0F5QH05EEE@1JFUX0
G5aL05IFEP1EEED0H61P5`0000060=WIf@4000000@3IfMT00080fMWI0P0000040=WIf@800000103I
fMT2000000H0fMWI00<000000=WIf@3IfMT00`3IfMT01P3>c/h0Hf=S06YZJP1NGUh0JFUY05aLG080
H61P00X0IFEU05mOG`1NGUh0F5QH05iNGP1OGel0Hf=S05iNGP1PH600Jf][0P1TI6@06@1SHf<0I6AT
06IVIP1TI6@0IfMW05eMG@1WIfL0IVIV05mOG`1PH600JVYZ069RHP1VIVH0GUiN06=SH`1TI6@0H61P
05mOG`1PH600GUiN05mOG`1NGUh0H61P05UIF@1LG5`00P1PH600501HF5P0Fe]K069RHP1QHF40EeMG
06][J`1EEED0Fe]K06UYJ@1WIfL0G5aL061PH01NGUh0IfMW061PH01UIFD0GemO06QXJ01PH600Hf=S
0P1NGUh01P1LG5`0JVYZ061PH01PH600Ng]k06MWI`80HF5Q01D0H61P06IVIP1SHf<0GEeM06ATI01O
Gel0IFEU06=SH`1MGEd0GUiN06=SH`1XJ6P0H61P06QXJ01QHF40I6AT06=SH`1NGUh0J6QX065QH@1Z
JVX00P1QHF401`1VIVH0JFUY06UYJ@1YJFT0IfMW05iNGP1XJ6P00P1VIVH03@1UIFD0KVi^06ATI01R
HV80JFUY06EUI@1RHV80IVIV065QH@1XJ6P0HV9R071`L01SHf<00P1XJ6P02P1UIFD0IVIV06EUI@1O
Gel0Hf=S06ATI01XJ6P0K6a/06MWI`1VIVH206EUI@0705aLG01VIVH0GUiN06QXJ01SHf<0JFUY06QX
J002069RHP0E06QXJ01^KVh0IVIV06i^KP1TI6@0IFEU065QH@1RHV80IVIV06QXJ01ZJVX0JFUY06AT
I01OGel0H61P06EUI@1[Jf/0IFEU06=SH`1UIFD0JFUY0080I6AT01<0IFEU061PH01QHF40IfMW06=S
H`1KFe/0FEUI061PH01MGEd0Fe]K05iNGP1QHF40H61P05IFEP1RHV80HF5Q05iNGP1VIVH0GEeM0080
Hf=S00L0H61P065QH@1XJ6P0HF5Q06=SH`1QHF40H61P0080HF5Q0180GUiN069RHP1SHf<0Fe]K069R
HP1QHF40E5AD000000030`<0EEEE05QHF01NGUh0G5aL061PH01LG5`0HF5Q05aLG01RHV8205]KF`0@
05mOG`1NGUh0GUiN05]KF`1MGEd0IVIV065QH@1JFUX0GUiN069RHP1MGEd0FUYJ05iNGP1MGEd0G5aL
05eMG@80Fe]K01@0H61P05iNGP1SHf<0HF5Q05aLG01MGEd0GUiN05]KF`1FEUH0FUYJ05ADE01KFe/0
FEUI05]KF`1HF5P0G5aL061PH01KFe/0FEUI05YJFP80E5AD00L0GEeM05IFEP1NGUh0De=C05]KF`1D
E5@0FEUI0080EUIF00X0HF5Q05IFEP1HF5P0FUYJ05QHF01LG5`0EUIF06EUI@1MGEd0GemO0P1IFET0
0`1LG5`0FEUI05]KF`0205ADE00405YJFP1LG5`0FEUI05ADE080FEUI00<0F5QH0000000000005@00
00060=WIf@4000000@3IfMT000050=WIf@000000fMWI0=WIf@0000000P3IfMT010000000fMWI0=WI
f@0000020=WIf@040000003IfMT0fMWI000000D0fMWI00<000000=WIf@3IfMT00`3IfMT0103De=@0
H61P065QH@1YJFT205iNGP0L06IVIP1NGUh0IfMW05mOG`1QHF40Hf=S061PH01SHf<0HF5Q061PH01O
Gel0HV9R06ATI01QHF40Hf=S061PH01LG5`0IVIV06MWI`1RHV80GemO065QH@1TI6@0GUiN05eMG@1T
I6@0H61P065QH@80I6AT00H0J6QX05iNGP1OGel0I6AT06=SH`1RHV82065QH@03069RHP1PH600GemO
0080HV9R00`0I6AT06EUI@1PH600HF5Q06=SH`1PH600Hf=S061PH01WIfL0GUiN05mOG`1KFe/206=S
H`08065QH@1VIVH0IVIV06IVIP1/K6`0J6QX061PH01LG5`206IVIP03061PH01KFe/0G5aL0080GUiN
00@0Hf=S06IVIP1VIVH0H61P0P1XJ6P01P1TI6@0HF5Q069RHP1XJ6P0GemO06ATI080IVIV00/0HV9R
06IVIP1SHf<0GemO06EUI@1SHf<0LG5a071`L01PH600J6QX06][J`0206QXJ00[06IVIP1UIFD0Hf=S
06a/K01ZJVX0IVIV06=SH`1]KFd0HV9R06ATI01WIfL0I6AT06=SH`1WIfL0Jf][06QXJ01TI6@0K6a/
06][J`1QHF40IfMW06ATI01YJFT0K6a/061PH01RHV80Jf][05eMG@1WIfL0IVIV06EUI@1SHf<0IfMW
06QXJ01PH600K6a/06=SH`1NGUh0IVIV061PH01VIVH0Jf][06ATI00306QXJ00506ATI01RHV80K6a/
06EUI@1_Kfl00P1TI6@0201WIfL0IVIV05]KF`1OGel0IVIV069RHP1PH600HV9R0P1VIVH02@1LG5`0
H61P061PH01RHV80H61P05iNGP1LG5`0H61P065QH@02061PH00X05iNGP1RHV80Fe]K05iNGP1TI6@0
IfMW05YJFP1QHF40H61P06UYJ@1TI6@0IfMW06UYJ@1SHf<0IVIV06MWI`1TI6@0H61P05eMG@1TI6@0
GemO06ATI01NGUh0Hf=S05aLG01SHf<0HF5Q05iNGP1JFUX0GUiN06MWI`1QHF40I6AT06UYJ@1PH600
I6AT069RHP1SHf<0I6AT06IVIP80G5aL00@0IFEU05aLG01TI6@0HF5Q0P1KFe/03P1XJ6P0HV9R061P
H01QHF40GEeM06ATI01KFe/0GEeM05UIF@1TI6@0GUiN05YJFP1PH600GUiN0P1LG5`07`1HF5P0GUiN
05QHF01IFET0G5aL05QHF01IFET0GemO05ADE01MGEd0Fe]K05iNGP1IFET0H61P05UIF@1LG5`0FUYJ
05iNGP1KFe/0EeMG059BDP1HF5P0E5AD05UIF@1KFe/0FUYJ05iNGP1IFET0Fe]K05iNGP1IFET00P1L
G5`01P1VIVH0H61P061PH01IFET0G5aL05]KF`80G5aL00D0Fe]K05mOG`1FEUH0EUIF05]KF`0205QH
F1L000001P3IfMT100000040fMWI00040=WIf@040000003IfMT0fMWI00000080fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@030=WIf@<000000`3IfMT0203>c/h0HF5Q065QH@1M
GEd0GemO06=SH`1TI6@0Hf=S0P1PH6003`1QHF40F5QH06ATI01UIFD0HF5Q06MWI`1OGel0GUiN06QX
J01LG5`0HV9R06ATI01PH600JFUY05YJFP0206ATI00<06=SH`1ZJVX0H61P06QXJ01LG5`0GUiN069R
HP1KFe/0Hf=S06ATI01QHF40H61P0`1LG5`02@1WIfL0I6AT06=SH`1QHF40HV9R06EUI@1SHf<0GEeM
06QXJ00205iNGP0906ATI01OGel0GemO06IVIP1TI6@0GUiN06IVIP1QHF40GemO0080I6AT00l0GUiN
06YZJP1QHF40GUiN06ATI01RHV80HF5Q06ATI01QHF40Fe]K06QXJ01TI6@0GemO06IVIP1WIfL00P1P
H6004P1NGUh0HF5Q065QH@1NGUh0HF5Q05aLG01UIFD0G5aL05eMG@1VIVH0H61P06MWI`1TI6@0H61P
06IVIP1NGUh0JFUY06QXJ080I6AT00/0JVYZ06][J`1VIVH0IVIV06MWI`1TI6@0IfMW06UYJ@1VIVH0
Hf=S06a/K00206UYJ@0L06EUI@1RHV80J6QX06][J`1VIVH0GUiN06ATI01XJ6P0Hf=S06MWI`1SHf<0
Jf][06IVIP1/K6`0IFEU069RHP1PH600GemO06IVIP1YJFT0GemO06EUI@1VIVH0JFUY06YZJP1[Jf/0
IFEU06UYJ@80J6QX00<0KVi^06QXJ01/K6`00P1XJ6P06P1TI6@0HF5Q06QXJ01WIfL0JFUY06EUI@1Q
HF40J6QX06EUI@1IFET0IVIV06MWI`1LG5`0J6QX065QH@1SHf<0GUiN06IVIP1QHF40Hf=S05iNGP1H
F5P0GEeM065QH@1KFe/0GemO0P1MGEd01@1OGel0HV9R06=SH`1VIVH0I6AT0080Hf=S00d0IFEU05aL
G01NGUh0G5aL06QXJ01UIFD0J6QX06IVIP1TI6@0IfMW06IVIP1XJ6P0HV9R0080JVYZ00<0FEUI06=S
H`1QHF400P1OGel01`1QHF40H61P06QXJ01HF5P0Hf=S05iNGP1PH6000P1IFET01@1VIVH0H61P05mO
G`1NGUh0H61P0080GUiN0180HF5Q06=SH`1PH600GUiN061PH01QHF40GUiN06=SH`1NGUh0HF5Q06AT
I01NGUh0FEUI05]KF`1IFET0H61P05aLG01QHF4205aLG00405YJFP1FEUH0EeMG05eMG@80Fe]K00@0
GUiN05YJFP1FEUH0F5QH0P1KFe/06P1HF5P0FEUI05ADE01HF5P0GEeM05IFEP1JFUX0HV9R05IFEP1I
FET0Fe]K05eMG@1IFET0Fe]K05YJFP1HF5P0FEUI05mOG`1MGEd0EeMG05QHF01PH600FEUI05YJFP1L
G5`0De=C0P1PH6002`1NGUh0FUYJ05aLG01DE5@0FEUI05YJFP1FEUH0GUiN05QHF01ADE40EeMG01L0
0000103IfMT300000040fMWI00020=WIf@8000000`3IfMT010000000fMWI0=WIf@0000020=WIf@04
0000003IfMT0fMWI000000D0fMWI00<000000=WIf@3IfMT00`3IfMT00`3@d=00HV9R06ATI00206AT
I008065QH@1PH600H61P06QXJ01OGel0Hf=S06ATI01PH60206ATI00?069RHP1VIVH0Fe]K06EUI@1R
HV80Hf=S06MWI`1ZJVX0HF5Q06ATI01XJ6P0HF5Q06=SH`1XJ6P0IfMW00<0IVIV00<0JVYZ06=SH`1T
I6@00P1VIVH09@1SHf<0HF5Q05iNGP1VIVH0Hf=S06EUI@1QHF40GEeM06ATI01WIfL0HF5Q06=SH`1G
EeL0HV9R06IVIP1LG5`0Hf=S06IVIP1QHF40GEeM06ATI01PH600I6AT06QXJ01TI6@0IFEU061PH01N
GUh0J6QX06IVIP1QHF40IVIV065QH@1PH600IfMW05iNGP1XJ6P00P1TI6@03@1MGEd0I6AT061PH01V
IVH0HV9R06QXJ01KFe/0I6AT06QXJ01TI6@0Hf=S069RHP1SHf<00P1XJ6P04P1NGUh0HV9R06IVIP1W
IfL0H61P06UYJ@1XJ6P0Hf=S06UYJ@1VIVH0HF5Q06EUI@1YJFT0J6QX065QH@1WIfL0KFe]06EUI@@0
IVIV01`0J6QX075aL@1XJ6P0J6QX06IVIP1SHf<0IfMW06=SH`1XJ6P0I6AT06=SH`1UIFD0H61P06UY
J@1SHf<0IFEU06][J`1VIVH0GemO06ATI01KFe/0HF5Q06=SH`1YJFT0J6QX06IVIP1YJFT0IFEU0P1X
J6P04`1QHF40IVIV065QH@1YJFT0IVIV06YZJP1TI6@0HF5Q06][J`1_Kfl0IVIV06=SH`1VIVH0J6QX
06ATI01bLW80IFEU06IVIP1LG5`00P1UIFD06@1LG5`0K6a/06IVIP1MGEd0I6AT06=SH`1UIFD0Hf=S
05eMG@1JFUX0GEeM06=SH`1QHF40JFUY06IVIP1TI6@0IfMW06UYJ@1TI6@0H61P05mOG`1TI6@0HF5Q
06MWI`1PH6000P1QHF402`1PH600HF5Q06MWI`1TI6@0H61P06QXJ01NGUh0JVYZ06UYJ@1QHF40I6AT
0080IVIV00<0HF5Q05iNGP1SHf<00P1PH600301RHV80HF5Q05iNGP1SHf<0GUiN06=SH`1YJFT0Hf=S
05iNGP1HF5P0GUiN05eMG@80G5aL03L0GUiN061PH01SHf<0I6AT05mOG`1PH600Hf=S05iNGP1VIVH0
EEEE05]KF`1NGUh0FEUI05iNGP1OGel0G5aL05]KF`1HF5P0FEUI05mOG`1LG5`0E5AD05QHF01LG5`0
GUiN05]KF`1JFUX0FEUI05YJFP1KFe/0De=C05YJFP1IFET0G5aL05eMG@1OGel0FUYJ05=CD`1GEeL0
E5AD05QHF01DE5@0Fe]K061PH01LG5`0EeMG05iNGP1@D500E5AD05MGE`1IFET0Hf=S05iNGP1HF5P0
Fe]K0080H61P0P1IFET0201NGUh0GemO05IFEP1IFET0H61P05]KF`1MGEd0D51@5`0000060=WIf@40
00000@3IfMT00080fMWI00<000000=WIf@3IfMT00P3IfMT010000000fMWI0=WIf@0000020=WIf@04
0000003IfMT0fMWI000000D0fMWI00<000000=WIf@3IfMT00`3IfMT01@3AdM40IfMW069RHP1TI6@0
IVIV0080I6AT00h0IFEU06ATI01RHV80FEUI05iNGP1PH600HV9R061PH01FEUH0HV9R061PH01TI6@0
J6QX065QH@80GUiN01/0JFUY06ATI01PH600Hf=S06IVIP1QHF40HV9R065QH@1ZJVX0J6QX05iNGP1S
Hf<0H61P06MWI`1QHF40J6QX069RHP1XJ6P0H61P06QXJ01TI6@0IVIV05iNGP1LG5`0HF5Q06IVIP1S
Hf<00P1QHF401@1MGEd0J6QX06=SH`1UIFD0I6AT0080Hf=S00P0I6AT05eMG@1NGUh0K6a/06=SH`1V
IVH0Hf=S06ATI080J6QX00/0Hf=S05]KF`1VIVH0I6AT061PH01SHf<0H61P05]KF`1QHF40GemO06MW
I`03061PH00R06=SH`1VIVH0GemO06MWI`1XJ6P0HV9R05iNGP1VIVH0IFEU06IVIP1RHV80Hf=S05iN
GP1XJ6P0H61P05]KF`1PH600IVIV06MWI`1[Jf/0KVi^06MWI`1SHf<0KFe]06MWI`1QHF40K6a/06QX
J01[Jf/0JFUY06QXJ01QHF40J6QX06EUI@80IVIV00<0JFUY05iNGP1YJFT00P1[Jf/04@1QHF40Jf][
06ATI01VIVH0I6AT06=SH`1UIFD0Jf][06MWI`1VIVH0Hf=S06QXJ01PH600GUiN069RHP1WIfL0K6a/
0080JFUY00/0HF5Q06][J`1VIVH0Hf=S075aL@1[Jf/0Hf=S06m_K`1ZJVX0JFUY06=SH`0206][J`0P
06=SH`1[Jf/0J6QX069RHP1XJ6P0I6AT061PH01SHf<0HF5Q06EUI@1VIVH0I6AT069RHP1KFe/0HV9R
06EUI@1SHf<0FEUI05eMG@1PH600IVIV069RHP1QHF40IfMW06ATI01LG5`0H61P065QH@1OGel0HV9R
06=SH`1PH60206MWI`0606IVIP1TI6@0I6AT069RHP1QHF40Jf][0P1TI6@01`1XJ6P0Hf=S06=SH`1V
IVH0IfMW061PH01TI6@00P1UIFD08@1NGUh0Fe]K05]KF`1LG5`0EUIF065QH@1KFe/0GEeM05UIF@1O
Gel0GEeM06MWI`1IFET0IFEU06=SH`1QHF40G5aL061PH01NGUh0G5aL06=SH`1NGUh0HF5Q05eMG@1K
Fe/0H61P05iNGP1VIVH0IFEU061PH01LG5`0FUYJ05eMG@0205]KF`0?06ATI01IFET0H61P05aLG01H
F5P0De=C05MGE`1NGUh0G5aL05YJFP1IFET0EeMG05EEE@1@D500F5QH0080G5aL00H0FEUI05IFEP1S
Hf<0Fe]K05IFEP1GEeL205IFEP0=05]KF`1CDe<0E5AD05iNGP1GEeL0F5QH05iNGP1IFET0H61P05mO
G`1IFET0F5QH05YJFP0305aLG00805]KF`1HF5P0EeMG05UIF@1KFe/0G5aL05UIF@1@D50G000000H0
fMWI0@0000010=WIf@000P3IfMT3000000<0fMWI0P0000040=WIf@8000001P3IfMT00`000000fMWI
0=WIf@040=WIf@0:065QH@1LG5`0Hf=S06IVIP1TI6@0JFUY065QH@1VIVH0HF5Q06=SH`80H61P01h0
GemO06EUI@1TI6@0HV9R061PH01XJ6P0I6AT069RHP1/K6`0J6QX06=SH`1LG5`0I6AT065QH@1TI6@0
IFEU06QXJ01[Jf/0IVIV06MWI`1VIVH0I6AT06IVIP1RHV80IFEU06ATI01VIVH0IfMW061PH01OGel2
069RHP0<06IVIP1SHf<0K6a/05iNGP1UIFD0GemO06ATI01[Jf/0GEeM06=SH`1NGUh0KVi^0P1SHf<0
4P1TI6@0GUiN06IVIP1RHV80GemO06EUI@1TI6@0K6a/06EUI@1OGel0HF5Q06UYJ@1^KVh0HV9R06AT
I01XJ6P0HF5Q05eMG@80J6QX01@0IFEU06ATI01RHV80IVIV069RHP1YJFT0I6AT065QH@1TI6@0FEUI
061PH01XJ6P0JFUY06EUI@1VIVH0I6AT06EUI@1ZJVX0IfMW06UYJ@80I6AT00H0IVIV06ATI01[Jf/0
JVYZ071`L01ZJVX206a/K080IVIV00P0J6QX06][J`1YJFT0IVIV06QXJ01QHF40I6AT06IVIP80J6QX
00`0Hf=S06UYJ@1YJFT0K6a/06ATI01ZJVX0J6QX061PH01QHF40K6a/061PH01VIVH206ATI00C06][
J`1ZJVX0H61P06][J`1TI6@0Hf=S06i^KP1XJ6P0HF5Q069RHP1TI6@0HF5Q06MWI`1aLG40IVIV06UY
J@1WIfL0IFEU065QH@0206=SH`0706][J`1ZJVX0IfMW06MWI`1RHV80FUYJ06QXJ00205mOG`0G069R
HP1SHf<0IVIV069RHP1VIVH0IFEU06YZJP1SHf<0HV9R05UIF@1KFe/0GUiN069RHP1IFET0HF5Q05iN
GP1LG5`0I6AT061PH01HF5P0HF5Q05eMG@1[Jf/00P1VIVH3065QH@0=06QXJ01UIFD0HF5Q06UYJ@1]
KFd0J6QX06ATI01UIFD0GEeM06ATI01VIVH0GEeM05iNGP0206ATI00505aLG01SHf<0G5aL05iNGP1M
GEd00`1OGel02`1PH600IVIV06ATI01YJFT0IFEU05iNGP1UIFD0HF5Q06ATI01LG5`0Hf=S0080G5aL
00<0FEUI05aLG01MGEd00P1PH6001`1QHF40GEeM05aLG01NGUh0GEeM061PH01LG5`00P1HF5P01@1K
Fe/0G5aL05QHF01IFET0HF5Q0080H61P02T0FUYJ05QHF01HF5P0G5aL05UIF@1JFUX0Fe]K069RHP1H
F5P0E5AD05iNGP1HF5P0FUYJ05aLG01HF5P0GEeM05YJFP1QHF40EeMG05QHF01QHF40GUiN05QHF01P
H600HV9R05UIF@1MGEd0EUIF05eMG@1NGUh0FUYJ05aLG01HF5P0FEUI05iNGP1FEUH0F5QH05]KF`1G
EeL0De=C059BDP0G000000H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0:
0<C4a01MGEd0Hf=S06=SH`1NGUh0IfMW06=SH`1VIVH0Hf=S061PH080F5QH00d0Hf=S06ATI01YJFT0
H61P06EUI@1RHV80Hf=S06m_K`1UIFD0IfMW06EUI@1LG5`0J6QX0080IVIV00T0JFUY06=SH`1QHF40
Hf=S06a/K01VIVH0Hf=S06IVIP1XJ6P00P1WIfL2069RHP0906ATI01LG5`0I6AT05iNGP1LG5`0Hf=S
06QXJ01TI6@0FUYJ0080IfMW00@0H61P05eMG@1UIFD0GemO0P1VIVH07@1PH600I6AT06EUI@1/K6`0
IVIV06][J`1VIVH0JFUY06EUI@1XJ6P0IVIV06MWI`1SHf<0I6AT069RHP1VIVH0HV9R06EUI@1WIfL0
HF5Q06ATI01XJ6P0JFUY06QXJ01UIFD0HF5Q061PH01LG5`0H61P0080HV9R01L0HF5Q06=SH`1TI6@0
IVIV06ATI01QHF40J6QX06EUI@1WIfL0K6a/06QXJ01RHV80IfMW06i^KP1XJ6P0IfMW06UYJ@1WIfL0
Jf][06UYJ@1[Jf/0JFUY06][J`0206ATI004065QH@1WIfL0Hf=S06QXJ080IfMW00d0Jf][06UYJ@1P
H600J6QX06=SH`1XJ6P0HF5Q061PH01SHf<0IfMW061PH01QHF40I6AT0080IfMW00l0GemO06MWI`1Y
JFT0GUiN06][J`1ZJVX0KFe]06UYJ@1TI6@0IfMW06ATI01^KVh0LG5a06][J`1SHf<00P1XJ6P05P1V
IVH0JVYZ06][J`1]KFd0H61P06UYJ@1^KVh0Jf][06m_K`1YJFT0I6AT06QXJ01[Jf/0J6QX06=SH`1Q
HF40JFUY06ATI01VIVH0JFUY06QXJ01VIVH205iNGP0N05mOG`1KFe/0JFUY05iNGP1XJ6P0IFEU065Q
H@1SHf<0GemO05UIF@1QHF40IFEU065QH@1RHV80IfMW06EUI@1TI6@0IFEU06e]K@1XJ6P0I6AT06YZ
JP1VIVH0HV9R06ATI01PH600I6AT06][J`1MGEd0H61P0P1SHf<00`1PH600GUiN05QHF00305iNGP<0
HF5Q00X0GUiN06=SH`1PH600HF5Q05mOG`1VIVH0GemO05iNGP1VIVH0H61P0P1LG5`00`1UIFD0GUiN
05iNGP0205UIF@0A06EUI@1RHV80Hf=S05mOG`1KFe/0GEeM05aLG01MGEd0G5aL061PH01NGUh0G5aL
05IFEP1MGEd0FUYJ061PH01EEED00P1JFUX205IFEP0405YJFP1LG5`0E5AD05QHF0<0FEUI01h0F5QH
05eMG@1KFe/0E5AD061PH01LG5`0FEUI05MGE`1LG5`0FEUI05]KF`1JFUX0GEeM065QH@1HF5P0E5AD
05]KF`1IFET0F5QH05IFEP1LG5`0D51@05MGE`1TI6@0F5QH05IFEP1NGUh0GEeM05UIF@1JFUXG0000
00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0:0=GEe@1IFET0I6AT065Q
H@1RHV80I6AT065QH@1TI6@0HV9R06EUI@<0HF5Q01T0IfMW05iNGP1OGel0I6AT061PH01TI6@0J6QX
06EUI@1TI6@0JFUY06][J`1ZJVX0Jf][06=SH`1YJFT0HF5Q06QXJ01/K6`0J6QX06i^KP1SHf<0I6AT
06MWI`1SHf<0HF5Q00<0Hf=S01/0JFUY065QH@1PH600JVYZ06MWI`1RHV80H61P065QH@1PH600G5aL
05]KF`1SHf<0IVIV061PH01SHf<0IVIV061PH01YJFT0HV9R05UIF@1QHF40Fe]K06ATI01SHf<0Fe]K
06MWI`1SHf<00P1TI6@03`1UIFD0JVYZ05eMG@1PH600Hf=S06][J`1PH600HF5Q06MWI`1SHf<0I6AT
065QH@1YJFT0Hf=S065QH@0206IVIP0306EUI@1RHV80IVIV0080JFUY00X0HV9R06IVIP1RHV80I6AT
06=SH`1aLG40I6AT06IVIP1SHf<0IVIV0P1YJFT406][J`0:06i^KP1TI6@0IfMW06i^KP1SHf<0IVIV
065QH@1SHf<0IVIV06QXJ080IFEU01T0Jf][06MWI`1UIFD0J6QX069RHP1PH600JFUY061PH01XJ6P0
K6a/06QXJ01WIfL0IFEU05mOG`1XJ6P0I6AT065QH@1PH600J6QX06EUI@1TI6@0JVYZ06i^KP1YJFT0
IfMW0080I6AT00`0IVIV06MWI`1XJ6P0HF5Q06i^KP1/K6`0J6QX06YZJP1YJFT0IVIV06ATI01VIVH2
06=SH`0906UYJ@1RHV80Jf][06QXJ01ZJVX0I6AT06MWI`1YJFT0IFEU0080H61P00D0I6AT061PH01P
H600IFEU05]KF`03061PH00L069RHP1HF5P0GUiN06=SH`1NGUh0H61P065QH@1WIfL0IVIV065QH@1V
IVH0HF5Q06ATI01[Jf/0Hf=S06MWI`1VIVH0J6QX06EUI@1NGUh0HV9R05aLG01XJ6P0HF5Q06QXJ01S
Hf<0I6AT065QH@80H61P00D0IfMW05iNGP1SHf<0HV9R06EUI@0305iNGP0Y065QH@1SHf<0I6AT05]K
F`1PH600GUiN06MWI`1PH600GUiN05]KF`1NGUh0G5aL05UIF@1PH600Fe]K061PH01QHF40EeMG05QH
F01LG5`0F5QH05iNGP1FEUH0Fe]K05MGE`1JFUX0FEUI05EEE@1QHF40FEUI05iNGP1HF5P0HF5Q05IF
EP1LG5`0FUYJ055AD@1IFET0EeMG05QHF01ADE400P1NGUh01`1KFe/0FEUI05ADE01FEUH0GEeM05QH
F01GEeL00P1PH6005@1FEUH0GUiN05UIF@1QHF40Fe]K05=CD`1KFe/0EeMG05UIF@1HF5P0HF5Q05IF
EP1KFe/0H61P05mOG`1IFET0G5aL05iNGP1HF5P0GUiN05aLG00G000000H0fMWI0@0000010=WIf@00
5P3IfMT00`000000fMWI0=WIf@030=WIf@060<k>cP1PH600IVIV05mOG`1TI6@0H61P0P1TI6@07P1N
GUh0JFUY06QXJ01SHf<0IFEU06ATI01RHV80G5aL06QXJ01SHf<0JVYZ06=SH`1NGUh0I6AT06=SH`1N
GUh0I6AT065QH@1SHf<0Fe]K06ATI01WIfL0Hf=S06EUI@1TI6@0J6QX06EUI@1RHV80Hf=S06IVIP80
I6AT00T0H61P05iNGP1QHF40HF5Q05iNGP1RHV80H61P05]KF`1VIVH00P1QHF4206EUI@0705iNGP1Y
JFT0Hf=S05iNGP1QHF40I6AT06YZJP0206=SH`80IfMW00D0Hf=S06IVIP1VIVH0IFEU06MWI`0206AT
I00_05mOG`1XJ6P0IfMW06ATI01RHV80I6AT06IVIP1WIfL0K6a/06ATI01WIfL0I6AT065QH@1SHf<0
K6a/061PH01QHF40H61P06IVIP1TI6@0HF5Q06IVIP1XJ6P0HF5Q06UYJ@1[Jf/0J6QX065QH@1WIfL0
I6AT06e]K@1WIfL0J6QX06MWI`1[Jf/0KFe]06ATI01UIFD0Jf][06i^KP1WIfL0IVIV06QXJ01LG5`0
Hf=S06ATI01bLW800P1TI6@06P1RHV80K6a/06][J`1TI6@0KVi^06UYJ@1XJ6P0H61P06QXJ01/K6`0
Hf=S06UYJ@1XJ6P0IFEU06YZJP1YJFT0J6QX06IVIP1]KFd0Hf=S06QXJ01]KFd0I6AT06QXJ01OGel0
H61P0P1_Kfl0501TI6@0IVIV06UYJ@1VIVH0I6AT06UYJ@1PH600Hf=S06QXJ01[Jf/0JFUY06MWI`1V
IVH0I6AT06=SH`1PH600JVYZ06ATI01UIFD0J6QX0`1QHF40301NGUh0I6AT061PH01UIFD0HV9R05UI
F@1NGUh0H61P05iNGP1LG5`0HV9R06ATI080Fe]K00<0HF5Q061PH01NGUh00P1TI6@00`1SHf<0JFUY
06UYJ@0206QXJ005069RHP1WIfL0Hf=S05iNGP1QHF400P1SHf<05@1VIVH0I6AT065QH@1NGUh0I6AT
069RHP1NGUh0GemO05iNGP1SHf<0HV9R065QH@1VIVH0I6AT06QXJ01JFUX0HF5Q069RHP1TI6@0Hf=S
06IVIP02061PH080GUiN00@0GEeM069RHP1PH600GEeM0P1OGel05`1MGEd0HF5Q05eMG@1LG5`0Fe]K
05mOG`1IFET0H61P05iNGP1OGel0Fe]K065QH@1NGUh0GEeM05UIF@1DE5@0FEUI05]KF`1PH600EUIF
05MGE`1HF5P0Hf=S0080G5aL00h0FEUI05QHF01EEED0De=C05aLG01RHV80EeMG05QHF01KFe/0GEeM
05UIF@1KFe/0EUIF05YJFP80G5aL00H0EEEE06=SH`1NGUh0G5aL05eMG@1@D50205iNGP0305IFEP1C
De<0G5aL0080Fe]K00@0GUiN05QHF01IFET0De=C5`0000060=WIf@4000000@3IfMT001H0fMWI00<0
00000=WIf@3IfMT00`3IfMT03P2<S8`0>c/k04A4A010@400?Cdm03@d=00l?3`0?Shn03lo?`0l?3`0
=SHf03Ph>00l?3`0?Cdm0P0i>CT07`0k>c/0>3Ph03Hf=P0n?Sh0=cLg03De=@0o?cl0>SXj03/k>`0f
=SH0>c/k03`l?00i>CT0=SHf03Ph>00n?Sh0?Cdm03`l?011@D40?Shn03Hf=P0X:2P0>c/k03Ph>00g
=cL0>CTi03Lg=`0l?3`0?Cdm03/k>`0n?Sh00P0h>3P01P0o?cl0=cLg04=3@`0m?Cd0>CTi038b<P80
?3`l00`0?Shn03Ti>@0n?Sh0<S8b03@d=00i>CT0>c/k03Ti>@0n?Sh0?3`l03/k>`10@40203`l?00<
03Xj>P0g=cL0>3Ph03Ph>00k>c/0?3`l03/k>`0i>CT0?Cdm03lo?`0h>3P0@4100P0j>SX0200h>3P0
?Cdm03hn?P0l?3`0@d=303Lg=`0l?3`0>c/k0P0h>3P02@0l?3`0?Shn03lo?`0j>SX0@41003dm?@0i
>CT0@41003`l?00203hn?P0:03dm?@0n?Sh0=SHf0410@011@D40A4A403Xj>P0l?3`0@41003hn?P80
?3`l01h0?Shn03lo?`10@400@d=303hn?P11@D40@T9203Ph>00g=cL0?Shn03Lg=`0k>c/0?Shn03Ph
>00i>CT0?Cdm03Ti>@0k>c/0?Shn03Hf=P11@D40?3`l03/k>`11@D40?Cdm03`l?00f=SH0?Cdm03`l
?00i>CT203`l?00[03Ti>@0k>c/0>CTi03dm?@000000>c/k03Hf=P0k>c/0?Cdm0492@P0j>SX0>CTi
03`l?00m?Cd0>CTi03Ph>00m?Cd0>CTi03Ph>00n?Sh0?3`l03Ti>@0m?Cd0>3Ph03Hf=P0a<C40>c/k
03Hf=P0n?Sh0>3Ph02l_;`0g=cL0<C4a03Hf=P0e=CD0>c/k0410@00k>c/0>3Ph03Lg=`0l?3`0>c/k
03hn?P0203Xj>P0G03lo?`0k>c/0?3`l03Xj>P0f=SH0<30`03Xj>P0];Bd0>3Ph03@d=00b<S80=SHf
03`l?00h>3P0?3`l03Ti>@0g=cL0=SHf03@d=00k>c/0>CTi03Ph>00e=CD00P0l?3`02P0h>3P0<c<c
03`l?00a<C40>CTi03Hf=P0d=3@0<S8b03Ph>00a<C4203<c<`0703De=@0d=3@0=SHf03<c<`0h>3P0
<c<c03Lg=`0203De=@0403@d=00a<C40>c/k03<c<`80<S8b00<0<c<c03Ti>@0a<C400P0c<c<04@0_
;bl0;2`/03@d=00`<300<c<c02h^;P0g=cL0=CDe03@d=00_;bl0=CDe02l_;`0c<c<0<30`03<c<`0`
<300<c<c0080<30`0180<c<c02l_;`0a<C40<C4a03<c<`0`<300:b/[034a<@0[:b/0=SHf030`<00c
<c<0=3@d030`<00c<c<0<30`02d];@0f=SH202`/;1L000001P3IfMT100000040fMWI000F0=WIf@03
0000003IfMT0fMWI0?l0fMWIA03IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI0?l0fMWI
A03IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI0?l0fMWIA03IfMT100000040fMWI000F
0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0=P3IfMT00`000000fMWI0=WIf@0f
0=WIf@030000003IfMT0fMWI03H0fMWI00<000000=WIf@3IfMT0=P3IfMT00`000000fMWI0=WIf@0e
0=WIf@030000003IfMT0fMWI0240fMWI0@0000010=WIf@005P3IfMT2000000@0fMWI00<000000=WI
f@3IfMT0203IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WI
f@3IfMT0203IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WI
f@3IfMT0203IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WI
f@3IfMT0203IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WI
f@3IfMT0203IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WI
f@3IfMT0203IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WI
f@3IfMT02@3IfMT200000040fMWI000F0=WIfOl00000B00000010=WIf@00o`3IfMUO0=WIf@00o`3I
fMUO0=WIf@00o`3IfMUO0=WIf@00\
\>"],
  ImageRangeCache->{{{0, 349}, {323.625, 0}} -> {-49.8402, -39.7549, 1.75674, \
1.75674}}]
}, Open  ]],

Cell["\<\
   Now, we see the reduced-image frame. The dust grains have been removed by \
the flat-fielding process, and the overscan region has been removed.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListDensityPlot[workingimage[\([1, 2]\)], Mesh \[Rule] False, 
        ImageSize \[Rule] 350];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 350 350 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.001878 0.0192308 0.001878 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.20703 -0.0125 -9 -9 ]
[.20703 -0.0125 9 0 ]
[.39483 -0.0125 -9 -9 ]
[.39483 -0.0125 9 0 ]
[.58263 -0.0125 -9 -9 ]
[.58263 -0.0125 9 0 ]
[.77043 -0.0125 -9 -9 ]
[.77043 -0.0125 9 0 ]
[.95823 -0.0125 -9 -9 ]
[.95823 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .20703 -18 -4.5 ]
[-0.0125 .20703 0 4.5 ]
[-0.0125 .39483 -18 -4.5 ]
[-0.0125 .39483 0 4.5 ]
[-0.0125 .58263 -18 -4.5 ]
[-0.0125 .58263 0 4.5 ]
[-0.0125 .77043 -18 -4.5 ]
[-0.0125 .77043 0 4.5 ]
[-0.0125 .95823 -18 -4.5 ]
[-0.0125 .95823 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.20703 0 m
.20703 .00625 L
s
[(100)] .20703 -0.0125 0 1 Mshowa
.39483 0 m
.39483 .00625 L
s
[(200)] .39483 -0.0125 0 1 Mshowa
.58263 0 m
.58263 .00625 L
s
[(300)] .58263 -0.0125 0 1 Mshowa
.77043 0 m
.77043 .00625 L
s
[(400)] .77043 -0.0125 0 1 Mshowa
.95823 0 m
.95823 .00625 L
s
[(500)] .95823 -0.0125 0 1 Mshowa
.125 Mabswid
.05679 0 m
.05679 .00375 L
s
.09435 0 m
.09435 .00375 L
s
.13191 0 m
.13191 .00375 L
s
.16947 0 m
.16947 .00375 L
s
.24459 0 m
.24459 .00375 L
s
.28215 0 m
.28215 .00375 L
s
.31971 0 m
.31971 .00375 L
s
.35727 0 m
.35727 .00375 L
s
.43239 0 m
.43239 .00375 L
s
.46995 0 m
.46995 .00375 L
s
.50751 0 m
.50751 .00375 L
s
.54507 0 m
.54507 .00375 L
s
.62019 0 m
.62019 .00375 L
s
.65775 0 m
.65775 .00375 L
s
.69531 0 m
.69531 .00375 L
s
.73287 0 m
.73287 .00375 L
s
.80799 0 m
.80799 .00375 L
s
.84555 0 m
.84555 .00375 L
s
.88311 0 m
.88311 .00375 L
s
.92067 0 m
.92067 .00375 L
s
.99579 0 m
.99579 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .20703 m
.00625 .20703 L
s
[(100)] -0.0125 .20703 1 0 Mshowa
0 .39483 m
.00625 .39483 L
s
[(200)] -0.0125 .39483 1 0 Mshowa
0 .58263 m
.00625 .58263 L
s
[(300)] -0.0125 .58263 1 0 Mshowa
0 .77043 m
.00625 .77043 L
s
[(400)] -0.0125 .77043 1 0 Mshowa
0 .95823 m
.00625 .95823 L
s
[(500)] -0.0125 .95823 1 0 Mshowa
.125 Mabswid
0 .05679 m
.00375 .05679 L
s
0 .09435 m
.00375 .09435 L
s
0 .13191 m
.00375 .13191 L
s
0 .16947 m
.00375 .16947 L
s
0 .24459 m
.00375 .24459 L
s
0 .28215 m
.00375 .28215 L
s
0 .31971 m
.00375 .31971 L
s
0 .35727 m
.00375 .35727 L
s
0 .43239 m
.00375 .43239 L
s
0 .46995 m
.00375 .46995 L
s
0 .50751 m
.00375 .50751 L
s
0 .54507 m
.00375 .54507 L
s
0 .62019 m
.00375 .62019 L
s
0 .65775 m
.00375 .65775 L
s
0 .69531 m
.00375 .69531 L
s
0 .73287 m
.00375 .73287 L
s
0 .80799 m
.00375 .80799 L
s
0 .84555 m
.00375 .84555 L
s
0 .88311 m
.00375 .88311 L
s
0 .92067 m
.00375 .92067 L
s
0 .99579 m
.00375 .99579 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.20703 .99375 m
.20703 1 L
s
.39483 .99375 m
.39483 1 L
s
.58263 .99375 m
.58263 1 L
s
.77043 .99375 m
.77043 1 L
s
.95823 .99375 m
.95823 1 L
s
.125 Mabswid
.05679 .99625 m
.05679 1 L
s
.09435 .99625 m
.09435 1 L
s
.13191 .99625 m
.13191 1 L
s
.16947 .99625 m
.16947 1 L
s
.24459 .99625 m
.24459 1 L
s
.28215 .99625 m
.28215 1 L
s
.31971 .99625 m
.31971 1 L
s
.35727 .99625 m
.35727 1 L
s
.43239 .99625 m
.43239 1 L
s
.46995 .99625 m
.46995 1 L
s
.50751 .99625 m
.50751 1 L
s
.54507 .99625 m
.54507 1 L
s
.62019 .99625 m
.62019 1 L
s
.65775 .99625 m
.65775 1 L
s
.69531 .99625 m
.69531 1 L
s
.73287 .99625 m
.73287 1 L
s
.80799 .99625 m
.80799 1 L
s
.84555 .99625 m
.84555 1 L
s
.88311 .99625 m
.88311 1 L
s
.92067 .99625 m
.92067 1 L
s
.99579 .99625 m
.99579 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .20703 m
1 .20703 L
s
.99375 .39483 m
1 .39483 L
s
.99375 .58263 m
1 .58263 L
s
.99375 .77043 m
1 .77043 L
s
.99375 .95823 m
1 .95823 L
s
.125 Mabswid
.99625 .05679 m
1 .05679 L
s
.99625 .09435 m
1 .09435 L
s
.99625 .13191 m
1 .13191 L
s
.99625 .16947 m
1 .16947 L
s
.99625 .24459 m
1 .24459 L
s
.99625 .28215 m
1 .28215 L
s
.99625 .31971 m
1 .31971 L
s
.99625 .35727 m
1 .35727 L
s
.99625 .43239 m
1 .43239 L
s
.99625 .46995 m
1 .46995 L
s
.99625 .50751 m
1 .50751 L
s
.99625 .54507 m
1 .54507 L
s
.99625 .62019 m
1 .62019 L
s
.99625 .65775 m
1 .65775 L
s
.99625 .69531 m
1 .69531 L
s
.99625 .73287 m
1 .73287 L
s
.99625 .80799 m
1 .80799 L
s
.99625 .84555 m
1 .84555 L
s
.99625 .88311 m
1 .88311 L
s
.99625 .92067 m
1 .92067 L
s
.99625 .99579 m
1 .99579 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
512 string
512 512 8 [512 0 0 512 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4C4A454A494D494E46464D47514E4848504A4D4B464A50474C5048514D4C4E4C474E4A4D
514E4E4E4F4B4F4C4B504B544F534D4F494C4754504A52514B4E504D4E4E4F534B514A4B
4850515351514B484D5052514F4E4D534A524A4F4E5452574C54534E4C4D4F5652585659
525250535253565052514F4F4F4A5254525053505657504D54524D4E504D525253575552
5451545859525251585C5455564E5A584B545B5657575859535556575452585855565057
575552535254555256585957536159555B565956525859575A5C5C5562575C585E5D5455
5B615F535E5E5F5F5C5B5C6161605F625F5A5C6062595F63605E5C6A6463625B5F5B6763
5E6264646B67656B6B6B6B6868636167656766646968626B6D5C616268626467685D5D65
6E6365686166646260616166646366696761676B6962636565625D62616167625B5B6364
6A666158626963605C5F5E6162646B665E61625C59605C5E5C6267655A615E645E5E5E60
666060666364636862585F646066635856595F5B5E5B5B5E585A5857585D5955585E5B54
565258555455575755565D5853545955535354595953574D5B5952544C5549545457524D
55594F585851514A4E4F4D4D524F584D554E50534F51504E4B4E4A4D54535A4F534B5445
55514F4C53524F534D504C504B4B4C4752565052514A51484C4A4A4E4F504D4A494D4A4E
524F4A4D4E4C4B4C
524C4B4F544856504F4D504D4F54535956575750534E5557515755565254554D4F515053
534B5250575150535357575357515358585A565855515458545A57575454555856585756
594D555253545555554F59544F57535555555E54565558545E58555D555857605A575A5A
585657575356575E5C5E5C5E565B54585E58595F5E5E59515B5E55575A5D5B5A5D5C5458
5C60545E5B5C5E58565B596359595D5D60585E595D5E5C5E5C595D55605B5D57625D5F5D
615C5D5B605E5A605E605E5F5B635D5C5F635E605F5F5C62666064636362666761666065
5F665E6764646064676562676765666867666766696B686A67696E6973696B6B646A6A6B
6E69676B676C7172756C786D726D6871716C696D6A6E68746F6F6E706E6A65676C6D6571
6D6D6B686968636F6C62666E6D77666F6D6C706E6A6F6D6872706C65676E69696F68636B
6A6A666965646A65686B65666A63676665666B65676068626769646C64626968665C695F
62616A666A6B686F666A62675F636363625D5D5A5E635F605B5D5E5E64645C6363655763
5D57605B575C5F5E66605C575F5B60545E5B595A58585F625D615C605D5D5A5C5352535F
575C5C5B545157534E55515853545C5757544E5B58565750584E52555B5B5758554F515A
545055585254525956584D585157535351584F535450515557564B534B4F4D534C4F4E4F
5348565751495250
535456535A5B56564F584E515557535655555655545B575C59585E5B595B5B5853565E59
575C57574F575856535A5452575C595855555958545E59545B58575E5E575D5057565A52
6258565C60595A5A5D595E555E5A5B5D605F5E5B535B645A575C5F60615A59615D5D625E
5F5D575E5C5E5C605860635C5B6062575F61585D635C585E5E5E5D665A605C635C5A565D
5E5B595A6358655B6561615E66655F64626564665E65625C6557606464666263675A6165
63615B5A63655E63625B6262625F6861636666646464616568666568676C656D666E6865
696B6A6867666264626E6E6B6B696C696E6A7271716B626F6D666C6D6F6B73716B71726E
6F706C71756C7670757571727274746D736F716F6E6F71746D70717875727172786D7377
6D757274726F6B70716F62746E766D7A75766F72746F707376736A6C75716C786B6C7471
676A726B696E69756A6F6E6D6A716D6870696A6471686D6B6C64686D6A696767606F6868
6F676A6E74706E7071666C666B6A66686362646B68656765635D685C605F656463646260
64635F5F665E5F645F636563585F655B5E5E6059625A625E5A6160605C585B565D5C5759
5860645A5C5A5B595B5B5C575B515857575D545B605F6158555C5E60605B5A5E5B55535E
585F59575A5B5D555F54575C5858524E5D5A565951525059544D50595657524A50514F57
55595A5E56545552
5A4C51555659545C5855585C4C525A5855575A565657595C59625C5C58615A5C575E5858
575B595F56575B5C5E585B5C5C60565858585A666160595F5A5B5A5D6258625D615F5D58
5D596359565C615E5B5A585A605F686161596267605E5960675E5A61625C5D605F626368
67665D6065606163645D5D61636264656462625C655C64615D5B5A5A635A575861626460
61655D64626A5C5E616A605F666C625F6B666F6D6662685C645F68655C64696261666A65
696361676463656569616B626268686A686A686C666866666E6864646D6E70696F6C6769
6E666B686E676A666D716E6B6F6A6C676F706D6F6E6A737175736F6F68726F6B7373726F
7074727B72817877747971767E7270726F707678707173727C727175727472747372726E
6F72746A756B787173757173717275787B7D707C76747B6E6B6C7378736E6D77756F7378
766E6E6D73707471746E6A6B6E7073686C69696B747066736E746D6E69716F6D6B73716F
6D6961726A6F6F6D646E656C65666A6A68656B6A66656C67665D686362676468676C5D60
64646562626167625C606663695F66636269605F635C6159605B60625969616567605C60
57645C5F5E595A5F585E626162615D5D5F5B5A5E585662585A565D5C595D595F575C5A57
5C5A59585E5A565B555D5F5F5A5D5E5A5C58545556545B5C534F52515756595A5B5A5954
585C545255535454
615B595A5B5B5959565F5B5E6160605A565E5D575C5B595C5755645F606356595A635D62
5D5D625C5C5A5B5D5A5D5B59646063605F6060605A61605F5A6261605C59605E585F6559
60585A5C5C5C635E5B5F596961605F5E61666367626466645A5E62675F6162686468665E
646261635F65665B625F5F606668646266666863686364626262625D67666365615F5F68
646164686466616461616461636368686D686A6D696A6467676B67666567656B616B6D66
696D6B646661666C6866676964606B6964656E6B697069686571736D6D6C696A696F7375
726E6B7170716F777271716C736B6E6F71737374706E736E6B72787373726F7470767971
6F6E736D767678767D72767D75767C707D767074717B6E747F787D777672767775747375
70727578747473786F737B7370796E7979777C7878797A757273757B7371737179757372
72736A727470716D72756D707374746D746E6F6E6B727076726F6E6E6E726C6F6E716971
686F6C756F73736F686B6C6D716F666369706C6D6763666B66676D6567646E5F6A626C66
64636C6262656667656267636867605D62645F676461605E6160615D62606660645F5968
636060625C5E62566262646060585759585D5F5B605956525E62695D5D635D615A5A5962
585960595F5E5859615A5C5D57585B5C595A57565B584F595D52585E585458625D605758
5E58575555545255
5A5D5A59585D5A625F5E5D5D615E625C5E5958655B5D5B545C6862606761635C635E605B
6466565D5D66595F5D625C5F5A5F5D5D675A5E5C575F605C605B635F62685E625B645A65
5B626162606464635E6B6765655D63666164575E6669605C64655D5F6A63695D636B646A
5E626A6160696666695F655E6160656E686B64616765615F6568636364646D6B685B6964
636368656A666566626267666862696669686962696268645F636962686A6767676A6C67
67696B676A676D60666665646C6D666A6B6B686F6D6C6F70686D736E6D6B706F6C727575
6A706F73706D686D71737169746B706F7277747B76707574736E816C7E71726E7076757D
7375767C7579777A7876797E7575757772717676787C7C75817D84727778767B7E757779
7B7C7E7E7E777774757376767577777C79787678767673727678777C7A787D74777A7872
7771727579687672737877736B72756D727472727175666D6971736D69746B6E6A6D6E6F
7470706E6C6D6E6A6C73746A6F6C6B6C656366706B6A6C6B65666D6F686D626C66636669
646D686B61646067646D6868606B62695D636A626066656863666367675D61595C645E66
676462615E6A5B6167605C605C5D605C615A61585D60575D5E605F5C6B5D635D5F61645E
5C5F5C5C595969575A605C605C59565D60615D625E5C54595955565D635B5C5A55545954
5458525558555559
5F5F5E635C585F5B5D585D5B625C605C605E5A645B5C5A585E616066606365616063625F
625C5C63625E5C5E5D5E5E5C64625C60655F62645D625C5E5F625D6166695F655E685C64
5F6161645C61625F645E5D5F626562655C5C635E656161646A6A6366626866606A6C6664
6468656A6663676760626767646A5D6567666B6767686560636C66625E68696E626D6764
696866605F69695E6563686266666570696666656D67646A6A6A696B66666D6F67666766
66696E67706E686B63726F69636D67696C6F7068726F6E6C696E706F696D6F706C737173
746E6C747C68756E71737571707173707977727B747A71777376727372787B6D7A767874
72767278727B767A767A747F787982797A7A748279727B82817E7A7B798276747B787A78
74708172797D7878737878767A70757B7A7A73717A7C7576777C79706F79747A7F797976
7B766F7875727B7372747577776D75737674716E726F7267726A736A6D6D7475716B6E74
7170776D74706F6D6D71736C6D716B686B696A6A6B686A6E68726B6C6A656A6970696663
6A6B6761696C6D6B636D6171686A6266636665667366616764635E63675C6166605E6262
635D6458625E645D63675F6E5E595C585B5F6A5C5F595D5D585B605D5A65635B5D5C645D
5C615C59585D5F5E60625865555B5B5E5C585C5B5E55585F5A585B545B545259565F5A58
5B5357525C56555B
5E5F625D585C56625E5A66605C63575E60605D5D5E5E5C65656262646262615E605D5E65
63665D665D5B6060655D5F615D5C655A62605D5F675F656167645A6057605C5D655E5E59
605D636062625F6169626062646464686566636462656E6369646D6D5F6266686A676A6D
675E6467656666676469686263645E6C6563636762686A68676E69616268676269666769
68666965666A676A636C6C6A6E6C69676F68696569676571636C6E666B66686A6D666C71
6A666C67696A6B6C6B6E70706E716C74666E6E726C6F6E7575717270776F726F726D6D70
73746F69746B757472766A727675787A7477707B767476787A7A6E7E7C7A71737976757E
79797F7E7B7E8175717D7D7A77807E7B7A7D7E787F7E8180817F787E7E8377797B767E70
7D7C787F7B747179737A7A79787F757676797978757B796F78767D74737E787B85797E79
7B7873776E7A71716F796D74727271757776747673786F7674777571726C706D6C716D6B
6C706D6A71676975706D6A766C6C6F786D72746C717378686A696B6B6F68736D69676C75
71616A696F6E68676A6B6F716D6B6A616463696463636C686466666C6364635E64636162
616266675C626064605C65625F625D5C6067615A5E62605F625E5A6164605960555D6360
595E5A5663625E615E665F6162585B565F615F595B5B5B5E605A5E5F585D5D5F565B5C57
5A575D565A554E61
605E5B60685F55615C59645860665663565E60575E61635F605F6063635E68685B5F5E60
5E6363605E5D63645E60605E5D625E645E6261666A6163655E61626164635C5B62695F5C
6560606261626563626665646665676564616267636A63675F62645D6967686A65646868
606C6464636A646D66646766666761696C61636D6766666761636D656369766B66686B63
6D65646568676E6E6167676C6D68686A636C6C6A676B6B6A726D6A6867696C64696C6A6B
6C6B6A676D666E656C6A6971696C7468726A706D6A7267686E707376706C6C7474706E74
69717171716E6E786B6F7A75717378746F6E787B7C7578797174767B767669757D78787B
7A7C73747C72768272847B7974787E7B7A7F76777B7277787C7E7C7D7A797F7A82787D7E
7D77737C7A767984747A757C797F797479767A75746E777C797679737982857A7C807C7B
797B7672716E6F767C757A7478757676767971757973737570766F766E7A727770736B6F
6C6F6E6B756F696E6A696D6F6D6D676D746F696D6F6D66736F6D706470706D69646A6869
696E6D666E6A6E6C6A666C69666D6A68676465766764616C6D64626365686C5D6367685E
6A62606B615E6D64635D666662606366625E6259615D616164615C606663615F5D625D60
615961585C5D615E625D5D5F56615B62575F56555D5C615C5F60585C605E6054585D5758
565D57565B60585E
655F5F5B5C625B5E5E605A59616163646066605B60596863656269626260616961635E5F
615C5F605B6163626469645F5E6665615D666763615D64636361645F615F626764616362
5F5B666A5D63636161635B636162666B656765635F6563686B6767646B5F636065666267
655E69696B656C656063676A646A6462656B5F666571656D736A646A676F5F6569646570
6D6C70686B6E6B6F696D68696565686A6A656F6669646B6B676D706D697368626C6D6C6C
716E6F6D6A646A706C746D6D676C6A696C7573756A6E7275756F737274706D776C757572
6C71687A727C756B7B736E7C6E746D76757C767A7478707773797A79747870797675777C
717D787C7E747E7F79857D7E7F7E787C7882797C7E787E7E787F7D7D7B79767F7F767E7E
7D7E8675737E777D787C7A807E7E7B7D7179797374757978767F7B7C787F7F7B7D7B7984
817778727579797777797C74797579726F757C7978756B7872776E7371727576706B716F
6D716D706F6E79737773756F717170667278746B706C736E71716C66666D7065726D6969
696D656A6C6B7068706F6E71706B676D61616A636663666767646D666569676863686166
656464665E645F605F6760656667625D64625C64625E61626261605D5E595E5D5C5A5B63
595C605C62675A62635E5D655F5A5C5E6061615A5B595A58585F5B5E5C5D5F5155595858
5A5A5C60595B5C61
635F645C5C63605966605D5E635C5D58615755605E65645F626668695D615F5C62575E5B
5E586460615F65646065605E65615B655C5F62616462585C605F6A676B66635F60696264
5B605A645F63625E60646161626466636A67616A6265676E655F696D6761636364606467
5C6966696467656B616C6767716968626862666466686460646B686B6C646369616D6C6F
6B6D676E686A636A69696B6B6D62676D6C6E746E6B66696B65676D6F6972746D745E6772
776A6E67716C686C6B6A71736A706F6F716B706D766D717371757270786E7277706F7070
70737376727277766C7C706E72777D77737A7375757A78727B7A74797A7678747777707B
7B797C7E757E7E7A78837675787879787B787E7D7A7E75737780787D7C797D7C7D7C7B83
7B7B7F797F807A7D797C807E77787A7E7A807F777072757F7F79797676817C7E7D7C837B
7B77737B73717D7D7978766C7C74797075737676777B7174707B7471777476796A707673
70706D6C6D6D6C73736C706C706D6A696A7374687065707065656B6B696A716D696A6B71
6E6F69656B676D71706A6E696C636A7367676267696D6A6D6A64636565696D666A5F5C61
6562665F6063655F636262646160635E645A64625B685C5C5F5C61645F615F5D5E636260
5C5F605D58635C5C5A575E5B5C57605E58625D5E5C6061605C595A5A61575B555B535959
596154565A54575F
625962595F615C5C5E5E6262605B605F6160675F5B616361626365675D5D626562616062
615D626261636363676461635F645C67615E65605D5E61646162636161606365615F6367
5F675F6460615D6967646C65606968646162675E5D66616168675F666860635E626B5E69
65666762646A67676F6763636A696C646B66646465646F686F67696E616B6C6B62686166
65656E636D6A6E656B6D66626B6769666E676B687269646A6B706D6962646B6B6B65726D
6B6D6B6C6C6D6A6C69697468676A696E6865746F6F77676F746B7171746F6F6870727871
6F72757976717875727272787479767C7C7B707B75757B75737C798179787C787879807C
7C7A7C7B807E8281757A7A74787C7C787C7A7D787376817D807D7B7A817E82797C797E7D
777D74767C7C797980827F797D7B7A7E77777C737A747C827C7B7A76797C7F817D83797F
7A7C77757A7B6E767B7A727874777A737478727B7A756F72777276747172726D72727370
79706A75726A6F7469746B6E70696E6E67676F67686D686C6B6A656771666D77726A6E6C
6F746C63726D6D7268686D6D656A6965626766666E6D6569636164666868666668666863
66665F6465605E6A67665A646866645F615A5F605959615A5C5A675F5A6062615F5E5B5E
6A5D5F625F5B62655B5D5E5F5B61675C5F53635F625B5A5D5D5D59565F605C5C585E595B
575E5E5C595C5C5D
61595D5C5E6151595E676561685F5D606161635E685F5B5F6065675F645D62615F5F606B
63635F636564625F605A6362625B635F61615C65635F6260616162666960626768646164
67606266626660615D66666B64685C5D6C6169635F6866595F5D636464696D6866666466
6464656765675F64646B6560686768686E666D6C686B66636568686D6E6D6977656B6368
6E6D63716F6A726A696B6C676B686B6D6F6F6D6A686A706E656B67676C76666870737269
716F696D6B7073776F6F766D6A7172766C6B756D716D6B74766F7376777571747675717A
716F767374747972777B797B79757A7375727B787D768082728680767E747D817A787D80
6F7675757F787778787A80827F7875747775797B807A7E7C8178837D7A867F82797C7D79
7C827A797F818582887C7C827E827A747F7C7E7D7A7B7E7974767B867B8180757D86797B
77767C7C7A7873747080727073737B79767376727D717979777577796D7273756C6F766D
7475716E6F6B7274706E6B677368756D6B6C6A706A66676A69706A686D6E6A7266696971
6D6B656C6B6A6C6F74746C6668636B6C676669686869676863666067616364605F646967
5F635D605E5D5D5F5B625E6161636465625F60595F62645C5E5C60675C5C6360625F6264
5A5C635D5E5C63655F58615C5D605B5B5A5C5A615B5F585E5B5B5D5C545A625E5A5E5A5B
605A545A605D5B68
6860555D5D60625F5D5E5D5F5E5964635E605A5D625D626C6463656063596161605B615D
6265615E61606069626362655C645D6263626263655A5D6560686062666A5B63635D6966
6261655E606369636263615C62616D675D616A646B67685F5E6767695E616064696B656A
6B6C686262636E6A6868646C636668666C68616369686A6D6668686E6968606D6C6E6A68
696A6C70706B6D6D6A696B6A636E6D656A6F66676D6E6A6E7465646D6B75706D68677072
6C6F726A6B6F6E6E6F7A6C727670726D7475706D77796F7E7D796D7B777E7B7571747673
71777670756C7A766E7A717F7977787D79767D7674777C79767D80727779787C787D7E7B
7E7C7A7A7375748382827C827B787A7E847F777A7B8080857B7B837B747C7F7A7D7C7A79
7B7F7F7E86827F8183837E7F77817D7D76787978828185797677777A7E7A80787F7C767A
7C78787577767A7B79757A7479727475757A727A747C70797B7570736F70747470727178
70737473686D6E6D6B716F756A716B6F7077727571746C6B6F6A6E6A6C696467706B676C
6D64686A64696674686B6864696C69656A6A62656F6A676566665E686661687065686663
5E6464676561605C6366665F63615F5F5C6364605E615E5C5C605C62585E696657626460
5F5B5B5C615B565962595E5E606859625C5C5D5F5C5C60535A58545C575E5D5E5B545954
5C575559605A5A62
605C58605E53605D5B5C635A5D5A665E64635E5F5E5F64625E615F68655E5D6965615D63
5F5A5E5E5D66696164625B5E5C6663635D6362645A635F5F646363616566606666615D5C
5E6564655D606563595E61666A65636264646864636B66606C6B66686866695E69636B6A
62666C6B69636268675D666A686A686E6D66656362707160676A70676A69706A6E69716E
6A6E6F716E686E6A6D6B716E6C6F6B6868636E766F756C5F6A6B6D6B7A656D6F68706C71
666D6D69786A746C706A716C756E77756C716A766F6D786B72767572706E727D72746E73
76747F767D706F787776787271727477796F72777A767C7B7A7B7A7A7F7B76747B737575
7E7D7B8074807A7F837F7F797D7C80877E7B82818184887F847F83827B81777C7C7B7E78
7F8283787F81827A7F7884807D7C847F7B79817D7B787D78777A7C7A787A83777F7D7C79
7A7A7D7F7C7B797B77807C7E757678777475787A7A767976767179747681777168787678
78717773767371757077746A716B7875726D716B76717372766D7768686971676D706F6C
606D6F6D6C6A686E6B6F686768656868696A6A65696B696B68626B666865636A61646264
685F66695F6A656265665C65645E596062636562625E64596362635D5F616368625D6163
61625D5C64605E6059635C5F5B5D625C515D61615F58635A5E5A67565D59565B5F595A61
555D5A605D564F5D
67605C515E635F5C595F615E5A64646568585D5D64635E5D6367646466616263685A6162
5D5C5A65575E64605C5C6066655E5F5E5E6361595F63696060626467615C636B61655E64
5F60656867615F635D5D6A626564656A66636D6362675F5C646168606A66636663676664
675E6D61666E6967686A6964666460686A6C6565656B636E6668656B6C616D686D676D74
686A66686B6B7170706A666D6A6C6E6E71666D656D666B6B676F6D6A756E696B6F6D6D75
6B736F6B69756B6877747177786A6F6E7870796D696F706E6C6E6F707371747973757878
7C6D807774777A767A7677737873797F7C80797C7A76817C7B797673757A7E73807F717E
8381737A7D7E7D78807C81857B7779867784797F7D8285887685828479797D7C7B7E817C
7D7E7F8388807D807E7E8678847D7E7E7D827A77787B78857A787E7D81847E79787C737A
7882837D748084747A81777678797B7D70796F737478797475757371747276757976746E
71766C77726D79706F776F706C70716F726B6F786E7172706D716D6C7573746C6A6F6F6E
6D6F6B6965646A66706A656C63656869696162696067666A696A69676C6C666B6B636C5F
6C646167645E6363625C6063656566645F65645A606667615A605E625B616467645D5F58
6759615F58636262615C5C5B61615A5B5A64615E60576456595E5D595E5A54565C5D585E
5E5E545D5D5B5F5A
596059615D5C605F5A6465625E625B5C62605B5E5F695C62646166675C61625E595F6962
5E5E5E625F5E615C625E586164685E5C68646560645C6164665E5F626361696864646763
5A5D5F5C646C635E615A62626464625F5F6A5F5D645D63665E5C6A676366676665656966
5F64656660646064676A6668636A60686B6A606D6B686D696F6B6969687271646D6B6A71
636D696C68706972686C666B647368666B6C6E746A6E686E6D7369686A676D716B6B726D
72706D6C716D7770736971706D716F7170746C7272797577757B7174726F777C71737273
73747C7679757374706F7879747C7975787B7D7B78787B767F797C7876797B7A7B797575
797F7B80797E7F7B7F7C82807F7E857C7B837E837C827E80817D78787B7D838077817982
7A7B79837F7B7F7F7C7D787A7E817F797B7E7C847E7772797F7A807A7E7D7D867B747B75
79777C79747B7C7578787E7977737F79767C7E77717473786B6E7573716F79716E6F7472
7573706B6F70716B766F74746D6F6D6D71726E737369796D6E6C6D666E6B6C6F6D766E66
716E646F6C6D696B646D636D6D636C696A67676F686968626465665E6663646A66656665
6666606263626368665E615F6163605A5E5C5F5F616064616369616161625E5E5E5E5D5E
5C59595A6163605F5E5A5E5F5F64605C5C5F66555F5D615B5C615E5D5F5D5460585A5F56
6059595E5D5B5F5F
60595C66615966605D61635D625E5E6060675D5C63615E5D6264695F616064605E616059
615F62645E5A6A676564635F60645B636065615E6562676366625E68585E5F635E655D61
5E6263606361615E6A6A5F6466656669626A646D6C6365686A6562676C6867616769616D
666C66686965656B636A6966667068676A7061656467656B6A6E666B696F6B726A6D716F
696F716C6C69686A65756B7171676B6C6D676571706A6E686E6E6F736F7269776F756A67
746E6E6F6A707871706A706F746F6C6C726A76727C7473737874727D7572727479787272
75727679757479717C787D7E7C79787576757A7F807B7E777B787B74797D7F72777D827D
837579768383797E7A817E7D807F7D7E8179797F7C8488837E7D7D86837F7F837C857B7D
8380868480788082797C7A837C838680847D837D747C7C767B7A7C7B7C7D7A827B7F8579
7E807F767379707A8077747B7577757A777474727778777775787C736D707E71767A737A
70767173766D73706F71766D70756E72706F6F6A74726B746B6F6E72686B70696F68646A
656E67696E67676C68696F5F756D61656967676D716468606B6561665C6766646A646A60
666668606460616861636766625F6E60615A5E60595D63615F6664606460625B645E6157
5B5F625E675C5C5D5A635F5E565F595D63645C625F575E5B635B59615B615E5A5F605762
59625E575D565B64
5E5F5B5C615E63645C625D5B626466615F6460636661606360616464635C67606566615F
5B6564625F635F60625D5960655F6060665E646360605D5D6A596266635C615963656561
675F5C64676661616A646F5F645A6166656569676D68685F6967687162676565676B6363
6169636365656F626767676869656C6E6D726A72696E6B647372676B5E6E686C6D696B72
6F6C6D616B68686D676F6A6F64667370686D6F686B6D7072706C6C6D6A727068726D7370
7872716B6D6F6E6D6E73706F6E6A707273756C6A6E76757B736F75747776777472727578
76797D7C7A787D77807982767477787F7C797D74797F807A7F7680797E85787279797F73
7A7D84767A7E7F7681867E817E7F797C827C807C847E837E80807C7F88817B7D7E817E7E
7F868985857D837A78787985807E837D7C8077797F7D797D78777F7C877C7E817879787B
807F7D7B827C7C7F767A79767B797D71777A7778827573707B777377727473747272707A
6E717477777171736E766D6F7275756E7273706D716C6C66737176646D746E6966637069
65646C6F65676C6B6E6C706F716B686B656B666A68666965676B696B676C6F6769676960
6A615E635F686464606065655E67616664615B5B5B615C6261665F595D645D5F5D626660
625A60606560605B6058645E5C5B6359605B605F5B6959635D5D505E5C5F5C5D5F5E5C5A
555C5C5C585F5C5D
665B605E6160645B5C6467595C61635F5B6163636563685D5F5F5F64616065615F5E5A5D
645C605F61615D67625B6067645D666A6664605F645C62646961625D5E6761625E5D6263
6A6469675F655F5D656A59615F616764645D666D67656362645A6666676766646C6E7065
676C6561646467706868666C686B6B71686A6B6E6D6B6D6969666E666B6869696667696B
6C6E716A6D6E6B6B6C756E6A6E65656D6A6D6E6B6D75716B726A726C737168756B6D6F6B
6E6E6F70707470726D7076717173747773726E71736E7677707A7571767878707476757A
777479796F7B7670777077797D807D7D777980797B7B7E757C827E798680797A83797C7E
7781787F787F867D79867D817981837D8579857D7C7D837F7D7F7E7A828180877A7E8182
7C7A847C7C7D8177837C7A83837F827E7F7E81787C7E767E7E78807B7679807A777C7D82
817F7C787D7B787A7A7972787C73767C7772767A807D7B797E767D7C77777876686E7476
7175737473767074776F726B6E7975706F6E75766A706E6D666D736F6C6A706A64716F69
706E66716B676B69716B70686A6E676D6763716C666A6D686963696563616265666A6563
67666864676464655F5F6060635F63636267585E615C6463616168675C6362615F645F62
5C605B5F6461635D605F6764655D5A5F5E6559635E62635E5E614E5E5B595D5A565B595B
605A5D5D625D5A5B
605D605F5D5E60625D6366595F5F616069655C5C605B64635D5F5F595E645D5F64615F67
6262616B63606B635A61616566625D5F645F615861616665696569626660646461625C64
675E686168655E6161666A665F6562636764696964655C6269656264686A63626A69655E
6B687067626D695E696665666B746A726B68616768686D69686A676F6D686A6D6466696D
656B7270736F69747568716F6C6F696C6F766F666D7173666F726F716A716A6B7370716F
696F78757769726D7177707276747F757679776E6D797C776E7A737A7674787576737A6E
7A757778797D7C797A71777A777B78797C7F7C7F7C7C7D7C7E797C7B80837D797B7D7C7E
747E7E7F8282847C80807F7E80807B8A7F777B7F7E857F7F7E888286817E85818A7D857D
77807C7C7C857F80817F827E7C7C81818078867A79817E7E7D7F87767B7B7B817D7F8176
7E797B7D7C7B7B7C787B71757C7A787B7C73807377797C747A71727A7678767972716D74
72757370757470717073786E6D747874717472707170727674726E6C6B6D746D6A6D636A
6E6D6A6E6B70716465716F726E706B6D6264686866686D656567696466606365636C6667
64685F6567636F645E636060695E6365616262605D595F6467655B5E60635E63605E5D64
60645C5A5F5A5C61625C5E5E605C605D5E635E5E5F5A61615E5F5D625E5F5A6064595D5E
645E595D61625B5E
605A6262605F58615F615C5A59605A5A645A6C67645A5F5C5F61606A645C636669645D65
5D625F635E5F5A60586164606362606D5E6163626B5E66625E616B6D6062676261616268
625F5F60595F64665F6969645D6468636565616765616566667066607161675D676C6662
6B676A6A66696E6B60706D696262686567686368686A686B6D6C7167716362636A686C6D
6C6C666B726D70746B6F6F6D6F716C706A6D667166726D666D716F6F7270746C6D6D6C73
6E707273706F6B746C74796D807B6F777B7F76777A6F727377777279797C757677796D7A
757F767B71797A7B7676797C7E77787878797A8076807D7F7B7D77787F7E837B7C7F7C7A
7E807F7C817A7B7F7A82817F7F857C7A8678827D847E8679877F7A7F7C837F858080877C
79797C817B7E897D7E7B807A7B817D7F7C7B77837B8176817C7A79817E807C7F7F7C807A
827F79797D7D797B807F797D78737C777B7A767B7B7C72787A7975766D78747173746F6F
736F78757174697075726F6D7270706D68687269746D706E696B6E73716B67696C676E65
70706F6A6A67676C666C6F6C77696C706C686569636B6965676D606665696B5C6762645D
65616B655B6461645B6562645F685E6A615F5E625F65655C5E67645D615E5B6A60615E65
5F606461585B5A5E5C5B5A595C5D5D626460615D6261605F5B5E635C60605C635F575960
5B5B5F605A5D575C
5D5C5F615E6661625F675B626061615B6A6562635D625E60625E5E6066605B5B60626267
586568615C64615F5E6459606763626463625F6161595D606461615D645E606F66626260
5F6562626060625F606B686366696465666764666766646268656D6B7168676969686462
686C64626D6062626E656B6268666C67706965636669656D71716B706C6C66726F716F68
6C6E616874726B6B67716F706F72706F666D656E7273706F6E6E737470797174726E6F75
73726D7477747073746C717677746D7572767376747A71687679787771727A777A767583
717C787C7B807B7C74778176797D77797A7E82807C7B827C7F797E7E807E797E7C81757B
837D787F85858381867F847D82867D847A867D7B7F807F80837F797F8481787E867F7E85
857C7D817F81868180818785868386807F7D837F7B837F807E7E7F7D7C7982827E7F7D82
7F797C76757F807A828177777E767B7C7A7D7A7C766F766F767372727E7A7A7470797879
6B707675787578767D7778727A6D736F7068686F6C7473697168726D6A6B666C6C6B6F6B
6C686B7069676C6C6A6A6D6D71686A66656B6C646968666E646E6466686169686667686C
6865665F5C67656561686862675D5A6A635C5F5D65646061616E6462665E60646067685D
5E5C5A5E5A5A5D5D61636162625D5C5B656263595F5B5E5B62605D5C6066605C65605B5B
55615D605D5D5E5F
5D5E5F5D65605B5E646560605E69615E6367645D5F5B615E5E6265625E615F686A5D625F
5E5F665F6262605A5E645E605F6765675D675E676560635C5C60625D6B62605E61606266
5E626362645F6359676367616266666260656163656B5F606A6063646B6A656B636C6766
666C686370696B646B6B6F6A726E6D6C6A6966716A6E6B6D696E646B736973716E6B6A69
6B6B6C6C6872737073726A69696966706D756E6B6F716D6A6870746F7376727076707577
6E7074766D76757470697A777D77747B6F7475797E6D74777475787977747677787C777D
767C7B7A7C7B7B7F7F7775717B787B877B837E7E7D747F807B7E867C7F7B7A837F808275
7B807C82817F7F7A79847B82817980887F848082848686868684897E89807E848481817C
7D7D8481808282837F7A8480827C807F838081807C827E7D817B7F807D82757E7A7A8079
7C77757F857E7F787D7F7C797E76807A777A72707779797A7E7776727B78727278747175
73797175797171767677767278797A7672746B7B6D6A73736A6F746F6F666D736A70686D
6169696C69636E71686F66696E676C646F74676B68676C676A6E666B6864666A656C6066
6A646165685B6B61685F606C615E616768616760685F62605F635D58675E5F596361665C
5F6262635B635C5A5D5C51565D636262635C5C5B62595E54615F61645E5E615C5D5B5C5C
60595B605F5C535F
5F615D65665B635E616457636160605E615C64605C626259666163655B6663655A606360
5E5E5D5D5D5D625C5C6559656761656557665E62626363635C69625F6361625E5D63695F
646363606C59626365616466676163606A5E64666360606B6C6162626D6A675E64696E63
6362666A6B65656B626A61686865616A6C69746A696869696F6D6C666E6868666C6C696E
6A706B6D6F73736C706F716E7474736B696C6A6F6E736870717172737170706F70737871
777777797576777171736C7275727076707E717B786E7382797A77727B787979797C7C77
777A837C79807D828177787E787A7E7A857A7B7A82837D7A8279807A7B807B7C7E7B7B85
7E7D75867E7C7F757C7E7F7E81807F80847E7D82817C848382838584887781847B7D7E85
79827F87847F7D7E7C7F877F87877E79867C857F848176827C8483817E7F7F7F857C777B
83797A828283737B7C7A7A7D7878767A76797B77817A7F787E7A7A75737472776F727476
7679796F7781777B7B79727C6B6F6F7072757877726F786E7576756F6A73696A6C6B6467
6C69696D6C6A6C736C6D6F6F776F696C63676262686C64676B6265696869686267666865
6461696F66645F646A635F606363636267606269665D5C635E605F625E635E5F5C615960
5C5B575C64585D5C685D5D5E5B6363635A615C555C5A64636162635E63635C6061665C58
595C5F625C5D6062
5C5B5E5B546163675C60625E5F655B6665685B6165645A5C5F626061625A5962615B5F5A
5763605B5F5A6663636564666A6D615C5C5F616660636564646162666663615B5E61655E
68665F616461636663666761676761676B636167686C6C717166656B685E646968626A67
6B625D68685F676D696E696D6A6F6B706F6D676B6B67706D6D666A6E666E6F6D69706371
706A6E6B6F6B736E6E6B6C6B716D71686B68716F6B6E776E7569796E73746D72756D7878
717A75767172706F7371767870727878747570717A787A73787370787377747A7A7B7873
787B7A7A7977797E7B7A79797A8579747F84807E8181767F827E83837B7F807F7F7F7A83
7E7E857B7E8A7E7D7B7F7F8585858585808487818480838783857981808287827D858083
82877E7F7F8489838577828285817E837C8185847C858181747F7E837C7E80808779807E
7B797D777B757E7C757A84777380727F7A7E777C7B807E7376767F7A7381747577727274
777F70797D81797E787C806E77706E6E7472727471746F6A6768746D6E696E6D706F6868
666C6A696A756F726C7071696D696D6A6F666966686B685F656A636D5D6967616867625F
65685E6D67626765645E6562605E6062615D5D5E62615C625E64626260626B60605F625A
5A5C5A5E6464646363626564666564545D635E59675D5D665C5D5C515C5D595A5C5B5D5D
6956575E5C5F5D5D
5F5B5E5F5D5C5F5B5D5C6560615E6365645E635F62665E5D5A615B6559595A625B625B61
5E625F5B5E6265656265636B5F62636163626066605D55665D5B63666164656666615F64
646763625F5F6260635E60625F5E67615F63696367746C6C6F69686468666A6B6766656A
6B6B666B6668666666646863676769766D7366686F63696C6A646C666C706F65656D6A6C
6C6D6B656D6F6D726D706C70726E6E6A7069706B69726E6E776B767174776F756F707A78
7D7B717374706E70717675787D7A7574736F71736C72717A7B7574797B7F777481787B79
7A778277787B8077767A7A84797F7A7E7E7F857F827F797B8082827E7B82817A8C7D7D7B
767F8184887F7E83857D7E8B807E83838581847A817786847C7D837F87878A7A81818383
7E837B88827D848684827C7D7F838083777C7E8382787F80777B7E7F7B77807D85797B82
7C7977797A80797C7C837E7A7B6D7C8080807D7D77787E7A758276787272797575787B73
75797E877D898486887D7A7679796F6B766E6A747774706A6B69736F6F717273716E646A
6B69696D6A6F6B6E6F6E69716868706A6A68666F666A6362626C635F6762616362696764
6C63636363675F635F6467665C646265665E625E6063616263626165626360566061655F
5C535B61645B5D5E65646063615F6160625D555B5E5B6262615E605D5E5C64605C5D5866
595A5B645E56585A
605F625A615E5B5F5D5E645F6466616464606662636164615E62625E60625D616062605E
605F6063646765605D675D616860676469605E61635F626A5E5B6568606363636B635B5F
596761605F615B665F696668626C655E686B626D75716762685F62686C6A6C656860606D
66606A6B646669656C636E6B64656D696E6E6D6E6E6F6B75616D6F70686C6B71726E6667
736E6D6E6E6B6D6E6770696F75706E74656E717871706F706A7A6F737975757473717578
7B7F7F767779717D806C70707B73757174757B7D7A7A7B7779787E757B7A7D767E80777A
7F7B82777C7F817F7C7F7C7D7A857A777B7F7E8084838179797E7C8185827D81807C827B
81807A8381857E7F807C7E7C7C8B83888D8181897F8082818280877F8D847E838783867B
7B7F878881808580818A84827E817E85847A867C837A857E7E808A80767F80827C83897B
7B7C817E747D7B77767C807E827B7A7F7C7E757B78797C758079777F7D71767C75767C7A
7B7E8A87898C8E878E867B767978736B716F6F7A6D6D6D6E696D71776F6B6C706B716B6C
75676A6E6863706C706F6C6E67726B6766646B68696A6A63666B6A656C666C6A62716E64
66666968645E5E646269635C6A6663685D5961685F60616763645C5F5B5C5D6168675D67
60616460615C64605B5F6165555C605A605864605A5E575F5D63555B5C635E615A59605E
655E5C675A5D585B
62655D66635D5A6062626360645B5F676362665C5F6159665E635D5F615C5A67605C5D5E
5C636162656861626069675E6A6465656163635D63695F62615C5B63666B636265615B61
5D64606364655D6562646764656469606166686B675E67686764656A6868676D6D656365
64646464726B68686B6F666B62696D6D6A6C636868686F6C676B686B70726F6F696C6967
6A6C6E767769716E686E6C726C6F7271706A6C746F6D75727171766B7570736A707A747A
807D79786E7D757677777574737375717A7276807B797A7978757A7C787A73787B807C75
79827F77797F7C757F7E817C827B7D7B807D7C7A81837A817F787F7B827C837B847B7D80
847F7C8784897B848A8688827E7D8B85837C898480858485858884828489857E857D7E7F
8487858185818084888383887D7E827F767B827884837D7F7D83837E7E7D827A7D807583
7C7B7A7F827F86807A817C7E7E777D7B7C7B7B77817B748279787676757379757673767D
7F818693919D999891877A7C7C7177766D7469716D756E756E776D717667656D6D6A6F65
726B6D6A6F6E656C6A696F746A6772656E69676E686C6F5D646264626566646665676269
6A67686164646164656568606A5A63665F6960655D67655D695E5E5D5A625F59625F5B59
62615A615F5D5E5E6A5960625C5B675E605B5F575B5F595D625F64615D575D5D595C5A59
5D6063545C555B63
625B5B5B60636361635D5B6763625B67625E675462665B6362646066636261625D5C6162
5C635F5F6167646167606E656C6E6464655D57585C65645F5D5E635E675F61645E66646B
65645F6660675E6966616266696767656965666263636B696B6C646261666664686A626A
6A6362686965666A676C6D706B6B6569686B716A786B72676B70696D716B6C706A6C6A70
6B6C716E707570746C6E6A716F72736D736C6D796872766D70746C6B6B6B747B7474716E
767571777A767970777674747972737A72767B777575787B77777B7D79757C78737C747A
787E7E7F7A7F86777F7F807D77817E7E83818079807A857F818183858581848976847C85
8385868F807C84858785838384828B7D8A8A868D7F8A8A82868582828F85787F7C7F8785
818C837D8187838384818680847E86838278817F7C80847A7E817E887D847A7F7F837D7C
7A787E7D7D807F7E837C79797E7883837C7E767E807A807B777B807478767A757D777476
7D7C8B959AAA9E9F8A7D7375717A72737A71746F716E7270716A726C706B76716C696E6B
676C706E6C6E786D6C6C736B666A6F676A6C666A67686664646762676D666863676C6163
676A6664655C646369606A695F62646B656B60616564625F5F5B5E686A6265615E615D61
5E6359675A5D586160655F5E655D5D5F5E53645F595E5962656259585B605A645A57615C
655E5C5B5A5E5963
5F5D60595E655B645D665A6364626265645D5F5C5B5F675C60655A6365645E656458615F
6461616262636374696470696D6863626665625F5D6161605F5A5E5F62625F65605F6363
635D626C67606B60626A6865686C646A6668696661666669666B6C626062606769606E6C
696A636866686C65746866665F70656C6565656A6F6C66726872706C7464686D70716B69
706D6C617373706E6D6D6C6D6A6B6C706C6C746B71716C75746F7373776F756F746C7876
7D77777576726F716F76777A757774767776757C7B78777E7A7B747278797277757E7977
7A7973767B7E79787B7F80757E837880807B817888807C7F827C808686798484827D8387
837D828B8981828487877E7F867E898C808783857B8784888A888785818288808182848E
7D8B86808A8182818E8185827E7C8483798381838582828581817E79837E7C7C88797979
7C84817D75767D80767E797E7D8188857583827C7E797F76777B7E77777F7E727777767D
80818A97A4A6A1948E7C7877737371717A7974706D73736E736D72746B6F6F746D6C7073
696A6C656A6D686C68686D716B636D676D716B6A6A6F6D69636965666968676764665F61
68636062665D606667636961615E6166626B61616067665F605C635F6064616369626063
5E5C595A605D5C5D5D615E61555D5C595C685E6060636360655959535C585A6263615E62
616158645E5E5760
615A5565605E645E60655B616B6062595E6068685E5F66655E645B5B625D63626661665A
62636767636461686868706E716A66686A6B675F6366635F6364656668655F5E645F635B
675E5E656865605F646569636D69606A696464626D675D6361675F6768675D6D676C6567
6A6B696C6C6364656B656C6F69696965646B6E6B717264736F6C68737072666C7A736C67
67707071746E736A6676706F726F706C6F7270786D727A716C76767575756C707A7A7874
6D78767175737C7076757B727A7973747C7E7F777C7B7E757B718281857C837A6E7A787E
7977757E847C7E7475797D7D767A7C7E80837D807F798085817B7E7D7F88817F81808D7D
807F868584837B7E7F8484858C848684847F848D82877E82848784838589898282818980
85837F84828383817F847F83867E828083867F7D8279877E808087867E79827C7D7F7F7A
7A7E7A7D847E7F7D7B7E7E7980837F7584797E797F8288797C7C777B7577737B7B767C7C
7A7F8A9B9CA89A8E87767F79757475787377706F67766E73717369707468766F6F736D6D
636966746E706F77696D6E6E6B6E6D696B6962726C756C6962686F6D68696D63656B6467
6662666A6562626A63626566606365626366595961635A68686467645D6662665F5E5F63
63615962645B5F625F6465606163635B5F5E605B60625F57695A5A5A5D5F62625A636267
605F5D5A6159655D
645C5A5D5B626163635E5C645D61636160625C6161655E5F60656366615D5D5A63625F66
5E605A61696864716C6D6F7677706F606168616370655E5F6664675F6764626561605A62
6566615B60686364656263665F6B636C636D5D5D68665F6764666C68696A67686A6A6666
67636769706E6F6B6770676B6B6B6869666C6E62716C6D6D6B67676B696E716B6C746A6F
6B6E6D6C6C6A706F6F75766A6B6971737172696E776F7C79767A717B75726E7774717278
777678797677787A787675727871777E737D747B7D7A7C787B74807A80727880757D757E
7F7D7B767B7D7F867B82847C7D7C787C7A81827C847F8480887F8481877F85827F7F8183
827C81818380887D828283807D847D878F8285868085808880888786898A878483898E89
898585888C8D8689828B848088847F807E8280867C80817B827C83868586837C7D7C7B8B
837A83787B817A8078837787777A7B787E76857F84827E83817C837A8279757C7D7F7679
7E868597959A8A90827C757878717370756E737371787071736D7072706C6E6F78736968
6A6E686A68676D696E716F656B6368756F6A686A6E686E646C6B686A6C666E6B646A6265
67686860646266676B68605E61695E6565645E6161645A64626565605C626764615D635A
62535A605767525D61605D5F62616863636060605D5F5F6261615D5F5A5E5F5B59635A58
5D5A5B6261625958
5F585B665D5E5B61605E5F61615E5E6560606062646664646164646267606465625B625C
5F5F5765636B676D6E6F766F7A6E72616A6261626664645F6161625D645F61606061615C
62636160646D636462616765636467676C646A696D65646866696C6A6D6F6362686C6767
6A6C666A646B61706B6E656C686A636F6B696A697571726B6B6E6F63667078706D70726D
6D7069716E786A6C6D64736C7575746B7572696A72796F6F77736D746A72727371767C77
7872766F7778736E767374727A787B7F737E7C7E757C7E7D77727876777A7C7C79797978
7A7D7A79797C7E757D7F858182817E79827E8686857C81817F85808A858B808881848385
827E8583888088808980878786857C858988807E87888B8B84827F818A8586878B7E858F
898E888A8787858387898B838385867D85847F827D7D8485828983868782827C88808488
8779807E84837B7E8183817E877E797B7A81777A8478747F7778797B7C7A7C78757A7E7F
818581858A87907D78737D7279727C73747076726970716E7272707076736F746F6C706E
766D746C6E736C6A6F6A6F686D5D6A68666966686B6A6C6A636468666565666167666669
62666263676369765C5E5A63686260646363606566625D656061606864605C5A62625E5D
6163615D6462655B615F615C5E5F6361585F5C605E5F595D65615A5E5E5C645D585E6060
5F5F615F5E5F5E60
615B5D5F6C5F5F61615F615F615F65655C6A5F656263616361656B686B66605D615C6563
646065676A696863677B767C7A73736B6F646162656964625E686266625D635F65636363
6765626961665E5C63636361645E6D6A6B6F6168696B685E6C676B6A6963666A66666369
666D6964626669676A6A656B6D6F655F6A696E676D6B6E6A6D6F70766E74696D696D6A6E
6E6F726E71707C686C6E6F70716A6F73697875707176736B7877746F7171766E7679707D
7A7E757F77767874787778787573797C807E797E78817B7B787879837C757E80787B7F77
8678817C7A82727C83818780898880818187807C8182827F7B8087867F877D818C818584
8887858386818883807D88898B8687878B7F8A828186848F838C8B889681898182888B89
898D87878284858B847F7F8485848E897E837E8385887E7F828586837F858581807B887B
8184897977787E80877978748175777C7E7C737B7B7D77767A79797D797D807C7E787B80
778380848A83827E73777A727F767D767470766772737673737373736B7570756E6E6D6E
676F6D6D69686373676B6B66686B6E646C69686E6A71676D656E6763625F696E6B676565
626D646C6861645E66686863646267646A62656366656560685F5E655E615B5B5F605D5D
5D5E5B5F576462625C5C5C5B5E685C605F5D625E5863625E61645F5F675F615C635A5B62
5D655F63565D5A5C
5F615F5B6159625D6563645C5761615B5D5F5F605F64586062615C5F695A635D6166625D
6666605C6261666566717A70736D6C646A61645D6B6562626761605F666664615F646163
676061646766606A6568616A6861656464686967686A68646B6866676F62636A62626C66
5F726F5E6A657266676A6D686971686C6B6B6F6F6B70706D736D6C6F6C6D71716F6D6B6E
71757275726D747472757278717674746D737C6D757671737475776D75727372757C7675
757376717B71747B7579747678706F7175757F7D787B7B76818274727C77777B78747C7A
7A7578827D84817C82797E8284837F858080827C8689858D868486858685867F7F868586
878981838587837F8A84888A8582868C8990898580868A8888818586808A83898A8B8884
8C858A87828D7F84857F8585878686878182877F84848680817E89897B827F85827B818B
8089737B7D847A7D7D827F7E827D817E7D7E7A7C7A7B7A7C83787F7B797A7D7A777A837B
807A7E82857D7D7876746D7474787A767D736D726B717473766B6B74796F696E716E6C72
6F696C706A67696F6D6E6C6B6C6B6A6D726E6E696F6A626B6669676A6B67616C6267656A
636B6D64686766676E68686862626D6D656A6868646365616059675F635A6A5B635A645B
655B62655D616660635F5A5F60665F626265635F5A66625B615B565F5B615C5F59625B62
5F5C5A62585F585B
5E5B5A655A595F635A5E5F5B626465695E5F5F6663606162646968565E6A59655F636564
5E655E6060686268696C6A706E6967666C655C685F67625C616960665F5D5D5C605C5F61
64686B62676C60656E67676C696763645E696667676B7169626A6765676A696B6D676763
616E6A66696E686D656A7168686B696C686A726D687471776F726B7270696A6F746E786F
6C706E726B73716E73737175747E75747075727575727173746E6E707371776F72787772
7972787E7F7377777C807D7C787F7878787D76807A7E7B7C7D7A7A777E887C7B797B8173
77837B7C808079827E837F8384817E807D838281857C847C818481818386838982868185
8880808F887F7F8B8C81858B8C8387878A868687878A8685898B8A888B878B8C80888887
858C8A8B8D8A838A8789928E83827D8785817E857B89817F7C7E81808087837F7F7D8281
8B7D7F7B7C7889847F7A847C7F8284847F817F82777F777F7E7D7E787E7D827A7D7F7779
7F7F7F7A807B7977727674787078756E6E737373746F71756F71726D7573717172706E6A
6D6F7072686A6E6D6F6C6C6C6C6B6F67636668646864626B6867696568616A6F6868676F
6769696169666C636D636B67686D676366676D6263615E5C5F5D63575F625C61655B5F5C
6062615E645F62605D63615F5C6263635F5F5B59595A5A585D5D605C615B636257575C61
6360615A58575B5E
5D5C575B5C5E615E6061695B636B646259625D63665B60605C616061646A5F5F5D625D65
605D6162665E6A6A686D6A6D6A656A67616C626764606A5A666662635F665E67635F6359
666561605E606466665D6963636467616860645A6966665F64696D5D62676866676D666B
6B64686A6C676E676669696F70726C6A70726E6F6D706D6C6E696E6A6B6E7270736C766A
726D6D706B766D74717176747072727A767776706A6C71786D717A73736E737474767374
77737773787975787A756D7B787973767979797F7778867B857C767A7C817E837977837B
848386868385867F87838285838889868D7F8683817E82818783878B8187828A89848581
7F85848785878A838E8582868E87858489848388839183888A8E8A8C8387868687878D8E
8D899188848C808882868B87878A857F888C8A858A827F8379877E8A868886877E7B738F
837C7B938A887E818184817B78787F7E787D7E81797B797B7878777C7D7E77767A77877A
7C787E787882787A6D797D73737B776F6B6F756C6E7470716D6F6F73757173706D726F72
6D6969696B726F6B6D716A6F6E647073706F6A736868696968626E6765686866666B6B65
656B64665F64685F6C646B5C66666B6E6D6E65606065645E595A5D5C66645D5F67645F62
5D665C5F665E5A6260645F5D605D62655A6061646258625E5E5B61675F5F64625E655F59
5E5D575C5D586861
606160605C605E5762605E655C615E62645C625F59635A62585A5C666460666461635963
615D5E5E64675F6B6267616764656660636667676365656560656266626460635D5D635E
626E64656269616960696A6C6C6C66675F5F616867686862645F656F6964696B6D686867
6B646D69676B6E6D616D696C696A6567686B696B6F6B6F707073736C64696B72686A796F
6B6A6C747071767573747A70747E7073706F6C747672766D6F74796F7676727971787076
7D7576787478747476787D7473737977807E7C7C7D827E7A7D7785787B7E7C8283778183
7E837A7E817C8484867C85808183857F80808283848487897A817E84857D888C838B8780
7F8A7E878B8982888E82838886808589818786858890898A868C7E8B8C89878685898589
7D8B7F89818A9183878A878883818283897D82837E87868A8682868987807D7E827C827B
7E7D8684877C817D7C8080787A737D8976797B797B7E8084787B7F80787678857F777A71
7B7277797B766E7674727974767579757677786E6E7370707471696F70716D6E66736B72
75646A716B676C6F7071756B6E74756E726F686369676F69646B606A646C6D656967666E
6B6A5E60646664646760636465656C6767695C615F605F586365686262606A605C69645C
5D5B59625C5D625D605D5D615E5A61685E6061675F5D5C5B606260615E5D656067665D60
605D585A5E5D605D
59605F62645D5A64595D5864645B6562615D5D5E616B666165596164655B5E63605F5E62
615A5D5E616664615F6670686263696763626965616160606A635C68635F68685F626163
62645E62646068666962636B6967605D6462636466676261636470686B846D6E67656564
6F6A6767647565755E6F696069697367686F6A71716D6D6D736C6F74697167726A6F686B
756C6C6D7373736E6F717373777E777579776E6E7471787574777470777A757A70707174
777A767677777B767D737C7E7C797A7F82787A78817B7F7B7D797D8180827A8384818285
84847E7E80867C8482867B89848584868082837F837E83858880878E848A847F817E8788
8B8A8781818689898A808A86918583878B898887878B8588938C8C86898688858494898A
8D8E8A83868B8986868C8286868B7E85818185868A868D8682817C7E7D8A858586838280
85818280877F797E837F878079867F817C7C828383837F787C757D7C7B7A7A777676777C
7A797C7F76787D787470807676716F717775767470696E70716D706D776F736F6D717071
686D77656C67696C73696D696E6B6D6B697067696C606863666F6F646C6D6B6F6F6A6A60
685F606965666C686B5F6867686B6C6565715A615B60665E5B6663635A5B626564695D61
685E605C5C6667616558626059646461655D6260615D645D655F605861635F5F6261575D
5E60615E5B5D565E
5F61615D5F595D62605C69615F5F5E5C5C5A56666165625E5D605E6062615D5E58665F5C
5F696261635E66646B64676660655F61645F64656568616661655A5F5B636261695E6165
676364686466616B6B646A6B68716E66655E66646A5E6C666A67676F6BC2666D64676367
686D646F6F66726C636D646A676F6C736B67676C716C6D6F6A6E6C6C6F726E6E716D736E
71747867716E7274716F6E7775757A727A726F6C7C756F747175797870737575747D6C76
77797478787B75797A8080727D7B757374767E7B777A7C747C7E7980797D8787777A7C82
7786817E84848583818380858E7C83858780828581898183848C87848A8A84858C86818A
86868685868A858E8F8784888B848A8E89898A898B89908A8A85928B8593929487878885
9485838C9386858A8889818D84828B89838A868387827C8781817E827E8580818182868B
7F857C827981837B807F827F7C827F847F7C7F7C787E7E7E7C8181807A7E767A83797C7A
7E7B777F7A7B75746E7973747C74797E7D7B727275736D6F796E737378736B6D67746F73
726C6E686E6C727271656F6F6B69666F6E6F6E69666A6C706B69656B67716D6A6C686C62
6E646966636966696E6A67676670726B6666646863656763676661615D6260625F606360
5D625D605D5B6061615F5F5C625A5D5B5C5C5E5861605D5D645C6A5D615D5F5C5F5B5E5A
5A5E5A5E585E6564
61595D5E615E58685E615E5C5B625E5B5E606658605D5F5F6362575F5D675E5D5B5E6262
685F675F5E66646B5E5F625F6164616266676267646264636369666260625B6569645D5E
61645D6A656963686666696E656D60646865676865656569696A686A6A63666864676967
6C73676E68676F6D6A6E6B6A66696B75696F6D6E6F70686E7174666F7374716C7570716C
68716C707A716F74796F7871746E7F6C71707370737872767B73626980727370777A7878
6F72717472717D7A817D767D778073757E7D80797D7A797D857B7E817D818181817B8383
837E8882827E7C888D88868385818286848387878985857E81828E8785817E898D838783
8B8B8C8D88898D8C8E8C9287898B8B8D8E898A82858F888E8D888883878C928E8C867B89
858A8A858887868B857E85888B8385908987868788867C90887F828587877F7F87817D82
8380857F8187837B81877C807F7C7D8084827D83807B7C7B857B83777C8078757E7E7F76
72777D7C7F757A79767F767B7677777479776E7570746E746E6B6E706F737170756E6C72
6B706B756E6B706E6B6B6A6F6E6A6A736D696D6670646C6F6F646B666C66666B676C6E67
6E6668646466686C696D62656A6E6A6A6A6A64686C61666165646462615F5E685E636462
6062605F5F68625C605A6262635E61655E60615C5F5D66645F5D62625A64645F61615A63
615D625E67656165
5E5D615B64595E5F5C5F5B6561646A615C5E5B615A5F65675D645A64635C595957636862
626265645D625A6165645E6564636A635D6467656368676363655D6A5B625B676B5A6467
66636E67676362646D6964716865656B666A6164676B665D656665666266696B6965656A
686267706B6469666A6C6F6A646B716F6D717067716E6D69706B706A6F6A78736D6B736B
796776716C757177747677787C78706A727671717173767078717474766E7A72766D777A
806E767A78777A7A7F7A78777B77777E7A807B818279857D7E7F7C7A7886807D84838280
808282878482817B888584868483877D7B89817C88828882888B8484838587888184848D
8B898384878B8A8385878D8886858E8C9396868987998F8B91888A8A7F8D8D84908F8E91
8C8A8C8687888B858D8C8090828B8985868486858988858B898D828687887F7C8380847E
88838177828283888085777E7E827D8380817C7D7C7A7F7F7F7B79807C797F777E7B7C7C
7F798676737B7A7A7B73757976767679757271727B796E7D717B6B78767677747076716F
6B6D6B736E6D6F6E7667666A6C6C6B6F63696D646B6C6F63766666676972666D6D646263
6C665F6A62696A636E6B686366706A6A6B64625C5E615F69616361626261645E5F695D6A
64635C585F5E656B6B635F5C5C60625A63625F636762626260676563605E6367625C6363
5A5D5E5868685F68
5F5D595B615E66616366575D615C5F62665D5E5D63605F5F5E65605D5E6564635E676560
5C665C626861656667686361676B6B6062605F616562646862605F63625C6669685F6F63
67686C656A6468626664636F6569676A686968616D686467666966666369697369676B6B
7269696B696E6B6671716F6A6067686F6F6270706D6F68706F656D6E71716D6E71756A6D
6D7571717272757073716C7077786D73777C72747674776C6B7B707B7770757572797777
757B767F77787E737D7179767279777E7F7C827E7C7B7581777B7C8381837F8281817F83
7C88877A868780808380848284868580878D8085828389828488868A878F908B85818C89
918790898C8B898F8F858D8F8A888F8D8C918D8F908A8A8A88898D8E94838C8A93909189
8D9088828A888D8A8B878C858D8E8D81837F887C8A8084858C83868283807D828283817D
7F85857D848082818080867A8179817D7D7F7E767D7E8678747F7E788081817F7A7A7E76
72787A727E747D76737F77767673777C777479757A766E727274727475716E756D6D7270
6B746B6F6E7474716869696E706B706C6F726A686C6F67656D626666706A6C6B6868636C
6B6768676367676B666560696465636B6368626365656764666366645E6662655F605C60
645D60595E616364636464605D63605C5C66615E62655B6962626669645F605E63625A5E
61655B5B5D645A69
5E56595D625C5D5962585D665B5E5F5F5E5B5F626558665F605F5F5D5D5C59625F635B62
6361616464655B5E666461636461636464616662645F645E645B625F625B5F5D645C656C
675E68676966686B6768676969666F636568675F6968676669696C666A65676565686766
686A6B7170706E7173686E6D6B666F666D6E726A6E69706F6A7269786E706E716E70726E
69746F6E717072736D717B757E79767A73797D786D70746F75736E73717676796F717278
767C727C7F7F787B78797D7B78787B7E76797B7B828779837A837D8183817E837E80847E
7F82817D807F85837D81828686848785898084878889838381818A8787888C918D8A8F8B
858C8A89878C8F8F8C8B8F8B898C898A878791888D91928D9287928D888E878B888D8A8B
8D8F8C89919186938A8991908F878B8286868E878A897F848C898688838487878580897F
89898683848382847E81858186897E76807C7E83847C7D8077767E77828379797C7C7A77
787A7A797A76747C7A70717A74738578777674716E76776F78737A787079796C6C776C6D
716C71696F6F6A6E69686D726E69696D6C6C6B6A6D666A6666686C70697667636668676C
6B6066676B626A6B696B61646A6C6A636166645D5D6F665D616062656561645F60625C61
63645C656963636662666460635D605E60655B686765666463686C6A635F5D5B63646262
5C60625B645F6161
5B5E625C5C6459615C5D615C5C5A635A5C64605A5F5E69605F5B605D5E615F6069656460
60615F65635A605D616463635F6665645F616B606664635F63636C6D68676363606A6063
6C686B5D6762606C6968626469676366636966696167686A716863606669646B68636A6F
676A6C626F706A6D716E67646D706F706D6B7871726E716F6E6A6E6C6F6F6D6E716B736C
6E706A6C6E717F7674707D757579777076717370787677736F767474706F736E77707373
738177717A807C7B777B707F7F7D79847E7E807978817E7F81877E7C85867C7A7C827F8A
8A85867C868483877B8A8B85898087818081828789827F878B8C888D8F838D8788848B8D
8C89928C858E8B8D87948B8D918B89848D8A8E8D8E8D8C87938693868A8A8F939387878F
8D8D828B908E8D8E8D8A8D868B8D878F8F87838B8E8A878C86888D888D8A82858886827F
80838484878280807C82808480828587857F82817F7979787A7A797D7F7976797C7E7C78
7F7D797B8073787D7B777E74757771777378747370746B7572737D70776E747072777772
726C6D6E736F6A7272776B67726A6A6A6C6C6B71676D6F6D6263696B68686D696A656B6B
676A6667686A6564616B606B686C61666562696462676863666C6265616766616160625E
60666262615B636360645C645A6261645961645F585A5C6A6C676065616A5E5E60646760
596464635D625A61
5E5B645F60645F66585B5E5455615861626166606265606165625E646564646257626260
6167625F5E5B5E5F6268655E5C6268625F5D68635D66605C696A6A62615F63696566645F
62676A676B6664676762686A6C7268666A666B65686D646667686A6A6866716C676C636D
73747465646C736C6E656F6F6F6A5C706A676F6C6C6A6C6F676D6D77706F757676737676
74737175726D706E77797575707873737A7C7A717B7371767470786F727981737B7A7078
737A7679787A767977797A7C7E7F797B7F7D7D7C7F84877B7983837E7C7F8A887C838384
7E838986848481868488828783958585858C818D858B82828C908C8A8A8A8E9492858C92
858E878B8D8991898A8B8C858D878989848D8A8C8D8F878C8D8486898B8E7F8A8A83868D
8A8C8B8E8F8C8C859389858D91888287868989888D818D838788838E89857E8A8D7C837F
887E8382848B887D808A847C808080817E8182867F86797D7F727C7B7E7581797B7D7F7A
7E7980797B7A7279747773777A7E796F78787775757974787E777073737174797C707471
777370716E716B776E6F666A666E6F766B6D726B70686D636A6B6D6A6B67706E6C656469
6E6465616261696363656A6166675F67626A6964696363676D62676661635E6662636864
6064695E615E605C63656560645F5E645F5F60615B666262626B5C656761665A5C605C5C
62685F665F61575B
5F5B585B5D6460605D5D5E625A5F605E5E6269625F655D5D615E5F6965655F62625D6561
635F615B5D66636F5D645F67635F6266675E596B596466696062616D65615E71605F6660
63636561686468676A6C717070676A63696E73675F666761716B666A6A6B6661636A6968
6D69696E6E727170696F716F706F70716472656D6F706C716B786E6871747279706F746F
717573797871717875797C747C797676747A7B7773777E7873756A72707D7E747B7D737B
7B7C7C74777975777878827D7A817D7E787B77827E81807A80838079858280848381807D
848D818085828683878887878D848C8E81848583859189888B8B8A87888590858C8A868A
8C90898A858E8D8890898B8A8E878D8C898E938F948B968A909086868B8C9091928F9090
9096918A918A8D95878D918B8A909192868E8E888C858C8D88818588898C828785858582
898B7F847F83807D84858981807C7F84827F8481838A857F867B7C867E817F7E817A8375
7A7A7E757D6E7C7573827E7673797B7F7C7773757975787A726E727B6B7A72707176706D
6D707068767565716D6E676A706D666D6D67656D616A71676A6F70696C65656868676F67
6967696B6269695F666766686A6D6461635F63666366646467606968666166616464605D
605F6162626460636262635D5B6167615F62605C5E6362606061635F61625C5B63615F5F
6761645F565E625D
5D5361635A5863625D5A5D66605F5E65606B605F685E6860646459615A645D5D645F615E
60606364675D68655F636C63685F67646862635F68626367656364616864686769606467
676666606F616C6C6D6C6D6F69666A65636E6262686C656A6A656C65666A6B6A6669686B
6B686D6B756E6D696E7068666E6A70687070716D6E6A73726F6F7570716D6E7470766575
716D736B726B7771747176757476756C7E7474777C79727A78717D74777A7B7579797879
777B7B7982797976807C77857C767A827C7F827D807C8588858E87867E7F8782817C8182
8488848C8485848C8887828786878D87858B8A858A898B88968D908F8B838F8F908C8A8A
9395868B928E8D878692918F9A92938E908F9188918C928C8D8B8D8B8A878E8E898D8886
8F8F9091938F9390958E8C8D878E8D8C8B8B8D818A84928A938981828C8A7E8A88858C8B
7E86828378838484877F7D7F807E7D8A81838280827F8D7B888782857C7E7C7B7F818182
79807A77757F7F747A75798076797277717A72766D7A6E6F7676767573707B77727E7377
6D7B707472716C686F6C71746D6D6A6F70736C6D6A6C69726F66686B70686A6B716A6A67
6F6B6A70666B686664646C6861666567656261686A60686167675F6865636565705D605F
62635A615A675B5F6562635E605E61635F6260675B6160605D64655E61645F615C656863
6263625E5F5B515A
5D63585C5F5C5C5C5859595F5C5E60646461606161665F616964675D566360615E615A5F
675E605E625D5D6360676A64695E64666268655F6168696565615C5E6A68606565616064
676768685D666A69697171676A67646B726C656A686765686A6A6A676B68686B6C707169
67746B6B676A756C6C6C6A6478726E706C65756C6C707172726C6D716F66736F72716B75
796F7076747771757574757871777D6E7A79766A757272717283827E7D7C7C80717F7D73
807C7F7A77777C8875807E817E817D777D7B7F7E81848282878782838282827E88898182
8688888489878488848284867D8684898E908E87898B8D85848B928F8E828D928B93928E
8F86898D968A888985948A898F908F8B8B928E8F90908F96899291948C97988C8989918A
9A91978F938C8F8C8B92919395898C8C8A898F888E8B898384848B8B8685838C868B8A87
8D888982827D8684878282827E8580827B85888183837A817E87807D817C7C807E7B7E7D
7C7D7F7A79777A83737779787B7D77756F797475737674727675747571797877736D6E7D
7174756E75726F6D686B7069686D716A6C71706F736D6A6A6562676F6A6D6E6C68647263
5C6767686668666A6C69645E6B6467606862646B63645E645E686160605F68666069626B
6562616362655F646361656561605F6565615B665E6564595E696664616560636060615E
615F6062575B585A
5A595B5D5E576861596561625C6160695F5F655B636160606763685E6361625E6461625C
5E625B615E676864616B6262605B6167686562616563626566616162636767646967686A
6A646A696B666C7077676D656766686C68716462616666646569696A686C6C66706B676A
6B6F716F6B6B6D726E6D726B6E6F6E6E6C736A6F6C6A6D77706C697472717072726F6F74
757274746B7376767B6F807874767D817A797E7776767F747A7476757F7772727B77737F
787E7F78777B827C817A7B807B82837D7C7F7B8178857D8083878C8A838382878B838481
878B8486878A7E8385808986878687948C867F8F878E908B8D91918990909088918B918C
8B8A928F929A8D8B92888894948C9383908D908E8A919293908F90928E948F9191978C90
96949392968B96918F86938C908E8D8A85908E8A858D8F8C8689828C898A8B8C8587868B
8A858A828A8491837B848184867E86808482897E7C7A79827D7D84818082847B817F7979
788072727E787C817A7C737D7A7F6F7878767A72757172797874717378746D7477737170
797B7671796F6C786D706A676A696B737271676D6F6A6167696B7069666D5F6D63646869
646D686367666E68666565675F68636867605B666561646867615F6365656464635F5B62
606067655B5E5F6966605F665E5F685E6060676461645B615969605F646260565F5F605C
626B5F5E5D605D5B
6060605D585E636659605E63605F665A5B5D635F6060585F5E676263616064625F63655E
5A645F63665E62625C646167646A6560606266615E6A6566656963646565646765686767
62605E696B6467706C70696B6E6E65696B5D6067686560655D6A6B6769696E716E74676B
696F6F6873746972756A6E6B7270766E726C6A6573696E6F737573737973747171757169
6A70737672717C74777773747570787A75777777726F7574757F73837C7C797F787A7977
80797B79797D817B7A837C80818081828281868185808184857B82808285838588858685
84888689898E8786858885868C9087888785877F8A8F8E92868C8C8D958D918587878891
8B918C899587908F8F8E8F8E8E9694938B8B8C8C9796978F8E918B8D8A968E93928D928F
949190968F91909A93918D878B8E8690918F8C8F888F91808F93888C888B898A96888884
878782828C8A818384877C847F7E7B887F838880868781817881837E837C7C867C7C8082
747F7E82817A7C7B7B7876757A8776727B7277787770716E747877757671756F73727175
737276706D6D6A6D707A706D716B6F6C6B6B726D72666967726F696A65686D686A685F68
6D6A705F696B656162636B696368636C6766645F605E5F6766596264606C5E6260605D61
61645E6263605C69635B616262605F645F616263666065605E5D655868626663635D6461
62615F625B5F5A60
5B5F595B5B5B60675C64635F5E6258666063626161625F63645E6158625E60615A616263
5C67615F6464636165696062636068606367656361606767625E6967696669636668656C
66646C64626D6B6A6A696F62736965746A666A7368676C6A64666869625F63666C6A716F
716A6B6F696D6B6E646A706770666D6B6E6F6E6F6B6E666E6B706F706A6E75726B776C72
736F6E74756D6E74737976727275746F7A787877786E6C7872787C827A7B7C7C7C778376
77787F7B757C84777B7F7C7A86817A828886838382857D78828685877F85848484888587
8E8A848B888D888E8B8F8D8D8B8B888D8C90918584948E89889795948C8F938B8D95898F
8E898C9492878B8F908C8F918D909390948E908F919C9A958C968E8D9291939087909791
938A9893938F8E8C8D8B8A858E828B8289918A8B8A858C8792868A898885838A8A8C8991
86898981808487838885847F828480807D83888A828179808384877E7F7E807A7B75817D
7C7A837F7C83777F797B75837C797979728578747A796F7C7A7970747477756D857E7D7A
75716F727675746A6C6B70716D6B71706D737471696C6C6A6C6E6670686A6F676467696A
686B726A6164646468686C6C6A66696962676161646263626160616660645E615F65605E
5F5F5F63675962686464686163605F5C62635D67645D5D5A5F61645D6465675E625B665F
615F555A5A59565F
5C535B5C585D605B5B6359675C5F625D615D5F5D62625F656165635F65615D6666616260
646260646068676A63615E6762645A6B64605E64656465686869646B67666265645F6A68
6661695E6864656968686E6668696F6B6166666A686E6B6D706E67646E6E6E6B6A6D676A
6865706B69716A69686E676D6D696E736A71736E6C6C74696B6F74717470737773766F72
7C7970746972786D747572767979797E797C78767974757C747E7B8077827E7B7A767E7D
747C7F757B7B7975827A7C857D7A7A85848A7E8881888685868382888188818E8282898D
8B81878A888B8589929287919389888E9491908B928B948E8E8E928A8A9292928E968F92
89909090938E958A998C919191978693899594978F9892959196918A968F91918E909391
8F888F99949497919290898C8F88968C8A908991928F8B8787958F858590868C8A8A8481
8A808C8A8288897D848A80848B7D7A7B888387867F8283857F7F817B7C81807B7C7E7B7B
7E827D7E7C7C81817B817D78807878817A78797D787D7B6F7779767270787572797C7979
787E7273726A6F6B756D6B6C6B726A746D72756E76736D616B6E687067666C67686D6A60
696667686E696364696C6C5C686867646366696A656B636161636568625F625F63615764
6362635D5F61616A65605D6163685D6960615E66615E6161625E6164625F685F62696562
5D5B595E55595D60
5E5C585F5861615A64615B6A605A67655D5C5E5C5B5B63615F5C615D625B5F615D635962
5B6163656364696361636263675F64605E645E665F606561646B6C656462656566606569
616866666C686E686A71706B6B696D6D6A676B6C686B6F6D686B676665666B686E6D6E69
69686F6E6E6D6B68716F726F6C746E6F68706C6D6F6D76736C717079766B777271717976
6F736F73696F716D737379707A78777571797877787278787F8083827A7D7F7C78827F7F
7A7A7A727D777D7B80807D8082878481777E8585878A8783818586828987868D838F8886
8C8C8A89918B8B8F8E8B8D8E9190928D938A95888A8E8E908F9092928D948F8F9391898F
979394989196948C8C8D90968B939093978B8E8C8B97948F969B91929193929294948C8F
97928C948C929790929A94909089888D94948F8B8F9395939495968A8C8C868B84928A88
82888D888C8586828C7F848C848B8183867E8384858583817E808085858181807C848280
7E82857D857D8181797D807C7E7976767D7A817A75796C777C717A7B7177767C7B797E75
7A777175746F737076776D756D6C736E70696E76716F67726E726A6A666C6F676C6A646D
626B666C606169636C65687064616B626A68646465636869695E616463615C62665A5E5E
6466635F6565605F5F5D635766646163605E646262616163625C5E645B6562645D5E6360
615D64575F4D575E
5E5F615E5F5C5B5A606365605C5E5F66685F6A605A626062615C5F5B6B655D5861636362
6963635C64645E5D6D5D645E6563676367656A6A606461646666695A6260626465666764
6167646667666F636F6A6B6A68626A636A6D6F726C7B69646E6A5B6D6F626B6C6C6A666D
726C6D5E6F66706E6B726D6E74756A716873696D6F727278766F6B736E77787A766E7673
7379787571747875747376707D72737D7974767981757A7E7881827C7B777D7776797C76
7F7A7474767D7E7C7A7B85848380838984868386838D8A87898586888D88858B8D8B8D8B
88888F8B8E8A9087878E9A8D89908D8F908F8992958E908D8F8E8990898E8E8F928C9592
9190949892949292968C92888A90898B8F89989A9491928E8F949298938D958D9691948F
998B95908E958B9688908C928C938E8F8E8D908E8F8D91898A8D92928B8A8885888A8C8C
89838A86869086838A8184878E7F7B8C7F848680848A7F85818685828185847C83787A84
8680837A83818187807A82777D7B7D787B83747075777B7C7B73767A6B777A787E777D7C
7478726D736F6C7174776C6C6F6C6E6A736C6C6D736F6B6D726F736E6869657069676F6A
6C6C62696467676B6B6B70686B6869636D686B6564656167656062655B5E5F6569635B63
645E65625D62646B67645A605D6A605D605A5D63625C686064625C5D5B61656162606C65
5B645F5B5F57615E
5D5A5F606660625B5D5F575F5A655D645E6765595F605E675A61625F625C626260596260
626366635F6367695F606C69616169606A6966616762636864656D6C6A65666263626461
63625F66666B736B6A6A686A6B67666A6670686A636364676B64636568646C6C7067686B
7267666D6B6D666A6D6F6A6A796F6E79777172736F6F72756F717270767170747A6E6B74
7072757B737A7578777873737D77787B737A777E77817F7C78747B76857C80857779747B
7B7880797E7D807F7B7F817F827D877F82857D827E7F8B878680868B7E8587828D87868E
868D8688858E8F8E94908B948B8A9292938C908F8F928C928F928B8C92918E968D8F928C
968A90989998928F918D908D9692939295978F999B9391999A919886968F8C8C9591979A
948E9E98949191919592898D88929494908D8C8C8C929291888F8B908C8D8B8C8B918B82
8B8B86908C8D837A818B847F85868184878D837D838286797F7F85838285898183897E79
807E85807D7E817C7F77727A747A7A7D7A76807973777B777C7A76797378777776787379
776C6C6A6E7872756E737368716E6F6F6870706F6E6A6B6F686B686164706C6E6A6E6468
696966656A675E68636B6A655E656A676A6962636C6C68675E6660615F616265665F605E
685D5E6868625B666261605A5A5A655D5F605E5C69625E675F5B62665D5E5E66616D6163
645C5B5C5D5E5C5E
6361555D59595C6361605E5F576067655D6360605E5F5C5C60675E645C676262656C6161
5E62685F61645F685E6A636162646B626A665D606568676663665C675F65656969646764
6165616C695C6668676A6967666B616A69626E6B61706B6C696F666D6B6C646A6D616C69
70726A6575686A6F6C6A6C68746F706A7270786D75677772757479707678757175757571
78737675747576767F787B79747E807D767275787878767A7E7C7C7B7E807F8288767C7F
807A7B7B797D7B797D83898380808B858283848B82828789849089868389808987898E81
8D9087848B8A8C938C8E969496948A91948E908D8C8E93918B8F918996958C9393939693
8F9293948E9D8D8E9B8F988F98978D948B929696979290919895968E949499938A919190
9A91948C96968F8F9990909492938E8C8E97959295938D90908C8D8E8D918E8A8D8C8E8F
888F87868588888C888685828A8A8586808A8B847F827E848581848285808D807E837F83
818A86848A8180817E7F7C787B7D7C797879797B7876727A767D7A7B7C7B777376767681
7172736F716E746D70756C6F696B706E736C697171726F69696E696F616B696F666A6265
636E686A68656766626A656A67656B636D656262656860686664616C60655C66645E6361
5C6263676761665F67625D6162645A65625E64625D5C606162645F67626264615F625E5C
5E5D62615F60585E
615F5E595D5D5D5A615E655A615C5C5E63675A65626063605D63645B615D635B5E625E67
606265615F6466625E6360685A686967646662676461646261586365656D6B606663606A
665A6A6869696B67656B6B656C666C656768676D69696E6A6E6872676A6F69667471676D
70686E6C6F696A6F6877726C6E746F6E706D726E7271726D727172717875767474787370
72756F7478766E71747574717C7A81797E7F827778767D7B7B7B7F7B7B7C7A77807A7E6E
7C807976807D7E777E858687827D828A8489868884898284878C868A86848A83928D8184
8A91878B8E92968A8C8F94949091928F8A958E8F9A8D939693948D979590968D93949295
9797948F9497949C8C92909A989691938F8F8B959298979C9791919D968D97939B929496
958B9895968E919794949194968F9493998C909695938B84938D938A918D8D8C8A878990
868B888D8C8684898F8588898381888D858483908185827D80838284838481877D868584
8285808580777F797F75787F7B787A7D7B7D787D7F7878777278777679777B7D787D7276
74767A73797170736D70727474736E74716E6A6C6F6C746D70666C66656A6A696C6D6869
6A616E6B61676A6B6E6A6B75656D65686C6662646260635D5F676C665A5D636361625C5E
585D5E656A605F6661645F64665E625D6663625F6761605E5B63616460635C5E62605D5D
5C5F5B59635A5D5D
5A6060605E5D5F585C595960605F616460635F62625A58615B605E5F6060646461645D59
64645E626060615E666265676468686C70686768636364616265605F6466636469696464
616563676B616E64666C6B6D65676C666967696A6A6E6D6F6A6D6D6469756B6F69696A69
6F76727368686E6E706C686D716E767870697866766F807374756E747277776B6F727372
6E7B7A787D767B7477717277797F797B7E787E7E7B82777E797F7E707C737D7F7D7F7782
79827D7C807E80807E8284867F87848582818286898A85888887868785888C8A8B8D858D
92878E91928E8B9599948A94898B8F8E92928D928F9492908D8E958D9495919488918E90
96949197908F999B95938E919590979795958CA0948F9D919F939687A293958F92999695
979696979594928D968D919B909793988B968F8C989795998D988B8F8E90918F898B9188
868A8795888D898788848683858B8F8C8087877F908B7983847F898483828D808B818184
838185887E847A88817E7C7F7E787A78787D7C78787976747D76767A7A7A7A7B79767C71
6A79736F756F736B6D756B716E6F68716D726D6F6E706C6D6A70666C706967696C686D6A
6968646D6B6F696669646E657265666969626067655F6068696E606466646365645E6569
5F6157626065606260646263625F5F60626066655C5A655D5D6854595F5D5D615D5F5B66
5D5D5B575B595C58
5D605B595E5E6063585C5D685E6464625F6456615E62605E6361635E5C66615E61616160
5D60655C5E5F606362626563666669656B6A62636A62656E666567656165656D646B686A
6469686763616A6A6A696E696B67666B7664616B71716D697069676D6A746A6C6E6A6A70
736D6A716F706C6C6E6A726D7570716E767473737675767B747378767474747171737175
6F77737176756B787374817F7B7C777A757C797C798282807E78788082817E7E7976877D
8079837F867E827A8084867C817F7D82808684888788879085868A87898489888F8E918A
8F8487938D93909492969396948F8F8C8B8E8E8E958E94929498979291998E9990969390
9692969A92948F93919493938B8E989699949E98959C91948F939399999A9B9799969496
9594979C9A9D9796939399959A979B90959895939A94999B9697939696869488848C8E8A
908D8C8B8B94878984888B86838D80818F807F868389848A867E7D8384878B7A86817D7F
858381807F7F82847C807E7B7D827779797E7378757B717A7876797A7F7A787277767675
75737477777873746C6D6A686F6F6F72747071706B6C676C6B6B6F6D6C70736A6B6C6A74
6D6A6B61676667606B625F68666B696C726B6866686768615D6968615F65665D62616263
5D63615F5A61626762656362615E5F5E645E5D5D635B61615B625F645E61605D6466645F
65665F5858595C5F
575F5C615960605D5C5C585C665B5D5E5B5D5E64645B5A5F5A5D6267605A645D5C60646C
6465635F67666867636562656A696865646760646661636562616769636C646766606162
6667676668676262676267666A65686A706B6F696769676A6A696A7270706E6B70707073
6972727E696D69736A6F716E746D6D71776875797372726B70716D6D7B7C73737573706E
7474797F7073757173787C797F7B81797A7B797B797E84787B7E87837B7A737C797D827C
7D83817F807F828186828285858B848A838F8B82828688838187838B8E888C92868D8B8C
868D918D928E908D92939793909199918D97958D999A8A9C98958F928F9093978B969B96
939494969992978D9791939E9496909995948F909290909B9B989A9A909B9896909B9997
9F908F9699949E92978B9B9595999A9797979B979C9492979D9391908D8F8D92848C8992
8D8B858788908889868D838A8983818B8580858289877C817B808885827C858782868081
858280857D7B857C7D7E797A7E788075807779847778807E7F7A757773797B7975737576
73777075707377777173766A6F6F716C6D666C6E746666676A636B6E6C6D6F6A686C706B
616E69656F696C6C6C6764646A686463696C5E5D65696667656F6A656965606965676167
60636063666A665C655F60675C65606265646263665D5B63685C5E5E60605D605D645B5D
5E615F5E605B5A5E
5F5957575B6058615F5E5A5C5D63605B5E605B5D5D5C6462605B5C675C595E635E5C595A
686365616463625E6A626A63676565656B6D6A6E66646061655F686A606A646063616466
6B67675E6466677164636B646668666C637365646D7065686B696F6C74676E6E696B716B
6B6F726B6D78716D706C6C6D736E74737570766F71776F76737979726D75737378706F75
737777737D77767B7C7B7875787A7A76777C81807B7C8283807E7A767C7C7E7C7A797E84
7D78847F887F848A8A888B89867F8883818C868481888A878C888B8D838F898D8D8D8995
8B8C948D8D8E8D94948B9595989191998D938C8C94908D9A90948E938C989997939B9392
919C9E8F989A9893939896928FA099989795978F919898979B9596939394958E9A959396
9891908E939493999295999BA69D9C9D95959E8A95999C959B95949399928B9690909290
91828B888990858B879185808F8B8E8E83828885817A88898086838D7C88848081867D81
88847D7F827F817A7A7E7E807E787A817F7A7979787A7F747978727A7A79777375797C75
72746E7373726F72706F727072666A6A6B6E716E696D656C6F6B6A6968676B726D6B6B67
716A6D66656B68686C68656D656C67686767676863646460686966666762625E615F6461
6864665D656563615F6162665C656263616367605E635F5A5E6163665E5D675E65635F66
6362545B585F585D
5F5D5B595F635D606365645F64605F58605C635E5B625E5B605E61636463636868596168
5D6469676064625E6A6865616169686C676767696A666766646267676864646B6966616C
6A6E656A686A6A67675E677067666A6463656B6A66636A646C73706D6C6F6D6D74736D69
686F6D696A6C687771746B72737173787C7070786D727675717B73737478767778747A79
79786C73767777737B797C7678807E767C847A817C82887A7F7D867A7F7F7D8480817A7B
8284818B848F808F8388878483868587898587878D888A8C8A8B958E8A858D978C8E898C
89908F8D8F909392948A939B8D8B9594989798958E979A949E98989D928E959595949D93
8F9C97939797908FA19C9B9E9C9595989694999A999E94949B9B969C989C8D96979B9694
9795979C99959896969B97939E91A09A9B9298A2999D9BA19AA19A9B9A9B9495918D8B91
8F918D918C8D858C908F8B8B8F8E898A8B8881888A847E818C878D88818487827A858C80
7F8384828285817C7C8386817A7C787E77797D837D7F7879827E72767678767E79747773
77767874707273757272746C72746C6D6C6D6870756D6C6A6C6D6F6B706E6E686D6D716E
64686D66726D65696B6C67716A676A5F6A66656369646669615F65626262666063686864
66605F62695F66646162696360646369616163635E63595C5D5E625F61605D635D5F605D
645D5B65615D5A61
595F5F596268635E5C59605E625C5B655C5E65675D5F6066596060696059575D5F626065
5D615E5D6161615B665E696466656B666563626266616769646266636765646D666A6069
626164636E67676869656966656C68676C61716E686C666E716F6A716D6F67696C6D6973
6967786A666F716E6D726B6F736F70756970776F74786F727672727670766F7974797773
7D73706F787E7E707872787A7175837D7C7D7D7A7481817884817C847D7C7A7D85807F85
89868E8F828A918C888C888282858581878A8A8B838E898A8F87908C86888F89888D8A82
8F8D8B92888597928F92918D8F8D949895959C96958E9B9D9A999999989B969B9396999C
989E9894A09E9899919A9C9797949699939B969893989A989E9F97939695949B94959198
A196989292919D988F969596989EA49D96989D99969897A19AA4A1A4948E9C948D918F8C
948C8E94868F92918B888C84818987858B878387868B888080898886878286897B86807B
7E87807A8B857E7E887C7F7C827D7D7F797A7A7B7677837B7E7380797A706F727F777978
7876737774777072746E79756F6A70666B7073736E6E686D6E6F656B6A6F6A6B6F73736A
68666C6765656E636662636A6F5D6D65686C636267645D6C616665636D6966645E5F6762
58645E645C6761676264605F63605B686D6165615E6859615C5F5D69595C5C5B63656162
5C625F5C595B5C5A
5D5D5D595A6362645861655E60635C625F5F5F605D5C6862645A5E5C6163606260575D5E
5E665C5E635C66645B67656666636366656764636767656E62656D686E67676963666463
60666763676565666B6C6D686968686B6B70686E66686B706D656E6F646C6E686E70736D
756D70697073676F6D716F7073736C7273706E6D75756D747B7A7A7A767678787776767F
74707A7D6F7A797476767682767D7C7F818480838080787D7779807A7E7C7F7D847C8285
818C898D8989878789868C8984878A8987878D958F888688888A87908D8A8F8C8F919391
8E8B8D90969695939697948B969291989C9093939296A1949291958B9A97989799939C96
9A9C9295929096969794979699949694969BA19F92929C9898A1959A9A9797949A959797
9D9C999D979998939B959B9E93A19D98969C9FA1969F9DA2A1A29D9E9F95A3959194938E
8E8E8D929293888C8D8D8A84898B81878A84817E888A8686858A7F8480897A87837F817B
7F8387867B858581807C81817B827A827E83807F817A7D7A7C7E79777F7B7A7A79717779
73756F74767278756B78747078726E7568696F6F7168706B6C6A656A70746B69706A726C
686D6C6D6C656A6B6A6D6A62626667626A6B6861685E666C71676465646A607567635D64
67646966656365686463615E63645C5C6162625E6266635F67645F5F65606964625D5E62
5D645F625B595C5A
5E5E5F655F5B5D5F5D62635C645E5A655C685D665B675B5F605F6260615F655D5C63605F
5D5F5C61666462625A63675F6860656666606968676266696C6668616B66666660615E6B
616869696874686A6674686564626B6C6567686765696C677170666A686E716F696F756F
666D677071726D766B7473746A73726D7578766D716F777473787470716B76796F7A8074
7A75797D7C7D807C748271827C7F79787C82827A817B7E777A80817D827D7B85817A807C
8485858D8E8B9B8E8E95838A818588858B8D86868790898F8A8B8E8B8A8D93928E918D94
8F8A938A958C938C979493909A94979889959A949EA09D9F989794A39C999D989A9A96A2
9AA0A0A49897939D9E93989E979A9E959C9A9B9A989F999997A09A9B979797A0A09F99A5
A29A939B92959C9996909DA197A798999D8F9B95A29FA19FA1A9A79EA09C92929592959A
8A948A8E8D968C8A8A8C8D90918B8880848A8588898A84908F7F867B88838289837E8B86
80818686867A7E817F7E7B807D7E797D7D7B7C7F787A787B7F7880708379737D776C737C
6D737B74787A70727379736F6E72767773756A6B716D6D6773696D736D6D70686B6C6C6C
756F6B70676F646A656D6D65686470666A6A5F676B5F66636667606862676B606B626565
666C616960646267695E5F6364645F6264645D6666626263635D615A605F6065595A605E
5D5B615D655A565B
645E625D595E59635F5D5D62655F6068635E5D605D595F6362655A67615F5E645B606360
5B5F60675C5F656065676A5F656164636664655C6B676B6A6C676B6C6566626464646A68
7066666B6B6B6E6B6B70696B696D61656A6B6269696C656E6C6A6E69657067666F6D6E6D
6C6A6B6F796D6A7271746F71746F706F73717D73717075706F7B72777A7A737A6E777479
7A797F7B7A7F7E74797B7A7A7D7C737E807B7F877F7A7F817E738A8281897D877F868284
81868D908B9095959691918F827D818983868A89908B868C8C8F918A92918B8F8F959097
918A988F918F95909297958F8E97938F8F9A9898909FA19F999F9AA29F9C9BA19D99989D
949B9D9D9C9797989F9C9A989A989990A196969D9DA19FA09D9F9B9B9F969B9AA3A09F9B
929995A098989B9CA1A397989296969E959F9F939D9C9FB0A4AA9BA19F9696949398978C
8F9990898D8C8A868F908E908587898A8B858A838A88857E7D88868C85807C81857E7D84
8483838381827F7E848381827B817F787C7C7E7D7D7B787D857C7D807B777C7972747C75
75727C7973747779756B73776D6A7C72746F6A6C74756E697274646769696E6A68716E76
706C636F746D6E646D6B6A6965696D686F65656562686C666564656160626C646460606A
5F65615B6A5C645D5F6663615E625B676362625F605F65626163605E6363655D5E5D5860
62655E61665B5760
615F5F6064616361605B5A655E5D625F5C6564535F625E5F5E5A5B605F656061625D5D69
625C5E6164625666626560656A5C656A66636D64656568686C6B6867676E6661686E6C61
6A676C656F73706B64686C6B7069616B6D696A6A676C6F716B6F7169656E6C6A6B756F6F
6D6A6F716F6B75786F69726C6C737170716C77756E7873787774767371787875807C7C77
75737D7B767979847F7A777E797F7B797E7D7C86837C7B837C7E7E817B82878887888B87
88898F8B8B939194958B8D86848D898A8B938D8D8F92898B8D918C8B8B848C8A90998D8D
9098968F9798959491968E968E949A959693989C949A9D989D99A09B9995989B9C9C999E
989A949B9F9D9AA49F98A09D98979CA49C9F969A959D989C9C9A959C9BA19F9C9E999BA0
9A9B9B94989E9B9A9C9B97A2989BA1A09E9B979E9B9F9EA8AAA49D999D9C94949294948F
92908C96928C918F9888898A878B87958286898480868580838880888084878384817384
8D7D798586807879818386877D7F7B7C7F8077817E797F7D727E827B79786B7D767D7378
797072797D7576756B6977767074707170726D736E7171706578696E6B67736C6D676B71
67747A6D6769686B6669666964656A5F6C676B6A7165686060696B695D5F665F5E6A6264
65606465655E6067626662685F645F636468645F61625A5E615C5F58685B55645E61565C
5E6364545B616061
5E59605F615D5B6661645D5E645D636361636761625C616260696365615B646A5D60626A
5E675D67696860675D636B6762666762696667626064676867686E696A6E676561686867
6C6A686C66676A716862686C686C6665686E6B716669666E68656C6F69726B716F766C6E
767277736D6C707470706D72776E797874707274747A737472787A767A71797679757376
7D76797B7475757680737D7A7C7E807C7E7D817F7C807B7A7F827D8884827A867C838D82
8A848E849392969685848D878B88848D8A828B848C9195938890898C9494949485919091
97969596949F929A9491989D8F8D9D9B949794989592A0999A9E96999A9C9F9C979C9A96
96A0999EA49F9A9B949C9F9C9CA19AA69DA19E979B9698A4A09AA19F999A9FA1A59B9F99
9A969F999DA0A09D959E8D92A59A989E9C9C9B9A9C989DAA9FA1A49A8E998F9392909490
948B8D8B938F8F958F8B8F908F8894928B8F8A82888488858C847E868C807C7D8786838D
8681838C87867F848A8782787D83877F7E7B84817B7E7E7E75857F7B76747E757B737379
7E78756C7573717372747273736A6C6B756F6E706A74716B6E6867726E71757372666867
6B6F6B6D6B6E6A66686C6A6B66716B6E6264686A62675F656169585E656B6B6068636562
61656760625F645E5F6462645C5F5C656067665E5F5C60645E5B585D626060585D596560
595E596365605A57
5D5C5F62605B5C6160606162585C615D62635B5F616561625C66606165616761625E615F
5B5F665E65675E655E61646D686261666669695E6C626864656D6670686E675E65676861
666A6C6B6769656D6D696C606B6D686C6E6E696D6966646E6A706A6C6C766F6D726F6975
6E6C756D6D737077726D71736B747378756C6F74797D747570727A7B717578707778807D
7C7D787B7D7C7E7877797D7A837F7D7D7B807A807E807E7F81837E7F8487827F8685888A
8689848E90959591918C838A84888A84868A8C898D988D8F898C8597979189918B909091
92908E96979694928B8F91939A9E92A29C9A9B989D9F95969B96A79D99A19CA79CA19C9C
9B9C979E9FA1A29C9C9CA6A4989B9B9EA09C9FA1A19CA69D9B9DA89B9B989AA29F9FA1A4
A39C9BA198A09F9C94A0A397939998A09B989499979A999F999DA299929A999994968C97
948E9191949491939A888C9088919287928B8987888A89868883888F87808C8182808280
828B86897D8D7E83837D8080827B848C7C7B7E7D7E7D7D767C77727F80827E7A7D7A7376
7C76757674747A767376756F6E706B6C726E6F696A7677746F6C716C6D6C6B726A716F74
777071726D676C6D64676C676F6D676A67686862666B65645D60636562676369675E6164
616662695F5F6A685A5D5F645F6768636263636560635E63666066625D615E585E5F6062
5E595C5B62636063
5F8369575E6066655E5B5B5D5F62675E5E606665615E5D5B62595A5B655C605F5F596C60
616763635E655E6765606A6566656365666B5A65676963696A646868676369615D63625E
676E6570696669706E6B6F646C68676D716D63686A66677166696D6E6A69727074686B6C
706F7175716A747170757171967D727572746C6F717B777A727473767671797178747576
787583787C847E747F74787B7C7D81797881827B8787817D7B7E7F83827E838D83848B82
8B86918B8C8B8E85948990858F8F8B9283928D928D8C8E929294929190928D908C99948D
9094919899979994969C91999C99909A969998A89D979A9B9A9CA19D989CA79F9A99A4A1
A69F99A2999C999F9D9EA39EA49EA69D9BA7A0A09D9B9EA09BA39FA39FA3A0989F9AA3A2
989D9FA5A19999A0979C9A949797A69895A1979B9D979D9E969D949F9493938F8F909790
9693868B9393958889958F8B8A8D8B8F8C8D89878B8F878886898C928B887D8386858085
7A827D89878A847D80827C7E7F7A75827B7B7D8377807B7A747C7D817A7D7D7C7D6E7C78
79777477787078726B73697176757374706E76746F736F6C69656D7473696F6F74716F66
6C676A6D71656568726E626C69606772656B63646E696062626D65626669666B6A666664
695B626963636C6664615D625C5C626061636964616264655B635960655C5960625E5D59
625A5D605C5C5C5C
607C65625E6061645C595F5E586063656A5E5B5D615B60625F5F60625F646464605B6061
65685F666365645C6263666B706B6168645F64666E726D62676D64646C67696665656965
67696B6B6470706E6E67686B6A6A716C6D6C6C716B6C69696A666D716F706D6D71776E6F
6B72716B747176727974727183737A796F757974797A70777470766B7673787E79777B83
7A7A7C7C7A7E7F7D7C82797F82757B7C7E858182777E857887847F8186828A7E838B8689
8387888C87898C8F838E8A8C8A8F8993978B8C8F8E8F908F938E919590909191978B8C8C
929C92A1929294979598989F9F9BA99F95A39A9A99A39BA1A39AA0A59CA1A3A69D9EA1A0
A8A3A29F9C9EA2A1A1A4A7A6A3A4A49EA1A3A6A198A29FA2A4A3989F96A0A3A5A09F98A0
9CA29FA1A3A29F97A49A9D9D9A959790989F9DA2969A9C9994949A9A9A9698929D97978F
92938E949596968C8E8E8A968F938B8B8D90838AA1A08A8A838B84898585808484898784
8682807F8285848579808A8A827D7A81827E7F7F7E81817C81797C7B747D787F7E727A7D
767677726D777B71797776746C6B736D6973726B6F70706E746F7778716C696C6F6D6A78
71706C707064676866676A6F6D68706E6A6F6465676C686865666468636969655D615D64
6861685D66696863615F62675F636A6562616161635B60615B60615A5A615A5961606264
61595C64545F5C5F
695D5F5F615C5F67636A64645F5E5C5C585B655B675C5B6262606160636B655F67636264
5A605D686B5F675F5F616266636969646662625F6C62635F6A6367666569625D64686C63
62606D686768696A6D716969686F686E666A6D6D67706970746A6D6D646F7272696B6F6E
6E6C6D6C7379767376716F6F756D71726D7A7872757C707275747C797B757978817A777E
7E797B77757F827D7F847F7B73827E857E877E7E827E7F85897E84818481858984838B87
8B908889878F88928F8B838E8D8F928C9D91938B9188908B958E8C9593918C9196979392
998D8F98979E9296969C9E9E969C95A095A19D9E9A9C9F9DA39B9A96949CA89FA5999A9F
A2A1A4A09FA09FA49D9E9F9BA3A79EA09E9D9B9EA7A198A09A9F9EA1A19A989FA2A3A4A3
9DA29F9F9CA0A096A2A09F9D9C9EA0A1A19D9E9C9C94A398A099959B91959B9396949898
8E9389979792978D8D8C94998D8E898D8D8A8A87FFFFF68887858B8C828688848586868C
8C827F82827F857C81888A80838482828276817A7C797B7B83828582827C7E8076797876
78777278707A7A746F74746E736F74676F706D6C686A6A70726C686E6C6D6A68716D706D
6B696C70696467696E67686A6A666D6465675F6669676868696A63686364636069666462
63686466646665615B64605E6463656364636064645F675D5F6761645D5A5F695C5C5D65
5F5F5960645B595B
61585F6765606664615E6366615E605D6762626061645F645C5F6262596264645B616661
5F64626661605F5D6267655F6D5F636860696A656B6660616B6D6A6F6064606A67636D5F
686E6A6C666B696C666B63696B646A676F746E6F6B6A6A716D6C71706D6E716868737273
70726B737175747A75716E7375766F7470716B7A7472767B7A797974757D72747D79787B
82787B7C857B7F837D7C79877D7C7F817B808285877E83838084848C83857F84838A838A
88888D8B848A8C87948D8C898D8A918B93918F8F8C8E948F8E8C988F9191949A92999594
9799929D929798959C9A9D9AA297A09CA19DA0A0A2A0A1A3A3A29BA6AA9BA79B9DA6A4A0
9BA4A7A0A795A0A1ABA59BA7A0A19B9CA2A19F9E9F9FA09EA0A4A4A39FA0A4A49BA0A2A3
A9A9A7A59CA49AA09EA299A197A79AA0A29A9F9B9CA19C9E9C9F9D9EA1989B939A908F98
949494919392968D899989898F928F8C88848D91A1FFAC8891818089868F8E838887838E
7F808983897C8A8687817D818381848884837D81768389887D7B7F8B8086837D78757679
7574777772737478767376747575726872767776716A65777975716B6B686F696E716C73
6A6E6E716C6E666A6566707062656B61676B686363606461646667696367646160686365
655F68636566656468615C6060645F635F6562616D685E605C665C605F645C585D67605B
5C5F5A59635C5B5E
605D5F65666761655C60645F63615E62666661645D61655F63605B62636457665F5D6364
5F645F635E5E62656862606262676662615F5D6467696363676C64626665686366636564
696A67666B64606B656D6B686C6E706967676D70726D68696870706A6D6B6E756F69696C
6A786C746A7075747C6F696A7A73707A7672717A737572747F737D75787377777C7B7876
797A7C7D7F7B797E7C7D837D827F7F798484828984797E82818682838486848685888586
848C818D8A8D878A8F938E8A8D918A90968B8D95918B95968D8D8E919499928E92989699
94929B9499949D9C9E8E9B9B999C9E9C9B9AA1A0A29B9AA4A89AA39D9C9FA1A99F9E9F9D
A19F9CA29A9BA4A0ACA59BA8A5A9A19DA09BA5A5A8A1A1A2AEA5A6A59FA29BA79CA6A1A1
AAA0A2A9A2A6A39DA3A0A5A29C9F9C9AA19C989DA2999E9DA79D999B9397999D9D929896
9C998C9597958D918F9796948C918F8D8C8F8B8A89898B838B848B888B82808A8D8A8488
8885897F828789817F827E81797D827C80868483827D847E7E88867D7E82827A79727A84
7B727F79757874757B7272797370A888717473706B6A7472687670707469676A70736A73
65716D6371666766656C6068656A6C6B666C65696C69635F6161665C6A63626966655E63
6B63626961646A5C5F6460685F65656467605F636561645E6964616663645B646361665E
625961615D5F5D63
6259636563666361626164616562616A5C64606259646061625A666563625B59645D6456
66625D636362675F67616464615F5D686665656168656260636A66656F5F6A63636A666F
626263676C6466666B6C6A6E6B666B646F6E686263686C6A7469716A6A68716E72666D70
7372747A7B76747D726E7671757071706F74757576787B817E797B817A7675787E76747E
7F787E7D7B7B7D807F87887D7D7B818486767F8485808987827F868481888682848F7A8A
878887858C8E8E8F918E8D8785988996908E928F949592919093949A9592909A93979A96
9A9D9D9E9D9D9C989C9B9C989B9D9FA0A09AA09B9EA2A5A59FA09F9EA4A7A2A9ADA39CA3
A59C9FA4A09B9FA1A2A4A6A3A5A7A4A79C9EA0A3A3A6A29EA6A2A3A2A7A8A29DA1A4AA9F
A4A7A4A4A1A1A0A69BA09B9EA69D9D9C9D99999DA09FA195999E9A98A39A949B9C9D9B93
9699919B99979792958C948D928D93968994947B968A8D8C91908780908C9283858A8E8B
8C878281817F7E8784848581827C7E83888782887A7D817E847F81817F807B7E75797777
727772757E7976718274796F79718C7A6F70766D7068716E6E71736D6C727368746D726A
6F756C6D6C696B706D68626A68706B6869676B676A62616A6E686F666B6162676A62656C
65615F6A5E6D5F5F5A5C645D646366676862636963615D605B675E615D6766636164655C
5E61625D5C615E5F
5E6563695F666B6364625D60655D5E6062626564615D6460626C675D6264676A61635C5F
6064636062675F676A6164626562636A675C63695B6469686C696A6D676863686A646E66
6B67636A68685F616A6B646B63696B6E70706C686F676D6F666B6C756F6F6B716E697375
6B6E716C757579746D7F7172777973706B7B70757673767A7371787B75767D8074787B7E
7979847E8387787E7F83877C7E8282807C857D89857B7E8C817F82888487818B888B8B8E
8588888D8C8C8E958F8D908C9696909396978B939A909194948C97968F91959A969E96A3
96A0A19E9697989C9EA19F99A497A2A39EA3A29BA49FA59E9FA4A6A7A2A69BA6A5A3A5A5
9A9DA2A9AAA09DAAA8A0A5A1A0ABA49AA8A1A8A3A6A7ADA29FA2A2A1A2A99DA5ABA29EA7
A7A29EA1A9A1A89CA598A29CA2A29DA499A0A19A9BA2999299A2A39EA39D959A96949891
949597979B8D90989D939590959493928F9393998E918D8E8B898B868B888A8B889C878A
898F82857F82848383857E8979818680888B79827C7E8585877E87808283817A787B7975
76747379786E78797C767271716F756F7674797672716A726A786A746675726E6C64686D
6C6F71706B706C6E6A68666A6C6D676F6865666766696765676166686758666069626662
64636D6C6865675F66645F626067605D63646262585E696160656160675F606756606862
5D5D575D5B606064
676869636368685F61645D6C5E635D62606362655A655C5E62616B666260635E62605E59
5964615A6569625D605D5F646066656A686D66626268666C6A5F696A69666464686F6768
686F73666A6E6B6A736167696F666F656E6D6C6E6F726F6E6C6E6C70796E6E6C6C666C68
6E6C767471787272716E7972706B71736C6D7278777076797A6B74767B78707479787A79
797D777D82867B78807E82867E7D85848382857F8884887D858488858686818A8D888188
8C898B888C8890948E8E909293908892909A988A95998F94979491989593929799A1A0A2
98A09E93949AA29796999C9B97A19B9AA49AA0AAA0A4A7A3A0A4A8A9A6A0A4A8A9A6A8A5
A5A8A7AAA49EA5A1A5A6A2A2AAA9ACA8A09FA8A5A4A2A6A7AAAAA4A8A3A2A5ACA3A6AFA7
A1A9A8989DA19CA29EA3A5A2A59AA29F9CA49BA29B9C9A989E9D9B9C9EA6A48AA0A2969A
9A9794968F8C90978D93959393919491958C9596958D8E928C8D8E828E908590898E9089
8B888A868185867C86828684817B7B7B7E8780857F8B7F788582808779797B77797F7B7E
767578797A7A7A7C717B78797370787873737872776E70696E74746B756F6C72666C6F6D
6B6A6B666B66686A696B6E70716B6B69666A6468656A6866686768616662636664656163
65615E636560625F666560646162626367646367635D656A62625E6661695D5E605B5C68
5D61615D5F64635E
62606A6A645F625F675A61635E6161636367655F665E6067626160675D6C66616461675F
5E5F605D65646065646E636760636B696567626663666264646864626C64636D64656466
6D646A626C6A6D6F646A68646267696A6D6172656D716D71746F74696A6C70726E6A6E6D
6E73756F72746E78736E73797279737675757A7E7D72807774756F75747D79777B787A7B
7C80797B78838282788083857A818485877E8489857D818782817F83898E858C818B868C
8B8891878D8A908F98978F9495909393988D929D989196969493949C9B929696A09DA09A
9E9F979DA29CA09C9597A3A09A989C9EA7A5A5A19FA0A7A49EA8ABA5A8A2A9A3A4A2A7A3
A3ACA3ABA0A4A6A6A9A7A3AEA6ADA1AAACA3A9A9AEA8A7A8AAA1A9AAADA89FAFA4A8A8A9
A4ADABA59AA4A69EA2A4A59FA49FA39BA09B9AA096A09B9EA79AA39F9698A09EA4A3A19A
9E9C8F9C939597998F9791958F93938A928F8D8E928F96978E858D8A898A858F8F8E898E
94928A8082867E827E8A85837C8379817D838382867F847E8980807A84757F8175797D77
79717878797978777D796C6D7675767474737378707075756E6D6B6D736E726B6A706D69
6C716A6E696D6D6467696A726C666A6769686B6C6A6363626868656565646C6E71666169
645F6363605F646561676863685D6360625E5C615E606262615C61626266605C5D595E5F
5E606166635B5F5F
645B66615E60635D675B595C605F5E62655D6160666465645B5D675961645E63615E6466
6D62615F6260675D69626068676C696360666668656A646262646163666363636D656268
6369717367626F686A6A6C6E626D6E716B6A6F656C676D70706D6F7766706F6C6D6F706A
676B6E7275717B796D777C72777B6F737471767E76757A77727C7A797B7477797A817F78
7E7B7E807B80808A8B86887881828D898D868E8D8B8584858380898783898C8F8A8C8488
8C8C8C9094928E98968A9493988F959492949792968F949896929491959C9EA19C9D9A9D
A19D9C9FA1A59F9D999BA19FA3A0A5B09BA1A69EA1A0A4A0AAACA8A7A7AAAAA5A3A0A3A1
9FA1A4A6AEA3A5B2ABB0A4A0A7A5AEA9AA9EA6ABB1A5A59EA4A8AFAAACA2A9A8A6A4A7A9
AAADA69EABA4ABADA1A4A2A6A1A2A1999E9F9EA3A6A1A1A5A6A29EA1A19F9AA29CA3919C
96929C9B8C979790959A899997918E978F929298909190919490948F908787928B969493
8B8C9185838280847A867C8587828D7E7F8481827E8187837E7B7A8676797F7E7C7E7582
78767A787C7B7775797574757D7B75747675797773726E73756D71766F6C736A6972726B
71686C696C706568686F6D6D656F6B656A6C6D67676B6068646C676A6667696560666266
60606767616564626E6366626165635C635E626364655F67615B6365615D63576665645E
5B5D5C5C615E5D5B
68625B615D61625E625E6163615F615D645E65605F6460626065685D656165605F636962
69646466675F6B6B65666C636968616A676461696A6969666B66656C6C68616C6965696E
6E67686A72676672686C6A6867656B666A696667706E6B6D6E79706B736E6F736A726C71
6E70757B737675727673717A727465717475727D7178797A7D7D7F766F7F79777D7A7B7C
7F8180837D847C7E8482827D82888F8F808D8C90828283848A878B83818E858B85878495
938A9491828F938D949491928E9894989D93908B9990949B94919193948F9E94A8A097A4
979D98969C9D9D9C9CA3A1A19CA9A7A2A19EA2A9A7A3A5A4A6AAA2A9A7A9A5ADA6A3AAA9
ADA9A8A9A3A8A7AAAFA9A9B0ABA9A6B1AEAAA5ABAAB3ACA5ACAFA2AEA7A5A8ACABA8A6A8
A9B0B2A6A8A1A6AD9BA8A4A59F9D9EA2ACA8A1A1A6A59DA09C9CAAA1A6A39F9AA4969DA0
9B9D9696979C98939797909B93969396979E928E939A9B8C928D8B88888D888990979394
878986868487817D8480877D7E858985888286847E8489837C7C807F897B7B867E867B7D
7B7676767A7E75737C7B78757471747073746D6C6F767770736C706F6F6D6C716D716B6D
6A6A6D696B696F6F70686D6C6D6A6D6B68666B656A6966607069655F6966625D646D6264
6C676162676A616665666363685E6560665C666663616C6164625F5E5E5D5F6063696461
685D5A636668575E
64645E63605C6062686061615F6466605C67656B6563675D68616B6460656B6465625A6A
645D69646462626470696864666B6064656A66626D686A6B67656662626A5F636C716468
6A6D6D62675C6C686A6C656B6B676F6B706C68686B6A6D63736F6E726A716C6D6E717172
6B6A68696A747574757272756D777170796F7A7475777B7477797E7B777C77867C7E807E
7F737F7783808381878582838C8C8A8F8894888D8D88848585878D838C898887878A8C8C
8A838D8D9295879495918F9999919C929391929595929393959A9B989995969A9C9A989E
9C9D969E9BA39D95A0A2A6A69E9FA7ABA1A0A2ABAAA7A7A5A9A0A9A6A5ACAAA5A6B1AAA7
A8A7A4ADACAFA3B1B7AFA4ABA6A9ADB0A9AFA9AFADAEA9ABAEABB1B0B2ADA9A7A6A3A9A7
A1A8B0A3AAA7ABA8A9A2A8A9A7A19DA6AFA6A8A1A6A59D9FA0AAAEA7A6A29E8FA2A49F9D
8F9A9F949AA29792979891999297969497949D9A9992979597908D8F8C8B9293939E928C
978E8F817D8582818782818984807982827E83817F80837C7F7C83807E7E767D7E777D72
7777798379787A747C7973717A7474757278747470706A76716D6F726D6F687171686A6E
6C726B726E706F6A71706C6A6D63656765686668656B64676D686F665D616662666B6363
6664636362635F6866686869696261696761606569616A675F6363625F615E5F5E6A6666
5B6456605E5E6261
655D625960695D65616058605F5C6063605A606565646264616269695D635E6164636461
6067646662606160666763686B6E6662665C6C636866686A6A6B636662696D6464666965
6C68736E6E676A646E6C676C686A6F68666F6B6B6E6F706E6D6F6F716E716D6F746C6E6F
736F786C756F70707B7B74767174787273767479757A75737A7A7277777C78797A737680
857E7E807A808486818387858492878F9C91918A8C898B8F8685908B7F8A848A918B9089
8E928F988E918D9A978E918C948F93928D8F9B98949B9C98A48E989BA0A69A9F9F9E989E
A09BA6A59C9DAAA29CA5A9A6A9A7A5A7A5A4AAA4A8A6A8A5A4B3A9AAA7AEA5A6ACA9A9A5
ADABA1A9A4A8ADAAA8AEB1AAB7ABABA8B5AAAAB7B4B3ACAEB2B6A9ABABAFB0A5A6AEA1A7
AFA9AEA9A3A9A9ADA1A8A7AAA7A9A4A2A8A9A09FA4A0A9A8A6A89FA7A8A29CA59CA19B98
979A9C9B9A929BA098979299979596968D8E979F9B9896918E918D9491998C938B98958B
8D8F81838A858D8986858782898E907E8285838A81847F817B7E7A7D81837E757C77777C
7D767E7875777976787B7579736F6F6D7770756F736E726F7372716F72706F746E6B6A71
726B6D6B6F6D6D666F6F726E6C6A68646B67625F676E646662666761656D626C6060676C
666B6665666968656465605F5E64605D66656268615E6B6B655F68616362626462606963
615B615E5B66665B
645E5E585F656659655F615C64656563615C6767676467655E60635F67606064675B5E60
6965626F6A69645D615C6267625D6A656A5F64676966675F6E62656C6461626469726B69
66656F6564656B6B6B6262636F696F6C68646C736E7370726D6471726D6F737169766C71
68726E757C786B76747A6F746E737B70777075707979747777787C77767A8279857D7E75
78827B7F87847A7C837C7E85918D96929194918D8A8785868288888B898E8C8E908D8E8C
889291888B8C8B9596969499969E909C9AA29D95929A979B969E96919999959AA29A9E9E
A39F95A59FA4A2A1A7A4A29DA0A2A9A79EA6AEAAA6AAABADADB5A7ACAAAAB2A4ACACA6A7
ADA4A5ADADA8B0ABB6ACADAFB7ADABAFACB3B1B1ADAFADB5AFB3AEB1ABACABB5A9A8AFA9
AEB8AAA59FA9A3AEADB2A4A7B19FA7A3ACA8A5A0A8A7A0A4ACA6A6B1A3A5A2A2A5A19F9B
979CA39C9891A4949C95939B968E9E9294929A9A9D969B8D91928A8E8E8C948D94989389
8C8A82878B8B8388818A878189807F8981897E86827F7D857E80868280757E7A7D837F7E
787A80787E7D7B78707C776A77736E787174707974736D6C767375727678757470706671
707572716D646976736D68716D69646B6B686666606A665C66646168686A6665635C6F66
6766646268655C62616664646A665C6864676562655B62655F5D63625F65656361666063
5D645B6159625C5B
645B5C605F585E5B645B66636065655E6767605E6164645B695F67606461626665606766
6865625E6364665E6163616C6D5E6565676B6566696F656963646266645F696A646D6366
6A6865646D716E6468666E6F686D6D706A6D6B6E74717175716C7A756D64756C6F766F6D
706D74717175747971787472767670736E6E757778767176777C747179787977827D857B
837E7C828384817F898F85858D8D8D9091938C8D8386858C8E867E8F8E858A9183898E8F
8F928C948F919C919D9193998F9A959697969196969691959E96929A959D9D9BA09F9E9A
9DA2A89F9CA5A4A2A29DA2A5A49EADA9A9A9ABA5A8AEABB1A7A9ABA9A7A4ACA5ABA5AFB2
B2AFAAADA5B4B0B0A3ABA5ADB4B3AEB7AEBBB8BAB3B3ABB2AEAFA7B0AAB2ABB2A9ACAFAE
ABABAEAAB3B3ADB1B5ABA4A3ABA7A9AAACAAA4A59DA3A3A9A6A2A5A39D9BA3A5A1A19A9C
9E99969B9CA19D98999D9A93989798909C9598999598979A8F969295929390929493938B
8D8F888B838C878687878C828C907E8B858788808084857E7C7F807E7B817778757C7D72
7B7E777B7C7D7D7C77767B7270747179777974717169746D7577756F6E746E696B6C726E
716D676D6F736E6B6A6E6C6F6D6367646A6765686165686C645F61685E64606868626569
616A6262616C636165685D606C66686168696460636565686262605E626263635F5E6360
665D61565F5F5E5C
62585F5A5F5B5C63636366636068606465605D696462616460646863625C636760696469
6566625C6059656467646666676D5F646965686A63696163606963686965676B6D6B6B65
6E656B6C616A646B616A6D6369636B6A6E6A747272676D76757371716E6F716E736B736E
726E6E75746B747077747A7375727771767C7D7B7A787E7B7C7D7D807A7888837F7E797F
7B847B80827E7D818986838A8F948D8B918B8C8A8A888B848984868B8D899086898B848E
8D94889190908F90879489928B9895A09C999D989A9794959F949998949D959E9898A4A6
A69CA49EA6A4A3A7A3A5A6A6A4A5ABA9A5AEB1A3ADADAEA9ABAAA6ADAAA9B1A9B1A8AEAF
AEA4ADB4B0A7B4B4B0BAB9B1ACB2B7B2B5C1B5B7B3B1B2B5ACB9AEB3B7AFB4A6A9B1B1B0
A8AFA9A9A8AAB0ADAAA8A6B2B4A0A4ADA0AAA7A3ABA4A8A1AAA7A69E9E9FA09BA3969E9A
A69F9B99A59F9C999A9E989898989796919B969093999595978C909094978B9994968F93
8E888584888A867F8B827B828B93838988858B7F7D878986837C827F8380807C77777A80
7C79787A777A6D72757C737B6F6F7576736E79796E77726C76707670736E6F7270786F6C
676E6E706D696A6A6F676E6B6C676A69636C6C676267646C676E646C6D67766364696668
5F63606B66665E645D69635E626965696A636B6461675D6768645C625A5F605D5B635F5E
5D5B5F595A5A5D5C
625362615C615F5F5F655D5D5A605A65605D646363655B60666165605D62605F615D655D
6263666064615B5E626D6764626B5A646A5E68686B6664656A6D686469656A6B5D6D666A
66706D67626664676B6E6E6A656C7969706C6F6B6C726F6E6E6D72717276706F76717177
746B746F7571727073757479776F7E7373757D777681787E7677797F7C757F7886827F81
7881857C818C8183828285858A8F88958B8B8A85939395818B897E848D898B8A8D8C8C90
8B8F92899496908D948E8F989E9B969F949690999C999F999E9F9F9A9C9A9FA29CA3A09E
A4A8A79EA4A79DA6A9ABB0AEA8A9A4A8B2AAB1AFB0AFAAACADB4B8AFAEB0ADAFB2A5AAAF
B4AFAFB1ABB4B8B1B2AFA9B4B3ABB4BBBFBCB4B7B4ACB1B3AFACB0B1B4B0ACB0B0A8B3B0
B0B7B2B2ACABB1AFADB1ABACB9AEABA9A6A3A7AAA49EABA2A4A8A7A5A7AAA39E999D9FA0
9B8E9B9EA19CA1A59AA0A39E8D988F9B938F9C9A99958E929B8C8D938E89909793938C8A
8E8489888C818D8587878C8E8B888795908C89818A8A85818888867A7D7C7B787D747A72
78787A77787A797377777C7A79707374737D746D6F756E76776F726C716F67717070706F
727A6F6E67666B676E686B696C65676569626C63666E676B6C5E616C5F676361656C626B
635E615B6C6C635E5F6A6060616464606B6757606465606463615B5B645D63665A615F61
5B656353615B605D
605E5F595D61615B586162635A625F6B6360655D66635E6562665E68666B5F6266636063
696462676460615E6465656865656667696C6A67656A6164696D6D68626963656868716C
606E6F67696E6F6167686A716A6F6B686C6D6D6D6A70787A776F737072736D6D6D706F6B
72727374777A78747474746F71736E73747E7B787778727874747D7D7A8180817F7B827D
88817F7F81847F7F8781848787878A83878A8A838B898E8F868A888D898B92898A8F908A
968B949696958D98938E91959594949997979D99A0939C9FA19DA09DA1A39D9C9E9F9AA2
A6AAA1ACA9AFA5A3A5A4A8A6A6AAA8ACA6B3A4ACAEA9A8B0B3A5ADAFB6B2B4B6B0AEB1AF
A8B1B2B5B1AEB4ACABB3B5A9BABAB8BDADAFB7B8B7B4B1AFB3B5B9B6B4B4B0ACAEB4B2AB
9FA9B1B1B2B6B2B3ACA8B2A8ADACAFAAA6A9A6ACA9A6ABA5ABA7AC9DABAAA4A2A2A19DA1
A09EA69CA499A19F97A1999C9F9C959797A293959096928B998C908E8F8D96949A8C9092
8A8D8B8C93838E8D86818E898C898A8D8A91948988888A8C838284787F827B767B82807E
777E7D7B7E787B7C79797975747574767770767375746D6F757074716E727C77756F736F
6C69746B6A6D68696E6D716666696B6C6667696A696A67616C72607169616D6560626463
6063666B61676264636A6D6761615E5F62685F6063626264635F62605A5C6B63605E635B
615E625E625E5E61
5E5E5B5D5A61615D626761635F66645E5F61686564655C6A5A646364626863655F64655F
646A625F676465676462656262616C63646D676B6B696E6868686169656760646C676B64
5F6E6B6C6C6166676A66696D6C677067736C6B6A6B76727470746F6E6A6D6F7174746D6C
776D6F75727A766D7072756B77737075737B7B75747C7C7A7F7A8081837A7E817D7E857D
7C8184777D808C848D7D8980898485878884858487898D8C84888D8C9287908B898B8D90
918F918E909293918C949C9A93959299959A969FA4969BA2A0A19DA399A09AA4A49EA6A2
A5ADA2A4A2A4A8A0A7A5A6ACACADB1A9ACAEAEAEB3B3B1B3B7B1ADB3B6B5AFB1B9B2BAAF
B0A9B6B1B1B8B6B1AEB3BBB3B4B3BCBFB3BEBAB1B6B4BBB2AEC0BCB9AFB4AEB7ADABBBA8
AEB1B9AFB5ADB5B3B3AAA6A8B3ACACA7A7AAAAABA8A6A6AAA9ACA1A3A69FA9ADA0A59C9C
A597A59AA19E9B9D929A9A989A9994989B9595968E939B9BA098958A9592948F92938E8C
8A90878E8693878689878B90838E87958B84908A858F8C7E7E8285837D807E8381767B7D
7F7C7E787D717E79757C7C7575716E6E6F6F7A7C74727A6D776F7472766A72726D72716D
6F6C6A726A736F6C70656A6B6F646D726B6A676A6168706A646F6667656666686A646A63
62626163665F6A6464616566616361636869615F6163616260626464606162605F666164
635B5B60635E6160
61605F5A606461686262616064656165615F64606965655D5D655F5E6163606C60646161
645F64606362656C6B65696B65646062706269686C6B63646A6865696E6E6763656C6D65
66686B6F6B6D686C646C6A6567716B71716F6E717B6A6E77747571726C746F7476777673
6C71756772726E7C6F766E747772747679797A7A8073797C777C7A79797A7A8285808281
818285808685837E8C8A86818785898B878C80878F90898C878E8D90898B8B8E9B93878C
938E9295938D91938F979B989D9E9D9D9C96A2A19B9E9F9D9E9EA1A19EA29F9DAC9CA7A9
A1A4A3A4A39EA6A8AFAEA8A6B1B3A8ADB3B4ABACAEAFB3B2AEB4B0B7B9B1AFB1B5B1B6B7
B6B2B0B0B4B4B0B7B3B3BAB8BDB8B1B6C2C0B6B9BBB3B9B2B2B7B2BAB1B0B4B8B7B8AAB4
B0AFB5B4B4B6AFADABB1A9ABB1B4ABABABA8ACA9ABB0A4A9A8A7A4A7A99FA2A695A59BA4
98A2A2A4A0A39C9998989D9D9B9B969A92999A9999909496949297919096938C958C9090
8A8C928B8683848D8C8A88848F88938F968F8E8489848C807D807E827C827B7F817B807A
827F7A7B78787C7B796E7A7C79796F6C797B76797372736F71716C7371686E7173747074
6E7671736C676C6A6A676C6D696A686A6866686D6E6B6A686C726765686D5F66616C6B6A
686763656B69635D636360646A635F675D62685D5F605F6467696D66636160635F615E5C
605F635D565F5B5A
5F5B5A5F605C5D615E6063615C695F5E63626567636A665F676461606A60626461666364
656362686B626060656A63646A696465666A646B6B6D686A7167656B6871686A68676664
666C706D68696A6D676E6B6F736C70676670756F6E6E74706A706D737473706B6E78726C
7A6E726F76757776797676737476817B7A786D767C79837B77857A837B7F7E87867F8486
80827F8689897E898A83828D818A82857C8A8585858B8787848C8E8E96908E969197898F
92978C9297909597989A91979A9C9A969A98A29C9D9DA19CA4A09F969F9EA197A89FA6A6
AAA3A5A0A8A8ADA8A9ABB8AEADAFA5B7B3B6AFB3B2B4B2B6B3B0B8BBB7B8B4AFB5B8B0B7
BAB4BCB3BAB7B7B9BDB6B3B9B7B7B5B7C6BABAB2B7AFB9B0B3BBB9B9B1B4B6BDB9AAAEAE
B1AEBBB0B8B1B1B2B1AEB5ACA9B6ADADAAACB6A9ACA4A8B0ACA7B1A5A7A3A7AB9AA4A2A0
A9A7A09D9E9A959C989E95A0A2979A8F989B95939E9F969B918C8F96908D878A8C959491
868993898B8A8A8F8A84838F8E938C8B86868589898B8C847E797C8187867F8081807F7E
797E7E7C847C777D7A757575796F79747D757574777C756979787073716B6E726D716E73
72716E716970706B776D6F6F74706C6C6C72676C7270676E6C72666A6F65716E6F696967
6A6864636B6267626567666368615E5D605D5F6463626260666D6462605E606163615E62
5C5C555F62575A62
655B5F5A635F595B645D6459646164605F5E6E5F60646361635C63625F615A636765645F
6861635E616360656667666262696D686A68686F676A646C666D6668666A6963606A6B6B
6466686C69656C68636C616A6870706E6E6A6F706C706F6B756A6B71736D757A67726C6B
6F73706F7B7777787673717979767C7370737A81807D6E8A7D787B857D7D7987837F8285
83898A7F7F8A85858686898B868286868B8A857F878F9090878B898F8E8D898A918E8E8A
92988F9297949D95939C9492999A9E9B9BA4A6A1A8A2A3A39DA1A2A2A0AD9DA09FA3A8AD
A3A0A4AAAEAFABAEADAFB2AFAFB1B2AEACB4AEAEB7AFB3ADB3B1B4BDB7B1B4BAB8B0B2B3
B7AFB1B0B9B8B6BAB6B7BCBDB3C6BBBAB9C3B7B7BABAB0B9B0BBB6C0B6B6BBB8B8B5B5B7
B7BDA9B5BBB6B3AFB6AEBCB8AEB0AEB2B5AAAAA6AEB1A9ABAAA3A7A7A1A99EA09FA1A6A1
AAA4A29F9BA29C969E98A19C9D9F9C9B9B9693999B97968F9099919495999092878D9594
909191938C89899084878B84918890928A7F8F8F848885837F7F818079827E7F8283847C
7D7C7D777B797E737572777977707673767177727377746F737575776E706F73697A716A
6F6E6C6B716B6F6A70726D6E6D6D6D73626A6666666B6768666F6E6F6B71706E69706367
6E686B5F6463646065666562676A606062646964645E65636666646061675E6163566466
635F5C625E5E5D63
605C57595F605B635E5A65606263645D625D6460635D61646061606968635F6864626161
6862635F6368655F5D705C69636868616A65645F646A675E6F69616667656D66666C6867
66636A686E65676B69706B6D6F726F696C6C6D6E7070696E706D6B6B6C78726F736B7575
716F73707075717176736F72767B7A7978797A787B7D7F8075837C7F807C7F7F7C84897F
878381798A7F80868787848482868582848689878686928D8E85928F8D8F86908E909191
948E90949A9A95979A9D949F9F999C9A9D9AAB9E9EA1A4A19FA8A8A2AAA79AA39EA2A9A9
A29FA8ADA5AAABABAFACAAB2A8B2B2BAB4B6B5AFB5B3B3B3B2B6B2B4BEB7BAB7BEB7BFB5
BCB8B7B9BAB3BBB2BCB7BBB8C1C1BEC5BCBBBCC3B9BCBCBFB8BABEB3B4BBBEB8BDBCB6B1
BCBAB9BAB5B2B5B0BDAEBEB5B5B4B1AEB3A9B0B3B1A8B5AFA6AFABACACA9A6A2A4AEABA4
9FA2A7A2A29E9C9D98A39A989BA39B9E96909E90A29A9B988E98959091979393978A9294
918F8D87898B8F88898884898B8B898B90878588828D8C7F827F818182827D7C7D7B847F
827C78767980797B787C7C75747B72716F727876747C70716E6874766D746D6F7371726F
66716E766F70676D6E6B6D6D676971705E66696C706F6C666A64737173756F6E63706863
6A666A67636A6B6C615F636365626661636665646169615C63686361635B5D615D5E6165
5F626961645D5B5F
605D5E5F5A596661655A605F5E6462635B5D6366635B5A66666B646263606169625A6660
6060616563686764646A616A616F6B5B676A61696E6B666B67696B6D6A6C6C6567696368
696C6766675E68716E726A6A6F70676D716E6D706D6D706B6F706A79776D6F7270766E6E
6C70726E70706E707C7A7C787778767B797C7B797E787C7B797D7D7E847A827F817D7F81
8085838079878787898684848E8C838E8C898182888A8A878C898A948C8D90888E8D8993
9492909794929C9A9B9B9B9998979A98A1A2A69E9DA5ACA39DA99EA5ABA7A5A79DA9ABA7
A1A89FA8ABA8ADAEAEB3B1ADB6B0B7ADADBEB9B8BEB8B4AEBCBCB5B8BDB2B8B7B8BAC0BD
B2B6B2C0BBC0B9BABCBAB8BEBDBEC5C2BEC2B2BFB5B3B4B4C2B9CAB9BCB7B4BCBEBBB0C0
B8BDB6B8B9B6B6B1BAAEB1B2B6ACABB8B1B3ADB2ADB3A5AAAFA7A9ACA2B6AFABA5A9AEA1
A6AB9CA4A49CA4A4A1A09C9E9C94989697999DA291969A9994979599958A90909192948E
8A93918C90858D89889487938F878D8D8D878B7D8282867E837A7F837E847E817F75827E
817E7C857E7A777D737B737E7977727C767376787270707169796F737671727177696C70
716975706B7071716E6E666C717067646A5C70676D676967676271666A676E6A6F6C6B65
5F626A6266656B65645F636964645E6869665966655D6265675A6E585E6E616161666060
6061605D635F5B5F
605D5B5A5A5E6250695F645D5B64635D615E69666367646261656961686361636362665E
6C62666A6063666462625D6063696060626564676762686964666B676C6B606D68646A6A
6768686E6B67676F716C6766696C6E6E756F6C68706E706B6C6E6B7577726F797671707E
6C72746A71726E757A76797674767C7A787A787E7B8281807B7E7D757D7A867B83808581
7F837F838B808A8A8B858883879381828987818C8990898C918F849288948F92889A9497
869994919A97979B9B999E9C9C969CA1A1A1A1A1A4A1ADA8A7AAA9A7A3A1AAA8AAA3ADA5
A9ABABAEACB6B5ACADB5B2B7B8B1B0B9B2AEBAB8BBB1BDC1BDB8B5B1B6C1C0BEC0B8BFBA
BEB8BBB8BBBCB7C2BDC4BCBEC4BCC0BDC1BCB6BBC2BDB5BCBFB9B8BCBCBEB9C2BEC0BBBB
B9B8B3BEB0B7B8B2BDB7B1B9B5B7B2B3BBABB4B7AFB0B6ADB7A3A4ADACA7ACA4A8AFADA9
9DAC9FA9A6A5A89EA798A59FA399A1A3969B96969F979C999A9B8D95938C94958C909390
8D8E878A868B8A86858B898E8C878686857E89847E848384858C808681877B847884857F
8180767C76807A7A777B767873737B7171787876737D7875717276796D73706F6F75746F
696C6C6E6D6B6D6E72636B66716C6B6B6C72706A6D74676C6A6A696E6D6B6C6B676E6E63
6566646A6463615F6463625D60646864625F64626564635A685F626B67625E5B6362685B
6159615C635D6161
615C5D57625F605F645B635C6861646460626263656265605F6066626167686366636760
616660676862666560645E63636A646666626367676B626A5F68666870706671616C696A
686C6B6F706F656D696E6F706C706E6F6D69686F6D706B736E71726E736F6D7378727474
7871736C7175766F7C737375797F7A79757F7E79807D7D7A7E7A7C808484817C7F808084
80808187848088888E86828C8B8487868D8F848B8C8C8B8B938A90918C92939293888E91
8D91979593969A9B9A9E9C97A3A29D9DA49AA2A1A0A7A6A6A1A59CACA6A7A4A3AFAEAFA7
ACB0A5A6A8B2A6B3AFB1AFB5BDB0B0B4B0B6B6BAC4B3B1B5B7BEC0B6BBC9B6BDBBC2B9C6
BAB8BBB7C5C6C5BFBABAC4BCD2BFC5C0BFC6B4B8BEC0BFBCBBB6BEB9BBBFB0C0C1C1BEC0
BBBEB6BEBBB6BBC0C2BBB8BBB6B3B5BABAB1B5ADB3ABB3AEA8A8AAB3A8B2A9ADA6ABABA4
A4A29FA2ADA2A0A29EA2A49A9CA0A59C9F9B9CA0A099949D97939A918F928B8F8A8A9296
9292928D8C8C8E8D8E8C868C86808B88888D8D82827D7E897C827E82827E8483777C8483
787E7D7E7F787F7479777577757578787077737378767275707678706D7471757370726F
6B74716B706C6F727164726A706E6E6E6D686F696C6569656D6B736A6B696A666C6C6862
68635F69696A64656164646565636464636569625A6269656668656764616565585F5E66
666361606060615E
615C5D5F615D63625A5E6260655D61615F6064676168636767656B646469685D5F676864
676B666965636065656A62646364636466675E6D6C646761626062626B6462696B6B6C67
6A6E6A69706A6D69706764686D6A676F6772706F726E6A71747272726E716D7072716D70
6D76727073737171756E7076757E71797A7E7F82807F817B837B7F7D847E827E7E808284
7C7E7E868686868D8B86878C858883938D878D858C8D8D918C8E90928B938F959A909194
939E9798969E96A19C9A9B95A5A39F9F9CA4A2A5A0A6A0A7A3AEAAA8A5AAAAAAABA7A5B0
ADAEB5ABB7B2B2B1AEBBB0BBBCBCB3B6B9B1BBC6B7BAB1B5BBC2C1BCBDC1BEBEBEBEC6C9
BDBFC3B7BEBEC1BCC6C5C8BAC1C2C8BDCCCCC1BFB9C0B8BEBAC1C3C7C4C7BEBEBDBEBFC1
C1B9C2B8BEC1BABCB7BABCB8AFB6B5B3B3B0B7B2AFABB5A8ADB3B4ADA7A8AEB5B0A8AEA7
A0ADA6AEA9A4A8A2A2989EA4999B9F999FA59599959F9A979D9B959790938A8F93929195
96908F9090928A878A90868A8C8A8F8386848B8D8191847F828286857987818183847C80
807F7E7F777C7D798076797379767C7475727676757571767B7476716F786F776C707474
756771709D6B726D756C7067696C7470716E6B676F697260686A6C676D726B6E6B666367
62676A646060705D67675F5F635F6465606866655C5F6A6A6C666E696A68655B66616661
6062645E5F5C5E5A
66595F6466605E63625E5D6663616260665B66615F635E5C5E656E65626B64626867646B
6672665A65636764636664635E6564635E5D686C6062666464616A706A6A6660626A6971
696A6B6D6C6F6D6E716B6B6E6B6A6A72696C6C69656D72706C7975766A766C7171716F75
7671707B72756C727B7270737F7678747E797D7A7C7B81818480787E807B84797C83817D
7D7D7E7F858B86868D868C8A898B8087868189898C8A898F8C8A88928892919292989994
989A9A9F9B9A969A9D9D9C9C92A59FA09B9FA59DA6A29EA7A1AAB5A9A4AEA9ACA3AEA6A8
A9B2A9A8ACAFB5B4BDB3BEB6ACB2B9B7BAB2B7B4BDB9BCC1C5C3C2BEB6BBC4C2BBC2C3B4
C2C7C7B9C2C4CBC4C3C5C7C7C9C6C3CCC3C1C2C2BFBBC1C5C2C4BEBDC7C0BCB7C2C5C3C7
C7C4C4BEC1C1C2BBBEB5BDBBBCB6B7B7BDB9BEB7B4B3B3B9B2ACAAABA9AE9FA5B1ACADAA
A8A7ADA4A4A3AC9BACA1A0A69E9F999BA0A2989E9B9A9B97989C9A9996969C9A988E988B
8C8C8E8F96909189908E8C8F8F8589828A838586808180858A86828780787D807E827984
7E7F857D7E7E7E827C7C7E747C7D7B73797270787D76747275737276746D6E7677786D70
776F6C7181757170726878707673706A67727069726C64696E6C696668685D636766606C
69676A67646868677071606963645F5F605A61616367696D676B66645E68675E6460615E
62645F655F606063
5C5C675F5E615F68625E606267636066655C5B68615D68626B666661625E5F685F60656A
665B6560616869636B6864676468686961686560656466696262686767696D6B6C6B6A70
6F676E6D666F706A6F6C786F7271756F69727169677065696B6B6B72716E6C776E727472
787475727C7170797D7B727475777D7C7A7F707F817F7C81827F7D84788080837F8E7E8B
7D82807D8088868D868E878D83898988848B8C8A90888F888B918897918E92949B8F9C8F
96999B9696A09895A2A1A09F9C9499A8A299A0A4A2A6A5A4AAADA4A6B3ADA9AEA9AAABB1
B2BCB7AEB5B4ACABB4B0B6B4B5B8BBBCC6BBB4B7C8BABAC2BEBEC2C6BBC2BBB8C0CABDBC
C2C4C8C0C3BEC1C9C4BEC4C9C4D0CBC9BFC3C3BEC4C0C1BDBBC3C2CAC8CDC4C5C7C2BDC1
C3C2BDC3BBC1C0BDBAB7B4C2C4B8BEB2BDB9BAB5BAADB6AAB2B2ABABA9A6A4A7A7B5A5AB
AEA8A4A9A8ADA0A8A09EA49F9DA4A49D9D9FA49AA29B9D989C9696969592908D9A929693
8F92928E868D8D91928F8C89888784868C8E8B89858882848B838682878782837E817E7A
857C77767F807F77716F7877767A7A777E7F7975747174787272717070757773706C7773
6B6E77706D6F75706F716E7171686D6A6D6A6A676966646868686C6B676469696F6E6F62
64686A67676E60686C69616365626B676A656C5C5B636170706C716B68696660675A6264
625E62596362605E
5F5A59625A685E605E5E665F5D635E61636469656765646D62656264685E635D66616362
68615D605F6061656367666E64636868635E655E61626A69635F666A60656D646B6A7068
6C6D6F65676A7070756E7367706D71717469696C68726F72726E73716F746E756C737270
7574757674776D747C737B77777575797C7F7C83817E79828384827E7C7F807E78848283
8787837F8581848985868E8489868487898B8E8C888C8C8F8A8F90978E96969899988991
97969A99A09E93A19D9F9CA3989DA5A0A49EA5A79EA7A8AAAAA9ADA5B0ADA6A6AAA9B0A7
B5B1B2B5ABB7B1B1AFAEB0B7BBBABEBEBEB7B8C4B7C4C4BFC5C4BEBBC6C3CAC8CBC8C0C2
C2BEC8BFC4C2C3C9C9C4CBC8CCC9C2C9C8C5C9C9C4C6C0C4C2C2C6C0C6CAC6CABEC9BBBE
C4C4C7C1C0CBC8C6BDB7B2B8BFBABAB6BAC1BBBAB1B4B5B2AEB1B0AEB0ADA6AFAEA6B0B0
A3AAA7AAA6A4A4A7A0A8A4A4A4A1A19D9B9E9C989E9D96969C91929C9493968E8D8F9495
929A9294908D97918795888E8B90848C8786858287828784888484827A8883827D80837E
8177807D7E7C7878767B797F7B777B7474717875707179736A79776C717273736E717477
746D716D73746C71776974736D6C6E6B6F6B756D696D6F6E6570686E696D62675E686669
666567686B5C666562696567616068616966645F5E66666C746D6F676260645F5A656364
5E685D6062625960
5F5E5C5D635E665F625A5C685D5A5B5E625F6069616164636169646A6365655E6A636867
5F60646368656362646369636B6361646B6A63676564636665696A6B6C6765646C676C6F
6D6B696B6D6C6C75666D78746B7369706E6D6D6E6B6D6B6B7476727473777870736D6D77
756E737371767873718073787C7476787B777E8179817E7C817F7C7E867F7F7D7B828488
7E878183847F86878A878A858A818B8D8A8C86918C8F8B8B94918F9489989A9096978DA1
9E9599A09C9CA09B9C9FA29F9E9FA1A0A6A8A7A0A09EAAA9A5A7A3A8AFB2B0AEB1AFABAC
B1B7B9B2B1B4B7B1B3B1BEB8BBB9BABDBAC4C5B9C0C1C1C4CCC7BDC2C0C2CCC4CAC8CDC0
CFC9C1C6CCC7C7D2CBCAC8CFD3C9CBD1C8C8CACDC6CAC3CAC7C7C8D1CDC3CAC3CAC4C1BD
C7BFC9C4C0B9C1C5C0BFC8B8BEBFBFC0BAB8B5BFBBB9B0B7B0B3B3B3B0B6B6B0AEA4A9A1
A3A5AAA6A7A6A8A8A0A2A29EA2A9A4A19DA2999B9A9C9FA19C9F9C969F9B949896989A95
90969396948C918D8E99928B8C868E8588898487888A87868383848580887F7D807E827F
83827A8081817C7E76797B7975777D717F76757B737B79777872756E75716C7573777170
6F7377716870696D6F7670786978706B6C6C6F6D6B6A6A5E6A716B706D6C6668666D6269
65676767606D6F616662615D6867626861655F6266666B6A746B6263696A675E635A5F5C
5D60605B635F5C63
5F5F5E6560605D5E60625B645A5B64625D605E5D65656563646965676B67625D645F6864
61686665606E645D66666465626363626264646366636769646661696B6E6D686F64676E
6E66696B6C6D68706F6B6D7171716A6F6567686B6B6D6D72766E70777676767871737376
746D767874746D787577797A727E7A7974777477807B837F81887F7C867E7D7E7A8B8282
7E85808A8387877E8C868A8B8C838784898C878D898B8F8A8F8B96978E9090919F9F9C91
98999E9EA3979E9A9B9AA49EA9A29EA0A3A2A5A0A8ABA7ADABB3AFA8ACA4ADAEB5B4B6B1
AEB6B6BFBDB9BBB3BEBAB8B5B7BFB9BEBBC0C5C5BDC0CAC9C6C1C6C7C4C0C8CBCAC9C9CE
C8CDC5C5C5C9CFD3D4D0D3CAD0C9CACFCAC5CACDCDC6C9C3CCC3CCCDCFD0C8C8C5C5CEC8
CDC4BBC7C0C2C1BEBCC6C2C6BEC0BEBFBEB8BCC1CABAB1B9AFB1B7AFB0B3BBB3ADB0AEAB
A3A7A8B3B0A8A6A8A99FADA9A6A3A0A3A49D9D969B9E9FA09B9B9797959A999A8F918F95
959396948D95918C928F939290838D94868C8C89838388827A8781868882847C7A7C867F
7E867F797A7B7A828179797F7B76787B757B79787E71797C767778717E737975706F6E74
6E75766E72736A756E716F6C6D6D6B686E6C6C70716B6C686E6466656C646666666B6065
5F62666661666B645C646968616463696064616666626A6E6B65696A615C5C63615E5D5E
5E6461625E605E5E
605F63605C605F6362645E636161615A5E5F6066626A60636368666567616162625B6867
66666468686369656360656563676066636269606B6F66636761616769636C6A6169736B
6C6869736B706E6D717169696E686D6F656E6A69646D7272717472766F7E6C7977757973
746D6C7975757A7A7875777D76767078757D7F78817F767D867B8A80807A798182808784
81848281888B8A898E8D888B868E8C898B8E8D848D8B89978F8D8F8F9091979D9E92928F
9594979CA199A39B9A9FA29F96A6A2A6A7A3A3A4A4AFACABA9A4B3B3A8A9B5ACAEB0ADB7
B1B3B3B7B3BDBABFBDBCBDC5BDC3C2C7C2C3BEC3C1CEC8CFCCCDC7C9CFC7CBCDC6C2D0D4
CDC4C9CCCCD3C7D5C3CFCFCBD2D6D6D9D4CDD4CACECBCDD0CAC8C7CEC8CAC6CACAC8CDC7
C9C3BEC4C6BFBFC3C1C9C2C1BCBCBBC3B7BFB9B6BFB9BAC0B2B1B9B7B1BEB1BDABB7A5AD
ABAFA7B0A9A8A9A79CA8A39E9C9CA1A1A59DA19F9D9F9CA29E929B919D969B9F97989896
919792929B9191928C908B8F8E89908A8989898784847C868585848382867D8A7D808288
7E7C7C7B7C7E7D7E84727A7B757B79767671777C8071736F7D6C797571717C707172716E
70786D6A6D7771716F6E6F6B746F686E6B71696D686C67726A6E626666695D6960656A6D
626C686C6A6167626C6562606166655E625C6462625C666C69655F6768616167655B6463
65685C615C5B6258
6362605B616A6355615C5F645F5C6B63645D65686664676A5D66636362636A6267626664
696C62665B6265626A61626C626665696D656566645F6C68656068696766686A6669716C
6A65696A6C7466746E6F69646970686575736B706B716F7073787377797573767B7A7775
75726E7774776F79727A7678797C76807F7C78787C77847E7683847D817E8085827D7D84
80817F89808584858288878D88909087838F8A8D8E958F97919293939B9295989A959A9F
A1A49AA0A2AA9BA399A2AAA1A4A3A7A8ABA7B9AAABA4ACB0ADA9AFB2ADAEB0ADB7B2BFB1
B8B6B3B6C1BDC0C1BAC0BBC8C5C4C5BDC1BAC2C6C7C3C2C7CBCACBCED0CACBCDC9CCC8DB
CBC8D0C8C8CFD1CCCED5D3D3D0D4CACDD1CDD0D4D3D0C5D2CBCDCACACBD7CBCCC5CCD5C8
C9CCC9C9C1B9C5C8C1C4C4C0B9C7C2C0C2BEC5B9C1B7BAB3B8BAB8B1ADB5B6B9B3ABAFB3
B6A5B0ABA8AAABA9ABA4A3A2A4A3A49FA4A1A5A4A09B9F9B9C9799989F9D999594909893
918D9B9495919A88958D8C918F8A8A8B8A9289838C8588848C89828682838080887E807F
777B7F7A7A7D7F7D767F797A747B76787D7673817475777274737D7477757372766F7170
6F6D6B6D6F6D756E7170766C6C756C6C69736B6B6D68696D6366696A676567656A676761
686A6A66656D5D6066645E696560676B67636360615F6564656668606265646764675E5B
6664636460615C5E
625C64596160625C5F666466625C5D5E6060665D64665D5B5E6063605F5F6B685C676565
60666469636566616A636A6A696867696A616F696866696C656964676B6E65626D6B6770
706F6B726763696F6E6B6F6F686C6E69666B726A6F716D7075727D77767574777A79777C
727775717E777F717C7A72787E7D737E7A7B777E7C81807D808881848287897E867E8281
82858281827A86848D877F83858F908B8D8F8A918C878E8F93908E92939C9291979FA3A7
A49EA3A0A39CA1A3A1A29E9EA5A5ADA1ABA7ACACA1ACB4B5AFABAEB1A9B1B3B5B8B1B7B9
B1BCB6BAB5B0BCBAC1C4C0C6C5BFBFC4C4C3C8C6C1C6C7CCCBCECBCCC3CBD0CFD1D7CAC8
D2D1CCD7CCD5D4D6D2D9D7D3D0D4D3D0DBD6D0D3CAD4D2D5CFD2D3D0CECDCED3CED1C6C7
CECBCFC5CDCBBEBEC5C4C7BDC8C3CAC0BEC4C5BBB5BFC2BBACBCB8BABAB5B1B6BAB9AEB1
B0AEB0AEACADA5A3A7A3A5A3A2A1A5A1A49CA2A69C9FA1AA9C95A09D9199999B96919E94
959194969494918F988C8E918D8B8C8C8687868A8B878C888E898D83828A8585847E7E81
8282797B8179747284837C797878787A74797A757F7C75757177786F8373746F7071716F
77706C74736D6F6D6D7273707570726A6A696C626A6C687061646B6F6B6C6C6568676963
626A6A64636B685E60646A5E65646A62626069686264676461646463655B62676260625E
5F60615A635E595B
635D5F60605D5E69625D62615862665F5F6563615E5F5F61606362626367656163637069
646869626A6465676A676365656763665F616665696963646B6765606E65706B6B696A6E
6B63706B6F716964716F70736C6F69696A6F716B736C6F7670787E7B77737A7675776873
6C74757873777D76757975777D7F7A7B7D818083817C7E7B85817C858480818286867984
898C8980898A8B878B8688898D86848B9389968F88918F8D969795999D9E9B9A9CA1A5AA
A39AA09BA39D989DA4A09EA5A4A8AAAEA9A8A6A9ADACAFB9B0AFACB7B6B4B5B4AFB7BEBF
B6BBBEC0BEC0C4BCB9BFBCBCC3C6D1C5C8C6C8CBCBC4CFD0CED1D0CFD2CCD2D0D1CCD7D5
CEC9CDDCCFD1CFD9D2D7D2DACFD3D6D8C5DACFD5D6CFD7D0CBD5D2DBD5CDD7CFD0CAC9CE
D2CBD1D0C7CCCED0C2C7C6CDCAC5CBC6C4C1C1C1BEC0C3BBBAC2BBBAB8BABBB8B8BCBAB5
B1B7B1AFA8B5AAA9A9A8ACA7A7A4A6A8A09FA6A49B9FA69F959CA19F919B9B979795939D
9096939898968D908F93908C9092878D8893878388898183878C8D828986868A8483877D
827D767881777E7A787A7D7B817E7E73727F7C747675777C6F7871746E74747573796F6D
6B716F746F6F736C6D7272716F7472697165686A7069716F6B6D6A656E666A6E67666868
68616461656A6262626467666765686D6369676D65675F666369625E62666A6261606363
5C5E6067695A5F62
62605C5D60615E65616564685E6365625E625B625F6A62636060626372685E6465646265
6361656661666167626168626568686D63606B6B61636862646665666C6C63646C726C6C
6E656C706B6C6C6B69756B706C6B6D6B6B6E6F6E756B77787675787E7A7A7B757478736F
7873737873787D777D7C757D7C77767B7C7B7A817B7E83838082857F87837F8B89807F87
7E81898A8D8A8285838588878A8C8B8D9089968D919091989492939493909B9A9D9CA9A7
A8A5A7A9A09C9DA9A9A2A6A4AEA9A6ABAC9DA9AFB2B0B9B2B1ADB7B7B5BCB2B9B6B6AEB3
BFB4C7B7B9C5BCBCBCC1C7BEC7C8C8C9C6CFCBC9D1CBC8CFD5D1D7D7D7D8D0D4CED6CCD4
DBD6D0D8D7D0D6D4D9D9D0D6DAE0D1D5DBD6CDD3D3D7D9D6DAD5D4D3D6DBD5D3D4D3D5D1
CBD2D0D3CDC9D0CCC6C4CAC6C9C4D0C4C6BBC0BEBEBAC0B5C2B8BDBBB9B7ADBCBDB1B1B4
B3A9B4B0ACB3B0A6ACACABA0A3A8A7A7A1A69FA4A2A0A59DA3A09BA4A198959999999A99
A297939494928C8992918C8F8F8E8A878D878E888A8A8497898F82828C8381837F7D7A89
7E7F7E877A7E8080807F7A757778787E7F7878757675787572776B70716F7A7673756F6F
70726D716F6D6E706E7170756D6B70656F726C686E68706867676B6A6666686568656D6E
5F6D645F656964696267616B656868626D656B676D6D6363605F6463656067656164605E
6267586557625B5B
5A6864625C5B685B5E5F64636063576262646567645B5F616161656B6669645961636564
5C6B656063666C666862606463676465656969696E6665676464676F6C696B6A686E6269
7068756B6C6469716B6D6D696C6C696A727272776C6E7070727873797676797474797471
7474787873737C7A6E807E7A7A7C7E79787C817F7B89807B81888180877D818884808683
8986868585878D8A8E908986858A8E8F8D8B89889094968C9496958D94959E9AA09DA4A5
A9A1A3A49FA19EA39EA29CA3A2ABAEADADA9A7B3BEBBB1ACB3ACBEB0BBB2AFB8B3B8BDC3
C4BDC2BFBCBCB4CBC7C5CCC8C6C6C7C9C9CACBC9D1CCDDD2CFD4D0D9DFDDDFD9DDDDD4DD
DCE1D0DDD9DADBE0DDDBDED8DCE3D4D8E3D9D6D7DED4D3DDD6D2D6D5D3CED4D9D7D4D4D3
D9D8D3D1D5CECDCACFD1D2CACCC9C7CCC5C2C5C4BFBAB8BBBCBFC1BCB6B5BBB5B8ABBCB4
AFB7B3AFAEB1B1B1AFADACACADA5A9A4A2A69FA3A09A9DA0A09F9C9C949B999B93929F95
94948F9A9997909193998B8E8D88948B8A868C8C8F8E8D8B89878D858683858587807E81
7C7E7C82757C83817A7C7D7678747871797A787B776B757D747377716E7174757A76756F
756E73706C7B6D7371716A716D6F69776B6A5E747171746C6B69686665666D676F5E6465
6E656A696C64646065626267666768666A6C636364626768655E62626265625963646666
5E5F665D5D655663
635C5C5B5F656B5F615E615B65665C5F5F575E656B63676462626961635C65625E6E6160
636B6E5E626266646566636365646867636B6F6568626869666B6D6B6B6E676A666D6B6E
6D6A6569726E6969696D6B6A776E6F746C6F6B756F777372767A7A7074716F7176747178
716B767579787A777C7476767778807F7E7B788581797C828083848086848B878185908F
8588858385938983858D8A888C8B938E8C8E8A90968696908F939893959F9A9DA7A0A4A8
A7ADA5A5A1A4A39EA7A1A1AAA4B0A7ADABAAB5ADAEB2AEB2B2B8B0B7B8BDB9BEC4BFC1BA
BEC4CACCBFC4C8C9CAC2C7C6D1C5CAC7D0CDCCCECFD3D5D5D8DCD4DCDFDFD7D5DCD8D5D9
DADDDBD2CFE1E5DFDEDBD8E1D7D9DADDDAE3D6DDDCDEDFDBDCE1D6DAD6D9D5D8DACFD7D5
D3D3CECFCFCCD1D2CDD5C9C8C7CDC6CBC8C0C1BCBBC6C3C3BEC0C4BABBC3BCBAB9BAB5BD
B4AEAEABA5ABADA7AFABB1B2A9A4A8A5ABA29FA8A1A89EA69F9E9D989B9D9AA19D9D9496
9F9A95928F8F9490908D908F8E928C8F8D908D898A86898D8F8F88877E8B888380867C7A
7D7E7B84817A7E7A837A787E787A78827A73767979707679706B7879717770656E706E6B
726F6E72707270776E6E6F6C6C6D6971726C6B70736A73676C6F6A6D6C636465636A6763
68646767676865646A69665E6562675B6866615F636F6563656C5B615F6A6662645E6662
5F6162695E525F5D
5E63605C5C6768635F605D606A5F635B5C5E6269676565636463685E5E5F6862695D6067
696265686C6A65646166656369676762666461636A63676D696F636469696A6C6B6C6F69
706B716D666C6966706E66676F75706A716F72706F757372796F76747678717B6B756D6D
7474796F767C787C7A7A787180767D7F7B78797C8380828284837C83867E818A8483838A
848C8787829190878D838C8A878E898E8A8E8B8A90918E8F8F95999D9597919B97A69BA4
A2AAACA8A7A19DA4ADA3A0AAA6A8ACA6B4B1B3B2B5AEAEB3B7B3B4B4B3B8B9B9BBB9C0C3
BBBCC3BFBFBDC0C5C5BDCAC8CDD2C7CCCDCCD0CFCCD4D6D9E2DDE4E1DFD7D7DDD8DCDFD9
E4E3E3DED8DEE5DBE5E6E1E6E1E3DCE3DEDED9D5E7DAD9E2D5DFD5DDE0D8D7DADFDBD3D8
D6D4D4CDD1D7CFCFD1CACAD1C8CAD0CAD2C6C7C5C8C3BFBCC1C1BFBEC4C3BFC4B5B2BAC2
B9BBB2B8B2B2B4AFAFAAB0AEA3A6AAA4A69E9FA4A4A19F98A3A2A19DA69D9EA09E94A19F
9FA19A8D8F929794968E8E938B8B918E9091908C878B8C949390888A8981838188858782
857A798574798074817B7F87767C787B7C7B7F7675797A7771766E7A757779757671726E
71726B6F726C72687179716D6B6A706A69676E6E736D6D6D716A6566696C6E666B69666A
626064676B5E6E625D606466655F64636D5F676A67695F6166616561655A666269656561
62605D5C5965585F
5E616261625A6269656165635D68646165676163675D62645E6567626367636464666261
66646B6164616A6C636863656B666A6368636266645F6C666662646B70646A61656B706C
73696E6A69686A716B6B6B716E6D6F7172706E70787473716E726E707371796E7575737C
767075757C7A75817A7C767F7F807B7C737D767778827E7E888283868B8B868B8682858E
8B888583848A938C91888C8C91898F8C8F8A8E9497929A9C95938B949A9D9E95A39D9EA2
A4ABA09FAAA79BA1A3A5A7A7B2AAABB0A6AAB1B3B8B6B5B5B5B6BBBAB4B3B9C1C4C7C5BE
BEC6C1C1C2C5C6C3CBC9C7CCD2CFD4D6D9DACFD5D9D6DED8E1DEEFE2EDDADDDBE2DBE1EA
E1E1DCDDD9E1DBE1E4E2E8E2DEE9E5DCDEE1DDE1DED9E4DBDCDCDAE3DBE0DBD9D7D9DEDB
D5CFCEDADAD8D4D3D3D1D2CDCCCBD3D8C9C7C6C3CDC1C3BECCC2BEBCBABBB7B8B5BAC1BA
BCC0B0B3B1AFB0B2B1ABAEAAAEA7ABA29FA3A1A0A7AAA4A2A0A29C9C9E9CA6969A9D989F
9C989F959699999496958F9394918F888C898A8985918E8A8A8D838C89828B847C838181
7E81867F807B7D7D787B7C7F7D76787B7C7D7B7C737678757B726C707B7B6F7070736977
716E6B746F77736D7773766B6B7070686A70666C6E716A6B706D65726E6F6D646D66686A
6C61686169636668646663646560676465616566675C67666864655E6361645E605F615C
635E56595F5E615F
6361665B62635C666A5F616061705A625D6460656067646265686F5869636C6063645E64
666461635D646163616564626A686264686766696D676A6B6467646B6E7370746B6F706A
6A766A6C6F6D6B6C706C6E6B6A6D6F6C716E6F786A766B6F6C6C6C77737373777270757C
79707978787D7882797875777E787A8481837E7D8185858280828387878680818A868F8B
8686878889888A8D858A8E968B919493938F94909398959396909197989E959DA2A09FA0
A399A3A4A1A8A4A0A6AAA5A5ABAFAFB2B3B2B0AAACBCBBBAB4B7B6B7B8C5B9BFC4B5C6C8
CABFC4C6BECACAC6C0C3C9CFD2D4CFD6D3CBD9DCD5DBD5EEE5E7DFE9EAE1E4E3E5DCE8E8
EAE1EAD8E7D9EBE5E7EAEAE1E0DFDFE5E8E0DAE2E2E0E0E3DDE2DEDAE0E5E1D8E7D9E1D6
DBE0D4D3D5DCD5D4D3D3D3DBC9D4DAC6CFC7C2CCCCC9C6C5C1BEBCC5C8CCC1B5C0B7C0BB
B4B2BAB5B8B9B6B0B3B6ACAEB2ABB0A7A7A1AAA29EA19C9AA49E9AA4A39FA5A0A09C9D9A
9B94959294969C928E918D8B91908D8C8F8B90948D85857F8A88828B858489807E838184
7C848781817B827C7B7A7C7E797579787774787A7A7E757573777D747872797572766C75
71756E70776D726D726D6D6D706F6C6D6F756C746B646A6E6E66686C6B66676C616B6C6A
6467616D5E646668666669646A69685D6263686665666669696A63676462645F63605F5A
6567606165625E5D
5D635F5E5E6362685E6059655D626366666364616266646863696564666D626568636268
686569675D6B6A646268655D6561656666606B62666A636868676C68656F696B67696F6D
71736B706D626B6A67696E6C6D756C76746F7173736C766E6B74697672786F7172737A78
757770787478727C777C7D767D8081857C8679817983827B84807F878785898E87878388
8988858C888782868C8A8C8A918E8D9198929597899198909593979D99979FA29EA295B1
A2A1A6A294A5A2AEA6AAA9ACAEB2B2B3AEB7B3AFAFB0B5B3B5BBBABCB8BBBDC1C5CDC5C6
C5C0C8CECAC4C8D2D0CECFCCD2CDD3C4D0DED6D3D9DDE8E1EEF1E5EAE4EBE4E6DEE3E7E3
E7EBE9EAE5ECE6F0E5EEEDEBE9F4ECEBEAE3E8E6E5E9E5E9E4E3DDECDAE0E1DFE4E0E1D0
D8DBDDE2D5D7DED6D8DDD0DADBD9CACDD2D2CCD0C9D1C6C3C3CECEC3C3C0B9B8C5BBBFBA
BAB2B3B0B6ADB1B1B3ACAFACB4ACA9AEA2A9A7A7A19DA8A09BA2A1A2A39FA09EACA1A49A
979993989194968D99948F9496918B8F8D8B8B9388898689868887877B8484818185887F
7E7E877B797E797B7A7F787B777D7B777681777374707E7E74737979717D6E766E717476
6F79666D726F6C717A76706F6F6D67706B6B796B6D7467766D6D6B656D6A6A6D69646868
65636D6F626B646B63646A5F63645C6567696A67596D6767646266676561645F66586067
63615A5E655D6161
645E64605E60605B626462626262655F5B6A6A626062636063636562676A5F6367665D62
5E665D616B6C6461666263606268616A666767686A676C6E6D6E6B696967646C706C686B
6F7074696E686D6E686A6E6D6F6B626E727572706E726E6B6F6C6F6A78776F7A6E74737B
7578747A77747E7D7E7E757C81787B7A8484727C787F857C87868684898084828487887E
86848386898D848D898C9190938A89949193908D91929890949192989BA297A39E9A9B9E
A1A79CA6B0A9A9A8A8A7A6A2ADB4B0B3B7BAACAEA8B3B8B8B2BFBFC0C0BDB3BABDC4C1C7
C8C8C8C5CCCDD4CBD2CECDD2D1D4DDD6D0D9D9D6E8DDE8DFEAE2E4E2E9DDE8EBE2EEE7E7
EBE4F2EDE2EBF0E3EBE5E1E6EBEBEBEEEDEBE2E5E6EBE2EEE9E5F0F2EEDDE7D9DCDCE2DC
DDDBDFD8DBDDD1D1D8DBD6D0DACED8CCD5C8CFCFCBCDC9C7CDC1CAC3BFC0CFC3BEC3B3B7
C0B5B7BAB6B4B4AFB1B8AFB0B4A9ADABAFAAAFA8A4A7A4A5A9A1A2A4A0A8A4A2A39B9A9E
A196959E9E90998F9397979291938C848D8C8996868B8D8A8F8F8D8D8C8C838582888082
7D807D837C787E76807E7A777782837777807A797A807A7170776F76746F717472757173
6E6E6D6B6F717571706D6F686B726B6E6B6868696C71626D6C6A65636066666A6E646165
676958626A676A62666660666361615E60636A69636E6E6466666366606260685E686465
63625D615A5D5F62
676360585E615C5B66655D5F6667646A5F58666368646D615F6368665F5C6465625F615D
64606365616A6F62636060676764636765696B6962676668736D68696A67646A686A6D6F
6E6B70686C7068696A68746F6A686D726E7A766D6E706B6C716B757B736E717770797877
7A757474727676767D7B7E7C807C7B7E7A817B7E7E8688818082827C85828E86868C9185
878689898C8589828A8C89888F918C988F95988C949696989D9E9F9DA09BA0A0A29B9CA5
9AAAA4AAA8A5ACA9B0ADAEADAFB6ABB5B9B9ACB9B6B1B4B1BCBABBC2BABFBECDC0C8D2D0
CBC6CDCECEC9D1DBCECED4D1CFD3D0D7D9D5D5DEE2E2DEE9E1EEE8EDE6EFE8E2E7F1EBE8
E4F3ECEDF1E9F0EBEFEDF0EEF1F8F1EBEFEEF2EFECEEE9EFE7DDEFE6EBE2DFE6ECDDE2E7
E0D1DFE3DAD6E2D6D6DFDCDAD5D3D6D2D8CEC9D7C1CBCBC9C9CEC8C0C6CEC0C0B8C2BABA
C1C0B2B8BBB0AEADA8B2B0B1B1B1A9AAAAADB0A0ACAAA3A3A8AFA8A59BA19E9E99989997
999A9A9B9D9793989391928D94948C91918D8C8D8B8F8B8D8E8A828D82887D8389848982
82847C7F777E7A8C7D7D807A7C7C7A7E7C807B7B7474766C7874777279807572736F706E
6F6D7474726B6F6D6F746F6F706F716B68716A6D6E656D67686B69686D6867626B6A6865
64696E7366695D6C666C666B6B5F65665E6462616764656B68605F66606061695B686561
6957635C5F655862
615C60616464635D636266645F6A656061636A6A5B5A635E5F6763665F6A6D5E5F60675C
6A6763635F655C5A646267646B6960686768676867656866615F6A69626A6F6B6F6B6D6E
6C6F6876706B6D6F676F64726A6F78746F7373746C716D70727A6F6C737877776A747874
76757780817984757F7F7C87827E7F7F7C7D827C817E8583807E888782858786898B868A
8C8B8B89888D8F8A8A91958C8E969891978E97979098939092959F9F9EA5A0A2A3979FAA
A4A69FA4A2A3A5A8AAB0B3ADAFB5AFB3ACBAB4B8B7B9B7BEBBBFBEC0C6C7C4C9C5C5C6CC
C9CDCCCFD2CCCFD6D3DAD3DBDFDADEDFDED8E3DADFE3E5E2F0EDE7EBF4E8F0EFEBEDEFEB
EFF0ECF0F8EDECECE8F4EFE8F8F7EDF9EEF6F0EEECE9F9E9EDF1F0E6EEEFEEE9E0EAE9E3
E2E1E1DBE6DEDAD9DADFDBDAD4DBDADADBDBD7CEDAD6D2CBCBC5C3C6C0C0B9C2BDBFC0BE
BBBDB8B1B3C2B7B1B5ABB5ADABB0ACABA6AAB3A8AAAAA6A8A2A9A7A9A29EAC9F989F9A9C
9C969F979A989293968D8A91929698928E8E9491899389878F86818784837F868585828A
7D867C7D7C8B84807F717E7B7B7E847477737576737C7C747578746F7571747679767974
6F6E6D78766E6B7372697577686B7367766E6B656871736B70686A6D676E646C60666A63
73696569636A6463686B6C656666666C6962686B62676661646368606562696560655E5B
605E5C5B5B5E5A5E
67615A64676064655E5E6166595F5D6360615B665F616362666A67696B665F6764606769
6C656A6362625F6A686364646B6C636C6E64686470646E6C64616968656B68696865726F
68706A666F6B6C756C6E6A6B706D6F726B6D7175717074706C6F71707074777479707A7B
757076767E787B80757F7F7F798077807E7A877C7E7A858783808681857F878985858D8B
86858B9088898B9092908B90919497948E9194A09995929B9999A29FA19FA0AAA2A3A0A0
AAA7A69FABABA5A6A5A5AFA9BDA7BCB1B5B2B7AEBEB8B9BAC0C3C1C3C1C9C5C0C1C4CBCB
C7C9CBCFD3D4D1D4D7D5E0D9DFD5D2DEE3E2DEE9E9E7E7EEE0E7EAECF4EFF3EEEBFBEEF5
F9F4F3F2FAEDF3F6EEFFEEF2F7EAE8FAECFAF5F3FCF0F1F5E9E9F1F8EEE9F0EAE8E7E4EC
E7E3E1E0DEE3E2E2DEDCE0DBDDDBD7D8DED7CEDBC9CBCBD3CEC6C6C5CCC8C1CBC7C1B9BC
BCBBB8BCB9B4BAB8BDB3AEB1B6ABB0ABABABA7AAA0ABA9A7A3A9A0A3A4A7A09FA19C9EA2
9F9C969D998D969AA19A928B94998F928C8B908B8E888C8C8B8E88858A897F8A84858580
838288837A83797D7B7C807B787B7B7D797D7B77737A7A7F6D74756C736F747D776D6F71
77756C767570706E6C6C6B706C6D6A6C6865666A6D6D6F6A6A696E64686D676C65656A62
6A6A5E65676962635F626B666363606362666363626463685F69696B636261646263675E
5E655C61605A5F61
635E5D635C6364606268616461606064666760635F69635E6568686E6D6B6267606C6D65
60625D6663685C64606A6965686766686863656B6C656D64695E69676A64736F726B7470
646D6F726F706E6E706E626A69676C6B6769736D6B716E716C716E72766B6C7C78757280
7775787878767576787F7B767C7F7B80798587847C7A817D82888286898A7F8E8385897D
908988838B8F828991919596908A919892909995988F989B989693A19D9EA1A19E9B9FA4
A0A8A7A6ABA7A2ADA7B4A9AEB5BCB1B3B1B6B9BCAFB9AEBBC5B7BDBFC9CAC5CACAC4CFD1
CDC7D4D6D3D4DADAD8DEDAD5DCE5DED5E2E1E5E4E3E5EDEBE9F2EBEFEFF3F4FFEEF5EEF4
F0F2F5FBFBF8F3F6F4F8F3F2F4F4EFEEFAF7F0F4F4F6FAF3F3ECF7E8F8F0F3F2E7EDEDE7
EBEEE2E7E2EADFE3DED9DAD9E0D9DDDEE5CBDBD3CFD4D2CBC9CACDC9C9C2C2C2BFCAB4C0
BFB8BBBAC3BDB9BBB5B5B3B5AEB0B3AEAEAFB3A6A8ACA6AAA9A6A2A7A798A69C9BA09BA2
9E979F9E9993929B959292988F949795928F8A8E948C888B8B8582888387858385898B7F
88827C847B7A807E7782807F7D827D737879747B807E7D787B797B7D76727B7776757272
7472756F7170737074726C726D756D6B65686B6F6B6C6E6E706D696B6E676A6D686C6F66
6A666960666B6D6A6B6B6B5F65626F6366656469646259686966636861645F625962605D
5E5C596266595D5F
655F656161606463605B5D6664686361566163635D5B64666462656068666B5B65646366
636A686364676969635F606B67656068686A6A6673686E5E666F6866616F6D686A606C6E
7073706E6F666F726E71656D6F746F706F6E75716F6E76726D706D7574707F74777B777B
717A7577797B7A8081857E767D817F7F8281807E82857F80848587878387868883868988
809A8D8E8A8D8A878E8A9191919893998F9895959B90949C9397989F9F93A49DA39DA4A0
A0A4AAA5ABACACA9A9B5B7B8ADB5AAB6B0B3B2B6B6C5BFC7BBBFC6C5C8CDC7CEC6CFCCD1
C6D1CDD9D2D7D8D8DEE9DFDCE2F0E5E9E4E4E1E6EBEBEBF5F1ECF8F4F2F9F4F5EDF9F0F2
FAF4F6FDF7FFFBF5F6FFFDF1F3F6FFFEFBFBFFFDF5F8F3FFFFF5F5F7F6F2F8EEF1EEEAF1
E8EFEADCE0E8E6E4EDE0E2DCDED9D7DCE2D3DAD9D5D9D2D9CDCAC9D3D0CFC9C0C3C1C6C1
C4C4BFC5BEBCBCB8BCB2B9B0B3ACB3A8AAA4A6B7A4B1A7A3A8A9A3A7A3A1A49F9B9F9F9F
A1A0A09D9999A0959196958E9092928F938F898D958C8C8A8788828985897D82828A8083
8785857E8A82747C85837E7B7A7A827F7E7C75757F7A7D7875717A737B7275736D747371
72706F746C737770726E6F666D6F6A6F6D6B6D6E7369686E6E656B68686A6A6B72646A66
6E626A60676C666965626960696A67686A6D6663666861666D65695E63686C65646A6560
575E605B5E6A5C62
5E6461595C6066605E605F5F5E635F616461696168616561676764636360686066656966
62616B63696D6866656C6965696B6167636B6A646E736665636B6764656768696A6F6D6C
6C6A71776A6B706B6F6E6E686C697070676C6D6D796F7270767174757A7273727572767A
77767D77787D797A8275787980807D7E7C797D7A807F7D7F888484877D8A868B848D858A
90868C8D878C96979090928E959B8A949E9F9F948F939897949A9F9DA3979FA29EA7A1A4
A1ACAAA2A1ABA9ABAFB8B2B8B3B4B9B8BABDBBB7BDC5C7BAC2C4C8C6CBBFC4CACBC2D0CF
C7D9DBDADFDCDADCDBD8D9E4E4E8E1E5E8E8EDEFEBE4F1F0F2F9F1F3F3EFF7F6F8F9F3FF
F9F7FFFFF2FAF8FEF9FDFAFFFEF8FFF9F5F9FEF9FDFFFFFAF4F8FCF1FFF8EDF8EFEFF4EA
EFE9F3E8E1F0E7E8E3E3D9E6DDDEE2D7DADFD6DED7DFD4D0D2C8C8CACACEBEC8C8C4C4CB
C3C2C3BEBEBBBEB7BAB8AFB1B0AEAFABB2A7B3ACACA3A1A2A4A6AAA19F9FAAA79EA1A29C
9E9A9E969D9E9F9494929293978F97948D91968F8D918D938B8B88858E8A868784888190
887D877D80837F7C7884818182777D807E76797E7C79717078787B78747D717574757572
726F716D74696C736F6D6F766B6E73716F6E71726E6E756D6E6F6D686E716C68686C6D64
6B746A6F666C6063676263656869696763656A62675F646A5E645F665F6A6662625B5B63
5F6A635D57625F5E
615B60605D635E675F64606567635E61606362606B63636065645E5E6262646666666361
606C68666B666862656664696867686E646C686D686C6A66686869677569696670746E6E
73736C686B7176716D70706C6A6D6D767370717172767A727171737C7276767E75757975
747C78767F81797C7E7C74787F7F7A7F828A82868886897E7F8883818582848A8A8A8C8E
8E8B8787928B888C8C918E8C998E8F8E91959C969999999B969A9AA1A6A09E9DADA2A8A7
A9A9AEA5A8ADB1B2B1AEABB2B7B0B2B8B8C0C6C4BBBEB9BFBBBEC7C9C7C5BECACCCBCED2
D3D0D5D5DADAE5DCE1E0DCE0E5E6E8EAE3F0F2ECF0F4EBEBF5F6F6F5F3FFFFFFFFFFF8F2
FBFFFFFFFFFCFEFBFFFFFFFFFFFFFFFFFFFFFFFDFFF9FBFBFAFAFEF7FBF7FBF5F0EEFAEF
ECEFF2E5EEE7E5EBE6E4E6EBE4E6E7DEE3DAE0E3DAD7CFD3C8D6D6CFC9CDC6CCC8C3CCC9
CAC1C0C2C2BFC2BBBEB5BAC0B8A7B3B2B3ACACAAB0AEACA3A7A8A5A4A3A7AA9A9FA89EA2
9F98939998999596928EA18E999395998C8C938C8A8A8D8D8E8B8580818A87868B838683
80877E82858680827C7F817D80837F7F7D7675797F747576777576797576777679786F72
75737770746E736F787A6F706F726D6C696F6E6E6F6B6D686B68656B636B6E6C69676A65
63706F6A6163646D686765676C68696B6869686A6162656663605F65645E666061626361
5B5E636466586263
6361685A5C656163605F5F656261656669606263675F635D6D626768696665616B656467
63636667635F62696663636164656C686E67666864666F70696A6C6F6E6D65756A686D65
6F70716E6B6C6F7470706C726D6A6D7374717B747675746A6B77727A757179786F767D75
7A7C727F787D847C7B7A797F7C7E817F857E827D85827F8C828A9281888B888C8A838988
918D898C8C8C918A92869A969A95969C9499958F9E999B9B9A929E9FA3A6A8A2A0A6A5A6
ABAEA0AAB1B2B2A8B3B2B3B0B2B3BBB9BFBFC1C0C2BDC5C1C1BDC3C9CCD0CCD1D1D2CFD2
D2D4D8DEE4DCDCE0DFE6E9E6E5EBEBE6EBEEF2EEF1EFF4F7FBF5FFF4F8FFF6F6FAFEF3FF
FFFFFFFFFFFDFFFEFFFFFFFDFEFFFFFFFFFFFFFDFFFFFFFFF5FCFAFBFBF7F2F9EFFAF8EF
F0F5ECF2EDE9EEEDF2E9EEE4E4DFE8E2E3DEE2DAE1E4E2DAD2D0D8CFD1D0CFCFC2CCD0CE
C8C7C6CEBBC6C1BBBAC4C1B8B1B3B3B7BAABAEAEADB3B1A8A8A2A1A4B0A19D9F9BA1A39D
9B94989C979494959791959B9695918F929796908F8D908F918D88858586868284808B80
7D82817B7F7F827D81877B737C78787F777B6F7B797C78777777797F7070787C7770726D
6E766A7571706E72766D776E7372726C6A6E636D6F646D706E75656F686A6C6C6C696766
65646B6C60676B646269696B69687072827E6A6C656665676969666163626966625D6161
6063645E62625E61
5E5C615D5F6162575C61605B6467636463606F5F625E625C66635E65636B5F616E68625B
68666962626069696763626664636860636569676F6A6B69695E6B6E6B72686D6C6B6172
6F73686E6E736F74746D6D657072736F7474766F7A79786E757477797675707C78726E7C
7B777980827C7D76797C797D7E797D7F857F8077848784838C7D827C868B8C83848F8886
918C8D8F8D91949691998A918E9599A29997958E9D979E9B9E9BA4A2A6A5A2A1ACA59DA7
A4A3A5B0AEA8B0B0AEACB3B8C1B4B8B8BBBBC6BBC6BCC2C9C5C9CDD0C7CFCFD5D0D3D4D8
D1D6D8D9DADDE0E4E4E3EDE4ECECE2F2EAEEF4F3F5FAFDFBF7F9FBF5F8FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEF5FEFEFDFDFFF6F9FAF4
F4F5F3DEEFF3F1ECEEEAEFE6F0E8E7E6E4E9DCDEDBDEEAD8D0D6D4CFC8D4D0CEC8C5C2CC
CAC8C0C6C3BDC5C8B5B7BABAB2BBA6B3B1B3B3ACAAB1B2A9ACA6A5A6AAA2A6A7A39DA2A3
9E9B9A9295959998939996999591959994918B8E898A908D888B898B828986808D7F8585
858A868881847E7B8A7A82857F7C76817574827279797B7B7574787477777B6E6E6F7171
726F7175776E74706A707273726D716A67726E696B6F706F706E6D646D6B6A6769686968
6867676C6D6369696562646F67697470968C6A73695B6B5B656966626B665D6666606A54
5F64626461576063
64625E6A64655C62675C625E64646A665F6B69645E63645C61606469646269646C676563
6B61616169696664665F62676466676769686C696A6D6666696969726A6B6A6F6C6D6470
6F6B64666F6E6F746F6E716D7074736E7171767070777677726F717D7072777678797279
767C757074757F7C7D7C7C7E7C7B8181778481817F7C8487837F86888382848A88888E87
8D8F888E888B918E8C90918E9194999A9C9898959A9E979D9EA5999F9FA6A7A8A3A5A3AA
A5B5B1CBB6AEABADBDB8B6B2B8B9B3BFBECCC2BFBFC2C1C8BFC7CDC7D4CECFD0D4D2D9D6
DCD1D7E3E1E5E8E1DCE6EBEDE9EEF3EBF9F0F7F7F9F6FFFAFEFFFFFFFFFDFAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFCFDF6FFFFFB
F5F6F8F1F8F4EBEBF5F9F1EFF0EDF1E8E6DEDCDADEE2E0DCEDE6D5D0D8DBCECED3D3CFCB
C7C0C7C7CDC3BDC4C2C1B6C0BDB9B3B3B9B0B3AFACACA9B6AEB2A6A7AFA9ADA0A09EA4A3
9A9D9D959A9C959692949C99989097969693968B95908D9088948D918D828586807B8590
8685818183837F7E80817F79777C807D787E8074717A757478747574737B78757B707372
707D707371727370746D716E6B7370676C6E6F6B6C6D6C656A696D65686B766B656B6D6D
696B656C6962676A666A6667646A6A777B6F6E69606A61685A636764645B656865686069
625E696562605A5C
605B5A61646160625E616561645E666366635F6267666362655E625F6466696765626662
6168646C5E6467636567676A686666646C6F6C6B68646B646468636B6A62676660767168
6B6D6E6C6C6F737669716F73716D777272797770727774736D79716F76756E7A7473777C
7A79797B7B7C7C7C807F787783867A7E7E817E82858A8A80817D83827F8D878A8A8A8588
888C898C8A878B9295909A9693909191999E969BA3979E999CA098A1A5A0A9A4A6A7AAAE
A9AEAAABB2ABB0AEB4B9BCBCB6BFBBBDC1C4C0C0C1C5C8C8C9C8CACECFD2D2D0C5D5DADC
DDDBD3E2E4E5E4E2E8F0E7ECF0F1EDF0FBF5F6FFFFFDF8FFFFFFFFF4FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFBFB
FAF8F5F3FEF2FBEFF1ECF0F5EEEDF0E8ECE2EBE0DAE6E1DEE3DED8DAD1D5CED1CFCDD5CE
CCC1CBC9C5C6BCC9C8C0B6B2C0BBB6BAB8B2AFB6B9B3B1B3ACADA7AFB0A8A8A4A2A398A2
9E9F9E9A9A9894959792959893929A96949E90968886928E8C8E8C89918A8E8D8685828D
83888B828186847F7D7B7383818076777B7579817A7C797A7B736F77837D777071747577
72726F71706C7A7175736F6E7267716C6E6F70776E6E6D716B686A74706D73696F716C6C
6C6C6B70656466676B6469656D626B76706D6E60686763615E616E66605D605F62656564
6165605F5C626362
64655F6266666761635F636564636B626068685B616664646469696762666A6D6461616A
5E6068625E676367666068696564666660666A6B6A69686B6A68716D6371676968736B64
736B696A6E6E766D6F7066696C777578756E72767773787178767C767B70717174778082
797C7A7C797A817F7D7D817D7E77837B808385897E83828489898382808B848C80878F8E
8B8E858A918E8F93928B9B99968E989F9C9999A1989999989B9BA2A19C9BA2AAABAAADA9
ABABADA8B9B0B7B4B5BEC0C1BCBCBFB5BCC2C1C6C2C3CAC9D0C8D4D7C3CDD4D1D9D9D4DC
E5E0DBE2EAE5EDEAECE8E8F1F5EDEBF7FFF2FEF5F8FEFBFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFBFCF5F2FFF9F6F3F0F4E5EAF4EDE3E4E7EBE5E0EAEBD9DEDBDAD8D9D6D9CBD2CF
D0C5CEC5C6C4C0BCBDBEB4BDB6B9BCB0BCB7B9AFB6B7AEACABADA8B5AB9F9CA0A4A8AA9B
A39A9FA29D9C9F8E9BA498938D8F9C938B9E908C8D928B8A8A8C9385898A86858A88898A
888D8280798281797D7C83847A767D75767E7E7B7E777979827A7A727F7C767479727477
73706C7070757570727872766C69726D6F6F716B71706A6F706979706C6F6E5F6B6E656C
6B6969646466666A6A686C6A63676562626767636C5E6864685F5F62656664666A676363
62656163625E5E63
63635F5C615F6963656363586661625F6463645E646A64626A64695F6B646E67666A635E
645E626C636A616166616D6B6061636767676E65666A666169656A64676D706B6C6C6B6A
6F6A646C6E6E746F756B746B6D736B6E6F74787875707578787377717272707C82747876
797C768179877A837C7B7B7A7F7D7A7C81868488828788828183858D8A8481868B898689
868A8D8B9690969494918B96989392959A989D9EA296A1A19E999DA6AB9FA1A8A3A7A3A8
A9ABA7ACAEBAB1B2B8BEBCC2C7BCC0C0C8BDC3C7CCC6CCC7CACFCBCDD0D3D3DCDDD8E2D6
DAE1E2E4E7F1EBEDE8F7ECF6F1F8F7FFFFFAFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFDFEF6F7FFFCF7F5F5F0F0F0EEE8ECF3E1E5E8E8E7DEDADFD7D9D3CFD1D3CDD0
CBCAC7CCCDC8C8C3BEBBC2BBB7BEC0BCB9B8BBB1BEAEACBCADA7A5A9A9AAA1A3A3A29DA5
AA9DA1989497989A9D969F9599988F979195958C8E8E8F8F8989918D9092848D8A84887D
8581797F837F817D7F807A7E7C7E7D7A71797E7F7D7A7C7F777C7E7A747B707A76717677
726F726B6F6B7673757B777775746E726C78766A6E6F6D74706E66666B65656A6B706C66
7066696564636564686A616262645D69656267616764616862635F5D64666262666E665F
62636261685C635F
626962695A61625E5E66646260645F635E62655E646663686467676765656C646E5E6A62
6960626068646364676468676C64636C68646961636F726670616B686B64606F6E6A6A6E
6D6F686D687374706F777577746B73727072717576747673757273777A7272757975767B
7D7A7E787C7B7C7F79747573847F8C8187888089827F858284888683868E83898784888F
8D8A888B8F949592918E9C979C99929D939C9B9699959BA09DA3A7A09EA1A7A19EA6AAA2
A7A6AEB0ABB1B3B4BCBDBDBBBCBBBDC7C1C6C5CBC6C7C6CCC8D0D6D5CED2DAE3D7E0E3DA
E8E5ECDFE9F6F1F3F2EDF8FAF9FEF5FFFFFDFDFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFFFFFFFCFBFCF5F3F4F2ECEFE8EEE7F3EFE6DBE2E8E6DDE2DED8D1D3D9D9D9D9
CBCCC4C7D0C5C6C7BFB9B5BDB9C3C2B9BFB2B8B4B5AEB1A9A9ACA6A2ACA3A9A2A2A69EA4
A3A499A097A0A0A09694929590939E8E939491918B938D888A94898588868386858A8384
7D838383818382837F7D798185817F7D7A7C7D7F7C737B7F75787577707C6F7570777576
726F6F71777772746F75716D756D736E716A6B6C6C6D7168696A6C64736E676C6B6A676E
69706C6266646665696A666B62615E6B6763696460605F685A625E656D676460646A6663
5E5C66645E5E665B
666261625C626362646265676168656B6264605F635C696C645D636C666A606B6D616A6C
696363656263666662626B6561686865686A6C696D6A636B6A6E726D6964646C666F6E70
6F6A7172706A6C6E6B6F756C757670707175726F7076707371737B787A7679757B747579
78847E7A7677767C7C7F7F7A86777C817F87807F85807D858085878A898C828A898E908D
898D888D98948D959B97929B9F929F98999D99959A9CA7A1A0A2B0A1A49CA2A6ABA3A9AE
A8AFAFAFB5B9B3BBB4B9C2BFCAC3C1C2C3C1C4CECECECCCFCBDADBD3D1D6DDE0DEDAE3DE
DBE5DFE9F0EBEAEBF2FFF8FBFAFCFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF8F9FEF6FEF9F9EFEAF2EBF4EAF2F1E7E5DCDFDBE2DED8D2D4D6D2C9
D2D1CED1C8C8C5CABDC2C5B9C1BBBEB5BBBABAB6AEB2B7ADB4B6ACACA0A5A1A9A4ACAAA1
9D9DA3A6A0A29BA0959D9C9996979C9596969593919590908F8C878A8889868985868188
868884838B877D818284817F827E7984797B797D7B747D7D7779767B777675746E727474
6C697271737672777173746C7667686B696C6F6A69726A6A6E6970676E6E716B656E6F73
6F6E6B686663676A6765656466655F62656265616764635F646A5F616765666561655D62
636260675C615E61
635C605D5F625F605F6263635C5D6661606360666A66646A6466695F606868686A666962
6264636562616667676964666B696A655E66776C686F7471706B67666B6868656A676B69
6B74706E6D6E736E696B6872756F7B75756D736E6F73726D736F7B777173797D7E777774
787D7E777B7F807D7F7B827A7882828280827E8189838686848785898C8B8180968F8A85
89948A968C8E898F93958F988CA2A19A9A9C9197A09B9FA1A59CA79DB0A3A7A5A3A5A2A6
A1AEB1ADB3B7BCB0C3C2BCC1C3BFC2C2C5C9BCC7CAC9CED0D0D5D1CED8DAD4DCEBE4E4EB
E1E2E7EFEDF0E9F6F8FCFFF5FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDFFFFFCFEFFFEF0F6F4ECF8EDE6E7E9DFE8D9DED7E1DADFD8D0DDCE
CCCDCFCBC8CFC3CAC8C1C5BFC1B9BDC1B8B7B5BAAFB4B3AEB2B5AAA4A9A5A8ADA6A19D9C
9899A6989BA1949F9D999B979890929592929191928A8A8993898C8F8687898C88858B82
818B807B83867A7F817C85878081817E7C7B7F787B7F767A77797B727370717377717075
777681746B7079746B7368756E6A6F6D69776A6B706D6866736A6E66666D67686D62676B
61656D686363646167666863616A66636467656461656A66606661626667646A67666664
5E5F5D64635A6061
62605B6264615E615B6367626C66615A6665656868666068626962666E696B6564696264
636A6B6668675F616D62666B646A6C6C69696C69646E6D6469716869686D696C716B6E6F
72726B756877706C716F6B6B706F716D7274717578746F6C707B80787F737678787D7974
777D7E7F7C7983837E7A7E79817F818387877F807A7D827C84878C8B8D8A8F8F8D8D9087
9289918B8F99968F9798929C9BA2989A939496A0A1A2A7A4AA9EA4A4A6A9ADA5ACAAB3AA
B5B5B8B2B8B4B6BDB9C5C0BDC1CAC5C6C8C5BACDCDCBCDCCD5D7D7D8D8D7D5DDE7DEE0E9
EBE4EEEEFBF3EEFFF2FEFFFDFFFFFFFFFFFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFCFFFBF3F1F4F4F7F1EAEADFEAEDE0E5DFDAD6E0E1D9D5
D8D1C6CDD6CBC7CAC5C2CABDC5C2BCB4B1BDBBB2B5AAB0B5AEADA4AAB1A6A7ABABA5A69A
9FA2A49E9D989C9B9E969B959896939194918D8F8D908F888C8B938C8E8A848B83858788
8C89827D82888281847C7B7E827C7C827D7D887078777C747C77797D7F6D777971747878
6F7578706E76706F75727A71746D7470726F6A6E6B6E66656B696768686D7168686A5E69
71686A6C6E66626E67736767666A69666263666664626A6069655D61655D61625B646067
60666662645C5C62
655E63625F605F636569625F5A625E59665F6A636367646263676A6360666369646C6664
63656567686B6A636A6365646264675F706D5E6577666564686B65666F776A6E6D6C6A6F
6F69706E6F6D6C706E6F7474706F6E726E7A716F6F7777726D73717576747B7A73717981
8573847D827E8480797C82827E7C7D808587817F7D8383857D868A818E888B90838B8984
8F8C878C8D8D93919B92979D9594989999949D9FA1A0A5A2A1A59FA9A8A4A3AAA7ACA7AF
A8B0B1B0B3B5B7BDCAC5BCB9B7C7C8CEC4CCC9CBCDCEC8DED5DAD7D8DDDEE5DEE5E4EAE7
EAEBF9F6F1F9F6F6FAFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFAFFFCFFF7F6F4ECF2EEF6ECE9F2E8E9E4DEE6E1DBDBDAD5D7
CDD1D8D3CFCAD0CEC3C9C6BBC0BFC4B9BBBAB5B5B2BAB0A8AEAEABAAB1A9A9A8A8A6A7A5
A39F9C9DA6959D9E949E959E959B9891919694978F95898D8797898B838B898388808B89
7F888B7E7F8784828084857D7F837E7B817D7A7D79797A797A7D777476767A6E7A747070
6E716D6C6F77716F70736B6A73746A6A7276666A6F706D6D756D636F6768696F6B676763
70636D6F6B6F6764676C6B6463716469635F676364635C6063656961635C5F6A60666668
6459615F625E5E5D
5D62595F5F5B645F635C5D6463636569636162606764646564696766636661666C675F66
676B606D63666A676662696C636C6B6968626A646D646567686F696C6C6D686A696A6771
6F66676F71736C677270747077717073766E7175727C77777E777C72767A76797E7B777E
7A7E807E7A807E76807887868582857E81808580827F877F808C888C84838E8B8B89958B
8F938D8D95909A8F9B9694909CA19F9C94979B9CA39FA3A6ACA1A5A7ADA7AAA8AEADACAE
A9B0B4B9BEB7C0BDC2C4C2C5C1C6CDBECBC8C9C6D5D4C9D7CFDBE3DAE2E0DFE6E8EDE8DE
EFF6F4F2F3F0FDFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFF2F6F8F0F5F3E9EDEDEAE6E8E9E4E4D4E1D8
D7D4D3D4D2D4CED3CEC5C3C9C0BDBABDBAB8C0BCB4B4BBB9B0ACA8ABAEA8A9A4A79BAAA6
9DA8A09A9F9F9D98A29C999B949795909396989196928B9296898C90868A8C8B868C8589
80868A7D7B8986887A82877E7D7D817C857D7B8079797C777A73727D7B7474736E706F74
71736D6F7073717571736E756E7471717266686D6A706B6A6A6E6C746C72656A6C666A63
666B626972646E6A606C66656964636560616367616563606659615F5F5E5E635F5E695F
64605E5B5E5E5A5C
625E5D5C5D5E5A5F5F64646565615A6161616264626C63646164666A675D60655F676869
666960676A6C68666966676D727069696A6C635F62696967685F6D7071676F6D68716C64
6E69696B6B6D6A726F6E766C717875706A7477727674767874737774768077737D807C7A
7578788276797A8387797B797F807F887E828483877E888785858C858D8B898E898A918D
8D928F8991988C948F9895949C9A949897A19A9A9C9F9DA59DA29FA6A7AAAAA9ADB0AEAF
B0AFAFBCBBBABFC1BEC0BCBFC4C7C8CCC9C9D3D7CFD3DDD7D4DAD9D4DFE3E7E8ECE8EBE9
F0F2F8F7FAFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF4FCFDFDFEFDF4F6F2F9F2F2EEEBEEE9ECE6E0DCD9DAD8
CCD2D3D2D3D2D0D1CACFC6C1C8B4C2C0B9B9BBB8BAB0B1B7ACB0B4B7ADB1ACAAAAA1A6A3
9EA6A6A5A89FA29A989C9D9A9996948F90949B9A8A8C8A958D919291938D8D9185858B80
858C80828682847D7F817D7D8B7E7D8481867B7C797A787B747A79777B766C7479747679
746F707B6F7576777C716F70707372676F7172766B6E69716D716D6E6E6B656561666969
657065686C686B64636A5D6C6F67676065626D6965686861636366636B676866605F6166
60635E5C635E595D
615F585C5D61676264635F656362666769656765646766635E61616468646366686A6168
6761696567676763656B69696468676B5F6C676870646C6C6F6D6C666C6D6E68656D6970
7076646E706E6E6E6E6F6A737370716C717474797770737474797C716F747A7D747C7585
79857B817F7E837F7D7E80828081848981827C84898A917F8E87828F90898B8C8B90879B
9194909390949B97959799959799999D9A9DA49DA1A7A5A1A6A5A0ABABADA3ABADB0B0B5
B4BDBBB8B2B4B8BFBAC5BBBCC2CBC3D1C9D8DAD5CBDAD4D1DCD9D8E3E0E6E8E9E6E9ECF2
EDF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFCF9F5FBFAFFE9ECEBEBEBECE8E0E9DAE4DBD8
D6D3CBD1D3D1D7D1C8C3D0BFC4C6BFBBB7B9B6BBB8B9B6B6B3AEB9ABACAAB0A1A8A5A2A0
A5A29E9DA3A29DA49EA0978F9798989696929B8E8A928C918F858D89838790928A8B8685
857B86828280827D898A7880798D787B7A7F83777D7F7E7F78817A7A747F736D74717972
7971776F7070797575746F6D6C696E6F76726E6A6C7666736E6D6F6C66696967666F6B65
6668626864676B676768686C6665666563695C6469646C66625E645E6463695F5D606361
5D645D60605D6464
605B5F61656561636268606466626463615A65656466636069636365606B646962636567
656A67656F62676363686862685F64686A666C656B6D706B6B6B6E70726B696B67776C71
726F6C726C747C7372746D7473776C716F7473737B787D767C7874757B7A757D747B7C78
7D81777978787A7F7F7E7B7E8581827E808184888284897F8887858B828C8F8D8B958F8C
928F8D97969598979691909D969E9C94979E9FA0A59DA2A39EA8ABA4A3AAA6A9A7AEB2B8
B7B9B8B5B7C0BCC3BFBEC5C0CFCBCACED5CAD2D0D3D1D8DBDFE2DAE5E6EBE4ECE9DEEDF3
F6FDFEF5FDF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFF6F4EEEDECF2EDE5E6EBE4DED8E8
D6DFD9D4D7CFC6CED2CACDBEC6BEC4BEC2C2BDB5BDB4BBB3B2AEADB3ADA8ABA9A9AAAEA9
A5A39F9F96A5A3A09F99939C94979595968C91938B92908F8D928E8E868B8B8C8C8B8889
8384858A887B8774807F82748086847B75787D79767A7B7D7D7D79757876757B777B6E71
7473737476736F6D72706D6A72686B676D6E6B6D71736F6770666C6C6B6F67626B686B67
6564636F65686364656566727072656A5B5F6462625C6463636B6962676C5F655E636465
636560655C5E6360
675E5F64635F655C625F5F6464626763635F6365696161636866665C6865646463646065
60696B606F6369666A6568646166686A6F6168696D6B67716D6A72666A6868666E657168
706E6F676A6E6D7273757671747A747575727578817776787979717D727B707B75757C79
7B807E7E7C7E7E7E7A7E807D857E81857F85868A8C82848C879084888B90878B8E8B848F
908F94969392969A9F9C97999F9A9898A29C9BA0ACA6AEA6A8B0ABA4A3A8AAB7AFADBDB0
BCBAB5B5B7B7C4BDBDBDBFC5BDC2CBD3C6C8D6CFD4DADDDFDAD7E3E9E8E1E2E6EDE6F6EB
EFF9FAFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFCFBF5E8F7F2ECEDE1E9E7E6DF
D3DCD6D5E0D0CCCEC9C9CAC3BFCEC7BBBBBDBDBABDBAB5B0B5BDAFAAB3ADA9AAADABA6AB
A4A2A7A09D979B9DA0A39A9C9999A09595948E909A928D95968E8B97868E8C8C8E8B868E
8589877E7F7D868283817E827F8880817E88807781737A7A7C7F79737D7A807378757674
707070707372736E71746D7077656F6E6375706D6A6B726E7169707363636F66636E6469
666A655E6D6A656C6D656E716B666266636A665E5D6062606662676760616565625C6762
5E636264585B5C5F
63626362625D5F5F62646361605D5E696B60616661696164665F6060686463626D63696B
7269686269666A676D62736666676A656D656B6B666B68706E6F6B6B71696F6D69676B73
70756A6B7371746F6F746E6F777468717474707978737C74757A7E787E767675737C7278
767D7A787A818079877A8683808184888187827E7F848B8588898B8A7D87858D87919D94
95918F8F949C9498899A9E989696979A9D96A0A4A29FACA7A8ABA3A5A7B0AEADAEB2AEAF
B9B3BBB6BAC2BCBEBEC9C9CACBC9D1CCC4C8D0D6D4DDE2DCE0E2E8E4EBEDEBEFF1F5F3F2
FFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FEF7F9F4FBF4EFEAEBE5E5DFE1
E6DAE3E2CFDACBD0D2CACAC7CBC0CAC0BBBFC4BCBCB7BCB5B1ADB7AFACABACA3AEA9AAAA
ADA1A6A5AD9EA2A2989B9697999D969B959998978E8C9297898A8C8A8C8D8489808D8785
878384858A8085807E7F85848080827E7A807E8481808183737671737F70756E76727274
7474767A6D70746C71706D726E71746C696E716E746A626E676C6867686D6C6A6C6A6F63
6D656961665F6865666662646A67655E6961655E60606368616566565F60665E67696663
5B6760605F5E5F5F
60636060645C65656A67676A635E625F636568636A656663615F6B6F606067655E656863
615E646C6A65606362676A6963626B63676A696464686F64726C6D69726E696E6B6D7067
706B6A6C716C707277737578726D747A757274787376777B7D6F7678777774747C76757B
7B7A838182797A838B80827F817D887E7F81808284848788888687888B87949093988C91
8D9495949B96919792949D999F9B99A09F9B9DABA2A4A5A8A2AFAFB0AAA8B4A9B7AEBBB6
C0BABABEB7BCC0C3CBC7C3C0C4D8D4CFD2D0D3D8DDD5D9E4E1E3E7E3E9EEE9F2EDF4F2FB
FEFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCF9FFEFEDF0E6EEE9E0E6
E0D8D8DDD3D6DFD5D7CAC8CFC8C2CBC2C5CBBCB2B8B9BAB5B0B3AEACABAAACA6ABA8ACA2
A6AAA5A39EAB9F9F969C9D9E9A9A9E99969D97938D95969494978E8C868B8E86918A8786
7C8785837A848483818180837588817C7B7F7D79817E7D777877797D757D796D70797775
74787074717572736F746B6B756967726F6A706E6E6A66706D68676F6B65696D6D696C65
656467666568656D69696662676865646462605F63646769625E63635F6361635A5E615A
60625B675D646564
645F61676065626467615F616362676664646166626064645F5D5F626A64666660666161
666267606A6363646C6F696669646865676A646864716D666A6F6B686D717167716C7272
6D6E6A6D6E6C7773766F746D73746D70797377787577727A7B777E767977727473778280
818783847F817D828082897981838280898280867F8B8B8B8385838C9599899392909990
8E9390929A98929493969B9999A096A2A49E9CAAA0AAA0ABB2ADB2B5ADA7B6AFACAEB3BB
B4C8BCB3CABDB9C3CBCCC6D0D3D1D5CFD4D1D8D9E3E0DCDFE5DFE2F0E7EAF2EAF7F7FCF8
FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2FBF5F4FFF8F1E8E9EA
E9DFDEE4D9DEDDDADAD4CDD4C3C6C3BFBFC3BFBCB8B8B8B9B1B9AFB0B9B7AEA7ABA6A9A5
A49EA1A0A0A1A3A1A19F9A9F9C9D9D9192948E99969390998F948E928F918C868F8E8C8F
8A8986888D7F848284848586877C807A7E81788C7F7879787F7B847D777875797E757A77
73767772747571766A6C6E6D716A6B72706D6C6D756B776D6B6D6F70696F6D5F68686A76
6B67696C6562696D676B6A706561676C696F63626C676569676167665E676266635C655E
62595F5D635E5D63
6464606161685D6460596259615A5D6560645E6663646664636662626664606C61556666
686C626C636F696C7267676A656C687160656B656F6868676B6E6E716A6E6C736D727170
756D67756B6D6E6D6C707770757977716C7674747875757678787E7F76787B7B7278777B
7A7D79817F808377817F837E81807F837D85888983888683898B8D8C8C908C91898D9296
91969D93919899949798A09A9D9AA099A2A1A2A0B2ABA4B9A5A8A9A8ADACAFADB9B4BCBF
BBBDBEBCBDC2C9C3C8C8C0CCC4CAD0D0D6DDDAD8DEE1E6E5E5E3E8EFEDF3F2F8FFFCFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFAF2F5F0ECEEE4F1E9
E7E4DDE1DDDBDEDCD6D4CFCACDBFCCC0CCC0C4BCBFC1BFBAB7B1B0B8B6A9ADACA9A9A8A8
ABA59FA9A59FA49FA1999C9CA096959598959499939A91949090978C8C8C87878A8F868C
89878D8488878384897F7A817F7B7A7F797886807A787E7B79797776797E777978767479
7774717272736D68737079686C6A71696E6872716D7366736864656F716A6A6B6C616365
646D6867666C6A6469626466696D635F6165635E6065625F656261636762665E65655F64
605E665E5F63595D
646367616A625F5F6064616067666061685C6663665E5D60656460626569626463616962
6468627164696D69676D65676867656B696A6F6467686C687274716C6D6D6E6C756F6D70
6F6D6C707367706E697774716C6E71727174757677767B707B7A7874737C7E88757C7A7E
7F7C7B848084808282837F7E837B87898384818086868B84848D868E898D928A8C928D8F
918E91919C969792979B989F9AA3959DA1A1A4ACB0A8B0A9BAAFB0B0B2ACB1B3B0B1B5B7
C0B9B9B9C1BCC4C8C6CCC3C4CECBCCDFD2D8D7DBDDE1E4E4E8E8ECE8E7EFFDFBF4F7FCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFF7EAFBEEEDECF0EC
E4E9E9DDE6DDD7D7D7CECBCFD8D9CACBC7C1BFC0BBC0BEBBB9B4B1AEBBB7B5B2B2ACA3A7
A7A4A2ACA6A4A5A49BA09A959F93999B92949597929E9595908E958A898D94868A8F8987
86898A828288807B827F7E7E7F837D7C857A7E7B7A7E767B747C75717E74757B72796D77
796E7370756F746E6977756A67696F6C6E6D73716A6A6F6A69686A676F696C6863646465
6B6068686763666D6C6669616268616567616665666D636161615C6464605C5E5C645E60
61636A5D62685F66
615D60676263656365666C68656D5D64646065646061676661626268606D6760615F6565
67656569696768666865606A686C666B656B6C696469666D6B71726D6F7068737476706E
6E6E6E6F706D7070777171776D766D7A74737A777975787A7678747D7A7F79807C827E76
7F81817D837F79797B807A85897D868E868C7E848F84848A848F8C8F8887949494999194
8D8D8B8E99999594959B9C9A98949F9AACAA9DA6A2AEB2A6AEA6A8B2B3B0B3AFB9B2C0BC
BAB4BAC2C3C2C3BFC6C7CBCCD2CDDAD9D7DFE2E8DFDFE4E6F4EBEBEAEFFBFDFCFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F5F7E7EAF2
E2E3E7EBE1DAD9E5D1D6D4CFCFCECBC6CFCBBDCDC9C3B6BAC3B9B9B4B5B7ACB2B1B4B8AF
AEA8A6A7A4A29F9F9F9EA29E9C989A9796989F9E949197998F918F8C8D8C8C8A8C838A88
84867F7B8881847A807F84818082867F807E797376817E7B7B7A787E757771757879777D
7872787775727572736C727371736966706D6C696A6D6669766C676B6F6E69646465676A
6569656C677062676A646A6D6C68675F656369666866596664606858655D6962646D6160
63646465615D5D64
66656861646061605D626461645D66625C5F5F6767645E6565676B6A6264686866606A62
6A6F6E67656763626668646A67656467666B65626665636A69686C707473716D6A6E6D6F
70726C6E6F6D7176766A6D726F7070756F77777C777379767873777C80757C7A78817884
7D7D8279858182887D828781877C868A8987868E8885868482898E8A938790978F939693
9A8D9C9D97929B96979AA1969E9C929FA5A2A0B1B0A8AEA7ACB1AFA5AFB4B6ACB9B7B6BE
BDB8C2BCBBC4CBD0CCCEC8D2CCD6CED4DEDCDBE4E9EBE4E9F1E8F3FDF4F5FAFBFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAEFF9F3ECECE2
E3E8EDDDE5ECDDE2D7E0CBD2D6D7D3CCCEC3C6C2C2CBBCC2BEB9B7B4BBB2B4B2B4AFB5AE
A9ABA4A2A69EA3A1999FA4A599999CA69E959C9B92959790939993948E878A87908A9291
8C878790788781867E818C7E847E868785827B747B7A767277797370767376757C707270
7075796E74757371746E74686B6F6E7A756F6C6E6B6C6A7164706C676D6B696F6A6C6967
6666646A6A6A6B6D636965626B66645B6C606B6966686265646E6066605C606766625B5D
62635E5F5E625F5D
615E655F5D5F6A645E626267626261626462626562686264635B65666D68616D6761686C
6666697167696F68686265696768696B6B68676C6B666D6E6D6A6E6F776F706E7371716B
6D6B706F796C6F736F707370707672707675777979767D737F797A79787A787E777C7980
7A7E89787A86827A87817F86877C837E8485838A878684868C878787848E9095948D8C97
9192909A9597979698A29C9BA4A29CA0A4A6A1A0A69EA6ABADABB5B0AFA9B5B3B4B0B3C7
B8BAB9BFBBBAC6C8CFC4CAD3CFD4D9D0E8E6DCEADDE7E4EDEEF4F0F5F5F9FFF9FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFAFDFFFCEFEEF2
EEEBEBEDE2DEE7E2D7DDD5D8D5CFCAD0CCCCC2C4C8BDC2B5BEB2BAB9B1B2B6B1B2B2AEA4
AFA99DA0A5A4A0A0A6A4A29F989CA09C968C959D938F998E979090948993928C8888928A
868686827F8384837D807D7F777E84817F7C8184787C747978786E7F797475707979766D
73747F78726E776A6D706F6E68716F69736A70696A6E6E70626E686A6B6E6B716E696570
67686D706363686E6A6C6C5E6564625E6861665F64645F64636565606066585E65625D5C
6166576A5E586B64
5F5D5D5F5859655F5F5D6C5E655D605F6763635F606C68656D63646864606065676E6C63
656A6665646A6B70666A636A636A716A6B656567706B6A6F69726F6B6E6C6C74746D7471
6A6F7170706B6F6E72707073756E72747B70707371777A777B717A77757875787C7A727F
83737E7F837F7F7C7D85867C81848487808988838A8E88878B8D858D8F8E95918C8C9492
91968F9293989D9C989B96A39CA29E9FA3A0A8A59EA8A8ADAFB1ADADAFADB1B3BFB5B4B7
B7BBC0C3CBC4CDCBD1D2C5C8CFCFDCDDDDE6E8D7E4E8E5E3EFF9F5FCFEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFF9FBF3F3EB
EBEAEAE1DDE4E0E2D7D7D2CCD7D3C7C5C4C5C5C8C2C5BBB9B9BFB7A7B7B0B2B7AAA8AAA8
AFB0AD9FA19CA3A7A1A096A49B999F9F9299959B949A97939293898B8F8D8D838287898B
8785878B7B808285837682827E7F817F7E7D84837A787E7A787A777A7874727C70717570
787472777373747875736A7070696D6F6F6B706D6E6B6C676E6873696E6B6F6D6A6B6B67
6B636A61626C70606865646C6C6764645D61666A63656069605F62666861645B5860615E
665D656165655E63
605D5E5F635F64616962676C6A64605A626363646C696F676963675F626364686C626268
685D666C6F6B636B66676A7568696E6B6A6E6D6B6F716D71736F706F727572696F706D6F
6C6F6D6E737371787C71736B6E6E6E747E7873758074787A74747C77737C827A7D798080
7F7976877C7D7E81837F8281858688897F85838483858C86928F8A908F8B8B8D8993928B
9F999895979BA29999989F9E9FA1A7A4A3A5A3A39FA5ABAFB2B6ADAFB0AEBCBAB1BDBAC3
C2C4C3CDC8BFC5C8D0C8CAD2D7D8E0DADEE0DFE4E7E4F1E6F3EDF5FCFAFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAF9F8F6
F2EDE7E7E7ECE0DAD5D2D5D8D5D1CCD1CCC9C3C9CFBCB9BABEB7B6B0B8B8ACB3B2AAB6AB
B2ADA5A8A9A5A3A39DA3A0A0999D8F98949490919B98968897928B918F8F8E8C8488868B
8A7E838785837E8389737D847F887D7F81827F7C7C79767F797D7D79747774767A797977
7976707167726E786E6E6A7171756775736F6C6C6F6B68686A64706F696B726B6B686C6A
646E666660696D646468676A6E666265636A6165696D656E685F66646263666260655E61
60645C6268605F5C
63675B665D6265675F6360645B6164645D646B605D6667646B6965626866636868606C62
626C685F696B676968676667666E7267656D6B736A6C70717171766F6F7773726A6D6E72
6969746C6E706D6F7374766D776E6E6B767F77718178767B79737D7D757A7B7B7D7F837E
7D7E7E7C79828082847885858C90828B88899182858B838E8C879492909090958C928A93
919A959A99989895969B9E9FA09C9CAB9BA09EA8A6AAA7A9B0B4B0B6B2AFB5B7BDBAB8BE
BCBCC3BFC4C5CECCD1D2D3D4D0DAE0E3E0DFE0EAE5F0E7ECF8F9F8FFFAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4FFF9F6EF
EEEFEAF4E9EADEDBDDDFDCD5C7CCCFD5CECFCFC8BFC5BDB9BDC5BFBBBAB6B1B6ABB1AAAC
B0AFA8A9ABA29B9BA2A0939E989A9F95A3949C9B9796988D918C918D8F978F89838D9286
8A8A847E83848387747C7E867C7F847F7D7D828479757E7B8482767A7C7B77737C767879
74727277736D6F726E6C71727172696B6F6D6B6D6977686F76696C6963656A6C65666764
6B6B6C6C6C64696A646C6765666065616A60626062626769646B675E5B61636160636262
5B5D645E655C6165
66676763625E676960646766685E6564635D6762636A6167666062665E5F6467706A6F66
6A6A65636E616663696A6762656F6C65626F676D646D70746D757773707470766E746E74
776C716F76766C7375746F716C6B766B73787472737A807B7B7F7C7A8184737C7E7F7C81
817A7E8277827C818284878286868483818582868486838E908A958F959096998A939498
8B97959A959699A4A29C9CA29BA5A3A0A2A3A3A9A9A8A6ACABBAA6ABA9ACB4BCBCB8BCBF
BBBEBDCBC4C6CAC9CED4D2CFDAD5DCD9EEE3E6DDF0F3F4F3F7FBF2FEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFBF5F8
F5EFEBF1ECE7DEDCE0D8E2D8DDD4C9D3CBD3CBC9C3BFC5BDC4C0B7BBB3ABACADACAEADB5
B6A7A6ABAAA2A1ABA49D9EA19D999C9D9D949D9E998E9B918D8C93928C90888F83928380
8A83897F8280837D817C7A857C78807F7B7C808188857A7B7C777E78787F72727C777576
7E74787471757276696F706C6C6F6B7B6E756F6C6F6B706C766A716D6B6C6F75626A5E6C
646C6564676767656D64636B646C5C5D65695E63686F636A63626163636364606A675C60
5A6062615A626264
6363625A565F606360656662685F6B5D60646264666B65655E686A6367666269676B6463
6C666B646366706D6568606A646466676765715E666F6E70777679706C6A726D65717574
6D6F6D6F6E686E6C7176687770717A737778716E7674777C79787C7F797B7B787F7D7A81
7B877C807E7C82857E7D8481848284818789868F868B8B938A8D889190948B9990948C93
8F9A978F9AA19AA19E9DA1A2A6A7A4A5A2AAA99CA3A3A5AEAAAEACAFBCB9BAB5B7B1C3C1
C5C1BBCBCFCFCDD4CBCBD8DFD4DEE4DFE4E4ECE7ECF6EFF4EEF9FDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFEFC
F1ECE8EDEEE9E8DEE3DCDFDCD8DBD2D0CBD3D1C7C8C3C3BCBBBAC0C0B8B6B4BBB8BFAEAB
A9A8A9A8B0A39EA0A4A09CA3989A9B9CA1A0948F9E9690969498978E918D87838485878E
8D878185878681857B82828183858476807A827C7F8676797F807C7C7A7D7F7773767570
7B7371717372717273757675726F6D716E6D6E6D716C6D6E666F665E6A6A5F66686E6E6A
6B69656D6C6C67646165636A637060636265636B5E646663626163686561636B65636160
60645D615E645D61
68615E5C6A605F646554586863655E5E60675F67655F6266686362636363676B68686C6D
60646C66676F6C6E6C727070676F6561686C6E6A706D726D7E6B78736C6A6E7071736E6C
6E74727275736F6E7B6D76746B6C75767777716E75757372787B71757F757B8680817381
7B7A7E7F7E83807E85817F8A8E8F8188808D858E88828F8E868F8F889088909496939795
9A9A959799999D989BA1A5A1A39EA9A2A7AAADA5AAACABABACB1AEB2AEB7B4BFB9B2BCC7
C2C3C5C5C0D2D3D1DADFD6D6D8DAE0D8E8E4EBEFEDEBEEF4FBFCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FDF8
E6EEF1EDEBE9EADFE4DDDAE1DAD8D5D1CDC3C4CCC4C4C6C9C3B7BAB3B9B5B7B9B5ADB4B3
A2ACB1AAA79FA4A1A39C9D9D9D959FA09990969990949C979595909A91898B8C89908A88
878E868B887F7D877B88837E817D777D837B81787D76807D81767A727877787680767571
797770717774727A7675727073757472716D70666F6B6F636F6D716764636A64686F686A
6A656269676868656E64686C6B6765686270676B645D666266626B6C676763665E5E606C
6162635C615B5C5F
635E615D63616961676363616063605E646760615D5F6D6F65645E6462686D6568676667
6E676769676D6A6F616E6B6F6D696F676C6D72716C6E71747C7C7D71717369716D71706F
737571756E716F737974696C77746C6C78787971747973787A7974737B797A7C7F798586
7E7F817E7A80807E7C7F8483858083858A8A8582828A8C848B8C928B8995908F94969098
9A98969A969E9A9F9E9EA39B9FA7A8AE9EA5A1AAA2A6AAB2A8B0B2B2BDB4C3BBB8BFC0C0
B6C8C0C4CBCDCFC9D8D5D4D4DBE4E1DCE4E5E3EDE3F7FCFFFAFCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB
FAF1F7F3EFE4E5E8ECE7E1E2DADBDAD5CFC7CCCEC5BDCBC3B8C7B2B7B8B7B7B0B9AEB2AB
A9AAADB2A2ACA7A49DA2A399A5A09B9D9C9B9593989498979798959692868C898A898C8D
8A8C8D897C888B8285817D8383857A7F80787E827C81797B797A7979767F6E767C78767B
7775747C6E73726F707570717170746F6F776F6E72716E676771656C6A6C6F676C6A6A68
6A686D6A69626A6965696261686D6C6C6561616B6265646064675D62656664685F626664
615F5E626360635C
6361616064666468655C64635C6960635F6561656267646664626466656264696B606669
68676665665D6B61696F676C6B6C6F7265697064666F746E71787A7070726F74726F696E
74697571727076747A6F78726E7672747078707D757474747675807A7A7A7C7B81787D82
827E877C7C7F887D7E7E80808284838D8B888583898D878F8D97918D979092938F969096
928C909A99939F9F9CA29BA0A69C9BA7AEA6A5AFABA6B1B1B7B8B3BFBEBAB8C0B9C0BEC7
C4C4C7C3C7D2D1CDD8E3DCE2DDE2E1E4EAE8EBF1EEF2FAFAFFF4FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFA
FFF7F0F1F2EFF2E9E7DAE4DCE0DBDBD2C7D1CED0BEC5C3C3CAB8BFBBBAB0BCB1B2B3ABAC
AEABADA4A8A7A7A0A2AB98A89CA19D9B9B999F8D9D9F929A93919093898F8F839195818F
858B8982888B89817C83837E80818080777E737A7E7A7E7E7B7E7C7976727B817578787B
8377767470766F797971727771727B6D72736F79716F6B67696D6C6C6B676B66716B6D69
676967666A62676163656C68646C6564616C666660655F6463605F5C5F6766606062625E
625E6665625F5F61
606062616164645E6061616467615E616868685B6B6D6166645E606266616A6C62686763
656564635F6B6F6E65726A646F67696E696770646E6C6B6E6A726F6972696F73726B746E
6B70716D767076746F6E73726F797275717979797475787F79787E81767A7C7D817A8281
7B8884797F7E7F7C83838380878288827F83878B85888B8F908D8C928E8F8E8B95999595
9893989B9A999EA09FA2A79DA39FA2A9ABA4AFA6AAA5B2AAA7B3B2B8B9B7B6BDBCB2C6BE
C3C5C2CCD0CDD4DDD3D8DAD5E7E3E4E3E7F0F2EBFEFAFFFFF9FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDF1FBFAFDF2E8F0E3DFDADADAE2D7DDD2D3CCCBC5C1C8C6BDCAB8B9B8BABDB4BAB3ACA9
AEAAA9A3A4A2A0A79CACA8ABA0A2969DA09C98969A9E9B988E8B8D8E958C8A958E87848F
8A868E878985848685807E887D7F807A7D7E7D7F7E7E7E7E797F75777A72757D827C7B72
776F6B777376737172776A7875706A7468716D6C6C716B736B66626D696E656D616B6563
7163656C6C6D6C696B696F656A6C6A656361636D645B626A5C6362636666675F695D6269
63595B5E65605C5C
5F5F6266645F6262656667665F5D666267666769695F616A6661696663656A646761676F
685A666966696967696970686B676E6A716E6B6E676D686A776E6C6D7075706A7A756F75
737073707275796D6E786C70707D7B747E7673777F7B7475777F787D77797E77777C7E79
8387808A817D82828882827C8489888D8C8F8A868B8587908C8E8F899496948E8E929A9C
959599969D9998A2A6A3A3A89F9CADA7ACAAA0A8ADA6AFB1A6ADB3B4B1B8C2C1C0C2C6C8
C6C5C1C9D6C7D5D8CFDFD7E1E2E1E6E9EBECF0F4F3F9FDFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD
F7F7FAFAF7EFE6E2E2E1E5DED7D0D8D7DED6C7C6C6CAC8C5CCBCBEB6BBC1B7B6B1B5B9AC
AEB0AAA9A0ADA4A4A8A6A39A9E98A79A9D989D989897979B969993908B8C8B90908D868C
89879583858A8B8C83807E7C878180797881807B7A788072806D7C757778787883767A7C
73727472767471797A7D7D766E716C706E72726F6C716A6A726B6F6F6A75696D63656F71
6F6C6760646A666868656561646A6365636565666C646A64666262626362665F63616161
6065605C6163625C
65625D626466615D62656567655E5F696364636564676C6664616367696A686B67666A62
6B6F646D67716B68666D6E6F676B6A6D68696D69706B6E746B716D756B656E717275726F
766E726F796B6B787376757272776F777A7B767F74747D7480767E777A767B7F7B787B80
7C7C767B7D7B82808A7E7D83888983898A8A8A8C8C828D918B8794968E8E909899939C98
9A949A92919897A1A19EABAAABA1ABA8A9ACA8A8AEADADAAB5B5B3BAAEC2BDBEC3BFC1BF
C4BEC2CCD5D3D6E2D5DBE2E5E8E0E4EBF2F0F0F4F5F8FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
FEFFFFF0F2EAF1E5E6E2E1E3E3D4DAD3D8DBD0CDCAC2C2CAD1C8C8C8BDBBBBB3B4B2B3B5
AFAEABABA8A6B0A4A4AAAAA49E989DA59C9A989A989598998F98938991928A828B909089
8887878A8D8A8682867C827D8479847C7E7E7F7E82807A7A7E787C777470777A76777379
78747773737D7473787478737278716E6C6F717071696F6D6B706F736E69736D6A6C6768
6C6C6A6C686C616669626B63616969626564646862696261625E6160606657616260625F
605B69605A5F585F
61615D5E6060595F646B696564656367676A666462616465616F666368656564676E6367
636465676D6B6A69646C696A6F696B6A67717166646D6A6C6663686B716C6B6B706D7177
726970796E787667706F707073707F7B77707A7B76747A7B7A78827C7A7B777F797B837A
7C837B787A7E7C8283807E848C8287828E898C91878F8B8D8F8B8C928A939196929D9799
99989A9D95A49C9EA3A5A3A8A8AFA6A8A4A3A6AEA7AFB6B4B4B3B9BAB6B2B9B5BFC2C8C0
C5CCD4C7D0CED7D2DAD9DEE5E1E9E9EFF3EBF5FEF2FAFEFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFF7F9F2F3EEEDEAE5E7DEDDD9E0D0D4D5CDCDD3D7C8C9C3CFBCBEB5C0BBB3B7B5B0B0
B5AEAFA5A0A9A5A2AFA6A99FA19F9B9DA09E9F8D9B9998959A97978F908B91969889908E
8F87878D8B8E88878281837F80827B7C7E7C7C857A7E7977727175757B797A79767E7979
75746D7473757370787277716F6E6F72706D776A67726D6C676C70736C6B6C6B7369686A
69696C6069676D69686B69676B73616D686563686264675D646665606761605D6462645C
5F6C685A62616558
665C5F5A665F5D6B676965615F5F696162696861656463666565686760646964626C6A69
6B66626E676C616A5F6E676E6E6B6E686B656E6C706F6A6A6D74676E736F6C6F75736B6D
7075726E777870756968756A717474757E73767A7A78797779757D7B73797D79827F807D
7E7F7A8184808786808283898389898289888F898D8E8793918C899494948F9491929698
989C9C9A949A9DA3AAA1A39DA49BAAA7A0AAACAEABAAADB4B6B4BAB3AEB5BFB9BFC1C2BD
CBC6C5CDD3D0D4D5D2DFE3DDECE8F4ECF2F4F8F2FCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFBFBF9EDF5ECF1E9EDE5E6E0DBDED9DCDAD1CECAD2D3CBC4C6CBBBBCBAB2B7AFB4B2AC
ABADB0A7A7A5A9AB9FA7A1979E96A2A29F999D9F9999989390979A9684878E9288928D8F
9485898984897F84878085887A7C7D7D767E7B787D7C817C797177737571797B78797779
747C77757A7274707573737677726D746F6F736E71666C6E71716D6D68656B68696A6C66
6C6E716D696A6E666C696B676861666560666967686963635E676064636565625F5A6763
61655E5F5C615A5C
6168615E646062606A5F65636B61646A6369675F64666A6168666565636266636165666A
6C666C6964696569646A636571657274706B6B73686C6C6C69666B6669706F6C72726D6E
6F6C757975746E74717170726F73767479776E757B7C7F7C7B7A827D807A817F817A8382
807981867C83897C82877D7A898487928287888C89918D8F908F8C8D8D978F8E97939BA0
A09A99989D9A9A9AA09BA5A3A7A8A8A8A8AF9FAFA8AEB3B2B6B5B2BDB3B5C6BBBBC7CBCA
CDC8D1CCD4D8D5DAD9DFDBE8EBE5F4F0F6FAF8FBFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFFFAECEBF1F1F1F1E8DDDAD9D4D8D2D0D0CCD7C8C6CFC1C3C1BFB7BFBAC1B5B0A8
ACACA8A5B3A7A4AEA7A0A5A4A3A2A2999DA3949F9D96968E9396968F95968A9091918B81
8C878B908488818C81848678867E7E7D7C82858078767B73787573797A727777716F7372
707371717D757171776D7679716B756F6D6F73776D6D776A6E6D6F706A6C6B6970706C6C
6F646D616A616A676A6E686B676363666A67646567656563626361615E5F626062645863
60615C645D61615E
615F67676766626A64646D5D63636B676269685D696463636A665E636366616662696769
65696A6A6B6566676866686E67706D6D6C6B6B6D676B6D696865646D74706F74716B7170
776F6A7072736D716C7B76757A7978727F798076787C767D7B7C7E767B7D817D7A84797F
807C76808A7F827B8C89837A85868C8A8481848F868394908785948D968B8F9298959B99
9C9C9F919A9EA39F9D9FA6A1A7ABADA9A5A8A2A8A9A4B1B2BDB1B8BDB5BCB7BAC0C7C7C2
CEC9C5D0D9D7D1D7DAD7E7E3E8EFF3F8F0F3FEFFFDFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8FEFEF7EEF3EEE4ECEAE6E2DDD9DED6CAD1D0D4CBCDC8CBBFC2C6BBB8B7BABEAABC
A9B5B1A9B0A6AFA6AAA6A9A2A4A1979C99A198939C989B91909594958B8F8D8A8E8E8E8E
889183898E90867C7F83848B827D7F84807D7576737D807D78777B7A7278767976787572
787374707375737178736C7179706A6D71686F736E6D726D6D677371626B7069666C6669
686B6A6C746C626768636C64676766676363656061655C66626D66655A69656764616062
65646C665D646060
6464615C6265696862646866616C6A66665C6267646666606762646B69686B6569696668
67676C6D676F626F6D66666F71686865746E706D6567676B676D69686E7468716E687676
76786874776F79717A6E72757A777475767A787A7B7A7D7C79797D79807A797A857C847B
7D7E837C827F8A7B7D858784897E7E86898B888A928F92928A928D959899989B91999A99
989B9AA69F9CA6A299A29FA8A6A7A7A2A6B1A6B3B4AFB2B4B5B2B7BDC2BBB9C0C2CCD0C5
CDC6D7D8D3D5D8DBDAD8E3E2F0EFF4F3F0ECFCFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF9F7F9F3EDEAE1EBE2DEE4D3D6D0D3CAD0D0CAC9CFCEC7B8BDC2BAC3BEB4BEB6
B6AFB3ADA9ACACADA59FA3A5A1A8999D9DA597989B9D969790999897968C8A89928D868D
958B8E8583918C88837A88848782808279887E7B827E7D7578757275727E787077757070
6F7A6D7D6C6979747372766C7173727075757378717A6C70776B6F68686D6B6E676A6667
676B6A6668636667606C666466626467666165616E666362606465655D655F5D5C5E5F67
645E675D575D575F
6261676063606662676462696A5F64605F66656A66666468626768686965656564686965
69636D626E6B5D6A6C68626A696A69686970656F636F6D676C6B6F6E6C6B6E6C736C6F74
6E6873756F6B72777676756C7678767B74737C7379747B7A7B767C7B767879807F80847A
7F868187858081878A84838A8A858382868E86868B90898E9491879690929195929A9195
939B9EA09E9D9EA99E9FA2A3A5A7A3AEABB2ACADAEB1B1BDB9B8B7C1BDBCBDC9C5C1C2CA
C1CCCDD2D3DBDBDDD9D8ECE6E6F2F6F5F7F8FFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFDF7FDEEF3F0E8F1EBEBE5EBE3D3D4D2D7CFCBCBC8D0CED0C5C5BEBDBEBABFB7B7
B3AAAFABA8A9AAABA89EB09BA5A5A2A5A49D969B98969D91928A8B9790918C8C8F8E8A8C
90948F878B8684818285818685877E7E7F7B7E8474767F79787D7A7D727474737B767670
787074746B6A6F736D6E7273757775717070747572757572726D6F6A686A6A6E6367686D
6967676B67696C676C68616769696365656C6766606B6565646C646A676E616364625F63
6265636261635F5B
655F5C5F646766656165636165696469666260616468636665696B675E5D686D6C69676D
666B686B6666696B6C6766716072676E6C736C6868726B716672697168767A6772716E6E
6D72776D72736F7672767277757B767777767A6E7C7C797E747485767B81808280827F7E
8284797E7E867E898287828185858C848C9389909185938D8C94968C9492969896989A98
979D9C9B98A49AA6A8A5A4A7A2A0A6A7ADA4AEAAB0B4B2B9BCAEBDBDBCC0C2C2BEC6BFC5
CCD1CECCD0D8DCD8D2E1E9F0E7E5ECF1F7F6FAF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFBF9FEFDECECDEE3E9E2DFDBE7D5E3D5DCC6CDCECCC9C0BDCAB8BBBEBBBBB9B9B7
B1B0A9ADACA6AFB5B1A0A0ADA89B9BA19A9E9A9F9D9A93919E948D90868F8E8C8E9A8E8C
8B8B8F8E868289898C858280838B8181827C7D7A7D74797579746E777F727772797C6D74
6A7476777771717A72707675736D6477726B6D73726F6F6F6C6F69726A67736E6C6A6A66
6C66686C6E6B6B656864656C696A676C64676C64606A69686561666463655D5F64675C5D
6161575F6060545B
5C625B6A615F5E676468666669626663646A636861666561686565636A67676C6B6F6365
68696A6C69666C6B686766706F646E6472676C6A6A726A6F706D697174746A707773726D
696E70756E77717E71767074767371707D797A7E747A897A797A7B7A81837E797E83807C
7C8280868A7D8A898981838185878A85868E88888F9090879394928A929191918B929598
A29AA09FA5A49CA3A4A5A7ACA6A5A7A6B0AFAFB0B8B6B1BAB9B4B7BFB7C0BFC0C2C3CEC6
D4D2D2D1D5DAD6DBDBE5EEE0EBEFF3FBEAFAFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFBF3F0F7F1E9E4EBE0E1E3E5CFD7D2D1CDCCCFC1CEC6C4C3C0BABFB5B1BAB2B5
B0AAAFADA9ADACAFACA7A8A3A697A39C9DA39E9F9793949A9398928F949195958F8C9289
8B8C8C87887E8282838A86858389887C817B7F7B7C79767E798079757279777B7A7A756F
75756E7B727870716D717670696C6E7471726771767976746D6B6A6E766B716D6A6A6666
6E5E63676667695F6C69726A65656469655E666368635F6667666A6A60635F6960646068
5C5E635F5E695D5F
606164625C616560645B686769665F64636764666765636B60656569636366676D676A69
636B6964656967646E686A716A66716D6C686F686867686C6A746D706973756E776D6F73
756F767171797A787873717F707075787379787B787A7D7A817577798182847F7C807D82
7B818B868286807E8A7C868A8B869587858D8D8B8F8692898B94899396999191909B9697
979CA0A09A9B9CA8A4A8A7A8A9ACACADB2AEA8B4B4AFADB9B3B8B9C0BAC1C4C6C7C5C9CE
CDD1D6D4D8D7DCE6E3E4E2EBE8E7F3FFF4F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFFFAF9EEEAF0EAEDE6DBE0D9DAD7D5CFE2CECFD0CAC8CABAB5B9B5B0BBB8BAB2
ABADB4B3ABA8ABA3B4ABA8AEA1A39E9A99A09FA4A395979B90929192929597938F928B8C
8D818889888A8684838C8583807E7C7E7E7F83757D797B787D807579787D7878777D7873
6F7377846F71767673726C71757373696F717269787571746C6D6C6E6E6F706B69686A6C
68636B65636562636365636C666B6D6868666A66696465706E6A66686561685E64676966
60696161655E5F63
6264655B5E676564686D5F5F66646861686769645F65636A7165716567645E6A6A616D67
656C68666F6A626D6B6A696B6A63706F6874696E686B6C656B696E6F70676F7370757575
73726876766A766E757C7B78796C7979717271797E7E788071817F827A767B7A807D8180
7D81828689828181867C877F82898A8785908C8886898E8D8A91969191929599959B999B
9C959E9C9FA6A09EAAA9A3ABAEADAEA4A2A9AFAEB0B8B8BBB4BCB8BFB6C8BFB9BFC8CCC7
CBCFD2DFD5DAE1E4E6E1E8E4EFECEBF5FEFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8F7EDEEEEECEAE6EAE2DADBDAD4C4D0CFD2CECFC3C7C1BCBFC2BDB8B0B8B4
AFB0B3B2AEAAABA6A9AAA3ACA19EA197999DA1989F9491999A92949498928E8F96918C8C
888D8E8C8D8B838684898381818782807A7A7C7D7A7E79777D78797676787B767C75737A
77827A7F766D706F6F766C7071716A66756D727170737A6E786E6C6A6A6F6B6C69636A64
646C696C6969676666626B6960646F676167616B6B696D6D656E656364626A6E64626764
545D5E5D5C5B6061
6266686661666A6464715E5D6A6164625E63636769676369625F68646B6261656C6B6E6D
6B6B636E636367646A6D65706A6A6F68746772756972686A6F6573696E72706E70717970
7072766E7B726C7B7B7D7176757A76737C747676787677807E777D7F777D76867A838283
7D7D82808282838E827F81898B8E87888B8A8B908E8A96989193918F928E90979996989F
94979E9EA6A2A3A0A0A2A2ABAFA7ABA8A2B4ADAEB7B5BBBAB8B6B7BEB8C2C1C3CACCD0CB
CCCED6D6E0E2DCDEE8EDEEE7EAF2EEFFF8F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFFFAE7F0E4E7DFE3D9E0D8D8D5D4D1D9CABDCABFC9B8BAC1BFBDBCB9BB
B7ACB0AEA3A7ABAEA4B2A5A4A49FA4A09CA29F9B9DA0989B8F9A958F9B91929290948F8A
8D8B8D898B80918388818583827C8479828285797A7E7978817878787578787574717373
7E747174726C736D786F75747073747369706B7878FFFF7770727264656C6F706B67666D
63656F68686764646A5F5F676B62706864636C646A6967636F696763605E5F686260615E
6B61605C6163665D
62646364676866656860676969665F636B63675F66636B626166646660696168656A6E68
696D6C68646A6E6E6B686D6E676E6A616D6E6970636E6C6B6A726671716C77706D6E6D72
70717173737675726E767970737B78757A79787D827E7C807D7B7E808381837F7C84867F
877D7E7D8381838182808B8483828B8687858595889489928C909689959992989B94949D
9697A09CA1ABA3A6A6A5A6A6A7B0AAA7B0ACAEB0B4B1B9B9C0C0B7C0C4BEC1C1C9C5CFD5
CFC1DAD6DCDED9DFDBE2E5F5EDF3E9FBF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF6F1ECECE8EAEAE4DCE3E1DACDD7D3D0C6C7C8CDC3C7C0BFC4B3BDAFB3
B3B9B4ACB4A8B1A9A9AAA3A8AD9BA5A2A7A39A9A939597959B93949191938E919294898C
9280878588898C867C877F8D8186827E7B7B7F81757D83767A7B7B797972797979707071
7B74776F6E7271737472726C6B766E736C75727378837A707176696A686368626E6D6863
6C696769676667676F6A686E695F626F60686D6D6B676564656A6A606762676263626662
6062576562605B5F
645D676161656061656168686163666B6068686569676668645D6C626461676D6468656C
67686C656B6A676B646C68686E696969686F736E6F726B6D6B6A6B71746A6D6C6F6C6E71
6C75737170727A76706D6A78747577727670747D7A787A84807E7D7B8A81818180808581
7D7E857F83898385848188878B8A8790868987888A868D908F979497969696A4969C9A9F
9C939F959FA19F9DA5A7ADA7A3A9A8A8ABACACAAB3BAABBAB5C2C1BCC2BDC7C1CAC6D0D1
CEC8D3D7DCDDDEE5E4E4ECE8EEFCFAF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFDFDF3F3E6E9E5E6DDE1DEDDDADDD1CDD2C7C7BFC3C8BEBCB7B7BDADBB
B1AAB0ADB2AFABA9A1AFA3ABA3A29CA29E9EA19A929A9298A19A9F9C9394938D8D929588
8F8D8E918A868A868A878781868C7E807D807B797E797B7B77787F77787B7A7A77737775
6E6E7B737774736F786B727277717277776D747073716C786F6E6B646B70676E6D6D696C
68686867666B6C6A61676A636569686865646961666765696D666A66675D646566626162
6065625D61605B5F
656160656762676263675F67635F5C6161656E65696467686668635F6065696666696068
6569696C726F6C6B696E6B6F6B7473636E656B6F736A6D6B776B6E7475697977736E7372
7A72727B6F6D767771776F747D7A766E757777777B7F7D7D79807F7B8C817D837A808182
867F7B85847B8682878F838785878087888B86868E908B8D8E8D8B988F959798919A969B
96979CA2A8A2A29FADA2A1AEAEADAFAEA9A9AAB0A9B5B5BBBDBFBDC9C7C0BFC6C5CBCFD1
D0D5D6D4D9E4D7EBEAEFEDF0F2F5FDFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFAF6F6F3EDE6E4E5E5D8D5E2D6D4D5D0CCD4C6CBC1C7C9C3C3BABFBAB7
B6B2B5B0A2AEAEAEA9A8AEA5A3A1A7A39F98989E95979895919490939292928C9797898F
88898885888B7F89858D808484877C837E7677837F7D7B7F76787F78707B7A75727F7F77
797874757371786C727971776F706B747171736F6F78706E696A69666D6C6E6D666B6866
6A61666865656D616469676B61626B62676766636669705F6767685B636168635F706566
646161585E5E5B60
6464615D6266646C69626461696765685C575F5E5C62636366646865656C68606A696D6B
6E6970696662676E6F6B6D65696A706D6E6E69696C6A66656B676E736E73716D6F71776C
6F717372757277767B7074737773747B746C7577767F7C7C7B7F80847F7C85808A7D8286
8183887C88807C8688898C838B8B878D9087839290908F929486929698998D969B999893
9C9F9BA6A4AAA3ABA3A6A5AAACA7AEAEAAAFB0ADAEBBB5B6B5B2C2BFBDC7CBC3C8C4C8D1
D1D8D6DCE3E4D9E6F4ECEFEEF0FAFBF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDF2F4EDE9E5E1DDE3DCDCD4D3CFD9D1CBC9C9C6C4C5BEC0C8BFB7B1
B7B6B1B2B3AAACA3A8A6A4A7A3A3A1A2A09D9996979F95949993978C8D91988C8B92938A
918A838C8B8980898786827F82898385787F7B7F7C7B7F7B7A7478757E7D727675777778
7F79787875707373736B75706C6D70696F75736F706E6C6F676C6A686A6B696572676D6E
6C6B636A6C6E6969676F656E6663646268686C656C6A67696661656065615F655C5E6568
60625F655F615F62
5E696263655E69636A606068616965696A686965606B6562656A626E646669686E63656A
6C7263686D6C67666B6773686E6A6C686D6A696E73686F706D6A6A716D6F706D6D6B7175
7277747C7974726F7277796D736C7376797378767D837B7F7A867B7B847B7C8179798187
7B81808881868A8583858891848A908D828B8D8D8A88838D8A948E89958C9A9A9B9A9F97
97A4A09FA6A3A0ABA2A7AAA6AEB3AFAEB3AFB7B2BCB7B8BEB7BAC4C0CDCEC9CECACDCED7
D2D2D3D7DFE2EAE7EDF2F2F2F8F7FEFFFCFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF6F3F0ECF4E8F1E2E6DAE5D4D8D6D0CED2C9CAC4C5C6C6C3BEC3B8BEC0
B8B5B6B3B5B5AFAEABA1A6A99A9DA09F989D9C9F9C9B999D9A9A989490908E8D8D8C8B8B
8F8F8C8D898B898C828E8883818581897B7D757D7A7D7B7973756C78817C787E77797A74
7775777274797870716D6F746E7166717374706F6F736E7270716E74666F6A667268676F
6B6C6B6B6969666A65676A6F67656463666668646D6564616963635F676362696C67615E
625F646162645F5F
6667666A6362636865686564716165665D5F636B6063656468686C636C6E706564616A66
6D686971666669636469686E716A6B6F6E666C68726C6D6C6F6C6B6F6E686B7076746A74
73787D7B6E747374727373797A757276797B76797A7C7F7D76817F7F85817B7A787D7986
818A8A82878A8391838C8789878D86908A8D8A8E878D8F96908F9790939799959C919C9F
A49B9E9DA3A1A1A0ACABACA89FA8B1B2ABB1B1B3B1B5B6BDB4BEBFC3C6C1C2C5CBD1CDDF
D7DCDEDEDEDCE5E6E9E3F1EAF5F4F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFCF5E7F1F6E3E4ECE5DFE2E1D9DACBD4CDCEC2C7C2C1BEC4C4C2BBADB9
BBB7B3B7AFB3A5AFA1A7A1A3A7A5A2A19E9B9C9F9A9E979B989398989B918E8C94938D8A
888D8A8D878C89828C8487837F837F7B7B8A79797D7D7575767C77717A76787A79767879
7E7976767B716E7274776C73706C6E6C7173716D6F75676B6E6F71696E696E686F676D6D
646A72666C63656C6F63666B65645F62666B62636B646A62666968676D6264615E6D625C
63615E62665F635B
615B5F6567646965675F6765635F6064636267686563636A61666667676566696F626466
6568686A64656A696C6B66686C6C6A6E676C6768726E6A6E776E6F6E6F6F6F7168726F76
727A7571726F78796F7B7B7476727070797C787C757B747E7E7C7D7E78837D797B857D84
7A8180808681827F87848C7E888A8B93828B8E8C8D93829091979492928F97969698989C
9B9D9CA4A6A69EA8A2AEA8A1AEAFA7ADADAFB4B6B1B5B6BEBFBFB9BBBFC3C5CBCDD0CBD4
D9D0D8D9DCF1E8F5E4F3F7F9F7F7FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFDF5F3F0EBE7F1EFEEE0DBD1DDDBD3CAD2D0D5C0C8BFCBBFC6C1C1B3B9
AFB8B6B1B5B9AAA7ADA9A8A89DA3A19E9C9F9DA098A29A9D97939A978D97938D8B8B908D
8D898996828B8F8881807E837E857F7C817C737D7C7B808180787B7E757B7E7C757C7771
7A796E797175777C7274786F706D6A756C6E717173716866686D74696D716B6C67656966
63686B627068706F686C686064626667636564645C6C646963656266606061665E606761
65616066656B625E
675F5F675F696767665E695D62666166676265636765645C696468626C667065696B6462
647068706F6469666E6A6A6D6B6773686A6C6B6F646E66686E6C706D6D6B746E71737370
757B7771726F747479777272757D7C7379777D7C7B757A7A7F7A7C80837E7F7B83807981
7E81827D83808C80868B8A85888988878A909591878E8F8C94939993909099939B9F9D9C
A1A6A29F9FACABA5A7ABA1AEA5ABA9AFA6B0AFB1B2A8B7B8C2BFBCBDC7BECAC9C7C2CAD1
D4D9D7E7DDE8E0DEF0F4EEFBF9FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFCFFF4F8F7EFE3EDE1E4E8DFDCD5DED3CECBC9CEC9C2C6C9C0BDB7B6BBC1
BCB8B6B9B4AFAEAAB29CA9A7AEAC9F9E9F9C9B9F9C9793949599949597958F8B8A8F928E
928F8B898B87848B8284898580857E797A84797979857B7C777D787D72737676737F7277
7A7A737A7572787B74746F7971706E726D6B6A706C786B6B7A6A6E6A676D6D6569696D69
69646968696F6C6A68696467696E6B616269676B6366646A625E615F63685B605C606562
6162606260615F5F
635A5F6A646463656564665F67676261676A5F62646C6467655B6D696C6A606C676A636B
6C686A676D6E72686562666C6D686A6B666C6F646B696D68746D6D6D74707170796F7571
797376727B776B75726F7A7E797579797579767874747D7C7B7D827A817F7C7C80848A7B
817E83818190878F859588808B8986898990869491878F8A888F8A9295979C9F9696949D
9C9C9E9AA5A7B0AFA2AEAAA7A8B1B6A8B3AFB5B0BAB8BABAC0C7C5C0C8C6CACBCDCCD8D8
D3D6D2E1D3DFE4F0F2F7EEEEFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFEF4F9EAEEE7ECDEE5DED4D7DDD4D2CBCCC7C4BCC5CDBBC0BCB9B4C3
B9B5B8B0A7ACAFACA9ABA9A6A2ACA6A4A2A99E9E9F9D999E9A9C988E8E948C9E938D8D95
848B8B8B8B868487857F868982837F7E7D7A7C867C7A7B7E7E7A7B8076767E7A73737775
7672777070777879757269716F7A736E6B6E6D6C696B717675727070716D6C6C6A686764
6C6966686564656968656B66626966646765646669636768646168616B605E5E695C6761
5F636863605D5D61
6365635F606365686764666363646665666361685F5F62696E656B67676F6965616B6764
676165666A696C6A6E636A666A646D6E66756D69706D676D6C6B717169726F736D756F75
79707874716B737F7A77787D7875747978787C7F7D7D827C757B7F78767A7D798288787F
87818A8D7F8889878F85878C91848D848B8A86848C8F91968F91929794919D93979898A0
9FA3999FA6A5A4B0AAA5ACA6ADB2A7A7B8B6B4B2B6B8BBB8BCC1C2C8C6C8C5D0CDD2D9D5
DAE4E2D8DCE3E5EBEEEAF0F5F5F7FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFBFCF5F4F7EDEDECEDE1DBD7D6DADBD9D2C5CFCDCEC4C2C7B3BCB9B8BC
B6B8B2B2B0AEADB0A5A5ACA6A3ADA1A4A1A49D989C99939A97949D90938B96909894868F
8C8C868A8684848888897D8589807F7C837D7C778077787D76747A777D7C7D767A797C75
78777C797E80717173726C6B6E70746C6E736C6F6971756D6A6A676A6F636C6468696D68
6868686E5E65656B6B5D666968656B6663605F616466676264645C66626B676460655C5B
595D6065605F6362
62685F5F5F656D68695E61686663646B64686C646663656A6A6C6A62656A6C646E706D62
636A6365656B7173696C6D696F7165686C6E6B70716B686A736F756E767170706B747373
747672776F7373746F747775747979766D7D7A747C79787B82747F7A7E85857E8283857F
7B86858A888D898B8C908E8A898A838989948A848C908D918C8F979C8F989B9494999A96
929898B1A7A5A8AEA8A4A8A8B1AEADA9B0ACBAB2B1B7BEB9BEC8C4CBCFCACAC3CBCCD5D4
D2D9D8DDDFE6F0EBE8E9F6F0FFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAFBF7EDEDE9E5EAE2DDDAD7D0CBD7CDCFC6C4CBC1C1BDC4B9C2B7
BAAAB8AAAEB4A7ABB0A4ACA79CA6A09D9AA3A1A09E9D989797999294968F9397978A8991
888D84828B8D878A8086858982877E7E8085798289837B7C83778078767A77767D747671
72716C747C7D76706D7B71747574727073766567746E6D6A6969736D686C6C6F6C6E6966
65626167666A6D6960676A6765696369606167636265676762645B6069665F6564606368
63686160625F6261
665D686864696167626661656A6765626762616066635D6561606D656B656766676B6B61
686B636462656966676A7062676B6862736A706E6A69726B6C6C69746C6E6F6A716C7571
747879727375766D6F75727E7E7B787C777983787881787C7B7B7B7D787B7E7C867A7E85
847E897F828E867F878E8C81888C8988869191908B8D918B92909A999A949895919E9AA2
9BA39BA6A3ABA8A5ACA6A8ACB6ABA8B3B2AFB3B2B3B3BDC2BEB9C3C6C4C1D1C9CFCBCED5
D3D3D8DEE3EEEFE6F0F4F2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFBF2FBECEAE9EDE7E5DADDDCD9D1CAD2C6C7C6C3C4C2C6BEBEBEBC
B0ADB7AEACAAAAA4AAADA4ADA4A1A0A3A39B979CA29A95969A9597919196929391898F90
8B8B8C8584847F88858D7F808984837C798480807D8C7979787C7B7F7C7B7B7876768178
7E737872747A787071736A6F716F70726F71707571706C7378706D71696D6D6E6B6F6E68
6B70626B6D6D646A6766666B6A675F675B64656668656060686B6167686B655D62606368
5F5D6260665D5E57
6361605F6868606560616B69656563656460676B61636B6467686E60686766666A6A686B
63616E6566686767695E646662686A65716F71696F6C6A70696B6F756B6E716F6C717177
71727774746B71787A767E7771787977787C73807977777E7D7873788082827D76787F7C
827F897F8583888B81888C8883858689888A8889889794908898968E979797909896A09B
A29EA8A2A4A4AAACB2ADA5ACA7AEB7AFB6BCB3B4AEBEBFC3BDC5C2C6D0C9D9CECDC7CFD1
DDDEE0DFE4E3E8EDF0EFFAF8F9FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF4FAF3EEEEF1F2E8DDDED5D4DEDBCFDAD2D0BBBDC2C8BBBDB6BCB6BE
C0B2B4A9A4ACADABA9A1A8A6A5A4A19F99A3A1A0A29C9995909098958E9587918E89928E
91928C9184938786808C887F807F7F7E838076807B7382777D7B7B7A7772757E7D6F7880
72727A76757972706C6E7070706F746F706B6E7072756E64676E6D6C6B6C6C60666C656F
6A6E656262686C6D6962646A62696B6865626A6465656967626561655D5B685E645E6062
62635C5E5F5B6366
666666666D66625E65635C676765676766626461686563626469666A6763696A68676865
6868676D6E656B6B6A6E6E6D626E6E66706E6F66686F6F736F706B6D6F6A6A7B756F7771
6D6E777476737873786F737A797F7277787F777B7F7B7D7A7E7B7C79797E7A807F807B80
8282848A828A8A8989867E8887958C868A8F8D8F8B919190948F97949699949C98979D9D
9E9AA4A3A2A7AEA3A8A7AAAAABB3ACA7AEB0B1AFB3B7B9BDC1C2C5C8C5C9CBD4D0D7D9D8
D6DBE4E5E4E2F7F0F7F5F9F8FFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8FFFFFEEBF0EDE8E6E2E1E5DDD6D7D7C8D4CECBC5BCC3BFC0C0BEC2BE
B8B2ADB3AFB1B6A6AE9CADA3AA9AA19F9CA8A1A0959F9B919395919190968F8E948E8E8E
8E8B8887878D8582888A8582837F847B7C837683858073797980787B7A7D747B7C747276
727476707C7976767A746B7673747872736C6879716D69696E75606D676F686C6E6D6B65
5E686864666E6668636567606A6C69646260666C666E61606064645F6863646158636361
605F5F6763615E63
6363586365686D5E626C6A656460676463646A66676463606A6B5B666C6566676A646B65
626561676C6D68656C6C69696A676E686C6E6B6E6C6D736E706D6C6971686E6A6E726C6B
746B6D746E7679767A77737577737E7A7A837C767C7B748583787A7E7A7A83807D81788C
8687848484858A878A8B8590897F848F8E858A8692938E8F928F929697959F9490989F99
9CA098A6A2AAABA7A2A3A7AEB1AAB2B7AEB3B9B1B7BBC3BABCBFC3CDBDCCC9CFCFD8CCD3
DADCE4DEDDEDF4F7FBF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAFCFFF0F8ECF2DBDFDCDEE0D6D3D3D2D6CDBEC7C2C2C0BCB7B8BA
B6BAB9B3AFACB5B3AFA7A99FA7A4A1A09F9C9F9E9F9799A09798989F91918E9188869187
888B898B8C8E898B85818B8E877D887F7B7B7A80817D7C797D737883768177757E807E75
75747C776D71787374746A6D6B756B6B707676756B6D71746C6572616E6F6A6D6A696E6C
5F6967656E637067646868645F6866676C6863626260616566605F615C64606C64676165
61615F5F5F62625F
6161646362656467606360606D646964685C5E6666646C63616C635D67666D6560676A62
6272646B6B696D666D6D6B696C6E72726D72716E6E6B6D6D676E6F6E6C706C7371716C74
73716E74716C6C726F7177717D7D807881747B797B8278777E7C7C867E84787E837D7F79
7F8487858C83848388898A8D8E8B8B8A8B8D8C8E908D92898D9892918D969B9993A58EA0
96959F9F9DA3AFA3A7ACABAAB0AEABA8AEB2BABBBBBBC0C0BFC5C2C4C5CBCCD2CDCAD2D8
D8DCEAE5E8EEEDEAF1F1F4FFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFCFFFCEEFFEDE6E8E8E8DBDDDDD7D5D0D1C7C5C5C0C4BAC3BDBFBAB1
BBB2B5AFB0AAABB5B4A0A7A5A9AAA4A0A69BA69E9A939692998B969497978F91918F8C91
8E8A8C8B8E9383838880858D81817F86777D807E7D7B757F787D7B7B797A75747C7C7C77
7876757376747A707475726B7578757072746C6C6C706A736C696A6566676F6D64686C62
66696D686C686B65716C656A6D6562666B676263636C67606A66685F606868625D616566
5B6365645C5E5F63
625D625E6362655F5D656462626A6462676466665F6467666F64666863646D6A6A6B6964
6367676467706B6466606A686F6B6F6B6C666B696C6A6B6B6D706D6C6F6D6D7476787476
6D786B796B737175767873796F7E7B7677788076837B7978777B7D828481867E80837E77
847E8877827F8486828189899292878E908F888E90948B96909592929992979A9C9C98A1
9E9C9D9EA2A2AAABA3AAAEABB7A8ACB2A9B5B3BDBFBCB6BEC6BEC8C2CAC4CACBCBD3D3D1
D2DBE1EAE9EAEFECECF3F5FFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF4FEF1E9E9EEE8E6DCDFD6D5D9CBD2C4C7B9BEC1C7C6BDB7BA
B9B1B0ACB2B3ADAAACA4B0A1AAA7A2A5A39CA3969395969F99999A8993968D8B8D928691
8D898B898192858A85877F8180847F7C8A7982827F877F80817F7B82737C7C7B787E7576
7B77756D6E7776767A787172706F767278736E6C666D696C6F696F746E676E6B6C696B65
6961636B67676169616860696563666D636668656A64615E636366696868676562686467
655D636664605F5E
5E615D6063616366626B65646A625F5E61666A636366686A72676F6D69616D6668666B68
65626D6B696565626F706362686C6A616B6C676D6E7070746E736E70727574746C796F6F
71747270766D74746F74717F7D7C78797A837A7D7A7A7C8177857D8F9B857E85817C7B86
807B7A817C8282817C8789868387848D8F87988A97908E8C8F9B94928F8D9C989A969A9E
9EA8A1AAA49AA6A8A7A2A4AAB1A8B5B1B1B6B5BCBBB9BBB9C3C6CBC9BFC1CBD6CCD5DCD9
E2E0E3E6E3EBF4F0EFFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDF8F7F0F7E9E4E4E3DEE0D3D6D6CFD3D2C7CECBCCCCC4B5BEC1BA
B7B6B6ACB4ACB3B0AAB1A8AFA7A5A8A2A4ACA5A2929C9896949697939597949290858F8D
8C8B8A8C8E8D87808183877D8681828688817B807D80797B7E7E7A837D7577787C7B7C75
7B7975726F75727474726F7774717672706F716E796F6B6E61716B736A6C6E706C726A63
6B6969706E6964656C5D646E6B676D666565636B63645F6862635F66646D68686467605D
5D635B6A64635E5F
635C65646361655B676064646A61675D6260626266686469666672706766656765666369
686864706467656671696D66706B73696B716A6A6C6D6F766C6F71746E7373716A706A6D
676A716F7675706E71707B7E787B797D81807B71807D7A7E747F838A8585858382828185
8183837E7F8786868283848E8689828E8E8C918B888A8A8C9195948F8B919A9097A49D96
A29B9DA69BA2A6A4A8A7A9ABABAEA8A9B3B2B3AFB8C1BDC1C3C3C7CFD3CAC8C8D5DAD4D6
DDD7E1E2E6F0EAEEF3FAFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F4F3F4E4F4E9E0E1E4D7D4D5D7D1C6CECACBC3BDC8BCBFC2B8
B9B4B2ABB5B1B1AFABB1A9ADA69FA4A19E9AA39F97969C9C989D9A9296968F898B8D8081
8E93908F8689908D84888687818486857F7E827C83797D7B7D8076767F80797976727C7C
77767376747B70727571727271706C6C666E6C706D75696B6C71726C61626D6969696D68
646A6C64696E6E6D5F6964696C626B63666363645B5D6767636665646167696B675E635C
656361615D5A5965
695F65686066646967676466685D66636D606A6B686261646B636A67666272686C60697B
6A75636C6C6E6A6B6F65706B6966726E6D6C6C6B69706E6A70716D796D72747372756D74
6D68736D6F7B6E6E716D74777A7A777B73727D7A757E80747C797F847F82847D7D818180
888485828B8B868A858182878B898C868B8E888893958F8F998E949899979C99949A9C97
A1A29EA1A2A7A6ABABAAB1ADAEACB1AFADAEB7B7BBBCC2BCC6BAC9CAC6CFD3DAD1DBD7DE
E2DBE8E1F0F1ECF6FCF9FFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF2FFFBF6F1E7E6EAE7EFDDD8D6CFD5C7D4D1C6CBC6C4BDC2B8BFBC
B8B5B5B6A9A9AAA6A2ABAFAAA6A1A4A19F9DA1A0A096949195969A9495998F8F928B8E88
8B89898C8E8484898687818E85827D89827F7E79807F777B7D7678767B73787A7E7A737A
738079767D7F7676727474686F74766F6C6C6E756D686C74686C6868696B6A6E6B6C6D68
6568676A67616C6B65696569606765666E696667696164615F6655656A61595B675E6265
5C63615D6561615C
64616663606263655C65616563646063606364665F6A62626B5F65646D6D656A6D6C6D6A
686969736E6A666767676C6E736C6C6F5E6E6C75756E736E6F747674776C757179736D72
716C7071776F717675717378747477747C7E767A787C797D7B7F7F817F887F7C81837B86
827F818985828D84898D868A908F898E8889928E8E9B869196908C90938F9794999CA0A7
9BA0A29B9AA7A3A5AFB6AFADADB6ABB0B5B8B8B1BBBFC0BDC1C1BFC8C7C9D1D7DCDCD5D9
D7E0E7ECE4ECE6F8F1F6F9FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFCFFF1F4E9EFEAE2E4E2DED5DCCEC8CED2CBC2C5C2BEC5C4C6BF
B6AFBCAAABAAB0B2A9ABA8A8A29EA4A6969B969F9F9A98988F8C949298938B8E8C978B8E
8D8D908A858883858D868F868389817C83847A7C797B7F7973807F767E777778747C7B76
7370747676776F706872737475776966796E6F706D7375706C6D6F6C6569686B6466616A
71656A6C6963677265606B646666656E676F6A646B626C646A63676360645F636B666061
5F635A5F665F5F5D
6760625F626B5F6A62696962656667626369695E65676865676C676867696C6C65706E6B
726C70686B6A736A70686A6C68666A6C6A6F73736F7377776F746F717070706E7A717973
6E6C6F737B747376767773787C747D77758175777A8079797E7C7F807D7C7F857E7F8581
848580817D8781898587868C8886888F849288908D878D959A9195989C9498929D9E969F
A2A3A5A4A09CA8A7ACAEAEB4B1AEB2B4AFB5AFB0B6B4C1BFC2C9CAC9C0CECCCCD0D7D7DE
E1E0E2EAF0F3EEF3FDF8F8FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFDFEEEF4EEF0DDE5E7DFDAD4D5DAD5CCCBCCC4C2C8BEC0BBBFBA
BABABBBAB8AFB3ACA3A9A6A7A5A2A4A9A0A1969C9CA49A999D979699958E8F93998C9595
8B8C918C8789858B808B878B8A8385827C84817C8076757B7E7F7B787D747B7279737476
7D797B79727575747372756F6F6F6971686C736E706F6F6E716F6E6E6E6B6E7065666D6B
6C6C63666864606968686C65626A6B6566656A6464636E63646760696561646A6C6D6660
625B5C6468646160
645F6760605F646164686B69686470656763636360655F6064666A6865666467666A6B6E
6A676D6967706873676A6A6F6D63706D6E66726F6E74767271757977786E6D6D706B7373
6E786A747575777075727377767E7C7E757C76747E7C7B767F807E787D80897E83827C85
827A7F87848785888E838A88838E8692898B8F8B92988F8C919495979B9A9B9F97989EA0
9FA29FA2A3A2A1A0A9A9B2B1ADADB1A9B4BAB4B4C0B8B9C4BFC1CCC7CEC5D3CCD4DCD8D4
E2E3ECE7E4F1ECF4F9F9FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7FFFDECE3ECEFDFE4D9D8D4D8D3D6CCCCC1C6C8C4C1C2C1C1B9
B5B4B6AFB3B2A7AEA8A3A8ABA39D9EA1A0A29F9EA09AA49E9595968F8C948F91908B8F88
9185878A8A82868383868888808582838582897F7D817B7D79777C7977777C757A797C77
7C6D6E7476787573737B74746F736F6C6E6D736C70686E6C6C6C6F6A6A6D6A71696D6666
646F6B6B6867696E64666464676F676D6967656A676B6668696068626060686368656165
626265645E646062
635F6462646560655E6763646564616A65636463646E666565676C706766686D706A706A
6D6A6C6E726E736A6E666B66786F726D716D6C7B7A767C7A7571716F6C6C6C6D6A6D7775
6C74716E797472757075747678757978787A7776797E76857B7D7B82837D7F798582827D
807D7F868F8183858A877E899185848B948C91938D8C949395989A979A96949AA2A2A19A
A1A19BA9A2A4A5ABB1ADA5A9AEB5B5B3AFB3B5BABCB7C2BDBDCFC8C8D0CBCFCFD9D1E2D5
DAE6E5E6E7E5F3F4FAFBF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF2F3F1EDE6DFDDE4E3DEDBD2D6C9D5CFD3CDCDC8C7C1BBC3B7
B9BFB6B1C2B1A8A6ACACAAA6A6A0A3A39FA1A299979A9697929089918F92898795958F92
938B8C8C89808D8F8A84898A86848587838E80827A7A777F75817D6D757B777B73797575
737B777B77717B747275707A747776666E746B6A6F726D696A6E6769696B6C6C6E69686D
6D726B6769626A6A6F686A686A676B6868656A6A61646A61626162625D5F6366615D6A5E
62675F5D6761635F
656764615E5F6665696261665D696A69636469656868686A6B6471606B696B69726D6C6D
686C736F676A696B6C7568686A70696F746B6F6C7077777771776C74746C6970746C706C
6E7170707171716F6D706D7A777A7C727C797D767D7B7A7D7F7C7C7E7D817C837D81808C
7F7B898384828489817E89868B8A848C8789958B8C8A9196979096949B9994969BA19C95
9BA49CA0A1A8A4A2A7A9B0AEADADB3B0B3B3B5C4BDBEC3C3C0BFC5C6CEC7CCC3D0D1D3D9
DEE4DEE5E7E9F2EEF5FAFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDF6F8F9F0F1E1DBE4E7DEE5DBCFD3D4D4CFCDD1CCCAC7C0C8C0BF
BCBABFB3B0B2AAA6A8ADA29EA6A5A29BA1A29DA2A29F94A09A979A91959793958C959697
8B8C8988948B888A898D8D858682807E797F807C817E777B7881747775767575707B7078
7C7975746E7474737A6D756E6D6B696C6E696C6F6C71666B716D73686C766E6A68686E69
74656C716367656D6C6665706F716F6F6A686A6A676A6868606568655F67686763626760
5D636064625E6164
6963685C6566646164615F6B626F65656A626B676E6A66606964666B6664666E6D64696F
706D6B686B6E6F6C666970686B6F6E68756F6F7B7D7A747B7271697868706D6E75696E74
756E6E77707776756F7C736F71797D78777E79777E7682737A7D837E7C797E7E84867A84
7F828887838483808487858D898588888887878F8B938890908F959088989AA095A4A3A0
9EA4A3A7A4A5A9A4A7B1ABB7B5B3AEB2B5B9B9C0BABBBBBCC7BFC8CBD1D0D2D7DAD4D4D8
E2E0E5E6E5F3ECF8F3F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFEFFFDF2F7F1E5E8E5E9E4DDD8DEDDDACFC7CDD3C7C4C3C5C2C1BCBC
BDBEB8AFB5A3A6ACABA7A7A0A1A2A8A1A2A19F919894999992979199968C919398978988
8E8E8B94878A8C8F8489888D86858080808082837D7B7A787F817C7776777A7E7A757876
727479797871786B706C747675717069717271716F6B746D6B716D72676E6D676C67686F
686C6C646E6A666B6866696C676A5E6167686A6066666561636562636C63686764686461
5D6060665C595D5E
635F6862696063626E6365676362615F62636961636867686463676870676C6A6D70696E
6F6B6C6F716A6B736B6D7067756B716B6A726B7978787D7A77776F6F6D6C69707176766B
727A70746F72707470727C7C7777767C727576797D7583817A7A888283797B79837B7E7C
847E807E7E8283868680878C8A918A8E8A8B878D8D928F9096949490959F92959E9397A5
9AA2A2A6A3A99DADA5AEAEAAAEB3B5BCB5B8B7B6BCBAC1BCC4C5C8C6D4CDD4D1D2D7CEDB
DBDBDDEAEEF5F5FAFDF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF6FFF1EFE5E7EEE9E0DDDCD9E0D3CBD0D4CEC8C4C2C1C2BFCCB8
BDBAAFB5B2B5B4B0A2A4ABA1A39FA49CA29CA19E999D98909697968C969192978D8E8E93
91908F9182898B869291808880888A8C7D827C797B6F7E7D7B7D7B70717A73777C7C7B79
777976786E70757473706F6A756F6B6E726E7375736E7672776E676D70756D6B67666466
666971666868656C6267676969686768646F615F67635F606467616A6962655D61626165
6061605E625F615F
625B625F5B655E606A6565655F5E6B60676B656F5F63646A6C696D636D6C706F65666C64
6B6B6C6972686C6871696A6D6D6C6A706F6E6977747C76777A70766D6A6D6E7777747076
726D7672707372707176787371747A707777777E757C7B777580787B787B82767E7E8386
7D848186858A8B888484888C8A8E9489878C8D918C8C928E8F9993969694A097989997A2
A69E9BA4A8AAA6A2ADADACAAABA6B0B7B6B3B7BABCC0BFC0B7C4C8D0CBCFD1CBD6CFD8DB
E2E1E5E1F6EFEAFAFCFBF8FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF5FFF8F7F4EEECE3E8E2D9E0D7CBCCD0D1C8CED4CDC7BDC0BAC2BD
C0BDBBB8AEB0ACB1ACA9ABAAA79E9EA4A2A1A1A59E9D9B9C9795978E93938D8D948C8D8B
7E89908C898A7C898A85878B8184837D847B7E837E7A79787F7B73767A7B7A777C827481
7D70777B777474727B7B746F7668716F7270706F736D726E7075706E70706F78706B6E6E
686E696B69726A65656364676A64716767656269666A6667686263645E6761635C656666
635F6262615F6361
6061606B646164626266636066676D6368675E6B686668636766636560686A696F6D6C70
686F6D696E6C72716E71696C696C6F6B707670707878717075706D6E6F7171716D737273
766A6D746E767975767679757E707477787D7C80787F7E7E7F79817E82887D837D838383
87888C828388898F83848A85878A888B8A868E97839199948B9191989A9F9D9C98A49E98
9AA39F9C99A2AAAAA5ABAFADABAEACBAB4B8B6B0B6BCB6BFC1C7C7CAC7CDD6D2D6DDD9E5
D4E2E6EBF2E7E9FCFBFFF9FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDF1F2F8EBE6E4E7E9EBDDDCD7D6D1CAD5D9D5CAC8CEC4C1C5C0B7
B5B8B0BFB4AFB8AAB3AFAAA4A5A1A5A39C9CA59D9C9D9B9E9B999C8D978E8F86928E838D
88928D9687918B8D8F868B83897F7F7F7A7E8382807E757B7D7A777F7B787777787C7C7A
76797B7B7C7B79726A727873707767706E7473706A626F6B6A6B6F6C6A686C6D6F726E6C
6F706A666A696E696C616B696965696A616962665E6561626B5E69626D6C615F5D665C66
645D596A5E5D5B5B
5B616B625A5D5C656262636E656A6867665F68665D676764656C666667656E706C69696A
6F6D706C6B6B6C6F6D6E686D6A6E6C7469686F6F737272727270727470716F706F70796E
73756A6979737973767C71776F717D7F7E7773777B7D7C7C7E7D7980838389897C817F85
867D81848380888784877D8E838C91878693918A9686988D948A90999296929DA3A3A29D
9A9DA3A39CA0A7A7A5A8A8B1B4AFB2B0B7B4B8B8B0C1C1C4C4C8C3CBC6CAD4D0D2CEDFDE
E1E2EBE2EEEFF0F9FDFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFCEFF0EEEBE7E7E0E1E4DADBCCCDDBCBD1C7D0C8C2CAC4BFBAC1
B3BBB1AFAFB5AFA8AEABA1A7A9A597A2A0999F9C989898979895988F91958A8A8E85908E
8B8C8C8D858F8486858982838782847C787C797E7B7B78807F7D777976767F75767A7A7C
7679807A81707973736F6B736A6C6C7470726E686B72736E6A72686870737471726B7570
6E746D666C686464676C69676C6D676867636B6564676564646565676665616167646460
595D5F615E635B5F
615B616A6567636867645F6F6A645D67665F6167646667686A68636C656A6D6C6375666B
706C6C636660686D6C736B6F726F72696D686F72737366716A6E716A7469707773707774
7473786D6C75756F747472746E73797B78767F7B77797C7E75767E7D8284857F7B838182
808282848786848885888888868887898A8F91948E938E8C8A9091A094909B9A97A3A2A3
A1A1A2A6A8ABA7ABB29FABAAA7B4B9B7AFBAB7B5B9B6BFC6BEC8CBCFCCCCD2CCD2D6DBDC
E6E9DEE6EDF0F0F4F5F9F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFCFFFDFCF0F0F1E8ECEBEDE0DED7D8D6D6D2CECFC8C8C6C0C5C2BABBBE
B1B7B6B1ADB6A9B7AEA6A3A3A49D9EA097999E919E969896909795948B8A8E8A93918A8B
89858F848B898988858980837D7F837C83857F77807B767C7C7F797C7878807771767A78
7B797B73797A757276756F726E726D727B746C6F6F6B6F6D756C6D716F7068756F77756D
6E6E6D6C6B6A66676366686C72666A67625C64666664695B626660685E67625C5D60645D
5C5C62685C5E625F
685B625E665C665B6867686862696869646661686C66656C68696E696C68697360676F6A
6D67696B6B6C6F696A69676A6A696D6869736F6F6E716A756F6E6F72746F716D73796D70
726C7D726F71716F737276767878737272767B72757E747E78777E80867F7D838584807D
7C847F80847F92868A878B9180898C8C90938F87938E998D978F91949A98919B96A19B9D
99A2A3A8A4A4A6ACAEA4AAAEADB4B2B1B1B4BDBEBDB8C1C4C6C5C9C2D4D5CDD5D0D7D3E2
DDE0EAE4E7E5FBEDF1FFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDFAFBF3F7ECE1E9EBE3DED9D2D7DEDBD0C5DACFC6C5BBBEB9B6BB
AFB5B9AEB3B4B2B5A9A9B4ABA7A5AF9FA39D98A5959B9E938F919191938A978E878F8A87
888B838E7F868E8E80898D7E868079837C827A7A7881837877857F7E777D737873747773
7C787D7877727F7D727472706C786F6C6B77706F6A6E6E736D6F706D6B7873716F767B79
736F6572656E66666A666C616A676167656B676165696366686A6663616165646A5F675B
616364625D615B5C
655D655D5F6866696A6A656367646963685F6265696B676D6969696D6A686F73696B6E70
656A6D6D6B69696D696E6C6B7270736C6E6A6E6B6C6F6E6F706E6C6E6B726F73766F726C
7471746E6D79727074747A707579777E717B6E747D7B7E767C7C817C858780797D7F8382
8883898285828B8C88828180858A818C8A8592979296918D9093988F959A999B939B9C97
A3A59BA3A5A5ACA5A8AEAAA7B3B9B2BCB8B8B2BCB1BDC6BFB8C1C3CECAD1D2DDCFD9D7D7
E1D7E2EEEAEFEAF5FEEFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFCF5F4EEFAE9E5E7E4E6E4D6D6D0D8D7D0C9D2C7C2C0B6BDBBB8B5
BBADB1B2BAACAFABADAFA8A5A6A6A5A3A19A9E9D939999979A8A949595939891948D8D89
928A898E8B8D808E88868386808D80837F80767A7C7D7C7C767A7C797E7A77737F7B7D78
79797A7A777B6A6B6A7575756A6B6B7170726470696F676E6C6E6F7376726E777C78777C
7576686469666469685E676A6A64686A605B6062656466636967626463646864625A5C65
6560695C65595C63
5F61636669675C685F646167666C6666635E65676A6E696969706C68656C6F72706C6A69
6B6D65706C6A6A736D6B706F66696E6F70716E656C72657171706E716E6C716A70776F6E
736C756F767373727A747B7673787172747979727D7D767A7D80777A798381837E828284
8186858885828E82898F8883828A8A8E8A8C9490888D9397928F96949494909696A3A19D
9EA8A89EA19EAAA6A7ABB1ABAEAFB4B6B7B1B6B7BDB9C2C8C1CBC9CBBECEC6D2CECBE2D2
D6E5DBE9E9E9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFCFAFFF5F6F4ECF3E0E9DEE4D9DCCFCEC5D5CDC9BBC3C1C1BFC0BBB7
B5ACB6ABABAEB2A7B1A3A8A9A69CA7A09EA2A19A9191939694959597929291918F90908C
879484838B8481858B8084847E8081867F7B817C7D7D7D7B7A7C76757C7D787A7D79797D
7D76786E7773767875767275706C6B71746F65656F6A7679726B6E6B69786E6D82787B7E
7075706B6C6C67666D6C696D686665626466656865616262625C64666B615D655B5D6367
635E626263645F5E
5F6062615B676960605D636863635C686D696862696167637168696C686E6B6C5F666A6A
656D706C6B6C70686D696F6B6E6E68726D7561726D71726F686C6B7375716871746C7476
766F7876767A797872707873717578737974807575758079827C80827E877D7B877E7D7C
897E898A8A86837D8B82858A8C888D90898A8D90948F8C9991918C969A9099929C989F9B
9EA1A2A2A5A9A6A4ACA8A9ABB2A9B8AFB9B0B3B7B3B5B9BEBDC2C4CFC2CFCFD0D6DFD9DB
D5DFE4EEECECF0F8F7FFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFBFBF4F2EDEEDCEDE8DCD9E1D6D1D6CFC9CACACAB8C5C4C1C4BABC
BAAEB1B4AEA8ACA7ADA1A9ACAB9DA09C99A59D8E9699A09495898D8B909C8D8E8E8E8488
92878D867F85839181838183857E7F7D827877767A857B7A757E7C807F727F797D777D74
7471757D77767A78726B737673746776706D6A6C756C746D706F6C737369797A71787676
70766F667076626C696764646764686564616163605E61675E6267696362625F6267645D
67625E5D5F686163
69665F5D665F67646066656563616562616364676664696D6A6963746A7064666B696869
6967716C716A6B696D716B676F68676A6E6764716771746A6E706D736D706F757172706F
707A73727A77777A717570757279787277798272797D777B7B827C7A838C888182888680
828687888981888F7D89878B87838684868D8E968F9393908C928F9D96939BA2969A9799
A19FA3A3A39DAAA5ACACABB5B1ABB2B8B6AFC0B6BFB6B9BDC6C0C0C3CCD0CACDD0D5E1D8
D6E1E9F3E6EEF2F9F2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFCF4F2F5E8ECE4DCD7DED8CBD1D2C9C5C4CACDCDBEC8C1C6BFB7
B1BAB3AFADADACB0A8A9A7A4A29E9CA1A3979C9F989D9998939C8A9696848E8489988F88
85858A858984818B858288827A7F777F7B807E8785867B7C7F797B78747478717C777E78
7E78707574716F6F7870776E756D727274706B6C6F717077716F71716A6E747A70797F74
6E696E666C636C6960666167616866636C6763676A6468606766625D6364665C5C625E65
6560575D66605D66
64676365626C6166636664666765636469676666606864696168646B6F6D696B676E6C6D
69666865736969687072696C676C6A6A6A62696E71666E686E716E6E6970707875787376
7372746F7C7371727576737573726E767A7E7F7A7E7D7A7D7984807C8683847E8680807D
8185837F89838984878186888B7F86868C8E8B8C988A89929D8D93949891979C9F9C9FA1
9F9E9DA2A2A7A0A8A8A8A8A9ACB2B4BEB3BABDC1BBBCC2BAC5C8CEC5C1CEC7CFCFD5D5DB
DBDEEBE0F0F3ECFAF3FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFDFFFFFAF8F7ECF5EEE6DCDFE1E0DDD5D7D6D1CDC8CEC8C3C7C0C0C2BBC3B4
C2B3ADAFAAB4A6A8A9A3A1A69CA1979D9C989E999599988F928F8F8E9295998F8F918C8B
8A8F8D928E84877E90808380848084827D7F857C8082747D797C747D7D7A7A7B7C76787C
71707A75776E7279776C6D78706D716C6C6B6F7176706C66706F6E6F66777577716F716C
6E6B6D68646A6A6E6A6768606A6169676F67625E6B5E5F6061646A646561655F675E6266
62605E5E61655464
636151625E5D65606464666F66685E615A66606365666A676A6D67696F68696D67686562
686A6670706F6C6C6B6A6D676C6A6A696366697066736C6F6F6D71736F6C6E7070737073
71766C73726C7773807C736B74777A7C78807D737477747C7776777B7F7C7F8082808082
8084808189868380898784898A838D8F8E8B8B8B94898E8F919298939690979B95969C9A
A5A1A7989DA6AA9FA9ABACAEACAFB1B5BCBCB5B6B7B9BFBABFC7CAC8C8CAD1D2D2D4D9D3
DCDBE6E3F4EEF3FDF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFFFFFFFEFAF6E5ECE3E9E3D6D7DACFC9D2CACEC8C1C0CDC4C0C0BAB9B7
B9A7B3B4B4B3ADA8ACAAAAA0A2A0A29BA6A1A19F929899959996918D8F918E8C8D8C898D
8C87868C878A887E828085807C7D877A7E807E7A817C7C81807A7A7D787275707A78787A
76797979746F717174716E726E70776E6D6C7B736F736E7469687169706F726B75716E6E
6F68676C656D6468616A656B64656866676A685D63636061626365606168626464645F64
6163616662615663
636462625F616767646664626469666C636161626D676967616A6A6762706B656967606C
6E706E62636E6B7270676D69726C73686D6F6C6A696A746D7271736C6E6D72746F6E6F73
73706F7374767B6A716F737070736E7A7B75757D7A7B7979827C7F7C877982847D7B8383
837D838585897F848A868A8A7E8787928D8E92918E92929094959098979D9699979796A3
A69AA2A99CA4ADA4A4AAAEAFB2ACB3AEB6B6B5AFB9C0BDBAC9C1C2C0C5C9C7CDCFD2DBE3
DBE1E4EBEEEBEBEDF6F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFAFEFFF7F6F9EFE8E4DED9E7D5D6DCD2CDD4CECAC2C2C0C4CEC3B9B8B6
B0B6ACAAABA6AE9DAE9FACA0A2A29EA09D979A9F9E979892989291988B8F968E988E8C8D
858B858488858883878280847E857C767C7984857C7D7879787C85797875767173797D78
797872787477707A72757571726D7A7A756E7070716E6A756D6F776C6D64706A6A646C6E
6C676C6E6B656766646666626663686D62665F5F66625D61645E65645C636D6362636E5D
665F605C635E5D61
655A5B6264646764636869656D675F5F6967615A6165686D64697172686A686F65676B68
6B6E6C6C676E6D6869696B6D716D67716C6D6B696B6A6F6B6E716C6D74786C7571716E76
77767076707772776D7A70747A6F76767773757871847D7B7B7C7F80817F807C7C848283
888785868F877E90858B888983848789888A898F92948F908D9398919F9C9B9A9A9C979C
A1A59FA4AAA6A8A6A4AEB5B0BAAFB3B0BBBABDC2BFC0BAC1B8C6C9C7C3C8CCD5D5D8CEDA
DBDCE1E6DEEEF6F7F4F3FCFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDF1F3FFF1EEE3E4D5E1DFDADFCFD1D3C7CEC4C0C7BEC5BEC2BAB9AE
B5B0B7B4B1AAA9B0AC9CA89EA7A1A296A29E9BA396A09791939299969A92929494868E99
90868D87918688888682867B7D8B797978807C7D7877777676877877737572737B747876
79707B747073746A71717272776E6C776F6F676A6970787073686B71716C676A6B6E6870
6D6E7167686C6A6C696B6A6565635F6667676A685D605D66655F6865655E5F6367636369
645C6166605D5E63
6558675E5D6066675F5D65686261655C666768666565666464646C65686B656B686E6B6D
68676767706F6E6966706F69676E706B6E706F6D6F6D736875666F6D6B7170717474756C
6E74747577777573717277757A75757184717A77797978787A7C7E7E7D877E777F84807D
8283848B7C8787828A848885808B8A878487888F928E8F93908E8F9699929D99959CA89B
A49CA2A1A0A9B2A7A4A5A2B3B2ABB1BAB2B6B4B0C1B6C5C2BDBDC9C3C3D2D1D4D4C9D7E1
D8E1E3DFEAEAECF5FEF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF2F9FAF7FAF0F8EAE7E0DED5E2D4D5D0CCD4C5C8C6C5C8C0B7B9B7BBB4
B5AEAEB4B2B2A2A4A0A8A8A5A59FA19EA2939A9B9C989A98A08E9893938F92938E898E8D
908A858C887F8C85848B77827D827D817E7B7F7D7F7581817B7A7B7A7574797379727279
796F737771757578717172736A6F6D716F74687068706E6B6A6B6E736C6B6D6D6A6F6E71
686366616D656A6C706A69656569666864616768646463666B6A6A6260685D605F61695F
61626061645C6666
6664606961606664646063626A666765676462686A696964696D635F6A6B636371636C6C
6B656E6E6D74666B6D756E686D6C68686E6C706E716D7471757273747275737A7372757A
6E706E776D707276746F71757670797A73767B7B71767B757C7A777F7B7E8186837D7F7D
818084807F83878985848E87888C90838A848F8F8F91909598959091959E9CA19AA2999E
A3A49EA5ACA3AB9FAAA9AAAAADB3AFB3B1B7B8B4B9C1B8CAC0C3C5CBCCCED1D0DDD4DCD9
D3DCE4E7EBF9EBF6FFF4FBFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF4F4F1EBF2DCE4DED6D3DDD6CFCBCAC9C6BDC2CAC5B5B8B0B2B8
ABB4B2B5A9ACB2A7A3ABA19D96A5A2A3A29D9AA396979899909A909093938F89908F8986
888B8A868C8A868787868A7F807E817C7879827D7F7A7E7A73717E76787F797879787377
7D7A7274727179726B7373716F73766C666D6F6C74796D71726C6D6E7068706B69656969
6565656D6B6B6D706B6C6669706067696166626166666266655D68656B636D61695E5861
6C65575D63626266
625F5B6564606162686463646567646568685E6E63635F615E626C686F6E646D686F666A
687466706A70666A726873696E6A6C606C6F71656C6E736E6B70666E6B78727471717374
76716A7873736E6E6F76777977797279757771807B787D7B7F7B7A7C8580807B81858182
85887D828185878A898386848F8E868F8A838B8D8C919092919490979499949D999B939F
A29FA2A0A3A4A5A9A9A3ADA4ADB0AFADB6B5B5C0B5BBC2CBBEC4C6C5CCCFD0D8D5D6DADA
DCDEE1E7EBF1EEF6F5FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFEF8F8FDEFFDEFEDE4E1DDD7DBCED7C7CAD0C3C2C2BEBBC4B9B3B7BAB8
B3B6B1ACB0A9A7ADABABA7A6A49CA5A6A0A29D94A095999390928A92898B928C878C9488
898E838584858387858184878B8A7B7C7D757C8176797678747A78737D7973737570707A
74776D6F74787277746D726D6C71716B706B72716B657970706C706F68646E6B666D676C
67706D616B676C6566626D64695D665F6A6266686A5B6562645B6A67615E64635D615E69
5F6560655D5A5F5E
68656665575E5F665F636B686B5F5F6464616E5F63646E6567686D6E645F70676D6F6A65
62716575656F6A6F6F706C6D706B6E676B69716F6D696D6B6E6C6C6D737B726C7276797B
7575737873706D79737B6E77737277767874717B7A787E7F7B7B7A7C7E8582837A857E80
7D7D7D867C838285848A8A858988888C8D848E9491939390958E999A919694989E9EA59D
9CA89EA9A7A6A9B1A3AFABA8B0A5B2B0B7B3BBBAB6BFB5BEC0BEC4C7C7D3C9CCD2CDCFCE
D8DEDBE3E8EFEBE9F3F8FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF5F5E8F6F5ECE2E5DED5DCD0CFD0D2C5C6C5C5CBC1BEB5B5B7B3B5
AFB0B2B5A9ABA6A4A7A69BA29DA1A4A29D94A69C96979F8F969A969593918F8B8A888B8D
8C928A82888E878985858C827E86818083807C7C80797B7F7D777A7D73747A75797A737A
717B76797874726E746F74767075706C7573736F70766F6A716E6B706F656B6F6A686B70
6C6F696B65696A63666D696C6A6567626D6063646265695C675E635B655D61695D5B6766
5F655F5B5D5E5F59
615F655F6660635F6363606A6C686E6565646A6C646263656A64646A7270726C6D6B6D6F
6B63666D67696C6E6B6B6B686A6C7069696C6E706B6A6D72706D746D756D74727376746D
7273757671726A766D72717C727A77777877797F807A76867D78797B857B817D80838389
838184838288838C858F8C878888878A8B8C8E9092929392939494979597969A959A9FA3
A1A59FA4A8A0A7A2ACABA9ADAEAEA5B5B1B5B4B3B4BDBFC3C1C5CBCEC7C7CDCCC9D8CFD8
D5D7DDE0DEE9ECF7FFFDFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFEF5F0EEE9E8EBDEE6DED6DBDCCFD2C7C9CCC6BFBBC0BAB3B9B6B6B0
AEACB1B2ACA1ADA3A4AAA3A09D9698A09497989A97949798999497938F96919392928C8A
828788828D88888783817F80818386827A7D7C83767E7A747D727B747D7077727B747673
74717C776F797C72746F6F6C6E6D7371756D69716E6A696B6E6F666B756F6E766B676B6E
6B6B67706968676C66686864696661686C67606B63625C5F6B5E605C62615F6362655D62
685F605F635C5E5F
66605F60676065665F61626164636169676662626E66636B656A686C676B676E6C6E6866
6A6B6E72736867686D6D6D6E65656F6E686F6D706F70686A73736E706F71746E74737876
73747872757179777C7473737B7D707C7E7878797E847A7C7F807C8079837D7E767B7A85
848585808583828C8683878E8B8B88898B90918C95939294969B949E939B9A9C9E989699
A29DAAA7AF9EA6AAA9ABA8AAA2ABABACADB6AFB8B2B0C2C4C1CDC8CAC5C9C7D6D4CFD2DA
E1DCE0E7EAE9E9F8F7FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF9FBFFFFF7F1E6EAE7DDDDDEE0CED0CBC2C6C3CAC7C7C1B4BAC0BAB3AFB7
ADAFB1ADAFAFAEA29FA0ACADA29EA29FA19F9F9D989D9A9991989299959086888E8C8D8A
868185838788867E86828780807D7988867E79877E737E7C7A7D77747876787C7C767474
6E76727A6E737570716B6F6E7073747068706A7373706C6D6E6B706863676E6B6E717469
6B6D67646E666F686C66696372606C6361646569635F66666963635F616A686761606161
61645C625C625C65
6267665F605E686163605D5D61666B6869656A64686A6A666367626370706C6A6E696669
6F7072716D666870716D73736E726C73716D6B6D73706F7470707A70706E7D6B7A76776F
6D717070747577706A777474767471807B797C82877E7A807B8380847C7979787D828382
84877E837E857F8084868E8A888B888983838F8E8F949691959A9394979E939998989799
A1A1AA9FA0A9AAA3ACAFA4A7ABAEB9AFADABBFB2BDBDBBC0C6C0C9CACDCACFC7D5D0D6DC
DBE4DBE7EEECEEF7FCF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFDFFFDFFF2F1F4E5E5E9E5E0D6D6D4D1D4CFCBCEC3BEC6C2C4B6B9B9B4B3B0
B6AEAFAAAFA4AFA59FA5A2A1AA999D9C9AA4A2A39798918E949C899A9495969088898886
858E8A8F878E8B8182867A83807F807A80758777837E7C7A7B77727E7B7D7D7A787A7B7B
77707173787A757B7971746F726E6E69706A726F73706B6E726B746B6A646D696A6C6566
66686764696363686669606A62635D635D61686662656664626461616461676861636065
63615F61645D5D60
68595E5F5C695E6561676D5F6368685F65696866646866676B676A696A6C6F676869696C
676C6C70696D6969706B6B736D6C676769716C6F6B6C6F6A686E736D71756B70706E6C6B
7A72726C756B69727279786D7D75777A7C7D7B7A7E797F7B81847D7E797E7D7F7E866F7E
88847D8484848B7E8788828B8B8F888C91928B918C8B92998F959097A59D9C979996A9A2
9E95A09AA5A6A4A4ABA7A8A7AFA8B1ACB5B1BDBDB1C0C2C1C1C1C0C8C4C8D6CBCBCDD8D0
E1D7E0E5E4F9E2EDF0F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFCFFFAF6F3EADEECE0E7E3E1E0DCD1D8D5CAC9CDCDC3C6BDBDBFB6B7B8BAB6
AEB3B1ACABAAA8A8AC9CAD9DA5A7A1A09F9FA59D9D989491958B8D8A8D8F898C928D8D89
8982858A82898289837E808478817B7D7A7B767F7C7D7C787E76837A7C7B7B7276777572
777A7A767B777B73736C6B6F6B79727277736D71736D6D69696F6B71726A67686F67676E
626F696F616963646A6B6769656B64686760655E616560635F665D6665615E5E675E615F
6364625F5D605D5C
63686163645E6263656B5F65616E62656667696267676A646D646A6E6A7170716E6D6F69
6C6B6A6E65686F667076696D6C726F716B6E726A6F6D71706D6E726E6F726D6C74747178
7070747872767C70787A726F7C7E787A7B887A7E7F7681767573767B7D79797E7C7C8082
7E8583818482898F858189868785888985908997948A919A9692949895989A9A9D99A7A1
A49DA0A39CA6A7A6AEAEABA6A9AAADB1B2B0AEB9B9B6BABDC2CAC1C7C4C8CED0CCD7DCDF
D4DEDFE4E6E1ECF3E8F4F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8F1FCF1EFECECE6E9E9E1DFDDD8DAD8CED3CBCAC4C2C0C9C7BEB8BBB3B0B1
B8ADACAAA2A6A0A4A5A7A5A6ACA6A4A3A9AE9CA09D98919A96929497868E938F908C8589
8E8784888B8586898585887E7E7E787C817F7D757B7C817C7C7A7C7E7A7C6D787580747A
8072797678756D6D7F6F6C69736B706F736E6E6E6F6F6A71686B6B6F63696D6E6B6B7565
6F686A636B6B6B646767656A6468655E63636264696C65625F695D645D685D6A60636761
5E616164635C5861
6059655E6565626C6160626162616067646A67636865665E686C6C74676D6867716A6168
6C6F6C6D6A646C776F696A6E706E70726C6C6D676E726F6D6B736D756F6F706F6E7A7276
7272726C736F717676737176737B7E77817D7D877F7E827B77737A777A7B7B807C7A7F86
85828085888C838288858A8C858D858F90948B8A8B90979A968D91969B999B979E9BA3A4
A4A4A7A4A3A6A3A8A6ABAFAFAEA9ABB1B9ABBCAEBAB9C5BFC1C0CBC9D2C2CBD0C8D8D8DB
D4E0DDE4EFEAE5EBF9EBFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFDFFFFFAF0F2F7E5EBDFDED7DEDADAD3CDC9C4C7C7BBC4C2BFB7B7BABDB2B5
B2B5B1ADAFA8A7AAA8A5A3A1A7AAA4A0A8A9A59A9F999E92919492888D8B8C8A928C878D
87848686847F85858A7F85818084847B807980827E74777B79797576767C727A7D767670
747578727175767A746D746D6C6B6C72766A6D6E746E6E736C72686769686B6A6C686A6A
65696C6E666D6B656369686D68676A61665F61626761635C60615E5C6562606467676360
656264615B616061
6065675D686866636665636561636263605C616964606667686F6D6D6F696A656C5E6A6C
6D6B676F6B6B6D68686A6E7070766D6E6F76756D6F6C706B7674707373656F6E71737E70
706F6C72746C6D76717676797473707B78858182857D7E79747A7C727C807D7B817E827F
7D807E83868384818F878A8884898B8991898C9091868894928E938E9097989B9AAAB8C2
ABA1A1A39CA4A5A6A4A6A2ABACA9ABADB3B1B3B8BDB9BCBBBFC3C2C6CACCCFCDCBD2D7D3
DCDEDDDFDEE3EAEDECF1F5F4F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF3EFFDF8F0DEE4DDE4DDDBD6CFD6D9CCC8C2CCC6C8BFB7BFC4BDB1B6AF
B0BAB0ABACA9AAA19DA2A0A5A3A7A99FA3A2A49E9C9D969897938B9492878A9392918D86
818083838083857F808181827F85837E807B7B797D77798175767D7C797D7876797B7576
767677787C727A776D6E7975716C7077696B6D706A6668756B706872756A6A6D706B6A63
6665696561686767676762636166646467655D65635F6B636165616564606A666C625F5A
60625C63605E5562
5F646269586765636A5E656661656C6562696968686F6D636768686D7173726B716C6C68
686E6E736A666A706D716F6E6F6F696F78696E7A746E686B70757E6F716E706E766E7071
756E717673717772777672797579757A7D7F7B7A85777F7A767F7E79817F877D8181867F
7F8282857C80848A867C8C84828785868A8F958C8F858C94979895979193A09B99A0AAB2
A8A3A19E9FA9A5A89EAAB0ACABA8ADB1B0B5BEABB3BFC1B8BABBC1C8CAD0C4CDCCD0D7D7
DBD2D9E0DDE4E5ECECF0F1F5FFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFDFDF9F3E9F7F2EDE6E3DEDDDDD4D3D3CBCEC9C1CCD0C7BCC2BFB0B2B8B3B3AF
B9B4A9A9A3A9A0A59EA8A6AB9EA59FA6A99D989C9C919C9A9491918B8F92898E948B998C
928A828582868581867F83777F7E8473807A807F7C7C7A7A7D79747A7B747C7578707474
72757571767773696D6E706D6F72776F726E6A6D6E6C6B6F736D6E686A66696C6768636C
676764686669656B6F6A6F656369636A66636664606464616061615E6561686866625F62
5C5F6461635E5B60
62656462656861646A6666666666626569686267616460686867686D6C6C68666D6C6B74
6D68716A656470736A68716369706B6E6C6772746F6B7372716B6D6E6C706D7273727572
7676727171726D777879776978767E75797B827C7F7F798073777B7E7A7E838584787D81
7D8781837F8886808A8186908789908D8B8B8E858D919A93989C9094939C938E989DA4AA
A3A0A19C9AA4A0ABA7A6A9A1AFA5ACAFA8B3AFADB0B8C6B9B8BCB9BDC7CDC5CAC9C9D3D4
D5DBDEDCDDE3E7E9F2F4EDF0FAFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFEDEDE9E6F2EBE9ECE2D9D9D5D1D8D1CACFC3BCCDC2C0C2BEB7B6B6B6B1B4
B1ABA7ADA4B5A6ABA39DA3A99EA2A5ACA19EA297999A96948E929492958F8E928B8D8C8C
81898882898478828379818080787A7E797A8078797B79747B7784787779757A75787A70
7770757974706F71726E766E736F737174706765746D6C6A6A686C5E6A706F736B6F6967
686D6E67666D676D6B68656769686A616A5F61626469646B6366695E60625D645C5E6466
645D645D635F585C
645C60695F5D636765676663656B68686265696361646D6C646D6E6562656E6E686C6E6F
69706971696D6F6D696B7369716B6D706E6D706675736A6F716D6C6E6B7C6F6E6E726E79
747E7177787772727D787C767B7380787E7C797C7C7B7B78747F7F7B7A7C7E7D7E7E897F
798580827C8784857F83888D868D8789868A888A948F918994929097939798949599A19B
9FA69D9E9C9DA09EA8B0A7A8ABADB0AAAFACB8B6BAB9B7BDBEC0BEBCC0BFC8C7D2D4D2D3
DBD2DCE4DAE1E6E3EBF5EBF4FFFBFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFEFFFCFAFBEFF0EFEBE6E8DDD6DDD8D9D0D5D1CDCBC4C8C8BDC4C0C6B5BCB1B9B3B5
A7B0A7ADA6A2A6A1A3A99DA79C9FA09D9AA2999B9998969899968E8D8C8D878A8C908C8B
8B898A867D84788580848581817E7F847D7D787D7A7B78777A807D757A7872747878726C
747175767B6C6E6B71716F6D70726E72716B686A67716F6A6A6D6F6E716C6E6A666D6B6A
706B6A686C676A6F6869696C6B66656B685E6A636262656662666B6C6362606364636361
5E5D645F615C555E
625E63675F5760666A636B656B64616267695E6665616C6D686E6C6C6764686B68666E73
6A6F73686A706972686A6E656A67706F71696C766B6A746A6B73746D71766B7377657571
757472717873757375777B7A777773737A80747F767682827A7C837D797F7F827E82837E
83808789868382858187868B8586888F868A9495938F8D8F91909097908D9798949A9B9B
A2A3A1A8AEA5A6A5A7A2ABA2AEB1AFB6B0A8B3B6B3BCB2BCB9C5C7C7C3CDCAD1C7C9D3D8
DDD6DBDCDBE3E3EBEAF0F4EEFFF2F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF5F9EEECECEEE3ECECE6E0D8DBD5C7CECECDCBC8C7C2D0BDB8C0B3B5AEB3ADB6
AEAEAA9EA2A5A3A7A6A6A1A1A2A29D9C9E9E999B91918F979292919090988E88898B8885
8487848284828680808380867B8A7E8779787A787F7A78777A7576797673767079717474
6F6E7473797472787A6A726F726E6D70736678726F6C676C6D676C696A71686863696C6A
6B656B656D66636B6D696B6B65696D686961696361606467636266635F5D62655E64615B
5C5F6360655E6263
625E5C615F646769616468626564676562675F64625C65696A617168626764706E68656B
6C6B6A6F6F636D6D68727368706F696669726C767476706E6C726970746E6B6D74756E71
70727470716E727276707C797B7A7C7979797E7B787D747B7F7C77777D7A7B7276848084
7D857F8F8284888281888C8B8C7C85858D8C8E8F8F918E93998D8E909393969B9A9A989E
9D9B9CA19BA1A2A2AAACA8B1A5B1A5B0B5ADB0B1B7BCB5B9B5BFC9BFC8CAD1D0D6CFCFD4
D8D9E1E7DBE5F1E9EDF1F1F3F8FFFAFEF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFBFFFFF9FCF5F1E6E6D9E4DDD8D4D0D4D1D1CACDC9C8C5C4C8BFC2C3B7BAADB6B1AC
B8AAA6A5A3A7A1ABA69FA7A4A29FA4999A9A979695999498969192948F8D8F898984848C
898A868E86827883808283868387807A827778737A74787779787776787B78757A75776E
7971796F74757074796970737571756F71716E656C646D6B6A6C6E6E64696C67666A6B66
6766686369686B67636663646A69626265656862606162616360636D676165636A656366
65595D6464615F61
65575C67676367676D6A626668626D6F60636765666660686D6765656B676A6C6D71686D
636C6E6A6E6C706E6F71706A6E6A6E6668716776716B71716D6D706E7176706C6F707173
75727172747573787872787E757A7D797279777C7B7F7A7B7F7E7D808072737A7F818584
757E807C838880838489858693848B8C8B8C86908F908B8D8E948B909693999E93A09C97
9E9EA09CA09DA2A5A79FB0A2A6B0ACABACA9ACB5B3BBBEBAB4BBBCBDC2C5C8C4D4CED4CC
D5CFDCD9E0DEE6ECE7EDECF4F9FBF9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF8FAEBF7FAE5E9E6E5E2D8D5CFD1D6D0D7C4CBC6BECDC4BDB5BEBFB4B0B5B4B4
B0ABA6B7A3B0A29FAAA49DA79CA09B97A1989C91949D89969390938A8F8D87828A908F85
8887808887877E89828887838382897D7F7B83767B7E7D707D817D7877777C7678737474
7C6F6E76677A79746B737271706C71716C6D68726B6D6D6F6B706869696E6965685E696C
676A686B6868656D6D7069635C6B5E665E63676A636764616764606969665B6662606561
5B605857605D635F
685D61666568636C6474645E616467656066616269695F626766656A6C6D6C656D68686A
6769686A6C646A6B6D6F6773726E6B6D626F6F6B74646E6E776F706972736F6E6E707173
6E7476726F747B76767676757B7C7B7675797B75827A79777B7B7679827B777D808E8880
86847D8481827B838780868A8087918A8A868E898988928F9295958E959D9B9F96989C9A
9F99A49FAB98A8ABA5ADA9A5ADA19FB1B9A9B1B3B9B8BABCB9C2C4C8C2CCBEC8C8CBD6D3
D7D4DDE2D7DCE5E1E4EBE8F2F5FFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF4F0EEEBEBE9E0E4E8D5D8DBDCD0D0C6CCC4CAC9C5C4B7C3BBB0BABAB3B1ADB1
B0AAAEA6ADA39FA6A99BA49E9D9D9EA09DA195979D95918F9095949292908688948B8F84
818384867F858184797C847E797D897E7E787A777876787D7A6E75777A75767A79777775
6D766C6F7371797271737A7372697070706E70696E6E6A6C687160686A6967676F6F6B69
6D63666C69696A6D656762686766666668606662696968695D646460636062655D5D6A61
61615F5E56625A65
62676A636364666268676C6963646765645E6A6166696A6C65636265676B716764616B69
6A6D6B6866686C706F70706C6E6E756B6E6E65746D6B69726E6C6F766E7B796C71717573
746F7572747A717171797A797D717A7C71747274747873737A7A7E7E7A7E847D79847F85
8582807D8481838086888489888D858A878C8F89898D90988F908E968D9A999F989B9C99
9D9C9EA09EA19DA9AAAAA9A9A8ACACACAFAFB1AFAFB3B0BBBCBBBDC2D1C9C8C9CECDCCD1
CFE5D2D7DBD8E3E8EBEDF5F5F6F9F8F9FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF4FCEFF0E8E7EAE7E0DAD4DECED5CDCCCEC9C9C2B7C1BBC6BCB8B9B2B2B8B1AC
ADACA5A5ACAAA5A59BA59C9E969A9CA493989991999A9C939B978C92878B8884928C8681
82857E81828581817C86807D7C817F8277767C8279787B767C75777D76737E767578756E
7371746F6D7678776E74797072756B706E6B6E736D686D726A736D6F716D726C6569675E
656F656C70646B6B68696B65656B63656B6F69676C6B656865686A6167666764675A6561
5F685C66625F585E
655F5D6B5D5E686566656463676068616568616467656365636565606C6B69706C686C6F
6C6B696E6A6F6F6F70716E6D696C6B71646869746D6B746D707270716B6F6E736D736B74
6C7973787573727F7879757C7379717C777980797C8075787C787E7D7C7E7C7C6F7D8082
7F847D847D82877E828A8786868988908E8E8B8C9191878C919098969192959894949997
A3A59BA09E9BA49FAAA4B2A9B3ACAAAFB4B2B6B7B7B9BBB7C1BEBDC2CBC9BBCAC8C8D2D2
CEDEDEE1DDDEDDE2E7EBEAEFF6F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFDFCF1EEF7ECECE7E3D7DDDBD9D7D6CCCACFC4C2C4C2C2BABAC5B1B5B8B5B6ABAE
ACAAABABA8A7A2A2A4A09A9FA297999497989B9794958F92998D94948E8E8A89908E888A
868D8583858B8882847A7C78817F7D7F7F7D7E797A797779747E7B72757775787E747476
717973716E6F79756971706E736E6E746A6E6B6C6C736E6A6D6F6E6C6B6F6C6C6B6A7066
6A636F67686562676C6B67676A6F6D6A6C666A6661665D606B6866656A61635F5B60625F
685F63656360605E
685F65656A5D6768606B62606863645F67646361646A6169686464646C706A6963676E6E
686B686B68666F6E6D6C696D686E6E69676A73706F676D6D73786B667172736F6D757572
7175737077717E737376747873797C727778787B7D7E7B78756C7B817F7B7C7C7A7F8384
80868782847E8586938986838B8C8E89838491888C878B9491979694939A9A90949A939D
94A09AA1A0A3A0A3A6A9A5AEAAA5AAABABB9B1B5B1B7B8BAB6C2BFBCC1C3C5C6D9CAC7CF
D0D7D6DBDDDAE2DFE0F4E8F1F7F7FAFAF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF5F3F2EEF5E5E7E4DDE0DCD5D3C6CBCEC8CBC3CEC4B8BCBCBCB3B3B9B5B5B2B2AE
B0B4A4A1A7A3A5A5A8A2A3A0A49C9C999798979EA1979B8E988D8F8E938D8E8E93907E83
818083897D847F7C7E837F82847C7C817F7C79817F7D7E7C7F797B767D7775756A787272
70737E716D727774746E7570716C726E74676D75706C706D676D736E6B725F6E67667166
5E696566686B646A62686369646A6566696370646A63656767676565635F64675D65625F
6460605B5C5D5D5B
65636765636469656665656B6568686260636D676868656C606D6D6666646C6A6C686C6D
6C65686C606C6C6B6B696A676F6F7269666C7075636C6D6C6A6B77736F7076706E766E6E
7A6F6F72767B6F7C6D7B7B7B757674707077747B7B7B797C7E77757A7E7A8078827C8081
867C8485877E827E8888828388908C8F8F8A8E878990968D90998D929C92909199969D9A
9F9CA69A999CA3A0AAABA9ACAAA9A8AABAABAAB1BAB8B3B9B9C1C2C6BBBBC7D1CFD1CED4
CFE0DEDADDE0E0E2EBDFE8F1F0FBF4F9FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFBF8FEF5FBE8F0EDDCDDE5E7D3D6D7CDD1D4CCCCCCC1C9BAB8B7B9B7B9B0BBB6B1B0B2
AFAAA8AC9EA3A0A0A3A2A19CA69B9F979198989A96959696928C87959198928C888E8D88
85878B8C8B7E7F807C807F807D767B747974777B7A77797D797A787476737E7D76747C73
6D78726E766D726F6F737171736C71756C7371626F6C6C6969746C686D6A6E68606C6B65
646B6A706A676363626D676B6E6F6666715C6264676B5F6566636E64645F636565626160
635E60645A5F6056
655D655C646463655B63606567666563676D695A6E676569625E67686F636964696A6864
6A656968666D6267676C6C726B706F6B6A71686A7271676C71746F69736E6D6E6E726F70
72767671707A7D75777A6F76767B72757E7F74707D7D74777A7E7D76837C7B7481827F82
7E7F8B8183848384818981828B8D8789858C8B91888F8E9196929692979699939A9F989E
9E9BA19FA3A1ABA19EA9A8A6A69DAEB0B8A8AFB4B6B7BBB6B8C3B9B9C4C4C2C2CDCACAD4
D5D4D8D8E3D8DBDAE6E7EFF7F5EDFEFAFCF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFCFBEDEEF4F2E7EAE4E1E3D8D7D2D8D7DAC5C2C7C6C5C2BABCBBBDB5BEB8B8ADAAB0AB
ACA5A5A59EA7A39D9C9C9EA29D99969C9590928E968B9692928A9491908F898B898B8B8F
868E85828485807B83867F84787F7B7E7A777D7A787A7A797B7A76797E76747173767871
7971797774787672726D6F776E6A6B7471726B6B6E6A636F6C6B70706968676A6A6B6A6A
686A63676D6B6F71676C69646A686A6C6C6769666A6062645D635E6764636A645F675B58
625E5C6466635E5D
61675C6060686566636265626964646962666A67666362626968646B6965676664706768
68696D6C6A69696A656F6A6A6D6F6B6D6470696A6C75716A6D6C7371697172706F6E7577
72727475767372727778787276777C76757D73767779787E7676757C7B7D767E87807881
807F7E858088868D8C82828D85878A8C8E8A89928E8D928D8F8F92929598929E9E8A9BA0
959AA59FA298989EA8A4A4A4AEA4A9B3A3B1B1AEB1AEB5B4BDBABDC2B8C6C0CFCDCED0CD
D2D8D5D6E3DAE4E3E0E2ECEEEBF9EDF9FFF8FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9FCF0F8F3EDE8E6E3E3E7DDDFD9CFD5D3CFC8CAC7CDC0C2BFBEBCB7BEB2ADB4AFAFBAA7
ACACA39BA2A9A1A0A0A1A29DA093949E959AA18E949998959798898B8D878F8E8C858383
85837F857F88837C7F7C7B7A877C80787B7B737C7C777C7C787770747A7B747972727476
75756F76716C6D726D7176736D7A6870737464756B6F6B6A706C666B6868696A716A6673
686F6F6466676967686E656369696C66656761626669656666696067675F6564645B5E5E
686660665E635B5C
64666669605E6964625C6B606765656969696D706D6B656C666C686767666A6E6D6B7269
6866696F666D636C716D6D6B65676A69696C6A646A726F706C71736C6F776E6F7169756F
747372736F706F72757174767C786F766F74797E7871747A7D7A7C7C81807D84817D8182
83897D83888A7F7D7F84848E8689818E8E838C8B928F93908E979098958C929B969A9C94
9D9DA399979E9EABA89CA7A5A5B2AEB4ADADB5B6B1B4BCB2B4B8BCBEB5C3C8CAC6CDCCCF
CFD5D8D5DDDAE0D8E4E2EAE6EDFAF2FFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7F0F2FBF4EFE3E2E1E2DEDBD7D3D4D5D5C3C9CAC6C7BBC2BBBCB6B6B0AFB1AEADA9A6A7
A5A9A2A59F9EA1A49E969C9F989D929D989B928F94978D8B96918F8E988C8F818E868E88
898682807D827C7A837D7E797F7D8077767B7B7E7B7C747A817B7D7D7379787474757470
7173736E726F6B7876756E697475786E6A726F706F6D656C6D6E6B6D65685F6E646A7273
65676D646A686B626D6B6869696D606D686466696A65656B66696768676C635B65695E65
645D5F665B595D61
6464616468625E62646260635C5E6569686D6D6766616C6369696B6E625F64716D6F6F69
61716A69686969636F6A6B6C6C6B6F6F6B736D6B6D72706F6972746D6C706A6E74747275
7674726C747B7775777777737771777577776F837877787B7F797C7A797A807E7A817B87
827E797D7E7E8584858E7D8785868D838F8D8A8D818C868C9291909799939F9C9C8C9899
989AA1A3A398A89DA2A7A2AA9EA7AEA8ACAAABACAFB2B2C0B7B3B3C0C1C7C5C1CACACFD0
CED1D7D8D7E0D7E3DCE7EAECF4E6E1F1F6F2FFF7FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
F6F9EFF0ECE6EDE3E0E0D9D5D8D3D8CEC5C7CEC9BFC3BEC9BCBDC4B4B3B7B3AFB0AAACAF
A9A4A8A2A6A69FA2A49AA19EA6A0A096989A949D97969B929493878B8B8B8B8A8C8F8484
868C828285807C807D7F827C7E7C7E7A75727C827972747C77837A7C7D7C6F736F757078
7C776D7670706F7472707474726D716E6C62696E75686E6C71656E6F6E6C666B64706670
6D6A676E706C6C6A67696869696469606263656563626768696366665F63686765616360
6467645F62616060
625F68645F5F656563676C66616764696A62646463676E6662666269676368666B706D6A
6B6867696B646C6F6863636D656068697168696B6D6674696E6D6B6C7274766E6E717174
78787275767679766E767478776F777572787B6E7B767F76797A7F7C7B81827D84817B81
83808482828087858E85868288888C888F8888898C8F8D908F9796989A8F99989D91999E
9E9FA399A1A0A1A09BA0A0A5A9A9A7A6ABAFB7A7B3B1B4B4B2BEB0B6B5C4C8C2CBC0CDC8
C9CFCFD3D4DBE0DED8E4E7E8E8F4FAF1F9FAFDFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFB
F3EFF5F3EBF3DFE2DDD8D7D7D7DAD3C4C3D4C3C2C5BCC6BEBCB1C3B5B8B2B6AFADB4B0AE
A6A5ABAEA0A5A49B9CA09E9D9D9CA0989B9B95929691969195998A8E9184908888878281
888882857C8381847F81817C7E787E7D7C7E817D7D7C7E757B7773767A75797370777871
726E7A6C7174707A726E716A7266686E6A6E71727371697168707266706A676D6C6E6866
726A6C6C6A6A63696C6667656663686066616664615C63666A626769636162605E696161
5D655B605F5D615A
645F586B6462686464616062676B696D67626A6A675D696B6860686F6D65636C716D6167
676D6F696B66676A6E6C666969706F6E6D6E6F6F736F6D6D70726B6F6D6F6C716C726871
74756F76797375736E75757476787678777E78767979787E79807A81807C7A82807A7A7B
84807D85807A828989847F8985878691988C9086939693929397959596979E9799A19B99
999E989B99A39FA9A5A5A5A2A5AFB2A7ADA7AFB0AFB8AFB2C1B4B8B9BCC2C6C2C7CBC7D0
D2D7CCD6DBD5D9DEE1EDF1E9DEEFF0F1F8F8FCFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEF3
F6F4F3F5E6E3E3E4DDD7D7D4CFCFD2C7CAC6C4C2CBC1BEBDB7B3B4BBB6AEB5ACAFA7A9A2
AAA0AEA3A1B09D9D9FA1A09D9A989E98969A9A9B98999199918D8E8B8F90878383878A82
8283867F8785888184817B80797B757B7B77767B81777778787B7F74777A747772776F76
7972757575736E666D716F717671706F706E6F6C6D6B73706C706D686B69676A66686469
67686C5E64685E63636165696A676566696A6962646469695D61666563665D64685E5F65
625F56605E5D5657
636260645F6360685B62626568656C666B6A61686D6E6A69696B6A626C5D6A6867666F5F
6C6C6C62726D6F6E716C6E686A6D686C716F706F656D6D71746F6F73706F72756C6E6A70
6D6F73716F786C777778707772747879757979747A7A7B7E7A787B888375848082807984
80817D7C858A868F858B80887E8986868B928887908A9292948D94909C9796989A979C9C
A59A9B9C9A9AA0A29EA9A9A29DA0A5A1ADA7AFB2B4B1B0B5BEB4BAC5BCBDC7C3C4CBCBCB
CFD0CBD5D8D3D6DDE1E1DFE1F0E8EEF0F2F6FAFAFCF5FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFBFB
F5F1EFEAEAEBE4E7D9D5DDD3D5D7CCCCC7D0CCC0C9BBBBC0B8BBB6B0B2B7AFA7B5B1ADAB
A4AEA8A5A3A6A59B9B98A19F9A98969B9797949E9399989A948B868B8C808A8C858F8188
828C8C85847C807D817E817D827B7E7A747C807C7B7A747778747A787678778077766C7C
776F75706D75706C6F7271726D6F6E746D7078746D6D6B6B706E696A6A686A6C6268706F
6B666A6A69626967666D686C676566656665626C68666467606564635F6263666265655F
675D5E625A5D5E59
60606463646263645C5F6468676B65666A656769626D6A6B696E6969646B696264686E72
66676A64666D646C746866706C746B6F7074676D6C6E6C6A6E736A6C6C71776D6E6E7178
6F6D70757478796E73697E7576717772757975787A777B74818280798279787C767C7B87
827D7F8283898485868584888787888D8A8D928C918A91948F938998909A9A94A0928D9A
94999AA1A2A19DA2A89CA8ABADA8ABAEACA6ACB0B0B8B3B5B9B8B6BDC3C4C5BCCBC9C4C9
CBCDD0D1D8D8D5DBDEDDE0E7DDE9EBF0F2FEFFFDF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6FBFD
EFEDEBE9E8DDD9E2DADCD8D7CBD1CABFCCC4C7BDC8BAC1BBBCB6C0B7BCB3B5AFADACAFB3
A2A8A9A59A9C97A39D9AA4979699949D8F95928D9A9797939390918F918F85928A818688
8386868482787B7E817C7E78807D85817D7A807D7E777A797376827879737C727873777E
776C6F6E6F6B7373736C706B707275696C7072776D6D6C6D6F6F726C686A6E6E6E76706F
6865696D6769686562616364646866696767646A6B6065646762675E62615A615E5C6164
5E6C64515B685E5D
6763656563606465636262685F6161695E62647068646C696E6B6E65666F6E656163726F
666B686A66676568676C6D6E726C6A696E686F6967726C6F746C6B6F6D6D6D6D6F747669
7073746D7374716C76787571797672747C79797E78776E76788380827D7F7A7D80828081
7D89847F83847F887F89878687838A8486848B8E918F94988C8E96959292948E9A97989C
9A999C989B999B9CA2A2A4AEABABAEA9ACABAEB2B0B3B4B0ACC0BCB2C3CCC5C1C1C9CACC
CFCED6D1D8D5D5DADAE5DFE4E7EAECEDF5F0FCF8FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF2FC
F0F3EBEFDAE5D5DDD9D9D7D5D3CEC8CCCDC9C6BCC8B7B9BAB9BCB4B9ADAFAAADB5ADACA1
A0A8ABA1A6A7A0A396989D9D9598909D8B9891928F8F918C8C8293868F8A8A87858A8088
8383887F7F7D7D887D8181858379817D777D77807478757A7A747874737678766D776D6F
6C79706F6F70716F726E6D6F74757878717071726F6C6D6B696D6E68696F696F736E6B66
6E676B676A6B6A65686D6E6665696B66656965675F606366666A646D60665F6365696961
5C5F615C5C605964
635C65666361686561666A6866676C6769646468756B6B6D6F6962656669656A676A6469
6B6F72686767686A626A6A6E706B6F63696A646C656A6D72736C6E716E70736C76707174
6D6F757177757875756D76787D787E7270707F767F7D7583758178847B81737D78807E7E
847E84837F7F8389848C878E8881878285888E8C8E948D8E9194959998979B9E99919195
949C99A19E9C98A1A0A5A3A89E9FB2ABB1ACABACABB3B6ABB6B7B2BAC0C2BDBAC5C5C7C9
C8CACCCFCDD4D5D7D7DCDDE7E8F0E2F2EEF2F6FEF7FFFFFFFCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5F9FCF5F3F8
EDEEE3EBE4DDDADDD7D8D3CBD7C6C5D1C3C0B8BCC5C2C1BDB3B6B8B8AAA8B0B1ABA5ACAA
A9A7A6A1A0A79C9C9599959A96959090909A8F91978F918F908E8D8A8F90888488838A93
8D83888582838280838183818076797977787A7A7B7977737B746F6F7673746F6F71736E
796B6D726F71756D766B7479726E6E756E6E72726A7571686A6E747571666A6F736E6967
71706365666A61616468696A67656961666E636664676B5D67616B6B61655E6161606266
5D60655B5E5A5C5A
67655F6066645E5F636B67626469686766666C6C68686E6A67666E676D64666F69676A68
636F6D6D65666A686A6B696C6D736C72696A6A6A6B6E7275696F6E6F6E6C796F71766B6F
73766E78747B7372777676797870726F79737B777A7C7F7878777A797E7F777B827C807A
7F847B7886867C8C8587848487868F8382898D878C8D928D958E989899999B95959B999B
979899999A969B9EA59C9B9BA9A0A7A5ACB1B7B1AFA8B5B5B4BCB7B8B6BEBEC0C7C8C2C5
BAD1D6D4CBD2D0D7DFE2DDE7E1E6EBE2E8F2F4F7F1F6FDFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFF4FAFAF6F1F1
EDE7E5E3DDE2DDDBD5D9D7D0C0CFCBC7C8CAC2C1C0C3B6BBBABEB7B8B6B1A9AEA8AFADA8
A5A8A19E979FA2A09B9C999F969C919D99999694928F8D8F8F8B8A8B7E848681867E888C
83858789857E7F7E7F807F7C7F807C777C767B7D76767C6F707C71797274746E77746C6C
7A7B6E707271757377706A6E736E6B6B716E706C716E726B6B726A67727373766E6A6974
6C6E6766636A676D6862646C676360626A66646862625E635F6262606566616264656165
6365605665616564
5B5B5F645E6267606968686F666D64646F67666D6D6E6A6B666865636665606265686568
6A6A6A6B6A6D636B746B6F6E6E6E6F6D6D696B6F6F73716F6C6071736E6E73746C6C7672
6B6E727170777772737870757670756F8183767D6C7E7D777A7F8380767573857F7B7E7E
7F83817C89837F7F7E8583898D8A88888B8A878588928E8D8B939393919994939E979A9A
9A9B929E9B9D9D959BA3A39EAAA8A4ABA7A8A7B3B29EB2AFAEB4B2B8BABCBBC0C7BEC0C0
C4CDD1D0CAD2DAD9DCDDDEDCDAEBE5ECEEEEEBFAF5F9FFFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBF2F0F4EA
E9E5E0E2E2DDDCDAD5DCCCCECDCAC9C9C7CABDBEB5B6C1BFBAB9B2B2ADADB8A8ACADA8A5
98A49EA4A2A1A1A19F9995969495959C8A91969198948E938F8B838D89878A867F878C85
87898686817A788582837980827F73747D7D7C7C7A75797B757C736A777A766D70787173
6B777271776D72716D6E796B706D6C6D6D6F696D6F71716A6C6A73696C6C726A6A6E6E6D
6C676C7268686C6866696863696967696961635D5F6268696A665F665D65646066615E5D
6462616663645C5E
5E6167656265666063656765696C6366656F67676768667170676B6D65636B63656A645F
68686665686F6B6D6B6C6E6E6B726C647070676A656D6D6C6A6C727569746C717B757370
6F716F736C7280776E6F75756E7A7C6E7B7D767B76797D7D7B7A807B7D7A818180827F81
7E837F7E8B81878780858B858B858B898A908D908C868688908C8E8C9792949090959996
989A93999AA4A49E9F9699A6A8A7A1A9A3A6AABDADB7B4B0B3B8B2BFC3C0BFBECAC3C1C1
C3C5D2CFCDD5CDD7D6D5E2E4E2E6ECECF7EBEAF3FCFFEEFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDEFF3F3F3EFF4
EBEAEADFD7E0DED9D6CEC9CBCFCDC6CACFC6C4C2BCC1C0BFBCB3B3AEAEB7B8B0A2A6A7AB
A0A3A0AAA5A69E9C98939A95969397978F9196949190908E909291848B858885848B8785
868382808284787E7E7E7B817E77757F757E7D797A727C717C6C747770747B7871767375
716F74726F71747375767572766D706E6F6F75716B75706A6564696B6B6C71656A6A6A6B
706E6763636A66636C6563606367656B61616564676065656D68636759666867615D6366
606165595B5F615D
61645E5F61656969636569656B695F67676A6D6C6C6D6F6A706566666C6D656B6C6D6A67
656B646D6768696A6B71706D696B6B6A6B726A6E6F7470726C707065716C6E736F726F75
72766F796F6B736D73777274767D6F777B7F76767A797C7B80777F7E777E817F7B777986
7F8180838B8F8A8384847E7C82898C8B9087878D89838B92898C8B95908E989592969A95
9C9A9AA39A9A9E969EA0A5A7A0ABAAABAEACB4AAACB3B3B3B2BBBEB7C3B9B1B8BEC2BFC9
CDCDCDCBD0D4DAD0D9D9DBDEE7E0ECECE2F0F4ECF3FAFDF6FFFFFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6FDF6F2FCEEEAED
E0E6E7DADDDCD6D8CCD4CFCBCAC8BFC2C6C0C4BEB6B7C2B2B4BAB2B9B5ADAFAEA6A3AAA8
A0A4A0A2A49BA29E9B989B9B949B999593928D95908B88899593898E8B8D8A8B88848A88
8184837E857B7D83807C7A8585837E7B7E787A787D7C757B74797B756F756E6F767C6F76
72716D746C72726D6A696F6C7169736B6F6F6C686A6D7066676E6F6F6C6C6D626B6D6D6B
6F6C6D69676860656E606669616566646B6760685E6462626567636D5F62625D68605A5E
62646661615C5A60
625B606868626363645C636863696A6166686768696B666A636B6D6966646A6764676966
66676C6B686F6F696A6D70656B6F67706E6D6A6B72726E6F6F6E6F666D726E7271757372
716D6E74727171726C7371737376777578837D767984707E7577797C77807E807D807D84
7B83837F83857B7F807F82858A83908884858F918E8E8D959092918B959C929490949698
A39F9B9B99A4A0A79F9E9CA5A3A0A5A9A9A4A8A7ADAEBDB2BBB3B0BCB2BAB5BCC4C6C1C9
C6C7CFD0C8CED5D6D4DEDAE2E7E9D9E0E8EEF0F7F1F3FFFBFEFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6FEF0F0EFECEFE5
E9DFE2E2DEDDDBD8CDD0CAC8C8C9C7C4C2C3C2C7BCB4B6B8B3B4B5B5AAAEA8ABA6A8A4A4
ADA39C9F9F9D9D999A9A979A988D919A9A9093938F8C9789928A8E8E87898C848A8A8583
7E818B86827B807F7C80887D777D727576767F7677797A797D7378786F766B736E6C7679
7372756A716E6F69716E6E6D6B7073716E6E6870716F69677168656A68616E6B6B6D6868
6E6C6A6263676265636C6967625F6066696768695C5E6A615C6564606462676164615E63
585D62645C5F6460
625F5D636062646461666365605E636465626E6B666B626D686C6B6F6C69626C65637069
696B6F68676E696C666E6D6A6C6C676A6D6D6D716C6B6A6B6F6B716B6D6C73736E717372
6D746B757874727674746F737A7778797A74787A777A78747A7D7E757D7E817A807F7F7F
7A7D8181898A847B8586878788878C8B888B8B8E898F8E968A95948D989896999294969D
9597919797A0A2A1A19E9EA99DA9A3A4A6A3A9ACACB8B1ACACB4B2B6B8B6BDBAB7BDC3C0
C6C8C5CCD0CCCBCFD2DAD9D9D9E5E3E7E3EFEAEDEFF1F8FCF9FAF7F7FEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4FBF5E9EEE6E6E6
DCE9E0DADBE2D7D7CED6D1C4D0C2CAC1B6C1B8BAB9B6B1B5BAB6ABA4AFA9B2B1A5A3A0A1
9F9BA1A29B9C9E9C9D979F959495969A8D949697908D908B918F8F8C838680818A8A8284
83898682818E847E7A857F7D7E7D7C7C7D7478757D757F767B7376727572716B7972717B
7571776A6379727772656C746D72696F716D6B6C6E6A636D6B73706C69696D726C696A6B
6867636E69696A5F675C666165676261626271626261665F5F576265606567605D605D63
605B5C6367625B61
666464636162666067635B696060666269615E656B656C69636A73636967636268656B66
6669646C6A666F686D6C5F716B6867726671726E75646E737571706970706F6F716D6C72
796D72766F737673756F77776F72747873777879777B7D7D7972797D7D7A777976858081
8184808087847C877D8284878B8A88888A818C89878D8F8F94908F99909A939995959493
9A999E92989A9F9BA29DA199A2A8A0A4A6A7ABAAA9B2ADB0BCB3B4B3B3B9B5BABDC0C4C4
C6C3C5CACFD2D5CAD6D3DDD0DCDCE3E3DEE8EDEFEBF2ECFAFFF7F8FAFAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFF6F4F7F7F6EFF4E4E5EF
D8E2DFDFE0D5D5CBCFCFC9C1C4C7C6C0BDBFC3B9B7BCB5B0B4B2B1ABB2AAA5A9A7AAB09D
A7A19F999FA1A19999909698948F938C918F8E949288918D8B8B8B8D8E908A8A8A828A7F
81828384887C7E8288837D7D77787D737773787B7C74786F7473707875767871726D7579
7175747473786E706E6D6D746B6C6E66746B706A6C706970706D6D676A6C6865696E6F68
6C6B666B5F666463636C596D68686466685E636963606167606263626464616661625D5F
62646465585E5F5D
66615C63686565635D66696265676C6A6568625D646B646B6769667065666867646A6C68
606B65626A6A6E6B676E6A6E6F6C67696D6B6E686B6A6C726F7367726A6F6A74706E6E6E
7676786D727379747572777C7276767B73747B7F787A80777A757A797F7F7D80807A7B81
7B817F7C85877B8580888888878686938E888D8F8B8B8986909395939B96998A93919194
9C95A19A989AA09B9BA19F9EA3A6A5A8ACAAAAA8ACA7ADACAAB1AEB4B6B8BDC3C2BEC1C5
CBCDC8C7C5CAC9D7DAD0D9D8DFDFE1DCE0DFDDECECF4EBF5F2FAF5FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFDFCFFF1ECF1F2E1E9E8E5
E0D8D7DBD9DCD0DAC6D8C4CDC8D4C8BEC3C0B6BAC2B4BBB3B3B1ABAEA2ACA6A2ADA7A9A4
A49B98A19DA39A969C909B99929299938F939093908D898C938D8B93948F7F8A85888683
828B878A81847E7F90807E77777C7A82817F7B76737276747E76736B76767B777874736D
7175706C73726B746A6D7571676B726B696A686D72716D636F676F67666F676D6D696464
6F6262686A636C696A67636566676B6761686B605C64696161645B5F696364645D625E64
625D5F6361605A5F
64645D6261636568655E6F6A665E656762676663646D6D646C69706468686A6B666F6D66
6A6F5D646B696F6A68726C6C6D636E7370696F6F68726969696E68726D7372706B70766F
797174757677737577777571797C817674727D787C757B7F7576827B817A828081887D84
868386858181797D7B848B83848488818F8A8A8886898F8E948693928C97959493949295
95999F9D969C95989C9AA7A2A9A3A3ABA7A5ACA7AAA8B7AEAFB2B4B8BABFB2BEC1C0BFBF
C2C8BBCBC4CBD2C7CED2D2D1D1DADFDFE7EBDEF6F3EEF0F7F2E9FBFDFFF7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFCFFFDF7F7F8F2EDF1F0E5E2E8E6
D6DAD6D3D3DCCED9D2D0D2C8C6C4BFC7BAB7B7B6B3B6B0B6B2B4A7B1A8A3A7A6ABA5A7A1
9E9E9C979F9D9B949A979B9897948B8F998F8B8D8C948E9795919185838887858A888484
878977807E8A857A7E7E7E79777B827D79777B7B7C797472797678776C74766F7B787677
6C7575736E6E72746A6A676E6F7074716B6B6B72626D6B6F696C6865726E666465606C67
6A7064626E666261606C616266656C65645966635C67605F5A696A6C5E5C636962615C6A
6462565D5C646565
655E67606764636261656A6B6D6666676460676C66626B686E696860686969686D646965
69666C62636D666B6A66656F6C6D726D65666B69696C68706A6F6E6E6A6775706A6E6D76
737472717477707980737877776D7A747A797273796D737A7B7E767975797B7D7E808279
857F7D84808485868384828287818C8083868D8589958F938C8E8F8E968B9999978D9995
988C9D949D9CA1969B9BA1A39FA0A5A9A4A2A4A7B1B2AEABB3B3B4B3B1B8C1C2BBB9C2C0
C1C5BFC7CBC6CECECFCCCED8D9DDE2DFE8DFEAEBF0EBE8F6F4EEFAFAFCF9FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFCF7FCF4EAF3EDF1E9E5E2E0DF
DFE1DDCFD7D4D3D0CBC8CABCC7BEC0B8BEBBB3BCB2B6ABB5ADB5B1A6AEB3ADAAA0A8A6A8
A1A29F9F9E969E989B97969B969299909393938E8B919191948E8F8C88858880838B8284
848781878781797F7A7C857D7B797D7D7F7C7A81807D76796E78797E777279727C74796E
787375736E70736D797771686C6C6D6C676D716E6C6B6E6F686867716C6A676A6C666068
6C656867686C6361636D666B6465676464665E6762655E5D5F626263665D6E6162676665
635A65675E5E6362
656560626065686067616864656264606366696A6569686B636C7168716B5C6E68656B6B
6E74666B6867686A6C66686F66626F6B7369716E746E726772736E7073717074746F6C6D
706E6E6C6E7375727578767475727972797478737571777D82817980827E7B88817B7F79
80877C8287898485868184878885898D898E8F93949292908A8B9094918E91959493938F
968E9D9D9C9D8F9B9DA2A1A1A3A3A2A2ABA3A3A9AFA3A8ACA9AAAEB0B6B5B9B8B6BCB7BC
C3C5C4C4C6C9C8C3C2CFCFD4D2D5DAD4E9DAE3DFE7E7F0F6F1F3F4FBF9FAFFFAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFBF8FAF5F5FBF5EBEDDEE5E6DFDC
D8D9DCCED1CCCECDCDC7C5C1C0BAB9C5BAB6B7B7B4B3B1AFB2B0A8B0B2B5AFA6A3A3A5A0
A8A1A19793999C939A9993959692948E8D8C91939194938B8B90908F8A8789887C777F7F
89847C7D7A807F877E7A837D73787E7774777376787B737E76757373777573767A6D7175
76746E706F726D716C726F6C6E6671696A6E686D67676D6D716B676D65686C69666F6E68
6B67606C6569696967686D636063656767656067606262635D645D61696165605F5F5D61
5E5D655762626566
625B63655C65606967626862625B6561675F666863646E6667696B656C6A63665F636B69
6D6A616F6A636D666B6A696D746E6A6C746C746B697070686D6F6C6E736C6A7472707271
6C6C6E6F787074747770777873777C75736F6F7B767977737B77757C7A737C7C787C797F
7C7F8289818285798887828884808788888C8D8A8D8F8991958F8B909894889291979497
969199929B9B9B9D9A999BA59EACA1ADA4A4A7A8A9AEA7B2ABAAB6B8B5B5B3BAB9BDB4BF
BFC0C2C5C1CBC8CFC9C9C5CCD5D2D7DADAE5D8E6EBE3EAEBF0ECEEF3FDFBFDFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6FAFCEEF3F2F5F6E1E9DDE1E0DFDE
DAE2D5D1DAD2CAC9CBC7BEC2C7C5BEB8BCBBB5B2B4B5B1B6B1AFACB2A7B8B7AAABA7A4A2
A89F9B999C97A09A949D9290959795978D8D8F948D8D94918C948785868A8C878386858C
847D7A817F7E837F7C7A7F7D7F83807D76747377767971716C7476757B777A6D74757772
7970786F756C6E6967716F6C69716C6F6A686B6B686F7068686C6D6B6A67636464696D68
686B6463696569696267686D6667636C68666A5C696262625A5E68686A5F5D6663635D63
5D62665F665A5C63
635C6168665C64615F63666D6563696661606165636660656A666968646A6C6168636E6C
68686A636B636D7066706B6B69666B6E6C72706F6B686D69696F737575716E6F746A706E
7370726F7176737870756F7278806C777671737B727B777D767A79797B7E7B82847F8184
8185837D767D8681848586837F8386858D8A908D8D8C9091D2DB918E978897929C899695
94939599939A9A9E979E99969F9D9DA1A5A0A9A7A4AAA4ABAFB5AFB5B7B7B5B5B9B4BDB8
B8C8C8C1C5C3C5C7C4CDCCD4CDDFD9D3E6E3E2DDE7EBE5E7F4E6EEF5F3F8F5FBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFBFFFEFAFCF0F4F9EBECE5E1E4DAE1DFDDD6
D1D2DAD2CCCCC7CAB8C0CEC1C1C2B8B6B5B6B2B5A9A6ADB1B2AAAAB8AEB0AEAEAAA5A5A9
A29DA79D97969D969798999895958F8E8E948D908E888B8A8B8E8B89828D898B83897F7E
807D818386797C80787878797F7B7E7F7A797275787671777173737173797A6D6F75767B
7A726E6C706D6D71717070676C686A706569696C6C726C726C696A6C6B6A696E6B666E68
6D6B6B6C6A6F6C6969685B6E6A61666866666267696B6061665F63636063626261606663
5C595B625A685E5F
606465645C6362666261606369606261656264675E6565676A6C626C65656466686D6C6C
6866686E6C6C6A6764656769676E686C6D656C6B68696B6F7071726E72706E7176707477
6D7071716D776F76727C746E7C767A7C7376777672747979717C7D7982807A8181828785
85808583857F7F7F7E82848286838B88828E98888C8C8783FF9C9986889A9C969595938F
989797949E8F9D94999F999E9A9EA7999BA6A79DA7B0ACB0AAAFADACB5ADB3B4BABFB9B4
BFC1BCC5C0C8C5C2CED3C8CADAD4D2D3DFD4E1DCE1E3EAEAE0E5EEEFEBFCFFFBF9FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFEF8F1F4EFEFEDE7EDEAE3E4DDDED5DDE1
DED5D6D2C9C4CBCCC9C0C6BFBCBEB6B4B6B3BAB4ACAFA5A9B0ADABADADABA7AEACA2A39D
A69AA2A19A979E999097908E8B948E998D95918A95908E8A8C8486858986858487828489
7E7B7D877B82807E7E8181877A7B7C80797F727779727279787571797A726F7B6F707575
72766C6E6F776F6D747572746A6F7268646C65666E66746C656F716B6C6D6E6F676A6C6B
6866696465656C5F6E676A6163656A6B6A656268676360656664675F5F625C6361646762
6460636659625B67
656458605B63606C616268646468606A6A66676A65606A61636864696E607065726B6767
72726C68696C696B6D6B686A6F6C6C686A71657470756C7667686D6C6C696E776F707B6D
716C716F6F7872716E756C7777747475787779757A747778777E767578867B787C7A7E80
80807C7F7E7E80818B818E898487838589867F87838A898E95918D928B909C969694938F
9594A294979DA49A96999AA4A1A299A49FA99FA3ABA9B0AB9EA7B3B6B9B6B7B4B2B3BABE
B4B2C4C9BEC5C1CDC2C1CACED0D4D9DCD5E4E1DEE2DFE6ECECF1E7F3F6ECF3FDF8F9FAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFAF8F9EFFCEAE7EFE5E3E6E5E0DBD9DAD1D0
D4CED1D8CDC7C4CEC5BCBEBCBFBBB9BCB3B6B7B8B7B3AFB9AAAFB2A5ACAEA7A0A2A1A6A1
9E9D9F969A949B9F919294878E91868F928C8C8F8E8F8D87848883898982848A7F827E7F
89867D8683867A7D7F85827E7E847574817F79787477767C74766F70776D7E726E766A71
7A76796D776A706A757175706C6C6F68736D686A716D676772706D67736169756B666969
6B6167676A6B646564676767626A67646766676861605F62695C636362645F6463616765
69606461615C5C5E
6261625E6B61646763606B68686769696764646B61685C66656869686C686E666967656C
6673696A6B6E696D6B71696A6B736D716D6E6E666E6A6C6A6A6A6A6F6D6870736D6C7670
6F70717A6F716F72747372797572757578777679766F737478757D7B7D767581797F8080
7B7D87837D838585888483868480908A82928388908F888C8A8D8C9393938D908C968C92
969197909A92918F999E99A0A29D9A9EA0ABAAA7ABACABACA8B1B2ACAEAFB0AAB2B3B8BD
B2B2BBB9C0CAD0BCC8C9CDD0D6D3D8D4D7E0DADEDAE1E6E1E5E4E6E7E5E9F3F4EBF8FFF7
FFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF9FFFDF3F1F2ECF2FDE5E6E4D9DDE6E3D9DADED7DE
D1D8C6C7CBC5C7C3C2C3BFC3C1B5B7BAB1B4B6B0B0ACADB1A8B1A8A7A6ACA5A69DA89FA2
A2949A968E9396949890949597988B92928D8A908C8B8C838A8D88878F858D868C7D8585
87827D85837E7C847D7D737D7A7D84777681786E727E7377797577787275757472756F6F
706B69666C7171766D707378706F6D706E6F6A6A6F726C69716969696E685E6A646B6B61
71686662666D676A676765666466605F67656C6263635F676664645E60626568606B665F
60635D5F605C6061
685C6262645E5E615A5E656161616967656765676D5F63655E6167656C656A6C66636C64
676A666E69696B69706D696A6A6C6F6F71696E736F6A726B69737175756B6D7076747375
6B6D6C72716F707076787578757373767A757C7871757E7D767D77807E7A78827A807B81
817E7F7D7F867A8781818987878B8C8A8C85869085898B85918A898D94928E9595968C94
918F9393949A9B9A9C9B9AA2A0A5A9A2A29EA1A3A3A4A3ABAAA8B6ADB5B3AEB5B1BBB5B3
B6C3C0BABEC6C5C6C7C8CACACDD5D3DAD5D9E0DAE4DBE1DFE3ECE7EAF1EDF3EDEBF6FCFF
F6F8FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFFF3F5FAF8F9EDE5F1EFDED8DEE1E2E2DBD6D5D4D4
C7D4C9C9D1C7BEBFC4C1C3BEB9B0B8B5BEBDB6B3ADB3B4AEABA4A6A4A6A39D9DA5A19C9E
9C9595969796999691969592888C8D939393908F878B8987838D7F838484847F77868783
81837E7C847D7F80768279807875747A7C7B737673747A787C73797D78727277746C7672
6F6F7277766D706C756F72716C74686765696E6D6C6C6A6C6570646F6B6A616568686D5F
636B6168646B67636365606C666A6B676D616360656064646763635C595F676356676465
5E5A625F5C5D645F
6261675D696464685F656062635F64696E66695A64635F6967626A69636660626B676B67
696D6B69686C686B706A676F6D6766726E70736B6C6C706D67686B6A6E69756C726E6B72
7075706E6E6F716E7472736D707076717573727B7A7C787C7D7D7D75727D7A7B7A78827E
877D7E7F7F83837F858586828185828787848985908B888D8C8A8D978F94939599929798
9997999F96999B949B9BA493A099979BA0A2A69EAAA6A8A9A7ADAEAEAAA5A9B0AFB6BBBE
C1B1B2B7BEC4BECCCDC6CDCAC6D8D6D1D7D0D5D8D8E0DFDAE0E9EEEBE9EEF1ECEBF2EBF0
F8FFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8FFFBFDFDEEF0F5F2EBE3EEE6E2E2DDD9E3DBDBCFD4D7D7
CECBCFC5C8C7CCBFC2BFBCBABBC1B9B8B7B9BCB3B8B1B2B0ADA1A3A79DA4A49BA3A59D9D
9B9B9F9D999A96A2949A979390988B8B92878C9491868489878B858485888D8981838284
7E8082827D7A7D7F7F7A7C757B7C797F737D7172737D7C747E717B7B737575757170706F
746B736E7A6D736E6F71716B726F7164676E666D6D686C6F7368666368646F66656B6268
666A64626A6A6A626D6467676061686261605F6565656660655E5C61606A63625C625B6A
5E6A5E595E556157
5F5E6861635C646965675C655F656D625C686C5F66675F66686368686B68666567686665
636B6E686E6869726C72716A646B6D706B676C6C7066686F746C76766E6B726E706B726C
6F6D7379726E736F71737974737E73747378707A7D79798075797D7882837E767B7B817F
7D7E7E88868181857A898882818A8A878F8585879287918A8E8B8B8D9191929092939197
949A9E92969D90959A9A98A1949EA6A1A0A7A7ADABAAA0ACACA9ABB3ACB1A9AAB5B3B4BB
B5B7B4B6BAC3BCCAC5C8C6C6CDD0D3D0D4CED0D9D9DBD4EAE7E7E9EBE7E5F6FCECF5F1F2
F9FEF7FCFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFCFFF3FDF5F3F7F0ECF5EBEAECE7E1E6D9DDE0D8D6E1DBD6D3D3
D1CACDCEC8C0C3C5BDBDBBBBB7B7BEB2A8AEB4AFB2B7B5A6AFACA5A99FA397AC999E9C9E
94A098989A949593938E8E96898E9193898D91888C8D828F8A898D8B858282848289897E
7E82817D877E827C7A7B797C777C797879757A7C7779737A797977736D72747072696974
737072696F737374796E6A746A6B726B5F6D686B736967696271656C6A646E696D6B6161
676C6B6461666766676A6B666760676762636361626561676564625C6562645F60616663
5E5F5E625F5D625D
6268635E6166696468666262625E616B6165616A6961626566636A686A6C6B666A65656F
6C6D6C636D6D646C626F706A706D6B6B6C76646B6F6B686C75706C706E71716C7A757275
6D71756E6F6F726F756E6F72736F756D736F7E7C737276797E72797B7C7D76857B7F7E7E
767F838082828C7C808682888E88898087868C8387868C8F92898C9292928C8689929994
938F969A8F97989A99A0919797A09CA69B99A8969FA0ADB0B1ACADA9AEA9AAADB5B9BAAD
B8BAC1BDC1C2C3C3BCC2CDC9C8CBCBD4D1D4CBD1D6DDCEE5E7E3E5E4E9F0EAE5EFF5F2F1
F4F7FBF9FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFFFFFEFEF4F0F6F3EEECEDEAE5E1E9EADDDFE4E5DBCFD4D1CFD7CF
CBC2CAC8C8BFBFC3C6BCC1B1B1B7B7BBAFB2B7AAB0B0ACA7AC9EA6A9A39BA69A9F9E999C
A49698919793938D8B93978D94918F968B9191918F7E828A888D85848A878986837D8387
7983837B7A7C7C807F7F757978807A787E7179777479736D776F757C727573726C6F7675
6E6E6C726C6B6C696E6F6E696B6A647064696D646E696B69676A6668676B656465686D69
706C68656C6468606B6A6762655F60606B5A635F676162636861606462665E6662645F62
616161665F5E5B62
63645A5B5E616268695F5A64655D6864706167645E646968606B62656962686A6A6E646B
64666A69646B6A6A707265696C68656769756B696A6B6E6D69706D6670707070756C6E71
7270727472746B71766E6C6D7A756F7074757C7A7B767C737D7975777B7A817F7C7D817E
817F7E8684798486837F7B84838985877D818C898B7D8C9391938A948F8E95968F968F92
958E9891979495999297999599A19EA7A1A1A3A3A2ABA3AAAAAAACAEA9A5AAAFB0AEB6BA
BABDBBC3BDBEBAC5C4C8C5C6C2C5CBD6C4D0CCD3CFDADBD3E0D7E1E1ECE3EDE4EFF1ECEE
F0E2EFF9FEFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFCFFF3FAFFF9F8FDF5EEEFEDEDDCEAE0E0E1DBE2D4DAD6D8C9CFCCD0D5
CCCBC2C3BFBBBFC0BDBEB5B7B7B1BDBABAB8B0AAAEAFB4B1A3AAA1A29FAAA09B9B9F9F94
99999998988D919A908F94908A8C91888B8C858B89808A8B8785898A8485848387857D7D
7B7C7B80857D78797F78817A82737B737A7A797476767773787B756F6F72736C7067716B
6F76656A696C6D74736B6C68686B666B706F6570686A6E6768676465666669676E706267
6B5D66686B63686362626463656666686A6360645E65605B6460635C6766655D6766645F
615E5E625A5D5F58
63616060685F66686465625F6B6965645F6862656A6B62646C62666966696B676F6D6F6F
75706C6B65656A6D6C706C696E69656D666E71686C6B686D6A6D687069716E7070696E6B
6C6F78767769717370707570727C7C716B797975757C75727B6D7D767A79787E797A8582
80827B89817D7E8382867D7F8483878D85898488868B8E8A92858A8E8C9295908D959291
9899939E8F94979895929C9C97999FA4A4A1A19EA6A6A6A3A6A7A3ADA7A7A9B3B4B9B3B5
B3B8BBB8B4B9BFB6BBC4C6CAC9C8CFC6C9D2CBD4D3DDD9DAD2DDE1E7E5E9E1EAE3E5F2F2
E8F8F9F7FFF7F4FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEF4FFF4ECF0EFEFF4E3EDF0EAEBE5E3DADEDAD6CDDBD9D2D7C5C4D0C5
CFC9C6C6C1BAC4BFC3C0B7B4B9B1BBB4B4AEABA5A7A7AAA3A6A3A3A59E9F9E9B9D99A099
959B9F9B969192928C939492878C898688898C8A898B83848084838A8A898382807F7E7F
787E868287807C7D7B767E81827B79757A7D7577797B6D7475716E6E71697C6F6E6E716F
6C726C7370696E6B6E6563676A676A66736B6E6E6E6C6A6566626C6769676A65636C6C5F
6867656C656265685F62676B6762636564616361675F5D61656762665F64655B64635F63
645E5D626C585861
655D61616064636660606562605B6362686865646864646565666565696B6C6E6A686D6B
6B6B6E6A646A686E6D6D686C6B6B6D696B706A71716C6B68726F6D72706E6F6E6C6E716E
6C6F6F6C6B6F6F7170736C6B7D6F74757576707A7A777879797D7C7A7A7E7E79827C7E7D
8283857F8187887D80858380858781808C81858E858485888B8889908B9092908E929193
909791999B9A9C939D949A969C939C9D9AA79BA5A9A7A7A6ACA8A9A8B0B0ADA9ABB0B5BC
C1B9BEBBB7C0BBC0B7CCCBC3C3CAC9CDD4D3D4D5D3D5E0DDDED9E1DFE4E5E0E1DFEFEAF5
F5F2EDF3F5F2FDF4F9FBFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFDFCFFF4F4FFF1F5EEF0EEEEEEECE9EEDEE1DAE6DEDADADDDED5D3DAD0D1CAD3CDCB
CCD4CABEC5BAC7BEBEB9C2B1B5BCB4B8AFABA8A0A8A79FA5ABA4A79A95A1A1A09C9F9E97
A697969A99969095948990939A8E928A858E8D8F8F87868B84838783837F8A827E848680
837D7B797F7A807E867A7D757A817D7E7375797A6E707973796D6C74716E666F73746B6F
6E746B6D6D7467706A67696B736C6D6D7068716A686A6D636C686B626E636862636B5C6E
656564676669666B67646064636463586A636364625D6C5F64625A6067616561645D6161
635E6562625E5A63
5A566262636362636369656561606964626864645A65656E65626F6E6B6B686E6A716665
636067656B6D61686F6E6665706D6C6B6B6C666B697172727269717074766D706E73746D
716D7177766C756F716C726E7F776E747678717C7578787378787C79777A7B787A7C827B
84817D7D85887C847D838486849789878F898983868987808F8E8C8A918F91999596988F
8896999298959BA4919D9C93A19A999C9B9D9F9FABA4AFAAA5A9ADA3ACAEA8AAB6A9B5B3
B5B5BAB6B3B7C1C4B7BEC2CACAC2C2CCC7CFCFCECFD4D6DBD3D9D8D7DDDCE2DEE3E5E6E3
ECEBEEF1F4F9F6F7F6F5FDF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF5F3F9F6FCF2F4F1F1ECE7F1EAE4E5E9E0D8DDD7DAD8DAD1DDC6C7CFCAD0CBC9
C4CFC1C4B8BFBCC2B8C4B3B2B3B3BCB1B1A3A8A9A5A5A9A0A495A6A9A69CA0A2A4969697
9C94929C9A9B91958E9487898C8A8D90878F8E87878A869286857883877B808A8382797D
7A837A807C777E7D7B757879807D7D757676737675777970786F766E71736B766C6E736E
6E6C656A6B6E6D696967706C6A63696A6A6E736667666C646E657162646069646564636E
666B645D696C666C685F666A63645D606863616466666360676761615E5B685C60616063
615F5E65565C5B5C
635B6B5F58606563696260626C6669626C6B66646B65656B6866656864626C716B6A6A66
676A6961666566676A666F68726E676A6E6C70666A72746D677068746E71706C6F6D7177
6B696F717177756F7673716F737B7577717A787776777C7371777C7F797A767C7B7B797B
847C75857F7B847E7B817B838E8A8A8C878B82898E858785888A838F8B918B908B8D8F96
95889091918E9C979696999B989F9E9D99A49CA4AA9E9F9FA2A8A7AAA7AAA7A7AAADAEAB
B9B0B6B3B9B6BDBBC0BAC4C3C6CBCBCAC5C6DACECFD6D7CEE0DAD8DCE0D3EAE2E0E9E9E8
EBECECECEFFAF8F9F3FFF9F9FFFFF9FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6FFFF
FFFFFFFDFEFFFBF1F0F1ECF0F8EBEAE7DCDFE4E7E4DDDDE4D4DBD4D0CBD6CDD2D2CCC3C2
C1CDC1C2BFBEB9C5B9B2B2B2B1AEB0B1B1A6A7ACA8A99DA59EA4A19EA39C9F9E9F999D92
9C9398958E8B8F8F938E948C999088878B858885858287838885858D8A84868681808081
847F7A797782777A837B77818076827E7978786E746B787D727674766F6F706B6B6E7272
71666E6F6B73716B6D6D6C706B666A66656B7475726A696D6A686B686B6B68696A60696B
656867606C66676F6A6C626466636D656663665D675A5F68606864615E60605E63665F60
5D656464615E635E
60625D68696267695F6160606560646666636A675F6662656568666B6A6872636A686E64
65666970616A676C68686C70726A6A6B6A706A6F676B6C6D70666F6F706C6F6D6F6E696E
71726F6B73706E786E7172756E6B727C6F7276717A787E6E777B7C73807D827F787F7A7F
7F7D837B7C807E86838885888B8A89858C86838E89878A878A8586948A918D928B928C89
928F919793959CA39A9396979CA59FA0999B9EA09D9FA9A5A2A6ABAAA5AFB2B3AAB0AAAC
B1B1B0ADB7BAB6BAC1B7C5BDC2C3C3C4C8CBC8D4DBD8D4D7E1D9DDD4D8E1DDDCEBDADCEB
D8E5E3EEF1EDE5F2F6F3F8F7F7FFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFF
F9FAF6FFFBF5ECF5EBF2F7F0ECE8E7E5DFD3DDD5DED9E1D1D9D3D0D9CCD4C9CECBD4C9C2
C3C0C2C2C6BEBAB4B3B9B9B1ADB7B6B1AEAFA4A6A8A2A1A5A4AB9FA6A0A0A3A39D9A9D9A
989793989895939091968F90968D86858B858C8789898B8D89878B847F7E857C7C7D808B
81837E82838277827C7B787A8083747C7A737377787A8078717573746F746D6F6D697473
6D6A6D6C63706D6C6B647070676E6B696C6D6C68686E636969676A6B6565656A62646A67
6568696A64646865676B626568656661696562626161665F60606269615B646163635B5D
675E5E635E5D595F
5D5B5F6464666965606564606368686567646668676A67666565656B636E6663676C6960
6B65716F6A666E66676D6E7166676C6B6965756C666673766C6C717965656B69736B7072
736C6F686D6C6E6F76726F756F7B767C7680747975757E7C6A747A757978737F747B7983
7B7A807A81818982818888858C888887888B838881848D8A898E8A8E8E8C948E92909391
8E8E94978996909398959E9DA2A3989A9E9FA2A6A4A6A0A7A4A1A6ACABA4AEACA5A5AEAC
B3B2B0B3B0B8BBBCB8BCBDC1C4C6C4C9C8C9CED5D3D0D3D7D9D5D0D4D1DEDDE9E6DCE4EB
E1E7E7EDE3F1EEF7F7F3F5FAF4F9FAFBFEFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFFFAFFF9FFFFFFFFFC
F2F9F9F6F6EFF7EBF3EDEFE8E4E7E0DFE6DFD4DCDFD6D8CBDBD3CFCFD3DBCFCFC3BFC4C8
C6C4C3BFB9BDB9B4B5BFACAEAFB1B0AEA6A8AAA7ACA9A3A59B9EA2A29E9D9D9B999B9794
969390989993959391958C878E8A908A85888A87888B838A88848884888182867F7F7D7B
787C837C7B827A7F75817B7A7E7D7872747978787B707A70717077727476776B6E686E71
6C6E696F6D73716A66646C68636A68686F6D6A6D716B6A6766666A646C6862656465646A
6D6562645F636666626A67655C6669675E666564606366615E6167655C5E655B62586C60
5D6161646561555D
63605E615F6369675B626068656A5B6A60615D64676461616762616B6667656D6F676C6D
6968686A666863666F6869696768677271696A636F69706C7674646F70646D7573706F70
72746E6F6E6E74736C736A6E7E7677767074727772797874747971747F787C7C7A7B7F7D
817B7E7E7E7E7A7F828580828B89858A8585878987868A8F837F8C8D8688838E8C90958F
888D8F8D8A96918F9F979B989C9D98A0A3A49FA09A9E9D9EA19F9FA5ADA3A6ABADAFA8B2
B0ABB0AEB7BCAEBCC4B8C1C5C2BEC7C8CDCBC2C9C5C8C6D4D1CCD6DAD2DDD6DCDEDCDDE7
E3F0E7E6E7F1E1F2EEF2EEEEEEF8FDFFFFFEFFFCFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFCFFFFFFFFFFF9EFF6F6F6
F0FCEEF4F2EEE9EAEEEDE8E8E9E2E4DCDADADCD2D9D6D0DED5D3D2CCC6D3CCCDC7C9CACB
C6BFBFB9BCBCB9B5B5B6B2B7B2B7B2AEA7ABA7A8AAA2ADA5AAA2A09DA29F9B97969D949A
979D8F93949896958C949490928B898F8C8893888689828C7E7A7C8282837B76807E877A
7B887F8379827879797E7C81797C797F7C8377766D7974767577716C716B6E6F756D7471
6B6B74706D6E706D696A656D6B6E6971726D63636B6E6B65676D68656A6F6B67605D646A
6265656D66655F5A645D5F646364606066615E5A69676563665F64665D5B5F615F61635F
655A675D655E6564
6A5B6368646663616768606762636A5E605E6364676B66656C6566686B61676B676A686B
6A626261696B6368616C6D686C6C756B6D6570696B6B696B6E716D74706B6B6E6B6B696E
6E6E6A716E757470776A78787775797674776F7A77787978767974757B747C7D7B80777E
7F7B7B86808186807A84838A8284858A8A8785888882888993898691868F858B868F8C8E
928F9396979293989B9B979C99A09DA09B9FA39AA0A4A19DA0A3A7A6AEA9A6A4A6ACB5B2
AEAFB6B0B7B8B8B7C1BEB8B7BFC4BCC2C6C8C7C8C6CDCDCBD4C7D8D3CDDBD8CDE3DDE5DD
E7E1E8E6E3EEE8EBEBEDEDEDF0EFEFF5FAF3FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF8FFFFFFFFFEFFFFFFFFFFFFFFFFFDFDFFFFFCFEFDF6FFFFF4F2F6F8F4F8
F5F1EDECF5ECEAEDE8E5E8E3E3DCDDD5D5D9D5D4CBDBD0CECBCCD3C6D1CDC8BBC7C1C1CA
C4BFB4BBBFB9B8C0B3B4B2B4AEABAFAEA1A7A6ABA5A5A2A9A5A8A3969BA099A096A09593
9C919D938E929A8B8D8E8F8A8D8D8B898289878A8786848B87828480777E837D807B8082
8282817E7C7C787579767778787A7E747A7C777C7B7A7B6E736C7C736D7475766E736D73
746E6F71716F646B68676E6A62626A6E6F6C65656C696E646668626267695F6B67686867
666A69655F696564646063656765606767646168685F5E6A5D645E606162615B625D6561
655C626463616262
6761636064615F676762646D6A665A62676B6362666173646A6B666E6A6969616767656E
696C616A65656D6B626A656B696A706F666868646A6E64656F6B686B676B6F6E70726F71
716C736F6B6C74756D77737D717277797378747274777D7678777C787472757482757D7D
7A807B7E80827E8481887E7E81868983887F85828B7E838A8486867F8D8F928F8E8C8F89
9092978E9193999598989D9A979A949E9C9BA6A8A3A49EB2A4A8A6A5A7AEABA4A9AEABB9
A2B1B5AEB2BFB6B4BFBABEBFBFBABEC8BCC6CDBCC8C7C2CBC8D3CDCED6CED1E1DCD7DFDE
E0E5E8E3E3EBEAE9EDF4EAE7EDF0EBF6F5FBFBFBFFFFFCFFFFFFFDFFFFFFFFFFFBFFFFFF
FFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFBFFFBFFFFFFFCF4FEFFFAFBFEF9FEFFF0F8F1F7
E7F3F0E6E2ECF0E6EAE6E7E6E4E9E1E3E0D2DACFD4D1C8D4CFCEC6C7C5C3BDC8C9C4C3BD
BDC0BEBABFB5BCB2B1B2AAA9B7ACACA5A5AAACA4A99FA7A3A2A19A9B9BA39AA095999D9B
919B8E9199939090978D8B8E8C85898991928B868386858C858488858482828980808080
818575747B7E7974827F747F797F757A767377776D736D707876726C6F74716F6A72706C
6E6A6D6E706D696C6E6A6D6967676D6B6C626F6E6D696A68696C63676564636667676B63
65656462626261696D66666467655F62625F63666165655B625D6567675D63615E646460
645F605D5A5D645F
64585F645D5F6762686764615E6368625F626969666D616169726C6668666C696F6E6764
676565666267776B66686A66696A6762726E6E726B6C666F726C736F6B6D6D68706E706C
6E7669636F7770767176716D8170757471767B7E7775737D7774737577737B74807B7978
7B7C7C75767A7D76807D84807F857D858585838881828A888C8A858C8E9385928B8D9297
95909A918B95938E9C929F999A979A9A9AA4A99A9D9D9E9BA1AD9FA8A7A7A8A0A9A5B2AE
AEADB1B4B2B9B0BCB8B9B4B6C1BAB9BCC2C6BFC4C6C9C7C3D6CBCBCED2D3D1D7DAD7E4DA
E9EAE3DEE5E9E2E3E4E6DEEAEBEAE9E9F3F5EFF9FBF7FFFFFFFFFFFFFFFFFFFBFEFFFBFF
FDFBF8FFFBFFFEFFFFFFFFFFFFFFFFFFFFFFFAFEFDFFFAF9FEEDF6FCF4F5F7F5F7F2F3F0
F1F1EDE1EEE1E4EBE8E2DDDDDAE0D8D7DCD6D7D7D2C6C7C9C5C8CCD0CCBDC3C3BCC2BEBF
BBBEBBC6BAB8B6ADB4ADB8B1AEB0B1A6A6ABA7A8AAA7A79F9E99989B9B9E9D9B979D8F9B
96988D9393948E8F8E8B958E8F878C8D87848C848B857D787F857F7C8387837F82837D83
7E80827D797E7B807A7E79797C74767B77766F73706E7470756E7572756F7B676E6E6E6A
7069716B6E7365696C6D6767646C696C6C716B656E686C62686C6D6C6B656661625F7062
6E6E6061696168666264685E63676962636266666369645F615E67635B5E676361655F68
5E675A5D61605C5D
6662606262685E62636962646C66696166656465636D69686C6B69636767676867606569
627364606C6E71646C68716A686D6C676B6D706F6E68686D726A6D6D6871686B6D706F74
6D646C6F766F776F6F767773717A757470747374727572787474736F777D727F7976727D
787E787B7C7F7F7D7F7D85828B877D8481837F858C8782878D88868C88908B918E8E9489
93918C8D95928C9294998F9F969C9699989A939CA2A2A69EA8A8A0AAA6AAAAAAA7A5ADB0
B1B6B1ABB4B1B6B9B4BCB6B5BDB9BCC0BFC0C1C1CDC9C6C9CBD2CDCDCBD2D4CDD9D3D3E7
E3E8E7E1DCD9DFE2E2E1E8E4E7E8F6F0EBF1F4EDF4F1F8FDFFFEFFFAFAF7FEF8F5F9F6FC
F9FDFFFFFFF7FFFEFCFFFEFFF7FFFFFFFDFCFEFBEFF9F9F0F5F0E3F3F5EBE3EEE8EBECEF
E5E3EDEEE3E8E5E1E0E6D6DCDDE3D7D7D9C9D0D0CCCECACBCCC6CAC0C5C1BBC2C1C1C2C3
B8BBC0BFBCB2ADB3B3ADADAFB6A7A1A6A8A3A6A3A2A6A4A29C9CA29CA29596969A9A8F94
9298928D9391908B908D928B8E8484888C87898387817F838D89827F818180818480847C
7D7B7D7D75807A7B7E7C7C787E737778796D79747472747A70716D747074756C7070736B
73736B6A6E6A6E726E6D686C676C67686A67676A68696B696B63686863626D656A6A6764
6F61656464666065645F645F66635D64626262666461665F5A6564656063616067646461
606266625F63605A
616164645D656160655C61665D646566666964646A65656862666871676863696268696A
656C67636F696568656C6B636367686B6768656A6D6C6A6C646F6D707271736C6866696A
6E696C76716D6E7972758076787070737572797C746F757A7A777B797E7C80797A787E7C
7B797E7F8280807A7C817E78817D827F7D8482868D837D80888887898D97869189898991
948F948F8F8C9594979A949696949F9391989A9CA0A6AC9DA7A1A69BA29E9FAAA6AAA8AB
ABB5A3ADAEB5B1B7BFB8BEB6BDB3BEBEC1C7C2BABAC1CAC8C1C2BECDCDD0CFCFDCDBE2DE
DCE3E7DDD9D9E4DFDEE7E0E4E4F0E8E8EBEFF5F4F2F3F5FDF9FFFFF5FFFBFFFAF2FDF9FD
F4EFFEF8F2F6FBF3FBF7FFFFFEF4FFF7F8FCF7F8F7F1F5F1EFFBE9EDF1E6ECEAF3F0EFE8
E6E6E6EFE0DBEBE2E4D9DADEDCD2D1DCDAD1D1CED1C8C1CBC9CACEC6B9BDCBC6B9C1B9C1
B8BBB6BCBFB3AEAEB6B2AEB6ADA7A6ABA6A7A6ACA2A5ABA5A5A6A09B9C969B9795969B92
918D8F93918A99968E908A8D8C8E8D8884888486838787857C7D86848084818181858181
7D817C78797D747579757673777D777278747275737475776E79747672736B6E7476796F
6E716A6D71636B73616A6D686C6C6566646C656A6A696C696A6A64666C65646C68656260
6465686166696A58606567605F615A645D69695F68606461615D655E645C655C57605D5C
67605F5B63625E60
665E675C626861666167636666676D646C6365666D666F6265656962606B6B6D6A62676B
63696A6A67676E71666E64666873696C656A676F6E66666B6D7764696F6E6F737169726A
6970707371787674757771716E787476756F777D7875737677757277767A7878807C7575
777D7A80818078837280887F8482848281857E81867E827F7F8A89888A888786898B8F96
8F8F978E978E9494958F999893939B9796A29F98A09EA1A39EA3A8AAA3A4A59DA6A2B4B1
A8ADB0B2ACB1B6B7B1BBC5C4BAB4AEB9C0C3B9BEC3C1BFC4C5BFCCC9C7CACECDD0CFDBDE
E5D8E0E1D5DBE2D7E2E2D9E2E5EBE9E8E9F1EAEDF0F4EFFDF0FFF8F5FCF8F1F1F8F3F3F9
FDF7F3F7F9EEEAFEFCF4F2F8F6FDFDECF1F7F9F3EEF2F0F2F2ECE6EFE6F2E5F0EBE0EDE1
DDE1EDDEE5E2E6DED5DCD3D8CAD5D1D6D1CAC8D3CFCDC3C8CCC4C5B9C5BDC2BEBAC0B8BF
C2C0BDB2B3B5B2B2AEABADA9AFA9A3A6A799A3A9A6A0A59DA09E9E999A9992A2959C948D
8F9E8F959089918C898D918590858A8587898B7E847F8B81848F787E7F8A807C7E798084
7E7C7D7B7A79747778777575797B7675726E777D6C76767A646A776E767974726E796A6D
7370706A646B68626E6E6A6872776B6B7068696570676C6D6866666C676565656A696A65
6164676762686666646A6464606067665D60625D62626361635B65615D6566595D66615E
5E5E625A5F5D595B
66606A61616569655F67606A5D6D606C66686A6666706762696C6965686C6B6A616B7068
686A726D71706867706D6E68726F6864686D6B6969696E686B646E6C6D6B696E6D666869
6F6B6E6D6D7670776F7B717174757674767A757975767480756D7679717B787D7875767E
737A75797A757A7B7C897C80797B827D817C74838484868C867E8D87888E89918C8B8790
8D948B8D8F938F908E919C9C9194959B9CA19EA79D99A29A9B9FA19FA59EA8AAADA2B0A9
ABA8AFAFA9BAADB7B4B4BBB2BAB9B4B1B8BFB7C3C2CDC6C5CACDD2CAC9C4D5D6D4C7D6E3
D2D4D7DADADADCDDE3DBE3DEE7E8E3DCE8DFE9F2EFECF3F0F6FAF3F1ECF3F1FEF3EEEDF2
F4F2F5F6F2EFEFF6ECEEF7F6F5F9EEFBF3EDF1F7FAF2F3EFEFE5ECE5E4E8F4DFECDCEEE4
E4E1E4DEE0DEDED4D5D6D5D3D9D6C7D1D1D1D1C6C6C3C8CBC6C6C3C8C2C2C0C4C0BBC0B8
B3BFB8B5B0B3B7B8ADABA7B3A8ACA1ACA5A096A29FA4A29F9E9F989C93A1979492929193
8D93929B9396908B92918A858E8D888C938F8A838B8C7E838A8A827C7F81807986818384
7F7C777E7682787D7A7979807B797A6F71736E7874726F71716B7067707A72756F706B70
73686872746E6C706F6A677164676A6669676E6861656A67706366686E60646A6D66695E
6466686A6868605C66666864616167606365666266625D605D5D67685D606363605A5D63
666260635C605C63
686060646464676468626167646B6A6265686560676F6F6961655F686065666771656964
656B6967676E6370676A6F686D696E6C68666A6E6C707071656F6E6B6E6F6A6764706768
6E697870686D70767577737D767473707273777877757D777C776D72777270747784757B
7C76757F817C7B817B7E7D7C83838584857F8685807C8889857D888D8989878A898A8E94
988D838893908F8D90919794958F9B9C9893A29E9E9EA1A39F9DA3A1A4A19AAAA6A0ABAE
AAAEABB9AEB1B6BCB9B4BCBAB0BAAEBBB4BDC2BAC3C2BFCBBCC6C9C5C5C7C7CCD2CDD1D9
D6DCD6D2D1D8DAD6E0DDE8E1ECE7DFDFE6E6E8E6E9E8EDEFF0F1EFE7EDEFECEEF6FDE8F4
EAF1E9EEEFE8F4F0EAF1F2F8EFF1F0F8EFEEF5F5EBECEAF0E8ECF3E3E1EAE4E8E4EDD7E5
E3E3E1E7D8E6E2D4DBDED5D2D3C9D1D5CABFC4CDCAC3D1C6CCBEC2C3BFC3B3BEBBB8B8B1
B3B3B6B9B7B3A8ACAEA9A7ACA19EA4A5A2AA97A6A3A5A49D96999A9C96929799919B9399
96948F96918E9890848B8E908C8C8D8B8E8D8682878F838383828480827C7E7E867B8281
827F7D7778768072777E7D787A757476717772726E7273716E70736A736C6A6E6E716669
71736F686E6B6A6D6D6C6C6A6566746B655F6E656C6E666A686D667265676A65645F6467
656A60685E60676263655E62616268626261635E5F66666163625E62606261636260595A
5D6566635E64575B
63656365636362645C625F676569636D6B65656764626B62666B616569656D686569686B
61606B6C6668606F6B646C676769646867676E6C6E6E646E6C6B6573746D6B6D6C676B71
71716E6A78757475776D737372706D6D777273717679787479757E767D7E7B78787A7980
777C837A797A827E7874807E7B8281848385857C81877F858A8386878489888B8D8A8892
94908C8A96959190979893939299939B98999C969C9F9EA09EA2A29DABA5A1A19DA8A9AE
A8ABACB0AFACB0B7B4C2BAB0BEB3BBB9BABCBEB3BCBBC3C0C2C7C8C4C4CBCAC5CCD1CED5
D5D0D5D6D5D0D8D8D8E0D8DCE3E8DEDCE1E7E2E3E5E7E8E7ECEBE5F7ECEBEBE5F0EBE7EC
E9EBEBEEF1F0E5F1EFECEDF0E3EEEEEEF4EEF3E6EEF2ECEBEDEDE0E0DCDCDDDFDFDFDFDC
DEE8E1D7E0D2CDE2D5DCD1D4D6CCD0CCD0CBC4C6C1BCC5C1BDC4C5B9C5BBBABABABCBEB5
B1AFAEB7B8B5ABB5A9ADAAABA9A8ABACA7A2A29B99A39899A49DA391959D989998988C8A
948E918F90968E928E838C8D8B8D8C85838B8C84858A8C81888188767D8A848282817A7E
7E7F7E75807779787A7E747C6F7F6D7770726E717679746D6A6E7B6F6B6A6B7571787166
6E69667265696763666D6A656C6D6B66706D696368656767696B6669656A68646C676A65
6C5E66636B61625F64686161605C655E675B6863675966615D61676061625D635F63605E
5B625F5F58645C61
656163666A685E656B60656368616A676368666B6C62666362646B626763646B69626367
5E6C6C5F686E65696C6C666C6664696D67626F6A66646D716B6F6B6C6E7370656C696773
7370686E70766A6F6B77787673717170756D7A75776C747375727277797377767D797E79
7780788578797C827E7A7D797D817C84837B868689838581898C868B8487878F8B8E868C
9A928F8E8C8A9490978E99949A979895969B9E9E9F98A29EA5A2A1A29AA5A49AA1A3A4AE
ABA4A7A6B3A6B0B4AFB4AFB4B8BAB8B4BEB7B5C0C1C6BFBBC7BEC4C4C4C3C8CAC9D2CBCF
CED2CFD0D1D6DAD4D0D8E2D3DEDDE4E2E2E3E4DFE1E4ECE8E0E8EAEAEBE4E2E5E8ECF4ED
E0E9DDF3EBE7E4ECE8E7E1E6EFE6EDECF1E5EBF0ECE7E7E8E0DBEAE2DAEAE4DFE6E1E3E3
E2DFDBD6DDDCDAD4D5D4D4CDD2C7CDC6CBC9CAC8C5C6C0C0C0C4BBB9C1B4B6BEB8BDB0B4
B5AEB1B6B3ADB1B0A8ACABA9AAA2A69C9A9B999EA396A097999C94979091908E9B8A9592
8F9690918A8D918A8B8D8F908C8E92858D8B7F878D84838A8388847C817C8A82837F8478
7677858279807A777A7374727B77747372737278776C6F7071737168786E6F7571677270
726F696C696A6F6D686C62686C646A66696A68716068636E646D6668686E5F696C626568
666762666163616D60676A5C63636165616164656262655F62656463666762615C675C6D
5D6261565C5C625E
625F5A61626461676869616068696D69606A696667666C6966646D6D6E6067696E656969
6B7066696B676D646E6764656F656A6B68676A70716D6C716A70756B7A6D6E6A72756E71
747172777276736E7E75746C747471736F746F7376787375757C7674727A7A747B77747C
727D777F78757E7A79817C7D8378818480828481868D86808489888B88838A8B89978C8B
888F9796868E9594908C98988891949495948E9F9B9A9A9D989E9AA1A1A6A0A2A69FA3AE
B2ACABB1ADAAAFB3B3B5B7B7B4B9B8BAC1B7B7C3C5BFB8B8BAC2BFBCC1B9C7C9C7C2CACB
CFD1CAC7CCCDCBCDCEDCD0D5DDD6E2E0DED7D6E2DCE4EBE4E2E2E3E6E7E7E7E5E5E6ECEF
E1E3E4DCECE8E7EDE9EFE5E5E5E6E9E7E6EBE7E4E9E3E2E8ECE3DEEADBDEE3D4DEDED7DF
E0D5D8D4D0DAD5D3CBC1CFCDCFCEC7C9CAC5C9CCC4C8C1BABDBBBDB8BBBCB6B8B9B6B0B1
AEB1B1ACADABACADB0A79EADA8AEA39EA3A4A1A8A29B9E9DA3949598969393998F918C90
8B839288898D898E8B858D8B8E928F868D8B8186858785807A8682848585797A80837E7F
77807A717E797B7C767E746F7777736F73726F74756A6F6F726F73776E736E6C6D6C726A
676B69696C6F6E686B6A6A6B6A6B646E6D68656B6A636C69686D6B656C6A65696A666963
686B6064666668626160655E626569625D64615D68605F6161655F6066606161565B6060
65615A635C5F5D61
64676460696166696765636B66636463686964696D676E616B646C6C6563686B67666863
6F6A666665636D6D6970686D656C6A66716A6A6B6A7072676E6B6C6A666D6C67716A6A70
6D786D74737A76767574757576756C756C6B6E7A78787375747773787F757A787A777375
71757C797C76777B867C7A7B817D82817E8285877B8684888B8281878C8C9088858C8B85
908A818E97928C91948E988E93988B9695939D97979C9CA59EA7A2989CA39A9FA8A2ACA8
A9A8A9AD9FB0B1B4BEB0B5B0B2B5BDB5B3BAB9B5BDC3BDBABCBFBFBEC0C4CCC6BEC2C7CC
C9C7CDC8D1CED0D1CED0DAD7D1D7D8D7D6DDE0DBDCDDDFE2E1E3E3D9E3DAE4DDE2E5DFE3
E8E2E1EEE1DFE1EDE5E0E0E9E3EEDCDAE7E8E9E6E9DFE3E8E3DFE7E3DCDADFD6DADBD9D8
D2D3D8D0CBD5D1D7CAC6CDCFC4CBC4BFC1C5C5C7BFC2BBBCBABEBEB7BCBFBAB7BBB2B0AC
B2B3ACA6AAAEB6AB9CA3A8AEA5A7A29A9EA29FA5999A939C989B9C9A979C98979D919191
8D9793928B8B8C8C8B8E8B8E8481868686868187877E8289808288867A808484827D847E
80817E7C7A75777A7470777C7376776E77696F77737174716C70756F6F66746771676F6B
716F6A656D6C6A6F696767636F6A6E6D62726A676A646A6A6D6C65646769686F69695F67
645969606C6860625E5C5A6461666B62616860675F635D6663695D5E675C5E5E685F6360
59605859645F5F5F
65675E625F6765636560665F5E6767666B686C686B6667616A67696A65666465636D6361
6A696D6868636A706C6C71656B676C686D696868686B6B69726D73676F6C756F6F6C7073
716F747473726D726E6F71726C6C776F716C6E77756F76767071766E75767875797C7C78
7D787D7B7775777777787C807E81867C8080807A84858485868391878F8D908E8B899188
8E8A8892968D918897949490899395929698989296939BA4A29BA0A0A195989AA2A7A1A5
A6A7ABA2ADAAB1B2B9B7ADB1B5B1BAB5B7B8B4BCB1BDB5B8BABFBDC2BFB7BDC2C2C3C4C6
C5C8C7D0CACACEC9D8D6D7D6D0D0DBD0DDDAD8CFDDD5D8DAE1E6E4DBDFE1DEDFE8DBE5E5
E4DEE9DFE7DAE4E8E5E8E3DEE1E5E8DDDDE5E1E8DDE5E3D4D7DCE2D8DCD7DED9D8CFD5D9
CECAD2D2D3CFD4CDCACACBC6CCCCC7C8BCC0B8BFBEC3C2C5BCC5B8BEB7BEB3BEB0AFAFB3
A9ACAFA8B1B4ADA7A4A9A8A6A4A1A49DA3A5A19FA39596999A989993939D9E97908D9895
8D8A888D909098908A8688848A8A878C8381847E8886807F828080827F7E7F7D7F7B857F
817B7A7D7072757978757F747A786976796C6A747976786D6D6E6E716A6D67716D6B6D6A
6D676A646D706F6D6A696C7064696A6D686F696568666568616964696E67666665606263
656C63696169696462696768665F5A625D6A60605A5B6269645A635E605A626362636063
63655A5F5E64565D
645C6A606360645D64626363636461656664686B646565636B6A6D6169696D696C66686A
656B676A66666A6869666A7268685E646E6F6A646B6D68686F6568716B71706D70716C6C
686D6E6E7373747073737369736F716E6F6D706E786B7D6F756F75777276787C70757B7A
707F787E747B817C7F7F7D8082817B847E7E857F7F87878282848C8F898A89848D88898D
8C8D7F909692919790929390948D919C92979395938C9A959D9EA19BA7A499A3A3A8A5A9
AAA8A9A4A8AFAAB1AAB0B6B0B1AFB2AEBCB6B3B7BBBCBCB9BFC0BFBBB8B9BFC0BCBEC7BD
BCC1D3CCC9CBCFBCD0D5CDD6D1D0D8D9D1DFD5D9DEDBD8D7DBD7E3DADFDDD8E0DBDAE4DD
E3E5E4E3D8E8E3DDE4DCE1D1DADCE2E3E6DCDED2E1E4DFDDDDD2D8DCD9D2DADCD7D9CFCF
D4D7CDD3C8C9D0D7C5C9D0D2C3C2C8BCC0C3BFBDC2BDC0BDBABFB3B4B7B2B5A9AEB4B1A7
A9AAA5ADA6A9AAA7ADA2A4A3A29CA2A79DA799949899A3989998989D92989A9190968A92
90878D8D8E8B8A908592818E7D87827F84798389898385857C7F848187837D7D7E807A7D
7F817D7B7B79787B72777379786A706E79746E7176787674736A706C6F6E696862657268
6D716D71696C6969636F6F6A686A67696267616963656568656D6A696366646668656563
6A6666605F5C64655F61695F5C6367625F57656061636A67635C616461655F645F60625D
605A606459585D5E
61635C5D6964635B666C6360646A6D646162626B666562666A6A6A636269636762676867
696C6A656C6C6C666C6D655F6E6A646E6B6F70666D686D6D6E6C6D6868746F6C6F646E70
6D7868706E6976777271776D766970767171757370767576766F777373778077747D757A
7A7B777C797D7B8079827B7B7F887D84807F80817E81848486858888898F8A818990868A
918C918D938F8C8E929096958D968F8E949799939B979B9DA09DA2A39F9F9AA2A49CA7A4
A2ADA9A8AAA9ADB9ADB0A9B1B8B3AFACBAB8B1C0B5B6BBB7B3B2BABAC4BBBBBEBAB9BDC3
BDBBC5C3C5C3C5C9C8D1C8D2D9CFD5D0DAD8CDD5D9D7D1D6D0D6D5D5D7D7D7D4D6E5DBE3
D9D8DEE2E4DDDBDDE3DED2D9DADCE0E1D5D6E3D3DBE2DCDFD8D8D6D8D9D5D0D0D7CECDCB
D4D1D7CCCFD0C1C7CDC7CCC7C2C6C3BFBAC5BFB7BEB8B8BFB3C2C3B5BAB1B6B3B1B6B0AC
A8AFB2B3ADABA4A4A8AD9FA5A4A5A5A59E9E9A9A949AA2999D9593948F8F9792948D9589
90908F8C8E82878D7F8286887E8A84828B8680818181887E7E7F807D7B7D83817F83817D
7D7873787C76767C747576787078707472737C787579726C707074746D6C6A6C656B666C
73726C6A69676B696F696369625E646A6367666C63626A65676766686465695E69656374
62686D6466666861626265606668616963625C5E6665666061645E636660585E5D605A5D
635C5B5F575A6460
686967656B626669696A64646067645C5F6664636762646463676A6260616B6264696961
686B63656B706C69666668696671666E6B656C6A666F6E6C6B6F67706C726E6C716A7075
6B7373786D6C766F70747176726F736E74747173757676777578787C7F757A7874787C7D
797A7B7D7A78837C7D7C7A8280807D867A7D828182857E84818685858985838F8A888D87
938C8F948D8F94918F8E8B959792939298938D92949996A19AA1A4A1A49DA3A0A89EA59C
A4A1A0A1AFB4ABAEB2B2AFB6AFADB0B2AEB3B9B3B9BDB4BBB7C4B8BFBEB5BCBEC2B9BBBE
BEC3CCC0C9C7C6C9C7CACDCDCED5CCCCD3D4D5CDCDD4E0D4DBD4D6D4D3D9D2DCD5DAE1DA
D7E1DCD9DDDDD9D8DFDDDCD5DCD6D4D6DADFDADAD2D4CFD7D7D1D3CBD4D5DBD1CDD1D0CE
C9CCC3C8CBC8CAC2C8C6CFBEC0C0BBBEBDBDC0C6BEC4BAB7C1BAB4BAAFAEB3B8B7AFA8AA
ABA9A3A2A7ABA9A6A9ABAEA7A3A8A0A09F99A7A2979A9491979A99978E9392908692948A
9094858F878D8B8C8C81818388898F87888681888184847D7D7A7E7E7A7D757E807C837C
807883767574757C777F7A776E76777D726A7879756A6C6E757275746F72716E706D656B
646671626D716E65676B6668746A6B6866696A64696969686D6963666964696569656067
6968666B686D62676C61606666626067646D67616660625F616263645D6362675B616261
656358605B585758
6664606D675C6B5F68655F63696264636060685E67686B666B6D6B6565686B67646A6162
6B656C6C6A64696E6B6F6264696766686A666E6F696A67706A686B6D697270706A70716C
6B6A6F746F6D6E74716E716B6E7370767572737270737274787C79757076807A7A757C73
7D797B7A7B7E7A777B767E828079817E7F897C8786818382848885838A7D898783878F84
84928885878C8F9095958D8B8F938F919398958FA29AA0A09D9BA09FA0A29FA2A5A5A3A0
A8A1A1A6A7ACA4ABB1B9AAA5B2B0B5AEA8ADB7BEB7B8BABABCBFB7B8BDBBC2BEBFB7B9B7
B5C2BFC5C7C1C8C2C9C3C6C8CBD0D3CBD2D3CED2D5D2D4D5D7D7D3D6D4DDD3D2CFD3D6D7
D4D8D3D6D1DBD3D9DBD5D1DCD9D8DBDDD8DAD0CCCED0D2D1D9D9CDCDC9C3C6D1D5C7D1D3
C3CECDCEC3C5C7C9C5C8CBC7BEB9C1BDB6BFB9B5BAC4BFBDBDB6B5ACB4AFACB1B0B5A7A6
A3A7B5ABA7ABA9A7A1A19EA7A5A89A979B9C9F94979E98938898949490998C959A909396
8C9091858988878788848B8D857C87887F7B828D8A887F807F8A7D797B7A817F7B807A7D
7E7E797D7971777E7378787B72746E77736D726F776C71746C69776C6A6B696F676A6B67
676C6A695F686667686867676465676A6B6866666F5B67666A676E6D6A636C6361675D5F
5F65636366626160675D5D5F5E62615E616062665E61615E5C676361665F68605C69625D
5C64645B5556595E
6464686564666762685F656167626363616667676A6663676867696C6969636B64666766
666B66676C60756D6267676A69666E6C696C6669676E6D6869676D69716E7172736C6A75
6F766E66756A6F69667073737172727278776A727470727477797C75767A77747A7C7077
767D7278807D787D827B7C7C7C857D7A7D81828189837E84887F848586888C88878A8F83
8A8E898E88988D928E90938F938E918E8E919193939896979E9C9F9D9EA7A5A09F9AADAF
A5A2A1AB9E9AA9ABA7ABA9AAA5ADAFA9B7B3AFB3B9B8B6B4B7B4BABBBCAEB9B8C3B7B8BC
BDBBC1C4C5CAC8C8BBC1C8CBCBD2C9D2C9CCD1D4D4D2D1D3CDD8CCD4CACFD5D7D5D4D0D3
D7DBDDD2D7D6D5D5D5D3D7D1D9E1D1D0D4D8D8D0C9CDD2DBD2D7D5C9CFC8CAC9D0C5D6D0
CECBC5C8BDCBBFC3BCC3C5BBBFBABABDC0B6B4BCB8BBB7B8B3B5B3BAA9A5AAACBAA4ABA7
A4AFAAA9A1A1A0A3A5A7A3A7A6A0A2A79E9A9C9C919E99909090938E95908D9692969790
8A8F82848A87858D858E82878E8383858583858280868584807F82807F827A78807A7B72
7C757971727B707C757C74766F6C7974747977707174756F666D6D6E686B706A6C696C74
6C71686569736669716B636463676B6A6B6D686A67666A67666466666B64636466656565
675F6A676466636562636264696362695F60676463605D616C61605F5F56615C60615F5D
5E5B61606158595F
6664636068676463626A666564666663646A6A68636569636362626669696B697266675F
666C66656667666C695F696A6B696C6C68666A6E6A716E6A696972696D6B6B736C71736E
6D6D716F6D6F6C7179776A6D72717078767674757570787678807378767A787575747775
7A757D797A76767B80837A7C807A84838179828884847F887E887F8F818485868D8A8388
8D89888D8A888B8B89918E8B8F94918D91968A999290909497989D9BA1979C9BA09F98A5
AB9CA59EA2A7A5A9A9A5B9AAA4A5AAB7B3A5AEADADB7AFB0B2AEB8B8B9AEBBB6B6B8BCBE
BDBCC1BEBFC1C4C5C7CBC6C3C2CCD1CFCED0C9CFCFCAC6CCCED3D2CFCFCFD9D1D2D3D1D2
D4D2DBD2DBD3D3D0DAD4CEDDCBD1D1D3CFD5D1D5D7CACAC7CCCED2D3D1C6CED0CACBC8CC
C2C7CBC7C8CBC0CAC1C7C8BFBDBFBBC8BDB5B6BDC9B8B7B2B6BBB2A9A9B4B0AFAAABAAA8
AAAAA6A9A6A3A4A2A5A3A0A5A5A2A1AA999EA29695959C8F949D90888F9889858A8E8E8F
9593828C8F898B8D90918589888A8181868886857C82827D868B87837D7B7B797C7A7A79
7F7C74737D70747C79787C8376757574736E71776E726872727272736B6D6D6E6F62666D
6E60716E6D676D676665696D656D6968656566696868685E5F6464616964616266636B65
636360636365615F5F5F5F5C64616965606561675F61635C6564655D6667696563625F64
655D635D5E656061
65666D676B646C6466646663656166675C656667636367686A666A5E6365696866696B72
686C6866656C6464676A6A68676E676966686B6C6D686964716F71676B6C726C746E6F6E
726C71766E73716D666E746E6C7073766E6C737275757471737275787A71727975767882
79777A7B747F77797F7F7A7E7884827E7D84807B8083877E8188808E8781847B8686898C
8A838D88878E8A868A8D8F93949193948B9194969A9294A1959D969A9D9AA19A9D9CA3A0
9E9E9FA2A4A3A1A9ADA1ACA9ABB0ABA8B1A7ADACB1BBACAEB7B4BEBBB0BDB5C2B9C0B7B8
B5BBBEC4BDC7C6BAC5C2C2CBC2C6CEC7C6BFD1C4C5CAD5CEC8CDCCD2C8CBD0D6CDD6C9CC
CDD6D0D4D1DBD3CFCBD1CDD0D4CCCED0D2CACFC6D3D1CFCDCACCD4D0CDCFCACBD4C2C7C7
C9CDC8C5C2C3C2C2C6BFB8BBC0C1C9C7BEB8C2B4C0B7BAB7B7BAA9ABA5B4ACAFB6A0A9B3
A6A2A0999FA2A3A0999C9F9BA19CA1A3A09A9895989995988F948F8E8E9193918F968A8D
8E8C86888B888B8B878A8585838288877B877E858A7E8187818081807E7E867B7C7A797B
7776737D7B73747A787D7D7B807A77796F76746F756F73737473726D676F7373696D656B
6663706B6A646C6B646A686D656568655F6667686A606661676B60686C67676466665D64
6065666061626161645F5D6065636860665D675E6161645A68615E6259645F63655B6662
61575F67615C5563
676D6A6B6D5E6A666D5D6A5F676662636B6067666364616E686B6A676D646769665F6667
69677167686467606A676A69686E63706A696B6B706E6B6B696F6B666C6F6F6C6B6F6E6A
74686A727570786D726F6D6D78727074767274756E7474757B7B7B80737A7B6C72797581
7F7E817C7A7B76767F777C7A837E7F767B848780807B828B8A8884897F8789818D81868A
898A908F8B8889898E8C918F8E899588958F9A9D93919B989B9D9B909EA397969899A0AB
A7A0A5A8A0A1A5A19DA6A8A9ACACABAEABA5ADACAEAFB9ADADACB4B0B7B9BEB4BCB7B5C1
BAC1B7C0BDBAC4BEC0BEC1C4CCC3C1C6CAC5CCCEC9CECACACECAC8C9CDD1D0C8C7C9CFC5
D3CBCAC6D5CFCDD8D3CECBCED4D1CBCDCFCECACCCCCFCAD2C4CAC6C9C3C7CCC5C8C1C5BE
C6C0C8C7C7C8C4C1C4C6BAB9C4BBB9B8B8B6B4B7B5BBB5AAB4B0B3AFAAB5ACA5A8AEA5AF
AA99A1A6A5A29EA79F9BA0A39B959F9C9F9A9B9692918896969A938F968C928C8991918E
8A8D8E888886858781848C858A86877F7F7B82867F7E84837C88817D817F7D777C767574
787479787E7B7E7573777E737178767471777077746F7571706F736A70696D6B68646662
756B6E62656F65666967606F626B636C69656867676761676D666161635C616E5B665E60
5E665F6566666065686365645C645E6468606965606365616060675E5F5A5F6261596060
625A585F605E5859
6E68656D64645F6464676360636165696A5F66685C6363676464656860676769656E5F69
676969606468686866676B69686B6567666965726B6F6E696C6C68746B6772676E717076
686C67716D6F72706B6C74706A687372726E75777172737570737878757C77787D787277
817C73727C807E7B7D7B7B8476838188857B7D7F7F877E81828184868B818A85867C878A
878C8E8C89888B8C928A8888908E8F9191948D91959797939992999B9CA796A09C9BA594
9AA19FA3A4A6A0A9A4AAA7AAA8ACB2A7ADAAADADAAA7A9B7B1AFAFB8B6B4BDB5B4B5B8BC
BDB7C3C1C5B8BBC7C6C1C3B8BEC5C7C0BEBFC5C4C6C6C9CECDC0C9CAD1C6CAD0C3CBD1CF
D6C9CDD1CCCBD2D1D1D0CCD2CDD2C8D2CAD1C5CACAC6C1D2C6C7C3CDC7C5CAC6C0C0CCC9
C7C0C0C4C1CABFBDBCB4BEB6B5B7BDB9B4B7BAB4B3BBBDB3B5B6ABACAFB0A8A7ACAAAAA5
A69F9AA5A19E9EA5A299A19B9A9DA49E9D9FA38F9796959A918F908D928C8D9294908485
8E8D8787878C897F88858F87877F8680897E7986837D8084837B7C7E7C7E777E7C7A7770
797B7A7A737773777E747876787476726E787075737571766C746E6F6C6E6C6B6D78716E
6C7273696D6A696B646864686C676365656468676968626564696B6260635E6B65646F67
6B655F5E675F6563646267655F5E616261665A636060635F5E655C605D635A60585D5A5D
6261556164545B60
707269676965686366656A636161606564636667696269666066666861696A6465616967
6D6A606363686C706763676269656F676065686F6A73666F6C7472736C6B696F696D7172
6B676F6C726D777771706A6C6C7374746E737276716D777071727B787576787C7B757474
797E7E7D7D797C7A827F82837B7F80817A827F847B877F89838185898882878B8E828586
8E828A8D868A939382968D8D888E9189968492958F9C96979A939C9293A2A29F92949EA2
A0A1A2A19C9FA3A2A4AF9EA5A2ABABAAA9A3AAB1A9AFAEAAB3ADB5AEB0B1AFBCB8B9BBBD
BCB8B5C6B6B7BBC9BFC1C4BFBEC2BFC2BCBEC5BDBECCC9C6C6C7CACAC7C6D1CDCBCFCFD0
CDC9C7CDCAC8C7C8CBCFCACEC7C7C8D0D4C7D0D3C2C6C6C9C8C3C5BFCCCAC6CAC9C2C3C7
C2C1C4C3C3BCBABEB1B6BCBDC7C1BCB6B9BBB9B6B3B5ABB5BAA9B2B3AEA6AAA9A1A6AD9B
A8A69CA1A6A1A7A59F9BA3A898A3A09C9C989795969D91918D918E979092968C918A908A
858D86868688888B89808877868484868486837B877D8379787A7885807B7A767D76737A
7672797776787077727374747475797571727271737170717566746D776D6B6F6D687265
6B68676C6F656871686B6D706467685F675E6B656170646763625C635C65616466636463
6263646068596361615E6C65606B61626068615A60645D575D63606561646C635D626163
5B5A5853535D5B5E
74696C666762656265635D676666635E635C656869645D685E64666567696B5E676A676C
67685F656A656A686767636364696C706C656A686E6C6A646C6D726D72707170646E666E
6E7171757074706C75716F706F6F75746E6A7770726E77707A71777276797B747A79747D
7477747972827E747F78798079807D7F7D7B82837A8086807B8784878A85877F88898A90
87938088878A8B89888F91908A968B8D898E8B8E908C9099A39C929A9D9BA29799A1A0A5
A6979B98A1A2A79EA3A8ACA6AAA6AEACA8A8A3A8ADA9ADABB0A8ADA0B0B1B1B1B8B5B3B6
B3B7B4B9B4B1B2BBBAB2C2C2BBC2BEC2C6BDBAC2C3C7C1C4C8C4CDC7C5C0CCC6C4C6CFC6
CBCDC3C7D3D2D5C7D0C9CCD0CAC4CEC9CDCDCEC9C5C1B9C9C5BFC4B9C8BBC0BCC1BFC2BE
B3C5BCB9BAB3BAB3BEB1C3B3B8B9BFBDAEBAB7B2ACACB2B1B3AEB2B2A3A7A6A4A89CAAA5
A19FA09DA299A1A5A8A39EA09D9E9C9C9C989A9297968A958E95938D91978E8F908E8E8B
8A8A928A82888C7C847984858382818484828B7E817B84767E7E77787B82777E747A7D7C
78737E76727D757D6D75717A737372716E6E796D7A7170686971726F6C6D6A6A6A68746E
6A676D7271696C616965696A68686D6763606A606A6465656164666965626866675D6562
696364625964606761605D5D615C626265615F60625B6160635E625F64605D5A5E5F605F
635A605B5C615E5F
767369656463666464655C5D5D60666765636563636868655E65635E625F646B6566685B
616B676B666261686E64686567666C6A6569716D656E6F686B706869606C6C6A6D687071
6B69747268736772767164686C6F736E68706E747070736F6D75757375707A7776747679
7B7A7B797D7C78807B837E817E7E7A757D817E797F857F81817F8183848387887E84888A
8C8A89888897848D8C898C8A8B8D86928B8D959894988D959C969E9C9E9C969A9199989E
A1979DA1A6A19F9F9FA4A9A69AADA3B0A6A69CA9A8A9A7A7A9B0ADACB5ADAFB1AFB7B9B3
BFB3BFAFB7BEB9BAC0C1BABBC0C7C1C4C9BEBBC2C0C3C3C0C2BDC1C3C5C6C6C2C6CAC5C4
C4C9CBCAC6C7CFCBBCD7C5C2CEC8C8D1C9C6C9C8C2C9C7C7C7C4C6BFBBC0BBC4C1BBBCAF
BFC2BDBCC1BAB6B5AEB7BAB6B7BABBB6AFAEB6B5BBB2AEAEA8B3B1ACB1A9ABA5A3A2A9A6
A3A5A29CAAA098A1ACA2A0A39E969E939B9B9D9A9391938F90928D8993918C8A8E898C86
8A86888B878D8A8B8B878389867D88887F837E80817F837D7E7D75797F7F8174796F767A
7E7B747875786F79737D717775736D6D74716F7074757171716B6F74696B6E7268706C6D
6D6D666B6A6A70716862706E6A666C6A6C656862686A6362656666675D5F695A60635F66
65626363626169645F65685E62625263565F5B6161625F5F5F62665B5D62605D615C5C5E
5F5C5B595D5E5C5D
82746C656B5F60656166626162656C5E65645E656565625E656262676161606367666C64
6760696364636A6B646A6266686A6B6064646B6E666A6F6B6F696B6B6D6D6B6C6E68696D
6E6D71716C6A6E6B67766C7072707371717970766F737573767A7974777B7B747A797576
7B72747D75817F797B808380877C7B7D7F7B7A7D877F7F84858282807E878A898287858B
878E8A9388838B8B8688828C8D8A928E8B8F90918A8C9999959495959E9C969199A4A1A2
A5A49FA1A19A9BA69DA2B2A6A8A1A9A5A8A9A6A8ACA3A8B4ABAFAAABB0ACAEB0AFBBBAB0
B4B4B8B3B6AFBCBABFBEC3C1C7C7BEC7C2B9BBBDC1C4B9C8C1C3BFB9C7C0BCBFC2C5C8D0
C4C3BBC8C5CAC5C4CEC6CCD1BFC6CBC0C0C0C2C2BDCAC0BFC1C5BCBBBDBFC6C6BBB9C1BB
C1B8B2B3B7AFB2B6B7B2BAB5B6B9B4B4AFADB3B0B4ABADAEB3A2AAABA3ADA3AAA9A3A8A6
9EA9A29FA5A09FA4A09FA7A3A09B989F978F959A9799949389948D918B8B89908A8A928F
8E878C9088888684897C84847F80817A7F837F7A827E7D7C8481837E7A817C7470747B80
7175777A747574716E777C7C7677707A726F7371696D71716D736C7872696B6D5E6A6D6B
666C6767706B6D6A6A6263616F676B6B63646B656D65676961636067696266636167645E
5E696B6463615E5E5F60656265645F605E64656756676060605C5E5D6B655B5B645B5A60
615B5D5F5B5F565E
7D7665666C68646866665D66615D5F665F6F62666464656465616468605E6A5E6A635E66
68696169666468666565686669676D6B6662656B6672696A6B6767716D695E6F6A696C69
7170706C70726E6F6F6F696B716A736E6E6E717373776E6F727779737B79707876756E79
75727E7F7B7A81767D7A7E857A7879787D807E7E848182887E8679818C887F768B8D7F84
85838D8191908A848790898B898F888C8F969A898D97978E92939595979D9A9A959EA09B
A5A19D9D979C9DA6A5A4A49CA2A5ACA8A4A9A7AAB0A4A8A5B1A7AFACACA8B4ACAEB7B4B1
B9B1ACABBBB9BBB6C1BFC4B5BFC5BEC3BBBBC2BCB9C7BFBBBDC0BDC7C0C1C5C0C1C4CCC7
BCBFC0C9C4C6C5C9C9C2C2C6C5C4B9C1BAC1C0C5BAC2C9BCB1C5BFBDB8BFB9BCBDBDBFB5
B6B6B7B4B5B8B5B6BAB3BCAEB4B1B2ADAFB1B2ACAEACACADAFA6ABADA2A5A0A1A8A7A9A2
A1A0A5A4A3A9A6A19EA99CA5A1989A9296948D938F8E8F8F908C8C8E8B8E8F8D878D8A8F
8A8C8B828C85868A89868A81837F7C817D79847B7F7F7977747C7A82817F7B7078757972
747178747677716D717476797271727977776F6D78686D6E6C71766C6D6C696F6F6F6871
696C6B6667646E656D6161666A636562706B686569676C6366635C5D686B6B62625F6363
62626666635E6060606368636765625963646060606863635E6162625C665B606062525A
6060625E5A615C5B
80786D6C5E66676563635A63616664616564636366666264615B64656268656367686B65
6A63625F5C656D6865716464646B686266696B616664706C686E6E6B696C6F6D716A696B
6B7869716F696E6D6A6D7270716A756F747374736E71757A727F7976787575706D72707A
79717171817E7D7D867D7B7F7C7E817D817F80847F81807C80827F7D807C7F8387848286
86838C878885888F8E8A84919093898F9095898D96898B979296979499949791A0A1989A
9C969BA39E9DA29DAAA69DA5A6A9A8A3A3AEA7A2A6AAA3B1A9ACB3A6B6AEA7A9ACB1AEB4
B6B0B2ADB2B5B0B7BDC1BFBEBABBBABDBAB9BAB6C2BAB9C7C0BFB7B8B6C3BABFC1BFC2B5
BDC4C1C2C5C1BBBFBDC6BDCCC9CAC0BCBFBFBFC6C3C3C6BBBBBAC4BBB8B8BCBEB7B1B7B8
C1ADC2B9B8B8B1B9B6AEB3B0B3B1B6B0ACB1B1AEB1A9AEB5A8A9A4ADA3A4A2A3A0A4A7A2
ACA5969DA2A0A1A3AAA39D9BA09A9D949D948A9498979488928E8D868B958E8C9289818B
8B8D8889888188868782887A80857C7C7F80807D83827F807D7D7E7D7D827C7A777E7A78
7C79737074717971776D7174747E6D676F706F756E6F6F6B6C756A686F72686C6B656970
696A656B686B6964636A636965666965676760646766646164656266646C656161606065
5D5D646664626162616466635A5F5F69636A5F5F645E5E656560616164635E595B68625D
5D645A5A5D5B5E5A
7B6B6A65615D67666662636065666962646564666A666B5D656560626961636462685F60
68636666676A6368646964696971636C696C626C616A66676D6B6A6F6A66646F6A6E686E
67677B766F726F6E697071716E757172726D6B747877797971736E71717A7173717B7678
7C787E78797C7A7C7B7A7D7D7D777C82817D7E797B8081827C8787827F7D857F818C887E
86888D8590888B908C8A89898F8B88908C90938B8A909593908F93969997A2949C9C9E96
9A9E99A19EA4949AA59EA3A19FA6A5AEA4ABA6A1A6A3AAABA2A3A5A7ACA8AAB2B1B2ABAE
AFADAFB2B3AEB0B1B8B6AFC0BDB4B1B6BFBCC3B9B6BABFB2B8BBBFB8BBBBBEBBBFBEBDB7
BEC1C0C1C4C2BDC3C4C8CBC0C1BAC3BDB8BCC2C2B8B9B7BCBCBCB7BCB9B6B8B0B9B9ADB6
B5C1B6B3B9B9ADB3B0ADB7B2B1B2AAB3B1B4B3A9B1AFAFA9A7A6A4AFA2A4A6A3A0AAA4A7
AA969B9E9F9BA598A0999C9E989C8D94989B978F8C9194968D8B8D928F8F938C8A88878B
8C8986857D8A8B818485838683827C7A7E80847F7B7F7B7B82817C7F76787F7A8072737B
76787A7C78767772706D7977747370757070786B75696D6B65696170716E6E6C6F6D6968
636A696A656B636361696B6D6B66667065675E69646C6B63626669636064636764636364
6165625C63626163636060645D5D5C625E58635D626162625D625D605D5F635D5F65655D
6362655A5B5E5C5D
7A6B686A67676866656169695F6866666563636566656361646565686266636762646865
65656B6668666B686866636967626C646B6F6B686E6D6469676D6662746B6D6C6C6D6F6A
6A6E6B726B696B6A6B6D7172706C736F71726E727A75716F737D7A717476736D71727673
79797E7A7F7C787D7F7F7C7D7E7A7C7D7C84767D8481767A817C877C8080818783848883
8187898A84858B888C87898C88898B9190868593918E919293999292959990949E989899
989E99979BA29C9C9B9FA2A6A3A4A19A9CA59EA9A3AAA5A3A9A5A8A4B0ACB5B0A8AAAFB1
B0B2ADABACACB2B5BAB6BAC3B3B9B4B9A9C1B7B6B9BBBFBDBAB9B6BFB7AFBBC4B8BCB9BB
B8BABBC1BAC1C4C2B9C1BFBEBAC2C1C0BFBDBDB7C2B9BABAB7B6BBB9B9B5BBB2B5B9AEB8
B2B7AEB1B7AFB9ABAAAFB7B2ABA7B3AEA6A4A8AFA9AFA8AAA6A7A3AEA49EA1A5A3A2999F
A29B9B9CA0999F9A999A999897949290958F95958D94918C94978E918B8E8A878B8D8A89
8D888B86898388898480888488857D807D7778817E7E7F7B777876757E787A797A817E7A
7970777473717E7974787073747170726B6D6E77756E6B7072756A7066666A666A6C6670
6C716F6C6A64616B686C65626965646269676661666564666267655F64666E6665606466
5F66656C62655F5E63645D635E5D645A62645E636362625F625C5F635D5E67655F615F60
5D5A58615C5A555C
6E686870606A65616368696068615E6561646460635E676669676463645F686A5A656765
5E686066635F6B676564666B666666646E6A6E67666A686A696F66636D6C686D676A6966
716F68666B6C6D696E6E70706A74777272726D74727476787876717578757175717B7C77
767A7D757C727E7F7D7E80777A817F77827F8280847B7E7D80808382807A817F8A82848C
7F7882828789898287878885848C8F8F938E908C92988E92928899939494929696979B95
93959A9E9A989F979D9F9BA0A099A3A1A8A3ABA9A8AC9EA49FA8A9ABA6A8A9ACA6ACAEB3
ADAAB1ABA9B2B2ADB6B2B5B3AFB7B5BDB1B6B6B7BBC3BBB3BBBCBEB9BEB3B6BDB8B8BCB7
B9BBB6BDC1BCC2BCC2C0B5BFBABABFBFBFB6B9BBBFB1B6B5B5B7B1B4B3B4B2B8AFB9B2B2
B3ACB2ADB0AEAFB2B2B3ADB1ADB4ABA9A0ADA5B0AAA8A9A3A8A99F99A3A2A8A2A6A49B9F
97A19A9898A3999F9BA0969C9A9A8C8E8D94928D948F8C9891908F8C8D8D9085928A8484
858783868F83837C7F82837D83778084837F7C807F7F7A798071817A75797B827C787A7C
7B787A6F75736E737773737A6E6A6F74766F676A7474656C696D726C676B68626F6F6667
6F7265686C6F6A66656A67686A6B5D6C65606A616959666C62655C6668635F5F615E615D
646560635B60635F6557695967685D5D6162616362676262665B6168575B655B5A625963
60625D5D5F5B545A
6D63646263686C65666A68676860606D6068645F646666696765656A666163635F636064
696564676D7068656E646C676366646D67636C666571686268706D6E716B6D666B73736B
706A666C7267706D6F69666D6F6C6D7475757070747772686F6F736E7C7476727179756D
7278827575797A7A797D777A7C7E7B807A8175807C7E797B8383767B7B7C7F81817E7E83
8586877E828D8A868C8D848A898F8B898C938F908691919195918F918B8F8F96919C969A
9E959C9A9C9C979BA198A0ACA1AC9EA2A0A5A2A5AE9FA0A3A9A9A4A0A1A5A3A5AAADACA7
B3ACB2B0B3B2B3ABB8B7B6ACB9B3C1B4AFBEB7B5BCBDB8B4BFB2B3B9BABBC4C0B7B9BCBF
BFBBB8BBBBBEBBB5C4BFC4BBB5BABCBEB6B7BDC1B3B9A8B2BBB1B4B7B7B1B0BAACB3A5B9
BBB6B1B4ADAFB0ACAEAEAEADA7ABA5A1ACAAA1A7A5ABA4A1A9A3A9ABABA49B9F94A89DA2
9FA0999D93A8A49B95969A9395969B93948F888E928F8C8C9296938B9190958C89878D92
80837C85857D8282898180837F7F797F7D867C7B7D797B7C7D837B747672737C75747078
707774747E7B777670756B756F727271716B6F78726F6E78686B696E6F72676A6F6D6A67
6D7065646C6A6C6566636C6B6663656E61696E5F6E626E646A6B6666625D626163646165
6161676160625B636065645F5E5F61656A6768626764625C625C615A5B595E5E5F5A5A62
5E605E59615A5D5F
6C606564625E64656A6C67655E6A6363615C65666462666166655D616460686E65646769
60635E6D656465666864625C5D6965656B6866656E695F686962636C6C6A676B6967676E
6B6B6D6B7074696D73726D71796F797972716E757278707A756D78787A70737B70767572
756E7580747A7278736E7680817C77777D7F7E7E807E7C80818B7A827787837D7E81897D
838785808A848B8485817F878880888C92938891939086898D998E928B919D9597909098
9999919799989C98A6A298A3A0A29CA4A3A0A1A4A5A79FA699A2A8A6A9A7B1A1ADAAACAB
9FAFB0ADA5ABADAEB6B9B6B7AFB7B6ADB8B9B2B4BFB3AEBAC0B1BCB8B9B4B7B5C0BEB6B1
C2B7B5B2B2B8BDC0B9C0BCBABCC6BCC2B9BCB5B4B4B4B7B2B2B7B4B3B2ABADB5ADAFB2B0
B4ACB2AEAAAAB9AEAAACB0A8A9AEA5AEB8AAA7A8A89DA3A59B9AA39EA89A93A099A39D9B
92A39897929A9C999594959A9595978F92958F918B95898C89808D938C9288888A8D8A83
857F8A8681828983887F8487817F7F7C86857F7D7C777D7C777F7C757B78777B767E7671
817573767574767777766D766B736A6D7477706E756E716D6E6A6A726F61696A6A696C65
676A6A646B6A686667646E65646C686365696B66616562656363656A6667676466615F63
5F65605E5C646662636466666A626264665F626364605E625B675B61645D586A63656761
5D5E5F56555C5C5D
6B6769625F656465676766706C5F5E625A6760606A6A5B5F5E6766646365696864626464
6A6663655F6666676569646A6D6368656E6969686C686266666C686770646A6D646D7172
6F726E69696B6A71716D706F71736D7075716F6D707072717B7C76776D787A7878827A77
7371767A77767879748081787A85787E807E7B7E7B7C7C7F7E7A7B7D7D82888180858086
838A8285868586858588888F878A8A9391848F8E8E8A89908C9191899491999695929795
9A8D999996969CA0979DA39E9D9EA09C9C9A9EA8A59E9CA9A3A7A6A2A2AEABADA4A8A8A5
A9A5ADAEAAB0ADAEB7B0ADAEB6B2ADB2B8BAA9B4ACADB7BCB1B0B7B2B9BDADB9B5B1B5B5
B9B9C0B4BABAB7C4B8B1B7C0BDBBC1B6B5B7BDBBB2B2BABBAEB0B3B3ADB4A6B0B2AAAFAE
B0B1AFB0ABA6AEADB2A9A5ADA6ACA7AEA5A8A1A5A9A2A2A7A89CA49DA7A6A29EA29AA095
959999949D98949994959D9D9A9A9394998A8D8D8B918A8B8B8C948D8D8E8E8A898D8983
8684818C84858D82818286818979827E828080857B7C767B7E79777A7D7C7C7B78737079
71737B7875706F6E7276716D737275756F706E74726971746B6B6E69726D627063706C6A
6C6C6A716761696B6569685E6065645D63656C6468685D6568676662656760635F675F66
655C625F5E5B6A645E6868615D616A625D5A636161615E636066655D5C6160665D5A5F62
5D5C5B615E655264
67596063645F6266615C5F636562645E6C5F666261646B605F645F666565666568615A5A
63656568666A676D6F676A6768686E686667686A6B6D6A666668686A68696E6D6A6C686C
666F746D706B71726D6D74756F746E6E7775796C786E7D7175727B707476727C757A7778
76737E747D707C747678827A77847D7C7A80847F807D73817A847D7E7F858680817F8B81
838880898781808C7E868C85878E87898D89848887888D8E89868C908B9493929493978C
9592969D98959093949A92A5A0A89A9F9BA59CA8A6A5A39E99A7A19FA7A19EA5A1ABA9A9
A7A7B0ACAFAAADB0ACB3A0AFAEB3AEB2B8AAB1AFBCB5AEB1B2B7B1AEB3B4B8AFAEB6BCB4
B7B6B1B8B6B4B6BFB9B2B1BFB9B2B2AFB8B3ADB2AEBAB4B3B0AFAFA5AEB6B1ABAFADAFB1
ADAEB0AAA7B5A7ABAAA6ABA9A3ACAAA2A9B0A19EA8A5A4A1A9A4A09DA69CA19E9F9B9CA1
98999C9694959596989699939394949395918F888F8E8C90958B908C868A8F8B89828488
817F8986848B898183788383857F797F7F7A787A7D7F787F7B74747B79767C7B796F7675
7475757574767073696D736F6D6F6B716E726F6E65697176716D706E6D6B716D6E686668
6D6D6D6D5F6A69626065616266666762626669675B615F65646265646460606060675E5E
6467625B6362615F655C64626159615C655F62635F61605D66615C6260625E5F65656960
62605D575C5D5F5C
665F615B5A616360686165626369635F6B616565686A5F5E635F636868665E6064696766
6D6C6D5E616965666661636665666E6D696B69666969706B6A6C69706B696E6D5F6C696E
676C6D716B6C726A70706F7574737477777D8075767472706D6F716774787C7278797A76
797A7E7A757E747977797775767D7D717B837D7C837C7E7D767B7F81817A798580808084
7B7E85848483898B89848883828C88918889928A928D8A918D998C8E8F94929296959196
8B9197949696999B9A9B9FA1A0A2A2A29BA79EA0A2A2A2A3B1A0A5A2A0AEA4A6A0ABA6A7
A9ABAAAAA8A4A7ADB1ABAFB2ABAAB4B5B3B4B7B2A9B2B1B5AFB1ABB1B2B1BCB2AFB6B7B8
ACB9B6BAB8BAB1BAB3B3B2B8BAB2BDB0B8A7B3B1AFB3AFABB6BCADAFB8B2B9A9A9A7ABB0
B2A6ADA8ADADADAAA8A7A6ADA7A6A6A9A2AAA0A4A0A1A2A59DA1A1A79C9AA0979D9E959A
9A9F99999A988C978F8D9190948C93918E8D8F8E8A938A8B858989888B9085828E828189
868785797D857F7E7E818286807C7C757C827D7875798079787C767672717B787B737376
6F747C776F71737574716A686F776B726D6D7170706D6C6D73756B68655F6D696F6F6A68
636B676967676C6D6D64656563616A626467646A656063636666656065635C5E615C6761
5E61625D68576D5F685B606A63645C5C62645D5F5F606059605F5E635863655B61585D69
5B5F5C60555E575D
66625E5E6466616261686965685A636165636A5B615966625D63696A6861645F66605F5F
6260616966636B5F616764656563646465636C646A67696B67706E67746A61656C6B6D69
6F6C6C6D6B716B6D706C706C7878797D8279787278766E7272786E707A78777B6F727674
726E7B77737B767A79787E76737F80787D827F7E7F857B7C7C837A7A887D7F80807E8382
83828283858A8B8E87888388858C8C8F908B8785878E86898E8D8F89948F8F9395968D94
999193949593989D98939398A1A39D9B9F9D9E9DA5A2A4A4A1A9AD9DA2A6A1A9ABA4A2A4
A7A6A1A4ADAAABA9ABAFB6A6ACABABAEABACACABB2AAB0AEB3B2ACAEB5B5B7B1ACAEB3B1
B9B4B4B8B8B3A8ABB9BAB0BBBAB2B2AEB2AEB6A5ADAEABADA9AAABB3B9AFB2ACADACAEA5
ACACADB0ADA3A7A8A0A4AD9EA7A7A3A2A7A09C9FA0A8A6A39EA6A59A9F9F9E98A0969399
8D9B9B979C8F9D90958E8D9393948E8E8D948F9491888E8E8D8C948E84918A8A8B858E8B
87858488828186867B877E7B81808083787E7D7976757B808377777977767A756E787574
72767B7071706D6A76756D736F686B6F6A6A726A6A6C6E716F786C666E6B656D6D676C67
706B626969626564656466645B6A6A666B6568656060645B6B64636A5D646261635D5A67
62625D5F5F6166635E61635B6258645B5E6661615E5E6061625D605F636361696364675A
635E5B5D5F5D5B57
665F616064615C62656661656667645C62666464675F6361606561675E6060645F666162
6360616264686B656D656E696B61616771646B75676D686D6762656C6F68656D6B6D696D
6E6E686A6A6E6D6A7171676E717578787A827C76757C767179707377736F717570767478
777375727B7274757482787C7A787D767F7F767F7B7A85797E807A7E837E7C7D83807E85
8681818981838B8984888A8983908E86818C878B8592898E8C8887948E88918E93909591
889398939694989D939E999D9B9A949D9DA09A989B9AA19C9AA49FA6A6A6A3ABA5A9AAAC
A8A2AAABA9A8A8AAACA5AFB2ADABAAAFA9A9B0ADA4B2AFABAFAEB6A7B6AFB6B1B1ABB3AC
B7ACAFAFB4AEB0B8AFB3B6AFB0B1B3B2B3AEAFABADADADB2A4AEADB2ADADA4AAA8ABA6AC
AEA5AFA8ADA7ACA3A4AB9FABA1A3AAA3A09C9EA3A2A6A69EA5A39EA09E9CA099999B9796
909699939295959693988E9490949797908B90858D90888C868790858C8883848889827E
8284848384818388817D7D7F7D817A7B7F777E7E767D7B7D7C74777C787F7C7C787A756E
6D727175756F6F7671716E72706F7573736C72756F6977736D6B6C7168696E6C6A686D74
656F68656C66616A62646865626366665F6064686C5A5F60626665655E665B65675C6969
68615F6452636256635B675E5A61685E6262625F69655F65615A615F6165605E5C696964
5A61625D64595C5A
67625D5B636763695A636460665C60685D6862586F6E6165676765626764686A5C65645F
65626B6867676769646968666A6F647166676F66696C6B6A6B6E65656B6D706E68696B6B
6D6D6E6F6F73726C71717271747C71827E7E72746E746F71737374726E72786F75787477
776D7673787A7A7C7A787B7D727F787D79848476807F7E80777F7C7C828379827B86867B
848189828482848A847E8688868C8E8B8B8E8692898E858C838D84958D93948B90929192
929488998F9795969D969AA0999D9C9A9C9BA6A4A4A7A8A29BA1A496A9A299A89EA49EA4
A4A4A9AEA89FABAAABA9A0AAADAEACA6B1A6B2AAAFB1B1B3AEAEAEB1B3B4B8AFA9B4ACAB
AAB0A9B0A7B1A9ACACA7ACB6B8B1ACA9AEB1AFB3AFAEA9B3A9AAA8ADA8B1ACACA6A2A8A7
A9AAAAABA5A2A8A0A4A89BA6A2A0A49D9E9EA6A0A3A0A29B9B9CA59F979C959C989A979E
9691909C9C9695919B8D8C8F958E978F91898E8C8D8D9094868B858A878384898B808087
89878585838583868082827F7F7A797D797E7B79807F817A73767A75787A777671787476
7A71797977776B70786F6D756C707571726F7571706E716B6E66676F6D6F676B70706B63
666D6B616665695E67616B68676667646171696263615E6168665C61695D5C665F606B56
635B6861606161635F5F615F5F676361615C615F606661695D635E5D6161625F5D5A6064
5C5E63565F5D5E62
605F5E6261605E66626062655C656063616B6A6B616860606D646A696265676165606B63
616763686B6762676966706A66696969706C666C6F6C676E6C6B696D6C696E6B6A6E6B6F
6B6C68696A71646E70726B6C766A727A7D7C786E726C737576787A707072717675717278
737874747971767C76757D7A7A797B78787E797D7B7A7B727C7F7D818082827780837E7C
838E84858E917C8985857F8E8589838A8C82878A8682878C8E868C918C928E868C8E908D
88968D9594938F9096999A9898A19A9698979398A99F9B969CA09AA49BA5A49CA7A4A7A4
A89FA69BA3A6A5A4A5A5ACA7B3A7A4AAA3A9AEA8A7A7AAACAAACA4A8ADA3AEB4ADACABAC
B0AFA9B2ACB0AEADAEADAAB0B8AEA8B4AFB1B4ABADB0B4A3A6A9ACB4ABAEAEA8A9A9AAA8
ACA6AEA5A4A8A59EA1A1A3A5A39C9E9B9BA6A0959B9F9A9F99A197939D9B9D9097989397
958D939A98919B9891979195929292918F8B8E8F8D898989948B85958E82888489888584
79867E7D7D867C7D7F797D7F7D7E77767E8176807A7C7B72787B7275797B717A79766F75
7474747372786D6E726C6C6F6C716E6C6D6F6E756B6E706F6C69736C6C6E676F65676E6B
6D6868646F69686263686864655E606568636363686C6968655D5D6169615E616462605F
5C66615D615D5C6362616060675A5D5D615F696362605C5F62615D5B645B605F5F5F5B5C
575D63575F58555D
64625F5C6765626761656162686361645E6A605F6166626564606D62686566636261656A
6B666561616868646163696D6263686A6B62706A706E6B6D7368666A6C6D6D6771666D71
726A6F6D6D716E67706D66726E6F7F7382787870726E677A747973706E6974757E707B78
7475737474787278757578787680757D7E77757C788079857A78888082797D7F82798485
877F817E87897D82828B84868B8A88888B898788818E8B8B898C8A8E818D928C918C9194
9395958E969A8E919A968D9299989A90A2A293A69FA09DA2A59D959DA1A4AE9DA4A1ADA0
A5A4A6A9A3A39EA7A7A2A7AAACA4ADA6B1AFA4ADB2B0A5B2ADA8A9A8B2AAB2ADB1AAACAE
B0AEADACACADA4A7AEACACA5ABA8B6B39FB0AFB0A9A2A6A8ADADADB3ACABA9B3A59DA8A5
ACA2ACADA6A9A0A1A2A39CA29EA2A1A09E99969B909F9A9D999997A2A39B9294959D9798
979293899799958E8B9B9494888B8C938D8F8E8A898D84888686837E848C8389867E7F7F
848A80848387877F7A8E847E7F7C7B7878767F77787582797B7D7B807C80757A77777675
7D7378756F7878777475677972706B736E6A6D736C74716C6976686C6968636E666B6A6D
6B6168656664676467606968646464616D5B6464666861656C685F625F61655F69625F65
5F605F5C606762636162625F695F5266625F615F645B645F57585F5E575C646A5E5B5C58
6056595D5E58525C
625D5C6164645C68625E62666465656267635F646263666562666063605F5F656A616465
635F636C696969626B685C656369686A6D6E736D6D716E6E6E6B6A666A66686E6D6C6A67
6A68666A65696D706E736E6D737A707479776F767270676F75757D6F7373726F766A7673
797476737773767A7E757778747D757B7A777B767D7D797D827E7E7D7B827F818079857E
7F7C82767F8482847E7E8B8C898A8E8C888382848587888F8791938E888C8F9089948F8E
98928E989A968F92999B969C95929296A29B9A96A39F9BA295A39C98A29EA39EA39BA0A9
A9A9A6A2A1A0A7A4A7A5A7A8B2AEADA3ADA6A7AAA9AFA9ABA3A6A0B5ABADA8ADB8B2ABAD
A7A9B1A6ABA3ADB4AAB5AEABAAB3B0ACB1AAACA8A5A9A4A8A7AEA8A6AB9EAAA8A39FA8AE
A4A2A8A2A9A9A3A99EA6A19F9BA3949CA8A09B9F9D9C939E99939F9B949B91989894959D
97889296968F928F8C8E8D918A898F908D8A8A8B8F8F888786848A88898F8D8983867A85
8484848682777B7E807A82817E7A7E7D7C7A7C7D7F79797A777578756F71767374716E75
73727775787576746F6E6B6A72726B696E6B676F6E6C6F76706E696C6A6864706A64666A
6A6E6B66666566606A63686969676569686566615C6563686356635C605B5E6457646661
5B6062646361686C5F6C605E616264676760666564655E6262636666605E616565675C63
5B60585B615E565A
65676763605F60536761616A616769645F675A61635F645E646661666A67636566655E6C
6963686562656666696B6761696C6D6D6A6A666C706E6F6E6D6F68686D6A6B696664646C
70697267706B73706B7064736C777170737675766D747071756F756B737A727672747873
7D737472797B7578757A75787D767F7A787C857879847E7E818484777E867E7D837C7F7B
8682807A7E888389818F7F828282888B8786848D8784898F868B85898C868E8686869293
8E9387918F949792979993969D939A9A969C95919EA0A1A3A29AA09B9D9E99A0A49DA19F
A2A5A2A19EAAA5A79BA5AAA69EA8A8A5ABA4A6ABA4A8AEAAABAAACA0ABAAADADADAAB2A9
ACADACB2AEADA7A5AAA9AEB0ABA6AEADADA6ACADA4A39EAAA2A4A1A7A3A6A8A5A6AEA7AB
A198A5A5AB9B9EA3A7A89FAAA5A2A09B969F9D9E969E9A929A9B939899969B979E9A9898
8E96978D968E928C8D8A90928F8C8D8D868D8793878C858C888583898589808180828781
77867D7C817D888679817C7E7C77767C7E83807E767B7B7676757276757473707976716E
7578746F7871737C736B6E756D706B6C6B686E6C6D6C72706B6F6E706B696E6C6F696768
6469656E61686864655E6C6A68656260686463676268586A5D615F5E6667616263635E65
64635C5D5C5C5F676466636065615F5D5F5E6162635D61585C5F665C6363595E5F5C635A
5F5A5E5D62615B58
616A665E6266635C6762635F605F63635D5D676260626169676162645F60656263656661
6B6467616664705D70686A6D6A636C5E6F706A716F6D716F6C6E6B6B696C676A6668696C
6B63666F6C716D6D6C676D716D6F777574766F75757373706F706D786F6F7A7171727975
79717671727470747A7A7B73777A727A7B7A7C7978837981817A85837D8080827C818578
82837F7E807F808080887E8284848B7C898A888C858F8B8387828D8E8C8D8C8A8E958C93
8B90888F9791919596969A958E94979592A39C9A979C9D9F9D929DA198959E9BA09CA0A7
A5A09DA59FA7AAA39D9EA99FA6A6A2A7AAA6A2AEA6A1A1ABA7ACA7A7B0B0B0AEA8AEAFAA
ADA0AFADA9ABA7A9AEABACA3A7AFADABB1AEABA6A39EA5A8A1ABA5A5A9A69FA0A0A4A7A8
9DA2A49CA49D9B9F9A9B9797A09B9F96A199939E9F9A99A3A098989C9E92919B909F939F
93979296909A8C8C929195888A888F8D8F90828B828A8D89868C8682887C88888282807F
85857E8687817A8084787C7C7B6D7D7A787A787B78817774787C77807A7B76A484747970
707774696D7773736D706F6C69676D6F70716A756B676E6D6E6C6F6D69696568676D6B68
66676968696966636262656866676466646A68595C566560636161606469666363656071
615F62666A6463616558615A6A5E606258675C605F5D616460625D5962675D5D5F5A6259
64565C5D5C5A595D
645D5F5F5E5D696762625F5D6866616163646A645E626A6C5F6163616669635F6864606A
6565666166696B5E686D63647073656A6A766B776F6B756C73696A646669646A6B6E6F69
686768666A726C6E6C706D6F60707373786C717576746E6D70747B7272747A7A71717470
727376737575757676747C757A797A737D7C807278817B817E7F817F818581808180897C
848080817A7C807B7D808A83858184817D8B868982878A8F938D84888B868A89908C8E8E
92999A968D9795979897979592959B999490999E9A98989F9D9E9E99999C9CA39D9BA19E
A6A39D9DA69F9E9D9EA6A7AA9C9DA59DAAA9A4A4A8A3A5A6A4A7A9A9A9A3A7A7ADB0A7AC
A3AAA9AAA2A7A3AAA4AFA3A1ADAAB2ABA1A4A3A09FA5A3A7AAAA9EA1A4AA9F9DA0A1A4A3
9E9B9DA29D9FA39F989B9D9B9C9CA0A39C9C9E9B949E9B9597949999918EA19595939694
8E938F9A958F8D8F94898D8C8885929C908C8E8B8B8E88808488878C7E877F8386857C86
82827B797E7B8084757E837D7C7E7A7A797C7E797D7A7A7D7A7471787A7571706E737075
7465777B6F6F6C737170736B6D6D686D6D766A6A67766A6D6A6468686E6B636765716B64
6B6560706D6765616D6864656B635F615D666D5C656B5E6466625B5B69666160615C6661
5D695D625E68615F60625E6666606563615F5F645F596060605E60605B5B5A5E63606161
555C5F5D5A5D5A5D
5F5D615D5E6A635E676865605F66636368626A5E5E5F635C646668615F66686563666761
6461616865696A5E6262665F6868646B70716C6F73716D6E696A6E6F676C656C6B696F62
626469656D6C6B6F7365726B73706B7273766D716F726F77747271716F7273717169707A
756E746B757674757477767D7A7D737870737B7B7B817B7E86857A7D7C79827C897F7E7A
827C817D7E7E7E8584818587847D888984888B848387888C878C858A8E9187938E8D8A8A
8F928E9A918F8E999484929099929695979E92939A9594909D9C9C969A9AA39B9E9D9C9C
A1A2A5A09FA3ABA79EA2A4A3A3B19F9EAAA8A1A4A6A3A7A89CA6A7A9A7A2A8ABAAADA5AF
A7A7A9A0A2A2A6A6A6ACA7A9ACA39CA4B3A9AAACA6A89FA59FA19CA6A29EA6A5A19D99A1
A19D9AA49F979A98A49E9C98A098969BA09494A19C969E949795989B8F93999794979487
8B918F868A8E908E8C848B9289948988878C8D8F888C857D84828B868386807E89838782
818581817F7F757E7C7E7D7D7678767F797A787A7B787576747A757979737172747A7470
79737376707468706E716C706D666A757E73666D70716570656A6F6A6868676E69726767
686A5E646D67696C5C5D666A63646465626663666064665F64625F645F686C65676B6164
62635F5F66625A625C6463606260625D5C5F605B5A5B6761615F545E61675E595963585E
595F6063675D635A
60655F5F60596A655B695F5E65646A646365666A646163605E6561686466696766646864
67636C6167635E636B696D65686266686E6B6D6A6E6D6B716C656D6A67716A67676D6F66
6571686874716967676B697069737071716F6B71776B76766D6E736E696B6F6C746D776D
746E7D7573737371727775787B78787676787373797B7C7D77807A75807F7F7C787A7F7D
7C7A7A7E8086847D81868F8A888985858E8D89898684838988858C8D898B8F908E88918C
8B8A9190978C908F9488978E8D9E9C9B9592959C9E959B95A0979B999AA0959F9BA5A299
9B999999A29F9E9CA2A3A8A4A4A39DA4ABA3A2A8A7A19DA1A5AA9BA5A5A7A6A6A7A4A4A8
A9AD9FA0A5AD9EA9ADA29EA39EA79F9DA3A0A0A1A1A499A69FA1A29F9FA8A8A0A4A3A39D
A1A49E9B9E9BA299989A9D989A9B96979BA3959DA2919B90969592989B93929597909994
8E8E8F8B948F9190918B8E8D96908C8A888F868D8C8F849186848480887C847F7F858281
8A7A867B82858183797B798680797E7E7C7F7A78748273757F767774747771776E797373
70716E7871736D736A706D6D7279686B767368666E6A6B6E6C6D6668666E6A66606A656F
666C62666D5E5A5E65646767615F65636B626662685E656966606462615F635E63606062
6965675A6460615D5C61595E666061676462636761665F5A5B6159595E5A596164615B5F
5A5E5B5E5F5C5B61
61645F5F636158637064636364666665675F6967686166686563686660636563676C6767
696B636261656B676869626D666B6C66746B696B726C6A6A666C65686E67706A646F6C71
73696A696A6B6C686B6F6D6E6E706E6F6D7B736B6B7173726D746C72746D727975717672
777574727173746C82777674767A747A7C7679777A787A7F7D7B7F7D80797976777B7E7B
83847F817B858B8082837982878F8689908A7F8583898988888B87908F898A848B909491
898C8C918F8D89889193928690969892919490959D999690A09C9A9B9F9EA1959E9FA09B
A2A09E9C9D9FA5AAA0999DA1A1A69EA1A1ABA69EA1A2A5AAA8A1A4A5A59DA2A3A6A9A2A7
9CA6A5B0AA9DA39FAAA2A3A1A2A5A1A7AA9F9C9BA0A4999D989FA6A49B9FA49A9CA09A9E
A69A9FA59EA4A195959A9A9A9A9B989A979A959699909B949893979199948D94928A908C
8F94908D94918B8D8D8C8F89878D95898D81899188858685858984888880818280847D80
7E807A83807B797E797F7C7C81797F746E7A7476777876757173747079716B7178706E70
7167747672716A756D696E6B6F686C6D6C6B6D6C72726E736C67696E676F686A6173676C
6C68686769696A5F616666606562646460676660625E6462646568626A62646164636264
5D5F645E625F625B5F60665D645F62645E67605C635967546263645A635B5C635D5D5F5C
5C5C556067615D60
6462645F5E645F625B62666066676B62626E656760686268656A68646768656F66656863
60676667646E6C6567646B6767616A61686667696E6F676B686A6A626869716C6965686A
6669696A716C6E6972696F676A6B6B6E6F66736C71756D6E737476706C6F787679717075
707477767A727674767F77766F716B737A78797C7C79807E817C8080827E787F7A7D7F7D
7C837E797E818483837E83888B8A868A8482848785888189878B8D8A878592918A91898E
848B918E8889898A8D8D96919790938B929896949794979B9D9997AA9A9096959C92979B
969C93989CA19BA39FA59F9EA59FA2A5A2A499ABA1A1A59DA298A0A09EA5A5AAA2A1A3A5
A6A2A3A8A8A99F9DA0A5A2A4A5A19CA8A5A0ABA6A1989D9DA6A5A29BA0A1A79FA2A19EA4
A39E9695969B9E999B9A9C9B92999F9B979998948C969C91969394949793919491938D8E
918C9490889390928D91808B8E8F8E8490898881878F8B8A87818187887C867E807E807F
857C8281817F7E78757C7C77767A7775797B797776737271767672747576736E71747075
6C6C746A7072736F6B6E6F6B68676C786A6D6C767568706A6B68666D6C696B6D68676E65
646765676D655F6F686C696A6C65606963606662676766615D625E5D66635F5B60556361
656560646762606567655E5A645B5D59605E6066605F5C5C5A65615F625E5F635D5D555C
585B625E5C5A555D
645F5D5D5B6060656164565C63606562686268626A6C6D676A6D6D6D6D696870686D616C
6A6E696C666D636B616A656B676C6B6A666E6A6C6A676761666A706B6D6E686863676C67
656365676361696E6A6B6D6E6E6F706E6F6D6A6C6D6F6D6D6F7271736E756D7072796E73
717074717572747679757A6F80787C7476777D75797A837A7B797482797475807C7F877F
82817E807B7C7F85857F7D8B7F80838D838284898B7F848C88898A88888A8D8886878A8B
9095938D90958F8E8E998D8D938F8D919091989A9D9194959B989A96A19A9B9CA39A9795
9F999DA39B98A19BA09E9B9FA0A09E9D99A2A29F9FA2A2939E99A4A2AD9AA49FA5ABA896
A3A5A3A79EA0A8A4A19FA5A19BA2A39D9CA59DA7A3A4A0A0A198A19D9D9B9D9EA2A1A3A2
9A9F9E9BA09D9C9897A6989B9E9C989B949394979998919C9397949788959190968B938A
938D8F8D8B8A8B8F8F928E8A8C8E898C8E7F82888F8E8886878483857F82888584837D7F
7E7F797F817C817A7F857E7F7A797D7F777A767A787470717576747370717670746C6A70
736C7673686D707372735F747072726A716D6B6E66737266656F6862636A686665666D67
646D6A67636366695F646C62696265666B5D6363686161645E626A6B5E666164605F6166
5F65625F5F5A60646356635C6366616B6463605C586157595B605E5958625C5D575D625E
6260635B5E595D5A
60576261645E65606364626469616465677069686E6B6A6E6D71776670716D6D6C636367
616266646262636C666672736B6868686668696C6A666969646A6B6B6266676B6E6E6A69
646B6D676A6A717566696F776B706C6A736A6D72706C6B72726F736F706D7774726F706F
7274706F6D777672757777717874757674707976827E727B7D79797C7F7C837D7C828174
7A817D85807B7C848587837B7D86848783827F8E868A898789898E898B8784898F838B8D
8A8A8A878E91928E8D919090968C98958F9A9595959195969B9F8E9C94929E9C9C94989D
98A39DA09B9E96A19E969D9B9D9FA1A59DA8A59599A79BA69AA19FA09CA098A1A59BA99F
9EA79EA29D959999A09E9DA49EA2A9A2A09BA3989DA69B9BA59CA3A79A97A6A1A6A4999E
93919E9D9A9F999A9D9C9BA1989A9C9F9A9B979A9A98949196928C9191948C94908B8F91
8D8B91938E91948C8A82888A858D849086888A8B80897D82808681887E83837F7C7F837C
7F847B79807D7F797F707A71767575797B7579827A757C78717975736F76747879756F72
71766B76736F6D75727161696A6A69676C6B6D6F6F676B6765696B6670676966686D6A6E
6C65646769706762656366676065635E6769665E666866625D6567606063685967615D60
5E60676A675F5A625E5C625B6663615E585D615E5C616063605D5C5F5D5F655D5E5D585F
5A5458595F57585B
62615A606562656B5F615F71636369666D656A716E6E6C797578747F78736A6F6A6D6766
60626C605E646E69646660696567666E6965676668686A64686C6A6766696666676B696A
746A696C676B74736B6D68726872687173686F6D66696C70716D6D6B7073757370717971
6E736D766D7371766D72787870787C70726E7575827A737E74797E7B7C7672777D7F7A81
80807E817D827F82827F847D87808188838785897F8A8783848E82878E818A8E8C8F918E
818C8A8F928D85938E9095828D9290958F8D8C8F8B978D989C9C9C979D9A9C989A9C9797
999D9CA1A09D9FA19B9B9E9AA09EA4A3A298A19D9F9DA3A2A4A4A49EA2A1A29D9FA39CA8
9FA0A69B9CA3A2A19FA59D9B9A9DA1A0A2979F959A979D9F99929DA09C9DA49997A69F94
9B9F989C93989798909793979B96989B96969D939093928E9C97928E938D909191908B8C
9397918B8E8D868C888B878686877E8C8487848483858883897E8185888082807E877B7B
7E7A7B7D7D787C757F7A7A807D70757D757B757C7878756D6C7474716E72736C7171747C
6D6B756D6B6D6F706A6F6A6A696D696A6D6E666F706572696B6F766A6867686966646668
6866636C61676969626A64666A6E606764685F6760626865665B625F6A63655E5F5C6559
625C555D5B6363635D625A5E5B646962635F5E62585B5F5E5C5E5F5F63605E5B655F6756
5A5E615F5C5A565C
645D60646362655E5A64635E6064696C68706D6D78757A7F8189898178786E746A6E676C
68646A6A696C6766696666686A6B62656B63676D696A65696864696B646E696772676167
69636D6A6A736E696A6D6A716F67696C6D66706F6D706B6D6F6E6B72746C777A706F6E70
74707570767D6D767275737775746D737B71767E7B7A7C7B767D797B7E7E797C81788376
817D7E81857F818785877C7C8A858B8284838589857E8587818A84888A7E8087858A8987
8F958995888B8E928C8A8E96908D948B8D9B939090988E9993979A92939D9797979D9597
9A999B969E9C9C9F9599A3A2A09C9C959AA09A97A3A09B9DA1A3A1A79D9E9CA49C97A49D
A1A39E9AA69F9FA0A39C95A0999A98A1989CA79F9A9DA1A2A39D92A399989E989F9E9F95
9C9497A5919799A09B97949492909D9A939897919094918E8E8D988C96908C8D918D8B8C
8A919191868A8F8984858D87858988878B838788888E8588848A7F8285827D7F85797A81
857C757F757D7D82757674747B777D7877787977707278756D6E7D7675737072776B6E69
796F6D706A7769706C6F686C686D6B6965696A67676A646E7167656A6C6A65666A6C6865
6C656B60696F6570605B63696766666162676663625A5F6163615F6163626364605F6062
5F656C615C625D5C5F5C615D6160686260625D5D555D62645F5B5B6157555B62635E5B5D
5658575B60565F56
62615C5F5F69666B61616462626068646E6C6E7483838D94A2A3A6999A7F7A776C6C6B6B
5F64606367706768666A66696B626B6B676667686A6A636B6F6E675D666A6F676A6A6F73
6F6869687567696C6A6A6C6F696A6F77726E6A6E73676A707172716E6E71767769796E71
756D726F7A7277787274706A7175737E756B777A75747A7779767573747B7A79737F757C
7D817C8084817D828084848185868B8B8289878187868185818A838587828786878B8D8B
8F838B8689858A8C898687938F90908A8A8D8E8E90948F98938D929195999E94979C959E
97A09796959D969698A09C999A9C989D9C9AA0A0999A99A1A19D9A9E9D9A9AA29D959D9F
959FAA969B979DA39C9F9C969A9C9A9CA0A1939AA19EA3999A99A4A495A292979C9AA097
99989A9B969894989C999594929D9F9792919698918F908E949396908C89888B8E878E91
8C92888E8E938B8E8885868782858A898A848680878486857D857F857D86817A7B7A8383
7A7E80717D7E7B8684797A7D7C7671767971787B767171767B757271736974736F75726F
72696E676E726E6B6C706A706D676E6E706B6A68646962686A67616D6C6E6E656B63616F
686C6D6861626965605E656B666A636A5E6362645E67646060615E6365635F5F5F665C5E
665F62655B5E665F6B5D63695D625D66635D5D5C5D675B635F655B655B665A645C5F5C5E
66625C5B5F5A575A
5C615F5D615D5D626962656D6166606B6F6D7A7C7B9CA5B7C7D7D5C5B694897E66716A69
67676A645C69656861686966686E616A64685E646469686965696B6A6B69646667676969
646367666A6B6D6C6A646E6769676E6A6B706D6F696A706E676D6F73726C706B6E72746C
7471737372757E6B766B736E7A7A746D767878797578777678777A7E7A7E76707E7C7D7A
777D7E81817E7C837F858582837D858F8588888B85877E84828286898B89847C8C8A868E
867F8686898E838E878E88928A96918D8896969798929896979097989691979293949991
9B9B979696949F959B9C9194939B9E999B9CA0979FA08F939AA19A9BA19A99999A94A79F
9F9A9FA5A29B9C9D9A999A979A9F98979E9A939C9B9E9A979C969A949D9DA09C9B98939A
9C988F9F9B9B9593949792949A96999694939795948D999190968C8A908E948F918E8886
8C878A868C8F8E878D818882888582897D83838989828382797B7D7E7F7D778286807780
8881807F7E817A777A7B7B7B717A7479777B707178786D756E707175706A766E7175786F
6C726D6D706B7066696F656A6A69726E656B616A6F686B6B6664616C6165636668686469
6A6D645E675D68635C5768625F606367646A5A67645B6A61655C666462625E60605A6566
64676560616366675A616164685860656264625861635B655B5E615C5E5B5D6061625B5F
6163675F5F605663
6A646063645A6260676464666668656774737A8696B1C9F1FFFFFFFFE0BC9D8678686B69
6B67675C625B666262656565675B6965646D6C67666961636769636B71686865676F6F64
6B66676B686C6C6F6A6A6B6E6C686D6C736A74706D726F7274736E71716C776F6F78736E
716C7771746D6A7475706D726D70736E6A77727876797A77797D7A7678747D7879747B7B
7C7F84807A7A7B807B798479858186878782808A888784848187818283838384837F847F
8B8285878E8F8A8D858F8A8A9292948C918A8E918D908F8F9693928E968C9A8B9C919593
9193A29997A19E969B959A96939A9E979392989F969B9DA7989A9FA3A09D9B9A9B92A09A
989AA2969698939A9C9EA19A969A989C9D9FA19BA1A09B949C9E9B999096929A9DA19493
919698979195919D96969397979E9292908E99969995938D8F918B8E918F8A8B948C8E89
8D84909288858185878B8189868082898D88818788817F78807D7D7D7A85817E817D7984
7C7D826E7C7D7C767B7979777D7E75767873767577757A6F747773716E746F706E71716F
736D67716F716A686769746D6B6C72696C666467646D776A6C68626268686B686A6C6463
6667636767675A696A616A6B6364605F635F69656A64675E646967666B68616266605E61
615A5A605F6867626F62696365615A606063605B6463615F5B5E6358605C5F655F5B5F57
625D5F5A5D595756
5D5D635D58655B62606264696860716C70778295A9D8FFFFFFFFFFFFFFE4AC9879706C69
6E7165636E6A6460656661665E646466666969676A64606A6A6969676F646D6A67666968
6565667066727368696F676A6E7174696C6E6D6C6D6F6A6A6F6F66716E73756E736A6C76
7175736D7673757071746B737475747174726E756E6E777C7E7B7B757C747470767D7A7C
787F7D7D7F7D80837D7E76737E837D87808280868E7C8C8B8B8282858287877A7E868982
8A8987848A92838F878E868D88888E8A8E989193908B929595978E969693929695999395
939999938F93908E99999892949E989A98929698959697979D9D9A9F9D9F9DA1999AA39A
9C9B9B9A979393A19BA0909A9A9791999895989498979A95A19A949299999D9D949E9695
98979D9C9A95948B94939793959199928C938A928C908F8A8E92908D9280878888848486
8D89878B83889089898A898387807D818286837E837E827E807C828181817B817C7E8380
787D7E817878767976747C767E6F7B77777779736C757073767C6E7770726B6E736A7467
656A69716D6F6E706C6C776F68666C5F6E676A6B6F6768696B6772676463696B62625F6D
656568616766666260625D6565626B6A566B625C5D63616064625E6563626160635A5E6A
5E5B5F595E62636466675D676366645D5B5F5D5A5E615F6360615C595F5E5B5F65555656
5F5D605C58625E5C
615E645D5C5F616960626763666F6A69718195A7CFFBFFFFFFFFFFFFFFFFC09B7F7B756E
6B6568685D676769605F6961625F62656D6669686362686964676F67696463676B66696A
6A696C6F6769666F6C67726E6969726F6D6C6E656D736E6C70736C6F7370706C6C6D6A6B
706E7073776E79757473776C747372797675777D776E827B6E757B748080787476787774
7775757C7E837F79838180828D83848381868C88838881868181898088828581828D8A86
89908B8589868D898C8D8484898A8E89918B8D92938B9193919096908E959A969391919A
999299929E8F928C97919195959A8FA39B949A9EA09997989B9B9B9895989E99929B9899
9B9B9A979E989697978F9992A0988E949C99998F9B9D979399929C9295959A91979A8D8F
959296949293929199978F98979190919794928F8C928C94908A93898E88898F9188908C
918C898A81968B8C8D898A808A8280827D818781847C7F7E82837C84817C7D837A7B7D7C
767D7D7E7C7F7B81807B76756D7B7A7B77757271757271746F73716A706D7A6E72716E6B
6F74746B6F6A6D716B7071716B6D6A6C667166636C6569675F6D6B6862666866665D6865
5C65626A6769636C696665605E6B6363636367656D656261685F64655B6665625D596364
5D61635E685C686D646860615F586361635D645D6A65685E66555A61605E5C5E5E565757
5F60585859605B5B
615F5F666666626261626264686F6B7574889AB9F7FFFFFFFFFFFFFFFFFFD898866E7167
66696D6769606D636366686867636267665F6C68676366676A6768676A6A6C666F6B6767
676A6B696A66696E716B6C686A6F666A68706F65646A787274777577727373767177726C
6F7B7473767977766D7172747171777471766F747373727E727D7573777A7779737B7D77
767B77827E7C83867E76827C7E848281807A8A7E80847E8D7B8181868588878891857F8A
848C8C8F958794898F8C88898C88888C888D8E8E899287928E93909492968C8F97949092
9B949B929B929996959D939094958F8E94989A9B94989B989B959C92999D9D9799959495
979794999A92979A9A978E9594949998939196969D99929F9C998D959392999A94909A91
97908D96948B92919093919693908F92909492958A8D888F928E8D888986918B887F8A8A
8281898D868C87887E838783837F878B8280827E7F8280807B79797C7C88817F817B797D
7E7E7B7E757C757F75777C7371756F71707172747B717270726F7174736D736C6E687272
72706E6D6D69646E6965676F6A67736E6B6A6E656B6B6767656A65616A68606B68646E62
63676B6B67686D6062715F666665625E6164605C5E65675D6862595B62655E635D5B625F
63675D5F606366625F5C5C5E605F5E625F5C61616361686E5A6463615A5D5E5A5F585D53
5A6560635B5E5F60
625D5C615C63616564615F6261647072788BA7D5FFFFFFFFFFFFFFFFFFFFD49E87756969
6B6665666C696569676C686B696061626B6F68656B656C636262676A6B6A67696D666764
69666D6B6E696B6B6C6D72666C6F6E756A7773696F74766C6870746D72696B6870717C71
696E75737171716C6F706E71717776727A757472767A7D777E7C727F79797C787780727B
797974807B80787E7C7A817E7A7F8082847D817D8384888A8A8186878285868583858284
8B8E8E8E8E9190958A84918A898F908D8E9593898F8E8C8A8F91938F978E8F918E94988D
9597978E9B9794979A969A99929495979D959A92979499969E9396929B9C9992968F8B9D
99959391A19A979B939A97959494919E95939B9397969A8F9A92969D96929B979B93959C
938F8D8B8F8B94938C948D96938C918E98908F8B8A96908B8A8A958482888C8C8E8A9085
898C8A858E8A818A8B828A8084818383828281807D83887B817A8180847A81788376757B
7A7E7C7A75797E7C7D797676767275777376797181767B7A757174716F6F6E6F78707170
6A6F6F6D72706A6E696C686E6A6F646E6C6667696769716D656D66666365626663676969
6768666265605B605F616D616963676662626163626664666062666464635A62605F635D
58615F6A6461616467685C6364595F635F5C5F63605F68605F645A606260645D615C5C59
5C59605F59595660
606060636065626163676363686F6F787A8DABE1FFFFFFFFFFFFFFFFFFFFC5967E74716B
676364656969636863636564636763606C646B696867646761666961656B6F6767696667
676B67666A696C7067696E64667470756B6C6F6E696B6F73716B7070706D747275727177
74707A79746E7277776A6D716E7C7274767B7578807679737C78797479777D797C7E767F
7A77817E807A7E847E7F847B80807F7E8582817E7C84827D7F8285877E82848A84908A8C
8F8793A99B938986878F858A8C888F858F90848B9088948C8C898E969798959390998E92
8F919399999493968D939C959490929592959699969E96959B988E969390929A9395939A
999094998B9298969899928C949C8B9891929A91948990989694929590908A909D8F9A90
909398928C949B8F9A8C97909197958A91918F86908B908E8A888D8988908C8B82868A8C
85808393887E84898683857F877D8489827D7F7F837B7C7E7E797D817980797B7D777476
77747A727E807A767679786C73796C786F707D747F74767073766874736A6E6F76686F6C
7071726F676C7075696D72677069646C6A6D68706F6464656B6B6B616D6C616D67656669
656170686A6566686B6A67615C655D6363615E5E64675F696566665D595F595E69685C6A
5F5D6164636164615E5E68655F5D5E6061615B645F5D696361626060625A665F61605760
645E585F58575F5E
64655B615D5B615A6463646B6A72746E7E93B0E7FFFFFFFFFFFFFFFFFFEEAA937D6E6972
6A6764686367636C6C5F61656365616866676766676664626166686764736B6466676769
636B6B6A6C69656A656A6C67686C656D6B70686B6A6A6A6B6F776A6F6E6F736E646D7876
6D736C726D7570726C6E75746D7D6D7473717470767A7879787B7B7C7468787E7C7D7C77
7D807E7F7D807B7E77797E7D83838080827C87838183857A837B84838B7F87847A7F8488
8C9096B29C8A8B8885868D89888E898686848E8C888390928D94948D88889292938F9996
989F91969A8E939C97918B96929093919B93959492988E9995918F9096939699958E9795
918F92989B8F9A969794938E9396948B9199949697918F968F919394968F969399939195
8D938C8F8E948D9494828F8E8F8F8D8F8E8B978E8C878B8D938E878C8D84888783908586
8383868F858786807F877F80808B888483817E757A80797C877E8282807D757F757B7D79
79786E7B7B7A747678797D737A75777276777979747673737072696B747274706D6D7270
7373696F6D6A6C706D71696D636C696E6A6B656B6C646B67686269655F6968676B61665F
646C6666626369676A686B6065626B6463625D655E625E6260626366625E605D6664655E
606C6163626361656A5C5F615E605D5F5D63636864625D66615B59615F5F5E5D5B555863
6159605B57605D58
645F615D5F6361686B616571686C757A839CB1E8FFFFFFFFFFFFFFFFFFC89E7E80786869
66646F69676467676666646165616168696165686665676663605F6967626D6467697064
63686A68696B666D72646A666C6D6A696C6F6B6A6F6C6D6B686F6D6F7475777270747270
6E6F6C6B7B717072787570736B77736B727A777174756F797679757A7A77737E787A7D7B
797F7B7F788379797F7F807F797A8B81808179827B798480848382828882828377848889
868C9091928B878D7F8982948B858B8B8B908B8E8C93819186908D898A8F8F918C928B99
9095908F968D8F8D8B8B9292909596A08F9A928C928F8F928E8F8E9B9A99989894918A8E
8C948D95908E9192929093949495989293949198959590989492968E948E9093918D9493
908D8E8E8B8E908F938B8E908690898893908688898D8C8C9188888E888985928D8C7E89
8D8B8E8785828583848283817D7F7B8A807B8479867E857F79797D7F80727F787D758077
7B7A78767B8378787879757B7377746F747B7C7673706F6F6E71766D6D706D766C727B7C
6F6F6E6B706F6A6E6A6A6872606E6B6D69656A696369676D6B6B68696C66646F69626A65
616A666B5E656267626E6A62676A59645B67606565626462636764676664686362636B5F
5D5D595E646360645E6365576364595E5A6062655D625C615C6162585E5F58615F635F5F
605864595D59575A
615B66655F5E5B666767676D686A7074848FB3E1FFFFFFFFFFFFFFFFE4B599857571716D
6B6569686C676868676568666E6067656260686468696A7065646B636D6E63686A66686A
666B6A616C696B6C67646A6F67706A71696D766D6A746A7273726F746B73727571747771
73747074706E7577746C7968726E6C716F777174756C7177757A75737777727B7E757D79
7B767B757C797B797E7C7D7F8078837F7F7C7C80897E7C7F848584848782888084807C86
858E8A878F8B86808585888C868988908F92898C918B8D88878F91938C9A8C938F8C988F
9C928E90958F908F948D8E93949B909792988B96989190949290938B9495999796958E95
89939B8D96958F9A8D939399909A95949A9A9490949A9890918F8892918D929191969691
93938B8B9389908A8B8A8C928F8E918A91918890858D8B8D868B878C898E858484847D84
7E91898A868480838B8084857C83838876847B7E7B83767E7E7B82747B80797B7472797C
7B7D777B7A7380767577717A78797674707970757A7F757273726F6C6F6E6E6F776F7066
72727A6D71636A6B6969666D6A716570696864616A64686A66666161656565646A646266
6F635A706563645F646B67625F675F605B636364636A5F62656C6364696360646160605F
685F6166625D6363605E64605B60555E605F59695D66665B63635A5A5B5F615D5E67555A
5C57625B605D5E5D
5B595A5E5B5D68656962686865686B717589A2D5FFFFFFFFFFFFFFF7B694867D74717064
646968666360696B676B646765606663696264656D6062656368656A6E675F6968686D67
6666696A6763676C656A6A6869676D696D6F6B69736B666A72666D6A6E7375717F7E6E71
70706C6F6E69716D776E72687778746E757279777E7A737F756F77757873767475737876
757A74767A787D797B7D767F7880767E7E7C7F7D838275817C7E85827B7D857D86848280
8B868A7B888282817F8385838E838989878B8B8D8F8E9388938E919091958E8797939292
9D8E8F9296978E92908A9190988E9690959490968F97958D8F8E9395929193958D889298
9787958F93929695939A8D94928B929B959390938C948D8F9694928E8E968C8F928E9392
898D8B888D8F8D958B8C91908B868F94858D868C8E8887848585838C89878E8B89838782
8A7A878584897F7C828889858786778184857F7A72807A7A7C827C7586747C7E817F7F7F
74767B7A76787C76786E7A75787A74756E6C777677726E76746D7377736C73697375756C
6B706D6D6C726F6F6B686A6A6E6A6B666F68706868666A696B676A656A6B636A696A665F
685C6266686466616A5E61635F61646760656564636B66596A60656063635C5F695C6256
5A5F5C645E605F5F64615E5D655562646462615B65695A5F5C635E5B585E5F605D605E5E
5E5E69605D5D5C59
6362625E5F5C5E6A655F6664656869757A8198BEE2FFFFFFFFFFF8C09D897F776E677360
6A646967666467625B6565655F696468685E68676464616D6567605C605F686A64666863
666566646F6B6C7265666369686A6E6D71696D6C696E706770716C67757970787FC57676
6A7170726F73756C6D747277706F746F70717E707371757B747D76797A78777776707976
707C73797B817E7C7E7683817C797D81817D7B83797F7D807D7C82808385827A8486818A
85877F868985807F83848989878785868E85908C8F9088958491888E939791948E899093
8B8E889794898E9390909691949096949596948F8F868E9797968B918E928D8D92959094
8D8D9195919497968C9698969490979E9C8E93908F968B9088958D8F91918F818F918D97
8D8C8F938D878B8F88918A929091838E8B8984878B8C8788827E888E8F8985878487867C
898F7F85837C88857F7D837B827D7D877B7B827B847C7A7E83757D7979747F79797B797D
7C7D797A7574766F787A796B6F76787770726F7776736B71776E6E726D6F717071706C75
74696C61706D6D667170686C6F6C6C68706470626B666C666668676567636369646A6069
686C646967646666626562686059676668696162676B5D666060655E5E606A5F67615E63
5A5A62635E6063656265656566636269625D5A5B5E61626361635F67605A5B5E5B5F625E
615C585F575C595D
605F65616266655E62656366676B6A6D737E8D9BBED6E2ECE0CCBA9A8B81746D6F706367
655A6462636B68626360656E64626363636B686A656265675D6469696266686C6B6B686B
71676A666E6867656D6867706C686A657466706E6E68706D726C716F6F73736C7A6E6E6F
747471766E6F676C6F706F6E706B727477767777767975756F7977717678787D80797B7B
777D7C7A7C827B787F787F7F7E787B7F8386807B797D8179817A7B7D837B7F8580848D8A
8A85818B84838583858680848387878A8C8887908A8A858A87878C8A90938E968C969596
89898F8F8E8C8E988D958B93848A9194978F908D93938E9698929190898B8B918F908C89
9491959592968E96998B948E98968A8E99888C9890908E8F8D8C8990958B9089948D9193
909B8B8D8A85899D90928D8D8785858A90898787878C92838085888288898488817F838A
8A818A7F8C8A85817B87817E837C7C7F8082827C767B787F767E82737D8182798177807C
7375777D78787A797771727B7472767976717376707070777572707073727277686F776D
6667726E6D66706C696E6A72696F6C6B6469656061696568696B64626968606364656262
675F646065655C6B6860665B685E656361635E5F5F656461625C685E6863665F5E656266
616161605C6066665A625C6359605E5D5E615A665C5A6161665D605D625A5C625E5A5F63
5C615D595C605A59
61645D5C60676160645F615F6B6561697679818E98A4ADB2A89D928885737173706A6269
626766646667596661615F676065666363636264666863676A6A606B6F5964696B636963
686166626C6C6D6466676B68666E6A736D696C6C766F6569626E706C6D74757972727873
736F6C746F6B6B737977726D74726C7376707D7473757274747876747B7D7C7A71747882
7B80807C7680787B797B797B78817C87817A827E7E7C837C81867F7E7C827E8380857D83
8887827E8983897F7E81838F7E8084818B887F888D908D82908B828D898E8F8D918C8A8D
90988D938E8C9091948C94928F8B8A97919093878C908C9090968E8B928C8F91908A8D8D
8E9195908C8B90959193948B8C958D8C8C958A9C8F8E8D949891908D91918D8B8F8E898D
938D888A8D8D908C838F868C8E8A888B87878B868C868C887E8D85818687847F848A8389
878C85877B8080838084837D817D7E7C8180817D76797B777D7E7C79787E74767A737D7A
787579756A71746E7A74757F757373736B7372717B6D71737072706D727164686B706A6C
6F716B6C67666E6E6B696F6C736D746B6A686A645F75656A6667616A6B666468686D6A5F
62686D6863696C6663665F6664665D646761625E69635D665F5E625E60625A605B656A63
5C645D605E655D5B606363645E635E5F605B676064625C64635E5B60635D5F5758555E5D
5D5E635C625B5261
59626066655E60685D6263606B626C6A6B6E707F808A8A8E8C80877B79716F676F656467
6B63646A68656960666463626B5D646566646E62655E64625E6969615F676765686D6162
636D6A696570666A636D6D65636E686E6F68726A6B69666D716E6F716F6D7370786E7375
7372766B6E6F6D7372726E75706E74797875747D747178737A7B787375787B7B767C7B77
7779787573797578777A7F79767A7C817F7C7E7F7F82838280847F817E8683847F7E8282
807F897F8082847C818A86838584868D8788887C84828687878A878C928A8A8B89908B85
8B8E8E928D928C928E89949195958B888F918F92879090988E968A8F928C928D84968E90
938B9191898E9197919291938D8E8F8E8D8F8D8F8D948C949698898C9097938F938A888D
9091937E9089888B8A8A848B90888A88858D888B84888885868588887F868382858E8C7F
7A808581857A7780848081798176817C7D797C85838179777A7B7B7A82797E7E7874797A
7E707572777A75787278796E73787472736E6A71716E726D6F6E70776F756D6E726C6A6D
6E6C69666C687173686969696873676E746B6B6B63696A6C6C6D6A636C6A696561666867
68666167686A696C67666665605F6863685F6062625C5D62685A67625C5E575862615D5C
5D5C60655F63645F615F62655C62615E58605F686066675D626262575F6461625B5E6262
5E616165615C645D
57645F60685F65686463616A60636B6663657570747B76777F717971716B6C6267656A6F
6A61626B6A626967616462696D606A636563656764676263636969626567635D64686A64
6A686466696D6965756C6761666E656A6E6C6E70676A656E6D756D6D6A656D706E676C71
6F746E6A6D726D6E6C6D6F7574697574727474756F777476737475737577757472767670
7B78737775727B74777E7F7780767A787F7C7F837F737A798782827E837D8781827F7F82
7D838B89858683897E857E8B8383888485888B8086848B8D868E898C8F8A89869189958C
8B8E868E8C948D918A87918A8B8E8792979292908D85919788948F8A8B8F938F9192898D
958B8C958C8C8F908F8A908B889290978F8D8D9B89928C9192918A908E899B898393978F
92908C8A8A8A878C8887898B868089918B86898B868A8583808982898486858F81868783
80867F7E7F85827D7A7F7F7F807B837E81777F7F7C79797D797C7A7C81787C727D757B7A
79757A7579747772757A78746E747771767371756C6D7077796B6A706F6E6D746E6F6D67
6E6E69666C6A676667646F6D67726D6A67746B686B636967676C675F69676C6B69696D62
65666B67666D685C696D65626561625D5E616163645E5F655F625E5E67635D5E63665E5F
5C6363645F645F655D63675B6161646564665D6466625C5D615E615E576558595C59605F
5C625C605D5B565A
5D5B625C5B60636461615F63636162656E6567716B6F7377686F766D696760695E656263
666960635F6A67676A636168635E616264626067626864606464686D6764676666626869
69646366666C686B666C66686B6C6D6C68726D6D696C69716D716F676D73726A6A706F6D
6C70737A7170726F717272707474717B73727071767D7973747673747672776E7C757677
817C817D7D817777837383737F7C787F7F7C7783817C7F7A7A7D8384847F807F7F807D82
8083887A7C848782897B7F8488878A7C8C8B868A848B888A888B928D878789948C848683
8A888B8586888B8E8E918E8F909C8F899281908D898B8D8F8D88878D8A878A8E888C8D97
8F938F8789948B8A8A929490908E908E908B8B9595968E8B9092858C8F948D8E8E8D9487
8C8B8B8A8D7F838D8A8B8B8C83899289848589898D8E7E8783857E82867F81827E7C8281
84878482808A7F7E817F827D7A867B7E7E82777D787B7A7B7A7D7C79787678787D797279
74787773767E737771757A6F747573707073716A72737675706F736E70706C75726B636B
706C696B6D686C676467686E69696D76716566666F6362606A67696B6568656461616165
67696461686866626162666262605D61696467626A666667616262665A605D5F68655D64
625F626262625F5B6560635E655D5D5F656262625C5D665F5B615D5B605D61576063595C
5B54595F5B5C5B5F
5D645A6361646060626269676A67606E68666B68676C6D6F67666C6D6E755F6A63636863
65676B69686069676868616A626665676764625E626060605B636863626C5F666A62666A
6D6563656D69696E6D696569746E6E66656B6D6E68636D6D716871656D72696A71706671
6F656C6F6F6E6F6C72696D6F736F717371737477757777777C74737471736F70736E7774
73776E7A74787A74787D76767A8083777F78807A7D8583767F85827C83827F827D817E82
7F85857E87868480797C81838B857F868B8889868A878A858A91848C8A8A8A898D8C8D8A
8A8B8E8C8D8C8C95898786908B8C87848F8B88818D908C8F878C92959386898A8A8A8F87
87839286918D8B928E8F8B888D8E938787948B8E8A8B948F838A8C90928D898F8E8D8D84
8889858A8A898A8A838A8D8B898C8589867E89877C857E8B8680828B807F828387838385
83837B7E7F7F7980857A727B7E7D817B7F7A7D7C78757A7B797684727285827E6E7D7D7B
7B737A7A6F7175777272747A7672717077776A7278686D6D746B707572696A6E6F6D7272
6B6C6E63666E6B6B76656D6B646C6F6968646B6761666C686B6869636A5F696468686A63
666267656264626664636C5A6564675F61616162665F635F5F5C646161625F60645C6163
695E5F5D5F5E605D5A5F5D655E6165655F6762645D5C5E5D5F615A636465595F62605D5B
5D5B5C5E5B5E5A5E
63605F65615E5E6B5D5C64616C6760636968686667636C676560676765626A6467635F5D
665B5D675F63605E696A6564655D685F5E6862686A5C6464626D6A675F6A6B655F696A66
6565636363646B6869696D606B69686F6E6B6768646A6E6D6B746A706E686C6B69766D6A
6B69766972686E6E6D6D73706E736F737375726E74707473707A72787A7674717777727B
7972757178777573737A7478777A7A767A797A807B7A7E7D808A818482808482867F8186
7A8B807F847B84868682847D81867D888590808288878D898F84858B868B8286888A8B8A
8A8B8C8C9088868C93958A868C8B918E8E8C8B8B8A868E848B898986898F8D8A958C8F88
8B8F8E91918990908E8E8C8C9190908C8E8B8C8C8C8E9099928F88888C8E8986888B8D95
8F89878484888B88918B8986888182858C8B86898D828182857F817F84807B7581837680
80818985828381787E7D76817D7F847F7B7C7C7C77757B7D767A7C7C7572727478777B7C
77717A76776F6F7177727271787676746E706A6E6B716F76706D72736E706D6C6E6B6F6C
6B6B67666E61686B696E6C696D6C5E6469666666646860636E6465696B68616868626968
6864696A6A665F6667696366636066665D5E5A6166605D5F65645E6463606360665E5D67
5F67625E605D5E5F5E5D65615C62605D5C61636265676259676265615F625F655D5D6060
5F60565B5E5B5F5A
645D595A5D625F675F6C626A6765616C6D606B67666963646467636C64646C6465676260
695F696161626D65685C635C67696564626362625C6368646B60676A6A6369625F646869
6666656466636762626C6C5F656F676F6A686E696C7068706B666E6B6C6B68736F6D706F
696A6E6E6F6F726F7A716E706D726C71776F76726C736F69777E70807578737075756D71
7178777577777B747282778279797A7C7A7D7B7B7B7B7C808782868289828485787B8387
817F7B7F857F7D857E828783837F878681868781878C85858A87838185898A8B8B898192
8C858E898F868E918E928F8689928B99898D8C8F938A838A84898C8B8A88838B898E8090
8F878E888D8C898D898E8F8C898A898C8B8F948B948C8D8B878A858F888B89888B8A868D
8792858687868788888C89858D8986848C8084888980877F808A877C7D827B87888A8782
84828684837B7F7E80827E7E7F7A7B82767A707D77727777787B72787D747A797A74757E
797B6F7674717875766F747B6F7479706C757072706F72736F6F7A71716A7171706E726E
6F626F716B6F6B6B6A63676F6C675F636D6A6A6C6E6367696A6A66695B64636377616562
686464696764616B6166686064616165616B5E6761625F66675C5F64615E5F605F646161
646161666863625F5E6261605F635A5F66615F695F5A605E5B5E646364585F595F625B54
6360615B585C5F61
5A555F5E60686467646569656467636365615B6461686D6669686B656567666361686563
616068635B696461636365686966605E666B61656367626168636760656D69636C63626B
666B686C6869616C615F6B6B676D6C7060656D6D716B696A6B6C6B6A726B6869686E6C6D
6D716F6B6C75676D70726C73746E71787676756B71756F726E7770707575797B74737975
74707B757570797B7D7B737976787A7F7E7A7E7C7A7B7C808089827E817B7C81807E847B
798383777F7C7E81898A8080828981868C8A848E838B8781818488888785818D8A8A868C
878A8C8D878E8E828A8E8C8C948D908F8D87898A8B8B938B9186898E91878D8E8C8B8A8D
8F91958E8C88898A948D8C91948D8F8988848D8E8A988B8E889386898A849187878A8486
8982888A8383838586897E90888481878787888582897D8B83838481807985827F82847D
80867D857580847F8079847E7D817B7F7F7A817F7D7A7679767A7A7779776F777176757A
6F7675747277707D7779757C67726D726D696C7270746F726E726A6A6F6A6E6B6A647071
6A6C6A686C6E706970626B636B6A6D6E616B6967606969656E6B696E6A5F6B6462625E67
6363676261666665606E5C5F6563665A5A69625D625E6064615D59616962636E69665D62
64645E5F63635960605B6361615E6063656058636D61635F5E5C556463625C5F5C5C595C
625F5B5D6556595D
5F655D5E5D65625E6B6A635F5D6067666564696A61686562646B636463665F68625A615E
626662616B616366646060616769665F6857616567626969686462675F6B6F6668666264
69656473686B686C666872677368656A676E6A6C6C6C696A73736A686F6567726E6A746F
6D716D6B6A716C6E6D6B6D6D6A6D6D7871746D757170756D746A79737A746D756F757977
6D7E7973737975727579737879737C7C7C757D80817B7E807F8283817D7D857E7C857B76
797F7B8183847E85817D7B81887D7C898186847D868987848B8488878286868C8D8A828D
888F8A898688878F8B8B8C818481868A8C88888F867F8886838D89898D89868D928B837D
89828B83878E8B8689868B8D8A8B8C888A888B908F8E908C8A858D8C828E86878587898E
7F828981848C8F8E868E847F89808586888B878783847E8084797F837B7D8E867E7B797A
7B777982867A7A7E7879807D7A82797674787E8179777A7A7D7A737578797B757A777979
77767A737377757972766E727276726F776E6E6D6E6D6A6A6D67786D6B73716A66686A6F
6E5F6A65686D656B6D71686A6C6F6964666A736E666A6862656964656A6968676C636566
615F63636C68646565676C6062666565645D63626062615C675D6165635F6162605D685E
5C5A665E636164636064636561636167655C5D64645F655D5E5C646562595E5F5C626062
595B6259585E5859
615E545D62616263615F585C60606262675F6263646065665F626A646862615F6465655E
635F6A615C6263606769666767646368625C66636B6463676864626667666B686265666D
636E656A686C686D64666A656F66666768666B6E6B6F6A6F676F6C6C72706C716869696E
6C6C6D64666B71736F6F6F766A6871726E73726B706C707470746E6C7073756D74767372
766B78747973787477797576767A777581797A777D7E78707D8380787E7E82807C7D8080
7C7C797A7E8084837F7E7D837E84807486818388838681837D888687877F878786888488
8B8B8A878887918A88867E818C828888858C8F848B888D868587898A80878384858A8D99
898A858C8B908B868890888E858C8A908988868B8D8F918C888C82878D8D81808A888A8C
817F8789838C87888A83868387848A84868683828683877E848676817F7F7B7D81847C7B
83817F7D7C7B7B7F7F7D827D7F7A797C7C7E717A7870797879716F70706E757B75757475
7172737A726D726D757373756E70767870746F7272706F6F6F6C72736D6E6E6B726F6A76
6B6C6A6A6C6E6673666662686D7064676E6B6F66616D6A676A67676A6B636366696F6A67
635E6162685D666A62645C626065586162646166665B5F5E646362646265655F60626067
5F5C6262615E5B5F6367656360655C645F635F665E655E5B5A5C625E5E57646860605B5D
625F575B5D5E625A
5F5B5D635C6564605D6B655E5F5C625F61676065606264616563665F6869666766626162
5D60666066616160626A6963646561596364646666666263666C6563636262626E687169
626A6E65646C6568636B62656E68686B6667696C6D696B68686F6B71716B746E6D6D686F
6B6D6A6C6C6F6C736C6E6C69716F7879726E64736E7875737271757773717272737A7970
79767574707275787E7975767D807C757D797780747B7C737C8182818283807A7C817D84
767E81797A867D817E838781817E888284837A857E817D86888D8B8B838685838390888E
8D818B868B8484888984888D868580848C8A8C848E8B878C898684898A868A7F8D828B84
86898B858D868D8C848B878A8C8B958A89828286877A87868C8D8E8589828289848A8484
838B85838A7C878287908688808187898A8681877F8781877D7F7D7F7B7F7C7F7F7B817B
827D82857C7080807A797278797F847F7978807C77756E7A78747C7E7B74757972747A73
767A7A797773737573777778736F7174716D6F7173746E6F726F6E6D6A6C72706B6C706C
6E6E6C6972686A6E6A716A6570656C6C6C6A655D6865706D6869636A6368646569615D62
69616A686164625E6A6B62606562676364676762636266666466615C60676067625E666B
635F5E5F61606563625D606462616362626861635F675E615C5D5C615F62615E635F655B
5F625A645E5A5A5D
645A625C625D645D5A5F60635D61606066635E6C61655D686467616065625E646562626A
655F636462666467666565606265666860625C6262685F64676B63696B69686967676763
666569686B6E616A6469676B6964656969656D686A675E6668676B6D6C6B6E7072716B6D
6E6F706F6C706B746668736F736F6E6C756F6B6E717378756E746D6F75777774776E757E
7576707E747772767772777D82767E787872777C7B7C7F7E7B817B7F75777E85817D7E7C
7E7E7B797C7B817C7E857B7F7A8486807F848282888888817E86828383808B898788868E
8585848E8484828B858B808C87888E8D89818C878B82828C7F8A8487828388848A8A8B8A
8686858491848A858E8992829185888E7E948289878D8E88848289838B8E8C8384848384
88818283808980847F82807C89828285868A7D84807E847E7E85808184817F8177847F78
827B7E81847D7C7B7D737B787282797E7A797E777B7B7C7F7C78757A7B7E75737879777F
7B7C7871766A78757970707876757B6E726D756D7173736C6E746C726E6867656E6B7468
6E706E66636E6769706F6A706A69646869685F6F6B69656A6A626862666B6A6A64696468
69635C66636561666D636263645F695F626D63656C666960656360576460686B6A5F5759
605F65595B6C5F5D5C63665C5E6762656365636A656461655F5D655B5F62606061605A62
6257615E58555B60
5F625D635D696361635B59636062635C68606A60626363675F5D626F6362646767636466
656A696160615F626763696863615E5F64626666686961646667666367686A6766656B61
6064706A6B696D656B6468636969686B6C6B6D69686D6A616B686A676C6D6C6C69737070
716A716B6B6A6B70666C71786D6F6E79727378736D727271726A736D7373737978747373
7F7472747978737273787574767D79787B7E79757B7B7878837E7A7B7D7C7A797E7D7B80
7B7E7D7F867A7D848C7F7D7D8285828684897E847F7F85847F7F857B8387848C868D7E80
80848787878786967E7E8B858A8485928987838486878885828384818E8687887D7F8485
80828A788889858C8686878A8C8785838385877F8383858385828988848482808482827E
85818A8B8687878288858480878484808587807E86858887837D867D7482847E7A7C7F7B
7C7C7E7D7B7A82827779747F7B79737C7779757474756F827783797C797675797B71797A
737477747A74776B726F7373747A74796F787277747772706F736F6A726F69726C69706B
7267666763656C6A6875716269656A666A6E6570706C7167686866656B666A66635D666B
615F6664686268686A656366596266636464666A686166666066615A615E675E65615E5E
5F63646F636466625C62635F6A65626568635E6C5F5B5A5B685B5F5A5F5A6061605E6163
595A6161695C605E
625D58575E65605D626960625A61645C6566625E65655F6260636465695F616260676560
65616165626369646567656462676762666864666A646D61636461656269686568686665
656369636B616A6A65696A5C676B64686F6967636C6B6C6E72736C6C6B6A716E6A6D6C67
72746E6C726C6B706F6970756B756E6D73716C6E706C70726A7575777771767074777073
797677787E76727B786B757A777C767B7C757A7A7E7774787E7B757E7C77777F80787980
80817E80847E857B83807C7B827C8683898A7E827A808582788582858383867C8A808688
7C838B8B8489848682838E8B84888C8A85848083848C8B88828D847E89827E867B82868A
88868D87848A8B84868C868E8983848C8B8587868689808B8084827E8D86838B89807F7C
858D8287828D758D83868483827C8287867C8281817A858982817F7E7F827680847A7E82
7E7D797B797E818077807776727E7A7D7B7D797B757885797D7072787581777672757371
74717673766F6E7575706E6C747371707270727978697273767668736C736668616B6C6E
65706E6670716A6D646E6D6F6E676C6B676568636C6067616C6D656869676567645C5868
62686861686660666668625D5D63646565635D5D606D61685B6A61625A6165646363615C
5C5B5E625C626366636065625B675D5D66606A6B64645E605F6161635C605F595F615E59
5C5C5D5E605C625C
5D61596261625E65685F5D5C5A60675D616361676D646362636D645F6061675B63616364
64625E6266616A6A6269655E616869616C66685F686D65606761676563636B666561666D
6763676167686664686D6969686E6C6866676562695E6B6A7069716B686E696C6D6A706E
686B726C70686B6B707073686F6C7068676A726A6B706D6C6E6C746C6C71717073777174
7375737578767470746F797C7D7974707C718079737A7D7579777C7F7B797674777A797A
7D897F787E848080777C7D7C84807D83837E82827F7A8A8287847E7F868A847D83848386
87858085908A908680818D848D7E8389848B85847F7E857B82837E82847E878188868780
8488868C878B858987878086877D8C8783898B83898B868B83848D858387857E7C858586
83817E7F8C82888D8881828180877D86837F7E7D7A807E81856E807E7B7383817E847C77
73767A7B7B7376807C777B797F7C767E7579757D76747977766F7D737172717372767671
6D7A796F7272726C71757772746B686F75737476727A767272736B6C7173676A6F6C6C6F
6E6A6A666A68696A6B6A726B6A6C6F6A6668636C6265666669606A646260665F5F6A645B
686662665E60655E6A6A605D61695D606B5E6669646668605E6066675D655F6662635B5B
5C5B64685A60625F61626A606262645D62636963645B5B5F5A5E686166585C5F615D625D
5B5A5C5E5858625E
6056605F615F60656260655C5C625F5F6462645E5A646565646063646364646A5F676262
645D5E646264676766636667616762616A6563626362666466666263696A686565686466
67636B5C666F6F6B67696C68686E6B6465616C696E6B696C6A6C6C6A6A686D6C6C70696E
70776E706673706A736E6D70746E6E6E6E726F6C746D756E75756E736F68796970746E78
74747A7775776E7377717D7C7376777774747977757A7D7D7475707E7C7D76837B7C7C79
7C827A84807682837A7F7582867D7D8180848684837C7E828282838A8689808284827985
8A82848A868B7E8688848C858384848B8A878E84848A7A8E7F78807D797B8282857A877C
7E878787838A8E7F858585888C8D8B8A838C8A7E8584838684898C818488868C7E8D8683
7F7D7D858386807F86807E7C808286837E898383828184797C7F827A847B7D827D827E79
72847C80787D7C7A747A7E797F737B7A757A777F78797973777779786F737679787A7671
7374747B786E707C74787372766C706E717A777A707D72736C72736B6F6E716B66706B66
7269667269696863706B67696C6F686D6B606A6C61696464656565605D67626262676369
656C64656264606365616361655C615C5E6A6468695E6968665D605A5E5962656164625B
5B596860606361605F5F5E63675B646364635F60615E635F5D5D615F5D685D5D55655D63
635B605C5F5F5E5B
62635E666C625D635C5E6A5E6360615C646664635E5A625D6A6462665F6163615F605C61
646B635C63635E6763676A6C626564655E626864626766646A65666B646B616766646766
666B636767646366626C63696C6C6A6B6B676669686867696868636B6B6B6E736B656668
706D6C686F6D716E6F6A6B6F6F70706E706F746A6A716A736E76796A6F6D7572767B6D70
6E797770767877717279727672797678777B7A7E7F7F748172737B78747A787C7B797B7A
7C7B827888787C827F7D82848481887E8683807A838683807E847B7C8580847E86828280
8689888384828386808B8086848F8B7C898F7C857D8483877B877C7F8481888A82877E7E
84828A8085898B8C847F85828985878C888C83888E81887F8589837B867C80817D7D8379
837D7B8281877E8186838A80808280877F827D818981847E787E7B7878837A84847E7F80
75747A7B7B747D7B7C7C7C7B78807F7875717A7B767B7973767671767C756F7972767877
787672727174737B737D71736F6F6C72757E757A7577757273676E656A6E6969696D6E6E
706E6B6D6E67606C6E6A68706C666B72656E66656C62695E626167696064626A6D676564
66615D63656866616A62675F5D61655F64696862626759645D605A67605F5B5B635B5F63
646561616263645D6666695E5D6362605D615D605A5D5D64605F5F596765545E5D57615F
5B645C5E63575C5D
5A61625B6263625F5D656664615E6267656561625F5F65695E5C655F706068696663635F
60675F5D626360626469686263666860666A6263666761646460636C6B6A6567636B6462
676266676D676A6A626460656A6D64666C6A6B6D676F6865696E6E6773737272606C756F
686A7B656C69686C6F6D6F656C6B6B6A696D6B6D7574716B697372706F72766C6E726E6E
7A7978797175786E78766F7779786D7A797670756F75767D727C7982787773767577767C
7D7F7B7F7E7E7A837B7B7D7D817D867D767D867D7D777F85827E7F80848484848A7D877F
81808A867F8A827F8181868B8A8881888583828581818583857C8A837B827E8582838084
86808B87858389828B858482868B8790888C827D8C88888784877F788481858283828085
7E84808085818A817D87817E81817A84807F847E808281847F85777682808178787D7E7C
7A827B777C8479777C747E7C7B7C757E77768173757C787774737173746F7D76706F6E6F
76726C75747376746C69706E736F728072727778727670687172726D7669736E70716C68
6C6A686F6969686E6D6A66656A666E697069686C696C656B64666A6A686A646864626269
6466636162666B646A62655D5E5D695B676460656B5C5867626363635C5B5C686A5F6261
585D615C65645F63625E665C5D625B605D5E6160655F62606061665B5A5D655E565B5A5D
5E645B6158575C5F
5C5D605D6062625D66615E615E655F6064606362656260625F665E666661645E61626062
615F60625F636466656766696367646064696666686864616569695E62636C6262656965
67666C63676762696A656B606B656F68666B68666B746A616C69696B726E686E736B686C
697271696B6D6D666D6B6B6D6E67726F6B6A6A736A6D736E696E6E726F7073746D707470
75716B6D7574786F697276777171757C797479767679737573757577757771797A747C78
767A7B858080777F81807D8081857E807C7E80857A7D7D7981767F818579807D848E7D7B
84807F7F7D85867F818B8088897F888A83848A89808B817E807F84877680878187828184
7E89807E8280868582838A85877D897E8C8882858D887B86848287778885848C817F8B85
858180867C877A7B85867F797A84837F837C7F857D7C7C8A7E7F777680827E767D7C747C
7C8080867C7780777C787875797A767E7A747873786F787270797A7072747B716E727374
7678707373757B6F6E757172746F777178777C73817373706F74716A6973716A6D6C6D6D
6566696B6D65656B706C6F6968686D666E67696D67656064686367696765686E6E676965
5E5D6869626064696661665D646360616565666568606265645C5F5D6164625F67615D59
605C586460675B61665F67615E6262615E6263605A5957625D5F6260625D5D5E5F615C59
5E5C5A5757545C59
65575A63625A60585F696160606464655D625E6765686762686063646360646566636466
616B63646A6A6261616762685F6062676863646A6B636060636A656066636661625B5C6B
5D64656C666A696B656A70616D6B686A6A6B5E6A68666E6C6D686768696A60686C726A6C
696A6D696B6B696A6B6F68656D6B696E68707170716B6B6C716F67696E6C6B6E7A746C72
7069746C6F7872746E7770787B757577757573766D7C7779787A7C7C807F787A7C767A76
797C7A7C7B7E7E7B847A7E787A7F8180847D78807C84797B7C7E817C84828383817D8582
7F807B847E857C7F7B8388827C868F83868A86858080807B7B7F80818284837D8287857C
82848284818A7D88828A878583898986867F837D848A85867D868585777E7B7E88868385
827C8184807F838784807D81877A867E80807E7D757D85827A7D7A7A807C787C81777974
80747779787D767A777F817A80727376766F77786E7172777D6E787A746A74746F746D6F
6E78757077736F77747574717572786D7475767D7478727372746C7670767170716F6972
7166796D696A6D646C6F676E676D6C5F676D6765656A676E6E69626867686669626D6061
636060606860655D6962606365635F5E5D6368656261615F605A5D5A5E605B5C5A606362
616060625E666161616166616068655664605D5D5F60585E6659595F5A675F59625B5966
5D5F5A606357615E
5B5A5F6062605E6266666263676269616366666960595C62655A67645F5E626164626767
656263606063636961625F6261666868655E6C686762686864605F6A696568686C646A67
6A67636067666665606C646466605F66686566666866686E6B6B706E676969696D736C6B
69696A656D6B69636A64626F6B766E68696D6A6A6D726871726E6E6F76686B6B6D6C6F72
6C7379746F767A6D7672776E727479757274787275777873726F787978727975796F7977
78757A797C8083807E81777A80807F7D7E81857E7D7B7F80857A7F8485847F7D8A828985
7F7C7E7F908282847984838B8A8882828282827F79837A7F818780847A8B7C8183787C83
7D81827C7B8B88897E897E827E7A87838384818986827D847E8386817E7D7E8282807E7B
8184858082807E7D877887777A85837B7A7C78787E7A81827879807E7C777F7C77787A7B
70767F797A7D7B7E7A7C7778767077807C7D79737A7775797676767775796E7A78687270
717472777174776F7671716F70756C78786E77777673707076766D677368716A706F706C
6F6D70686B6A6A6E6A676D6D66686C6A656D6D6A67746B656063636A6E6A636761636261
6164646963665E636A61685E68625B615E6A655E605E6164626266655C635C655E60605F
625F5B68555F645D57606C5C61655C5C5960626056635A5A675F60605C605D59585D5F5C
5E636461615B5D63
6357605A5B5E5C635C656360636265625F64636666625F5D675F675D6167606060635E5F
5F656363636562625F685B6364646464686860685F676466666361666260666D635E6767
63616666676A68666265646966676C6A6A67666B67666A656572667474626A6E716E6F69
69676F6C69686D6B6D626E6A6F726E6C6C6B776E6C686C736C7270706F6F776C71716871
6F6C70736F73707475757A7172747376756E7B7975727B7774747B7D7C797D7E7C75757E
777A827D7C83837B7F7C84827F837F7E7D8581877F7F7A82807D7C81887A7F8175897C87
7F8A7F81848184878481878482828285857A7E8089857D867F88827E7C7E7C807B7D7C7D
7D818384857A7A857F8887888280828180828582898685837E7D828483787A817E827F89
817F7A8382838181808B79817B7D797D837D7E7B7E7D777C817E797F7B79797F7B79807E
7D797A747A807574757D7A7A7D75767678767872787B7772757676736E6D707572737375
6B6E7471747170746C716C6D6F786E736D76737070796D71717978746E6C6D6F6A726D71
6B7271746D716370686A686375686F6B6A6867686463696E6962655E675F63666666645E
665E66676A625B696364656461665C63606362636368675E5C635F5C645F605A59616561
61625F60665E5E676564655B605C5C5B5A5A605D6B62655D5A5F616461575F595B5F605A
625E5E5B5B5C6063
5A5E5F5C5D635C62605D645F62616265605D615C635E59635E675C61606466656466665D
5F6961646C62665F5F5E5D675C5F64655B685D656A62675E676461686466636963656468
616B656864666A6B6260656560656C6B666E6B6B64666A69676E696D6A6369686D6C6870
6C6B6B7170656B6B696D6F6E6D716A6A736E6E78786E707471726D6D72726E7377697475
726C6E7374736C717071717479777775797D7571787C79747C707471787A78767B73827C
7B7D797C7F817D787F7E797A80807D837D85817D797E77797C7F78797B7C7D8381887C7F
8284827F818C7E7F827D8484827D7C87858183877F807F837F78807B7C7F868679827E7E
7D828386867D7F867E89857E7E878380827F8880808182847A7E838283807F81877C817E
798A83777C7B85847D7B82797B7E78817E7D7C7D7F7D7E837C7A787B777B79777D7F797A
767B71777A787A777275777A777C737A73767575737572717877766E736F776A6C727079
70747072717072787470706F6B716F7570736D7977716C716C72726E6B70686B6E6D6E6F
776E6B6F676E6D746A6869696A6E6A716C626C65636868686A6364616567685F66616267
605F646B635E6563635C5F5F69625F6466575B5D6162605C615F6064625F61625E5C6455
605F596567686861645C585C64666052615A5F60605C5D5D5E63685D5A61605968625E56
695E6059615D6257
5B595D635D5C625F625E5F636060596A6A5F5E66635F6264645F645F5A5F606069656459
5F5E635D5B67615D61666865646562656364626669656064665D62636964636866606867
6360646464666B64635E6861686F676A6B6E6768676A71606A666E6A6F686F6E6D696B63
696C70716A6E6B6866696F69726E71686E726E7271736A666B6B726D6B6F7868766E6F6F
7071666F77716D7170767070777472786F7874767B76797673767872767975777A737980
7E7E7D7575757586777B7A727B817E7E7B7F838578787F7B7A7E7D79797B7B8487827F81
867B83887C857E7C84848081827C7F887980828280827B7A8487828585828083837C8581
8385828086808189808682837E80847F8185838E8283868A827A847E7F7C7A857B7C7E7F
7D7D7980827A7E7E7D8084817C7B797C7C74767C78727B737C7D7E7B7C7B75797D7A7976
7B7A767E737C747A7B727A75746D6F76737D6B7976737974737371756A727B7673737570
736F73736B716F686E69756E6F7371746D766878737071727A6F736C6A70706B706F6F6F
6D716D687170696F6C6E6C6C676A6C6D686865666E65656563646266646666646A62676B
5D6761646D62656B5B61615D5A676060656462645E5C5C5B5E605F5E5E595B5A5E656262
5B635B5F65615D5E655C61655E5E5D5E59615D61606161615A5D5A5E63625F62605B5D62
5C5F545D5D595B5E
5E5B56605F5C5C5E5F61675E605C5B635D636663615961676063685D6563605D64616B60
5D60635F5F635C5C61625C6664636166656465666565655B676665657365636162616368
64695E645D636D6268645C656F60656B656268686A6C6B64676C686E6B6C6A6661636A6A
696A636B6F6A6E716C61656D666A6A746E76757068726B7070716B66716E726E7272706C
6C72737169706F7175706B75736D7371747675716F71767474787B7A787B75806C797C82
79777787797C767E787F747C74827F7B797F7E7A8076817883787E7C807A7F7876798184
85838A8B7D837F8377807E807C7F847C867E777578827E827F80837A7F807F8083807D80
7B807D8081878084847F8B847F7F7E7A848181808279807D7C7F7B7F817C847F7D7E827C
7D817F7D82817C7C7A7481777A7C7781747C7F80777C77817C757A797F777C79757A7276
717477707B78767675757A777275746E77767678786E7B7374746F72756F756D716E726D
7B72776D74706D726D746B6C746C787173706F6D74736C6F716B716D656E706D6C6B6F75
72706C6D6D6F74686E6A6F6F706D6F6D696E6965716D7065656E6660696864616D616565
6366636563605E6A5F63635F5C5E6B5F625E665C635F5C6264636060615D625862585A60
695F625E615B5D5E5F645D595F5F635A64636461595C5D626155625D59655F645D5D5D62
5E5A575E565E5D56
60625C5E65695F65615C63665F675E6160665B6763625F5F686667626263685F6564645D
64615C5F61625C6765686967655D625F6263696864655E6667666363686D676562636569
6B64616661606466606268715D68646E64676A61677165626564686B6B637064646D6768
6866646D6E71696C696F6B6A6C686D6A6B696D6D6C706F646F76716D726B6B6D696B736F
6A6F7172766E736E6A6D7A6F7B796F757975787471766975797779777174757A75727173
7A7E7D7A777E7C7A76767C7E807E7E777C7C7B807879827B817D757680857C84847C767F
8482817F80887E7F7F8B8082817B8281807B797E7F847E877F86857A867F7A7C837B8183
7F8486807A757F7F777E7E817D7780867A85897E8381807C82837F827A7E8580807F847A
797D788681787D817F7D7A6F7A7B7C7A7A7D7A79827F7978807B7E7F7B767B746E6E787A
7F797A7A767779737478757077767074797676717771766F72737B6B746C6B71756A7471
7572786F756F71716C715F706F6A706A726C6F6D746F6F6D787070707272787170686D70
6E6D757B7471716B706B6D6F6B686E6B6A6568716D6D696264716968675F606A69625D5F
67666463626764636268645E566B685E6863675F69625861565F5B5A6558675D5E616161
5E5767615E5D5C655E63595E605D5C5A5F5A5E5F5B61675A59625D5F5E6D725D5A5C615B
655C59615A615B60
5A5B605E655B5C5D605B635A625F5E5E685F5E5C615A565B5F656161575E625E685D6265
5B6163615F5D5D616B635B5C60675C6863636668686266616066656461685F666A666567
5C5F666A64646763645E66655F60616362696266666364655E696D6567686E6871656D65
686A7166636E716C676D696365666D706E6B6D706C676E646D6969736F75717270716A6C
74737473726A746D75726F777376746F6D75747075767A76726F737875746B7679767877
767F7A7E7D8473777B7D7981767B8881777B7C7A7B7F7B77847A7C7B867C757B79837B83
82807E827E7A7A817D80817D818284857F7C748086838486847B82867C79807A7E77817B
807C83817783787D827A7F7C7D847E7E808386828181857F817C79797D7F807F796F7A80
7E827C867F7D7F797F7D7E7A7E7983777D7D807F747576777C7777707475797D777C787B
7579787E7C71726E6D75736F70757375757A716E757574777169707874766A777279766A
727373706C7071706A6D6D6E6C6E72697177706A7170756D76706C706F6B7170757B736E
6A72716F7076706C6D696C736E6775706B6E6A6B6B676569686C686D6366676A6266626E
69686D5B6165636465655D5E6165635B635B655A605F64615F5E625F5D605E6461636460
626463615E575C605E62615964655B615B63575E5F61575F626362675A5A61605E606262
5F5D615D555C5E5F
645C595D5F605E5D6064666160636760635E6257605D636365615C5E615C6160605F6363
625F5F636466656A6566635F69656567615762616864656467645F5C686C6E6568666761
5F616168686468666462696C666A61686A65676862647365696A6A65695E6B68666B6867
68666B6F726A696F6D67736F6E66686E6E6D6E6B676B6A6B7270716F69716768766E6D6A
6D7A7070717077706E706E73736F797173756D716F75777873747B6F7573747774747D79
767D76707C757C7A7A7A7D7B777D7A747F807D837A7F7381777D7B7E81776E7C867F7E7F
7C7E8484827D7E7A7D7F84817A787D7B808477827D867B7F73877E7D837D7F82807C7D75
817E8078807F7F847B79807D8584797B7C7A7B7D878080837E80737B7E797C7F7B818284
7D7F767A8278797D787D767C7780747B797A77777D7A787E7773797975747B707F70776D
7D7470797B6F72737876707A757A7671726B7271777371746F6B706C70736E70726F7178
71766F73756C6F6A6E6C726A706767776B6C6E69726E6D706F74746F7670756D71716E76
707A6E757572787478676F7A6B6F6A6D7168696B6165656D6867635F5B6A686360636A64
656365685C636167615F63596262605C60676460636661656156605D62615F6164606463
5E5F5D5A6360625A5A5E61626261655F5B54646162615D6364635F5C56616556605A605A
625E5C6259625E5C
5A54605E5E5C5F615C645F646469645F5D645E5E5F5B5A625E645D62686B6260615B625E
6261605962606862586761665E606061605C69666B655F6356656A5E60626A676D5F6663
6965656161686670666A65676A646068686966685D646569656F646A6C6F6D6868626867
62696369666C6B6C5D686774666B6C717470686E6F6C6A6E736E666E6C6F6E736F6C6F67
6F776D717470746E6F6E70717476736F757572707673757875727673746C7A7676727774
7576747977768377747B7C7383787F7B807D7F8178797A7B7E7F777F76807D7B7A7B7E76
8180807E7E807D8480787E7A8C7F7980867C847D7C7B817A817A7E80767F7B807F7B787B
85847E83767A807B7A79798186798182848084787F7F827A7A7A82817B7C7F7B7A7E7F86
7A827C837B818079787C777B76767B877F78777C7D7F7A747A75777774727F7B7771776A
76797C7476757D7A7872746C746E7D7574736D737673776C72707275796F747370746B71
796F7272686C7172726E73776B6B707170676A73716F6F74707073766F766F7A79717874
716F70757576746F6F6E6E746F707072696D716C687071656F6E5F61606A606561646662
5A64645C656663666160615B595F5A5D626560625B665A5B5D5A5A5D5962616060665E60
5F5F636361575E5D615C5F5E595A626757695F5D62605B5E585A625B645B5E5D5D5D595E
6465625F5B595861
5B555E575E62675F615C645F635D68635A6264635E5F6B5F6A5F5C5E6562635E5F635E5F
625F5E5D6068695F636365625E6762645C5E666060656D69626764636769646664606365
64656366696067696668636969626966615C63666462656A6D676567726F656365696966
66676368686968646B70616A69686E6D70696C696E6E68746F706F6C696D706F6F716F70
6D7077716F736C7272677072706D746D75717572777B78707B777C7A75767B76747C787C
757A7C777B7D7C7D767F7C7A7A7C827F7C7D7B767E7B7A71817A808583807D78837A7884
877F887D857F7B79727A7A7B7E867B7F7C81817B7F757574857982798684807F807B7C76
7580857F817C7A807C7C877E787F7C807D7F807C7D797E7D7A79757979847D7E81797C7C
747B7D7679717A767D797A74757372807975767B79777D7576787A7F737A787D74777574
6C7570737A6F7C6B786F7878706D6D746C73726E707870706E787773786D677674756F6E
716B6D71746E78766F6B6A6D6E6C6B6D706A6F707574707070727173737B75757A707872
79777776727570717C6B7576706F736D6F6B6A6A66686F62666966656770696168686763
675D635C6165655E5E5E60665B6260606A5A63605E5F63636160645B605F5D62636C6063
5E5C5F5C5E5D6659615D625E615F5D535C5F605E5C585F59655E5E5A5E62585B5D5E5F62
585B605C5B60625A
5C61605A66615B645E635D5B6463595E6967625D605D6364635D63665F5E5E5C665F5E5F
6560635E5E5E605F646368595E6366626066656164686D625C615F6766666169736C6366
646B62606166656762666768646064616765656464596B64686B646A706D6B68676D726A
6A6F6669616D6A67636B716D65676C67676E666B6665716C6E6B696C6E736F6D70716A6F
6D7770706D797371756B6E72726F7370767576737472707179767B7471727D7676707579
7079727A7C797A737C78747E7B75787E7A7D7F7A77737D6E7476777D81737A737E7D8480
837F7F7A837A7F87848A7981878283847784757F767A7A797A7C828377817B7F847F7D77
847B787C84807E787C8179767C777B7F76817C787D807B7883857D7F767B7D7D737C7F87
797C7779797A7A797777777C777F7B747876757C7377787B79757E75777F777B747A7A7A
6F766F737278736F7779786E7A6D6E74757274717671707373766D747071737476726A6C
6E6D6F73706C6B716A716E75716D71746D6D6974716C6E747573766F77737975737D777C
817C7C80797E7E77727C76737679717271726D72716B706F6A6B646E6866666364626468
6564696065635F5F596564636062636267675865636261656262595B655E5E58665E665A
645D5D5E5762625D5B555A5B62635E525B66615F635E62595A5E5C61615D64596360585A
54635F56585E5961
605E625D605E59615D605E5F5B60595864616462615B655D685B675F616262655F5B615F
5F66625E69655A60636264645F6058625B6260695C646468695E626B6B6664616666636B
6B66616261656561685E6468675B5E6761656366635E6C65696D67666C696C6F6D686768
646D686472626468716D69696A6F6D7168696A6865676D67666E6D676D6669726B766C70
67716B6D74716E72696F7071726D6F6A706E7970717473757870716E7E7C767775767975
7D7B74797678767673797D78807B7A7F7F7B7A797C71787C7E797D82797B757F78838278
82818582857A7A7C7F7D838283807E787677787B73797C79807C767A767F75817E77777F
75847778807D71848183787C7A7B7A777E7C72797F77767D827A727D7E7A778077797C7A
808275848479797F7A7A7A7B7676787C78767977797772777578786F7977787D7E7B7E75
7C72716D78747273706E6F7A757970766B6E73727777706F6D6E726F74736B726A736F72
6F726D716E6C6D707573717174716F726D6E756F657572706F747576727B7A777B7F7179
7E7A7B7B767E7F8083787B747877726F736E6B6E696A70706E66696C6469656C67676462
65646661685F60636762645D6262605B6066605C6057665C5C54645D6566675F635A6158
67575A5C575F5E5A5D596B615C5E625F5E59655E5C5C60615B615E5C59585A6165585358
575E5D5B63595D58
5C5B5F65595D6162605D596165605F63606360636260615E636262585D616161645C675B
63655D6563685F695F665A63616161655D655E6663686364695E62636265615D685E6567
68636A646A625F63656268656168676663676769656B666B606B6A666F6A696A6B6C6F68
68656A686B67656F6E6F7265696D6B6462696B706A70716C686F726A6D71676E726D6971
74696F72706E6E726F70756F7270716C6F727275766D7580757A777579726F7673707877
767D7C747374717E78796C80717F7C777F767E7B7D757576767A787E7E797C7A7A7E7D85
828381827B837E7C8186808274817F85808079797C777C7F7D7779836F7D797E777D7A8C
7A7C787B7D7A79837D797D797E75857C80758072787977797C7E7F7F7C79757F7B7F7A78
7A78807D75758075737A787977797D79727D777971777A77787C80747474717D75777076
787577776D6E74736A6B736C71776F6F797075706F6C6B7169666D746D736A70716A6871
73726F72676B6A6E6E706A696D74746A6F6B72737277767372777A7E7174747A7D758284
7C8487827A8581808080787D777779717172706E71736A686E676B6C666F676E675A616C
6264635F5F5D68666262615F5F5A6062635E635E5D595E60675D6260655C6367575E5C5F
5A5C5F5D615A51626460605D665C605661655964635C595D5D635F5D5B635B56665B5D5F
58615B5C60655B5C
645F5F5A655D6761636761625F5E605A5F60616263646260665F605F625D676764606061
645E5D65605A5F615A6A6365606661606663636A5F645E666B66676669656A61615B6962
60655C5F5E6361625F5E6765636568656B5D60706A6965666B6D6662686968656D6A6464
6C6D6D6D6266656C6B676C6566676A696D6C6C6B6B686C736B6A686E726668696B73676D
76736F6C6E6D6B676C6D7375727171706D7977707275756C6C766E727C6F78777879727A
75767A7671737472767379737B78797E7B7D807D72787878787A77758079787B7C807C70
8080817C7980807F7F7A7D787D7E7A79837E7578747676807B777A7A7477727770817877
7B78867C7D747D787E84787D757F7D8573767478857774777F727C7578747A797C818179
70757E817879727775737D777A757A7C767A79787674818373747A7275757A7573736E77
747A736D7170747473707370786A6E746F757174716F6E737672766F737074716E737271
6E726E6C72696A6D6F71687A796E6F716C6D6E736B716E7D71777C7781807B7A7B84888C
85848E8585879186867C8179807A7376727D757A796F69666B686F616A6568696A6C6564
676460636160606258685C62605B665A606459575C5C615F5B605F616261625D5D5F6361
5A5D60625C59606169625B5C5D5B5F5E5D64625D626263645F5A665764645C60635C5D5E
5B5F5F5E625F4F5B
625B585E575E5D63625E5E63605F615F6360655C625C67615F625C655F5D605F605F635D
64655F61675A5C645D5E5D62626562686060626C6361576662686364685F64646166685F
60676060636D6861626A666761616C6F65676A6465666A666773695F68686C696C626162
6769645F69676A666C696B6869696767676A6C64666D70716A6E74676A6870696B6D6E6D
696E726B676D6E78746E6D757C6A6D6C72697372726E74726F747276727C727274747477
72777774757779727D767777727279757C767B797A77727E7876757277777F7A8182767F
77797D7B75817C7A7C7C7E7F7F7B757C7F7A75757C7779837D8276757A76717B7E7D7478
7D7C7D79777D777879767E7A7C7A818077767D757E7878807E7C7F7275767D78727B7D75
7A71767C7D6D747B787C77777C767773797872767177717278777A7C7D79717370767B71
7B71746F746F776F70746B6B6D72736F6969776F67716C6B6D6F7265726A70716E67736B
6B6E70717073716F72706E72706C6E726E72716D75737272797477807E7E81837D7E8A8C
898C958F88919290868D88877D84797773746873756D6F696F6F696871686268636C6265
69646465666D686563615C5B5B6160625E5866655E5F5E5E6363606464635B605B5B5D62
5C6261625D63645F615959615C5B615B606259655E5A5F5C5E596264595F595D5F5B5D59
5A5658595F535659
635C625E675A5C5F605E60625F5C675C645F5C646260615F615A655E625F676563636266
685C6560655C635C5B5E5B6165645E60655E626A63656364655F686260646367646B636B
6367676066636A5F64656B67646160646665676B63646761645D67646A6C686665666B6A
6C625D666964676B67725D656E6A6C6B656A71716B656B666B69686B6E6D6C706A6B676C
6B6D7168757370716F626C6F6B6F6E6F75746D6B706C6C7174787E76757474747178786D
72736E757B767674757A757C7E767574747E707D81727F7A7F7A7777787774797D7B797A
787B7D7C7D7C7A847B7D76787879887E7C7F7D7E7D7B7C817E7C7A777B75797A7D7D797B
777A817D807B7A737B7D797E7578757C75797C82787D7F817D777676797B7F717E807D74
75757A79787B78717375777A747870747B717775726E797A71797A77767A707677757376
756A7878786C72716D74716C6C6C6D6E7373686F6E71686F6D6D6A6969756E7065696C6B
73716A6D776570737467766D737173706A6F6B78717470777D7A737B7E7B828583868F91
8E959B96989EA49B9B978D928D8C7D81797673706E77747474656C7070676468626A6761
5F656360656262626B63655E5E6264585D5C61635E605E5D5E5E645C65585B5F5A605D5C
61636163625B5C5B5D5A5E5E595D5C5D605C665F605861585E675E5E5F585B566165585A
585D575A55585A61
5E5E61615E5A69625F5E62615C67615D60635D636959615B655E615F5C59606061655E63
62625A5D66645E5D5D5E5F645C5D64656163676A5F695F645F616A68625C666366646064
6463616765606064626569655A66636D6469626B6866656666656A6D666962646A62676B
5D6D6D7067676869686469736A68686769656C696B6D686B666768666A6D6A67716F736D
686C71726C716D7A736F6D6F7571737172706F736872727479736E70727A727476757579
76746E71747A7371777F727A7771747D777A80757B7B7B6E77707C7B787E757C6E767479
7B757978817E7C7B83757E76887A72787A7F767980837C787D7C7B7A7C7A7D737C7B7873
7E847B7F7B7D7F73728179777B7B7B79737D787A787778777D757E807A77757D787B7A70
7977727676746F77797B7B747A7B717D766E7D7570717A70777773797C75777B74756E76
6E6E786E6D756C71716D716F72706E6F6D7372757370646E647372717672686A7174706D
746F6B71686E766C6E6E6B646F6B776E73736973747970757A7D77828080808E8886948F
98A4A9A9ACB1B5B0ADAB9DA0988E8686777D76697071706C6B74706E6669696C69696967
626160646264655967635D605E636461576060605F5D5E5D6260565B65575F6060605F59
5964645C5B5C5E61626060636565615C64605D595E5763665E5E5C585A5F64655F5A5F5F
595B5E605D5D675C
5E5F5D605E5C5F615F615A5C5B5D5D605A68606161636564635F635D5F605B5A61645F63
65626060626A605B5A5D5D6461625F5E626463625F5F5E615D5D68646E6160645F636767
656662676362696866656B62615A6363676C6B6867665E656B626A5D666866686A626465
6772646C6B616D6B686A6D65656A6C666B6F696B6A66686A69656A69696C666F67716C67
69716D717070746D70717169697067736F706C74726D6B726F6E707770766C6C6E6B7B73
70757C706B777778767A79737B7979727B787F79797475767675797D7879828072708078
787779767B7E797F77757E7A7C7C777C86797E7E7B7B77767B727C7A73807877787E727F
7B75807D77767B7F7E7D747B757B7A72796D7772767D7E7B777C7B737071737C767A7C7A
727E73797B7270746D7C7979797C7072767D6C7B79777074707A777074787372706F6F70
776D736F736B7471747173736C6D6E6F6D6B73716E74737272726E6F7074716E7073716B
79736B717171776D766971756A6E73726E6C726E7A7874777D817D7E888C89838493939A
A0A9B6B9C7D1D1D2C2B8B8A1998E8C827E84787879757272786F726A686B6B666B636B6A
645F65626261665C6060635F5E5D5E5D64666263625E63605E5B5E5D5D5E636261605B63
655856625D6261655F5F5E595D60656566606360605C645B5B58575B5A5C625965616361
655A5F5E59535C5D
5F5B5A5E625F60645E635C6162635E5A655F625C5A5A585D625C5C615D5C5F6067596C62
6462605A605B6468605F595C5E645F645C676661616062646366655E695E645F6059645F
63616462676964666361676565655C616466616464676A64676965616962656963606A6B
636565656A67696964656A66696F6F67706A646B68716B6C6E686B6D706D716F6B726469
6C696D707D75756D6F696D6D6D6D6C727278786D6C717172696F717575766F6D6E717770
78707B6E6D7D7177767D727374816A757B74807474767B747577797178796E857A828177
77797672797E788377747D7B7773787C7A7A768179797A7C7A807C7B7B787B7174727576
7D7781727D7A737B72777179757672767578787479777D777D717C767A7F78757D757C78
796F72788373747A7D7C79767671746F777A7A71777273736E7B7379747077726B777079
777473786A6C726972706F757270746C746F696C77736F70706B6A72756D6A6973706C68
737371726D6A6D6A6E6C6D6E72716C6C6F6D716A79737872758184727D88868B88989FA5
AEAFC4D1E2EEE6E7E7DCC5B2A790988E8287807C7C776F6B6F686F666B686B6568646466
636B626465615D5E69665E5F6463606261695B5B6A5E6362605E615E665D6260605E5F6A
61625F60626D5A5B5E636269605B615C595F5E655D63565E646359625A5C5D5F5B5D5D5B
585D595B5D585A5D
605B6261575A5862595A5D5F5C616368665D64625F62645B5E685F656162585D63665F65
5D655A5C615E61655A61606064686365636566666260665F625F6364656365655F67645F
605C6460626764646461645C6969626563616463655C5D5F696A676163676B6463686965
6764636467616863626A6A6D676A64686B67666C7367676D696A6D68696E6D676B6A6870
6C646F7274766E6E716B6B726C6E6E71676B7974697673737070697471736F73716F7074
7273707978797D74767273727770797271777B7A7A7A777C797372757D72717974737676
78817E7F72787976777B787978777E78737C76777F7C747E747F7B78727A7B7A7F7A7C7A
717779797E727676788073767E7D7A79747E747A707573786D767C7C7978797B7C7A7379
787574747C7979777A7472756A7D747270717775707772717B72747572727A6F78737672
74766F78736E77697271746F78716E6D6D6D6A6E726D72706F6B6B6C7170716C6E6F6F6F
72736C6A71656B6E716D716D75676B6E6E6E6C6D6E6D7674807C807E7E86899096999AA1
B7CFD1E0FFFFFFFFFFEBDCBFBA9C9489847E797872736F7171706A6C6E6C5E6C68676862
646A686764645D61625C62565A656263615B5A5E65605E565E5C5B606160625F6255635D
606A5E616065625E6361625F615C635D5D605D635C5F5D5B655D635D5C5F6161645D5E62
5C595C555B5E5B60
575D605B5D635E5F5F5E625D5A5B6059635A5C615F605C5C605F605C645D605E665E6562
5F59635E58615D605958615E5A63626363655B606765605E6365635F6061635F665D5F61
635B6560636A696964636769666467606461665F6263696A63646A6C6364676964696864
66666566666B64616767716961646667626E72746967696D666E60667065686A736B6B73
6D6A6A716A7271636B726C716E6F7B70707371796B686A7A6F73746C6D73707672737570
78706E72766D7C707373787B7C6F777571737A7480747778717D7C7E79717874757B7677
7B7E77727481757E757E7E74757F72776C797B777179777177757A807576777077747176
7E777C747379777E797B77797E797B787A6F74797574777773757473747B6E7075797B7B
777C7574806F7974757D7475767A7A716F76787D716F7B716E6D72716D7572756D6E7072
777171736D6B706D6F70716F6D75677170796F6F6D6B6E6E726C7066726D6E6F6E6E696E
666B716E6F6B6D6B6F6D6F716E6E6D6F726B7274726E797C767C7F7D8184888C9293ADB0
C9D0E9FAFFFFFFFFFFFEDECCB3A99D9487817F7B7B777976776F726B705F6862686B5F70
626268656361695E5F5D6563626460616662655E60625C60685B605F5D5C5C5B5E625F68
6264605E635B605C605C626667655A605B5A5D585D605D69605E60615B5E5A5E60585E62
565A5B5A605A5E65
5B5C5F5E6563625E5E61635D5D665F66625F5A59625F635B605D5F5F5E615C5C59645E60
66625E6460625E6664635E6161615F64605D625C5D625F636161656860685860596E665E
6A66636160646463606565655D6168636A6462645F6463676C645F5E6266636464666C62
606A64666F67676468696A645E6B6A68686C67706A6A62696968706F65696E6D6B676872
6D6A6B686D70736C6F716E7068716C6F706E6E6D6B7171706E706E716E79726E6E757770
6C717271767774767D6C727478727677717274787E707274747F7A76777572787574747B
747A7F707777787774747B7B79757C797F7676797A77707B777477767C7B7C7A7D777F83
83797C79797F756F787B797876717B77727576787974797974757871737A7B6F79747571
797575787077797376717B727A776B7675787572767175767A767B7774716D7079736F72
6E71706C6C6E71746E716D727071736E70706D6F716F71756E716F706D706B6B68686A68
706F6F696B716C6B6D6C6E6D656D68736E707173716E7C75777D7B7E837D8B8C969DA0B6
C6D8ECFFFFFFFFFFFFFFDDCEB6A89794898781837E74766E736F6865676A666569676967
616564655A605D63625F6365645E625B625E60615B675C5F605F5C5F6160606067675C60
655A5F5E645A635C665A61615D5D6360655B5E6461605A6266605C5E5D65635C605B5B5E
645E5959575B5B5E
5C60625B5C5B5A625D625F5F5C5A5E5B5D625F5E5D62625E6362625D62616163605D615B
5B5F626065635F616465605F5F655B605C695D61625E655F616261636369596362626263
625F5E605A62626163666262666161656B666763606267646D656C6B6367636868666A67
645F60676C65676A6D686767686D69666D696D6B676B6A646B6C6D686D67706C72696865
686768686B696C6A706A6B706D6A6E6E6F6F726B676F746F6A7776746D70736B6E717C70
766D74756F7B76766F746D7977727C74786D6E6C777A777677787A747A787873787C786E
7879767C75757574767877787C7B7F7B7374747877757C7F76777777777A7A747E727F6E
7B7C7A7C7D7C727A777E7778757777707579797B8174737C76737C767872767A716E7479
797078707A7F746E7A737A70736F796F777572706F76787772736E73726F707776777171
6E75716E76797074727075676A75666B736B71746D6C6C6E686B6B6A696C7368706F6C77
6C6B69746B6E69746E656E6A6D75666B6E757270737472727C7E7B7A7C838B8F9C9BA8B3
CCDBF8FFFFFFFFFFFFFFE7CFBBAA9C938D83857A7E7A6F70716E736F6C6C6C686861675F
656563616364636562655B63615A5A6363605A64545C62616162655F5B6460605E5F635B
5E6162655D5A6462605C5E59615C5F5D5F5C615C59615E5D5F6065646266605A5D5A615C
605D565D57585B5E
5B5D5E61655E615B655D595E585B59625F5F62635C5C5E5F5F635D605C655D615D5D6561
5B61655E61675D5C6C6360695C61646060605D66616062616063625E645F6563645E675F
6161646F655C64625E65606764696461696B666364686A5F616263666A67666666666562
636B65676764605E705F6A6D69686C626E6E64706C6B656F6C66686A6C6B6A6368656B70
696D656A656E6C6A6C746B636B6C6E716D6F756E71716C6A74706D766D7771726D6E7372
706E70747270717274767077776E79766A7474777375797972797C7E7677747976797673
787679757A7A7476757778777A797C7C7A7B7F707D7576717B6C7575767E767573807678
76797D797C7B7F79787C7570787B7676786E79787C7E71767B787A767477776F77727373
767573727C7377737C6F7475797879778077717771716F77796C7A71767670717276736C
717475717071746C70626F726A6A716C75736F6A716D6B6E736D6B665E756D6A706B7B7A
6B686F6D6F6D68696F706D716E736E6C726E726B726B7072747F7B7D7F7F8B878C9FAAB4
C5D4F4FFFFFFFFFFFFF9D8C4AFA4A092898D847E7B756F736A7566667177686A696B6467
61635F6166685F635A625C5D68635F5D6460625F61635C625B5D655E69605B5E63645C64
5D60665F5B63595B665D58595D63635E61565E5E5F60605E56585D615D56615D64585F62
605E635C5A555960
5B53575D5C5F575E5B5C61615F655D5F605C5B5D5D63645C656161606057585E5E665E62
60636462656162596061615B6561675A6062625E5E62616264645E5C6265646161616167
62605F5E60676762605D656068675E69646264665F6B66636A63696A696666645F666C67
6B6F666A6A656D64685E696D636E6260636365665F6A6D6568776D6C6B696A69716F6974
6B6F6D687376686D6C686F6D6D6B6F6E706E6C6F6C6774716D7276746C6D6C757275716F
726D70717178787C7277787678707975777475707D717676757A76777676797C75767A79
70707977787874757F6D757E7D7B7B747675747A78777E7A7A7C79747974787479787B7B
7D747A73747D7C7E7B7577776B77787476757B74787A7B777378777175796D7D6F767074
70777B7875737675757277787A7171766D75767B73747872776C7473776D6F7374766C74
6B6E756B726A706F7375756F7373796C78756A6D716F706E6A6D72676A6D676A6E666C71
726F656A686A6E6C6E6C676A6F69716C6E746C6E7375737A7A767D7B7E7F8983879AA1A8
C1CDE4FAFFFFFFFFF9E7CCC1AEA1988F8C81867A7C74736F70726D6E6B706C646A626762
6766645E6066606866625D5E6865615E5F64615F655E635E58595C5D635C6560575F615F
65636C665F61585F5C605C61605E655F5E575B585E5A5E5F5F58605E624F5F655D62595D
5E5D5D595C645E5F
5B575E5B5D5D5A615C625B60655F646364666065615D62615E5A635D5E66625A5C606366
635A60635F625C6262606561605D616762636165555B635E6363615F62606861616C605E
62636562635C6266686062675F6867636A646861636A5E6B60616B6861626D65646E6F69
63666A656265676B6563616665666D6B6A65666F696C69676870676968686A6F6F6C6E70
726C6C686D666D706C6A6E666A6B6D6F6E6D6A6D706F7470677266736C76737674726F6A
70716E7676747477726F7376756D74777B7475747D79736E7D75757870797B7173777377
767770757A787373727C77757876777A787C74757A7F797A787A7778757A757B71757772
7F787A787572807876727974757872817A7A7974777670717E7D76747A76786F7B726E72
79746F6F746D6F7474737E737772756C7A72747470737270707371736C6B746C6D6F6F72
7177746C7469746D6F716B70716D6A787174706A716D676A6E676A6D686E686D696B6C6E
717072707271637268686B766B6C7269716D737271756F72767273797E7C7F858B939DA7
B6C3D2E7F9FFF7F1E1D4BDB4A19A978D8B80787D7E7676757771766D6B6B626B66676366
636265626264606561616463595D5A63605E646064655A5B606059635E5E6168615C6362
615F65595B5C596360635C61606268645C5A5F5D5F5A62585E5E5F6059615F5A5C5E6560
5A595C5D5D5D5C5C
5C5F58635F5E5D6360586158635B5B5F5E615D5D5C5E63655B5A605E5E625B6260686861
6365675E68605F5F5E605B64616161615D666565655F5D5C6869605F60625A5963606766
616463666065655B626364665F5F6566666E5E6762675E6C696867656B64636865666469
696665646F6E646366686A656759656D68686A6A6C656E6C70676B6E676E696D6F676C68
6C686E6E6C6D67696C6771716F66736F716F747071706F786B696E6F72697271706E7177
737271707676746E71726F7A7277736E796C7174767375737875757077727A7772747C72
74737C7A7074777A7C76767477737A7F7A6E7C7D79747A79757878777C7679767B787479
6D7B73796F727876797B7771776E767279706D787578726D767274727775747879766F70
7375767171716E696E6E706E757572727771717B7572727A6E796B6F736F6B7075737472
707470706D6D716B6974686766717273726F6B6F73706C67716B6E62696E706A6E6D6972
7461746E6D6C656C6B6E6D6F6B666E6875726E6D7573766E6F6E787E7D767D838C93949B
A8B9C8D2D2DAD8D2CEBDB2AB9E95888B858182767A7773706F706E666E675F6B6868615D
5C6A6662625D625D6566615E645F585863625E5D57635B5F636360605B605F635D596869
675E5D5D62615A5B5C5B6458615C60615A615E605A62606258615A5F605E5D6362585B5C
5A5D54565C585E5A
6059595E585E5765625C5C6460585C5F5C5E605F5762605C64665F5A645F5E685F655D67
5E6163665A60645B5C5D695E5E625C615E61645F61625E5F625B5B5F64636061665C6063
5E625D656864676357626053606363626C6963655F61606468656465656568616B6C666B
64646B6D5F6561696E686B676269646D62676762666C696A6C6B716A6F68677062686E71
6D6A676A716A69697168726E6A686374756C7A656B696C6F6F6F7069726F6E6F73716E74
6D73716B697D7173736E7A747474776E78707E767576726D6D747B7379707172757C7077
746C7B76758087766F7B787B797A777378757E7477817974787576767772787270786E72
6F787B777B7A6D7576737475737974727971707B73777576757C6E75757983756D777473
6F787A716F74746C757C6F727277767A7279747B6F716C6F736C767B716B6E6D73726E71
6F79746B78777078686A6B69706F726E72696F6F6870746773707374676B6C636E6D6871
686E6F6968686B6B6C6B6A6F6D6E6C6F786E6F6D756E706E6A75707679767A80878F8D95
9A96BDB5BCBDBBBCB1A4ACA09B948A86827A6E7279777274706B716D6B69656466676060
646460605F64625F686260655E60625B606A675C615C6061625D635F5E5B65645F5C6069
635C5C5D5C655B585D5D60666162615E545B615C5A645B585A5E5E5E625F5F5D615F5B5C
595D59645D585D63
5B5F595E5C595B5F61545C5F5D6662626B625F60625F5F5E6161605D5C5C5F605E60685F
5E645D5E60646669645D675C625F6260665F565E5F6368646461595A66605A635D616260
615A6162636A5F645D6163666065606860686561635F5F6563646466655D606366646863
62676460676D64665F6264626564646363696F6C69697166726A62666D6E6B6B686F686E
696B6F6C676B6D68706B74756C6C6A6F696D6D766A65717067706E6A6D716B7270777075
6B687477716E6F706E726E756E747274736A7370746F7474707372757879726E796B7571
776C73737B74706F787371757178757374787573726E7372757275727579717678717777
7673757376747174757671777B707974767475767D72777977737774797A7472707E7A77
716E7871757276777276777075767377756F747177797472706E6D716B7369726C727269
70726D7074736F6E6E737170756F6C79717471696C6269716D6E696D70766568756F736B
6E686C6B646E6A6D6F6A666B6B6A6D6D76727268717071716D727971737C777C7F7F8A8C
90989F9EA5AAA6A0A2959B8D92868C79847C7E7A7873736A666B6E696E68616567676C62
676C605F66625F655E665D635D606060615C5A5B5F5D63615E63616262625D6465605E62
655E5B5E6460605C5B5F65685D65655F6267645B605B5E5B625A686062615E5B5F565D63
5B61595B5F605D5F
5A5C61615C5F5F5D625E615B5F5B5B5D625E5A5C626361616360615C69645D63615F6364
595E65675D5765655C6365635E645D6464686058685E5F5F6259625E635C5B5F665B5E65
68625D625D676267685F5D646C63646466606065666462656464666867656A616460685F
6667655F6069676368666964616D6B666A6E687069626B676A666268705F6369666D6569
666D697071716F706C696A726C6F6D7369706F656E677570726C6B6F716A71706E757371
6F736C79716C6D78726F6D72717873757276697A6F7071767470757A737B6C747472757A
7C79767871757575757A7B7078766C787978757B72777A737C766E757B72767D73776E6D
7B7574776D727B78727374756E7675707C74756E747377787677797F7A767472736D7477
6C767174787273786D737876737675706D7A6E767468756D776D70737373766D6B726F65
736F686C6E6F736D6B6B746E697B71726E6D6F696A6C6B736C696E6B706D686C74697164
6B6768656C686C6C6F7265716B696B6C6D71706B686E6E6D7267737570707074827E8684
878A9092969198959284938F94817D7B7A787B7A716E76696D68647066656B6769666465
64696667656660605F61626464645D6360626060605D5F62636663645D59685F62575969
5F5A5D5E5F6263606B5E5F5E635D5A5D5C5A6058595D6261595A655F5E575C5662565F68
625A57595B5F585A
5D58655F575F5D63685F615E6362645C625E625E61615A635C605B5C625D635F67675F5E
655F5B6064605C615C605958606266576162605E635A5C616163635A615C6562635F5F65
5D5F64595965635E6B63605D5F686B5F61665D6268686568606C6D636465656165646764
68686C656768646D6E6465666B666C636A69676D6B6C68696E6B6969656C716C6C6E6669
6C686B705E697065696F666A736C6F756C6A6D656F6E6D686A6D6F6D746B6B68706C7279
6C74746E72726F6B7071727077766E7675726D7375786C72737376746F70767474747578
74736B74836A787880766C747A6E767B7E73717578736C6F78727376727473726E756F75
71746D7879766D7676747573707575707279716E6D79796B7673746D7B7C6D6F736B6F72
6B7370707770706F7A6E71727778767C75736F766E6A74727A767374706B6C746D69716D
74716C6F666E6C7070687170736D79716F69716C6B686C6B6C6D6E6A6D6F6D6E696C6964
676E6A68696C6B6D666E77656464686C6A6E6C70636965747178676C716678787A747C81
8487848583958B8588837F8681787A77797171786F726E6D7D686B656C6B6A6E67676964
68606465636B656A6269666362625F6267655E625E5F625D5A5E6261626866625F5F5C61
5E5F575E635C615A5B6161635E62616061625E5E635E57595A5E595E5F64595E5A5F615B
57625B5C5F58585A
5E565A5B5A5B5B5D5B66615C645F64655C5F615C5B625D635A60635E65645F5E66646D62
645F605F5E5E5E6567685D645B5B5960625B5C63605F6059635F5C5F60605C5A6361625F
585F66686B60665C5F635D6461625E62665D62676866606B616863616D5F68676B66615D
6568696965646465646864666B696C6866626B63646B69646C6972696364766B6D686470
6F686D696B7168746E6A6A6A6F6C6B686E6B6E6D6B6C717A68706E6C6E706F71726D7173
6F7470707571717472717372696D6C7073776F70727373787272717777777B7570727377
756F7672756E6E6E737C7673767A75687D6F6C6E7276777B7869746F6E737A7A747A7574
757571707473767174706D70727678776C77757273727475777179777C6D7378737B746F
7275726978706F6C6F746E6A726F6E6F7174776D766F776E71717277736F707471706D6E
6E75696D6F6E6E6F6F6971636C6C706E6C6568666B6B666F706B6868696B6C6F6A697162
6870667471686D6D6B6B666869666D746A6370736B69746E6F6B6A6F6F727175746F7B84
8080807D827C827680838088817C737D7A6D73796C736A73736C6F666767636568676266
6358676664626466675E67686362646261626063625D5F5F625F5A67595C5C63625B615E
5C6061595F5D5E5B66615F635D625D61615B575D5960665C56605C5859636058595F5956
595A585D5C575858
5C5A5F625D5C66625F65595D6762636061615E655E5F5E62605F646A62606661625F6362
5F60646062635C615C675C5C615A5A5D636464625D625F645E5E6662635F5E5A60626060
5B606365555F6160615C6264676563685F675F635F636263676567666466686760686161
666C666A6462656769696567616169686B626663696B61676C6B646C6A676D6766666A67
6B6C6E706A6571646A6966736F676C736C73726D736D70707169706F6D6B776B6C737073
75717B6A7169707070746D6A71736B736F727777777273727273756E727B786E726B706D
6A746E7C777B6A7371787377777575746E7376776C727577776B766E74787C7A76746C69
7C777271786B77787872726F71797173706975737773797171757B7775757775736F6D68
7171736C726F6D756F6E7272756A6E78696F7071716A7772756F6D7577706D73776E6C72
6F72756F6B716E736B6A6F676E6F69716C6D6B73686E6C736B70746E686C63656C6A6D69
6A696C6C6A6C696B6069676A6D6D6B69646B6C6F6D6E6F686F6C6E706E71766C74727B71
74837A837A7D817C80757A7C777E6E7977796D6C6E64706B685B6E6E696870616462646D
6564636769646562656360625E6162615B5E6463645F5A645D5B6162625E5F63635E5E63
655E5A595E5D5D615F636061605F62565F5C59565F615D5C58595A5D5D645C5E62596362
5D5E5A5958645D56
5E5C5E5F5D5A5F5D636166665E5F5F61605A665C6062655B625F605C6864616065686161
5F62605C61625F656461615A59615E565D645C625C5D61635C5761616363616164606063
645F646566616161645E6562615F60606563626769655F60636164626363606569676769
626B676963666564646766656368686C6B656B616868656C61656B6A6B6D686767626B65
656C6B726869616B67716F6F6A676D68756E6B6A73706E6C7172746F7178717175746F70
707679666B6C726B6E716D706B786F6E75726F7477757070747874726D7070726E707371
7977756F74737073746C706F7473736E7A77747C726E757377726C72767175786E706E6F
697273737470726E7C746C786A757277737371706568717378727A77836F717372716F77
6B726D6D796E74716B716B6F67766E6D7169706B6C71777272716F7174776F70746D716E
72696B6E646E6A6C6A72666C6D676A6C686E626D696A71706970646764696F646B716968
66656B6B6C6F6B67606B6869696C6F686D656873696A6C6F66676E6A686F726F73787572
767C777283747572706A787475766A726C707267666E6D6F6B6B626766706F686666636B
6869625F5E6569695C5F635F5E63646B666164615E645B6360646159625F5A635B625B5A
5E67605C575D605D586A5A6163525A5E61595E5E6056565A5D57655C5C63565F5A605A57
5D62605E5D5C575D
5D5E58565C61625E636261635F665C5B5A605B625E615B5D606461656560636364686467
64595F6063596061675B605E5C5A5C615F646163595D62615E64605F65655E5C5D626061
6260616263606B5E60686B5E61616160686168666463666164656965695F6869645D6E68
6C66646A68676566606868616B6A6A68676A636561706560686D6A6E6B646A6C686A6E6C
646A686B72696672686B6D696E6B6B6B70726970676871716E716D6D67696B6D72706F6E
7371716E6D7479706D6D6F7270756F706D716E6A6F77707678727673777272767270796F
7577756F6F706E77786C716E7C727D7076717577706C767376757071776F6D7A6E797973
6E6D7270746E7071706F7574737673766C786F7273746F6D7179796F77757B6F726C6D6D
6E75766D70737B7774736D736B716E696C7272796F746C76706F726D73786C7170706C74
6E6973786D6B716D6F6D6C66696B696E696E696B6F6F646569666B746A6B67665B6F6667
656B6F686466646E736A696E686E67686A69686070696873676B69716E6C67706E6B706E
726E75727C72736E6E7573786E6D69726F726B716C656C62656A66636E65675F6A656E65
6766666A68676063646064605D65636065605D606160655D6066645B61695E5E575D6562
65615C595E5C655F5F5E625F585564575B58565F585E57585D595B5F59615D5C5A635F59
5A5B5A605A596360
63575D615D5F6865625F5C675C5C646262615E565E5C655C5D66635C646166626762605D
6661635C6055635D5F5F5F5B5E5F59615962605B58635F5B575D666662596463595C6066
5F595F5B665B5B655F666A616561635E5F5D5F676564606663696660725E655C64696B67
6463665D63675E5E5D6B606267696D676D71636464676A6863646868637162696C6A6A6D
6F6E6D696466646E6C696B6C7171746E6E6D676C67686C707369736B75706A6B6875736C
71726F706F736B6F7071726C7172736B6F767273677573747B717871746E737974716B74
76716F6C746B72736F716F746F6C73716F6E6D756F6D766D6C6A6F7472716F766C70726F
6E7173736E6970786E737671696B7A6E727279776F7371707070776E7173726D6C767070
716D766F727471686B736D74746E6E6F6C736B6C71786F74706E6C6E796F707472757075
6F7472766E6D6D6F6A70726D6969746A6A6B67646C6B6565656D6960696D6669676A6C6B
696B6A6B62626E676763696871616364696B6F6C6965766C616C666A6D6E676C6F667373
6C6B6D747776796D6B736F6E6D6E736E6A6A666C676A70606D697063676A6A6A696C6367
6A626667676763696066626561625F6365645B625E6663675E635F5D6560656256625A64
5C5E5D64666164615D635C5B5F61585A5C5E5A5D5B555F565D565A5C5764566260585F5C
585F5E655B555654
6259635A6363655B625B635E60605C5A5E5D5E5F615B5D64635C5E555C5E5C62635E5F66
5D6663615F5F5D5C665E6161585D5F5B5F59615C61615C6057605F645A645D5C68645E58
5F6061645D5F62605F68666660616261675F66695A5F6163675F63676A6566615C696565
5F696461686665656261686364626868666968666B626B61686B6E6660646E656A676267
66696A686A6E6C686F676E6C66706B686C6C6B6C6B6B746A71666E67646D6D69716D6F6E
6D736F6A7875717773736F696C6A7376776C6C6E6C71787C726F706E6C7372746F726E6C
7B6F6D7574746E74727471726E756B6B72727A7272707075736E756B6F766C7A7972756D
6A706F6F726E6E766E717370676D757970726D746F6F776E756F75797479697A6C666C70
74726D7A6E716C746C7067746F6E6E7771726E70766D6D6E707B6F7B70737175746F7476
6B696F736C706F69656B6C686969666C646F6B716A69676D6E6A636164686C67686E6665
676C6A696B656769656D6D6A6A65676D6C636E636E616B6167696D6E6867617774686D6C
6C7370727672706D6D756E6A6472666B676B695E6867686365666A716C6967696C6E686C
656B635F6963646261626466655F60625865666362615C58665865615E5E625F5E62575A
5D5C6062605E5C605F63615F67575D525D5B5B585E5F545C63625F58565C58595D5A5F60
5C536755645A5B61
5F5F5A5E605560675F5E5E56625B5A596360615D615A5B5959605F55615D5C5C5C5B6061
5B68575460625E5E5D64595E64645D5D525D60635A695D5C575E6563616A626562606465
655C5E646263616264656768605F64646861666C616662626661615B645E675F63616660
62676164666362667166675D63616B636468696A65666965646660685F6566706A676D6E
6469676A69676969646C66667074686C6A6C6D646A6B6A6C6F716E6D716D6B6F6B716E6D
6F717275726D6F72776A6E6F656D7269716E6C6E796A6E6D677472736D6F697676756E71
6D6F7A70736F726F73737078756E79747B7171757672756E77716D6E6E6C7371706E7570
70737271746F796C6F7471716D76726F706D7270726A6F6F70657375716D736F6E6A7471
6E6B696D71736F7372726C75796D70736B73706D6A706E70637472736A7277707378736C
68706D69716F68796D65666B696E6B706E6A70666D6A6D68676A696D696C656E67686567
666769676D6671676B6B6B656869656F616E64656B6864696F67676963696A666D6D676F
726A676E6B72686C6E6C726F736D6D68696C6B676A7168646462646763646566676A6260
686B6B65666964625E6263675D60615E5D606569695C6861585D65606762605E5B5A5B5D
5F6063635D5D585E6C5C6365615B5D62655E5B595F575B5C635E5B535D5C5557595F5D5E
5B5A6062585A5D59
565E5B595C6958595D646165605E605D5B615F5E60625E625C585E61625B625E5D606261
5B5E615E5F62675A605D645F61605E605D5D58615C5B59645B5A60695D605B6461645E5E
6062605E6B605B5F665D5F635D5E645F645D675B64635F656963596162675C6062646962
685D626265666165686C6B6767646B636168616B64666B64696D70696B6C62696C626368
5F6E69675F686B6568606D6D6B6C69686B6F686A6465697572716F676D6F69696D71716E
73706C6F6B707069696D716E746A6C6A7271737276747771746D797678796A6B776F6D75
736B6C7778736E7C6D6F6E6E716E6E756C6E716F7372706F6E6E7174706A73716E746F7E
6B7C70716D6D6E6E716F706C6F6E746F696F736F6D6E6F706B72736F736F6D687074746B
6F73746F6B766B6D736F6D6D7B756D72697271686C6B6C706D68696F6A75766D6E757579
71726A6C726F696E726E676E696E66706A627269706B646967666F666B6D6B656A666767
666D6270626967676B6E5F705E6C6D686C6D63646A676A696A6761666A6A5B6867686E64
6E6F6F736C6472676D6A6B69696966656468626167656B6A64646B656968676168666062
646A6464656663675F6565616063606860685E695F5E625B61635F5E595F635F615A655D
665B5C5D546161615D63625E5E5D675E5C6153585A5B555755575A5B5B5D5E5D60575660
5F60595C5D5B5761
605C5B5F5E615E625A59605A5D5F595F67655E5C616064595C635E605E5E615E605C5E61
5F625D5E5C615C5F5C636460605E63615C615E605A61635B5C605C5F5E616060645C5F5A
60655D5F636B64645E666562665F6365645A61605F5F60636159615E63625F6560606868
6665615D64646764666A635F65656E645F685E616B68686468716169646C6963676A6363
6D696B6466646C666A6B68706C6A6D6E6A6A68676562666D71677171706E6D5D726A6B71
746E7173707472696F6B6B6B686F707274706A73716A716F7173766C7174707170767173
69757272796C776D706E6D6C71726D73716B74706F766E71746E6C7A6D70726E76736E6C
7172776F706974746E6C6C6F6E6B726A706F6A7778746B7675696F6E726C716E76786A6C
6F72756E6C6C6A6B706B6D696E666F71746C716D6F7269727171717074696C78706E7D74
7172767372756F776B706B6C6974736E6F69646E7370656967706C656B6D646768656668
6966696F676A6A646D61686466676A676A666B636A686A66676D61666E66736D6864656A
6C6B696F6D6F6D65676E6A6A676D66626970666B6A6B696B666C6D6363676B666368666B
5F66656366635E6165686462655D616A6763615F5B645F61645E645B61685F5B595A6462
6460615F5D5C5D63605E5D5F5F585D5E5C5F5D585C57605F56555F59625D5D56575E5460
5F595B5B5F59585A
5A585D5D67565A615C615D5E5A5E5F5C5D656065635660595F655E5D615A6B625B635960
635A665F61606162665D58595E595A5C61635D5D6162685E67615F5D5E5D66605C616366
6163645F5E5D6165625B61646568646565676565646C685C615D5F6664615E6163696860
636264626A5F6A636669686C6764686465686165656569696966676A6767656A6A686963
616A6B6B6466637065686A676069686C6E706A686B716C6B6E64636E6D6A6D6D72776A70
7468686C73716D6F6E7266716F6C6772797572786D6E6D767074736B6E747370736C6870
787372696E6B6F7473707469706F72726E756B70706A747372687B776F766A71756C6E6F
6E6F696770716C68716D6B6D6D6D6F706D6F6D676F6F7174706B6A736D70747B70676D70
6F696F6D6C6C6E6E72666B6D6C716B6D6E706D6F6F767170736B6B7268736E717179737E
7B777B7A7D7579756D7070706F6968626A64766C6B736D6B6F646669656D63677162636B
6963636766656561696A6C626C70616A676A6D68676D686B645D646765606564606D6866
6A696E6E6863626D63635F6E6967646A6262656667656564656E6368636A6062566A675E
606363696A61636366626665625A5E6163635C675F645F5F6462686467625F65625E5F5F
605A67586169635C595C665F615F5860605B55585B5A5956635E5C61585E5A5F60685A5E
5F605B59555C5359
5C545E5F60605B5F625F675B565D5960665F605F615A5F5F5E5D5F5E585F58595F555D63
5D625E5E585E65645F5E625F5F5D605D5D5D5C585B5C525C6061605B5F65626159606160
60665F635D6162655F605F5D6460615F685E685A6662656061605D665E666562646B6465
596167686963676C61686765666C5E6261676862685F6467626669636A596B74666D6B6F
66636164676868636A6C696868706E6D6E776C68726B656A6F6D6E6F6C6E71716C777473
6B6967716A7074696976756D71686F6E716F7973676E6E73737C76706E6B6B737468746C
6D716D6E76726D786F706971716F75776B6F696B6D6C6A7076786F6A6D73727472766E6B
746C706F6A6F6F736F757171666A6973726C736D6D6A6E6B70707070736E76696D6C7364
69716A706F726C716B686A656D6F70706E676D6D706D676E71746B706E7271776E74787D
7C7C7D8B8E817C7C6E6D6D736A656A69646A697167686C6D717264687061696A68676C63
70686A6968686660686168646760665E6B63686A6A606C6461626A646E6A626268676162
6F6C686C686C67686A65686862675C6D69716A6364645E60675E676B6163626768626C60
6B636B6A6B65635F5B69635A646560615F606563656468676367666067635E62565E6465
5F5E5C6458615F5F5A5D595E5C615C56595A5C585E615B5C595B5B605A5C5D5A5B54635A
5E615D5951595857
565D575D555F5B5E5B645F5B5E5862625F625E61655C605E585C5F655B63665E635B615E
6361645B625C615B59585F605F60595B5B5A585D5D5A5C606160635A5D5E5E5B695E6169
625F5C62626264636361695F625F61635F67655E61646165616060606361696762676364
5F676363636064676660676B636D6267646A6E666E6467646764666768646A6067696869
686567696E6A6568696C696C6C6467626D6B666A6A686E67706E706A666D6D6B7171716B
6B6B6F6D736E75726E69786D706F6B6C6F69676B6D6B6F6E75786F766F70756C73767172
6E6F70757575707276726E6A776F7A6E726B726B6C6F7272736D696F796F6E6D776C7572
71726E6C72716F76686B7172716A74726F746E747B6D6D6B746D706B716B6E70736A6D6B
61707565666F736A7071696A636D726B6D6C6F7270646C696C6A6D6D6D6A687274777284
858C929E9D938D7C786C6E6B6A6E6669766F6C6B6A67686B686762666560695E6B616768
696A6E61656366616E6F656B68606B67656663666D6864676E696A6868686A6466656C6E
66646862696E695C61695F6F5E666A5C6967606466686260636566696961626363635A5E
676A63686E6163646560575F606761615D6567635F68625F5F65636463606063615D6064
575E61625E5965625B5D665A646363535F6059615E55555C5C57595B5C5C605D5A5C575D
5E5D575A59555B60
5E5D645C555E5A605E5D60626357585E605C625C5F59615F5A64625A5C5B635E575D615F
59645C5A5C59605D5A5B5D5E645A5E5B595C5B5D5B58665E5D655E5B5F62616361655B5F
63615F5B5C5F5D655A666462645C6B5C5E61615D655E695E6161646265645F665E616D5E
6668656A61646B6A66686563686564636268667066636C6265666B62696B6C6E69655E67
696A646B5F6A6D6869676C696C656D6B5F6B6B686C6A686565686F666C6A6D7071696B6F
7572716B6E70707272746A696D746A6D6E67757272686F7372686E777469737171787172
6B75757872716D6E7078776F706E6E6D706E6F706A6D68726C6E75756C72697369706F6D
70706D71706D707070706C6C7176727470707571716B6B6B766A756E73696E6F7269706C
616F6A6C6F75706A696D6D6E736F6C706B6D73716F6B6B6B696E6D6B6F706F76737C8087
919EA6B8BBB1A98578796B716B6766706C6B6E706D656E70636565686D666B646D6B6D64
6A676B676F6E67646464676A676769636169686961636967686B65636964686862636667
696469666566636366646563625D656264676162696466625F6362656161665D68685A64
5F686663656564655F696967646361656468686560616164635D605F6263615D695B5A5D
5E5A606458645E605E5B605F5E5F605D565E60615F5F5A5B525D5B5B5A58535B5D5D6456
585857565B58535C
5B5B575C5B5F6061595F625D595C5E56615B5D60605E5B5C605E605665605D5C62615B60
5F5C5E5F5D5F61575B5A5B5D625E55635F5E626763635B625B5F63606163625F60565D57
666B5B6159625C66605D60606060676A575C5D5F66675F605F6664645E60645F6965636A
63635E6B6A646862676265676960696C666C6B67616569635D665F686B67686A666A636A
6662696A6B676369666A6967656F676964616B6B6F6B6D6B6E6A6A70696C6A686C6E7067
6B75706B6F726C6C66736E726D6F756A726C716F6C6D73776B757672646F72756D6D7373
70716E6D6F696A6C6E6C7675716E74796B7173726A6F6D737272797271706C6F686B7066
6F6A716C676F6C726C6F716D6B6D71716D6F6D726F6D6E6970736F6A70706D726467706D
726E736F67746C6A706F6A6E716F6E696A716F6B6C6A6C6E6D6B6E7671706D7A737A8590
A3B6CCDAE6CDB4937C706F666D6769616A68656F656A6E6C696C676F6A636268636E6460
6A64646A66686F6765676766636569666363646861605F6B6668645E6A71656363686969
686367666762635C6467655C56606362646162665E69676067666367686762636864645E
6164676664626764675F5E6E64656168635F636468636166635D6662675D67675B5D5E64
5A6368625D5B575B61605761615F665C5E5F635D5E585A5D5B5B5D56555D5A5F5860505C
5E5E605D595D5757
5E5B5E575A5F5F63625F5B64585D63585D5C655B5C5C5E6355595E60615F625F565F595E
64605A6257625E5D5D5D565C5E575A595C656A6461575A5F605D5E685F555F5C6161675C
5B6263695D5F61635F615F5860635E5E60605F5E6164695A6963645E6765655E646A5D5F
68646568605F6466646065686868606C6F6A6C655F6B6969616D6062686A706A706A6A6D
6A6D6A6565696A6B626B69696E7263676F6B6A6667696A6967686B6B6C6D6E6B696E6A67
6E6D6D6F6D6F7275706E6C6C6A6C6871686F6D6F716A6C75706F6B6D75706E736C747574
716F6F7170706F7073736F77727173716C6E7171736C6C6C7474766F73706F736C6C6E71
6E696E71716E6B656D676773716D6E68696E6E6D70706F71696A7778716D7971696E696D
696A6C736D766F7171756D7174746C6E667367726E79666A6D6C6F786E766E75787E8499
C8DEF7FFF0E0C09C8474716E726B686D6B6F68666C676A63666A6D646664685F64696468
6760626562636B666B676B67676367676B6460626966666A636063686565686C6A6B625C
6665676664675E5E62646662626169606560606265665F5F62605D626262606561646069
6065685F63656461625D636164605C68605F615D6362695E616969666664636162635C5F
5D5F5C5D5D5E6261635B645D605C5F5D515C5C57585E5B5E575E5C5B5F5B5B625E625956
625B615B535C5B5A
5C585D5C5E5C5D5F60615D655F5F5A6361605D5B5F645B63655E5B625C5B60585F5C6761
665F62635C5D635F5F5859595D5D585F5D66625C625C5C5F5964635C5D5E615D5C5E5E61
5B5D636662615F5B626164655D605C66586361625D5F675E69685E5C676A615F67646A6E
68656863606760656063686463636165635F6B646C6A67656F66696A646267646B6C6966
676161666669656A65626B66646B6A6A6967766971686A60696F68756D716D6D676B6768
6C6A69696E6C68716C716F7174736E6B726F656C70726E6F716E6E686D6F707069737274
726F6E6C726C6C6F6B7370796A737173706D6D6C6B6F746C756E6E746A6D6D6A716E6970
6F65676C6E7471696E696E716A65676B6A726F716F726B6C7275746D6B6F6B6E67696D6D
6B6F6F706C6D726B6E706E756D6D6F6D716A71716F73656E756B6871716D7576808692A8
DAF7FFFFFFDBB39A81766B726969726F6E6869706F656E6B6762676562656A6B69675F6A
666C68695D66666E66686B6867686761647166656D6968676662636367606265646F6568
67696A6462665F5B6767606265645E6765635E625C5E6164686364605E5B5C6066666161
645F5D616659616466615E6960676165606263655F64626B6B6E5F606066635F605F635B
6A615D5F635E5D5E5E5D5C605B615D595A62575E5A585E5D5C5C605856525A5F5B575959
5C5B605F545C5B52
5B5B555B605A5E625F61615E64635B5C6262615D5F64675B61565B635D545C5459615E56
585D585C63605E5C595A61615C5A635E605F555E5B5E5E605D5C62615E5C5E655E625F61
5C5B5D53616062605F5C5B61635D63625C5F655E636163625F5C6160646463626C676C68
666A636766636160686A5E6A626B6664686568656868706A626A636C646F6C7169666A6A
68696163666769676A6765636765696066696B69696C696966686E6F6F66686D6E6B676A
76707370716F666B717676796D746F6F6F6E6A716F66766C696C6B706C686B71676D706D
6D646D776D70797576756E76717468767479656871726B6F6B7673696B766E7672717363
6D6B6B73727273756F71706F6D696D71746E6C6A6A73646F696A6C6B706F6E7172716B6B
66726D7368686E6E6D716C6C6C6C6C6B6A6C6A6A656E6B65746B696D6E777173828498B5
E0FFFFFFFFD3A68A73756967696C6C6E6768656F706D68706B66656668665F6166627168
656463626A6467655F67616362696C666E62646A696860686E6266635D5C686362656667
5F6B6661605D68645A5E5A665F626660656369666464635C5E65586262615F6362646D61
5E5C68635E6464626560656964695F695E5F5D6264675B6C646B616460696266625C6561
5D635F6166575D615C5E6760555F5F63635F5C585A565D5A5E5957595C5B59565B5E5D5D
585C5A5A58525258
5E5A5A605B5B5D626261595E5C5B645E625D605E61625C5C5F5D5F5E635D62615C5B5E58
605C5E5E5F595C5D5D605D605E625E5B665E655F6166635F5E5E64615D605B5959645F61
615B5A6663605E5F615B5B6263645F69645E62665D64645F605E5C68616165606A64645F
6A616868686061666A6864656A625F666465696C68676464645F66696A656A6C68686869
5F676769686C6B686866686A606E6E6E61696D65656E6B6C6E69696E6D6D6E6A696F6E6D
6E6D686E6D6B7271726B736E6D686E6A6D6C6474756F6C6A68726F7270776D726C70746E
6D6B6B7075716C716B6F6F6C766E706B70706F6C6A6C716375726D6E706E7A6C756C676F
6B67706D736C6B6D69686E6B6A6F6D706E696E7167726B746D706D6E736C686D6C6C6B6C
6B676A6A6E6C6C726B7469726D756A72696B676F6F716E72716C6C706D70767B7A8597B3
E0FFFFFFE8BB9785766D726F686D6B6866686267626E64606567656A696170666767616B
63636562626B636C646B67676461646B6366686969676861676068696C716D695A62635F
6B636B6461626261686364646C60615F685E66665F615B626363625F5F63626365666564
6266646D59655A65676369665D606564606461666665676E6D6A65675F606262605F6961
5B655D5F66615C60605B6360605A5F6257645D5F5B64625D5A58595B5958605F555A5C5D
5A58645B5D5C5650
625F5F565A5E5F636153605D5C5D5C5955585E5D5D5E666762625F605C5E60595C5F5E5D
5D6061655D585A60625C605559595B5C655D5F5C5D5C5863615B625C5F5D615F5E5F645C
5F64695B5B60615F655B6162625E5C635C675F5B63626365645F626661665F625E5F6062
656661645F665B64635F656E6363686367696369645F6668656264705D6565676A676771
6D656F6A646463676E696B696F6C69656A6C6A6B626B6C666E6C6E6C766D686E68696B6E
6F6D7279706B6D6A70726770766D7060716C6C6E6E696A7272686C736B716F736F6C6769
726D6E73666F70717673736D6E796D716D6E756D6B6C706D6E6872686B70706A736F7174
6E6B6B69686D696E6D726E6C706C6C6A6F72716A6B7170736B686C6D696B7471736D6F68
6F6A6C686D6B666E6C686D73677169646B65676B6C6B6C6E6F72706E7370737572869BB1
CFEAF6EAC3A28D7974716D6F666C6469645D6B6963636467636B616362646B6564665B66
6669605F656366676E64666F6662606063696568656A6A675F676661636162626065675E
5D65645D6561636160656267645E5F67646865605D6160646567655E5B645B6263616864
64636668606364615863685D625E626060615B665F6E6769616B6D676D695F6361676665
5C5F5B645F66645D5C61615E6563575D635A62655C615D62576061605A5B5F5B575F6161
55595D585A505955
5C575657595D605C5E615E605C5A5E5B5B67635F5D63636160645A5A5D605E6357625F5B
5B565C5F5F595760605E5E5C59635D605D6262605F5E5A5B65635A565A56616162615E5C
5E63615F5C595F645D63605F62635F646066605C5C5C696267615D6567606A645D656566
6A656063686A60656A645F6869686A676C6767626B686C616F6468616A6A626563656762
606B64646B6B686D67666369666F586D69606767676D66606769696A706B6B6C6A656C68
6C686A62696F6F696B6D70676F696B70676B6E71716F736F74706F6A6D716E6F68736C77
6D6765737369736C6C677474676D6E6D6E7971776E6E656C70707070746B666C6D726867
696F6A6B686D6E6C696D6C736D6B6A6671666D6F6C696D66686F6A6D686B697066656C71
76676F6A6C6B6F63666C706A6B646C6970716E706469696C6E6D7172696B716F7A8189A7
BEC6C9C69A8D7B7073736E6365676363656C6D68675F676868646C6B6C6C646265646167
66615F6169646C646861646B696D5B636467645C60626C685F6363646A63696860646461
6A5D68645F5F5966625F63615D67635E6461636267615D62605D5E5E67605C63655C645B
5E69636364685E645E5F616561646B62675E6463665F5A666D5F6160696E656467696865
63666C696363595E5A64605E5F5B67595D61595A605D5F5B575D5E5D555052545A595D5A
5C56595A555D5C59
5F5C5D5F645F5861635F56615F5E5B5C5D595B6261615E5E5B6166605C5B59525E615F59
625F565B615C63585C5C5B5E5A5F585C605D635F5E575E626A685F6258585A5A55656260
5C60636753655F63585B685F615C5D6263596061605E635E636463605E6066695C6B6667
625E63606464656663626A6068686A676265636865726767615F66686A6566686A5D665B
6463606865606965696B6C706B696973676768666966696D6B696D666C696B706A6F6E6F
66696E6B696568726F677371676F746C6C69656A7270696A6F6C6C6F6E766D6B706A6D6B
6A7171716B6E7270726F70696C696D70756F6D686C707170726B69696C706C6D6B6F7370
766D706A666B6D6A68696F6F6F696C716B6A656D6E6D706F6F6F6D6B6A686D6A686E6D67
6E6B6D6C71716F6D636C6D6D666570666A70646F676E706F7573627068726E717D828A9F
A5A5AA968D837C6E74696B6C6F6967666B6767666168696D6866656C696B616760606569
67626463616A68686462646469706F6169646469646060615B6363646262635B60666268
6F63686064666065675B635E5D5C64635E595E6061655A62605E5F655E5B675F655E5F60
636360656063675F6560626E655E5F6368626661676967606D686A6170656C6D635E6964
62655F61606164625A685A6060615E6164635C5D595E585A5E5B5956585D5F54625A5557
575B57595259515E
5F625B62605D5E5958605E605F5A615A5F6058645A685D5B5D5E5F5F615F655860605B60
59665F6462605C54625C66635D6360595D62605F63645A5B5F62595A5F5D5F5E5B665660
6056615D5B655E5C63605A5A5C5E5D5B625C5F676964656862625C5D685C636065606663
686664626C69695F6164646160646B6A6968636B636C645D6A6D69655D716C66676A6466
6564656266656F67646D6A62686F64656C676B626765696863676B626A746B6A6B6D6D6F
6A676C6C6A6D66727362716A6367706468726F6B6C6A6E6D6F7675726E717472716A6974
6D6B736B797173737071706C6B6F6A69707063726473767074686F6E71736E6D71716F6D
706971666B6B73756D6D69696D6A6F746969666D6A6F6F6F746B6F6D6D726F6B71666B6E
6B6E6966746A6C6B676B68686C666B6B676A68686F69696270746A6D726B6D78736F867F
8F9291877F7B726B696A6B62686A62686C6567686A6860696664655F6B67656A62696962
6A635E6B61685F606E6763646B67606459636064625D5F5860616265646A65645E686A60
615F64615A665F63636460605A605E606367696061596C6261655B62605E5C6A6662615E
66686363615E615F63645F685C69686166676563635F6865656E716D6B6C6D656C626564
666B626463606560625B62625F57585B595E5F5858565F5E635D5F595C605F5F5C5D5A53
585A5D5E54515D59
5B5B5E605F625F5C5C5E5C635F5F695E615D5B5F605A61605F55625F615C625A61615B5E
5B5B5760625C5E5A65605C63625B61645D5C5957585A5E615C585D575D5D5C5E665E5661
5C5960625E6758615C635F6A5C5F61656260616362615F63635C63676161616760626061
676464645F67666364646A6665676960676B60636A696A65655C6462676C6D6765696066
616763646869676A636B656D686662656768676B6B6D666B686C62686B696B676E6B6771
67676A6E627073756F6E736B67686D6A707366696972756C6C6F7271727275736B6B686D
6A666F6C726F6E736F70726B6D6A6F6A74666A696E726D6D6E6E70706E696F6F6D6C7373
6B6A6A6E696769696E6A777172726E6E66636B6C6D6F676F6A6B666E6A6F6B6D686A6973
6765716A6A6664696C64666E6961706A6B63736A696A6D6D71666E696E706B716C767476
7E797A7F7A747175676B68666864626E68675E64686B636566686C6968616E6563645E62
66626761616266646D63646B676A65686467685D63646164665E5D656263676466676E60
626264625B64635C5D636360635960665C5D6865636962655D656859615E6164625E6363
67636061615B605B65646467636064665F5F606165646A60636965686A6A6C6A6C6A6961
5F695961635A6260666461595E5F605C5C5D625D605C555D595A5C5B565C5E615A595D55
5E5C585C54595456
5F56625A595F5C635F5B5C615A565A616066676759645F5F5E5C69625961595F5C585E5F
625C5D59636858615D59575A6057615B5F585A605A5C5C5D5A5F61635F6062605E635E56
62605D5F6661615D61695F6262635D5F6162605B64645D6164666760595F646761616265
62685D656660676A67646568616470685F6B6665676263676867676666655D6366686566
6B67696862686D6B6869686B60656B696D6665636868686A6F6B6C6B7269636F6F6B6E66
6C6663696E656E6E696F706C6969656B66736B6D7168696A70656C746B716F696B6B676E
6C6F7973736C707373716D6D6A6C6B686F676D666D717170756F746D6E70736B71676B67
6E676F6E6E6F6971736C70736F6C727268696D71696F696670696B6B6869696C7465686E
6E70686768676F666F6C6C656F676369696A69686E676767696C6B6F676F706C67707773
7470746C716B696B6A6F6467666567616A6A65666C6164606D6A5F675F64626366656261
6267666164676C6168686B66656B6D5E6367625B656567656E625E5B665A62606066675F
616A616765615D5D625F645B61645E5C6767585C6164635F666361605F64605D60575A66
625C656266626366655C62625966696360656964656A656F636D6A65767672746F6B626D
656665675C5E6065665E5A5D605C5E62585C585A5A58555C615A5F5B575D61565B595961
5B5B505857575355
5C585A5B595E585A5D605F5D5D585B63615B585A63586657595B655E59635D6064635F5C
57595E565D5C575E5C69605C615C5C5E5F5A59615C5C61625C5A5C5C665E5E60615E5E65
61626464575B615E5B5E5F5D65615F5E64606463646A635A635A6163635D5E615F625960
66665A64605C6866625F655F5E62675A6863625E6B5F6168656666616870696B675F616A
656E666E676568655D615F6961636267646B6769606A66736B6E6C6B6E72626E69686767
616D6869636D6C6E6A6C6D696673686F736A6466686F6F6F68706A736C68736C6D687165
676D6A6C6C746C706973697070656D70666F6D6E7269637073716A6C7376696A686C6D70
6963656E716D6C6D69747172696E6F686C6A656B6767666F696F6A6F6C6C6F676E6B6171
62706A63716D606164656D6E6D616E676770696B6867696767706A706D706D6F6E64726A
6F716D6D666C696B6F6C636367666B676A676460666F5E69666869636768656365666760
646E60646A5F6060666365655E646360656462606460665F6766636060576065636A665D
5F60655D626562605E5C60635C5D6165605F5C5C5B6162665C5E63606462695F5C5D5E63
66665F5C67616160616167565F67686967636665646167606B74716B6C736E726B6F666B
686465636564626C625F60635A54615C5A605F5B5C5F5D5F595A63585D5A5F5E54576059
57585B5A5E5C5A62
5E5A5C5958585D5C5D6060565F5C6466625A6163635F5B5F666356595E5D5A61595C5760
60605D615D61595E615B625E56575F5A5B625F5C605C645F5B5A5A60615F616456606760
605D615E5F635F625D695D5F61575B615F605C6361625F5E626265686261655D625E5F5F
626460656060656164626A675E686569636664625B6563696B60626A68676A656D696661
676864646865666966655F666B6467676E655F5D6A696B6D6E6A6C6A696964686C626769
6A6D676B6F6C636D6B6472696C686C606B686E656B6B6F6E6C6D6C6D6C6970626A686C6C
6D796A74696B6C6D6F707073666D706C7169707474716E717174716F71696C6B6B716F68
656E6968666D706B747072726F6A6970766B6D65726B6E6F696E6B696E6B676D696A6E74
69696C696D6A726C6C6F6E6964706B6B7165706C696D6E69676B67686A6C646568756972
71716C6C616C6E676B6B6A6D606B696A6B66656A656B6757616C656467646C64616A5D65
686B6B66645E676262635F64636264686061616060665D636465646363616B666065655F
6562685D615C5F5F5D5B5B5E5E66605F6161666B6262626C636261606565615D625F645D
606C615F606161605C5F5F635F6569636165646763696C6D73666D6A6D6C66726B636F62
6D6C6B61686161595F655D616161605D595B645963565E5A605F6162695956615E575B5D
535A575F5261595E
605A5D595C55595E595B5D5C575F5B5E5F5A55595A5C5B605B5F5F5E626462585B566061
57605B5F5D605B595A5A5B57595A635E5A5E64615E5B62635757615F5B6057555A596061
5C6365605D6758615F616562635E645C6460635A636367655B655E5C62645F6760676261
686266616761675D6061625E68615A605F5F6A6D66625F64626465696767686B67686D69
65655F686267666B67666362716C6768676962616A6F69636D6F6A6B6C6E636C6E716569
666967696A666E656B6F65696E696E6A67686E6A676866686D69646D6F74696B6B666D6C
696D6B716E7E7071746C666B6C71716C717274726E7273746D6E6C6D6D6C65746B686A6A
696E676E6C6874686B6C6E716D7267726872686969706B676E6B6A6A656A6E6B6C70696C
6A6C676267756761685F696C6D72706766666765666F6D6D6564686B6A5F616B6360676A
68645B6962626D675E6A656B68626765617164626167645F5F6A606464636365666F6267
6A62656065645F6160625E61666B62615F6162625E625F5E6964696A6B6467625E636A66
6465625B635D635E5D5C6367635B67606160626667575E64676A675A5B64615B645E5F65
675D6261645F6460606360655D625D616564665F60686163666D6E676F746D756F6E796D
6A6F66666160655E6362675F5F5F5E635E615C5A615F625B5F625F635B605E545A5E5A5A
5A5C5E565A58595A
5F585F5558575D5E59645D5C61616262655F5F5E605F5C60595B5D585C605F5A5A5D595B
5A5F605F5E5C5D5A5C595E64615A5E5756625A5F585E5B595862565C5D615A615B5F5B62
5F5F5F5F5F5F5C62615E5F635F62626361675D59635F6260586162606560625A62656161
61626060625A64626266616469636462686867676A676560606D6665666860686C6D6264
6861636E636768696B6D6C6B6F65706C6C60656C6968666363686E676B67696C6966656D
686C7166656F6C6A696C6870706766696A6E6A686C6E6867686D6E706D6D68706C686965
646E67736B656F686E6A6C6C6F71756D6E70756D6C73756D7071686D6B686A6F6C64636D
726E667268686A676E6B6F696C696E6862696F726C6A666F696D6E6363686C6A6470696B
636C6F6D70666E5F6C63676F6B6E6A62666D626A6F6C6C6E6A676D6F667360696A65656A
676B6360656F6C666163666C6966656165616A6A66636866636261676261675F60655D69
6667675F6261645C61616561656360655C6065586068676162686463606A5C5E61606669
615B605F58635C5D65595C59525E6561615E5A5F615F5F5C6660625F6660675A5D615E67
5D595D5B5E6066605A6565605F62616369646562686668696B766A6C716E737172736F71
6D6D6B6C6369626661646264635756685B5B5D5F5B5E5A58605D5661605E645D5B555E5E
59585C5B575E535F
5D5B5C5C5759595F595D625F5E5E5D64555C5A5D625B5F685C605E5C5A5E66585F5A5958
5D60605E5B5B625C59595A5A5E5E625D5C5A5A5B5E59545D5E5D5A635E5C605A60616264
5D5D5D61605A57625F62595B616062615D616268665E625D636163605B6C616466676068
6764685E656068656160616062625B656864636161656565645F6D6564666A696A635A64
666466665E675A696E6367696A6D686C666F696B6F67646D6A65696A6866676A64696E68
6C6E6C6E6B6C67666A6A61686A6C6A6E636F6C6E6E6F676B686E726B796E6C676E67656D
6C6D6D6B666F6C6E6F6A6C6B6268786D6F776D706974696E6C69696B67696F696F626F62
67696C6B6872686C6B6E68726F6868726A6F6F716E6A6E696C707367696B62646E69636C
636968676B6D6069686C635E6B626C676D676D6E656869696E6B5F6A69646B6C68616765
5F6565656B666B656568646C656D666665646366646262635F656664686A6662675E666A
606A616760666A666861615E5E5F636663655E616D5C5B67675E6964625D695F60615E5E
645C5F6062615D6161615A5D62625A6059605E5B5F5E686168615D6768645B595F606061
62605D606563625F5B5E5B5C5E5F676867666A696765716D6D72746A6970737972787576
6A6E66686A6E6165656267646165565B616060585A5B5B565E5B5D5E5B59605D6159655D
595B60535F53565D
61615662585C5A5D5E595D5F5A535A5D62585F5D6461605B5F62585E615A5C5A625C5B59
58585E5E615B5E5C5C5F5B5C595E5B5C5B645E5E60615A5C615A595C5B5C5F5B5B565E5E
59645E62606262625E5F5D5F5A5F6660685F63646464605E61635D666C5F626169616161
626D6462656065645E6763646564636B685A6B6863666967646E6361676D666464686967
5C6762616263685C677064646E6371606D726E66656D6F6B6D61696A6B6667626A696B69
62645D6C6667636B6B5C696768606C6D68676E696D6F64686A6A6D666C6468666F606B72
65606B6A646977646D6C72656A6D6A756E6F716F6E706A7068776768686F6F6E6668716C
6C686D64696F6C686A6C706B696B6D6668706B6C6C666B6F6C6E6D666E6B676E67656968
656B6868636E6F686766636C696E6D6A6D6C646E6A696E6F6D6E6D705D6867635E686A61
6B616767656C67645A6467696968666462646469656660626363646765635D696363685E
626066696965606663696366606261635E5B5D5A64605E69685D685D5B65635B61646860
615E5F625B62665D5B6164605D5E616360635D65635E5F6567615F5D6764636463535E5A
5B626157605B5B5F5C5E5E6266636B64616A6B6A646775736A6A7371777A7A776F727177
746D6F6E6868686B646959645A5F615A5B6560525E5C5B595E5B5960605A62595A5D565C
58575B5A5B5C5058
5B565F56645C5C5A5D5C59575D575A5C59625D5D5A5E5F5C605E6165625E5A5C585C5A59
5D605E5A5D5B605959605D59595D585E5B625662555E605A5C52535E5B5B5F625B605C61
625C58606263605C5F5B67615C645C60685E6464615F585A616463625E5D5D6369606A66
61605D62695D5E636A6662626169656D6A636767646862646669656361616C6A6C666869
6B6762626B676D5F6B6666696C686C6365646A6E6B636B6766656F67686C696865646C6F
70696668666B636A6C6969656E6A6A656967676565656A6F6F6C646E70686E686768686A
686C6B666D676B686B666A67646B696A62676A716B6F69696C6F6F646D656E6D65696E6A
6B726B6466636B686F7268636864696E69666D656869646969716F656C666F6067656463
686A606A6A676467656663666572686F6A6B6965676C6066667065686C61686C67666466
6363686369606F6D67646269636469606160675F695F6666626263676863636163675F62
60656A62626666645F64646161656460646364685B625B5F59635D6659655E5A63675D61
685A636256675B605D5C655E5E5E595C575A5C5F5F665F66665C6162666A5F5B64596161
5D625E615C5A615C5D5F61695E656962626069656D696A6B696C6F717779797576777E78
7B7A77746D6B666F5F6461596A61616255645D5E5F63625F54605B6163615B5A5C5C615D
5C5C5D535E5B5951
5F5557575F575D5C61645E5D605D5A5C5D5F606465605F5E53615D5E5D5E5B60575D605C
575A595E57605D5A5561615D60625A5D6064615E56615F6559585D5E5A635E605F635F64
5E625C655F6163635F5F6161615A605A6062675C61615B685C6061606064606165676763
66625C646767676A645F6264686B6464616669676C68665B676568675E6B656566646866
6D68646263625F6766676765696F6C686B646C646E6B696B61626868665E6F6D6B6B6869
6E5E696866636B6A6E6B6B67676E616C7164686E646D677065646965706E6A6E646A6D6B
656E6D6A66656C646F6D6C686D696F6B706E726B6B656E636F626869666C696D66696C70
6869696B6A6E67696D6B636F696B69686E6D656C5F6969686C6B6C6B686A686263636F67
6A6469626B6B726561676C6B68666E676B6F60676A6F696B6D6D67636B626E676E6C6568
5F6365636D61635E676163636A66696066616B64676262655C5F6064646663695F5F5E60
63616166675F616467666C5867605E635F635F5D625960595C6161615F5D65605B585F65
5E5A6163615C5D5C6362605D66585C605B62606567646D6166616364655F5F6061605A61
6166555D5A636161605F5F615C635B6560686565626B6668737176727A7A6F7E777E7C72
7D80747A7B70736B6D6566616265615A5E58625C6258605A585C6566616560565A595E5F
5C53595D57535B59
6461625A5E5B61615F60575B545B615D605B665C645E575F5D5E5C585758585C615F5E57
5B585F5F6059685B5D565F5A5B5F5E5A5C5B605C655B5F5E585D59595F59625D5F5D6260
57565D5F605D5859605E5C5B5C605D635C5C615D6060615F5E5F5B5C666465636061605E
69645D646262646562686460646767666063696860666A6D6D5C61656664616B6B646265
6962666864696B64626261656C60696968676B736E65616A6C6F686565626B6E65666666
6970657467626C6C716C68686A6E62626F6B6A6B716D70666D6D6B67666B6D6A64656F67
6B666664666C736B6A666C68706B67696766656C657370666C6E75676A6D6F6C68616E65
766968696C666A67606D6A656E686A6668646469686F6C6767696D656560686E64696964
6B656E696C6E686C65706D6E676D696C636C6F676768676A6B656761676C6A686D686662
61636868656367636667626862666562616C606068625F6561626C5F686664665C5E6461
69655B635D666461655C66666E5C605F5F5F606161645B625F645E656465676062606365
60645F525B5D5D5C5A65615E5E606459585E63615F655F666662625A60615E5F5A56655E
5F5F615E5E605C605765625E5D6462655B6667696B6D6C6D6B766C75787882787F818B7E
86827F8078706F6A6C6766645F69665F615E655C595A5C5F555858575C5D595B5D5E5B5C
4F5B62605C5F595C
635F555F5B5D59625F545E5A5F5C5F5D5D5C575862595B5C5B5860585B5E5D626662595E
595D6157595A5F5E5B5D5E5E5A5F5A5D605E5A5E5B5B58646156625C606B5D5A5F5C5F62
5F63635C5F615D615C595D5F615E58626066695D62655F60636161616463656E866A6E67
625B5F625C5B6061626C6362635C6760616268636366615E616963686263696863676661
6069656263626468686564656961646D626869676F706565646F6E6A5F67616C68646568
69686A5F606A6965676467696369686769646E6B6A6B6B676A6D666865626C6D6E6F6D64
686962666A6C656B6B6D6E66696A6F6A7165686E71696A666C6C6D6E6E736A6C61686969
7066626873686668696B676C6B73736E6969636D6B62676468706366606B6669676C6B6C
6C69656B6961626A696C6E696B6D68666B69646C666C6B67606B68616A68676464696566
6465646C62686A616A686A636363635E657067686962635C63685C635E63645960696068
6263656465625E64616864666661645D615A645F605C6365616562685A66626465626261
61625F595B5D5969595C5D5D5D605658655C5D6061676964605669655B625E645E595858
555E5A59595C5E5E5E625660566062626A6B6B6870686B6D7274727773747E888A87868E
92858F857F847C746E6C67666D66685D5A5F604F595C5E5C615A5C5E605A595963575957
5A5E5E5C535F585B
5C5F5B5E61665A555F5E5B5D625C5E605D565758625959605D63595B5E5F595B59605E5F
5B595E5D5D595A5A5F57585A5A5A5E5C665F61625F5C5B615C565C555E5F5C5F645E605D
5C675A615E6261635D5D66565E61615C5B5A5E5C6563605F5F5C62626062657082646661
63686961676163666464665E645D626165646268686F6A5F5F63635B68615E636C676661
696C5D6969646261686A6D676860686369666C676A6D676D696C67636968626464686466
64696B6C6563686264666D6E686E6967646F6E6B6F6D6771686A656168706B6B6A6A6B6C
6A66676C656F6A6A676E6865676F686C656B6771696568646D67666C6F656B686A696B6E
6A6564726867696E6C6C6F726F727B7071676C6C6E6F7068686768676664696D67676667
5E6566675D636E666A64696D615E666F626D68656B63666C6D68686866636D6762605D63
65666B5D66626A6B64656267666566655B6561675F6D6169616162626162606161626A62
6366635E6B5C636764655D5F6961636664626267645D665E5E625E6562615E655F5E5C5C
5C5E5C625E5F5E61615A60605E5F5C5D575A61565F63636060665F62675F64635D5B5C5E
5D575E65625A645F5C5C66635A565F5D676367626368686D706C7B707A82888C8A919198
9C9F98918D807C7574656D646E64676263685C5D616258625B64595A5C626363635B5853
58585A5D5459565A
575E585D5E5D615F5A5E605E605A5B5D5F5E5A5E615D5B5D5B5F5B5A5F5E605F56565B5A
615C5F625C5D615A565E58585E5E615F5F5C57585A65605F535D5E5E5E6367645A5D5E62
5F635D5B5C5F5E5D6166646165615F5C5D5A616161635F5B615E616167676466685B6069
60655F635D66616B63675F6262616765606662656867646B6669685E6863616568646463
63626966676A64666669707266646A636F666B6B68676F65676865626A6A5E7069646767
6968666B6A676C6A6E6867676D6865646B705E686D656663646C6F646A6667636861786B
696E6963686A64646B6F6A646D696D6C6C6D67656E65686B72666F6D67666E676B666761
676C736C6666657269706C6F6F696C6C646B6366686B646E696B66616569696665606866
65625F6D6B67626C67666169625D646A6167686C6D63685D68635A6865616464646B5E66
60656365656160636660676161625A62636A696464646268646666616460666463616166
6068605C6064686264635D605C5A625F5D5D5C63635E5D5E65635C5B60615C5E61635E60
5E595B5C5B5A5C63625E5D5B5C56625962625E6663656368616463635F615961625A5D61
566260575F5A625A615E66676464675F6067666B666270676F6E737478818B8B8C97A7AC
AAB0A7A39D948C7D79726A65666968645D625C625D585F646564595C5E5E605F5B60605A
595C575D5D575D5F
5C5F5E625F635B5C545C5D5D57646A5A5F5C5F605B605D5A585B555F5E6556615E59635A
5A5C5A5E625A5A5C615C5D585F575B5E5D5D5E63615D5E635E5D5B5C5C5659595D655B5E
655F545E6759655F605F5C615F5E5F606062656163625D6A5C5E625D636A63696A676B60
6A616265646162635F655E67665C665E63606962636060646568605D646668636665646A
67645E6361656262696764636763696B646D6466666468636167666C6B69676662666C69
69695C6D68675D716B676A65676661686B646C6E6B6A65676F6E696966686E676773666B
64676B696C686D6468646B6A6C6868696A6F6B676A6D696A6A6B646A64726F665F656766
7068666A6C686E6B646F6D6B6C666A6C686C696E6C696A66646570686662686D706A6F67
68636F6D6565696A696561625F666F696765666463646665636A6366646A69635E625D67
6566676464606260616363626664625E635E6160626B615E626766636461615D65615B61
626165666662625F5C60635C665E5E5F665B5F6160605F5D615D5E5E63615F605E635E5E
5B575B5A66615C6462615D595F5F625D5B5B665960605F5D5A646061585B5F5F5B5D605A
5D615D5C5A5A59655F60576058645F5B6368706366666D6A696B7269767E868B98A0B0BC
CAC8C0C0AC9E957F7E736C6E6B6560626267655E5D5D5960625D585C5E5A5B5A59606259
5B62635D5654605A
5D5A5C5F585E5659525F605E625B5D59615A5F595E5957635D5E595A5D5A625D595C5863
675C595D5D5C615B555860575C5C645D5E5F5C5B605A5D615C5B63655E5F625D575E6261
5E685E626165636267675E685C5B5F605A665A5F625F5D625D646366655B6468686A6966
6964645A656C64596B65646B6168695F606262676662636567656A605B64655E6D606263
6B63666766646A656A636260636468606466636463675F62676B6267646564616E6A656F
6564626A616C606B686A666C706C69666E6364606A6C616C6C686765646B65636863636A
6A6B66706B6A6B67686A67677268616A6A6D666C686B6E606A6E6E6F7173666F636F6A67
646A6A6F6D676B6C6067686C6E6D71696B676E6A70666A696D69676665676764686D6468
6263645F65696D63646A696B6B696D686663666A67675C67656568656563636265606163
6667626868625D6667646862666662655D6460645B62616066696B5F5B635C676160606A
5F635B585F62666A5E5F6060675F58605C5F62615B6561625F615F5B5C5B605B615F6861
605F5A5D585D5B5A615E615A63625E5E5E5D5B6261645B5F5D61595E5B5D5D576057625E
5E585E595C5A605E5B63666160625C645F5F626466666464706E7069797E7F8D9AABBCCB
E5E5DFDAC2B3978A7E76756C6B646663625E66605D5F5C5F605D5D615B6161605B5E5D63
605D6156615C5C54
595C605B60555B65625F5C5D59625B58616A5E5D5E5A64565D5E5E625C5C5E615D5C595F
5D585864595A5B615B59615E5A5964545C5959545A5C6064565958595D5F5A565D5F5F61
59665F5C5C5F665E626B5B5E5B6064665D5E5C6461615F565E64636466695F6F69646860
69666763605D6362665F6765625F5E65636064635E6166647166625C646865626A666E68
6766625F6263666661686D69646A6A62676B66646765606A656565686365656666646267
5E656B676D66646E676D6C68696863626D676B6A6967656A6A666967665B67696D6A6C70
6A6A746B686B6C656769655E6A656C6F656B67696E726C6B6B6B6A6C6C6A63626D6B656C
6968646E646E6974696D6B686868666B66696E656564656B6C6B69686465646C62696C68
696468666660656C656A6A6A685E6969636C6C6D6B646267666668626568696962625B63
686A636766655F5F5F5F706264676262646A606E676262635E60645C62695D6163656062
646360655D636460615B655E62685F625C625F6B5C5E606159605D6264655F686065605B
5B665D585662565D65595E5A5C5D5F58535F5B5D5B5A5B5A615F5B5C5B5E56605B5E5B5C
5C5D5561625B5A64595C625E5C5B5F5F62646067666367686E717375787D8795A7B1CCDE
F9FFFFF5D4BEB09284797B726B65676463585F5A625D5C5F5E5B655A5B5F605A5E5E5D5F
5F585A5B56525359
59575D5A5E57545F59565D59605B555A57635A636059574F645E5D5666615D5B62605C58
5E5C585F575C5461595B5A5B5B5C5E5D57625B525F5F5E625B606259575D585F625E6160
645F59605D5C606662675F635E605857645F63615E655F5D5F5C6661645E66616B626964
676E60616166665B5D68665F5F6164605E6463656165656962635F6865675D62625E6461
6465635F646560626067676763616566666563646861696A655C63696868626C6768686A
6A6C6B6C656D676464685F676871676670656766696A6A666B666668696970696C66656A
746B64646C636E6D696A6B666C6F72697362676A6A666A676868666C7073646A68656E68
65666C676C676B69656E676A6F6C69676C696F6569666D6F646B6A6768656A6966696567
6D6A6D676762646665685D676764656E6C646961606369645F636367656668666569666A
6B5B606A5E64646161615F666461696864655F67636562625D5B5E6160606765605F6265
636866605E585C5A6365625B65625E655D5E605E5D596065665C615C5F615F625C5C635D
5D5B5F6861655C5C606161585A626061635B5F63606460595F5E545D625E606061545B5E
585E58635C5F595C6068585C56575F6461665B665C61646F6C6B6B6C73818795A3BFDCFD
FFFFFFFFEFD2AF92857C7B6F696B656762605A5B62635F5C525F5F575C5B57645E595F61
62575B5A5C54545E
5F5A5861565C5A5F5A5D595D61585A5D615A62625D5B605F565B605E5A5F5B5A5B595D5C
5C5D515E58625A565E5E5F5A5A57605F59575958555E5B62625A5D5F5B5D60635C575B5B
605A6265605D5C60655D5A5E5A576163635C5E636062596165645A645E686966636A6063
5F5E626A6161625E615F635E676563655F625B5D5A676669675C5E606569616764656361
675D5E5B6261626765636364666A6766626B68686566666B69666565645F605E6369686B
676565666A67696B666D6D687060686B626363696C73626A6C6470696B6B6F6F6C6E6A6E
696761656A6A6A686C6D656C6D716B666A696A676572696A6C656A6C67696B6967645E67
646665636865696A6C6A6667656F65646263686A6C69685F635D64696B6D686C6F6E696D
666A66706C68676366616A69686A676868616E615F65666768656560635D66636B626565
646862675D6867646264666468606766605F6A606764626160655767685E5C605E5C6063
5F58635A5E62605F5E5E655D5B64695D64655A64635F66545E63625B5D56625F5D636360
5E5A5C5E5D5E5C605B5D5B575E5B64585E5960575F58585A5C5F5C5F5E645A56585F645A
5D5D615E5C5D64575C625E61625B625E5C60656665656668646D6874747B8B98ABBCE9FF
FFFFFFFFF3E2BD9F938876776B71696B6B6B5A655F5759605F5F5C5A5F5D645F5C566062
5C5D57545A5E575C
5D585A5C5A5F5A595E60645C6058555C605B5658586156605E5B605D5E5E5C5E585C5759
55575A5A5A5D5A5F5E585C5B5E56575C585B60605C575A5D5E62585C5F5F5A585B635D5F
5F5C59655C5D57605E615C636659605B5C5D5F61635C5C5E60626161656A666666665F66
6668605E62595D5A655D63615A665E5D656762655A60605F5760625D5A645B6263626861
646563666167666367665F636867646467626A646763646566665A62656865695D697169
68696D6D636771616B6A5F6866666B686B6A696E66656B656C6D66686D656C686C69656F
63676D65646C6B636A63736E68676B6464666C686C626B686C65696F6B6666626F6F6A60
686E636B696A6A67706C6A6567626B6168676663666966656465626C646A656769655D65
666962696763696665696268686766656D686B67685C66645D615E63636B5D626D5F6062
6766626266625F61656B63685C636260615B66636B62616064645E5D685E62615D60655E
5C6264625D66615C5E61575D5D635B60676766615F5F5C625C5D5E5B5D5B64615F5A5E63
5C5F5B5C616157595B5D56595C655F5E5E5B61565B605A5E5D64625860565B625D565C60
61625E6059595E5B5C5B5B60595F5E5F615E645F615C6D6A63696F76697A8395A6C5EDFF
FFFFFFFFF4D6B09F8C827F70716C67666865605C6064606061675F5D5E5B57615C605D51
5B5C5C615556595D
5F5C5E5A585E595A59605B5A5964605B605F58595B5E5C645C5D615C5B545B5A5E58605D
555C5B5C5D605B5E5C62625A575A5B5D575B5D5A5A5A5A5E5D605C645D595C635B586158
5C5C5C676260555D64645D605A5B5C606161635F63576463625C5C655E5E6166645F625F
655D5B6463635E5F5F675B615D5B5D5F5F605E67665B5D5E5D625F615D5F5B5F66646562
61625F61676463595B6D5C61615F675D676A6A6B6460626368646F6C5D65646863656165
66666C676964676E686C67676B6D666A676B6B696B606C63686266686C6B6A67696F6C75
61676D6A6866696F616A62696E6B6C65636066646B696A6A6D6B6B67726B6A6568686268
686F68616B67686B64686863666C6363636865636668686F666A6563666661656B66656D
6C676969656A676862696568666265676C6066636967686868646569666960685C61685E
6A6165626563665D676867625F5D655F69605F5B646763655D5F6367665F5E5D5E5C5E62
5F655D5F5B60586564606863666367666166625E63625C5B636459625D5C655E5E63615F
65605F57585C5F5B5F5D5A575B5F615A5C605F5E5C5E5F555D5D5C5B5A5A5B5D5E555A5A
5F5B5E575B5A5850615C5D5D5C615D64665E60685D5B67646C6C6A747279808EA5C9E4FF
FFFFFFFFEAC7A79694857B78776A6A666D65605F5E5E5E5F58635E645C57575760585D5C
585D605B5E58625B
5F5D5C5F5A5B5B5C605E6257605E5D575B575F575B585A5F5E5B575F5D5C645B5D60615D
5D5558585C58545B5D585860605457555D595D5D5C5E5D585A5B5B5B60625F5D625D5E59
5E59635C635E625D5C6059625F5F635D60675E595A59635B61625B5D625E5F63645F6268
5F5E6A64646162605F63655E625C605A625E666761686460656267695F6163615E6B605B
68605A5E646766605E6566666A6460686263676466656764606164696565656761686467
6167675D67696A606963686B6B65696B686966646A6E68676F6970686B5E6B6A666A706D
6A6D62676467686C65656B716A6068636E6C626B6E65666A6D65626860696C7065676567
65686468676467696C616767666D655F636D6A67636861646966676869656466606B666B
636968665C686F65695F666A65616568636A5E6A6963696A67675E6367616568625D665D
65626567646C6668666865616160656161646962655F66626464675E67605F5C5E575F5C
645B5C5F61616460636160686E636969616563645B65625A605E605C5E5F635F585C5F63
615D5B5D5B585B606355625A5B5E6357565D5F5F585B5F5A5F585D5D66595D5F5B5A5C5A
57625D615D6459665C65585D6461635F5A5F626565636A6D6867676D7576818CA6B9DCF1
FFFFFFEBD9BDA9998B877C707271636F6367615E645D5E60585B6456685D605F5C605B57
585D5758585A5661
5D5E5656585B585F5A5B5B5B565E5A5D5B5C565C5556695F605F61625B6057615D585A5D
5C635C5B595F585F5C585C605B5F5D615C5F5B5E575D5C605B5B5D5D5F555E5B60595E63
545C5E60615D5A5C61655C5E63615F605F665A60605C5E5A645E5E5C6467625B61666265
6763626A65595F5B645C605D5F5C5A61615E605C656260695C6363635D625F6768655E66
6E5B6668575F61635D5A6066685E65646864676967615E63675E67636967655C60685C60
67636465676965636B676560666B6866676A6966666569626A686C69656A666467686E64
69616465666F6766656965656A656865676A606963686F656F656C6967686A6B68676E6A
61656A6469686A6D6B60656363696A696C6864696766656368695F696B69656A6A696965
68646665656562626064676C686464636266656A6E6A66626B63656B5F67635B65696365
64665F5E5B6868626467615A6863646B6B685D5F64695F5A65636468665E5E615F5F655C
5C5E685D6059625A5F59686367636B66666261625B645B61606162655F5F59656261575C
585B595E5B5F58635C6059625F595E585E625F655D61645B595C5D60605D5961585F5561
615F5E5F605B5E575E5E5F595A5959646363625E5E64646663686D74707F7C829DACC8E0
F9F8E5CFCCB6A59591858370746B6F66616764675D6160605C5B625A5F605D5C575B5956
59605F555B585C5C
5B5F5E5E5D62635D60585C575F58605B5A5C625C5E5F635F655C5C616061635B5E61605D
5F5E585A62605A5F585E595D5D5A615B5B565D5B5F5B595D55585A5D5C6560625D60615C
5C5E5B5E5F5C5D625C5D5F62615F5E5A615D5F5C5B59655859635F60635B5E61636B5E63
6A636B6C645F626963656760575A60615B615C64635E55575E66616A636363655E656A65
60645C5F5E5D5F68645E605E66645F645B655F625D6A646B6D636A65626762676969695E
67676666676E6A666A6466656B686763636767666668716D655D6268666767626764626C
6668676D6B6C66646569696D66696A6169616068646F636F6A6465666669646869696A6C
686062606A6B69666E6269647164666A6A686C6B6864696369666A676B6A6F6C666C6765
616164646461636460656460676368656161686368626562616366616565696566675F65
5964616C636865615A6765695F5D646167666363626067615F636668586163595C616561
64606061615F66645D65666061686465616263605B545E615D595B665B6561595A635D58
625E645F5D5E615C595B5C5758556163675B5F625B5658655E6156545959635B5E595C5F
5A585F5A5C625B5A5E5C55605E5A5C595B5F546263606362685F68666E747C7A8E9EB3BB
D0CFCBC5B5AD9C93937A7C7778696E656A6568625F626661625E5A5E635D5F5B5B5F5F61
5A5C58614F515556
6258625B5D5B595C5A595C5C5B5A5D5E5A5754575F5D5E575D5E5D5F59596258615D5D5B
5B575D5B575C5E5D5F645C625B5F5E5E5F616261615B5B585B5C5E5C555B5858685E5B5E
5F595E635B59595A62645F625B645D655A5A5C5B63585C6160625E5A666460655F646E63
626F666D5F5F6064595F5C605C5E5E6460625B5D5C64605B6C61666264605F6363686366
5E63615D62646263626464636565615F5D6658655E5E6364695D6767646B646069656065
6665706260646966666A65676C696864616C6B686D676D666C6D6D63616961706A696667
666C6F696F5E676A6960636D6A6C6D686371696A6966696563636168676969656C69626D
66666265666D6C64696A63646965666366616B7E6D626D6860676A6A65666463646C6862
6768645F695E6365666B64636465666266696865666967636566645E6263605F64645F61
6267606464615F62675C61635F6465666B5866675C5D636766645F5D61625E67685D6361
6066645D636360616162615F63656D5E66635B5D63605B5A655E605D605C565F5C5F5D5E
605D55595D63555D5E625D585B68605E5C5E5C6262605A5B595C58605A625763565B5A64
5A5E5B565A61645B525E61675F5E62605E5C65636166646360646F646E6B777F8B929DA3
B5AAAAAFA1998C8C8985837A746B6D716662646A61675E606060655D625D5D5D5A5F5966
5660565C5E5A575C
5A535D615B5B635C5C5E5C5F5A645E5E5C5B585C5E625E5857585E645B545E5B605D5C61
6161595958595F59625661595E5A5E5C6558575F58585C5E5E6060625B5957585C606163
5C585D625A63635F5B6360616164595F60596564635F5E5B5D5F635D5E5A62655E586871
6670666A656B5E67605960625F6A5E5E6261615863655E60645E5D695E626660605E6362
616B5E666A5B646963616569675D6B615E62615F6162675E645F646069616265635C6266
69667067655E6B6B616B676B64676A6D6C5F60616A6C6364646C6B6D6562696C6872626B
65666868676E63696B65656B6961666A626167696B696664656669656A61706B6C636765
706263686B6B646A62686A5F6767626766666765686B6A636A676568696B6864686A5D60
6969636661646B656568646660666A62645D67605E6567676169625D675F635C6A636568
64666B65605A64656563676B63666162606B69625E5B635F636664606363635E5D5A6162
605D5B5F60615A5C615E6161605F6964626158635F5C5E5F65615A615D565E61585C6066
5C59605964605D5B5C5C575F5F7E5A555F645C5F635A5B5F605A565A58635A59595D575D
585B5D605D5E525A5B5E565C5C51565C5F5F646466616466665E6B666C7272767B888D93
95999A9198938C8C8A7F7C7971726C70656365676362606463655F5F55575C555A5E595E
5959575859555458
57575B60605D625C606457615C63605F5F5B5F5C5E6760605C575F5959575B555D5E5F5F
5D62595653595B615C565C5E5F535F585A585855586059575F515D5C5E5C5E5858615F5D
5F5E5C615D5F615C545C606165585D5E5F645E595D5D585A5F62606259635A615C696C78
706F6F696363605C635B645F63625D615C6065625B6764636165596768665E645D616564
6460695D625C606C5B695B6B5D656A5D635F5D5E5D676264606362666266676A676A5F64
665E6164676A686C6A6D6B71676464666865696F6A66676368696A696566686C6C5E6869
686D696669686A6A71696F65685E67646566666669676D696E6A63656B636B6464676562
6A5E6564666666686661646E6F6F66696D656C666A6E6C6A666A675F676568646D636866
656D6866606968636566656764696662615E67655F6B69666A6268656467625D5C65655C
655F67666666616164586261655F5C6560615D5E5A63605E5C5B5D646A6060625E665C66
6463665E6A64595F65625E69656064685E655D615D605A6359596662595E5B624E5C5A62
5C59585B5E5F5B5D5F615A62615E585B606465575D59595D5E59595A59575F5D5F5C5F55
605B5B5F585E5C5D5B5B5E605A5D5858675E606061616167636568656B65736D727A8388
87848B908B8D828682817C6E766F686B676566636460605E625B5C5E605B5A5D64595D5C
58585B5756565954
5F585B5F5E58625D5C605E5B575C5C5C565C5B5D5D645B5C625C615C5A5E5E615D59595C
5F5E585E5C5D5D565E615C605F5D5A5A5E5F5E5C5F605A5D59595F5E605A575A5E596359
5957575C5B5C5B5956605E5D59565E625C615665606B5C5D675E665E5F635A666965676D
75726C6B6959585F605D605E65645E665B61615D5E6564636B6764606D5D5F675F65655B
606160605D6A6A656363616A656262635E5E606260656B6B676460606267686663686862
656B666B66685D656A6765666968686C6369666568696A69646C67676965666364686664
616C646B6569676D6A5E686469636B666C64676C606464646662605E6D676768696B6764
636D646A696A606A636464626C616C686163676C6367686461636C6966676368695F6861
626368686560665E666B6B62676364626468656B676565686C685E586063695C6B5C6760
5D6163686461636763655E5F625F636A656164606465675E5C6362615E6A5D565F5C6866
6467605E655C60666466645B6661605F5E5F5F615D615F5A615C5A5F61615E5B5E5F5D63
5C5E5B5B5C5E5A5C5D5C5B5C5C585D5E5C6161635E56576063575B5A5C635C56585A6155
535B5956535A5B5C5C595C59615C5D5665566062635F5960606163646A6A656A6C72727D
7E7C8782877B807C757E75726D6A6F7472696562636A595D605E5D60645C56605C65595D
565A535759585A5D
595A5F585F63635C5A5D5E5E655B62585B5C605F58605D58625C5D5258615A59595F595B
5B5F5E5A59565A5E556259615C5B59505D5A5B625F65645C565A606058625E565B605B5F
5B5F635B62625B5D595A585E5E5E535E5D6160615C625A5C5F595E585C5B5E6464686B75
737171706B6268655A5A5F615E5061686063665A655D65655D5A665F606062575F605D5C
5A61575B5D665E6162665D67675D6460615F615E605E645D6B5E636260696C5E67626365
6168686668696366686C6B6C6A676B685F696A5D69676C6B696463616A60626867645E6C
6C65696E6A676A606A6F6461646569626B68666768635D6561686169606064656361675F
616462606766615F6567686A66606D6764636260656B6B6765625E656464666463626865
635E6960686A6C6266656B6465646264625E656362696064857E645F60695B6158606367
5F5F6360605E656060635F625D6164665E615F566865615C5A5E615E545F5E62645B625C
5F625F5F575E69656557605F615E5C5B616164615F5C675D5C5B5C615C5D61575E655959
56595D5D5A615A5D5B5A585E58606458636F5E5F5F5E5E5B5E5A595B5B585C5E595E5D58
5C555C5B5C595A5E5C5C645E5B62635E5E5E6060605F5E5F5E616567616E6B646C6D6F74
77787D7A7D827874777F727371696D6E6B67676767655A6762615F5C5C5F6162625D5C57
5C5D5F5B555B5A5A
5A57585E535757595B635F605D55575661605E5C615F5B5F5A5D585F625B5C5A595C605D
5D58545F565E5E575A58585F665E56575E5C585D5C5F59605D5F56575F5B5E545F5B5C58
60645D585C57615F5F5B5F5B5C5B585A6555605E625F6262576162615C5A5D646960736A
706667696862695D5A626467625E595A5E5B60575C646162606261636162696060646265
595D5D5A63616160626E5E645F5B5C63605E61615E6C5F64615A64626963666165686A65
646168656A62636F656467696A706D64635E676A69675F6865696661636B67666465686E
62675F69666361616466676967676563676F736867686270676A6970665C6B5E6B6B6267
656D615F636662625D625F6969626D666561646F6465676464676066696D626666696B6C
696A6B646B6D626666685962655F66626767626562616E656667605C605C696064635F5E
605E605C5E605C625B5A605E5B595E6469625F61635F655F67655D5E62625A5E59576467
5A5E66625E5B616059665A5F5B60575E5B5E57595B5E6261575E5D5A5F5D5D5D5A5B5D5E
5D5F57545E58595C5C5D61615B5E60576761635D5C5E6153565D5A60595A5C6457605D5A
555B5E5C575C61625B585D5D585F5C55585A5D615D605C5D64676161656567656568676F
70736F7C787A7A76757373786D6D6E62686A665D6A656262695D5C59615961565760555B
5D5A64575F5A555D
5D5B5F62565661595F5A5A5A5B58615C5D665C5B5961595F5E59585F5764566064585B5A
595F595E665C5F515B595D5C5B545A62565A675E5B5D5D5C595B5D5E5D615C625A585D58
5B6361605A63625F5A5B605A5D5C5A62595A5E5B5D5E5F5B595E59625B5C5F6069626763
69666D67645E605E5F5B6867625E5F5F5D61655E62585E5F5B665E64615D62645E64625E
59635D62645D5F576A6B61686464615C605F625E5E5D64656161626265646A5F62616368
676466696663655D6A63656166626B69686964686063675F67696B686363656664656168
64626A6E6867655F636467666C656667666469686B69676C6B6864696A60666766616767
666C61626A656263636B696B67626466696A685D636564626A6361695E6267636960636B
6464686563616963686362686861655F6D5E60665F5C66636D635C6563635D645F635F6C
675F676369626068605E6262655D576A62646568575B60615D655A685E64655A5F62605F
5C635C65625F5D5F646664646060635C5E61575E605F5A585F6660605856636163605D5B
565A625A5D555C5A5D5C5B615B625D585A625B5B5D5F595C5C5B595857575D5C605A5659
545A6354565C5C615860595C5C585C5D635A585A6060625C5A665B6862646065666F6872
7A74747771727573756E6D77726E6A6A67686968636067606562625B5D5C5D5F5B5B5C59
5F5B5A57565B5A5D
5D65535D585E5D60555F5C585858625A5A5E645856605C5E5E605E555A625763585C5E55
53545A5B5C575E5F615B5B59545C595B595957605B625F5759615B545B54595964595B67
5B5A57625F56595A615E5760635B605A60535959575B5B5E5D5D555663615B6460636560
6763635F62625B6362635B606160636363605E5B5F5F5B5A5A665C665D615B6162625A5C
5E5C615C5E65605C606267665D61635C57626A635E605C62686A6660655C6263645F6660
656565626D67646563696769646A67616968656065686965696568696165696460656866
6B6A6C6867616462656763626567675E666866726768646965686463636D5F69676B6962
68666666666467646263616A656A6662676A645A6769686163686567695F6465686C656A
666369625F615C606D6869626361626467616061636C63656166615E5D625A5D65666463
61616364645D5F605D5F595C656060675F5F6259646B5E675D685D6161595A5C5B606463
5A62605E615D625A6464675D585E5F5A5D5B635E615F615F61605E5B605B615D5C615A5A
5C535D5C5B5B605F595A5C5C5F5D62605F605C6060655D6059605B635B595E585B615B61
5B5A5C64585C5A5B5E5C5C545A65585E5C5D4A5E615A5D635C59655F65655E5C6566656E
65696B686D6D706D68717171706A6669686F696966605E5E635F5F6B5E5F5C60615C545C
655E56615F585655
5D57615B575D5A575B5F60595D605C585E5D615C645B605B5B5A5E595C615F5A57635F5B
605D5A5C5D5B615D565A5A595B5C5C5656595D5C5B5D6858585C59575B6A5F635B625C5C
5660625F5A5E615E5C625E5E5E5F565E5D5560595D595B63615B67646861655C5E605C64
616865615E5C605C6365636465606263655C63615E6161616564616A605D625956586363
5A605C5C61625E6160645E5F5E6359625C606167605D5C6664595B605C5F666665646867
6A62696B6B6665676161656C6A6D68696462635F67636368665C6D61676962636F646366
6664656A6362616B68666A686765666A66696E666668646967676762626A636966666C67
696668636261686A63686368656A66655F6966676463666567646666616863676463695F
5C5C5E686A686A6566625D6C5C646765636A5F6C6361615F6360665C6662616262656A5C
5E6064655F616167625B605F665C60645F636060595F5E616A5D62605F6367625D5D5D64
5E65635C616064625E5E6267605B5A5A575C5F5E605B5A605F5C5E5C5E5D5F615A62595B
5B635B605B5D615C5E576159545B60645F615E625D5B545A5B585D5F58585F5B60585B61
6155695B585C5B5C57595A575D5C5E58605F56585E605D595C5F5B5C675F676461686369
6A6A6C6C6B68696C6A6C6C696761656D71656366696061605C5F5F5B6161625E5C575E55
54565C5B53575B5C
595454605C5A5759595964565F5E5D625A5C5C5C5B595862595B5962625960585E5E6065
5D5F5B5B5C5A555E60585D5C5B565D6159514D5759615E5A6361615B5D54575F5B585A5E
635D585C685B565F5C5A585E6056645B5F5C57615E5F615B60605A586362605E5C5C5E5F
5A61565D5A625C5F606662626861605E5E5E605D5F615E5E5B60635E6063605E54605662
605B626561605B675C69635E5B5E5C65625E6260626066615F5E6661677268646466626B
626B6467645F6A64626064656367686A6066656566626467696462676868666363666669
65676C67605E69655B6762615F5D6B656D62676B616C5F6563626666656C6B6265616165
60645E6B60686B68646A6769666764696D6D62626871635F6662656C5E6065645F666C68
656665676863636166636663676661626267645D6360625E65626860646057625F5D5B5E
655C606462625F5F6467615A5D626A686460626A5E606261595D555E5F6561615E605F5E
5F66615F5D625D5D625E5E5F605E64615D6263635F5C62646261615B5D595E61565B5F5E
55645B60685F615D5A59525E5D5F5E5C5D5E59635E63595E5D5C5A555D57605659585A5E
58605B575C585C57585B605B5A5B5B5F5B5B6062625A5E5F5F55615C615B606561566B65
67647164666C746F5F6A6F6D6866706664665D666C616A5E565B62615A5B5C54585D5A57
5A5A57585A5F595D
5B545B535D5B5A595B5C595A53595C5856555D5C595E5E54595B5C60595A5955595A5E5F
595B5C655E59596059645A6062585B5B5E5E59575D575D585A5856545E58625B635C5D58
5A5B5E5D5B5C625A60595C605E59585E5C545B575F5E5F615A5D5A5F6160585C5B60655E
605761635F5962615C5F62616066605D5B625D5C5E5E5F5B635C695D5F60635D5D59615E
5D5C6167625F5E61606361696265645D625C5B5B61615F695B675F655F5F6566655C6664
6C665F63696C656B6767656A686265696666656368636C6C696661635F67665F676C5D69
61676B646465666161646262636665666667665F6B6864626965675D696A6B6765695B6B
6D6C63676365626662666568676365636567626B64646964625D64716262676161605B65
62646965626A606160665F6465646A5B63676060646A65656060616B6766655D60675E63
5D615F63615E5A5D5F5D63656263655E64605B5B5D62606063625B676658625D5C5F555E
615B5D635F6166636060625D6662605D5E5D62605D5A5E57605A5C5F5862565959585B62
5F60585B5F616260655B5E5B58595A5F595C5D595C655F5C62545B585A595559585D5D61
5552585E595856565B5C59595B5C5B5E5E5F5B595A60565A5A5D62596463636663655E65
6366696C666B676A676B6A616A6B666468666563636767595F5C64695F615E615B63565F
5E5C5D575D59535B
5856615F5B5F5D5A5658595E5E5F59585A585F5854585C5B585E5B535F6360555A555C59
5A545A575B5B625A5D5F5F6059605D575F5A5D5E5B5A5C5A5E5D6259555F585F575B575B
585A5E5D5B56525A5D60575757575C5E5E625C5D5D615C62605F5A595F5E595F5C555D5E
5D5C5E61615F5C5F635A605966616162645E61605B5B63605B5B655F635E5E605E605F5A
645D6060645E5B5C6563635F5C5B656654605E5D63636461646264676967626E63606461
6364646566616865645F6967596168616C6B696A6669605E5F6C67626864646669666362
6564656565695D6466606A69695D696D66626D666A6662616A6568626167646363616265
6666655F6261666765656B6B65666363606465625D6964656463666567676663615D5E5E
67625F696A646066606D6766626A6060656A64616566616C6461635E625E5D6465615560
64675F5F615F5F63696061655A5F6065625D665E605D645C5D60645E656156605D5C5961
665E5B605B5C5562675C665C615C64645E5E5E616365625C5E5B5E64605F58575A595860
60605A585F585D59615F595A5A5A595C5D5C5C615E5951575E565452595D565A5C575F59
58555453575A6157565D6059665A5A5A64615B625C62595B5D5A59605E5E605D595E6E65
6062646865656765646269686E60666464635D655A5F625B5F5762645956605D5F5C5558
625B5D5858565A59
56585D61545A585A615F5B5B5E565C5E6056555C5A5A575C5B5A64605B5E57565F5F5957
58545E585A5B565D5B5F5D545B5A5A5B5A56565C59575758605A575D595A6054605B605D
5B5E5C61555A5D575E58595657595B5E585E575D5C5F5A55595A5B635C5E5A62625D5E5B
5F63626060585E625D60615C5F60665E62605E625D61616061606156655F616361595E5D
5D635C675E606C5A5C65645D635E58635D615764625D685F596561655E63606C61636B61
66656068686765686A616269696765616567686760666564686B646966675F64666E6165
69656B61686164635B5F6664676365646868645F66656C6A6B5D67645F6562676A646366
5F6560605F6765635F5F66616A63656A636A646370656669686760676268665E66636163
645E6260615D5E676161696A63606665696A686164675E645F5D5F626462636364685A63
646060585A625D656666595A5C5E61625E57645F62616064595F5A5C5F625F606160595A
635F5E6060615D5F66625E61696066635F5A5E595E5C5B5F5E5F5C6158585F5A5B515958
5E59635B56615D5F5E5C5D57625A5E575B5D595C5962595959605B5A5B595C605E5B5E5C
5D5B5E575B5F5B5962585F5E58615559615D5E5B56675162615A645E5C5E5E626263625C
5E656466636C66645A6368696D65646560616066626A69646062645F635B5C5C5E5E625C
5A5B5A565A55525C
5D5B565E5A51565E65585E5F5D535C5B56615F615B59595A5D5E535D56665D5E625B5761
5C61575B5E58625A5D615A555458605C645E5B5A54575757585B625658565B5F5858615D
6260605C6061605E60605A5C615B5E5A5F5E5C5F5E5B5D635C5D5D5B635D5C61625C5A52
595F565C655C615E5C605C6363635F64655F585B6162625E616363626D5E5C64615F585D
606664616461625F5F686B665B5E5962585F5B615F5D5C605F60665E6066606061626066
665E616662666A60636D686662646663666961606B6D6469646669606268646462616469
6A6762636365646167635E64646061645E64636666646065676E656B60635D5C67676560
6A665F5E6C646D69675C62636464656B655F636066606868626C65686562636160656461
5E5D6B605E626366626761646367616965676761636964636464655D595E63626061605E
5F5B636B5D5E625B62615F665F66635F5C5A67606164596161605A5C5D615E5D625F5F5F
5D5B5D635D606057636465625D6268615B5F615C5B6C5B595C5D615B5F5F5D53655D5B5D
5C605D5D58575C5E5A5F5C5B5B5D605A615C5A5A58645F5E5B5F5C615C57615D58615F66
60605E5A5E615C5F5E5D61575B605D5F5F5B5F5D53575B585A5A5A5A5C615E5B5E5C6462
6160615E5C646468635E696D686467605F5B69625D61615F63635D6858615B5D5D5A5C61
6359635B5D5B575C
5A5C5B595A5D645A61625F575D60595B605E5D5E5B615E5B5964575B625D5D6158585D64
575D595D5E5F595C5C585B5C605D58575A585A545A535D5C5B555959595D5D615D5D5E61
5C59595E57555B5C5A54585D5D585E5C585C595B5F5F5B5F6458665C58546160595B5E5C
5C595D5F5F60605C60645E5E645A59655F59585A625E5E6263616A5B5C5D5D5D5F656356
64606054625F5F695A5B585E605D606161695E625F5A5E635E61605C6763646060645C62
5E646567655F6563626A605E61615C686564645F6569675D606D616C61666A665D676362
6365665E676B65666B665F63676A6363686C63645F6B5F67636661676761625F67616764
616466636563635E666B636965646465616B5F5D665F646A5F635D6469625B635C61636D
6561656865616861616D61656C66656659605D66666565635D606163675F635F5E596260
6260626563635E5C60655758645F616361595F5B626363626C615F615E5E5E625D575F59
5E636160635D5A67646269635D665E5F5D5D60625F625B5C6061555E5E60595D545F5C58
635C5C635D55535D5E57575D5E625D5759585E5D54565D5A575D605A5C5A5C5C5C675D5B
5E5F566257575E61565F595B575F5B595A595F5C595E5A545D535F585D645D585C61625A
6266615F675D68645E5B616A6D6760625F5C636065626859635B5B5C5E5C5762575B5E63
5E5A545F5955575C
5A5B58615B5C5F5B5D5A575D545F555A5A605C5B58595C665D5C56575E5C5C605F5D5960
5D5A575B5B5D5B545A59665B5B5F5A5B55555C575C54595A5E56605859625E57635A5A5B
5C5C605D5A5D5A5858575A5C5F5B5D586261615B605F5B5B5D6561605D635F5B585D5A59
5B5F5E5E635C61635A5E5B606357635F595C605761625B5A606265616160616A65695F5F
6664686663675F5F5F60635C5B605F5B5D6162635E636361616262676A5F5D645F626463
68676C685E6A606761625C605E6566676164606362666264695E67666864636066676361
5D6560686260655E6C6263606263676162655E655D5D626062605D6A6464616566676A5F
63696B64676768656866685E605F635B656666635E60626566595F6163635C6662616862
635B636568636167626969646463635D6F6164666665605A5E5C69626265635F636B5E6A
625E635E6159636363565D655A606260645F60645C5E666375635D64586257635E635B5C
5F6459585B605F62696368645E6361595F5B5E5C615E605D5C605F5D515E5D5C61595C5D
595C59585E5A5C595C5C585A5C585D5B5558565A5D5D5B595C5F5D5A5A585C61605C625D
61575E565B5D5F5B5C555D5F5A5358605E645C5C605A5659555E5D6459645C5D5F655C62
6061565E5A63626468616B67695C605D696060635D5D59605E5F615B615E5963595B5B5C
5A58575A565C5859
5F5C5E59635E5C5A565A5E5C5B575A5A5C565A5F5F5955595E605F585B5A5E605B5E555D
5D565B5E5F605B5D5A5D565E5D5E5E5060595D5F55575B5B595F5E575D59595F6860575A
59545D5F59605B5E60635D615E5954585F5A59625C635D60595A57615C5E545C645E5F5B
5962605E645F5D5F615A5B6257625B61626062625D63585D5B5D60656760665C6065685E
5F6364605E6460675F5D5C67625E615E606A67635E5B59606366676164666163695A6562
63665E646764686A616A6A5E63696766676A60646663666666666266655F616366656169
636A5E5B685E5E6265655B60666A646C656062635E6266616564636560655E636962655F
6460616363616468645F6263605D6361675C61606067606C6A5E696769606B62645F615B
6262645F5F63646367695D595F6A5F636363655B6366656563645D56655C5E6360566364
5A6064636062605E63645E605A5D5E69625E6060605B5C5F5F5B635C605F61605F585D61
635A5E5F5A62605D5E5D646B67655C5F5E5A5D5C61605C585F5A5A5D5F545C5D62645E5F
5C5A6058595C625E595F565E5659566259605F565A5C5F5A5D6260575A5D5A5757555E5F
5857595C53615A565E5956535F575759585A60585D5E5F585A5E585A585F575D5A605F67
5C5D5D64616062675C6264645A63676560646360595F5F6A6361655C5D575B5C64545C5B
64695B5B595A5957
5D565D525E5E5C5B5A6464615C585957595B6062595A5B615A635B5D5E5A575C58575958
5B55615A5A5F615F5D5F5F625A5E545E5D575D58575E4D585F5860575958575D60615758
585958595F595D625E635B5B57595F615C5C5B5D5B585E555B605D5B615D56645E5A5C5C
5A5D5C62615E5A5F635B685E535B625D5D5D605960595F605E605F615A615A635A5D665D
676263626460615F62635B5D615D5763635F5D6561605F60635E616662625E6061676166
67615D6766665F6A666264615F625E625F6465626967626468636A6167636760655F5D65
5B6461655C69626361656466606063636A6462625E5F646265606466606961655F646566
65695E6163656064626565656063646A67616267625D626161665C6264656462615F6065
6361695F65636A69645E66645E606563686261675D625B5D6B5E635E685A605C5E605D5E
5E5E635F675E615E5F5D605D67635D6265645F5A65605C575B5C6165595B61595A635960
57635E5C5E5D5B616068686C656161585F5760585B4F5A55595E56585E596159585B5C5A
5F5A5D595F5F5E605F5C605E575D595E5A58595A5E5C5D5C5C5F5C5D5759614F58615962
5A5A5F58535E5558545B5F58605A595A5E575A5C56555C555C595D5F5C645D5A5B5B6264
5D655E585A62606261656364686466616662635E61645D5E6158585E57655858575E5D54
585A5957625A5C58
5C595D5B5D5B5F60585A63585F65575D5B5A5D5B605A605F555A5B5F6258615E5A5B5756
5B564F5C5A5A5D5B56545E5B595D5D55585D5B575C595850585B5C5F585F595758575C60
565C5D60625F5C60595D5C5C595D5E5E5B5D58645E585B555A5E5C5C5B605E5B5D5A5B5D
5B585D5E555860595A5E575C62665D5F62615A605D625A5B5D5B5D5B5C60656264626166
635E685F5E68575D645F5E5F5F5F5B5C64616362605F68626068635F6B61676160656964
5B63636A6B666664635C6069675866616560665D5D606562666463616B5F5D69625C6266
626E64685F64636261655F5E696560676466686363655F6E616A5F5D5C5C616864686562
636165625C656A64586A66636261696160676062636E6859696465686B666C645E5F625F
5F615C5F685F6A636064636C66615D6266646061615E67615D5B66656060636160626561
5B5D5D63675E5C636C5F5C64635E655C685B5B5B6261616262616158635F64625E615E5C
6363615E5E61585B635D6066665A61665A5C5E5E5A5B5E5B5C5456585C625E605B605D55
615854625D5362635E5D555C60555D5A5D545A585C5B62615B5E5B5C575A5B58605C5C5A
6161615D5C585B5B5B5E5858595D595856605D5E675E5D5C545656565C555C5E5C595A5F
5D655E5D65605B5C635A5F61695F636562635B625F5D5D5E5F6060615D5C62575A555B5D
5E59515C5C5A5959
5C615A5E565B5E5D6163615C59615C626065615F5A59595E5C5E5E5762555F57535B5658
5F5F5F5B58565D5E5C56575C5754605B585C5754595E5A5C595C59585D565B605E5A6060
6064595A615D5A585F605C5656566268595F595D5A575C5C5D5A5D5D5A5D55615E5D5C5F
585B5C5C5D625B5C615C66655F5F5C60646360635F67605A625B62665C5C5B5E615F6262
56615D5F616164646864635B645C5C625D6567655D605B6260615B5B5B62655D626E6B6D
615E5A615F6661676D626363605F60626A67666464676B63646661636361646465646165
63645C6061645D635C68636260696565636D69615D63656167605E636367645C62636462
68686961665F60665E6166665C61635F645D6068586965655C5E5D5F6267626564636265
63625F685B646D6365606067635E5C64655C6763606861635F625F5E5E5A5E5A60625F5C
5F605B62615D61665B63665D5F6259645F5C5F58605F625F5A605F625D625B5C5D63625B
5A5E5A58615B5F665D5E615E5C5E58595A665966645D5A595C5A5E5C615D5D655B575D58
5F5A55605A5A5D5C5B5C595E5A605E5D5A685E5A585B5E6064575C605A5658605D5B5E5D
5B5D5B5E5B5B575C595C535B565D58595D5A5C5A5B5E5756595B5C575C575A5F5B5C615C
605F6159625C635F656060665F6162645E625B59585C635C5B57605E5B665D675F5F5856
5E56595A595C555F
585B64625D5B595E615C5E5A5C5B62665D565E545C5D5C585857565A5C585A585759585A
575C595E595A555C615D5B5C555C55595B565C575D605A63595F585D6156535D5E5E5A5D
5C60585A685C62575D5F5B5A5A58585D595F5D59655D5A5F585E5E59575B5F575E545C62
625D625A5F5B615D5B595F6559605B615E5D5C56565F64645F5A55625F61675E5E615C62
5C5A6063626160565F635C65615D625D58665F645F6261625D656561615E5E6763656058
5E6668615F626165626069655F6D63656760676463676865625F63606167616462666562
5F606361655D596365646164645F60656B5B6361696465625F5B6465606468696567615C
65625D63625A5E6163616166636263635D6068616A6065605D656164665E6664605F635D
5F6365625C626163616365656B64646065645C6162605B665F5E5C5D5E64625F61585F5F
5C5F5A68585D5D615E5D5E635F5F625B615D61605F60585C575958546066595E595B6060
5F615C5C5B605B61625B5C5F5E5D5E5D5C5B6358595D5C5B5A5C5E5C5E595A5B65525B56
62645958635F565B58595B58585862605D545C55575B575F5A5B5557526262615B575261
5E5B5A59585056575A58595C535861535D5E5C61605A6058635D5F5F5F5C59615D5E6162
5F5D5E5D645B5E60625C5A5D62605F6762635E5A62566062645C6562625C5E5D5A5C6861
565E5A595F595C5A
604D575C6058615E5B625A5C5A54585B55605B5D5B635D5A5859585D595D5C5A55515C5A
5E565B5C565B5F5C5C5A5C5E57635F595C575A5E5B575E625C58585363505D636160625B
645D565D5F615C58555F565B5F5A5C575B595F585E585A58605F58615E5C5B5D5B5F6260
5F65585B6268575A64655E5B5E585A605B595F63615E6364615C5F5E5C595D5E625D5D5B
5C60665D645F60606159635D5462655F5D5E665F5E615E61626561645C635F5E5E5E695C
5A5F6164636165675E62605F5D626B5E665D615C60646761605E61605F6366646162625A
5E5F66656563665E6A6960626163616562655C68675B68666865646B5D64616C62616667
6068696462605E61616064605E675E655C675F68615B63686766635F6667615F5E5F6266
5E5E6261655E556562626E685C69605C69625B685F68645E5A5F605F5D626760605F5D66
5E5E5E60585E655E5F5960606163675F646761615D615F60605D635B6157605B5B5A615D
5A5D5D5661605D5C5F5D5D5F615F595D5959595B5A595B615B5E5D5A5A62585E575C5A52
575A5559585C57675754605167595D5D5D585B555B5C5B58565F615F61585B575D5C5F59
5E5B5B5F5C575B5C615F5C5B595D5B5B5A595E59545C615E5D5659565D5F5C4D5B575D5B
605D665F5F606162606157576661545E5E546066625C60615C63635D65615F5F5D5E5D5C
61585C585D585559
5B605E5B5D5E5E5E605F6066545E5F5D5C5D615A5B5A586061605E5F57596757585A5C59
5B4F5B615C5A5D5B5D5E5C595D59525A61595C605C5B5D5B5E5A575E5A5C5D5F5E585C5A
5C5B5F5C595D61595B575C51635959595C5654565A54595F5A5E5F5F66605860555D565F
60605D596063575C5B5A5D5B5A5B5D6662615E5D5D5D655D625664585F5E5E5F5A665E61
66615E63615D60635C6459645E5B5E5D63665B5D6460625C685C6462626168626A636362
675E5D62616B67686665646466655A605F615E61676764636A626164615F5F5D6160625E
63625D5F5D6B6762686563625E655F5E645D665F615E60606160675B69665F6262666460
60605A66635E635A5C5C696B61665A636561656C64656466645F5F5D625E5F5F5E5C615B
676665615E63635F5B5B5F6160666063635D6163645A64625F605C61616063616161605C
635F605E61665A565F5C5E5E5C595F5B5C60656063645D5A5F605F595E5A62615D646057
5E605B5C635F5D5F636054605D62515B5F625F5C5C5E575A5D555F54585C535E64625A63
5B5556605B60625C5962535F585D585F5E605B545A635E5F5759565E625F575D5C57525A
5A5A585A5C525A5D57615B5C58585A5E5A565A59595C5F5F58645E5D62575A5F5654585B
5C5C5D56655D5762605C5163625D5E5F5C5E65655D5E5E625E58655E565D64605B63565E
58595B5956595B5D
59615D5A555D615C625E5D5F605F5A5C5E61585D575C5B5D5C58595A5A5A625D59585C59
555B5D555E5958575F5E585A5E5C56585D566260605A5A57595C5A655D595B5956585960
5954565E556160625A5E5F5E5A61615859585B6059535C5F5B5E5E6158675E5D5F5C585A
5E62586060575F5B5E5A5D5A5E6560635E625C5C5B5A625A5B585D585C5F5B5E5B636162
5D5E5E595D5D6A65685D65575F5F625F5E5862605C5E60645E6162606362626A675F6459
63685F676362636064655F6469696568676B606067655B5E6B63675D6264636C67615F62
6861605D625A63615E655D63686260615F5F6866656260606662615F6260676263646060
67626C6C605F6462665D655B6066626764616969605E626363606062645C646A6464625F
5F61675E6567645F5E62616163695C586266645C5D5E5F645F6B60635E63605E605F5E64
60645C61605D5E60625D625E62635E69665F5C5C616367605C575E565C5C5F5A5D5C625E
5E5F5F5E5C58615E615F5965555C585C685B555F53525F5D5F57525D5A576058615B5959
5A5E5A5D5F5B5D635D5E5B575D5B56595F5B5F56525E5860625A595A585F5E5C5B595C5C
5B62535A535A5B5958595C58565F5D5E61585E565C5D5C595C58575A615A53615D5A675D
5658615C63605C5A61605B59565B5F6764625E6065575E5E535A60565E5D5A525B586060
5D665F59575D575C
605D5A5E5C5F5E5F615F5D5B615E635F605D59585761555854585D5C676259575C5B5C5C
5C575D5C6059575E575B5F5D585C6258595E595A5C5B5C5A565B5C5962575F5C605F5953
595D5F585B5E575F56605B5C5B54555C51605E5C5B5C5C5A595457605E556063605F5761
5D5F615E58615D61635C5F58605C5E5E655C5F635F6461616157605A5C60615C5C60575A
5E5A5C5B5D615E596460606261615F5E63625F615D605C5F635F625D555E62645C6B5E5C
585B5C5E5F64626461635E68615D636260665E61605F616566606866665F626263666191
68626A5F6262595F666065646461606463666065625E63685E656160655B5F6A66656069
5D6063646462665F5F6064655C5C5F626460626A6262675F625C615E5F5D666061606463
636164706069605E6364666166616062666162625A5F5E64625D665B5E5E5F5F645E5C60
625D596362635B5E5B5B5C625E5A5C615D5D5E616461645D58615F615C5B635B5B615F61
6162595A605F5E5F6059555C5857595C5D615D5C525C5D5C635A5A615E525C565C575D5A
5A565B575F5E575D5E5455675B59635A5C59615C605B5958595A5C585C5E5A5756615F59
575958575D5B5A5E5D5F5A525854545B60535A575A5D5B6057585B525B505D575E60635E
5A585F5A60585960625859635E5C635C5E5F63606259655C615D5D5E5B5B6561585C605E
6057596254585D60
5A595B5C5956625E6056565C675E625E615E5E585B5E645B59575E5F5B535A575458545D
5D5A5B61535D5E6558565C5F59555D615C5F64585A595B665C595F5C5E6061575B5E5956
5D615F525C5B5A5B5D5E5E575A5A585C625A5E5E5D5C5C5D645D575B615E5E605C5A5C57
5F5866655F5F5F5859655259575F64635F606261615D615D5B5E5C5E665F5D665B625D57
61625E60595F626362605F605E5B665E635E5D655B5960605D5C5F6466625B585E64645F
655D5F60645F635F655F645F625F685F5B65645E5E65646762605F6667616062655DFFD5
746361645964646C675B61605E5D5C63676060625A6662606166635F5E616563626B675E
675F606D665E64625E59636160615D62676661655F60625C5A67625E5C615F5F6762645C
626B5F6059666268615F646060635E5B655F615A655F5967565E605C575F5D615D606159
59665F6561595966635E5C6362645E5F6157565D5B5B615E605C615A555C5F58685A6258
575E5558585C5961655F5A5C5A645C60585C605D56615C625C5E5B585F615F5C5F5A5B59
595B615D585C55595B5E5F6052635C60575B5D585F5E5A5854575C5858545D555760565A
5F595C5A545756505C5C595A64625A61595A5D675E5558595857545D595C6060595E6362
5E5559595F60596561605D60585D6163615D5D5B5E5E5E5C5C6564605D625C5A5C635C5F
55585D5A585E5B58
6260555B605A645D606259565A575B60555F5E5B5D525856606063605C5C5D5B5E565F58
53575C5B5C5B5A5C546260595A5B62555A59555A5D5D585C595A5C61595C585B5B565B53
5F5E525E585D585A5C535F5B5D63605E6158645B585D635E5D5C5D5E575A515F5B595F58
5B5D5B5D615F5B5E55655D665E5C5A625E585B6357635C5A59645F5C5C5F5D5D63595A5E
5A5D5D65615A5F6562656658655A62615F5958575A5E635A665E605F605F6A636662605D
625B61655E5D6763615E5E7367646264615F625D675E655A625E656067615F605E646564
605C5E626561666560605C62605B5F69666667675B625D5A606562685D63625F66626664
60636163645A60606B5E605E5F6462616A645D606563635E675D5D5A5B645D676163615E
6763655F5E60605D6060645D5B6360636160676A5E5B5E635C5E655F5E5F5F655E5C6758
5D625C605F605B5A5D5F5C5B625E5E5862625E585C635B595F575C5C566360585F5B585E
63595F5F5F5B575D60585557605859585A5C5B555F5A615858585E5B5F5B535E55565D57
595C5D5C5B5A5D5E565E5C5A565E5C60645D5B5F5D56595E5E5C575F5B5A5B5D5856595A
5755565F4F535557585F565752595A5B5F5758605B5B59515D5B585F5C585551595C565D
5B5D5B5B6059655D5C585960625A6660645D606360605E655A5F5A615F5E5A625C595D5B
595F5858585A5A58
5E64575E5F56595D58575F585E67605F5C5B545C5C64565A5B5B5B615C5C5C545E5C5E60
5B5761575A575E54585562605C5658605D57615F60595C5A5E555F615B5B5C5758655A5C
615E5F5E5C595F5A55585D555E62565F575861605D5A5A5F5F5E5F615C585E58565F615D
5B565E565B605C5C5D5F5D54595A6264636059605C5D5E5E605A5B59525C5E5C63655B5F
695F5A5F6161646062636066605D645D5E5A5A5C5F5B615C64625D5E606261625F59665D
5A5F6D5F60616562655B58606A606360615B645E6064645E655F6360616564686568616C
69606360625F61685F62605E60625F5D616067625F5D64625B5F60615E61635C5F626063
615E63695B5F635B5E58626A625F646063675F5E63665C655E5E606461606063625E5B61
63615F5E5D64655F5B626064645D5C6168605D5F605B605E5A605E5D5D62635F68605A69
5F655A605F5D615E5D655D5A5C625B5D5D625C5D62625D5E58565D5A605C5864625C5B5E
5C625A61655D5B5F585D5C5C5A5E6059555C59565B615958605D5957565A595A565A5B58
5A62615B5C59635B645B595A5E5D566059585A59545F5B615A585B615C575B5E615D5A5A
5B55555756575B5B5C615D55625C55525A5C5E5B5E505D5C555F5D565F575E5F615E5B5D
575F595E5B5B595B6055555F5F615F5D5E6061635E5A595F575A6260615A5B60585F5062
585D595C58595D58
5958625960595B5C5B595B525F546B645B5E5A5E615A6059575E5C5F5A5D59605D5B615C
575758595B5C5A555E5F5E5E54575D5A635A5E575858595D605B5A5D5B5C5D555F5B595F
58595A585854575E5A5C635D545957585C595D5C5A5B555A635F585C5B5B5E5F535D6162
615D5D58645D5A615A56535A5A5D625A5A62605D5D5D565E5E5F595C61625D60665D5F5C
6057665A6062645C625E5C556A5F5F5F625D63635C6368635D5D6260615C6264675F5B65
63665C5D646D616461635F67626164655E61635E605C6261635F6B606A615E6163695F68
656A6764636462645F635D5A636164636465675D5A645D5E635F5F61605F676567646062
6166605F6565625D625E6462575B665C5C6966646369625F5E636268606267616660655F
5D5E64625D67605F5A5C655F605C665F635B6D626159606360635C615E64645E605D5C5B
56575B63595E6360625D5D5C5C61595A5B605D5D5E61675E5857615E5F6361605E596065
5E60555D565964575C54595C6053655D5A5C5B5E5F5E6156595A5C5E645957595D5C5C5B
5B5A5D5E575D5F5B5760595E565D5B6257625D60595A5C5857565D6155575C5D635B5956
5E5A5E585C58625B5A5E5D5D615F5B5857535B585765635B5B5963595B585C5C5C5B575E
5A5E635A5C5D545F5C625B5C605A5F605C60545E5F5D5E5D5A585A565B5B5C565758565D
60635B55565C565A
6258575D565F60605B525E5C585F5E5D5D5D5C595D5F5B57605A5A66596659565B5C5C59
5A595C605B5B5B595F5E5A5459585A5B555E625D585E5C5D5A5B60585957615B5D5B5F62
5B5C5B595D595A5F5F5D5E595D5C59545E5C5958586160525F5D645F615D61595A5C6454
61655F5459565E5A5D656359635C615A605A595F5D645D5A55605B5D5E5A5D5F5D655F5E
635A5A5A605A6060615C5D5F6362625F5F645F60605F575E6259635A636866665F626562
6558686762605E5D6466666169626367605D646460695F5B646262635E6B60695F67666B
64635E65645E605F645E6162616061605E615E58665C5F645E66625F666162665C61635A
5F585D5E5D625F615F5E615C625A625E61655C5E656564646465625F5F5F5F5A5B5F5B60
606A5E645C675E646264655F675F61655A62655F5E5A5F63655C615E5E5B615962655D5D
6260625D5C5D646059565F635C5D615B5B595B5B5E5D5E5E61595F6357585E5C53575762
5D5D665F545A5D56625C5A6056615A5E595B5D5A585C5D565A5A5E5C565762555B5A605D
5E5B5D5F5A605F585F5B5A5A585F5B555C5C565A5A5B5D5B585E55555A5C605C5A595859
5D54565A59615E5A5B62565E55585D59635A5B5E565C61575B61595C5D5E575852625957
5C5B56595F575C595C5B59665B5C5B5A5A5C625B5A5E60565C63605A6661585A5B576059
5A5F5F595359595C
5E5B56585D5B55575E5B5A5B566059595E595B5B5A5C545D595A605F5F5F5F5A565B5D57
5B5F59595F575B55565A5C5A545B6056615E56575F64605D55575D5C55615E5D5F595954
5B5A58605D5B5A53575C56615B5854575C5D575961635F5A585F5F5E5A5A5A62595B5F53
605B615F5D5C5C59595D5A5B585D595B5E5C595F5E5F575C605D545B5A5F605C67585B61
5E645A64605F5E645A5F6161625B60645C5C645B655B605B60665F5E636A625F59655B64
60615C626067665D6561625F606564605E64616668665E695D62615D6B6565635D627467
63656D656D60646360575F615C5F5F5E69685B5B605D5E60655D635E665E596963635D62
6563626060666066635E61625C655B665E5F6060615C6361646061666164635C5F605A63
64606A62665E5F6068635F5E6066656061605F5C665B5A5E5F5E5C6060615F635C5C5F65
665D5C5C5A5E6062565F5B5C5D5D5C5D5C5F5D5C625A5A585D5B6066605A5F595C5C575D
5B65615B575C5E5F5C5764565F5A5B5B54545A5D57545F5A5D58665B595452595C5B5460
5A585E58595B5B5F585D555C575E5E5C605D5C5B5D6054565C5B615E55605F6256595A5A
605C5B5E5C595E555D52575C5B5D546254625C5A56575859585B5C6156525C5C57555858
595E5659605E57575C57605E545F5E5D5F57595C5B605E5C61605F5C635B5A645E5C5D5B
5A5B4F5B5D585E5F
605A575E5B5E5B5F5A5D595C585B585D525D5C5C5A665F5A5E5C595C5A625E565C5F5755
555C5E5F5E5A625D58565C5C5D595A60595A5B5D605D5D5B5E5C605C5B5B5F565E5F5957
5D5D615D5E565B666555555E5962575A6061565D5D5A5E5A57585A5855575658565C5C61
5F5C635B5A5A57566361565C5A5E5E565F575D63555B5F5C645B585D5F5D5B5B605C5C61
5F565B5C63635961635E5A5D5F565C62616364605760695C61595D60575F6363605C625C
635E5E5D626460625C596562645A645B695E5A6566636760676068605F5E6364616A6764
64675C6461656560605E5E66605F5E5E6164655D625C635F60596264605D6566615C685E
61635D5D5F5F685C6562625D5D5E615C6063625D615C695E655A61616064595F655E6062
5E5D615B5B645E5C63655C68635E6564665C875F595A585E596063605D5A5F5F6168555E
5C65595F5F5E5F605D63635E605760625C5F5E625C61675C5A60625E555D615E5D585D59
5A5F5B54575A5B5F62595C5863576059575F565E5E575C5B55565F5A595A5F5D555F5B59
535E605A5C5D5A6158545D5C585B60545E5A595D51595C58585B50565A5E5A5C56595359
59555D58555B565C57595C5E5C565557575B5760565A5659515E5C595B5A625F56605C58
5C585B5955575A5A5F5A5F5D545C57535F5C63605D5F5A5C5E585A595D615C555E5E5B56
625E5F5A61575E5B
585F5C605F5A5D5D594F585D585C5B595E5B5D595C5B59555E635C5B59605C565F585B60
5D5B5C5E5B5C5A59595B59575F5D6160595B5E585A5959595B5D59615E5E595D5C585A5A
59555F5A595D585D595C59565E555D5C5A575A62605A5A5A62665A50545D585A535D5C58
61575E625F5D5D5359595D515F585D5C5F635D5D615F5A615F5E5C615E6061615B595B60
5D5B595F61645D60666963625F5662635D646261615A61636363645D65585E64606B6267
6664656564615C5E645F68615F6358686667616568626269645C61635E67635F62686365
5E5F6669665E5F605B605D625F5F616161645A5E615C6166665A65615F5E636066656260
606363625F5C6263645864615F68616A63625E615E6366605A675A60625C6164615E5F64
605D5F5D615861646061635C63565D60626C785F625E5B5B5E6460615E595B605D63625C
5D605E5B5B67595B5D5D605D5E5D64655C5E585F5B5D615F5E625C5C615B56565B615F65
595C595D5A6059585B60605E5E5A5D5E57605A615D565D5A5C5D5861645955564E565A5C
5B5B5D615C555D55596157615853555B5A5A5B5E605D5A5B5B57555A60595456595D5B57
5A505350585D595857575C535A55595B57575A575B5B635F5A5D575F5A64555A5E5D5B5C
5E6057545E5F606058635B645958595A6158555E5A58595E5B5B5F605762585C5C5A625E
625F595A5C555761
5B58595D595B595F61645C605B595958605E605B5B60655F605E645B665A5A5A5B60554E
55595C5C575F5C5D605C595F56605D5C59595F625552595E645D5E575E5959615E68605F
575D5C605E5F5D5B525D635F59625F575954625D5D5B5C5A565C58595C6258635E645B66
59575D57605F5B555A5D555A56585658605F5C5F5C5E645D5A5E5D625F5F6059625C5B5C
5F5E62605D5E685E60605E6462605C5E6264605E5D5F605F62605E64585F5E5E60636761
60606161626167665D5C635E5C5D6364616967615F6063606362666161575D5F62616260
6361695C64626263625F5E6463615D5860606761635A625E626763606169605E61616060
6264606961665B60635C6366615E5E67605C605F605D626061615F605B62635D6261605B
5F5E615C5B635C656662605F60635D615A62645B5C60635F62655D5D60605B6259595F5B
5F5E645D5662585E6063605D60625E5E5B60655C6360635F5D575B5F5C585B5D5A5F6053
5A625D5B5A595F57635F5D5E605B625A565D58575E5852565A5B565E6257555F5D5B515C
60595E575666655E545C5C585262585C585B5D5C5C565B525D58585E5B565355525D575B
545B5858555A595A5A575B57576053585D585453535B5A565C585A5F59585F5B59625559
605E5F5958575A5D5F585A605A5A555A5B5A636258655A5B5C5C625D5C5F605F5E5A5B5D
615E615B5D55585C
5C54595B595F5655585B60605A5C5F60555D615F5D5B635C636063605E595E5A5C505959
5E575F5F5D605F5D5B5C595A5C5D5B555D5F5B575F6060605D5B5B5F5B5E5F5C5E625857
5E595D5B59555B54605B58564D575D595D575C5A525662575F575858575C5A565A5E5B58
5F59596157575A5C5E5C5C5B5D59625C61615F5B5B5D5F5D60575E55586D5E5E5A605F64
6364605A5F656261605E62625E54636064615F55605F5D60605E5B5C5F64635E62616364
5D60645F61646760666363655D6162665D5F6160665D6662626666636067636264686663
5C65655E62625F5C5D625D5C5F61626255625F6860605D6062605F5E64635F5E6064625F
5D5E5F5D54645C5F5D605F62605C62645F60615E635D5B61615E596B6263645D615E6561
615E615662626361576660595E63685E62615D645B6257625E5E6464675F62665B5E5E5B
5F62635860655E5A6455655E5A5C5E5D65615A59656461595A535C5C5C5F5B59585D5C5D
565E5A565F5A5E576056625A5A5B555D575B60595E5E5A5060575D6156644D58585C5B5F
5E5B555159565D55605E5C5F5B54595E5A575D59575A5B58625759555052525C615E545A
59505C5559545A57545552585A5F5A5454585B5A5A575F5653555E515A565F585F585F5B
5A605F545F535C5B5A565E605A615C5A5F565958595B5D57616760575F5B58575C595C63
5D5C58535955575E
5B585D57565C5D5B5B5F5E5C5D58555B5F61585D5A6058605E646A645C5F5A5C645B5A58
615B53585C5A5C615E5B565D5C635A5E5D5B5A595D5F5F625C5B59565F5857555B5B5766
5C57565A5E5A525D5E61585C5A59585D5D57595D57595B5E5D515559585C605F575D5F5A
5C5D595A5E615E5C615E5E55575F5A5E5D5B5B595A5E5B5F5B625B616560605C625A5F64
5A5E5F645A5E5E57595C63645E5D59615F5B5A575C595D5E5C5F65616564645A5D66635D
675F5D656368606163656863665F615E5C5D5E656262655E5F61605D605C675F5B676561
5F636466665D62585B63616260675C64605F60626467635F5B5D5E655A59645F5F676061
5D6164646360605A61635F656560596362615F65605E635A605B6460626162625C61605F
60615E625A5D5C61615E636B645E5961666061615E5D605D605D56645F5F5A6559625F57
5E5B5B5E61625B5B65565B555D5F5C5E6055575F5D6164575F635B5C5C65615F5F5F5F5B
5A595C585F5A59595C635F605A575D575A5A5D5E61575A5D5C5B5C5F5A5D5A5657575D5D
5956595959595B5D5A5C575359585A5A59595D5E555B55616057615B555C5E5F5B5A5653
5C5D5D545E575B57585E5656575E57595C51575D5A5B5C5B595E5A5758565A5D5A575D5B
595C5757585A5A5A5F5C5C5C5C5F56635C5D58595656595B555F5E5D5E5E5B5F5C5F5B5D
585A5F5B605D6059
5555595B5A5958605F5F5A575C5C5D62585B5957555E5C645B60615F6265615C5660635C
5A5C5E595C615A56595E61595B5A5D605F605A5D585D5C585C5556545D595B5B5E5C5B66
5A545B5C595B5A595E5C5F59615B5A545C595658655D5F5C5C615F5C595C5860575C5454
595D5C5B5A5E5D555F5A595C5E605D57585B5F5E5A5F5F5E58565E5A5C5E5965565E5960
605C5A5B615E5C62635A6063605D665F606362635E60605F616462615D575961605D5E62
555F6467615E645B64645B6266636166646563615B6563645C5D636665626162636A695E
6D6465615567605B606163606264646460666165596466645E5F646764615E6260656868
646361665F6169635B6259605D63645F675F5F63675C6364615E5C5C5E61615E6765645D
625D6061665B5F5C636062596161566465605E62605E60565D596168615C5C605B63625E
5D615D60576163595A5E595B6259625C5E5A5862585E5D5F5B5E5B5F615E5D605D61605A
5E645A575E565A5F5E5D5D5F5B5D5C5A5E575E5759565A5A5B5F565F5E5D555D5F5C5758
5D595F5F5C5D5D5B625E61615E60575B565C595C5B5F595A5F5660595F5E59595A5A5853
5C5B5A545A5D4F5B595152595A5658564A585956565C595953645B565B575A5C5E5E5459
54535457605A5E575A5D5A5C5A575A545B5A57565959565C5B5E5A56565B545859595D60
5A5E595C5A5D545B
5B5B585E605F56655C645656605F595C5856615E5C5D625A5F695F6062595F5A5E585C5E
5D5A5C5C5D595E605A59555B5F5A5C5D595B5B5C5F5E5E5F5954585453595A5D5D5B5957
5F5B5B545C5C615A595C575E6257585858615554595A545B5E525C5F5D55595D55585E55
5C5A5C5A5C6066615C625B5A616A595D5C6059615F575F62665E5F545E5B5A5C62585960
605D5E605C60645F605F54615A615B605D605F615E5B5A605F6363605A5D595F675E5964
646865645C5F67685F625F685B6468626360646565605E625B5B6163645A605E6865665F
5E5E5D5E5F625A5C6A60636161675F5E67655A5E64645A645961665E60615F5C5E5F635F
615C5C5B5E5E57605F625E625C545D5D59636661665F675D5D635B5C616160655E626266
63615E60595E655C5C5D63636163606560645C5E635B5B5B5A5F6159575B5C665D565D60
645D686262625E5C5A5B615B5E5C59575961625F676759655C605C57576254595F5F635D
5E5C575B615F61585A62585C5C545C5D5F625B5F5A595B5A5C585B5857615B5C575D595B
5F5C5F5C535B595C565F5B5B5A5F5D5B5C5F5A5F58615C5C595B59635852575C59585253
585956565D5A605E535C595659575C58535C55575855565C5C5B56565E5A5A5C5E54585A
565B5F5D53555A585B615C59635B565C5C5C5B625D6155585C5959545D585E585D5B595E
5B536258535C4B5A
5F5F5B575A5B5D5E575F5C595D575E5D5C5B5759615D5B5D5B635D5E605A5E645F5D5760
5A5557586764575F5D5A60525B605D55585D5D595C5B5B5A59605A5F5A5B5D5B5C545C59
5D5A5A5A585A5E575A5A595C5A5D5A5C575E5257585A5D5A5C5F5A5C5E5B5B625D5E595B
5A5E605C5C535A5A5859615A57625D5A58605E5B5F615E605C5D585D5F595D58635F5F61
5A66615E5E635D615A605F5F625A645E61616361635D5E5D5E5F5B5C615D5F62635E6163
60655E625C646562625963595F6563605F5E5F5E5F6062655F5B63635D61615E605F635F
656160615F60625E5C635F5F595F605F5E6062625F5B63605C5E63655E665E656060655D
64625E625D5D645E6160606863675A645D5C5F5C625F6161675E615B635F5F5C5D5F6465
605E605E61605E5C645D5C645F625D5E5C605E5E57615B62605A585E625E5B6260565862
595B5E5F5F585C6462605D605B615B565E5E5A66625A5F575F615C5C5E5D666559575C5E
56545D585C5B5C58595E5F5D615C605C575D59575C60585D5C585A57575E5F5E5A585959
5763574F5D5E5C5A5B5D5860515D5F555F585C5A5E565F57595C52565B57545C55525F56
545C5F5658615656615C575458565A545859585E56535D575D515D5C595A58555A595757
5F575E5C565B5A60575A575661555D5D59575D595B625B5A525C585B545A585D59605D59
5E56605B655D5358
6158585E5E6660575F58595E5E645D5F59565E665D615F5F6E61605C5F5B5B5960585859
5E5A5F5D5C5B5A595A545B615F5B5B635B62615A5E60585F60596262565856555A5E5D55
585C5D5C62545D5E5C53545457635762595A5A5B525A58525F5B5F595B5D5E58595A575A
595C5B575959595F595F5C595A5C5F5E5E5A5B63605F635F5D5C645F6062625D635E5F5C
5C60606259615E585B5B69585D645B58635D625A5C655D666360665B6063605E62626061
5C6261635C5A5A5E625D66615F616669675D65625F5F616863685D5D626369605F5D5C66
64645861625C625D635E695E5C625E5E63645E67625C64625E5C63696663645863656363
61616061605D616066615A5E5D6062586157615D5E615F69665B5B665D5E5E605B695D60
655F64655D605F5F605D5C685E62675F5E605D6061605A695B635F5A62605A625C555B5B
58655C5B58565D5F5B615C5D555E636257565E5D5D5D5B5C5963625B605D5C5D625D5E5A
615A5D565D61575F5D5559605D5E605E5D5D5E655963615E605D5E585B5E5A5E585C595D
5A5A5C5A5B5B5F565E5D615B5C535A5B575B5A59575C5B60565C565D5C585958565C5A53
525A5D585B5655505D5C565D5B585253515B5A595756575B5A605B55575C555B55575458
5B5D575F5957565A5458555D5E545E5A555A5B5356595B5A5C55585E595D605B615D595B
5B5C5C5A5659545C
5E555C5A605A615F5E58576053585D5C5C5960605D615B6365636457585F5B5B5A5B5B5D
5C575D595A5B635B5A585B5A5E595F55565C5B5B62595D5C5A5E585D5D59575A5B585957
5C585E605E5A5C5A5858585C5B565E595C57585F595F56575859575D5755575E5C545F56
5B585C59576058575A575C625E5D605E68595B5B5D61635A5C565C605D645A5E65636559
5D5C615F685F5B635D565F63606061645D5C5C5A635F5B605F605C61645B5B5C60625C66
5C6361645F655E5D685965666062625E626361605C64645B5A5F60666064615F5E626460
645F66605F605F655E5B5F5C5F5D6360625D6467635F5F5B605E685E6C6464656664605F
655B5D635B6260625C595D5C5C6167646261605D5C5F635E5D646267615D6362635F675B
606461655B60625F5A625E63606161625C6268595E62585D605F665C5B635F675F5E5D62
5E615D615D5E5C5F595E5A5C57645C5D5B595E5F5E5A595F575B5C60605A5F5960645A5B
5B60625D5D5B5A61605D65585F5B665E5E61595F5D596258535A605D5B625E58635E5759
5C555F5A5F566053585E585E645A6159615D5F57575A555E575A52595B585D5356555A53
5550575C5F545D5B5D5D555D575A5356614F55605956565C59555453535A5A5A60575B56
5E5E575A5C555C5D5A57565E5E5A4D5B5A5D5D5E525B5B525A585660605C58595E5D5A57
5B59576058565659
5D5162565D5C585E565C505A67615F5D5D5B595B6160635A5C5E575A5B595F605C5A5B5D
595A6058645F5A59585F525B5A5A5B595F5B5D5C5D575B5F5D5C5E5C5E5B5554555B5E5C
5E5B5C5A635E5B53595E565D5D5D635E5B585C5C55545D5C5E5A5B585A5B5F6259625E5C
61595C6058585A5A5E5C596154655C5A615856605F6259615F585C615B60605B625C5965
5F5C6560595B60595D59565C6360605C5F5E5B605F61686064605C5F5F5F5E685D635D62
605F65626663675E62575D5E695E585F626762645B6061626464645F5E66635F5A5E6461
6C625D5E62665D655F616461636062616561645F58575E67605E59675E69636365585F64
625E675E5C5F665C665A615D5F61655E61626463675F5F5C605D635C63605F635E615F69
64615F606462616363646263615E5F615A5D5E605F675E5A605A5E5C585C585C605C5E59
5D635F55595B595E565E5D685A5C5E5664595A615F605B5C5C59585B5C60595A5E5C585E
5F5863605D5D5F5B615C5B62625E5F565E5F5B59605A585E60575860595B5A5D5C605757
5E585D5C5F615955595959615E5C5E5B5C595B595859575F565E5A5B585A5460535A5F5E
565A57545454575C505A59575B5B64595F5B58605558555C5A585D5B5C6253575B5B5B56
615C5A5D605D5B5C595A57575B5C595859555B585A5E5B5E5D5C57565E5958585E565D56
5C585D555459545A
5A59576061575D595C5D5C5D5D5B5B5D5A5B595E5E5C63635A65595A5E545A595C595A61
5B5C5A57535D5A5B57625A585D5D5F555C5B5B53555A55585A5A5B5D595E5C5A5D5B575A
595A5B555A6256595E5E595A5E5958505A57565D59585857645C586056605B635960595E
555B555E565A595B5B5E5C665F5E5F565E5C555C565C5F5E665A5D5A5D5C615D5F5F615E
5F585F58635F5F55625C5E5F5F5F5B5E595D65625F635F605A63655A645F5D5F5F616162
64665D5D5F675F5D645C5E5861605F646A675D5D6461615E5E6364606361636361635E61
6264615C5F655A605E5D6258615E605D5E6761606163655D67626162626A615F625D6460
635D645C5E595F615B5F556763665C5D5F64636661645E6059625F5F605B625E6462615D
61615C5F5E5B5D645E5D5A605E63675B5D5F5F5E5F5C5F5B605C615C5D5B645B57605D61
5961615B60595F615C595E625A5D6464595C565A5D5C5D635A60635C545B5E5C5C5C585C
615B58655B5D5B575C605A625B5F5B595E5C57525F5E575E605B5E5F555E605F5B615E5F
595C56585A5B5A5B59615B5F5B595358565C535C565962545D5B60595C59585957585D59
5A585A595553575A5657565F5B645E5A57565757585A52595C5C585E56555856565B565C
545E565651525A5A595C525A56585953525D615C56535858565C52555660595E51575954
595B575A5359585C
57535D5A57585A5F575C56615D5F5A5A68585F6257626658625D5D565E5C5B5660605F5B
585B5B5C5659585F5A55675F605A5D565957615E5D5F5B5E57635C5C5C5A5B5D555C5E58
5D5660535D5754595359586056575A5959585A5E6152585A5D5D5B575F5F5B57585C5E59
5C5B585B5B5F54545C55595A5E5D5F5F635B6059605B5D595F58615A61575D5D5C585F5F
5D615E5D62606058625A5E645D5E5D6053565D615F595A6166605863625A5F605A646258
5C5C64605C69695D586766636361605D5A5D5C616564615961615D5E636361615B626163
5A5B5D64685E65686166655C5E6263645C6563655E62605F6360605B64555D5D62596460
6461636463686055686A5F5E61626161695B5F69635F61655F6B5B5F655D5C5F60625A5F
6263645A5D615D5D5D68605F5C676461615E5F64655B625D6268595D605F5D575D5A595E
5A5C5E655B5D60525B555F5E5B5B5A5E5D585E5C54595E5F5D5D66565E5F5A5D615F615F
5C5B5C575C5C5B5D5D5D5C5A60605F5C615D5A5A615C645F615C5F5A5C5D59595A57605E
62595B595E5F5D5F615B575B605E5A5A57595752565659605A5B5559564E58625C54575F
5E5B5758595B55605D5A555A545A5A545F595D5C585754615A5C535A54575660525F5B50
5E565B595B565955595959575B5B5458545654595C5D5860576059585B5B525556555B59
595B5B5B5856585B
605E5A5A5A5D595B5F54555A60595A555C5B5A5C5A5B6256615D61565960606451585B5C
5C5E5C615857625F5A5956575A575A595A5B5858525A5B565C5E5B585C5B5A5C5A5A625A
605956565C55575A5B5B5C58565C5B51585E525C5B575B585D555F5A585959585D5F5A54
595B5455595B57595B5A5357595E5D585E5C585D585F5D5C605F5F5F5C57575C615B5A59
63605862655858605B5F595C5E575D675861595D62555A60635B615B636064695F615C5C
61645E62695C615C685C645D655D675C5D5D5D5F655C66625F5F5C5C616668625E62615C
635F616360666160615F64646561655A63615E635D5E5F5B5E605F576468626067635863
63645E6061615F5D59635F635C59656067636460615C63605B5B5D62665D5C6061615F60
5E62655F595D5D5F625F5C5F5F5A60605F5964635F62625B59625F5A585C605D58645F58
58585E57545D5A5B62625D5E585D595E5E565662656660605E5E57605D5C5A605A5F5B5F
5C5A5C5E5D5A5E5F5E5C5E5C5E615F5F5961575A5D5A516155615C5C5B5B5C5F5C585F58
5E655F5C565D5A5A5E585C655A595657565E5F5B595A5D5458585A575E5F5A5B5A595657
4F5860555357555B525957565C52575954595757575C5757545655585D5A5D5B565A605A
595A585365585564635157555462595559525C555F5A605156585D54555B5B5D595D5D55
525862535D57595A
58535C625C595A615A5D505A615A5D585E52585F5A57605859555956545B5D565B5F5A5D
605D5C58665E605C5E58565B575C5E5561595364595F585C5A5C5E58565C585C5C63565B
5E5C5F5D555C525A575B61595C5859575D60595B5C525C615B5A58575E52595F5E566269
5E5D5E5B5F585D5B5A5E5E605F605C5F605C5D5F605C5F5F5C5A5E5F5C61605B5D5D5B62
5F635C625C615F5E5E5C61635B625D64625B5A56585F616164676863606362665F635E5D
62625F67635A615E5C5E615D605E6761626360675D645C62625C655B6A6265595A606064
625A615E63556860646360676260595D64675E625E5B5F62566460646060635F60656061
645E5867625F616261635D656160625B646266595C5B6262656161626D5D645C62615D63
656064625B60605C5D65625D626059625F555D5C61605E635D565A5F5E6561615F625D64
605F615D575B645F605D5C5F56565F5C5E595F60665A5F61595E5D6059545C565B5B605D
5B5857625F59565F5F5A5D5D58595F5B5F5E575E58605D62585D595A5D5E585B5A5A6256
5F5F5D595A5F5A5C5B605D585C565759545D54575855575655555561585A5B5E58545C54
595E575B5850575A585C51575A51555A58565D5560575C585B5A525964625655545D5857
5E5C5B59615B5B5A525B595C5D585E535B5B5C4D575A54555C595A5C595857555756575D
5263565657545659
5D5B565653575D5E5A57575E5B5D5D5E5D5A565B59565E5A5763585A5E545A55565E5855
5F595F62625E5E575B56615E565F5E5860565D605B5D5D605A5D5C5E53566462545B605E
5A5E59625C56555959595F5A585D585D5E5C5D5B6158565A5A5958615F5959575A5B5E5D
5E575655585E585B5D575560615E615859585F63595C616262645D5A5864595A605B5F63
6260635958625D605B60605C595F605D61535B5B5C64686B57625E626060635C5B64625A
5F6563646459676060676464666767626465606062616560645E5C635F61615E61625B62
5D6261646160616564605A655B69615B625B6163675D615C6563585F625F5A5D60635D5D
645E605868615E5E5F605E635E625A5E5D6261645E5D62675B62635E6167626265596062
6061645C685A5C6361605B5D63645F575D62625F5C5E60605E625E5A5B5C595F5F60635B
5E645C5E5B5D5E59625A5B5F59555D595D585563606461575E625A605D58635E625D5A59
5758615C606259645E595A57585D5C55605A5B595B5C5E5D545E5D5F565B5E6057595F5B
605B665D5E60635A5C575F5E585A5A555C5D595D59575A5657575A615A5B55555A51555A
5252605B565B5D5A5A5956595D6158555653555A58575256595360555954585556595756
5C56615D58565A595C5B5C575455585457565553595C5D61586055585C565F5B61585956
5960595B5A55535B
5F5B5F5A595C5E5753585A5D5B5D5D64605D575A655957595A5A58605761525E57586160
5F5F5C5D605F575B5859555E5D60565858595A5D5D585C585F59615F555A5C5E5D56565B
5C5A60605E5B5A5B585B60585F5C5D5E5A5A60585C5E5E5B5C56575B5D5C5E5B605B5B58
5753605B5A5A5D545758625E565B5B605C5B61655D595E5F57645F5F5C626060655E5F5C
5D586064665F5A5A655C5B605B605E5760615A5D5D625A5B615C576160645F5C63676063
636564645E62606262635E666660655F615E645C605F606861686162585F5E606664655B
5E5E615F61625F635A65625F5D5F675C5C6360665E625D5F6060595C60645F5A5F635D62
5D5A5F605C60625E5C6266635E605C62645C645D5B5C625F5E5C5A60615B5E6363615F5A
6463615D5D5E555D5D665D5C6262595E5F555A5C5C5E655B5D5660655B5F5C5A615E5D5C
585D60585F615B5B5F5D5D5B5D5A605F635F635E5D64595A5A5B5D5C5F5A566060615B5F
59565661565D5C605B5B5A665A585C5858615B5C5A595A575B585F5B57555D5B6061605E
5D5F5A6262585C5F62545D5C5D565A5A5B63535A5C5A535D545A5D5C61595857505E5E56
56545C575A59554F59575A5E555D565756605A5C56575C4E56585F5E565D5A5853575F5E
525C5E62605A566157565456585E575B56595B575A615D5A5F5A595C59585A5954555A52
5C605C6050515658
5C5C5E5C665B545B5D5655625D5C595C5A58565F625A5C5A545C61605A5B5C565E585E5B
5D6153575A5F5D5B5E5C5B5C5F5D59585C555F5C5E5A595A5A55635B56595E595D625F59
53585C5061585B5A5960575C5B58505756575C6255585C545B5F555E5C5959635F545D5C
5C5A5C5E6060605D585459605056565F61655D625A625A5D626257605A5A636163665E5D
5A5C53635F625E5E605F58635862635A5E5D63635C5D5D5F6060626463676161635C6060
65625E636562605D665A616566665D5E6562656B6165665C61666463636363605E5A5C57
5F64645D62625F5F606360625E635A655E5E5D63655964645C5B5E5D5C65555F61655B59
5F61565F585F6266615C615A5A5D626666625C625E5D5E605A605F615D6260656463615C
62605E595B5C635C646162585F605D5D5C5D5B5A645D5E5D5B5A5C5F5D595F5E60675B5D
5C585F5E59635B62595A5B5A5E5B585D5C5C625F5C635E5D5B5A685F56595456645D585C
565C59595B58595C615F615F5F605D535C5E614F575D58605B5E59575B595957575B5A57
58585E5A5C595B5D5F615F6355595B5B5858535C5A565E585C5857565F5A5B5A60565B58
5F5E62565F5D535A59565158555D575C5B6553565F5B5B595A5C5A4F50575A595C565759
5E605E585E59565E585959565954535B535555525A5C5D55515A5B5E5A615B545863595A
5B505D54535E555C
5B5B585B585D5A635C5D5C5A595D5C6159585D575D5A54595E58565E6257595E545A5D5D
54585A6161605E605A59605B56605E5C5B596660545958605A594C5C5C5F5E595B585F60
57595A5A59615F5B5A575A595B5C5E5954565D585F5158575E5C5A555C5B585C5B5F595D
595B5A59555F5958605B625D5A555B605D59595A5E5D555E5C5D5A5A5C685D625A5C5D65
5A5E5D5F605A5F615F5F62646260665D5B56625A575F616263615F61655A646062605E5F
5D62626162605D5E6065605D63616561616A63635D645F5B626161645F665D5E66625E5E
615F635E62685E64645D5D5F64605C616665605D64665F655E6164655D5C5B62635E5F5B
626064656060615C5E60595F62625F5E635D655E645D5A5D635D5F5A605860615E626464
5E5B5F585B5C62596460676660605F5E5F645F5C605C6260675C555A5E5B565F5D62625B
5C5E5F5E6061595F576062595C5E5A575B6060565B5C585F62595A5D5C5A5D5B555B5D5A
6258605C5C60615C5760585F5E595C5D5F5858625F5B57565C5A5C5A585D5A57555E565B
575F6152564F555D61595E596361595A5D5F5A5F60594F5D64595356595F58605C575859
5C58585958575F4D4F58545853545962575A5E5C585659585A565959525A5B575E565B5C
595C51585D56525E5C5B5A55545658565A57565C545C5D5B5F5B595A56555862575D5C5E
5A595C5F5054535B
5C5C58565760575B5C595B575A5A5B54595863575958615F595E5A60595B60555D605360
575D5F63635B5F605F595A595A5E615D5B575B5E5D5F565B605F5859565857615C565561
565B5954535758595E5E5C5F5A56535A5E5B57565B5A605F6060545F595A5B5D595C5F58
605A5F615D5E586460655A5E6660595E6860555E63665F5E61585E6259585C615F5C5D5E
5D635D5E585D585C5F60595A5A5C61615A505B615F6361615E6360635E5C6062615B6264
5A63615B5F5D615A6260625B605F625F5F64636062626462636A685D636160655F675C62
675E60665D675C595A616659605F5D5E5C5D6258645F59605F615C5C61655D5D5F655B60
5E5E5B5F5D5C606163626069615D58615C625A616160625E5B5B5F5F5D5D5C5E5C5C5F5F
65605D5D5B5F625B605E565B5F5C5A615C5F5E615C615B545B60596367635B58535F615A
5C5F625F64605C5C60595F5F5B615C5A5F5B5E5D5D5A5B575F585658585854565E585557
5E51525C5D6163585F5A5B615958585D5D5B5A5360625B5C5D5C5E60565C61535E605A5B
5A595760545860585A5C5B52565E5A5C5A60575D5B5D565F5C524F5B58565D5D565D5A5B
5D54595A5C5D53595A605B5B63605558555B6359555751535957615C585A5A5B5E586159
5A565D505B5A59595E53586057535D555A5B5858625B555E525F5959585E535F5A565454
575B5157585C525D
5D5959545E645F545D635D59565C5D575A5C5C5E57625B5958565C57565F58565F61585B
5B585F605C605F5B5E5A63625C5E5D5F59585B5C58575A585A60535B57635B6A55625D50
615C586361565A565C5B58585B5F5E59575A57585660595E586157605864595C59595A5D
565758575B555F575E59575B5E5B635959595F5E5B5D5D5E5B625B5C605C615F575F5A5F
605E64605D5A645F5B615D64626160625860685C616164615C646162666A625B615C695C
5C615F5E595B6065675C60665F656062606566605E65626066645D686067626264645C6A
5C645F5B605F5D5F5E62665D65665F6463616061586563626562655C605F5F5C66585F5F
595D605B62645C605C646565605B615A625F5964605D655B58675B625D5B64636468585E
6061635C61646463645C5D60635A585F616160625D5C63605A5C5C585C595A5E5E5C5B5F
5C5F5F5C585E5D565A5F625D625E615B62575C5C5E5D595E5F5C616159575B5E565E5559
625A5E5A5D5F5E575F615B585C5D585A5C5C5C5C5A5C5F585B57555C6057585A5B5E5354
5A5965564F605C5B4F57515E5C5D5D596156575D575A555B5A5A5D5D58545A5F5959595A
575B56585357505759595A5D5651555A5B5D53555C57555B5B5959575D54585859525263
56575F5D5B5B585D5660555C5456585B5B5C5A5B5654565F585B5A58605E5A5D5855545E
5D5456585552535D
5A5852605C61615B5C585B565A5F5557585C5A5A5A5D5C625F5A5C5E615A5E5957555861
5E615E5F5A595D625E615D595D5458545B5A555D5E575D585F5C5D5E5B5D5E5B5B5C585B
5F5C5C5961566060565258595D4E5E595760595C5760615F63595861575F5757625D5B5D
5D5F59575D5E55605858605F5D59585D5D5A605E6061665F635E585F5D5E585F66625E5D
5B5D6258595D5F5E5B5F5F5C5B5F5E5F5A5A64585F6363625B645E605E635D645D605D60
5A5E5C625D5C62675E63696760666B6163655F5D60625D605E625F625E615D5B685B5F61
63606364626668615B645F615C5B5C5B5D656257645B5E65595D5E5B5F66625B5D5E5E5F
605B6062605C6C63605E5C5D62575F5F5E5F5D5C5D646759635F655E625A60595F606358
65615A5C5B625C5B585963595D5C60615D6360565E5A5F59625E5E625D5D5E5B5F5A6059
555E5C5B5F5C63585C5F565C5960555F605B5E5D5C58555A5E5A59565F575C5B5E585A5D
5E5E6356606457595E5F5C5D5C5665585F5A5C5D5A5755605A5759645E53526058605A52
5C57575657575A5E605D5D56575C5D5B5C555B635659515D5D575F58525659585C5A5C5A
5D595A5C55585D56595754525859555950585A53565A5A59625C595C5958566250565555
53565E5C5B5F54585C5956595958515056575858565D57585C57626559615E5C5957555E
5B5B595C525B5C60
5A5957595957565A56595E625A615A56555F5A56605A596156595E625F5D625C5D5A5960
5D5D605F5E615D585B59615D5B5E585C5D5B5F5C5D63585C595C5A605E5C52595C5D6054
605B59555E57575E5F635C5E635B545756595D575C5A5E5E5A5E585A5E5A5B5957575D59
5A57585E5B5B555D5F5D605C5F5B5F5F605E5A5D5B6356555A5A5E645B5F5A645B645F5A
5C595E6258626161635B5F5D6165605A625F5A5D61595E60606759646166615C63606160
61605F60655B58625D5D5C5D6660635C6561616464615E5F6363605E6063615A605D6162
5958625B5D625F5B675E61635F5B655A635A6060615F6362685F5F5C5D655762645D645C
61595F605E6162605F68625F6564635F606161596359615B61605C645F5F5B6067625D5D
5F5B5859625C5E645C625C625862645F60615F5B6252605E5F5E5C6565605F5B615D595E
595D5E5B5C5A58605B5B5F5A595C6058545D57565C61585B63605A5D58605B565C555D54
5C5B5A61625B615A5A595C5E64565B5B5C5C605A5E5A55595E5F5A5D595A5B58575A6259
555E545D5B555E5757585B575C5B58575452525953575C575659555B5858565856595556
5A55545F57575A57515B5B54585859595F58585B555A5A535F5753555C5A51555D615B57
60575E545B5955565A545553575756595C5A585855595B5C5D5A5A605963605B5E575B59
58535D5C5757525B
5F5D5A51545F61585E6054605B585F5D5652545C59595757585D54605B5B5F5E60605C5B
625C605C5A656768585D5D635A5C5A585162535B5856515959616063625F5B59585F5A5E
525D525D605958575B58635D5C5A545E5D5B55625E5B5C5C5F5858625C5B5A5862545E5B
566152605B56545E595D5A5B566059595B58605D5C5C5D615D5E635F625C5E6160555E59
59635C5C605E63585B625E5E645C595E59625E5C5D5F645D5E605B5A5D5A615D5F65625D
63625C5F63665961605965656363606364615E6A6262605D61645B5D5E62646858656058
5C60656361615E5660645C63606162695D575C5E5B61685C5D6166685F5E655C5D5A5E6B
635D5F5E6265645C5E625C60645E5F625C6060605F595763656766605B5E65635961645F
5F545F5F5A5C615D5F656459615E5D57586158575C5D5C595A5754645D5D6259625A5A57
615C595957565C5F5A605B546159616659565C5A585E60625D5E60595A5A5F5D5D5C5D5B
61605B5F5B5F5B545D5B57575E5F5B5D595E55575C59554D525C5B5C575B5B5B595B5D5B
566361555C5B5E5B545F555B59565C575B5E56575B565F535759585350565A5555545956
5853545E55535754555C5A58545954555D625A5457595955525958555A5B5E5860595855
585A5D5158615B5A5A575D56555A5E575E5D5956555E5559565D59586159565A56565257
565453595D5A515B
5E5A625957525E5D56595A655663595D5E5B5E5B5C5B595E545961595960575E575B5F59
5D615D63576964675E5C58585F59605D63585C5A5757555F575A615C585E5558625D5F5B
56605B5A5D5F62585B5957565C5C5758595B575D585D5A575F5D59585D5C5B5C55585E5C
5E5B565B5E63585D5C5C5D5D5659565C615967625C5161645D5C605F65646058625B5E5E
5E5E5A5D5E5C565D605B685D625459595B5C61655D61595C6064605D61645D5E66616262
5F5F66605A5F5F5A5C635D61635F606161625A62645F5E55656161625D5E615D5E5D6162
5D6163625D5B606466665D5C585B5B5A635E6268605C645E5F62606062636264645F605E
62585F60645F61635A5D5C6664625E5E5C5E5B625B5E64615D60645A615C5C57615F625D
5B5B5D5E60595C625A625F585D5C5C655B5B5C6062645E62505A64615C5A5D635F5A5858
56655B595F5D64575A5F605B5E5B605C58595956645B575F5B5B64585F5A5A615B605859
635551575C5E5763595D5F5B5D585B5D5C5C585D57585954555A595D595D5D535A59625A
5A56615858575A595D54605C5C5C5B535D545A54585955595F555C5A5B5A565854596157
5A5858565A56525A57585C5A51535955555956575B61545D585556545A565A57595E5A57
5C585D555D6058544E5B5A545C5B5E5F555B5854515358575860635B5D5C595C5B575C55
545A5B5460565754
5D56595E58585C605C565A5D57585E605F5B585659535A5764605D615E595C5F615E5F5A
5861636066615D655D605960605457595E5D5C5362565A5E5A5D575B5D5E605861645B62
605F5B585C595E555E5A595A5F565852615C57585D5A5A58665F5E5D665957615A5C5C59
5A5C57605D5E5D5E5A63585F5F5B54625C5F535E5F53635F5E645D5F5A585D6063626261
615D5F575E625C5F635E5D5E5966605B5C615F64575F5A5D645E5E595D655F5664626366
605D635F62675F645C5D686762605D615D6265625C655C675D5D675D5F575F6062606665
615A5F65625B6761665E5F615B5E5E566166555F605E59565A5E6265656363555C595B5B
5C5F5F6160655B606362615B576065665C606164655D605C645C685A5C5B5957605A6263
595A5A655C5D605B5A5A5C5D5A5863595F565F5A60605F5960595E585B61605E56585959
5C5B6257535C5F645B5F625C5E5E676A5F5A605F5A5D5A635D5B5A5A5F615E5F5A5C5E5B
615C5E5E585F6263595857605C585D625E59585D5959595A625B5F595E5E515359575D5C
58605D5F615D5957585D585D5D565B5A5B585A5A59575955615557575A5B585B5A605A5B
5356565E5F5457565D5C5A5556555558585B5A5A585D565E50575A555A5A515257525257
5B5D5757575557555A575A57525E58555A5856555B555D595A595B575C5E565E605F5A59
52585D5C5D59565B
6057555A5C615F575A595C5A585E5C615D5B5A5A5C5A5F5F595D6159605D5D5B57585E61
5D596364696267695E60595C615C5E5A5D5D5961555D5E555D605D595F59555E61645A61
5C62575A5C5959585D5E525D595D5D595A5E5A5A5F58595A555B56596162585D5D585E58
625C5B5A625B5B5D5D6158605E605D5F5D5D605855675E5E575F595B615D585E5F5E6168
5E585C5B5A5C6060615B63605B5E5860565D595C60635D5F5E5A64555E665C5D5C605A63
5F615F635E63645F5E5F5D6466645F605D635C6B646263676561625D5E665F5F5A5C665A
635F5E656267615F5F5C5C5E606A5B5B5D585F6560645558615D5F67605E5F5B635D5B65
61645B5D545C5A5C5C61625A5C5C665F5D656363635E625B605C5B6458635B5E5D666359
605B585F5B5F585F5B5A5F645C5E5C61605D5C645A5760645C5C60585B5C5F5C5A5F5B5E
645E5B5C635D6164655D605964616F6962625F605B575C5D6059565B595C5F605E545D5A
5D5D67625E58585F645D5B5F5C5B5D5D5F5A5B5B5E5164575F5D56535D5C565B58585462
5A5C5558595D60605B5956575A595B5B5C5E58565A5C5D59565A56575D555B515955595A
5759565D5A56565F58505553615A53575157585A5B5D5A5E59615E55575A5A53575B5D5F
5A575557555A535D57605B5A5E555F596057565D5D575D5856605A58605C58605859595C
5D5457585E56575A
5E5B575C5E59625B5E5D575D5C615A565C5D5A595C5A5F585B5A5A615E615E5B5D5F5B5F
605D5F5F646364645F54595F595A5E5D5C5E58605F5B5B5B595C5B625D5B595E5B5D5860
5A5B5A6462605C605A5B605E595A5C50545B585A5B5F5D5758565E635C565B5B58586359
5B5C5957615D63545B56635C5F615E5E655E5F5D6161655C5E5C5758575958585F585460
5F5F5E655B655B5C596465605E685556625C575E575F645C5E5E685F63625B5F5E64655C
625C5F5E5B62635C605766625E6264666A615E61675E635B5D615F5F605C5A5E5F635864
625C5E615C665A5C5B5D5D585E635A665B5D665E5E5D60605E615C5C6166655E62645D64
5D605A5D5E625C625F68605C5E60605C5D5E635C5D655F5D665E5C60606157635F5D5F5F
5C5E5D5556605D5F5B635C5B5B5B635C625B625859605F5A5A5F596869595A5B5B59605B
555E5C5A635E5B5B5C665C5B5B5A6462575F5F5E5E645F5B58595E5C5B575E5E5C5F5B5E
646764655D5A5F5A595B63615F5B615A5E5E5F55585B575B5A5F59605E5A57635E595B5F
575A6059545E5E635C5A5A5E5D5C5E535D57595A5B5E57575B5B5D5A56565B5555605856
5E5859595B57515B505757535D555B58585A535A515B5A58595D595E56555B535E59545B
5D675356575E58555558585551575D605B5B5E57585B5A565858585D565E585D565D575D
5A5A58585F524E5E
5C59585853615F585E5B5B5E585C625B5C595D5D5C555B5F605C5F5F5C64625E5C635A5C
5B5E6563616166615B5F58625C5B58615B5D5B5A565B5F595E61646060605C635B5C5754
5C595F605B576054665C5D5A5A5F585F5A59585B58575C5D5B5661605D605B5A5956575E
61595C5E615A5C5A5B5C5C5D605A5E5E615F6057635D5D61585D5F615A635B5D585C5C57
615E5B5C5E605E6161625B605B60615A61595C61595E5B64616060635E58585D645E6761
5E60625F6860605C5C5A6462625E5F6265585B6961625B606D63625F645C60635B5D5C62
56635E5C64646360605E685C605D5D625B61655F5C5E65615F5B5A635C6162625C5A665B
615F635F5E6162695E5E61595B5C6460615A63616063636A5F5B6364615F5D5B575D5B5D
655D5D5C60575F5E5A5D5C5F5B5C5A5E5B605857615D665F5D645D5F595C5F615B5C615C
5D5C635D63605B5A5E5C5B6265635F58615C5D605E5B5F635C566063525D5662615C6168
6D8F6F6662605D5E605B5F615F5C5F565B595A5A5C59565C5F5D5E5D56645960565B5E58
5B5A595A565D5B5F5E575B57605C565F5660615D5B5254615C5861545D56595C52535657
57595B535C59535454545557565D5756565A585E5A595C5E56565656565D5C5F5A5E5857
575B535B59585C5C535F595C595C5B5C58575558575E585A605C5C5B575359615E605E52
5B54545357575255
5D5A595C575B555E62555B535B5D565A5A605D5E5D625A5C595F6259585D6060655C615E
615C5F5A64615D5D635F5E5C595B5D566254615A565A595960555B595D57585C5C5A5E5F
5C5860615A5F58625A57585E595B5B5F5D585D63585B5E595D5B5E605D5E5D5C5B5C5D5A
5B60595B55595D635A5F60655A5F5C605B66625F585C635D5D636061535B5B5A5F595A5B
60595C5D5D605D5C63615D5F5E5B5E606162615F5E60615F5F605F5F5F655B6162605B5E
65605F636264645A615F64606463635F61616A615F635C6261655D605A5A65665F605F5F
595B5E585B625E5F5B65595C615A595C61605F5A5F665E5E5E5F6361635B67625F5D585C
5D6259625D606360605E5C5F615F5A5E5F5B62595F585A605C66645D625860605F555C62
5A5A645D5B5F5F5660585D59595C5F595F5D5A535F57585A595E575A5F5F5C5D5F5C5C60
5F595C5E5B5860626362585B605D565E6166585E605856605F5F5D5A5E56545B656066CA
FFFFFF73586657545A5E5F5D5A625A615952575E565B57575D595A575E5F5B5C57566D5D
5A575A585C5C5958595C5B5C5C5D585A595D5659605B60565956574F58525D5D5656575D
555C595B5F5B5753585C5E5C5B575655565659575A60505853535759545455555557595E
5957525854595657575E5B54555A595A5F5E57595F5A5D565754555957555F5C5553595A
5D5B56555B59525E
5A59585C535B63575C5F625A5C58675C5C5B5C585D575D575F5E5B5E63555E5B60605D5D
5E5E5E5E675A5B60575C58606457535B605D645E5B5C585E595E5E5B595559665A5C5B5B
58575B5A655B5D545E5E545E5A505B5A57575F5E565F635C5F60595B61625E5E655D575D
5F605E5E62605E595A5A5B645F5C655F625B5E5A5E5C5B5F5B646055585A5D64585E6157
5E5B636A655C5C5B5D5F585D635D636056605B5B575B5F635F5E5E5A5F625B5F5C5C5F59
605E5B615C5F62615F6460625F5D635A60646860635F59625D5F5F6264626160615F695F
5E605762635B655D5C5F64655D5D596A5E585D5F5C595E625F5D5E625A61605E60646164
5E5F6264685E616467655D5D59565E64605C60615A575D5F625E565F5C645C5F5F5D5B5B
5E5A61585F625B54615C5D575C665A61585A575B5E60605B6056625C565661575A61595F
655E646661615C625D5B635D5B60615E5E5C605F61575D6065595C585A5D5A5D6157578F
FFFFFF872B5E5D5D5E5B5954515D5E57565C5B565D56605C5D565A5A5354575858545755
5857595A575E575A5F575B5E5658635B615C5E585A5A5659575959585557555A585A5A54
5A555A5A5E505A59585E555B5952585D585F575B595A525A54555953535C545C57585457
585C5A5A5D57525B575956575D5954585C595A5C5A5F5B675C5A5D5E5D605F5D5554575C
515A5B58585B605C
5D5E565F565B5E575C5D5E5D615B5F565B64615E5B60665C625D61595B655C6462625B5C
64585C5C6262645A5A585D5A645D5B5E585E5F5B5D59565F5D62555B5B595A5D5B5D5F5D
595E5C5F5F61535C5E5F58645A515F55595351575E5C5C61615E5D5A5B5B5D6363585A59
58575D5C59605D5C5B5D615E5C56655A58645D605F865C5A615D575C5A665F5D615F595B
64645D5E615E5A565D5F58635E615D5D5D5B635B5A5E63625D5B615C615C646062605861
5C6460565A6263636767646461635F656358635A6063665A5D6161605D5E5C625C615A63
6062635A5C605C606A5A605C5C625B5F5A5D6459655F5F5F605F5D5961605A5C625A605E
5E65615C5B635F5E64556360585F5C5E5D6153655A6166605E5C575E59615D5C5C61615E
565B59595D5F625F5A625C5A5D5F646155645B5F5E5D5E5E585F5D5C5F5F5A5F615B5F5C
6564635D5D5F605A5D606464675462585D5C5F5E5D595D5D5F5C595E5A585F575E5A6057
000000000E565756585C60575D53585D5A60625B5C57575A59575B565B58575B5F5F5B5A
5B5E585857545A595A5E595F575E57545A5F575D54545A5C5A56585D5D565754585F5F50
595657575853585A58585A555C505653595C58565552565A596157585A54575C585F5050
54575B555C585954595D5F5B565B5959595A5C5D5C5C59565C5B5D585D545D635F61595E
595D545F5A585D58
5D5C5D56645C5D665F595B5B615A625C5A585A5B555A5A5B575F625A605D67645E606162
5D60605F5F5F5E5F595A605B5F5E5A5B5C63605A605F58605E5C5C5A5957575A5E585E5B
5C565C6157595A5F5F5B5C515D575D5B5E5C515C625B4D565D635F6466575B64585B635F
5960575A5F5F62595B5C5A68595B58655C575E5B5F76635B5E5E5C615C66625F625A5960
5D5D615E5F61585E59605B61635A5D635E5F60695E5B59625B5D62625D5E5E60615D6362
635F5E5E5F5766635F63615E5C6967625F5E66646162625B5F645C6161615D685A5D5B62
616160615F5F5D5A5960615D66605C64616062615E635F595F5B615761605F6062636265
5A615E5F5E67625F61685E6C5E645B605B5C58625F6162605A61575D555E5B63615E655D
675F64585F5C5E606058595C59615D5D5F5A585461615D64585C5B5C5D5E605363666763
5D5C645B5E5C595B5F5A5B5D61645A5E615B625D5B5B5F5F5A5E5E5A5E5D59605F5F5958
18000000545D54565A6157595B555D5E5B585E59575957505A5A5D5858565E565D535B5A
5453595C5856515655585A5455595B53565B575B5A5B595D5D5E5A5A5A56595A5A515956
5C53565A575A595A5651595D545956576058515755525B5256605D4F565759525A51555C
545C615F5759565A5857585A585E68545C5E61585E5A5A5A545C5B61565854595A595657
5B545B5A585F5757
615A585B5A5B635C5A5D625A585D575E5759585B5B5C576263605F5C5D635E5E5B5D5963
635B5F5F5F57585F5E57555759575C5A625B5B57555C615B5E62625B605E5D5F5961635F
5C59635B5961595759585C5D535B52575D5F57585A6155575C5B5A5E5F5A55615E555662
5C5E615B605A5B5A63595C5D65585C605D5A545B61585E5A5C615E6463605D5F64605D5E
5C595C685A5F585F5F615F615E5C5E62605F5C5E5C60595A61615D625F5E5F5B625B5E65
60645E5C6260615F615A5B5C5E5B696261665D59615B616565625E625C5D655E5A5F5960
60675E615E615E5963645D5F6065595C59615D605D6562605F5D585E5D5E656062605E5B
5F5C5F5C615E5D62625A5F5D65605E585C585F605F5F5B5B605B605E5D595A605E57595B
606168605C5E5D605E5A5C595B625A5D5B5C5A645C5A605F5C5C5D5E655F565C5E5C5E59
5E5D5D595B5E625E5D646064595C5D595D6062695E595F5D58625E5D5E5E5A5D5D595E60
58426053545C5B60585C5D5B5A5961585C575A585C61515F595B5B60585B5B555B5F565B
5A565D5A63585D5E51605C5B5A605A615F585A59575B5A585758585A5C5B55575A5A5355
565D58525253595C50575C5757535456555C57555857595C60535B595558515455595459
545E535654585D54565B5D5E585C58616554575A5D5A5F605D585D5756545A575C575A5E
625C5B55525A5559
5F575B5D5C5A665958585C62645A635A5B565D58625D595E5E61645E5C5C5F635D645B5F
5E5A5D58605E5B605C57585859635C595857625C60585A5C5D595E5F605C5C5B585C5D5E
5B5B5E615C5B5E5A565A5E59615B5B6163565B595D5F5F5B615D575C5C615761595C555C
5D5C555A5C5F6261615A665F605B5A575C615F5E605F585A565D575D5B6A5F6360655C5F
6164675860605D5E5C62605863616661625F5F616257605D625F5B5E5C6E69605A5D625D
64635E62635E5E5D5F5D636463605F605C656159595C605E5F645D5E606063605F5F5F65
65655B60605A5F5B60635F5D605A69675863625E605C60615C605C62565C66595D62565B
5E6A595D5E64625E6062605E6163605D5A635C606066605E5B5C5E58605E545B6162605B
60575E5E5D5C6165575E605B5F5A5A5C5B5D5A575E625F5E5E5E64595C5E5F575B696365
66605A5E5E5C66625F5E625762635E5D5F635C61605A5C5B625C5963615A5E5E5F585C5F
645E5A5B57585759635F5A5F5C61565A535D5C5E5D595E5962555B56586061585E5B5B5E
55545763595D605C4F5D5852645D59595955575F59595C565D5C5D595B5B5854585E5754
5A59585A585B59565C59525C575A585956535A55595359595959585A51545B5256564F59
59565B58595D5A5A575C5D60585B5D5A5B5B645F565B5D565D5C5B595C5A5F585C5F5C53
5758595A5658585B
5A5D585B5C605A5C5A5B5E615C5D5E5D5B625A5851615E60615B57635C5B5B66605C555E
5A5F5A5B5E615A555D555D5B5D616159605F5D5560555A5E555C5D5F5F59595C59545855
5863615C5E585D5A5D5F5F5E5C5C5C566160575A555C5D585C595E5C565F58605E575F59
575F5F605F585F645E56575A5F5B5E5E5D5D665D5D54635A5E5B5C576262645A5E5C615A
605D5F5D59655E5B56615A5A625A56635A5B6163625F5A6061595C645B625E645E61625C
675D605D625D5A5D5F5C625D5E5C5C5B656463615F61595C606662575E60565B5962625D
5D615C5C695D5F626560625E5F5A5858605F615F5B5E5E5E576461635C64606662606366
615C64616765606262615D6459625F5E5D5F595D52596364616053645E6160526062605B
605E56605D635A5E5B5A59545A58585B5D595F5A595E5C5F5A605E5B5B5F605F62616166
6568585B5E585E625E5D61565F5A5B5C625E5E615F5B6363685957575C5B5E5B5E5D5A5C
5C5A5F64555B5E5A57605B525B545E5E5A5A5A65575C5B55565A555B5A5E5855595A5755
5F57575D5D5C5C5C5B605C5C555A575856535C595B5C5B5C545959545356575D5A575C57
4F5B595856575356595659585A545F534E535A5B544F59555F575A58505D575B565A5958
58585756585C545B595456585D6259685A5B5A525D5F5E5F595E595D5C5A555A565A5753
575E5A57515B545A
5C595D5C605C5B5C5A585C595C625A6057585C5A5E645F625D605F5E5B585E575C5B5E5F
5F625E605C5659615C615C5D5C635F61615E5E6060625C595F5B5A5E58655F5B585F5861
625B545C5A5E5E5D5D5B595C57575D595D57585E6163655F5D62615A5F5C5C595B62615D
585B5B5D645F59645D5B5D5B5B63645A5D5E585C5F615E615C585C5C61555E5D595E6364
5A63595E59625C5F5A585962605F60615F5E5C5B635D66585B58605F625F605F5E5E5659
61605E6359615F5B5F605E6161595A626261545C64655F645D5C63606060615C5E665E5A
6061625C5C5B5D6760626062635E5E5A5E615B626557605B5A5E60625D60606261625D5B
5F646161615E615E5F5D5C605E63625C606066585E59635D5C625E5D59605A5E5E605B5D
5F5A5A5E5D605C5B625E5C665E59595C595D5E5B625A5A59595A5360605E5B5D5B5E5E64
6466615D5A605A565B5F675660605B5E60625D635F645C655F62625D595F5C585B545F58
60585A5F5A595D5F5D5B5B5D575B605A5A605B58605D5A575C545C605F5C5B5F57585458
57585C56545756595B5954615C5D5A5A5B5D585B5C57525A50585E5A575E595A55595C5C
565A57595A525154605A5459565C535F56555656515B5A585752585C5A5A525460565655
5D515F56555456585B5E5961595F68665B5C595B5A5C6159595C5962605B5D5E535A5C5D
4F5558595B505A5D
5E5D5D5F6055615F59595F59635A635D5B5B5C615F5A605E555C5F5C5E60585A5F5D5F64
5C605A605E59615C5F59595B5C59615F60605F5D5D5F655F5C595C585F5E605D5E5B5858
5F5C5A555C5E5A565E5F5C605C5D595D505C5E5F5D54575B5A5D5E5E62575D585B5D605D
625D5E5E605E6759615A5F5A5B645F5B555C5F615D5D605D5E5F5D62585B635E5E646362
64625560606C61645D5C5E5C5D5E5C646363565F5D6161605B5A606160645E6862605F65
5B5C62635C5E675D5E64655D5D605F62625D65605F635D68606360615B605E61685C6365
5E5E5E5E5F5F5958645B645F60635B605B5F5E5E555B5B5C62626562595E63605F626059
60605B5D615B65605D5E605A5E59585F6266635F5D5C5C5D60595D626C5D5C6062585D5F
555D5660675E5D59575E5D5F655F5F5E5E5B595E5E575D605763635E5F606561645E6064
61635C5F5D595E64645B5B5A595F585F585F5F605E575F655E60635860555A5D585E5F5E
5D5D58595D605C605C5B5D5B5E59615B5F585C5762595E5958515C5659565758595D5D5D
57535A5E5E59525A5C5D575B64575055595B5B575E5A56605755595A5458555D5D585452
595359595B5859545853535556595B535655525E58535A595C56514E60565851545A534E
5A6160595C565E5D614E5951555B5960635D5F585A59595E5E605756575A5E5F62545559
595E5B5A5B54525B
586558565B5C625E5E5F605C55635B6361695A5C5B596257595C5F5A54565F55615F6361
62635E5B5A6362625D5E575F5D575B63655F605B5F5E5B5D5F5C5C575D5E625D5A5C645B
5C5E5E5F5B625E5C5C5B5D5F5B565A5A5D63595664605C615960625C5C5F5B645A60645C
5A595C5E685F5F615A565D635B5F595F5A57625D5E616056615D5C5D5A5D57595E5F615D
5D5D605C5962625D60595A585C5E6A5E5F5C58636561616066645E5C5F635F5D61565356
605F62635B6762615A63606B65615D5F626368696167625E5D5C5F615B61615B585E5F61
595C625B5F5F58616D645F645B59636059575B585D58565D5D5C5D625F5E5C5C6363605E
605B5A61635B605D5C5C5D5F61625D615E5C5A625E625C5E5B5A5A5C5B635C5F62605F5C
635D5E5F5C5D5C60615B5E5B5A5F575D6062595C5C5F61625D5A5A595A6355595A5C5C58
54605A5A5F5F60655E5B5E655A625C5F616061635E625B5D625F5C57585E615E5C595B58
5D595C605E635E5D535E575B5C5C615F59585B585F55595B625761555E5A5A585A565358
595852575A58585B584F5C5D5C5B5D59595C5B59585C605B5B585754565B515A58575A57
585A5859615550555A53555E6058565B5557535052535C5A564F54565359585B58545457
5A505C595A575B5963555B585C5A5F66615E5F5B595560615D5B62565A5C586052635A51
5551575758505451
5D5B605B5E5A5F615D5E675E655F61605E59545D595C5E5B5F595E515D5D595E5F5C635C
5C585E5C5B65615F5A5D5B5E60595C5C625B5F616160555D5C605A635F5B5F62605B5C60
5756625F5B64605759545F595E605B5D5C5E5956595A646164605C605A5E5C615E615B51
5A66615E61605F5D5F5D605E61605F545E5F585C5A5D5F5C596157595B5F5A635E5D5C5D
5F5D6062625D5B5E5F63595E5D5B5A625F5B605C5B595B596463635D5F565B5C5E5E6060
6365615E5D5A5E6660605E5D635F616164605E61635D5F61606761655D61625C62615C64
55625B5F665E5B5A5E5D5C5D605E5E645F5B5D635B5A5F576255565A5D5F6459615A615B
5A64625C605C596A5E625B59655C5F595F5C59625D635E5B635D5E605A56605C59585B5C
555A5C62605B5B595C54615E5C5E555D605A5C5E5F5960595C58635F5B5F665A5C625E5D
5D5E5E605B5C5C60656161595C5A5D5B5C5B6565605B5C6160635C5C5E5F5E5F5D5B555E
5A5C58625C59575E575D55505A5B5B575658545E5A5958615D525A61585D5C5B55565C58
5B5A595C5B56655C5756545B5C595B5B6256625C555C5A565B58585D59556157565E545C
5B54544F54575D535855575658545452574E54545751585656555C605B585652555A545B
535559575455585B575757575C5C575E5C565E575A595A5655595B5C5C525C5655575755
5758575A58574F5C
605E5D5D5C5E565D5E5B5B5D5C5C6157595B595A615C5E605D635F5B58595C5D5D58695F
5D625B5B5F615E5E5B5F595A5E615765615D535E5D5E5F5E5C625A5E5D585F5B5B5F655F
62605E605F635A5E605D5B5D5A575A605D5C5A5C5B5A5E615E61546863605D5A5D5A5E5A
5F605A635E665E5E5F545A5D5C5E5F5C61595C5C635B5F62605A5E635B5C62585E5A585B
5C665961605F605B5F5C5C5D655A60615E5860605F5E5959615B566062625D58595E605C
57645E6160615B61605C62635C5F5C655D626463595B62635C665E645C635E635F60585E
615E5F6062615657605D595E5E5D5F5C5B5A5F5B5D5D60615A5D635E595E5E5A635F5F61
5E5F565F675D5D55665E5D5C605E59665E5D605F616A5D5E615B5D605B635A60635D5A60
585E5E5C61655B5D5D5F5F665B664B5F5860605E5E585D61605F61575D635D5B5B5F5B60
605D5A5C615C5E6262565A6259615C595B645E6A615F6661625F61626460555A56635C5B
5A5A5D5B5F5B6360595D5957615C555558575D595B5B5959525C585B5C5F595458585957
5E5B5C57575B5C58585A595954575D595B5D5A5C595F605A555756515953565C5558595A
5856535255585A5954575858575B545757565557555356505255555856535B5559555650
56575C5B595855545959595E5556605F585F576159625B5B5D5855565C5558575B565250
575B5B5550544B59
615D5B59575C5F5E605F60635D5E61645F5F5F5E5A5A5F585D5F635F585D5B5E615A5E5F
5B675A625F5D59585C605B5B5E565D6161635A6062615F5E5B6560605B61615F5C605D61
5B565A5D5B595C605A5C5C665C5B576158615C5E6561565F635A5C68625D5D665E64595C
605A5A575E615E5D63645F5F575D5C615669565E645F615B5D65585C615C625F61615B5D
61615D65625B5E5D5B6158545E5D5F6564625F625F5C5D5E6164625F5C645E5E5A625E68
5C5F5D6167686461636366615E6A605B61635F61595F625F5C655F62605A5F62585C5E60
6161665D5C5B615E5E59615C5A63685A61685D605A5962645B585765605D5D5C665D615B
58605B5C615C615E6068615B62605C5C5A5B5E5C5A5B5E656363615E625E59505E626256
60585C625D585E5F5A5E575C5C62515364615B615B605C5F5E535B5C625A64555E5D5A59
55585B555A625D60586059585C595B5A605F605A646063665F5A5E5E5D5D565C5E5F5E56
5658585E5D5E55575F5F545960575B595C5A5B5C595E605C5D5E585D5F5A5E5F5B5D5F58
5C5D5E595A555255565A57515A5D5D5D5F58595A5657545A545C5859545B565E58595C54
5E565B5E5D565A53575856535F575755535757575D505455505B55555754535856545B5A
565B5E5C54565A5E5B5B5C586054635E59565C53575D575E54575A55545758565C5A5955
555A5F55505B4F58
595958645C585B585E5F605D5B5F60635C5D51595362555C5E65635B5B605C615D596861
5D5F5D6161575B61615C5D5E60595B585C5B56655D625C675F54635F5F60645E5E5D5F5D
555B5C625763555C5F63576163575E5E5F5F5A61565C605A5A5E615F60575F5A5F5A675E
5E635F5F5D63595F615D5E5A5E615A5F625D5B60655D5E5E6161595E5F6165665E635D5F
5C5C5B64546057605E5E585D5961615D606560585C6360615B6264665C5F5D5B5E586762
62606061625F6360645F635B626763645D5D5F5A65605D5C6261605F626463625F595C5F
5F585F5A5C5B595F5C60605B5F5B5D5E5D595E5A5A5B5F62605557675F5F646060615E5E
5E5C5C655E665860545B60625F675D625E625D655F58635F655C63596760625D5F5E6162
615F5A615C5F62575E5D6562616064605F5C5B5D5D5F5954645A56625761605D5F5C5C5E
55645D5F5F5A62595B5D5C5A5C5F5E5C6563645F5D6465615B5B595C595A5F6358565F57
575F565C59585B5C51595B5B5B585B5C5D5C5A56575A5D565B5A59585D615758585D6259
595958545F5F595A5F5A5359585E615E5D5A5F5859545E595657595A59585C5758575752
5F5A51565A58535D58595554545450575A594F5854555556545658525958565C52565B53
5C5A565553585C55575A5E575E5A5F545857505A64585E565A565D604F59555862585C56
545B5E5C59515958
605C5D5A5F5B585A5A565D5B605F5B655A6162625F62625E5E5F5A5E59535C5B5C5E5E61
5E5E615E5C5E68555D5C5C5B5E605F5F595E625B5C536559565E5B5C5A5C60605F565B54
5A58685566575C5C5D6255585A5C58605E605B59565B5D5B655E5D5F5E695C5F655B5E61
6561616460675C5E625F615E575C5762625C555F615C6260585C5C5B5E5E5B605B626161
605F5F5F635E6661646063625C5C5D5E5C5C605F5A61625B5A63655B605E666360595C64
606164645C60676161605D5F605B635D656257655D63585C5A5B62595B685D615B5E5A5D
5C5F5B5A61555B5D5E5A6258596160605C5E5E6658605E575B6069635E5B5C5F64685E5D
5F5C5F5D65645E665F5A66585E535E57645E625E635E645A5A625D60555A595C5E5A585C
5C5A5E5A5B5E5C5B585A5F5C5E605B5B5C6058606460555A5E5C5D62615A625E57606062
5A545B5D5D6059585F5B605F625D575D606460635D5E5F605F5C5C5F5E5C6168615D5F62
5B5C5B59585E5E595E5B5A60645D53565D575A57565E59595E515F56615A625D59575C5B
5B5A5A605B52585D595B5D5A575659575B5A5C565C5B57555A5E5C5A5652575B5C5A545B
555D5456585558585655565957595857524F5557515358575452574F545252545B5A5359
5B5C58565558555A565A585E55584E585F5C5359575B60575D5C5B515E5D56575F5B5F5C
4E52595C595C5661
5F5653605D5E5A5C5C5E5C5C665D5E6161615B5B5C5C5D63615A5C5B5F5E59585E645E5E
5C5C63616764646265605C5A64565A6051635B5F5B655D605D5B635E5C5A5A5E625E5D5E
645E59615A5B63615D5C5A57515C5B5A586656595B5D5F585A5C5A626159645F5C635262
5C54605A645F5B55615A5C5F5E5C605D5C625B575D5B5C67635D5A5A5E60655F6262625A
61635E5F605E6163625E5A5E5D5F616264605F5B5D5F5B5D5E5B6269615E5F5D5C605D61
646366615E6060655F66665C5C5A5F5F655C615E5F5D5C5C5E64615F5C575D64625F635D
5F61585F596163655A625D655F6062605D5C57615F615B595A5867615D5D5B61625F645F
5D5F605A625D575E565C5F58575F625E615C63635A5F5E5C5C605C5F5B59596157586062
5B5E615F5E61605D625D5D585A5A5D5D56615D5B6358595B5C5D5D5D5E5D58525A5C5F5C
5C5A5B5A5F5F5D5E6859605D5B615D57645B5B605C5F5A675D5C57575A5D5662545C5661
615D625E5D60595C5B5A6059605D5C5B5C5C57525B61575F5A5C5D5C5E545A5B5955615A
595A5757585A5A585A535A57565B59595D5757555A5654525A5A5659566455575656554F
5B5E57575C53535D5C5955595658554D5A56524E545350535E5B505655565C5153585C5B
555755545F5E5B565B5E55585F555B544F505A5759575754585F545059575E585D585F58
5A5D5553605B5A5A
5961575B61625D5D57615F655C605E66655963585E5C645B605B585D5B605D5F5E5B5F5F
656661575851575D615C5D565C5761545C605E5F615A5A5A5E605C5B5F5C5959605B6060
58605F5F5C5C58625A545D5B575F5E5A585860595B5E595B5E5C575B5A5D60595F605A61
63605D57615759585C5F5D5D616062605E5156615E57605D5F605F60595C5F615E5E5B5D
606362675E60625A5861605D5A5D615A645C5C625D5D5F5E5C5F696462605E6560635B64
5D5F665F615F635E59626062645D62636259605A585F635D655F5B64606461595F605C64
5C5C64605D605D615A5E5D615F61585A625E616158575B5C5A5F5D5F5D5E635C5F60625C
5F5B5E615A5E55565C5D5A585A5D5F545B585E6360656067635D5864625C61615A5C605D
5C5B5E5E61635E5B5D5C5A5D595F5D605D576565625B5B5F5F5E5A5F61605B605E60585D
5D5A545E5857595A5F5C5D5C5A5F5E5762596067615F565F595C5E5D585B5E5B585B5F5C
5A585E5D5A5F61585D615F5D555A61585D5F595E586159585F5D5B585C595B53565F5B5D
5A5C5A595857535D645758615D62635A55575E5A55585955595052585656585357535B56
5A575A565A56585958535B5B585357595258574F5B565E54545E5658535053555A545C57
57575A5A565D5555555558535A5B54525B585B595A57585358565A5857524F56525D5856
595B5B575B4F525C
5B56595E5E5B565D605B605F6064595F666561635F60595F5D5D5E5561615D64625A5C5C
595D615D675A625F5B5F5C5C575E5C5F635E575C625E5E58615E5A5B5F625E5E5762625A
595F5B6057595C595C5B5F5455615F5A595B5E5D5F555A66545F58565A595D5A62545F60
5C605F625C58625F60625F6162605D5C5C5857645D5D5F695B5F5E5F5D5E61665D5F5760
635E5B5E605F6563595B565C5962615E5A5D5F5B62605A605C6460625D5B5E5F5A626669
5F5F5D5E606060655F5C5B60626265605F5E5E5F5E57635B5D5D69595D595E5B5C655E63
625D6661605E5B5959615D665B5D5D635E5E5E5D63585F615F5F58645F5A606264605B5F
60595A59636460655A5B5F5F6062605D5B5E635B635B5A5F636362605E625C5C5959615B
59615A625E5D5E625A59605A6259555B5C5F6368635D59595C5E585E585B5A606356565F
555B58595354605B5B5C5D61615D6458615D635A685F615E595A5C565B595C5D5A60595D
5D5A5D5E5C5F59645A625B5F5A5C685D5B605E5B605B55555A5A5C5B5F605D5E595A5A5C
595C5959525A535A5B585B545A59565C5E5C5A595554595856575D5559535A55575E595C
5C55535453575357555E5D5258535754595C5751595656585552584F57585A6155545352
5A59595956585756585858585A58525860585D5B5B5C5850585E5D55535750625D59595B
5E5A5D5856595152
5F5E555F61625D5A5D5E5E5D5A5D5F5A615E5F635F6765625D616259655A5B5D5F596262
5C5B5F605F5C5D5C5A565E5A5B605C5E585A5A5A5B645C5B5E635B565960595E5857605D
575A605F5A5A5F5F5D61555B555E615C5A5B5B595F675C5963575D60645A61645C5F615C
5B60605B585D5B605F5C5E5D5E5F595C60625A61595F5C5E61615D59595A5D555E5E5B61
5A5C6158615D615A5A5C5B6160585D606255625A5E5E5E5F6060665B625D5B6263606366
6C5A6463676B60675E5F5C5D60615C5A635E636255636466605961635E62615A5D5A6362
625C5A60605E5D5A5F5C5766615D5C5F575D575B5F5B5E605C5E576160615A5D5B5B5D5E
5B57605F5F5E5D5E5F6159625A5F5B5A6254675A61535D5F66605F605F5E5E5B5B60635C
5B5B59615C585360565F625B5A625F635E5A5D595A5D5A605364655C5B5F5F5656595B5D
625A5F61595C5D575A595C52645D5A59605C6163645E5C5A5E5A565D5D5D5659615E5B5F
625F60595D595A5C5E5F635B66595D5B5E5D5D5D5B596652565D5E5B595E5C585D5B5C54
525952585D56565A5D595A575C5C53555A625257575655575A5456585B545B5858565456
575B5556575D5059565C545656555858535354535553514F5B50545958555B545559565F
595A575B55555957515757565757595E565652545B595662645E5B595B5C5F554E555A56
5356505758585659
5657525662565D57544F565A615C585A5952515E555A5F5C545456545C5A555A52555957
5251535D51544F554E575654574E555053525657595C57575E575A53555D4F5852515351
5654505255545955505B57525251595952575E5C5B51554A54574D595E59545A59564B59
4F5353575454545A5853575A5B5A5A5A5D5451545554525358545B565855545A545C5A52
555B5557575B535F56595757575E51515559565651585256535A515851535858595B5555
59575259595A5D585958515C5B615F5E60555556575E5359575458575755595A5A5C585A
5B5A5E5553554F5759515055565956535355595651525457564D545B555756565C5D5A5E
565D5055555C57504D56535855515252535857695A55544D535B57525C55515457585256
54534E545A4E5456515A57545C534D59565554554D5F595454615459544C55544E565155
4E5A545950554F525153594D5551574B5253555A5256575957565356485056485651524E
594E594F5755544D5A5D565351525951495A585153524E5557585051504B53584B53544F
4F484E4C4E564F4E4750504F51554D4B514F4D53564D5354504E504F50584C4F584B544E
4F50575157514E495052504B45475452544C4F4A484D534952554F4C54544A4B51504F50
4F4E4E53514D4D4D4751464C4C50504D50524D474E525A4D53554E4F535154564D514D4D
4B4A52544B534853
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{350, 350},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005N0001GR000`400?l00000o`00003oo`3IfMUO
0=WIf@00o`3IfMUO0=WIf@00o`3IfMUO0=WIf@00o`3IfMUO0=WIf@00o`3IfMUO0=WIf@00o`3IfMUO
0=WIf@006`3IfMT2000003@0fMWI1@0000020=WIf@800000103IfMT2000002l0fMWI100000030=WI
f@800000103IfMT2000002l0fMWI0P0000040=WIf@800000103IfMT200000300fMWI0`0000020=WI
f@800000103IfMT200000300fMWI0P0000040=WIf@800000103IfMT2000000P0fMWI000J0=WIf@04
0000003IfMT0fMWI000003D0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@040000003IfMT0
fMWI00000080fMWI00<000000=WIf@3IfMT0;03IfMT00`000000fMWI0=WIf@030=WIf@040000003I
fMT0fMWI00000080fMWI00@000000=WIf@3IfMT00000;@3IfMT010000000fMWI0=WIf@0000020=WI
f@040000003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT00000<03IfMT010000000fMWI0=WI
f@0000020=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT0;03IfMT010000000
fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT000001`3I
fMT001X0fMWI00@000000=WIf@3IfMT00000=@3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI
00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0fMWI0080
fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@00000_0=WIf@050000003IfMT0
fMWI0=WIf@0000000P3IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI02/0fMWI
1@0000001@3IfMT000000=WIf@3IfMT000000080fMWI00@000000=WIf@3IfMT00000<@3IfMT01000
0000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT01@3I
fMT001X0fMWI00@000000=WIf@3IfMT00000=@3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI
00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@0^0=WIf@050000003IfMT0fMWI0=WI
f@0000000P3IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI02h0fMWI00@00000
0=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI02/0fMWI
00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI
000002l0fMWI0P0000030=WIf@040000003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT00000
1`3IfMT001X0fMWI00@000000=WIf@3IfMT00000=@3IfMT01@000000fMWI0=WIf@3IfMT000000080
fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@0/0=WIf@040000003IfMT0fMWI
00000080fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@00000]0=WIf@040000
003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@00000^
0=WIf@030000003IfMT000000080fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WI
f@00000_0=WIf@030000003IfMT0fMWI0080fMWI00@000000=WIf@3IfMT000000P3IfMT010000000
fMWI0=WIf@0000070=WIf@006`3IfMT2000003D0fMWI0P0000040=WIf@800000103IfMT200000300
fMWI0P0000040=WIf@800000103IfMT2000002l0fMWI0P0000040=WIf@800000103IfMT200000300
fMWI0P0000030=WIf@800000103IfMT200000300fMWI0`0000030=WIf@800000103IfMT2000000P0
fMWI003o0=WIfEl0fMWI003o0=WIfEl0fMWI003o0=WIfEl0fMWI003o0=WIfEl0fMWI003o0=WIfEl0
fMWI003o0=WIfEl0fMWI000F0=WIfOl00000B00000010=WIf@005P3IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0:
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0:
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0:
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT02@3IfMT200000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0>P3IfMT00`000000fMWI0=WIf@0k0=WI
f@030000003IfMT0fMWI03X0fMWI00<000000=WIf@3IfMT0>P3IfMT00`000000fMWI0=WIf@0k0=WI
f@030000003IfMT0fMWI00X0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WIfD@0
fMWI0@0000010=WIf@003P3IfMT2000000H0fMWI00<000000=WIf@3IfMT0o`3IfMU40=WIf@400000
0@3IfMT000d0fMWI00@000000=WIf@3IfMT000001@3IfMT00`000000fMWI0=WIf@3o0=WIfD@0fMWI
0@0000010=WIf@003@3IfMT010000000fMWI0=WIf@0000050=WIf@<00000o`3IfMU20=WIf@<00000
0@3IfMT000d0fMWI00@000000=WIf@3IfMT000001@3IfMT00`000000fMWI0=WIf@030=WIf@0G04a<
C015ADD0BDU904e=C@1>CTh0ATI604e=C@1ADE40CTi>04Q8B01:BTX0CDe=04I6AP1@D500AdM7051@
D018B4P0CDe=04i>CP1<C4`0CTi>04e=C@1ADE400P1>CTh07@1;Bd/0C4a<04];B`1;Bd/0Cdm?05=C
D`1?Cdl0BDU904M7A`1@D500BTY:055AD@1>CTh0D51@04i>CP1?Cdl0De=C055AD@1:BTX0B4Q8055A
D@1CDe<0DE5A04Q8B01=CDd0DU9B055AD@1>CTh0De=C0080BTY:00`0CTi>05ADE01GEeL0E5AD05=C
D`1<C4`0CDe=05IFEP1HF5P0EUIF059BDP1@D50205=CD`0E05IFEP1BDU80Cdm?04m?C`1:BTX0E5AD
059BDP1CDe<0EUIF05MGE`1=CDd0E5AD04e=C@1@D500CDe=059BDP1GEeL0EEEE05ADE01ADE40F5QH
0080DU9B0300F5QH05ADE01EEED0CTi>05YJFP1;Bd/0Fe]K05IFEP1GEeL0FEUI05=CD`1FEUH0E5AD
059BDP1HF5P0EEEE051@D01GEeL0EEEE05=CD`1DE5@0EEEE05IFEP1HF5P0EeMG065QH@1IFET0Fe]K
05UIF@1FEUH0F5QH05MGE`1JFUX0G5aL05EEE@1GEeL0F5QH05iNGP1DE5@0Fe]K065QH@1CDe<0GUiN
05mOG`1LG5`0Fe]K065QH@1PH60205mOG`0@05YJFP1PH600FEUI05mOG`1PH600G5aL06YZJP1SHf<0
Fe]K05mOG`1WIfL0Hf=S069RHP1TI6@0Jf][06EUI@80Jf][0P1XJ6P0201QHF40IFEU06MWI`1TI6@0
J6QX069RHP1]KFd0HF5Q0P1RHV804`1TI6@0J6QX05eMG@1UIFD0Hf=S06QXJ01QHF40I6AT069RHP1Q
HF40IVIV06ATI01VIVH0IfMW065QH@1[Jf/0JFUY06=SH`1UIFD00P1RHV804P1QHF40IfMW05]KF`1S
Hf<0I6AT06IVIP1QHF40HV9R06=SH`1PH600GemO065QH@1RHV80Jf][06IVIP1QHF40G5aL05UIF@80
G5aL00<0HV9R06EUI@1QHF400`1NGUh3061PH080Hf=S03H0J6QX05QHF01OGel0H61P06=SH`1HF5P0
FEUI05]KF`1NGUh0Fe]K05QHF01JFUX0EeMG05QHF01IFET0F5QH05iNGP1DE5@0DU9B05QHF01DE5@0
EEEE05MGE`1FEUH0GEeM05=CD`1IFET0EEEE05=CD`1DE5@0FEUI05MGE`1=CDd0FEUI05ADE01<C4`0
BDU905ADE01GEeL0CDe=05EEE@1?Cdl0F5QH055AD@1:BTX0Cdm?04e=C@1BDU80Cdm?04e=C@1>CTh0
D51@04m?C`1@D50204i>CP0=04e=C@1DE5@0FUYJ04m?C`1;Bd/0ADE505EEE@1?Cdl0De=C059BDP1C
De<0CDe=04a<C00204];B`0604M7A`1FEUH0D51@055AD@1:BTX0B4Q80P1:BTX0201?Cdl0CDe=04Y:
BP1=CDd0CTi>059BDP1:BTX0CDe=0P1<C4`60=WIf@4000000@3IfMT000d0fMWI00@000000=WIf@3I
fMT000001@3IfMT00`000000fMWI0=WIf@030=WIf@0F05=CD`1FEUH0FUYJ05]KF`1FEUH0Cdm?04i>
CP1EEED0EeMG05IFEP1EEED0EUIF05ADE01GEeL0G5aL05QHF01NGUh0FEUI05]KF`1HF5P0EUIF05UI
F@@0EeMG02X0EUIF05=CD`1DE5@0EeMG05aLG01HF5P0EEEE05UIF@1DE5@0GUiN05ADE01HF5P0EeMG
05iNGP1MGEd0D51@05IFEP1JFUX0HV9R05IFEP1LG5`0FEUI05YJFP1MGEd0GUiN05EEE@1JFUX0GEeM
061PH01NGUh0De=C05]KF`1JFUX0G5aL05mOG`1QHF40FUYJ065QH@1MGEd0HV9R05mOG`1GEeL205iN
GP0:05aLG01HF5P0Hf=S05aLG01PH600EeMG05mOG`1HF5P0Hf=S05aLG080GUiN00X0GEeM05YJFP1P
H600Hf=S05YJFP1FEUH0GUiN05]KF`1JFUX0F5QH0P1UIFD0701QHF40GUiN06EUI@1OGel0HV9R06AT
I01VIVH0IFEU05aLG01UIFD0H61P06ATI01VIVH0Hf=S06MWI`1QHF40Hf=S065QH@1JFUX0IFEU05iN
GP1RHV80Fe]K069RHP1OGel0J6QX06=SH`1VIVH206ATI00<06EUI@1XJ6P0IFEU06QXJ01/K6`0KFe]
06IVIP1XJ6P0JFUY06][J`1XJ6P0IfMW0P1RHV805@1^KVh0Jf][06UYJ@1/K6`0KVi^06YZJP1aLG40
Jf][069RHP1]KFd0K6a/06e]K@1[Jf/0LG5a06][J`1bLW80KVi^071`L01aLG40MGEe07IfMP0207Ee
M@80LW9b00<0M7Ad07=cL`1_Kfl00P1_Kfl08@1aLG40KFe]075aL@1hN7P0LW9b075aL@1hN7P0Lg=c
07MgM`1eMGD0M7Ad079bLP1[Jf/0L71`06m_K`1dM7@0KVi^06e]K@1eMGD0MWIf079bLP1dM7@0L71`
07IfMP1cLg<0K6a/075aL@1/K6`0Jf][07AdM01aLG40JVYZ079bLP0206UYJ@0d07EeM@1_Kfl0KFe]
06YZJP1]KFd0J6QX06UYJ@1TI6@0LG5a06e]K@1/K6`0I6AT06e]K@1YJFT0IfMW061PH01_Kfl0J6QX
06MWI`1ZJVX0M7Ad06i^KP1`L700IVIV06a/K01[Jf/0IVIV06QXJ01RHV80Jf][06QXJ01WIfL0Hf=S
05eMG@1LG5`0H61P06EUI@1SHf<0I6AT061PH01SHf<0GemO06IVIP1NGUh0I6AT06=SH`1UIFD0F5QH
06EUI@1KFe/0GUiN061PH080HV9R01P0GUiN065QH@1PH600G5aL05]KF`1MGEd0G5aL05UIF@1HF5P0
I6AT05aLG01JFUX0FEUI05]KF`1LG5`0Fe]K055AD@1GEeL0GEeM05ADE01PH600HF5Q05QHF01LG5`2
061PH00;05YJFP1NGUh0EEEE05iNGP1HF5P0FEUI05YJFP1KFe/0EEEE05mOG`1GEeL00P1HF5P04P1>
CTh0FUYJ05IFEP1ADE40DU9B05UIF@1=CDd0D51@05IFEP1BDU80BTY:055AD@1GEeL0EEEE05YJFP1N
GUh0E5AD059BDPH0fMWI0@0000010=WIf@003P3IfMT2000000H0fMWI00<000000=WIf@3IfMT00`3I
fMT07P1QHF40FEUI05]KF`1KFe/0FEUI05IFEP1KFe/0HF5Q061PH01JFUX0GUiN05eMG@1LG5`0FEUI
05aLG01EEED0I6AT061PH01FEUH0FEUI06=SH`1RHV80GEeM069RHP1LG5`0FUYJ05eMG@1JFUX0Fe]K
06ATI080H61P00h0GemO061PH01JFUX0HF5Q05mOG`1RHV80HF5Q05aLG01PH600GUiN05mOG`1UIFD0
H61P05YJFP80G5aL00T0GUiN05]KF`1IFET0JFUY061PH01NGUh0HF5Q06=SH`1RHV800P1TI6@0101N
GUh0HV9R05mOG`1QHF4206QXJ00<06IVIP1TI6@0HF5Q06=SH`1UIFD0IVIV069RHP1OGel0H61P06QX
J01RHV80IVIV0P1XJ6P01`1SHf<0HV9R069RHP1RHV80IfMW06IVIP1UIFD00P1OGel0101TI6@0HF5Q
06QXJ01VIVH2065QH@0806ATI01QHF40Hf=S06QXJ01]KFd0JVYZ06e]K@1ZJVX306MWI`1=06EUI@1W
IfL0Jf][065QH@1]KFd0JFUY06e]K@1TI6@0HF5Q06IVIP1XJ6P0IVIV06UYJ@1PH600Jf][06ATI01^
KVh0Jf][071`L01XJ6P0IFEU07=cL`1]KFd0K6a/06YZJP1YJFT0Lg=c079bLP1^KVh0LG5a071`L01_
Kfl0LW9b075aL@1/K6`0Jf][06i^KP1aLG40Lg=c07AdM01^KVh0Lg=c06][J`1hN7P0Lg=c079bLP1d
M7@0L71`07UiN@1aLG40KVi^06e]K@1fMWH0N7Qh07emO@1bLW80OGem07EeM@1lO7`0OGem07IfMP1d
M7@0Ng]k06i^KP1oOgl0OGem07MgM`1bLW80MWIf07EeM@1cLg<0MGEe079bLP1hN7P0M7Ad07=cL`1h
N7P00P1cLg<0101`L700KVi^07UiN@1gMgL207QhN00C07YjNP1bLW80Lg=c07]kN`1aLG40Lg=c07Ui
N@1cLg<0LW9b07=cL`1ZJVX0M7Ad075aL@1]KFd0MGEe071`L01cLg<0M7Ad06e]K@0206i^KP0806][
J`1`L700LW9b06m_K`1^KVh0LW9b06a/K01^KVh2075aL@0=06m_K`1/K6`0Kfm_07=cL`1_Kfl0Jf][
06a/K01aLG40IVIV06=SH`1`L700KFe]06MWI`0206IVIP0]06MWI`1UIFD0IfMW06i^KP1ZJVX0HV9R
06IVIP1SHf<0K6a/069RHP1UIFD0IfMW069RHP1WIfL0J6QX061PH01MGEd0I6AT05mOG`1TI6@0H61P
05iNGP1PH600GEeM069RHP1VIVH0I6AT05mOG`1XJ6P0Hf=S061PH01LG5`0GUiN05IFEP1RHV80I6AT
061PH01HF5P0FEUI05eMG@1OGel0H61P05IFEP1BDU80HV9R00<0GEeM01<0HF5Q05YJFP1RHV80F5QH
061PH01OGel0GUiN05UIF@1QHF40G5aL05MGE`1HF5P0G5aL05YJFP1GEeL0Fe]K05QHF01IFET0DU9B
00<0F5QH00P0HV9R061PH01HF5P0GUiN05MGE`1EEED0E5AD05EEE@H0fMWI0@0000010=WIf@005P3I
fMT00`000000fMWI0=WIf@030=WIf@80FUYJ00X0F5QH05eMG@1RHV80GemO05eMG@1QHF40GUiN05aL
G01IFET0F5QH0P1KFe/0A@1DE5@0J6QX069RHP1WIfL0Hf=S05aLG01NGUh0Fe]K06ATI01FEUH0GEeM
06IVIP1OGel0GEeM05aLG01JFUX0GemO05eMG@1WIfL0GUiN05MGE`1OGel0G5aL05]KF`1SHf<0HV9R
05iNGP1RHV80I6AT05YJFP1KFe/0HF5Q069RHP1TI6@0Hf=S05iNGP1WIfL0IFEU05eMG@1VIVH0HF5Q
05MGE`1VIVH0JFUY05aLG01UIFD0GEeM06YZJP1SHf<0GEeM06][J`1TI6@0GUiN06YZJP1QHF40JFUY
06IVIP1YJFT0IFEU05iNGP1PH600KVi^06QXJ01TI6@0IfMW06EUI@1OGel0IFEU06=SH`0206ATI003
06][J`1KFe/0JFUY0080Hf=S00L0IFEU06IVIP1UIFD0HV9R06MWI`1VIVH0HV9R00<0JFUY0P1RHV80
1@1TI6@0GemO06UYJ@1XJ6P0JVYZ0080IfMW00<0K6a/06MWI`1YJFT00P1WIfL0<01]KFd0IVIV06IV
IP1TI6@0KFe]06IVIP1[Jf/0J6QX06m_K`1/K6`0L71`06QXJ01cLg<0KVi^06][J`1_Kfl0K6a/07Ee
M@1ZJVX0L71`07=cL`1`L700J6QX075aL@1cLg<0JFUY06][J`1`L700LW9b07MgM`1kNg/0L71`07Ee
M@1cLg<0PH6106a/K01aLG40KVi^071`L01eMGD0OGem07EeM@1lO7`0MGEe07MgM`1hN7P0MWIf07in
OP80MGEe00<0LW9b075aL@1fMWH00P1lO7`02@21PH40Q8B4079bLP1hN7P0MWIf07inOP1gMgL0NGUi
07alO00207inOP0707MgM`1dM7@0Lg=c07IfMP1eMGD0MgMg07UiN@0207QhN00P07IfMP1cLg<0MWIf
07QhN01lO7`0N7Qh07emO@1gMgL0N7Qh079bLP1aLG40LW9b07UiN@1fMWH0LW9b07QhN01cLg<0Jf][
07EeM@1]KFd0M7Ad079bLP1aLG40IVIV06UYJ@1aLG40KFe]07AdM01[Jf/0JVYZ06e]K@1_Kfl2071`
L00T06a/K01^KVh0JVYZ07=cL`1dM7@0Kfm_06][J`1/K6`0Hf=S071`L01[Jf/0K6a/06EUI@1VIVH0
Kfm_06QXJ01RHV80IVIV06=SH`1YJFT0KFe]06QXJ01QHF40I6AT06MWI`1]KFd0J6QX061PH01RHV80
JFUY06=SH`1ZJVX0H61P06EUI@1XJ6P0IVIV0P1WIfL02P1QHF40G5aL06ATI01VIVH0IfMW069RHP1N
GUh0JVYZ065QH@1PH60205aLG00>05eMG@1LG5`0FUYJ065QH@1MGEd0EeMG05eMG@1PH600G5aL06][
J`1SHf<0GEeM065QH@1NGUh205aLG080FEUI0100EeMG05YJFP1LG5`0G5aL05UIF@1MGEd0HF5Q05eM
G@1NGUh0G5aL05UIF@1EEED0EUIF06=SH`1LG5`0FUYJ0`1DE5@0101BDU80EEEE05EEE@1IFET60=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT03`1NGUh0HV9R05QHF01LG5`0HV9R
05iNGP1VIVH0G5aL06=SH`1NGUh0H61P05eMG@1NGUh0G5aL06EUI@03069RHP0H065QH@1NGUh0GEeM
06EUI@1SHf<0GEeM06IVIP1KFe/0H61P06EUI@1OGel0GEeM05aLG01JFUX0HV9R05eMG@1WIfL0GemO
065QH@1TI6@0FUYJ05MGE`1LG5`0GEeM0P1NGUh06@1PH600Hf=S061PH01RHV80HF5Q06UYJ@1PH600
HV9R06ATI01XJ6P0IFEU06=SH`1RHV80IFEU06=SH`1TI6@0KFe]05mOG`1RHV80J6QX06MWI`1ZJVX0
IfMW06ATI01WIfL00P1VIVH0201TI6@0J6QX069RHP1TI6@0K6a/06EUI@1SHf<0HV9R0P1XJ6P08@1W
IfL0JFUY069RHP1XJ6P0HV9R06IVIP1WIfL0J6QX06IVIP1UIFD0JVYZ06MWI`1SHf<0K6a/06YZJP1/
K6`0JFUY06m_K`1YJFT0IFEU06MWI`1aLG40Hf=S06i^KP1[Jf/0IVIV06YZJP1]KFd0K6a/06YZJP1V
IVH0IfMW06YZJP0206][J`0806i^KP1`L700LG5a06a/K01VIVH0KVi^079bLP1_Kfl207EeM@0Z079b
LP1`L700Kfm_06m_K`1bLW80KFe]07=cL`1dM7@0JFUY07AdM01eMGD0LW9b07IfMP1bLW80MGEe07Qh
N01dM7@0MgMg07]kN`1dM7@0MWIf07YjNP1^KVh0OWin07YjNP1cLg<0NGUi07EeM@1nOWh0NGUi07in
OP1kNg/0PH61075aL@1mOGd0NWYj07MgM`1nOWh0NWYj07emO@1hN7P0OWin0P21PH40801hN7P0OWin
08>3P`1gMgL0Ng]k07inOP1`L700O7al07moO`1kNg/0LG5a07UiN@1jNWX0NGUi07QhN01eMGD0MWIf
07UiN@1hN7P0MGEe07UiN@1hN7P0MWIf07AdM01nOWh0N7Qh08F5Q@1nOWh0NGUi07QhN01cLg<0KVi^
0P1aLG401@1iNGT0M7Ad079bLP1aLG40MGEe0080MWIf0340Lg=c06m_K`1dM7@0MgMg075aL@1/K6`0
L71`06a/K01aLG40Jf][071`L01]KFd0LG5a06UYJ@1eMGD0KFe]06YZJP1/K6`0Kfm_07QhN01bLW80
K6a/075aL@1hN7P0JVYZ06UYJ@1[Jf/0Kfm_07=cL`1YJFT0IfMW07EeM@1QHF40JVYZ06m_K`1^KVh0
IfMW06][J`1_Kfl0KFe]06YZJP1QHF40Hf=S06UYJ@1SHf<0K6a/06QXJ01VIVH0K6a/0080Hf=S02D0
I6AT06=SH`1RHV80HF5Q06IVIP1LG5`0HV9R06ATI01LG5`0IFEU05mOG`1RHV80G5aL06MWI`1QHF40
GUiN061PH01OGel0GUiN065QH@1TI6@0FEUI061PH01MGEd0H61P05UIF@1JFUX0Hf=S069RHP1QHF40
GUiN05mOG`1RHV80F5QH05IFEP1QHF40GemO0080Fe]K00d0GUiN05YJFP1NGUh0F5QH05eMG@1OGel0
Fe]K05MGE`1JFUX0GEeM05IFEP1EEED0HF5Q00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI
0=WIf@030=WIf@0>061PH01KFe/0J6QX05mOG`1QHF40G5aL06ATI01PH600IVIV06=SH`1NGUh0H61P
05iNGP1SHf<205mOG`0N061PH01SHf<0J6QX06QXJ01OGel0H61P05iNGP1SHf<0H61P05eMG@1TI6@0
GUiN061PH01MGEd0HV9R06ATI01NGUh0HF5Q06YZJP1QHF40IFEU065QH@1RHV80I6AT05aLG01KFe/0
JFUY05mOG`1UIFD0H61P0P1RHV80101SHf<0HV9R06EUI@1TI6@206EUI@0=06ATI01RHV80Hf=S06YZ
JP1WIfL0HV9R06ATI01YJFT0IfMW06YZJP1TI6@0J6QX061PH00206ATI00D06YZJP1TI6@0IVIV06MW
I`1VIVH0IfMW06UYJ@1/K6`0Hf=S06MWI`1VIVH0IfMW065QH@1]KFd0Hf=S06UYJ@1[Jf/0J6QX06][
J`1]KFd206EUI@0506MWI`1^KVh0HF5Q06MWI`1/K6`00P1XJ6P07`1SHf<0K6a/06YZJP1[Jf/0JVYZ
079bLP1ZJVX0IfMW06UYJ@1TI6@0JFUY06YZJP1/K6`0Jf][06MWI`1VIVH0KVi^06a/K01ZJVX0LG5a
06a/K01dM7@0LW9b071`L01]KFd0LW9b06QXJ01^KVh0Lg=c07IfMP1/K6`00P1dM7@00`1^KVh0JFUY
075aL@02075aL@0Q06i^KP1[Jf/0Kfm_07EeM@1cLg<0N7Qh06m_K`1^KVh0Ng]k07EeM@1hN7P0LG5a
07IfMP1kNg/0MWIf07EeM@1mOGd0N7Qh07]kN`1lO7`0M7Ad07alO01fMWH0LW9b08B4Q01iNGT0M7Ad
07inOP1jNWX0Ogmo07MgM`1bLW80MgMg0080O7al00d0OGem07UiN@1oOgl0PX:207emO@1nOWh0MgMg
07alO01jNWX0NGUi08B4Q01jNWX0O7al00<0NGUi00T0MWIf07EeM@1dM7@0MgMg07UiN@1fMWH0Lg=c
08:2PP25QHD00P1lO7`207]kN`0707IfMP1aLG40Kfm_07IfMP1eMGD0M7Ad07QhN00207IfMP0507Ui
N@1eMGD0NGUi07=cL`1`L7000P1fMWH0101jNWX0LW9b071`L01cLg<206m_K`0506i^KP1eMGD0JFUY
06i^KP1YJFT00P1]KFd0<01WIfL0KFe]06m_K`1]KFd0Kfm_06IVIP1_Kfl0KFe]06ATI01`L700KFe]
06ATI01ZJVX0JFUY06i^KP1]KFd0KVi^06YZJP1/K6`0IVIV06a/K01VIVH0JVYZ06QXJ01TI6@0IFEU
06MWI`1QHF40K6a/06ATI01SHf<0IFEU06a/K01SHf<0IfMW05iNGP1ZJVX0H61P065QH@1NGUh0I6AT
05eMG@1VIVH0HV9R061PH01VIVH0GUiN069RHP@0HF5Q00H0H61P06IVIP1QHF40GemO069RHP1PH602
065QH@0;05aLG01MGEd0GUiN069RHP1MGEd0EUIF065QH@1RHV80GemO05IFEP1MGEd00P1LG5`0301P
H600F5QH061PH01PH600E5AD05eMG@1HF5P0EUIF05MGE`1FEUH0H61P05iNGPH0fMWI0@0000010=WI
f@005P3IfMT00`000000fMWI0=WIf@030=WIf@0K06=SH`1TI6@0G5aL06=SH`1IFET0IVIV05eMG@1S
Hf<0G5aL05QHF01GEeL0EEEE05iNGP1TI6@0GemO06IVIP1XJ6P0GEeM05mOG`1LG5`0EeMG05]KF`1N
GUh0I6AT061PH01OGel0I6AT0080H61P01D0IFEU065QH@1UIFD0G5aL069RHP1TI6@0HV9R05aLG01O
Gel0JVYZ06][J`1SHf<0GemO06UYJ@1RHV80Fe]K05YJFP1TI6@0Hf=S05iNGP1PH6000P1QHF40501T
I6@0Hf=S06YZJP1QHF40HV9R06EUI@1^KVh0GemO06UYJ@1WIfL0HF5Q06=SH`1PH600I6AT05aLG01V
IVH0JFUY06MWI`1UIFD0HF5Q0P1WIfL00`1YJFT0HV9R06QXJ00206IVIP0?06QXJ01PH600I6AT06QX
J01/K6`0I6AT06UYJ@1]KFd0K6a/06][J`1]KFd0KVi^06YZJP1SHf<0JFUY0080Jf][01X0HV9R06MW
I`1/K6`0M7Ad06i^KP1VIVH0Jf][06EUI@1]KFd0JFUY079bLP1]KFd0M7Ad06MWI`1gMgL0JVYZ06MW
I`1/K6`0J6QX06][J`1ZJVX0Lg=c071`L01_Kfl0LG5a071`L080KFe]00H0Lg=c075aL@1bLW80L71`
06i^KP1gMgL3071`L00X07=cL`1fMWH0LW9b07MgM`1/K6`0O7al06i^KP1gMgL0OGem07=cL`1jNWX0
MGEe07YjNP1hN7P0Ng]k07AdM01iNGT0MWIf07AdM01gMgL0L71`07]kN`1iNGT0OWin07EeM@1nOWh0
N7Qh08>3P`1eMGD0N7Qh07UiN@1kNg/0N7Qh07emO@1nOWh0MGEe07MgM`1hN7P0OGem07UiN@80OGem
00X0Ng]k08>3P`1kNg/0NGUi07moO`1jNWX0OGem07alO01nOWh0MgMg0P1jNWX03@20P800MgMg071`
L01eMGD0Ogmo07UiN@1fMWH0PH6107alO01mOGd0Ph>307]kN`1gMgL00P1cLg<207emO@0B07QhN01/
K6`0O7al07UiN@1`L700Lg=c07IfMP1gMgL0LG5a071`L01kNg/0LG5a07AdM01fMWH0JVYZ071`L01c
Lg<0L71`0P1]KFd00`1/K6`0Lg=c06a/K002071`L00406YZJP1YJFT0Lg=c06QXJ080L71`0P1UIFD0
5P1[Jf/0JFUY075aL@1YJFT0JVYZ075aL@1_Kfl0JFUY06][J`1WIfL0LG5a06YZJP1^KVh0K6a/06YZ
JP1cLg<0IfMW069RHP1YJFT0JVYZ06e]K@1TI6@206EUI@0906e]K@1ZJVX0GemO065QH@1UIFD0IVIV
061PH01SHf<0GemO0080HV9R00H0HF5Q061PH01NGUh0FUYJ06ATI01KFe/305aLG00C06ATI01OGel0
GemO05eMG@1SHf<0H61P05aLG01PH600F5QH06=SH`1LG5`0FUYJ05iNGP1LG5`0EeMG05iNGP1RHV80
GEeM05aLG002061PH00605UIF@1JFUX0HF5Q05]KF`1EEED0De=C0P1IFET0101DE5@0EUIF05ADE01O
Gel60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0;P1QHF40GEeM05iNGP1Q
HF40FEUI05iNGP1UIFD0J6QX05mOG`1PH600HF5Q06=SH`1XJ6P0Fe]K05mOG`1UIFD0IfMW06ATI01R
HV80HF5Q05mOG`1[Jf/0Hf=S05mOG`1SHf<0I6AT05mOG`1PH600Hf=S069RHP1KFe/0GemO065QH@1L
G5`0Hf=S05mOG`1PH600HF5Q069RHP1YJFT0HV9R06MWI`1TI6@0HF5Q06MWI`1RHV8206IVIP0A065Q
H@1MGEd0IVIV06][J`1XJ6P0GEeM06a/K01YJFT0GemO06QXJ01IFET0GEeM06=SH`1TI6@0JFUY06QX
J01VIVH00P1TI6@08@1UIFD0IfMW06MWI`1OGel0I6AT06EUI@1PH600IfMW06QXJ01^KVh0KFe]06QX
J01[Jf/0Hf=S06EUI@1XJ6P0KVi^06e]K@1gMgL0Jf][06=SH`1^KVh0KFe]075aL@1ZJVX0LW9b06UY
J@1/K6`0IfMW06QXJ01[Jf/0Kfm_06e]K@0206YZJP0=06i^KP1UIFD0IfMW06a/K01fMWH0J6QX071`
L01bLW80LG5a06m_K`1]KFd0L71`07=cL`0206m_K`0506e]K@1aLG40LW9b06a/K01eMGD00P1]KFd0
1`1dM7@0MWIf07=cL`1fMWH0MGEe07AdM01fMWH00P1aLG401@1_Kfl0Lg=c07AdM01iNGT0MgMg0080
Ng]k08/0MGEe07YjNP1eMGD0LW9b07QhN01fMWH0P820079bLP20P800MWIf07AdM021PH40NWYj07em
O@20P800MWIf07EeM@1oOgl0MgMg07QhN01jNWX0PX:207moO`1eMGD0MgMg07EeM@1kNg/0NWYj07in
OP21PH40Ph>307emO@26QXH0Ogmo07UiN@1mOGd0NGUi08:2PP1iNGT0Ogmo08F5Q@22PX80O7al08:2
PP1nOWh0NWYj07moO`1lO7`0OGem07YjNP1nOWh0M7Ad07IfMP26QXH0PH610820P01mOGd0NGUi07]k
N`1fMWH0O7al07YjNP1cLg<0M7Ad0820P01`L700Lg=c07]kN`1iNGT0Lg=c079bLP1mOGd0NGUi07Mg
M`1eMGD0NGUi079bLP1cLg<0K6a/06m_K`1]KFd0MGEe075aL@1_Kfl0LW9b07AdM01^KVh0Jf][07=c
L`1eMGD0KFe]06a/K01`L700JVYZ06MWI`1YJFT0L71`06QXJ01]KFd0JVYZ06IVIP1YJFT0LG5a06][
J`1UIFD0Jf][06YZJP1_Kfl0M7Ad06a/K01XJ6P0Jf][06a/K01VIVH0JFUY06QXJ01WIfL0J6QX06IV
IP1WIfL0HF5Q06ATI01OGel0I6AT06MWI`1OGel0GEeM05iNGP1MGEd0GemO069RHP1NGUh0HF5Q06=S
H`1UIFD0GemO061PH01OGel0I6AT0080G5aL01T0IfMW05aLG01SHf<0H61P05mOG`1TI6@0FUYJ06=S
H`1NGUh0G5aL06EUI@1OGel0HF5Q05eMG@1PH600Fe]K05aLG01JFUX0Fe]K05mOG`1NGUh0Fe]K05eM
G@1DE5@0HV9R0080GUiN00H0Fe]K061PH01DE5@0FUYJ05eMG@1XJ6P60=WIf@4000000@3IfMT001H0
fMWI00<000000=WIf@3IfMT00`3IfMT01@1XJ6P0EEEE05eMG@1PH600GemO0080GEeM00D0GUiN05UI
F@1SHf<0H61P05YJFP02069RHP0406a/K01SHf<0IFEU06=SH`80HF5Q00L0Fe]K05eMG@1RHV80HF5Q
05iNGP1PH600JFUY0080HV9R0180G5aL06ATI01RHV80Hf=S069RHP1UIFD0FUYJ06EUI@1XJ6P0H61P
06IVIP1KFe/0Hf=S05eMG@1YJFT0HV9R06EUI@1NGUh206=SH`0:069RHP1QHF40G5aL065QH@1WIfL0
GEeM06YZJP1[Jf/0IfMW05mOG`80IfMW00d0GUiN065QH@1TI6@0Jf][06EUI@1[Jf/0J6QX069RHP1S
Hf<0KVi^06QXJ01TI6@0K6a/0080IVIV01T0K6a/065QH@1YJFT0J6QX06e]K@1VIVH0J6QX06UYJ@1X
J6P0KFe]06i^KP1ZJVX0JFUY06YZJP1`L700Jf][06e]K@1ZJVX0Jf][06YZJP1^KVh0KFe]06YZJP1V
IVH0IfMW0080KVi^02P0M7Ad06ATI01[Jf/0MGEe06e]K@1XJ6P0L71`06a/K01_Kfl0JVYZ06m_K`1^
KVh0Kfm_07YjNP1bLW80L71`079bLP1dM7@0L71`06e]K@1iNGT0OWin07emO@1]KFd0Ng]k07inOP1e
MGD0LG5a07IfMP1aLG40MgMg071`L01eMGD0NWYj06i^KP1jNWX0Ogmo07MgM`1hN7P0NGUi0P1fMWH0
3P1gMgL0O7al07IfMP20P800LW9b07UiN@1lO7`0N7Qh07inOP1kNg/0O7al07YjNP1cLg<0M7Ad0`22
PX801@1kNg/0NWYj08B4Q01oOgl0NWYj0080P8200180Ng]k08>3P`1kNg/0O7al07moO`1mOGd0NWYj
07UiN@1oOgl0OWin08J6QP1oOgl0PH6108>3P`1oOgl0MgMg07emO@1fMWH207QhN00408:2PP25QHD0
MWIf07MgM`80NWYj00@0P82007moO`1fMWH0NWYj0P1hN7P0201gMgL0NWYj07]kN`1eMGD0M7Ad07Ui
N@1dM7@0MGEe0P1jNWX06@1dM7@0L71`07]kN`1eMGD0Lg=c071`L01dM7@0L71`079bLP1hN7P0Lg=c
07AdM01XJ6P0KVi^06e]K@1aLG40Kfm_06YZJP1[Jf/0Kfm_07MgM`1eMGD0LG5a06a/K01_Kfl00P1Z
JVX0301/K6`0I6AT071`L01[Jf/0K6a/06ATI01XJ6P0I6AT06UYJ@1dM7@0Jf][06QXJ080JFUY0180
IFEU06YZJP1RHV80Kfm_06MWI`1UIFD0IVIV06QXJ01VIVH0J6QX06EUI@1XJ6P0Hf=S05iNGP1TI6@0
IFEU065QH@1LG5`206IVIP0506=SH`1QHF40GemO06=SH`1TI6@00P1NGUh0501LG5`0H61P069RHP1H
F5P0JFUY06IVIP1RHV80H61P05mOG`1KFe/0HF5Q05]KF`1IFET0HV9R05iNGP1PH600J6QX069RHP1L
G5`0GEeM0P1LG5`01P1CDe<0F5QH05ADE01GEeL0GEeM05iNGP80E5AD00D0G5aL05EEE@1IFET0FUYJ
069RHP060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT07P1WIfL0G5aL05iN
GP1SHf<0G5aL05UIF@1QHF40FUYJ06ATI01UIFD0F5QH05eMG@1TI6@0GUiN05eMG@1WIfL0I6AT06IV
IP1RHV80Hf=S05YJFP1RHV80GEeM05YJFP1UIFD0GUiN061PH01LG5`0H61P06EUI@<0GUiN01d0HF5Q
05mOG`1SHf<0H61P069RHP1TI6@0HF5Q06=SH`1[Jf/0IFEU05iNGP1OGel0IFEU06QXJ01QHF40Hf=S
05eMG@1ZJVX0HV9R06ATI01ZJVX0IVIV06e]K@1RHV80IfMW05aLG01QHF40J6QX06YZJP0206IVIP09
06MWI`1VIVH0IfMW06e]K@1QHF40KVi^06UYJ@1XJ6P0JFUY0080I6AT03d0J6QX06YZJP1UIFD0IFEU
06][J`1^KVh0IVIV06EUI@1/K6`0HF5Q06QXJ01WIfL0KFe]06QXJ01ZJVX0J6QX06][J`1aLG40L71`
06IVIP1]KFd0K6a/06i^KP1aLG40KFe]06EUI@1VIVH0Jf][06MWI`1]KFd0MGEe06i^KP1[Jf/0Kfm_
06e]K@1[Jf/0Lg=c06][J`1eMGD0Jf][07MgM`1dM7@0MgMg06YZJP1_Kfl0N7Qh07UiN@1]KFd0Kfm_
06i^KP1/K6`0Kfm_071`L01aLG40NGUi07=cL`1hN7P0O7al06e]K@1gMgL0M7Ad0080NWYj01<0MWIf
07=cL`1cLg<0NGUi07alO020P800O7al07IfMP21PH40Ng]k07IfMP1cLg<0NWYj07=cL`20P800LG5a
07inOP21PH40NWYj0080OGem01h0P82007alO025QHD0Ng]k07UiN@1gMgL0Q8B407moO`22PX80QHF5
07IfMP22PX80Q8B407UiN@1mOGd0Ng]k0861P@1lO7`0OWin08>3P`28R8P0OGem0820P01nOWh0N7Qh
08B4Q01nOWh0OGem08:2PP1gMgL207QhN00F07YjNP1hN7P0OGem08B4Q01nOWh0N7Qh07=cL`1jNWX0
PX:208>3P`1dM7@0Q8B407AdM021PH40MWIf07QhN01kNg/0OGem07UiN@1cLg<0M7Ad07UiN@80MGEe
02X0LG5a079bLP1fMWH0NGUi07IfMP1^KVh0MWIf06a/K01bLW80NGUi071`L01gMgL0Kfm_06a/K01a
LG40Kfm_06][J`1hN7P0KVi^079bLP1]KFd0LG5a06a/K01eMGD0M7Ad06YZJP1_Kfl0KVi^06m_K`1[
Jf/0IFEU06ATI01VIVH0JVYZ06EUI@1SHf<0J6QX06UYJ@1QHF40HV9R061PH01VIVH206YZJP0=06MW
I`1/K6`0IVIV06][J`1SHf<0GemO06a/K01QHF40I6AT05iNGP1SHf<0G5aL061PH00206EUI@0D06AT
I01UIFD0I6AT061PH01WIfL0HF5Q061PH01RHV80Fe]K06ATI01WIfL0GEeM05QHF01WIfL0HF5Q05QH
F01SHf<0HV9R065QH@1LG5`2065QH@0<05]KF`1TI6@0HF5Q061PH01GEeL0EUIF05iNGP1MGEd0GUiN
05ADE01FEUH0GEeM0P1NGUh0101DE5@0GEeM05]KF`1JFUX60=WIf@4000000@3IfMT001H0fMWI00<0
00000=WIf@3IfMT00`3IfMT0@P1PH600G5aL065QH@1IFET0H61P05eMG@1SHf<0HV9R05iNGP1PH600
IfMW05eMG@1SHf<0GUiN05eMG@1TI6@0JFUY065QH@1TI6@0H61P065QH@1IFET0HF5Q069RHP1TI6@0
FUYJ06MWI`1UIFD0Hf=S061PH01TI6@0Hf=S061PH01QHF40IFEU069RHP1SHf<0HV9R05iNGP1HF5P0
GemO06=SH`1UIFD0GEeM05iNGP1SHf<0H61P065QH@1NGUh0JVYZ05mOG`1TI6@0IFEU06UYJ@1RHV80
I6AT06a/K01SHf<0J6QX06EUI@1RHV80K6a/06QXJ01QHF40JFUY065QH@80IVIV02@0J6QX06EUI@1U
IFD0Hf=S06UYJ@1VIVH0L71`06MWI`1ZJVX0HF5Q06ATI01WIfL0Jf][06YZJP1VIVH0JFUY06m_K`1b
LW80KFe]075aL@1YJFT0Kfm_06a/K01YJFT0J6QX06EUI@1[Jf/0LG5a06MWI`1[Jf/0KFe]06EUI@1a
LG40JVYZ06QXJ01^KVh206m_K`0;079bLP1gMgL0Kfm_06YZJP1dM7@0KVi^06m_K`1`L700N7Qh071`
L01ZJVX00P1_Kfl0701/K6`0LW9b07IfMP1bLW80M7Ad07=cL`1hN7P0LW9b07emO@1bLW80M7Ad07Ui
N@1bLW80MGEe079bLP1iNGT0MGEe07UiN@1lO7`0N7Qh07inOP1iNGT0N7Qh07IfMP1eMGD0Ogmo07]k
N`1nOWh207]kN`0G07AdM01mOGd0LW9b07MgM`22PX80OGem07EeM@1fMWH0Ph>307UiN@1jNWX0PH61
07emO@20P800OGem0861P@1iNGT0Ogmo08B4Q028R8P0OWin07emO@26QXH00P1oOgl01@1lO7`0Ng]k
07emO@20P800Q8B40080P82000H0PX:207alO023Ph<0O7al08J6QP24Q8@207emO@0A07AdM01lO7`0
Ng]k07YjNP1kNg/0OGem07YjNP1kNg/0QHF507UiN@20P800Ogmo07=cL`1`L700NWYj07MgM`1kNg/0
0P1eMGD00`1jNWX0M7Ad079bLP0207MgM`0607EeM@1hN7P0Lg=c071`L01nOWh0MWIf0P1jNWX03@1f
MWH0LG5a07IfMP1cLg<0L71`075aL@1fMWH0L71`06i^KP1bLW80Kfm_06YZJP1dM7@00P1[Jf/04@1_
Kfl0LW9b06QXJ01`L700Kfm_06QXJ01ZJVX0KVi^06MWI`1^KVh0IfMW06a/K01YJFT0Kfm_07EeM@1Q
HF40IFEU0080IfMW02h0LG5a06QXJ01PH600IFEU06IVIP1LG5`0IVIV06YZJP1TI6@0H61P06IVIP1X
J6P0I6AT061PH01XJ6P0Hf=S06MWI`1RHV80GemO061PH01JFUX0GUiN05UIF@1SHf<0HF5Q06IVIP1P
H600I6AT069RHP1KFe/0GUiN05MGE`1KFe/0HV9R06MWI`1LG5`0GEeM05YJFP1OGel0EUIF05mOG`1M
GEd0I6AT05aLG01OGel0EeMG0P1KFe/02`1IFET0Fe]K05iNGP1JFUX0H61P069RHP1IFET0GUiN05MG
E`1FEUH0I6AT00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0R05iNGP1K
Fe/0HF5Q05iNGP1TI6@0G5aL05eMG@1RHV80I6AT065QH@1TI6@0H61P06IVIP1PH600Hf=S065QH@1T
I6@0Hf=S06MWI`1PH600IVIV05mOG`1KFe/0I6AT069RHP1SHf<0H61P069RHP1IFET0IFEU05mOG`1P
H600IVIV06ATI080H61P00H0GEeM05UIF@1RHV80Hf=S065QH@1IFET206EUI@0G06MWI`1LG5`0I6AT
06IVIP1QHF40JVYZ06m_K`1OGel0FUYJ06IVIP1UIFD0JFUY06e]K@1XJ6P0GemO06MWI`1XJ6P0HV9R
06MWI`1UIFD0Jf][06=SH`1QHF400P1SHf<05P1UIFD0Kfm_06MWI`1WIfL0J6QX06EUI@1^KVh0KFe]
06YZJP1YJFT0KVi^06ATI01cLg<0IfMW05iNGP1^KVh0K6a/06UYJ@1[Jf/0Kfm_06a/K01QHF4206QX
J00E06MWI`1ZJVX0Kfm_06IVIP1cLg<0J6QX06m_K`1XJ6P0KFe]079bLP1`L700K6a/06YZJP1bLW80
J6QX079bLP1cLg<0N7Qh079bLP1[Jf/0Kfm_0080KVi^0340Lg=c06m_K`1ZJVX0L71`07=cL`1/K6`0
JVYZ07IfMP1kNg/0Lg=c07EeM@1dM7@0MWIf07AdM01bLW80MGEe07IfMP1iNGT0O7al07YjNP1mOGd0
P82007UiN@1fMWH0MgMg07QhN01lO7`0NGUi07AdM01oOgl0P82007moO`20P800NGUi08F5Q@1bLW80
NGUi07moO`1cLg<0OGem07IfMP1jNWX0Ogmo0861P@26QXH0PH6107inOP1iNGT0PX:20080O7al00L0
OWin08>3P`20P800O7al07moO`21PH40Ng]k00<0OWin0100QXJ608F5Q@25QHD0Ph>307YjNP1hN7P0
QHF50820P023Ph<0O7al0820P01iNGT0Ogmo07UiN@1hN7P0MgMg0P1lO7`04`1nOWh0N7Qh07QhN01k
Ng/0Ogmo07emO@22PX80O7al07moO`1jNWX0MWIf07]kN`1mOGd0LG5a07YjNP1hN7P0PX:207=cL`1k
Ng/00P1gMgL0901dM7@0Lg=c079bLP1bLW80NWYj075aL@1dM7@0MgMg075aL@1cLg<0MWIf06e]K@1b
LW80MGEe06i^KP1cLg<0KFe]075aL@1/K6`0Lg=c075aL@1TI6@0KFe]06i^KP1VIVH0Hf=S06UYJ@1T
I6@0K6a/06EUI@1WIfL0Jf][06a/K01`L700LG5a06QXJ080Jf][00@0IVIV06QXJ01YJFT0IFEU0P1[
Jf/0401WIfL0Kfm_06UYJ@1WIfL0H61P06YZJP1NGUh0GemO06QXJ01TI6@0H61P06EUI@1NGUh0IfMW
06IVIP1QHF4205]KF`0405aLG01RHV80IVIV05UIF@80GEeM01@0GemO069RHP1PH600HV9R061PH01U
IFD0H61P05]KF`1PH600I6AT05aLG01KFe/0FEUI05]KF`1PH600Fe]K06UYJ@1SHf<0GEeM051@D080
G5aL00@0GEeM05iNGP1JFUX0EEEE0P1LG5`00`1OGel0GEeM0=WIf@050=WIf@4000000@3IfMT001H0
fMWI0P0000040=WIf@80H61P00D0GEeM05iNGP1RHV80GEeM06IVIP0205mOG`06061PH01UIFD0G5aL
061PH01TI6@0Hf=S0P1OGel0401NGUh0GEeM05mOG`1QHF40IfMW069RHP1QHF40Jf][061PH01SHf<0
FUYJ065QH@1VIVH0HV9R05mOG`1TI6@3065QH@80IFEU00X0JFUY06IVIP1TI6@0I6AT069RHP1LG5`0
IfMW06QXJ01QHF40IFEU0P1QHF40501ZJVX0IVIV06EUI@1SHf<0IfMW06UYJ@1TI6@0IFEU069RHP1U
IFD0HV9R06QXJ01ZJVX0HV9R06UYJ@1UIFD0Jf][071`L01WIfL0KFe]0P1YJFT01P1UIFD0IVIV07Ad
M01bLW80Jf][065QH@80J6QX00l0JFUY06QXJ01WIfL0KFe]06QXJ01]KFd0IVIV06UYJ@1UIFD0Jf][
071`L01_Kfl0JFUY07EeM@1aLG400P1_Kfl01P1YJFT0Kfm_06m_K`1VIVH0LG5a06IVIP80Kfm_01X0
JVYZ075aL@1[Jf/0Lg=c075aL@1YJFT0Kfm_07EeM@1YJFT0LW9b075aL@1gMgL0LW9b07AdM01oOgl0
MWIf07MgM`1^KVh0NGUi07MgM`1^KVh0Lg=c07YjNP1dM7@0MGEe07IfMP80NWYj00X0MGEe07QhN01i
NGT0O7al07YjNP1aLG40NWYj07]kN`1hN7P0O7al0P1oOgl02@1lO7`0OGem07inOP1lO7`0Ng]k08>3
P`1iNGT0Ng]k07alO00207inOP0307moO`22PX80Q8B40080P8200140OWin0820P01kNg/0Ogmo07Mg
M`1oOgl0QHF507moO`1nOWh0PX:208J6QP1nOWh0QHF508Z:RP25QHD0OGem0820P00207alO00>07mo
O`20P800Ogmo07inOP1lO7`0PH610820P01hN7P0NWYj07UiN@1nOWh0OGem07moO`1fMWH207]kN`0=
07emO@21PH40MWIf07UiN@1kNg/0O7al07]kN`1lO7`0Ng]k07EeM@1lO7`0N7Qh07]kN`0207=cL`0C
07MgM`1lO7`0NWYj075aL@1jNWX0N7Qh07IfMP1bLW80LG5a07AdM01eMGD0Lg=c07EeM@1`L700LG5a
07=cL`1hN7P0KFe]07QhN00207AdM00M071`L01aLG40LW9b07AdM01bLW80K6a/06][J`1dM7@0JVYZ
06e]K@1ZJVX0KFe]06YZJP1[Jf/0L71`06ATI01aLG40Kfm_06i^KP1[Jf/0KFe]06ATI01XJ6P0IVIV
06e]K@1UIFD0IfMW06ATI01VIVH00P1SHf<0301/K6`0IfMW06ATI01OGel0IfMW06=SH`1TI6@0Hf=S
061PH01YJFT0GUiN06EUI@80HV9R02D0GEeM05mOG`1TI6@0IFEU05iNGP1PH600GUiN06=SH`1NGUh0
I6AT061PH01LG5`0GemO05YJFP1QHF40HV9R05iNGP1PH600G5aL05eMG@1SHf<0GUiN05mOG`1JFUX0
HF5Q05mOG`1MGEd0GUiN05YJFP1PH600FEUI05iNGP1TI6@0FEUI05eMG@1RHV80GUiN00D0fMWI0P00
00010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@09061PH01RHV80H61P05mOG`1QHF40GemO
05aLG01IFET0H61P0080FUYJ0200K6a/06ATI01OGel0G5aL065QH@1PH600I6AT06=SH`1VIVH0I6AT
06EUI@1MGEd0GemO06=SH`1OGel0H61P05QHF01TI6@0Hf=S069RHP1]KFd0GUiN06=SH`1[Jf/0GUiN
069RHP1QHF40Jf][061PH01WIfL0HV9R065QH@80HV9R00H0GemO061PH01OGel0IVIV05mOG`1YJFT2
06ATI00>06=SH`1UIFD0HF5Q06EUI@1QHF40IVIV071`L01VIVH0LG5a065QH@1MGEd0K6a/06IVIP1[
Jf/206YZJP0=06UYJ@1^KVh0H61P06e]K@1YJFT0HV9R06EUI@1WIfL0Hf=S06QXJ01ZJVX0Jf][06e]
K@02075aL@80Hf=S03<0J6QX06a/K01/K6`0K6a/06][J`1]KFd0L71`06][J`1_Kfl0KFe]075aL@1/
K6`0JVYZ06IVIP1aLG40LW9b06IVIP1]KFd0Kfm_079bLP1`L700K6a/06e]K@1/K6`0KVi^071`L01c
Lg<0Kfm_06][J`1/K6`0M7Ad06e]K@1kNg/0Kfm_07]kN`1fMWH0MgMg06m_K`1cLg<0MgMg079bLP1i
NGT0O7al07IfMP1gMgL0KFe]07EeM@1oOgl0Ng]k075aL@1jNWX00P1fMWH01@1lO7`0MgMg07QhN01h
N7P0NGUi0080P82000H0OGem07]kN`1gMgL0N7Qh07inOP1kNg/207alO00707YjNP20P800O7al0861
P@1kNg/0NWYj08:2PP0207moO`0_07alO026QXH0N7Qh07emO@1nOWh0QXJ608N7Q`1jNWX0Ogmo08>3
P`1oOgl0P82008N7Q`1lO7`0NGUi0861P@1kNg/0RHV907emO@1kNg/0NWYj07]kN`1mOGd0O7al07]k
N`23Ph<0Ng]k07IfMP1lO7`0NWYj0861P@20P800O7al07moO`20P800NWYj07moO`1iNGT0OGem07Ui
N@1kNg/0Ogmo07emO@1hN7P0O7al07MgM`1jNWX00P1kNg/0201bLW80NWYj07UiN@1fMWH0N7Qh07Ad
M01cLg<0M7Ad0P1_Kfl06@1hN7P0LG5a06UYJ@1`L700LW9b06m_K`1bLW80L71`06e]K@1XJ6P0JFUY
07AdM01`L700JFUY06][J`1cLg<0LG5a06MWI`1/K6`0IfMW06EUI@1`L700Kfm_06YZJP1WIfL00P1/
K6`04`1_Kfl0MgMg06a/K01`L700J6QX06EUI@1SHf<0JFUY06EUI@1]KFd0IVIV06EUI@1[Jf/0IfMW
069RHP1MGEd0IFEU06][J`1KFe/00P1TI6@0;01UIFD0HV9R05mOG`1XJ6P0JVYZ05mOG`1NGUh0GemO
06EUI@1LG5`0IfMW05eMG@1QHF40Fe]K06YZJP1QHF40IFEU05mOG`1TI6@0F5QH05]KF`1NGUh0G5aL
05YJFP1LG5`0GEeM069RHP1PH600HF5Q069RHP1QHF40GemO05iNGP1SHf<0H61P05aLG01SHf<0EeMG
061PH01KFe/0GemO061PH01MGEd0G5aL1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI
00<0fMWI01/0GEeM05mOG`1UIFD0H61P05iNGP1TI6@0H61P05iNGP1YJFT0GUiN06MWI`1TI6@0GemO
065QH@1NGUh0HV9R06EUI@1NGUh0GemO06QXJ01MGEd0GemO05iNGP1VIVH0GemO069RHP1JFUX00P1N
GUh0501OGel0IfMW06MWI`1MGEd0GUiN06EUI@1PH600G5aL061PH01RHV80Jf][061PH01NGUh0H61P
069RHP1NGUh0Hf=S069RHP1OGel0FEUI0P1WIfL01`1QHF40IVIV069RHP1PH600HF5Q06EUI@1[Jf/0
0P1PH6002P1SHf<0Jf][06YZJP1[Jf/0K6a/06MWI`1VIVH0J6QX06=SH`1YJFT206][J`0@06m_K`1Z
JVX0KVi^06a/K01ZJVX0IVIV06YZJP1^KVh0KFe]06UYJ@1TI6@0Lg=c06UYJ@1aLG40Jf][06YZJP80
Jf][00D0K6a/079bLP1cLg<0Lg=c06YZJP0206UYJ@0?06IVIP1]KFd0KVi^06][J`1aLG40JVYZ06QX
J01dM7@0Lg=c07IfMP1`L700MWIf07EeM@1^KVh0L71`0080MWIf00<0MGEe071`L01YJFT00P1gMgL0
5P1dM7@0Kfm_07EeM@1iNGT0KFe]07MgM`1dM7@0N7Qh07UiN@1dM7@0MgMg07QhN01gMgL0MWIf07al
O01jNWX0O7al07]kN`1oOgl0MgMg075aL@1hN7P207]kN`0H08>3P`1nOWh0M7Ad07moO`1kNg/0QXJ6
07alO01kNg/0Ph>307moO`22PX80MGEe0820P022PX80PH6107moO`1iNGT0Q8B408:2PP21PH40P820
07moO`24Q8@0PX:20`26QXH04@29RHT0OWin0820P01nOWh0Q8B40861P@1lO7`0OGem0861P@20P800
PX:208>3P`1jNWX0P82008:2PP20P800Ph>30080P82001<0O7al07inOP21PH40Ng]k0820P022PX80
MGEe07YjNP20P800NGUi07MgM`1eMGD0QHF507moO`1hN7P0Ogmo07UiN@1nOWh0P8200080NWYj01X0
L71`07MgM`1iNGT0OWin07MgM`1bLW80N7Qh079bLP1hN7P0M7Ad07EeM@1iNGT0LG5a07UiN@1aLG40
MWIf07MgM`1fMWH0N7Qh07YjNP1fMWH0M7Ad07]kN`1]KFd0Lg=c06YZJP<0Kfm_00@0KFe]06YZJP1`
L700KFe]0`1YJFT0<`1SHf<0LG5a06m_K`1VIVH0KVi^06a/K01TI6@0M7Ad06MWI`1XJ6P0K6a/06MW
I`1^KVh0Jf][06QXJ01VIVH0IFEU06a/K01VIVH0JVYZ065QH@1XJ6P0Fe]K065QH@1OGel0H61P065Q
H@1NGUh0IfMW065QH@1WIfL0J6QX069RHP1PH600Hf=S05QHF01WIfL0GemO05UIF@1QHF40G5aL05mO
G`1RHV80Fe]K06=SH`1JFUX0GEeM055AD@1MGEd0Hf=S069RHP0205aLG00?069RHP1IFET0E5AD05mO
G`1QHF40GUiN065QH@1LG5`0Fe]K05aLG01PH600Fe]K061PH01LG5`0GemO00H0fMWI0@0000010=WI
f@005P3IfMT00`000000fMWI0=WIf@030=WIf@0J05aLG01NGUh0E5AD065QH@1WIfL0G5aL069RHP1O
Gel0IFEU06IVIP1XJ6P0Fe]K06EUI@1JFUX0G5aL069RHP1PH600HV9R05UIF@1RHV80Fe]K05YJFP1G
EeL0H61P05]KF`1JFUX206=SH`0306ATI01ZJVX0KFe]0080G5aL00d0HF5Q061PH01SHf<0I6AT065Q
H@1RHV80IVIV065QH@1KFe/0HF5Q06EUI@1XJ6P0GemO0080HF5Q00@0IVIV06=SH`1WIfL0HF5Q0P1W
IfL04@1[Jf/0HF5Q06QXJ01/K6`0LG5a06IVIP1UIFD0J6QX05iNGP1YJFT0HV9R06YZJP1[Jf/0GEeM
06QXJ01OGel0IfMW0080JFUY00L0KFe]06m_K`1`L700Kfm_06MWI`1[Jf/0IfMW0080KFe]00P0JVYZ
06IVIP1^KVh0KFe]071`L01SHf<0L71`06YZJP80Jf][00T0Lg=c06i^KP1/K6`0Jf][06e]K@1aLG40
Jf][075aL@1_Kfl00P1^KVh06P1eMGD0NGUi07=cL`1dM7@0LW9b07EeM@1hN7P0LG5a07YjNP1fMWH0
LW9b071`L01cLg<0LG5a07QhN01bLW80N7Qh07AdM01`L700LG5a07QhN01cLg<0N7Qh071`L01hN7P0
MgMg0P1jNWX207QhN00?07]kN`1jNWX0NGUi07UiN@1kNg/0NWYj07UiN@25QHD0NGUi07moO`24Q8@0
OWin0861P@1fMWH0PX:20080Ph>30`1oOgl0101jNWX0Ph>307inOP1kNg/207inOP0307]kN`1oOgl0
QHF50080QHF500@0P82008B4Q021PH40P8200P23Ph<0201iNGT0PH6108:2PP27QhL0OGem0820P023
Ph<0QhN70P1oOgl08@29RHT0Ph>307MgM`22PX80QHF507inOP1lO7`0PH6108B4Q01lO7`0PH6107Ad
M01oOgl0Ph>307inOP20P800QhN70820P01nOWh0NGUi07emO@1kNg/0OWin07alO01jNWX0MgMg07=c
L`1bLW80Ogmo07inOP1lO7`0Ng]k07inOP0207IfMP0>07YjNP21PH40M7Ad07MgM`1bLW80M7Ad07mo
O`1`L700OGem07UiN@1nOWh0O7al0820P01gMgL206i^KP07079bLP1dM7@0LG5a06m_K`1WIfL0J6QX
06e]K@0206i^KP04071`L01_Kfl0J6QX06a/K080JVYZ00@0MGEe079bLP1`L700LG5a0P1]KFd00`1Z
JVX0IVIV06UYJ@0206QXJ00B05mOG`1ZJVX0KFe]05eMG@1WIfL0J6QX06MWI`1OGel0IFEU05iNGP1W
IfL0HV9R06EUI@1NGUh0IFEU061PH01NGUh0HV9R0P1MGEd02@1RHV80G5aL069RHP1TI6@0HV9R061P
H01[Jf/0H61P05mOG`0305YJFP80I6AT0P1SHf<02P1UIFD0IVIV06EUI@1DE5@0Hf=S05iNGP1WIfL0
GEeM06IVIP1MGEd205aLG00905UIF@1JFUX0Fe]K05eMG@1YJFT0EeMG05iNGP1OGel0GEeM00H0fMWI
0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0C05mOG`1NGUh0GEeM05aLG01KFe/0
GEeM06EUI@1QHF40GUiN06EUI@1NGUh0Hf=S069RHP1NGUh0GEeM065QH@1KFe/0FEUI05YJFP02069R
HP0<065QH@1NGUh0GemO05]KF`1RHV80IFEU069RHP1SHf<0GemO069RHP1QHF40Hf=S0P1PH6006@1M
GEd0IVIV05]KF`1SHf<0HF5Q06EUI@1VIVH0HF5Q05mOG`1TI6@0Hf=S069RHP1OGel0H61P06=SH`1P
H600HV9R05iNGP1QHF40GemO06UYJ@1WIfL0M7Ad06a/K01YJFT00P1XJ6P0201VIVH0Jf][06IVIP1U
IFD0Jf][06IVIP1[Jf/0J6QX0P1VIVH02P1XJ6P0Hf=S06MWI`1fMWH0KFe]06IVIP1_Kfl0Hf=S06a/
K01ZJVX206a/K008071`L01UIFD0KFe]06YZJP1/K6`0KFe]06EUI@1_Kfl206e]K@0406a/K01`L700
KVi^06i^KP80L71`0240Jf][079bLP1^KVh0MgMg07IfMP1dM7@0MgMg07EeM@1_Kfl0NWYj07emO@1k
Ng/0Lg=c071`L01^KVh0LG5a07IfMP1hN7P0NWYj07EeM@1cLg<0LG5a07=cL`1bLW80NWYj07]kN`1d
M7@0NGUi07moO`1dM7@0PH6107]kN`1jNWX00P1gMgL0201hN7P0P82007IfMP1jNWX0Q8B407moO`1j
NWX0OWin0`1oOgl07@1iNGT0P82008:2PP1nOWh0PX:207YjNP2<S8`0OGem07]kN`1oOgl0Q8B408R8
R01nOWh0QHF507emO@2;Rh/0P82008>3P`25QHD0PH6107YjNP1gMgL0QXJ607alO023Ph<0Ogmo08N7
Q`2:RXX0PH6100<0Ph>301h0R8R808:2PP24Q8@0QXJ608:2PP1mOGd0Ogmo0820P01gMgL0O7al08>3
P`22PX80Ogmo07MgM`1kNg/0Ogmo07MgM`20P800QHF507]kN`22PX80NGUi07MgM`1jNWX0NGUi07al
O023Ph<0NWYj07]kN`1lO7`20820P00K07emO@1gMgL0OWin07EeM@22PX80N7Qh079bLP1iNGT0MGEe
07QhN01cLg<0NGUi07inOP1mOGd0Q8B408J6QP1mOGd0NWYj07UiN@1_Kfl0Jf][06i^KP1dM7@0MgMg
071`L01[Jf/0JFUY0080Kfm_00@0LW9b075aL@1^KVh0JVYZ0P1YJFT02@1ZJVX0Kfm_06i^KP1^KVh0
JFUY06QXJ01`L700JVYZ06QXJ00206IVIP0:06=SH`1RHV80K6a/05mOG`1WIfL0HF5Q069RHP1YJFT0
I6AT06a/K080Hf=S00/0IfMW06=SH`1TI6@0IfMW05aLG01TI6@0IFEU05iNGP1RHV80H61P065QH@02
069RHP0Q06EUI@1RHV80H61P05IFEP1QHF40GemO05aLG01KFe/0I6AT05]KF`1NGUh0IFEU061PH01Q
HF40GemO061PH01MGEd0EEEE05iNGP1KFe/0HV9R05iNGP1PH600GUiN06ATI01PH600GEeM06IVIP1I
FET0Fe]K06ATI01FEUH0FUYJ00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WI
f@0Q069RHP1MGEd0Hf=S05eMG@1PH600HV9R06=SH`1TI6@0Fe]K06MWI`1RHV80IVIV05mOG`1IFET0
IVIV06=SH`1MGEd0HF5Q05YJFP1WIfL0G5aL05iNGP1LG5`0HF5Q069RHP1XJ6P0HV9R061PH01WIfL0
JVYZ06ATI01UIFD0HF5Q0080Hf=S00`0JFUY069RHP1LG5`0Fe]K06IVIP1SHf<0HV9R065QH@1KFe/0
GEeM061PH01SHf<206EUI@0<069RHP1WIfL0I6AT06ATI01PH600HF5Q06QXJ01WIfL0GUiN06QXJ01T
I6@0IFEU0P1XJ6P00`1]KFd0IFEU06=SH`0306ATI00906][J`1XJ6P0Jf][06IVIP1[Jf/0JFUY06e]
K@1ZJVX0Hf=S0080J6QX02<0K6a/06MWI`1XJ6P0L71`079bLP1_Kfl0K6a/06UYJ@1ZJVX0K6a/07If
MP1YJFT0LG5a06QXJ01/K6`0LW9b06m_K`1bLW80L71`06a/K01dM7@0KFe]079bLP1aLG40MWIf07Ee
M@1`L700JVYZ071`L01dM7@0P82007emO@1hN7P0OGem07EeM@0207MgM`0607AdM01cLg<0MGEe07Yj
NP1fMWH0P8200P1iNGT05P1hN7P0NWYj07alO01jNWX0N7Qh07]kN`1lO7`0NGUi08:2PP1gMgL0NGUi
07alO01oOgl0OWin07alO01kNg/0OGem0820P01mOGd0NWYj08>3P`1jNWX207moO`0H07]kN`1lO7`0
Ng]k08B4Q01mOGd0P82007moO`27QhL0Q8B407]kN`2:RXX0QXJ608:2PP1nOWh0Rh^;08>3P`1lO7`0
Q8B408F5Q@24Q8@0QHF508B4Q022PX80RHV90P25QHD03`1nOWh0Ogmo08N7Q`21PH40QHF50820P024
Q8@0Ph>308R8R01mOGd0PX:207IfMP1kNg/0N7Qh08B4Q00207emO@0=08>3P`1nOWh0OGem08:2PP1m
OGd0MGEe08>3P`1kNg/0NWYj08:2PP26QXH0P8200861P@0207inOP0K07emO@1kNg/0Ng]k07MgM`21
PH40M7Ad07UiN@1hN7P0MWIf07=cL`1iNGT0MWIf07=cL`1mOGd0PH6108J6QP2ATI40VIVI09RHV027
QhL0NWYj07alO01gMgL0MWIf07AdM01aLG40KFe]0080KVi^01H0MgMg075aL@1fMWH0IFEU06e]K@1Z
JVX0IFEU06][J`1]KFd0Kfm_06i^KP1/K6`0JFUY06m_K`1ZJVX0LW9b06EUI@1YJFT0IfMW06QXJ01_
Kfl0GEeM0P1RHV801`1UIFD0I6AT06EUI@1WIfL0JFUY06YZJP1XJ6P00`1TI6@08P1UIFD0J6QX06YZ
JP1JFUX0IVIV06UYJ@1PH600GEeM06EUI@1MGEd0GUiN05eMG@1JFUX0GemO05UIF@1OGel0FEUI069R
HP1JFUX0GemO05eMG@1NGUh0JVYZ061PH01LG5`0Fe]K05iNGP1KFe/0GemO05]KF`1OGel0GEeM05mO
G`1TI6@305eMG@0705aLG01IFET0GEeM06=SH`1DE5@0EEEE06=SH`060=WIf@4000000@3IfMT001H0
fMWI00<000000=WIf@3IfMT00`3IfMT0:`1OGel0H61P05iNGP1UIFD0I6AT05eMG@1JFUX0I6AT069R
HP1UIFD0GEeM05mOG`1KFe/0IfMW05aLG01UIFD0FUYJ06EUI@1NGUh0IFEU05QHF01OGel0I6AT065Q
H@1RHV80Hf=S07AdM01YJFT0L71`06e]K@1XJ6P0HV9R06IVIP1RHV80GEeM065QH@1PH600FUYJ05iN
GP1RHV80GemO06EUI@1OGel00P1SHf<05`1RHV80K6a/061PH01PH600HV9R06QXJ01UIFD0K6a/06YZ
JP1VIVH0JFUY065QH@1VIVH0JFUY06][J`1/K6`0H61P069RHP1WIfL0H61P06i^KP1YJFT0Hf=S0080
J6QX00H0K6a/07AdM01VIVH0IVIV071`L01/K6`206EUI@0C06m_K`1/K6`0LW9b06QXJ01`L700M7Ad
06ATI01]KFd0LG5a06][J`1`L700KFe]065QH@1cLg<0L71`06e]K@1/K6`0KFe]06][J`0206a/K007
07AdM01[Jf/0LG5a07EeM@1dM7@0Lg=c07MgM`0206m_K`0607AdM01hN7P0OGem07MgM`1eMGD0LW9b
0P1_Kfl0:`1fMWH0NWYj07MgM`1dM7@0MgMg07EeM@1lO7`0N7Qh07inOP1jNWX0M7Ad079bLP1iNGT0
MgMg07EeM@1iNGT0NWYj07UiN@1fMWH0Ng]k07UiN@1kNg/0Ogmo07EeM@23Ph<0N7Qh0820P01kNg/0
N7Qh0820P01lO7`0PX:20820P026QXH0NGUi08B4Q022PX80Ph>308N7Q`1mOGd0Rh^;08V9R@22PX80
0P27QhL0501oOgl0QXJ608V9R@20P800QhN708F5Q@27QhL0Q8B408Z:RP27QhL0QHF508:2PP28R8P0
PH6108B4Q02>SXh0Rh^;0820P02:RXX0PX:20P21PH401022PX80OWin08B4Q01iNGT208>3P`0808F5
Q@22PX80PH610861P@1iNGT0OWin07alO028R8P207UiN@0508B4Q021PH40MGEe07emO@20P8000P1n
OWh0301mOGd0R8R808F5Q@23Ph<0O7al07inOP1oOgl0MgMg07]kN`1gMgL0Ogmo07inOP80MgMg00T0
OGem0861P@2:RXX0Y:BT0:6QX@2DU9@0O7al07QhN01cLg<00P1aLG400`1iNGT0L71`06e]K@0207=c
L`0E06e]K@1dM7@0Jf][06m_K`1]KFd0K6a/07=cL`1ZJVX0K6a/06YZJP1]KFd0K6a/06QXJ01]KFd0
Jf][06e]K@1WIfL0LG5a06][J`1ZJVX0KFe]0080JFUY01l0IVIV06UYJ@1WIfL0I6AT06IVIP1QHF40
J6QX061PH01VIVH0GEeM06IVIP1SHf<0JFUY065QH@1NGUh0IVIV06][J`1QHF40H61P06IVIP1OGel0
G5aL05mOG`1PH600HF5Q06=SH`1RHV80Hf=S05iNGP1IFET0H61P00<0GEeM00T0GUiN05EEE@1MGEd0
FEUI06QXJ01NGUh0H61P06=SH`1PH6000P1IFET02P1LG5`0FUYJ069RHP1QHF40HV9R065QH@1HF5P0
I6AT05iNGP1PH6060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT00`1QHF40
EEEE061PH00205iNGP0B061PH01KFe/0Jf][061PH01IFET0H61P06QXJ01NGUh0IVIV06EUI@1TI6@0
Fe]K069RHP1SHf<0HV9R065QH@1JFUX0HV9R0P1WIfL05@1TI6@0J6QX06QXJ01`L700LG5a06YZJP1X
J6P0JVYZ06MWI`1SHf<0IVIV05mOG`1TI6@0IFEU06QXJ01OGel0GUiN05mOG`1SHf<0IfMW05iNGP02
06EUI@0_05mOG`1TI6@0JFUY06=SH`1YJFT0JVYZ06UYJ@1TI6@0KFe]06MWI`1SHf<0IfMW05mOG`1X
J6P0IfMW06e]K@1/K6`0IFEU06YZJP1YJFT0K6a/06=SH`1TI6@0Jf][06a/K01_Kfl0JFUY06EUI@1T
I6@0KVi^075aL@1bLW80Lg=c06m_K`1XJ6P0L71`079bLP1/K6`0Lg=c06a/K01WIfL0L71`075aL@1^
KVh0Lg=c06IVIP1`L7000P1_Kfl0201`L700Kfm_071`L01hN7P0LW9b075aL@1/K6`0MWIf0P1eMGD0
?P1`L700NWYj07QhN01]KFd0N7Qh075aL@1cLg<0O7al07IfMP1eMGD0LW9b07UiN@1cLg<0O7al07mo
O`1gMgL0Ng]k07EeM@1kNg/0PX:20861P@1lO7`0NWYj06i^KP1hN7P0NGUi07MgM`1nOWh0Q8B407in
OP1eMGD0NGUi07emO@1jNWX0O7al0820P023Ph<0P82007UiN@20P800PH6107inOP1mOGd0R8R807mo
O`21PH40SHf=07emO@1oOgl0QHF508B4Q01kNg/0Ogmo08B4Q025QHD0S8b<08J6QP24Q8@0Ogmo08f=
S@27QhL0OWin0P24Q8@05023Ph<0RHV908V9R@22PX80RHV90820P023Ph<0Q8B408:2PP23Ph<0PH61
08B4Q023Ph<0QXJ608:2PP23Ph<0QXJ607emO@22PX80QhN70P20P8004026QXH0NGUi08:2PP1mOGd0
Ogmo07YjNP1nOWh0NWYj08B4Q01oOgl0OGem07inOP1iNGT0P82007moO`1eMGD207UiN@0A07moO`28
R8P0O7al07alO01kNg/0MgMg07=cL`1kNg/0MWIf07alO01oOgl0RXZ:09bLW02JVYX0SXj>07IfMP1o
Ogl00P1eMGD05P1hN7P0MgMg06m_K`1WIfL0KVi^075aL@1cLg<0L71`07AdM01fMWH0Kfm_07=cL`1]
KFd0JFUY06IVIP1^KVh0L71`07MgM`1]KFd0KVi^06][J`1]KFd206UYJ@0;069RHP1/K6`0K6a/06UY
J@1XJ6P0KFe]06QXJ01]KFd0IFEU06][J`1WIfL00P1VIVH03@1UIFD0HV9R06YZJP1RHV80IFEU061P
H01SHf<0HV9R06IVIP1IFET0HF5Q05YJFP1XJ6P00P1TI6@0101MGEd0HV9R06IVIP1NGUh206=SH`0:
05UIF@1TI6@0Fe]K069RHP1OGel0IFEU065QH@1SHf<0Fe]K05iNGP80H61P00D0HV9R05MGE`1JFUX0
FUYJ05eMG@02069RHP0706=SH`1WIfL0H61P05eMG@1JFUX0FEUI05eMG@060=WIf@4000000@3IfMT0
01H0fMWI00<000000=WIf@3IfMT00`3IfMT02P1OGel0Fe]K05eMG@1NGUh0HF5Q061PH01OGel0HF5Q
05iNGP1UIFD2061PH0D0I6AT01T0IfMW06ATI01UIFD0Fe]K05aLG01OGel0EeMG06EUI@1[Jf/0KFe]
06i^KP1fMWH0NWYj06i^KP1QHF40JVYZ065QH@1VIVH0I6AT05mOG`1QHF40HV9R06ATI01QHF40H61P
0080HF5Q02@0HV9R065QH@1PH600KFe]06ATI01RHV80IfMW06EUI@1TI6@0IfMW06a/K01ZJVX0KFe]
06EUI@1XJ6P0JFUY06a/K01]KFd0Kfm_069RHP1/K6`0IfMW06YZJP1VIVH0JVYZ06][J`1QHF40Jf][
06EUI@1/K6`0JVYZ06m_K`1[Jf/0JVYZ07EeM@1aLG4206][J`0306m_K`1VIVH0L71`0080L71`02/0
LW9b06e]K@1`L700LG5a07QhN01ZJVX0KFe]07=cL`1/K6`0MGEe07AdM01eMGD0JFUY06YZJP1iNGT0
Kfm_07MgM`1]KFd0JVYZ079bLP1cLg<0LG5a07alO01hN7P0LW9b06m_K`1hN7P0Lg=c07IfMP1cLg<0
LW9b07QhN01kNg/0Lg=c07alO01nOWh0O7al07emO@1gMgL0N7Qh07IfMP1jNWX0O7al0080NGUi00L0
NWYj07emO@1iNGT0NGUi07inOP1mOGd0Ogmo0080PH610100OWin08:2PP1nOWh0QXJ607alO021PH40
Ogmo0820P02:RXX0Rh^;08R8R021PH40Ph>308F5Q@1nOWh0Ph>30P28R8P06029RHT0P82008N7Q`26
QXH0O7al08V9R@28R8P0OWin08R8R02;Rh/0Q8B407moO`21PH40QHF508J6QP2;Rh/0QHF508n?S`2>
SXh0RXZ:08N7Q`25QHD0Ph>308V9R@80Ph>300T0QXJ608F5Q@24Q8@0PX:207emO@24Q8@0PX:208V9
R@26QXH00P22PX809`28R8P0Q8B408R8R01iNGT0P82008B4Q01kNg/0OWin08>3P`1nOWh0QhN707Ui
N@1kNg/0PH6107YjNP24Q8@0M7Ad07MgM`1hN7P0Ng]k07YjNP1lO7`0MGEe07YjNP1oOgl0QHF50861
P@2:RXX0T92@07emO@1cLg<0OGem07UiN@1lO7`0Lg=c071`L01bLW80JFUY075aL@02079bLP0:071`
L01fMWH0Kfm_06m_K`1/K6`0KVi^06e]K@1dM7@0KVi^07=cL`80JVYZ0100Kfm_06e]K@1ZJVX0J6QX
06UYJ@1VIVH0Jf][06a/K01ZJVX0I6AT06IVIP1UIFD0IVIV06MWI`1VIVH0JFUY0P1RHV80501WIfL0
Hf=S07IfMP1NGUh0FUYJ06QXJ01RHV80I6AT06=SH`1PH600IVIV05eMG@1UIFD0HF5Q06QXJ01TI6@0
G5aL05YJFP1RHV80GEeM0P1QHF400`1TI6@0HV9R05]KF`02065QH@0A05iNGP1OGel0HF5Q05mOG`1L
G5`0GUiN05mOG`1MGEd0HF5Q05YJFP1NGUh0I6AT05eMG@1NGUh0H61P05mOG`1QHF400P1OGel00`1P
H600fMWI0=WIf@040=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0101QHF40
GEeM06a/K01OGel4065QH@0805mOG`1UIFD0JVYZ05mOG`1RHV80HF5Q06=SH`1UIFD206][J`0D061P
H01MGEd0G5aL06=SH`1TI6@0IFEU06MWI`1YJFT0Hf=S06MWI`1fMWH0NWYj07=cL`1[Jf/0Kfm_065Q
H@1UIFD0JFUY069RHP1XJ6P2069RHP0906=SH`1OGel0Hf=S06=SH`1WIfL0HV9R06UYJ@1VIVH0G5aL
0080Hf=S0280HF5Q05iNGP1ZJVX0Jf][065QH@1YJFT0Jf][05iNGP1WIfL0Jf][06UYJ@1SHf<0JVYZ
06IVIP1SHf<0IVIV06UYJ@1TI6@0IVIV06UYJ@1ZJVX0IFEU06][J`1_Kfl0GemO06YZJP1^KVh0KFe]
06][J`1ZJVX0KFe]071`L01^KVh0M7Ad0P1]KFd04P1ZJVX0KVi^06m_K`1^KVh0L71`07alO01/K6`0
Kfm_071`L01ZJVX0Kfm_06UYJ@1eMGD0L71`07IfMP1[Jf/0N7Qh07AdM080LG5a00L0KVi^07IfMP1`
L700NWYj07inOP1oOgl0MWIf0080N7Qh01d0MgMg07QhN01cLg<0NGUi0820P01iNGT0OWin0861P@1k
Ng/0N7Qh07UiN@23Ph<0MGEe0820P01hN7P0Ogmo08J6QP1hN7P0O7al07YjNP1bLW80Ph>30861P@20
P800R8R80820P021PH40QhN707alO00208:2PP0X07]kN`27QhL0QXJ608N7Q`21PH40S8b<08F5Q@24
Q8@0QhN708>3P`26QXH0R8R80820P01mOGd0RHV908^;R`27QhL0Rh^;07moO`22PX80QXJ608B4Q023
Ph<0Rh^;08R8R021PH40RHV908:2PP2;Rh/0RHV908f=S@27QhL0PX:208F5Q@2;Rh/0Ogmo08B4Q025
QHD0SXj>07inOP80Ph>300D0QHF507inOP22PX80QHF508>3P`0208F5Q@0<0820P028R8P0Ng]k08B4
Q029RHT0MgMg07inOP20P800NGUi07AdM021PH40MgMg0P1lO7`207]kN`0307MgM`1jNWX0NGUi0080
OGem0180P82007inOP1hN7P0P82008>3P`20P800RXZ:08:2PP1nOWh0MgMg07YjNP1oOgl0OGem07If
MP1`L700IfMW079bLP1fMWH307=cL`0306][J`1`L700KVi^0080KVi^00D0Kfm_06e]K@1YJFT0J6QX
07=cL`0206][J`0D06QXJ01^KVh0I6AT06UYJ@1XJ6P0JVYZ06MWI`1]KFd0KVi^06=SH`1RHV80JFUY
06][J`1WIfL0IFEU069RHP1TI6@0J6QX065QH@1NGUh206QXJ00;06ATI01RHV80I6AT069RHP1UIFD0
IVIV06EUI@1PH600GemO06EUI@1NGUh00P1KFe/01`1PH600GEeM05eMG@1KFe/0EeMG06ATI01RHV80
0P1LG5`0501NGUh0J6QX061PH01MGEd0HV9R05QHF01SHf<0GUiN06ATI01OGel0IfMW065QH@1LG5`0
FUYJ069RHP1MGEd0GemO06=SH`1MGEd0G5aL1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0
fMWI00<0fMWI00X0GUiN05YJFP1JFUX0FEUI06=SH`1JFUX0GemO069RHP1TI6@0JFUY0P1OGel02P1S
Hf<0HF5Q069RHP1YJFT0J6QX05iNGP1IFET0IFEU06=SH`1TI6@205iNGP0A061PH01XJ6P0J6QX06UY
J@1ZJVX0KVi^06UYJ@1VIVH0K6a/05aLG01OGel0IfMW05aLG01YJFT0H61P05mOG`1MGEd00P1LG5`0
4@1OGel0I6AT06][J`1RHV80K6a/06EUI@1^KVh0IfMW06a/K01WIfL0I6AT05iNGP1VIVH0IfMW06][
J`1YJFT0JVYZ0080IfMW03T0JVYZ06][J`1WIfL0IfMW065QH@1ZJVX0IVIV06i^KP1XJ6P0IFEU075a
L@1XJ6P0Jf][06a/K01XJ6P0LW9b06QXJ01dM7@0MgMg06m_K`1[Jf/0L71`06UYJ@1_Kfl0KVi^07Qh
N01/K6`0L71`079bLP1cLg<0LG5a07=cL`1aLG40MGEe07inOP1eMGD0L71`079bLP1eMGD0LW9b07=c
L`1dM7@0KVi^07=cL`1aLG40Kfm_079bLP1gMgL0NGUi079bLP1nOWh0Lg=c07MgM`1lO7`0P82007al
O01oOgl00P1hN7P04@1fMWH0P82007inOP1lO7`0OGem07YjNP1gMgL0R8R807]kN`1iNGT0PH6107Mg
M`23Ph<0O7al0820P01iNGT0OWin0080Ph>300L0PH6107inOP1mOGd0Ph>30861P@1lO7`0Q8B400<0
PH6103T0QXJ608V9R@22PX80PH6108F5Q@20P800Shn?08R8R01oOgl0S8b<0861P@2;Rh/0S8b<08N7
Q`2:RXX0QXJ608N7Q`2:RXX0QXJ608V9R@2:RXX0R8R808N7Q`2;Rh/0P82008R8R027QhL0S8b<08^;
R`2=SHd0Ph>308Z:RP29RHT0SXj>08>3P`1mOGd0QHF50861P@25QHD0Ng]k0861P@1lO7`0OWin0820
P027QhL0Ph>307moO`22PX80PH6107emO@1oOgl0O7al08V9R@24Q8@0NWYj07alO01oOgl00P24Q8@0
3021PH40PX:207MgM`1gMgL0OWin07emO@1hN7P0OGem08:2PP1mOGd0Ogmo07UiN@80Ogmo00P0P820
07UiN@1gMgL0MWIf07AdM01`L700MGEe06i^KP80Lg=c00l0M7Ad075aL@1_Kfl0LG5a06e]K@1eMGD0
LG5a079bLP1`L700JVYZ06m_K`1`L700J6QX06YZJP1]KFd00`1/K6`00`1_Kfl0IfMW06IVIP0206QX
J006069RHP1[Jf/0IfMW06EUI@1XJ6P0JVYZ0P1XJ6P01@1_Kfl0IfMW06UYJ@1YJFT0IVIV0080Hf=S
02/0Jf][06QXJ01]KFd0Hf=S06MWI`1]KFd0Hf=S05iNGP1LG5`0GEeM05MGE`1OGel0G5aL065QH@1K
Fe/0G5aL061PH01QHF40I6AT05mOG`1PH600GEeM065QH@1LG5`0HV9R06=SH`1OGel0Fe]K05UIF@1J
FUX0F5QH05eMG@1PH600HF5Q06=SH`1RHV80EeMG065QH@1SHf<0HF5Q05YJFP1GEeL0GUiN00H0fMWI
0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@80H61P0180G5aL061PH01GEeL0HV9R
05iNGP1LG5`0HF5Q069RHP1LG5`0HV9R05UIF@1JFUX0HV9R05YJFP1LG5`0I6AT06IVIP1TI6@206=S
H`0=065QH@1NGUh0GUiN06MWI`1[Jf/0HV9R065QH@1TI6@0IFEU061PH01SHf<0IfMW06=SH`0306EU
I@80HV9R00L0H61P06=SH`1MGEd0Hf=S069RHP1TI6@0IFEU0080JFUY00l0H61P06YZJP1/K6`0K6a/
06MWI`1OGel0HF5Q06MWI`1XJ6P0HV9R05mOG`1UIFD0JFUY06ATI01[Jf/00P1XJ6P03P1[Jf/0KFe]
06UYJ@1[Jf/0KVi^065QH@1YJFT0K6a/06YZJP1WIfL0J6QX06UYJ@1_Kfl0Jf][0P1`L7003`1cLg<0
I6AT06UYJ@1bLW80JVYZ07UiN@1[Jf/0JVYZ07AdM01aLG40MWIf07=cL`1jNWX0L71`07inOP02071`
L00606a/K01dM7@0LW9b06e]K@1_Kfl0NGUi0P1fMWH01@1iNGT0LG5a071`L01mOGd0MGEe0080N7Qh
00L0M7Ad07IfMP1hN7P0M7Ad07=cL`1iNGT0P8200080O7al01<0PX:207YjNP1mOGd0QHF507QhN01n
OWh0PX:208>3P`21PH40OWin08>3P`1nOWh0PH6108B4Q026QXH0O7al0820P023Ph<0QHF50080P820
01h0Ph>308B4Q027QhL0NWYj07inOP24Q8@0OGem08b<S023Ph<0QhN70820P02:RXX0QhN708^;R`22
PX80SXj>08:2PP28R8P0QXJ608F5Q@21PH40QhN708F5Q@2@T900RHV908J6QP1nOWh0Rh^;08V9R@27
QhL208F5Q@0>08V9R@2;Rh/0RHV90861P@2ATI40Ph>308Z:RP28R8P0Ph>308:2PP29RHT0OGem08>3
P`1nOWh208J6QP0408:2PP29RHT0P82007emO@80PX:200/0Ng]k07emO@26QXH0QhN70861P@1mOGd0
P82007QhN01jNWX0OGem08V9R@0207UiN@0E07]kN`20P800N7Qh07]kN`20P800MWIf07QhN01oOgl0
MgMg075aL@1bLW80MgMg07]kN`1^KVh0MWIf079bLP1iNGT0MWIf07UiN@1eMGD0MgMg0080KVi^02H0
L71`07AdM01aLG40Kfm_071`L01]KFd0IVIV07=cL`1bLW80I6AT06YZJP1[Jf/0IfMW06m_K`1aLG40
MGEe06i^KP1eMGD0KVi^06m_K`1XJ6P0JFUY06m_K`1YJFT0Jf][06YZJP1TI6@0KFe]06UYJ@1WIfL0
KVi^06][J`1NGUh0I6AT06IVIP1TI6@0H61P06=SH`80IFEU00<0IfMW06UYJ@1LG5`00P1OGel02`1H
F5P0IFEU069RHP1RHV80JVYZ061PH01YJFT0G5aL05eMG@1IFET0G5aL0080GEeM0100H61P05eMG@1N
GUh0FUYJ06QXJ01PH600HF5Q05mOG`1MGEd0Fe]K069RHP1PH600GUiN06EUI@1PH600IVIV0P1PH600
101HF5P0FUYJ05eMG@1MGEd60=WIf@4000000@3IfMT001H0fMWI0P0000040=WIf@0:05UIF@1OGel0
I6AT05eMG@1TI6@0FEUI05QHF01TI6@0Fe]K069RHP80GEeM01H0HF5Q06IVIP1QHF40FEUI065QH@1U
IFD0GUiN06=SH`1OGel0HV9R065QH@1MGEd0GUiN06IVIP1QHF40GemO071`L01RHV80Hf=S06MWI`1S
Hf<0JFUY0P1QHF40101PH600Hf=S05aLG01SHf<206QXJ00F069RHP1QHF40HV9R05iNGP1RHV80H61P
06IVIP1YJFT0Hf=S06][J`1WIfL0GEeM06ATI01SHf<0IVIV06MWI`1QHF40I6AT071`L01[Jf/0Q8B4
06i^KP80IFEU00d0Kfm_06MWI`1WIfL0MGEe06EUI@1NGUh0JFUY061PH01YJFT0IfMW06QXJ01ZJVX0
LG5a0080KFe]00X0Lg=c06m_K`1YJFT0LG5a079bLP1_Kfl0J6QX07EeM@1/K6`0KFe]0P1cLg<01P1_
Kfl0Lg=c07=cL`1nOWh0MgMg07UiN@80KVi^00D0LG5a07EeM@1dM7@0M7Ad07MgM`0207YjNP0?071`
L01aLG40MgMg07YjNP1fMWH0MgMg07]kN`1mOGd0Lg=c07inOP1iNGT0NWYj08:2PP1jNWX0N7Qh0080
Ng]k0P1mOGd01@21PH40PX:208>3P`24Q8@0PX:20080Q8B401H0OWin0820P01lO7`0PX:208J6QP29
RHT0QHF508B4Q020P800PX:207moO`1nOWh0Ph>308R8R027QhL0SXj>08Z:RP1oOgl0PH6108N7Q`28
R8P0RXZ:0P21PH403@29RHT0RXZ:0820P026QXH0TI6A08>3P`2;Rh/0RHV908N7Q`2;Rh/0QHF509>C
T`2<S8`00P26QXH02P28R8P0Q8B408V9R@2:RXX0SXj>08>3P`26QXH0RHV908J6QP2<S8`208J6QP0I
07inOP21PH40PH6108J6QP2:RXX0SHf=08:2PP21PH40OWin08Z:RP25QHD0QXJ608:2PP20P800PH61
08:2PP27QhL0NGUi07inOP1oOgl0P82007UiN@1oOgl0PH6107alO00208>3P`0407moO`1lO7`0MGEe
07alO080NWYj0P1fMWH0401lO7`0NGUi07alO01fMWH0OGem07QhN01`L700P82007IfMP1_Kfl0LG5a
07EeM@1dM7@0L71`06i^KP1aLG4206e]K@0307MgM`1cLg<0KFe]0080LG5a01`0KFe]07MgM`1/K6`0
IfMW06a/K01YJFT0KFe]06i^KP1]KFd0Jf][071`L01WIfL0K6a/06QXJ01SHf<0Kfm_06ATI01/K6`0
Jf][06m_K`1ZJVX0H61P06QXJ01PH600IFEU06IVIP1XJ6P0GemO0P1XJ6P06`1[Jf/0IFEU075aL@1J
FUX0Fe]K06IVIP1NGUh0IVIV06=SH`1JFUX0HV9R06EUI@1YJFT0HF5Q06QXJ01PH600G5aL06IVIP1Q
HF40IFEU069RHP1IFET0I6AT065QH@1MGEd0HV9R065QH@0205eMG@0305mOG`1PH600HF5Q0080GemO
00L0HF5Q05eMG@1NGUh0HF5Q05iNGP1MGEd0GUiN00D0fMWI0P0000010=WIf@005P3IfMT00`000000
fMWI0=WIf@030=WIf@05065QH@1MGEd0HF5Q05iNGP1XJ6P00P1NGUh01P1KFe/0HV9R05]KF`1PH600
IVIV061PH080GemO02T0HV9R05MGE`1MGEd0GUiN05eMG@1NGUh0HV9R06QXJ01WIfL0GemO06IVIP1[
Jf/0GUiN069RHP1QHF40I6AT069RHP1VIVH0HV9R06ATI01RHV80Hf=S06UYJ@1VIVH0H61P05]KF`1U
IFD0I6AT05eMG@1QHF40GEeM06YZJP1YJFT0J6QX06IVIP1YJFT0KVi^06e]K@1TI6@0J6QX06MWI`02
06EUI@0j06UYJ@1ZJVX0J6QX06YZJP1SHf<0J6QX06MWI`1YJFT0K6a/06MWI`1^KVh0IfMW06m_K`1Z
JVX0Jf][06YZJP1YJFT0MGEe06UYJ@1]KFd0Kfm_071`L01^KVh0LG5a06IVIP1cLg<0M7Ad06a/K01`
L700LG5a06QXJ01aLG40L71`075aL@1_Kfl0NGUi07QhN01aLG40KVi^07moO`1aLG40Lg=c071`L01h
N7P0MWIf07]kN`1RHV80P820079bLP1`L700MgMg07QhN01_Kfl0LW9b07AdM01aLG40OGem0861P@80
OGem00T0P82007=cL`1nOWh0P82007UiN@1jNWX0OGem08F5Q@1nOWh01021PH4208>3P`0<07inOP22
PX80PX:207alO02=SHd0R8R808>3P`21PH40PX:208B4Q023Ph<0QhN70P25QHD0:021PH40SXj>08N7
Q`21PH40RHV908f=S@27QhL0Ph>308^;R`2=SHd0R8R808f=S@2>SXh0S8b<08N7Q`29RHT0Rh^;08j>
SP29RHT0PX:208n?S`28R8P0SHf=08R8R023Ph<0S8b<09:BTP2<S8`0Ng]k08V9R@2:RXX0QHF508R8
R026QXH0Rh^;07inOP28R8P0Rh^;08F5Q@29RHT208N7Q`0M08R8R01lO7`0R8R807moO`25QHD0QhN7
07moO`27QhL0OGem08:2PP20P800QHF50861P@23Ph<0Ng]k08N7Q`20P800Ogmo07emO@20P800PX:2
08>3P`20P800O7al08F5Q@1kNg/0MgMg0820P01hN7P00P1nOWh01`1fMWH0MgMg07emO@1oOgl0NWYj
07UiN@1oOgl00P1fMWH01@1gMgL0M7Ad07MgM`1eMGD0L71`0080KVi^02H0Jf][071`L01_Kfl0LG5a
07EeM@1^KVh0LW9b071`L01[Jf/0KVi^06][J`1^KVh0Jf][06YZJP1^KVh0JVYZ07=cL`1YJFT0KFe]
071`L01/K6`0Kfm_06ATI01VIVH0K6a/06IVIP1WIfL0K6a/06MWI`1^KVh0J6QX06ATI01VIVH0K6a/
06e]K@1RHV80JVYZ06i^KP80JVYZ00/0I6AT06a/K01VIVH0HF5Q06ATI01RHV80HF5Q05iNGP1XJ6P0
Hf=S069RHP02061PH00G05mOG`1XJ6P0G5aL061PH01RHV80Hf=S05iNGP1UIFD0H61P065QH@1OGel0
GEeM06ATI01MGEd0HV9R05YJFP1TI6@0GemO065QH@1SHf<0HF5Q069RHP1NGUh00P1UIFD60=WIf@40
00000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT03@1OGel0FEUI065QH@1NGUh0HF5Q06=S
H`1GEeL0HF5Q05aLG01RHV80GEeM05iNGP1SHf<00P1OGel01`1UIFD0H61P05iNGP1TI6@0Hf=S06MW
I`1PH6000P1LG5`07P1RHV80HF5Q06IVIP1WIfL0Hf=S06MWI`1[Jf/0H61P069RHP1OGel0IFEU069R
HP1XJ6P0H61P05mOG`1RHV80IVIV06UYJ@1OGel0Kfm_06MWI`1/K6`0IFEU06ATI01RHV80IVIV06=S
H`1_Kfl0JFUY06YZJP80J6QX01<0KFe]06QXJ01WIfL0JFUY06IVIP1SHf<0JFUY07=cL`1WIfL0Jf][
079bLP1YJFT0Jf][06i^KP1[Jf/0LG5a06m_K`1ZJVX0IfMW0080Kfm_00H0L71`06e]K@1_Kfl0L71`
06m_K`1]KFd2075aL@0?06i^KP1eMGD0JVYZ06e]K@1eMGD0LG5a079bLP1eMGD0Lg=c06a/K01`L700
N7Qh06e]K@1gMgL0LW9b0080M7Ad01T0K6a/06][J`1`L700MgMg071`L01eMGD0LW9b07MgM`1eMGD0
Ng]k07moO`1hN7P0OWin07emO@1aLG40MWIf07UiN@1gMgL0Ogmo08:2PP1nOWh0Ng]k0861P@1gMgL0
O7al0080Ph>302H0PX:20861P@1oOgl0O7al08R8R01jNWX0QXJ60820P023Ph<0P82008:2PP26QXH0
QHF508N7Q`2=SHd0QHF508>3P`29RHT0Q8B408J6QP2:RXX0Shn?08^;R`25QHD0S8b<08V9R@27QhL0
RHV908b<S029RHT0Shn?08F5Q@2?Shl0RXZ:08n?S`2<S8`0TI6A08n?S`80RXZ:00l0R8R808f=S@2>
SXh0Ph>308b<S02CTi<0TI6A08V9R@2@T900PX:208Z:RP2=SHd0RXZ:08N7Q`25QHD00P2=SHd03@23
Ph<0Ogmo07alO02:RXX0Q8B408b<S023Ph<0PX:20820P01mOGd0PX:20861P@1mOGd00P25QHD01@24
Q8@0PX:20861P@20P800NWYj0080PH6100P0OGem07moO`1fMWH0OGem08J6QP1dM7@0Ogmo07QhN080
PH610P1jNWX0401fMWH0N7Qh07YjNP1nOWh0OGem07IfMP1oOgl0MgMg07IfMP1gMgL0O7al07AdM01e
MGD0NWYj06i^KP1bLW8207AdM00:07EeM@1^KVh0KFe]06e]K@1`L700M7Ad06][J`1^KVh0M7Ad075a
L@80JFUY0P1`L7002P1/K6`0LW9b06YZJP1/K6`0IfMW06EUI@1RHV80IVIV071`L01/K6`206QXJ00E
06a/K01[Jf/0J6QX06=SH`1WIfL0Jf][06EUI@1PH600I6AT06EUI@1[Jf/0J6QX069RHP1UIFD0IfMW
06ATI01SHf<0I6AT05iNGP1RHV80IFEU0080H61P01L0I6AT061PH01NGUh0HF5Q06ATI01SHf<0I6AT
05eMG@1SHf<0G5aL06IVIP1QHF40HV9R06EUI@1YJFT0HV9R06IVIP1TI6@0H61P05iNGP1RHV80GUiN
065QH@0205]KF`0306ATI01YJFT0fMWI00D0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WI
f@030=WIf@0>05iNGP1IFET0HV9R05aLG01IFET0HV9R05eMG@1KFe/0GUiN05mOG`1KFe/0GemO06EU
I@1VIVH305mOG`0>05eMG@1IFET0HV9R06=SH`1RHV80Hf=S065QH@1TI6@0IFEU05iNGP1VIVH0HF5Q
06ATI01QHF4206ATI00506IVIP1TI6@0GemO05iNGP1KFe/00P1RHV802@1OGel0GEeM05aLG01UIFD0
IfMW06QXJ01WIfL0IVIV06][J`0206MWI`0;06UYJ@1VIVH0Hf=S06EUI@1WIfL0JFUY06QXJ01VIVH0
JFUY06a/K01ZJVX00P1UIFD02P1XJ6P0IfMW06QXJ01[Jf/0LG5a071`L01^KVh0Lg=c06i^KP1]KFd2
06IVIP0S06e]K@1bLW80KVi^06UYJ@1_Kfl0JVYZ06UYJ@1^KVh0L71`075aL@1`L700LW9b06UYJ@1d
M7@0KVi^071`L01bLW80KFe]07]kN`1eMGD0NGUi07IfMP1cLg<0OGem07QhN01`L700Kfm_07EeM@1^
KVh0LG5a07IfMP1iNGT0Kfm_079bLP1fMWH00P1lO7`0201oOgl0N7Qh07QhN01iNGT0Ng]k07QhN01k
Ng/0MWIf0P1kNg/01027QhL0Ph>307YjNP1mOGd20861P@0O08>3P`1nOWh0Q8B407moO`22PX80OGem
0820P025QHD0OGem0861P@26QXH0Q8B408N7Q`29RHT0P82008N7Q`29RHT0Ph>30861P@2:RXX0QhN7
08R8R02ATI40SHf=08n?S`2;Rh/0S8b<08V9R@27QhL0Shn?08b<S00208^;R`80RHV90P27QhL00`28
R8P0TI6A09:BTP0209:BTP0?08f=S@2>SXh0QhN708R8R02:RXX0Rh^;08n?S`29RHT0TI6A08J6QP2C
Ti<0RHV9092@T02?Shl0Rh^;0080QXJ60100QhN708Z:RP1oOgl0S8b<08V9R@28R8P0Q8B408N7Q`25
QHD0RHV907moO`29RHT0QXJ608B4Q022PX80Q8B40P21PH403026QXH0OWin07IfMP1lO7`0Ph>308B4
Q01mOGd0MgMg07IfMP1gMgL0Ph>307UiN@80O7al01T0MgMg07YjNP1jNWX0NWYj07AdM01lO7`0L71`
075aL@1dM7@0QHF507QhN01fMWH0LG5a06i^KP1gMgL0N7Qh07=cL`1hN7P0L71`07UiN@1/K6`0MgMg
06e]K@1/K6`0LG5a0080Kfm_01H0KVi^06QXJ01]KFd0KVi^06UYJ@1]KFd0K6a/06][J`1]KFd0JVYZ
06IVIP1XJ6P0L71`06UYJ@1WIfL0IVIV06QXJ01/K6`0Jf][06IVIP1[Jf/0HV9R0P1[Jf/02P1QHF40
JVYZ06a/K01SHf<0IVIV06ATI01MGEd0IVIV05eMG@1PH60206EUI@0O06ATI01OGel0HV9R065QH@1S
Hf<0G5aL06UYJ@1SHf<0IVIV069RHP1TI6@0Hf=S05eMG@1NGUh0IFEU05]KF`1WIfL0IFEU06ATI01X
J6P0K6a/06=SH`1MGEd0Fe]K06ATI01RHV80G5aL069RHP1KFe/0GemO065QH@060=WIf@4000000@3I
fMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0201NGUh0I6AT061PH01TI6@0IVIV05QHF01NGUh0
EEEE0`1QHF40201VIVH0HV9R061PH01QHF40HV9R05iNGP1UIFD0I6AT0P1RHV802@1PH600HF5Q069R
HP1OGel0Fe]K05mOG`1RHV80IFEU05aLG002069RHP0505mOG`1XJ6P0GEeM06IVIP1LG5`00P1ZJVX0
2@1QHF40Hf=S06UYJ@1VIVH0I6AT069RHP1ZJVX0IfMW06IVIP0206MWI`0=06QXJ01ZJVX0LW9b06IV
IP1ZJVX0Jf][06QXJ01]KFd0IVIV06QXJ01ZJVX0J6QX06IVIP0206a/K00706=SH`1cLg<0M7Ad06EU
I@1/K6`0Lg=c06i^KP0206m_K`0D06YZJP1`L700JVYZ06m_K`1/K6`0JVYZ06m_K`1WIfL0KFe]071`
L01_Kfl0MWIf07=cL`1fMWH0M7Ad07=cL`1eMGD0KFe]071`L01gMgL207EeM@0]07QhN01cLg<0NWYj
07YjNP1aLG40Lg=c07IfMP1dM7@0N7Qh079bLP1iNGT0Lg=c07]kN`1`L700Lg=c07YjNP1iNGT0NWYj
07IfMP1gMgL0NGUi07alO01oOgl0NGUi07moO`1mOGd0O7al08B4Q01kNg/0NGUi08>3P`1nOWh0Ogmo
08R8R01lO7`0Ph>307inOP23Ph<0QXJ608B4Q021PH40Q8B408R8R027QhL0UIFE0080QHF500@0S8b<
08f=S@2;Rh/0PX:20P2<S8`208Z:RP0V09BDU02BTY80S8b<09:BTP2>SXh0Rh^;08f=S@2ATI40RXZ:
08^;R`25QHD0SHf=08V9R@24Q8@0SHf=08b<S02?Shl0QhN708f=S@26QXH0RHV908j>SP1oOgl0RXZ:
08J6QP2=SHd0S8b<08j>SP2?Shl0S8b<08F5Q@29RHT0SHf=096AT@22PX80QXJ608V9R@28R8P208f=
S@0?08N7Q`28R8P0SXj>08F5Q@1nOWh0SHf=08>3P`1oOgl0OWin08>3P`24Q8@0R8R807emO@2:RXX0
O7al0080P8200P21PH405P26QXH0Ogmo07UiN@1oOgl0LW9b07]kN`1eMGD0PH6107]kN`1mOGd0NWYj
07UiN@20P800Ng]k079bLP1iNGT0MgMg07=cL`1jNWX0NGUi06m_K`1hN7P207EeM@0307AdM01nOWh0
MgMg0080Lg=c00X0M7Ad07alO01`L700LG5a07=cL`1`L700KVi^075aL@1gMgL0Kfm_0P1VIVH05P1_
Kfl0MWIf06e]K@1bLW80L71`06e]K@1SHf<0Jf][06YZJP1[Jf/0L71`06a/K01UIFD0JFUY06i^KP1U
IFD0HV9R065QH@1SHf<0IFEU06YZJP1VIVH206MWI`0W06YZJP1YJFT0JFUY06=SH`1WIfL0HV9R06IV
IP1QHF40GUiN06IVIP1SHf<0I6AT061PH01YJFT0HF5Q05iNGP1LG5`0Hf=S06EUI@1TI6@0GemO06AT
I01OGel0H61P05]KF`1VIVH0HV9R06][J`1LG5`0IfMW06IVIP1JFUX0H61P05aLG01RHV80GemO06IV
IP1QHF40Fe]K00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0=05mOG`1H
F5P0GEeM06ATI01PH600GEeM05iNGP1JFUX0GemO05iNGP1RHV80JFUY05mOG`0205eMG@0B05iNGP1O
Gel0IFEU05mOG`1RHV80GEeM065QH@1SHf<0HF5Q05]KF`1VIVH0Kfm_05eMG@1OGel0Hf=S05mOG`1V
IVH0IfMW0P1IFET09P1TI6@0JFUY069RHP1QHF40IFEU05iNGP1aLG40GemO06IVIP1SHf<0IFEU065Q
H@1TI6@0IfMW06YZJP1aLG40L71`06MWI`1SHf<0JFUY07=cL`1OGel0IVIV065QH@1[Jf/0IVIV06YZ
JP1[Jf/0HF5Q06YZJP1YJFT0KFe]06UYJ@1^KVh0LW9b075aL@1YJFT0LG5a0P1_Kfl0401aLG40I6AT
06EUI@1_Kfl0L71`075aL@1[Jf/0KVi^075aL@1dM7@0NGUi06m_K`1dM7@0LG5a07EeM@1iNGT2075a
L@0707EeM@1lO7`0M7Ad07UiN@1fMWH0M7Ad07]kN`0207MgM`0=07QhN01cLg<0JVYZ071`L01mOGd0
M7Ad07]kN`1cLg<0Ng]k07alO01dM7@0NGUi07EeM@0207QhN00807emO@21PH40OGem07QhN01gMgL0
PX:20861P@1jNWX20820P00G07UiN@22PX80Q8B408>3P`20P800Q8B408f=S@20P800QHF508J6QP27
QhL0R8R808N7Q`24Q8@0S8b<0861P@24Q8@0Ph>3096AT@29RHT0Rh^;08Z:RP27QhL00P25QHD04P2<
S8`0QXJ608Z:RP2@T900RXZ:08F5Q@2=SHd0T92@08V9R@2:RXX0SXj>08f=S@29RHT0SXj>08n?S`2;
Rh/0UYJF092@T080QXJ600<0S8b<092@T02BTY800P2@T900302FUYH0RXZ:096AT@2=SHd0UIFE08f=
S@2;Rh/0RXZ:096AT@26QXH0SXj>08R8R080S8b<00D0R8R80861P@28R8P0S8b<08:2PP0208F5Q@0]
08:2PP2;Rh/0Ogmo07moO`20P800OGem08F5Q@21PH40P82007moO`24Q8@0Ogmo0861P@23Ph<0QHF5
08J6QP1kNg/0QXJ60861P@1oOgl0PH6107YjNP1eMGD0NWYj07inOP1mOGd0O7al07EeM@22PX80OWin
07=cL`1kNg/0Ogmo07MgM`1eMGD0NGUi07QhN01bLW80KVi^07]kN`1[Jf/0LW9b075aL@1fMWH0KFe]
0080L71`0180MWIf07EeM@1aLG40KVi^06MWI`1`L700IVIV06e]K@1WIfL0IFEU065QH@1aLG40IfMW
06m_K`1YJFT0K6a/06EUI@1XJ6P206MWI`80JFUY00T0HV9R06UYJ@1OGel0IfMW06IVIP1ZJVX0KFe]
065QH@1OGel00P1SHf<206ATI00?061PH01XJ6P0IVIV06IVIP1QHF40I6AT05eMG@1PH600HF5Q069R
HP1TI6@0Hf=S069RHP1SHf<0Fe]K0080HF5Q0140HV9R061PH01NGUh0Hf=S061PH01QHF40Hf=S065Q
H@1LG5`0Fe]K065QH@1OGel0IfMW06ATI01OGel0GUiN05eMG@060=WIf@4000000@3IfMT001H0fMWI
00<000000=WIf@3IfMT00`3IfMT00`1MGEd0F5QH05mOG`0205aLG00>05QHF01IFET0G5aL05iNGP1T
I6@0HF5Q061PH01QHF40GemO065QH@1TI6@0IfMW05IFEP1PH602065QH@0H05mOG`1WIfL0H61P05iN
GP1MGEd0Hf=S061PH01ZJVX0JFUY05iNGP1VIVH0HV9R06EUI@1QHF40J6QX06EUI@1QHF40G5aL06YZ
JP1PH600IFEU065QH@1PH600IfMW0P1XJ6P0101VIVH0JFUY06UYJ@1aLG4206MWI`0606][J`1bLW80
IFEU06QXJ01WIfL0J6QX0P1ZJVX01P1[Jf/0J6QX06][J`1`L700LG5a06MWI`80Jf][00/0JVYZ07Ee
M@1/K6`0JVYZ06ATI01bLW80L71`06a/K01eMGD0K6a/071`L002079bLP0;06e]K@1_Kfl0IVIV06m_
K`1aLG40Jf][07UiN@1_Kfl0MWIf07MgM`1aLG400P1eMGD05P1hN7P0MgMg07emO@1jNWX0MWIf06YZ
JP1bLW80LG5a079bLP22PX80OGem07alO020P800LG5a07emO@20P800O7al07YjNP1gMgL0O7al07Ee
M@20P8020861P@80OGem00l0Ogmo07inOP24Q8@0PX:208N7Q`22PX80Ph>308:2PP1nOWh0R8R80861
P@26QXH0R8R808B4Q029RHT00P24Q8@06022PX80QXJ608J6QP24Q8@0SXj>092@T027QhL0Rh^;08f=
S@24Q8@0TY:B08n?S`22PX80TY:B08^;R`2BTY80SXj>08J6QP2=SHd0UYJF08R8R025QHD0U9BD08V9
R@80Shn?01/0Rh^;09:BTP2?Shl0T92@08n?S`29RHT0TI6A09BDU02GUiL0V9RH08V9R@2ATI40RXZ:
096AT@2?Shl0Ti>C08n?S`2<S8`0TY:B09>CT`2EUID0S8b<08Z:RP29RHT0R8R808j>SP29RHT00P24
Q8@02`2;Rh/0QHF508>3P`26QXH0RXZ:08N7Q`28R8P0RHV908:2PP26QXH0Q8B40080PX:200X0OWin
0820P022PX80QHF50861P@23Ph<0NWYj07inOP27QhL0OGem0P1lO7`04P1nOWh0Ng]k07emO@1mOGd0
Ogmo07UiN@1jNWX0Ph>307MgM`1iNGT0Ng]k07MgM`1eMGD0NGUi07EeM@1cLg<0M7Ad07IfMP80MGEe
00H0LG5a07QhN01cLg<0KFe]07emO@1dM7@207EeM@0:079bLP1]KFd0Jf][071`L01XJ6P0LG5a06YZ
JP1aLG40L71`07=cL`80JVYZ01L0HV9R06m_K`1ZJVX0KVi^06QXJ01TI6@0Hf=S05aLG01WIfL0IVIV
06QXJ01ZJVX0JFUY06ATI01[Jf/0I6AT061PH01RHV80I6AT06=SH`1NGUh0I6AT06QXJ002061PH00O
06QXJ01VIVH0JFUY06][J`1UIFD0HF5Q069RHP1UIFD0I6AT06=SH`1UIFD0HF5Q061PH01UIFD0HF5Q
05]KF`1NGUh0IFEU05UIF@1YJFT0IVIV065QH@1PH600Hf=S061PH01NGUh0HF5Q061PH01RHV80Fe]K
05YJFP060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT2061PH00M05QHF01N
GUh0IVIV05UIF@1NGUh0H61P05mOG`1JFUX0GEeM06=SH`1PH600F5QH05mOG`1WIfL0HV9R065QH@1T
I6@0HV9R06=SH`1NGUh0FUYJ05mOG`1SHf<0GUiN069RHP1LG5`0HF5Q06ATI01ZJVX00P1PH600601V
IVH0GUiN06YZJP1VIVH0JFUY06=SH`1UIFD0I6AT06MWI`1XJ6P0IfMW069RHP1NGUh0JFUY06ATI01`
L700K6a/06UYJ@1[Jf/0KVi^06UYJ@1[Jf/0H61P06QXJ080IFEU01H0JVYZ06][J`1YJFT0JFUY075a
L@1dM7@0IfMW06UYJ@1_Kfl0J6QX07AdM01YJFT0MGEe06i^KP1[Jf/0L71`06i^KP1bLW80JVYZ07=c
L`1YJFT0Kfm_0P1cLg<0401iNGT0Lg=c075aL@1eMGD0LG5a06YZJP1`L700MWIf075aL@1lO7`0MgMg
07=cL`1dM7@0L71`07QhN01eMGD207MgM`0406m_K`1dM7@0MGEe07=cL`80O7al00@0Ogmo07QhN01i
NGT0P8200P1iNGT0101mOGd0PH6107YjNP23Ph<20820P0090861P@22PX80QXJ60861P@20P800Q8B4
08F5Q@22PX80P8200080QHF500@0R8R808J6QP24Q8@0R8R80P29RHT01@27QhL0QHF508R8R026QXH0
T92@0080QhN700H0QHF507moO`2?Shl0SXj>08J6QP2<S8`208f=S@0308F5Q@27QhL0R8R80080TI6A
00@0RHV909FEU@2@T900Shn?0`2>SXh02`2DU9@0Rh^;08^;R`2<S8`0UYJF09NGU`2>SXh0Rh^;08f=
S@2FUYH0SXj>0080TY:B00/0Shn?096AT@2FUYH0Shn?092@T02JVYX0TI6A08N7Q`2;Rh/0QXJ6096A
T@0208n?S`0K08R8R02ATI40Shn?09>CT`2<S8`0Rh^;08V9R@2FUYH0R8R808B4Q027QhL0PX:208b<
S021PH40Ph>308N7Q`24Q8@0Ogmo07]kN`28R8P0Ph>30820P026QXH0PH6107QhN021PH40OWin00@0
O7al00X0PX:207moO`1nOWh0PH6107alO01kNg/0N7Qh07IfMP1jNWX0MWIf0P1bLW803@1hN7P0MgMg
075aL@1dM7@0N7Qh07EeM@1fMWH0MGEe07=cL`1bLW80MGEe079bLP1fMWH00`1]KFd01P1jNWX0L71`
075aL@1_Kfl0K6a/06][J`80LW9b00L0JFUY06MWI`1_Kfl0JVYZ06EUI@1]KFd0JVYZ0080J6QX01D0
KFe]071`L01YJFT0Jf][065QH@1SHf<0Jf][06=SH`1XJ6P0K6a/06IVIP1TI6@0H61P05mOG`1WIfL0
FEUI06ATI01PH600GUiN069RHP1PH6000P1QHF40301NGUh0Hf=S061PH01YJFT0Hf=S065QH@1RHV80
H61P06ATI01QHF40HV9R06IVIP80H61P00`0GEeM06EUI@1XJ6P0IVIV06=SH`1MGEd0HF5Q069RHP1O
Gel0HV9R05mOG`1PH6060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT04`1K
Fe/0FEUI05]KF`1KFe/0IfMW05aLG01SHf<0GUiN069RHP1VIVH0Hf=S069RHP1QHF40GemO06=SH`1N
GUh0HF5Q069RHP1PH6000P1QHF402@1SHf<0G5aL065QH@1OGel0I6AT065QH@1UIFD0H61P06=SH`02
061PH00606=SH`1UIFD0HF5Q061PH01WIfL0GUiN0`1YJFT01`1SHf<0J6QX06EUI@1VIVH0K6a/06AT
I01]KFd00P1ZJVX0101_Kfl0HV9R06UYJ@1dM7@206YZJP0906QXJ01WIfL0JVYZ06IVIP1XJ6P0HV9R
05mOG`1VIVH0JVYZ0080LG5a00T0Jf][06m_K`1]KFd0Jf][06ATI01`L700IfMW06IVIP1[Jf/00P1^
KVh07@1[Jf/0KVi^06i^KP1[Jf/0Kfm_06YZJP1^KVh0LW9b07MgM`1/K6`0Lg=c06m_K`1dM7@0KFe]
06i^KP1cLg<0MWIf079bLP1eMGD0M7Ad07YjNP1hN7P0MgMg06i^KP1hN7P0LW9b07alO01jNWX0Ng]k
0080O7al00`0Ph>307MgM`1hN7P0Ng]k07alO024Q8@0Ng]k07moO`1jNWX0PH6107YjNP28R8P208>3
P`0608F5Q@1hN7P0PX:208F5Q@27QhL0QHF50P24Q8@01025QHD0SXj>08Z:RP2;Rh/208R8R00Y08^;
R`2?Shl0SHf=08^;R`28R8P0S8b<092@T025QHD0U9BD08j>SP28R8P0UIFE09BDU02?Shl0Rh^;08f=
S@29RHT0Shn?08V9R@2DU9@0TY:B08^;R`2@T900S8b<096AT@2=SHd0Ti>C09BDU02>SXh0Shn?09bL
W02JVYX0S8b<08j>SP2=SHd0TI6A09>CT`27QhL0UiNG096AT@2:RXX00P2CTi<04`2>SXh0S8b<08^;
R`25QHD0SXj>08^;R`29RHT0TI6A08^;R`2:RXX0S8b<09:BTP26QXH0RHV908F5Q@23Ph<0RXZ:08V9
R@2ATI400P29RHT01P20P800QhN708>3P`25QHD0Ogmo08:2PP80P82000H0Ph>308Z:RP22PX80NGUi
08>3P`24Q8@207inOP0<0820P01kNg/0MGEe07emO@1jNWX0Ph>307alO01gMgL0Ogmo07]kN`1eMGD0
O7al0P1iNGT01P25QHD0M7Ad07YjNP1_Kfl0NWYj07UiN@80M7Ad01d0MGEe08F5Q@1nOWh0NWYj075a
L@1_Kfl0MWIf07EeM@1ZJVX0Jf][071`L01]KFd0LG5a071`L01cLg<0M7Ad06UYJ@1/K6`0JVYZ06i^
KP1`L700J6QX06m_K`1TI6@0IfMW06YZJP1XJ6P0LW9b065QH@0206ATI00A06QXJ01/K6`0JVYZ06IV
IP1YJFT0IfMW065QH@1TI6@0Hf=S069RHP1PH600IVIV061PH01NGUh0HF5Q06EUI@1NGUh00P1OGel0
3P1WIfL0FEUI06QXJ01TI6@0J6QX06=SH`1PH600G5aL06=SH`1MGEd0I6AT05eMG@1JFUX0HF5Q0P1T
I6@02@1WIfL0GUiN05]KF`1OGel0HF5Q05EEE@1JFUX0FEUI05mOG`060=WIf@4000000@3IfMT001H0
fMWI00<000000=WIf@3IfMT00`3IfMT0801NGUh0F5QH05QHF01QHF40FUYJ06ATI01KFe/0H61P05YJ
FP1UIFD0G5aL05iNGP1KFe/0Hf=S065QH@1LG5`0HF5Q069RHP1OGel0HF5Q06=SH`1RHV80Fe]K06=S
H`1UIFD0I6AT06=SH`1QHF40HV9R06MWI`1OGel0H61P0P1NGUh01P1OGel0H61P065QH@1[Jf/0K6a/
06ATI080IFEU00<0H61P06EUI@1QHF400P1VIVH206QXJ00X06YZJP1`L700Jf][06UYJ@1]KFd0JVYZ
06][J`1XJ6P0Jf][06e]K@1[Jf/0IfMW06EUI@1VIVH0J6QX06e]K@1^KVh0JFUY06m_K`1^KVh0KFe]
06][J`1aLG40LW9b06m_K`1dM7@0Kfm_06QXJ01/K6`0Kfm_06e]K@1cLg<0K6a/071`L01fMWH0Jf][
079bLP1aLG40NGUi06m_K`80Lg=c01<0Kfm_075aL@1cLg<0NGUi071`L01hN7P0MgMg075aL@1hN7P0
MgMg079bLP1hN7P0Ogmo08>3P`1jNWX0OGem07alO01hN7P0Ogmo0080NWYj00<0LW9b07MgM`1mOGd0
0`20P8000`27QhL0Q8B407MgM`0208F5Q@0908Z:RP23Ph<0PH6108J6QP22PX80QhN708f=S@23Ph<0
R8R80080S8b<00/0RHV9096AT@2;Rh/0SXj>08^;R`2>SXh0T92@09:BTP2CTi<0RXZ:08R8R00208j>
SP0T08n?S`2BTY80TY:B09BDU02?Shl0Ti>C08V9R@2?Shl0Ti>C09RHV02ATI40U9BD08b<S02=SHd0
UYJF08^;R`2@T900UiNG08^;R`2<S8`0UiNG09BDU02FUYH0TI6A09:BTP2CTi<0TY:B09BDU02<S8`0
Shn?09:BTP2DU9@0S8b<09NGU`2@T900VYZJ0P2@T9003@28R8P0U9BD09BDU02;Rh/0Shn?09FEU@2D
U9@0UIFE08Z:RP2<S8`0QXJ608B4Q02:RXX00P28R8P0402=SHd0S8b<08J6QP22PX80Ogmo08b<S024
Q8@0PH6108>3P`1nOWh0Q8B408F5Q@23Ph<0OWin0820P025QHD20861P@0407alO024Q8@0P82008:2
PP80QHF50P21PH400`1mOGd0P82007inOP0207IfMP80NWYj0100MGEe06a/K01lO7`0LG5a07]kN`1a
LG40MWIf07]kN`1iNGT0MGEe07MgM`1aLG40M7Ad06m_K`1`L700MgMg0P1]KFd01P1cLg<0KVi^06UY
J@1^KVh0LG5a06MWI`80LW9b01h0JVYZ06IVIP1_Kfl0K6a/06YZJP1]KFd0HV9R06IVIP1PH600HF5Q
06=SH`1UIFD0J6QX06ATI01QHF40HV9R06QXJ01TI6@0IFEU06QXJ01YJFT0GUiN06ATI01SHf<0G5aL
069RHP1JFUX0GUiN06ATI01SHf<206EUI@80GemO01D0Hf=S06IVIP1TI6@0Hf=S05iNGP1TI6@0HV9R
065QH@1SHf<0G5aL05iNGP1KFe/0HV9R06ATI01NGUh0H61P065QH@1TI6@0EeMG04e=C@1NGUh01P3I
fMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0100GEeM05mOG`1VIVH0H61P05]K
F`1MGEd0EeMG05YJFP1UIFD0I6AT06MWI`1UIFD0GemO05iNGP1WIfL0HF5Q101RHV80101IFET0H61P
069RHP1VIVH206=SH`0306UYJ@1OGel0K6a/0080HF5Q00X0H61P06YZJP1VIVH0IfMW069RHP1XJ6P0
IFEU06e]K@1ZJVX0IVIV0P1RHV80101TI6@0Hf=S05mOG`1VIVH206][J`0706YZJP1XJ6P0JVYZ06MW
I`1ZJVX0IVIV06QXJ00206=SH`0:06MWI`1TI6@0Hf=S06QXJ01TI6@0K6a/06MWI`1XJ6P0LW9b06IV
IP80KFe]00P0IVIV06e]K@1ZJVX0JVYZ06m_K`1iNGT0MgMg079bLP80Kfm_00h0MGEe06m_K`1bLW80
MWIf075aL@1dM7@0KVi^06][J`1`L700LW9b07]kN`1jNWX0MGEe07MgM`80Lg=c01@0MgMg07QhN01c
Lg<0MgMg07inOP21PH40O7al07QhN01kNg/0QHF507alO025QHD0MgMg07AdM01kNg/0N7Qh07UiN@1m
OGd0P82007]kN`80Ogmo00L0OGem08N7Q`22PX80OGem08:2PP1oOgl0QhN70080QXJ600@0Rh^;08F5
Q@22PX80SHf=0P26QXH06`2=SHd0R8R808F5Q@2?Shl0U9BD092@T02DU9@0RXZ:09:BTP2CTi<0S8b<
08n?S`2BTY80S8b<08n?S`2;Rh/0S8b<096AT@2FUYH0SHf=09:BTP2<S8`0RXZ:09RHV02IVIT0TY:B
096AT@0208f=S@0B09JFUP2CTi<0UIFE09NGU`2IVIT0Ti>C096AT@2JVYX0V9RH08J6QP2?Shl0S8b<
09FEU@2GUiL0VYZJ08j>SP2HV9P0U9BD0P2ATI401P2BTY80SHf=08R8R02DU9@0T92@08f=S@80S8b<
00D0TY:B08R8R02?Shl0T92@08f=S@0308^;R`0?08:2PP2;Rh/0QXJ608b<S023Ph<0NWYj08^;R`1o
Ogl0QHF50861P@24Q8@0SHf=07emO@23Ph<0QXJ60080Ogmo01`0Ph>308F5Q@29RHT0Ph>308V9R@1i
NGT0OWin08F5Q@1mOGd0PH6107alO01gMgL0LW9b07AdM01jNWX0OGem07IfMP1iNGT0Lg=c07]kN`1l
O7`0NWYj07UiN@1cLg<0MgMg07IfMP1hN7P0NGUi0P1/K6`00`1^KVh0N7Qh07EeM@0207=cL`03075a
L@1_Kfl0Kfm_0080L71`02L0KVi^06][J`1_Kfl0Jf][065QH@1TI6@0K6a/06YZJP1^KVh0J6QX06UY
J@1VIVH0JVYZ06MWI`1XJ6P0Jf][06YZJP1NGUh0IFEU06MWI`1YJFT0HV9R06a/K01XJ6P0IfMW06IV
IP1QHF40GemO069RHP1UIFD0GemO05iNGP1XJ6P0GUiN06QXJ01RHV80IVIV069RHP1PH6000P1JFUX0
401MGEd0H61P05iNGP1YJFT0HV9R06MWI`1KFe/0HV9R05eMG@1NGUh0IVIV06e]K@1SHf<0I6AT05]K
F`1LG5`205iNGPH0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0=06=SH`1E
EED0FEUI05UIF@1SHf<0HF5Q05iNGP1GEeL0H61P06EUI@1SHf<0H61P05iNGP0205aLG00306MWI`1N
GUh0G5aL0080HV9R0100K6a/065QH@1NGUh0J6QX05mOG`1TI6@0J6QX05iNGP1SHf<0HV9R06ATI01R
HV80JVYZ05eMG@1UIFD0J6QX0P1VIVH01P1LG5`0GemO06EUI@1YJFT0I6AT06MWI`80HF5Q01T0K6a/
05aLG01XJ6P0IfMW06UYJ@1WIfL0Jf][06YZJP1YJFT0KVi^065QH@1`L700K6a/06m_K`1VIVH0Jf][
06a/K01ZJVX0HF5Q06a/K01`L700JVYZ06EUI@1XJ6P0JVYZ0080K6a/00d0J6QX06m_K`1ZJVX0LW9b
07QhN01eMGD0IfMW079bLP1eMGD0NGUi07IfMP1hN7P0LG5a0080MGEe00`0N7Qh07=cL`1eMGD0MGEe
07IfMP1oOgl0Ng]k07UiN@1nOWh0P82007IfMP1eMGD207QhN00>07YjNP1nOWh0O7al07inOP20P800
PX:208R8R01lO7`0P82007YjNP1kNg/0OGem07]kN`1mOGd208>3P`0:0820P02;Rh/0PX:208B4Q02;
Rh/0PX:208V9R@24Q8@0RHV908J6QP80RHV900H0QhN708j>SP2=SHd0T92@08B4Q02;Rh/208b<S00=
08j>SP2DU9@0U9BD08Z:RP2DU9@0SXj>08f=S@2>SXh0Ti>C08^;R`2ATI40RHV909FEU@0209>CT`07
09JFUP2CTi<0TY:B09BDU02>SXh0SHf=09^KV`0208n?S`0B09RHV02=SHd0Rh^;09:BTP2FUYH0TY:B
092@T02HV9P0UYJF08j>SP2DU9@0VIVI08Z:RP2ATI40T92@096AT@2<S8`0UYJF0P2?Shl00`2@T900
U9BD09:BTP0208j>SP0;09NGU`2BTY80UIFE08f=S@2@T900S8b<08j>SP2ATI40SXj>08f=S@2>SXh0
0P2?Shl04`27QhL0QHF508R8R02<S8`0QXJ608:2PP2:RXX0QHF508J6QP2:RXX0Q8B407moO`1nOWh0
QHF50861P@22PX80P82008f=S@1nOWh00P23Ph<02@2:RXX0QXJ608Z:RP20P800PH6107moO`1lO7`0
Ng]k07alO00207UiN@0807]kN`1hN7P0LW9b07IfMP1mOGd0Ng]k07alO01gMgL207IfMP0H0861P@1b
LW80Lg=c075aL@1^KVh0KFe]07EeM@1/K6`0JFUY071`L01^KVh0K6a/06UYJ@1aLG40Kfm_06UYJ@1^
KVh0Kfm_065QH@1YJFT0IVIV06YZJP1UIFD0Hf=S0P1XJ6P0;P1UIFD0IVIV06YZJP1UIFD0IfMW06EU
I@1SHf<0IFEU069RHP1UIFD0H61P06QXJ01TI6@0K6a/061PH01LG5`0IVIV05iNGP1QHF40G5aL06=S
H`1WIfL0HF5Q05mOG`1WIfL0GEeM069RHP1TI6@0IFEU05iNGP1TI6@0GEeM05aLG01QHF40I6AT05mO
G`1RHV80I6AT065QH@1RHV80G5aL05iNGP1RHV80HF5Q061PH01NGUh60=WIf@4000000@3IfMT001H0
fMWI0P0000040=WIf@0B05YJFP1PH600GUiN05eMG@1HF5P0G5aL05UIF@1PH600GemO06ATI01SHf<0
GemO069RHP1HF5P0HF5Q061PH01NGUh0H61P0`1TI6@03@1IFET0I6AT05iNGP1RHV80H61P05iNGP1V
IVH0IFEU06ATI01XJ6P0K6a/071`L01WIfL00P1SHf<04P1QHF40IFEU061PH01TI6@0Hf=S06ATI01Y
JFT0I6AT065QH@1SHf<0IfMW065QH@1TI6@0IVIV06][J`1]KFd0IfMW06IVIP80JFUY00<0JVYZ06i^
KP1_Kfl00P1]KFd09@1YJFT0MGEe06m_K`1YJFT0JVYZ06m_K`1bLW80Lg=c06QXJ01^KVh0L71`06QX
J01]KFd0KVi^07QhN01`L700N7Qh07IfMP1_Kfl0Lg=c07AdM01^KVh0LW9b07MgM`1[Jf/0LW9b07=c
L`1^KVh0Ng]k07QhN01fMWH0Ng]k07MgM`1bLW80MgMg07moO`1iNGT00`1nOWh04`22PX80OWin07Ui
N@1nOWh0O7al07=cL`1oOgl0OGem07MgM`1iNGT0PX:207alO01nOWh0P82007inOP22PX80QXJ608N7
Q`24Q8@00P22PX804026QXH0RXZ:08R8R028R8P0QXJ608N7Q`28R8P0RXZ:08^;R`25QHD0TY:B08N7
Q`2ATI40TY:B08^;R`2IVIT209BDU00308^;R`2?Shl0TY:B0080TY:B01<0U9BD09:BTP2=SHd0UIFE
08f=S@2EUID0U9BD08R8R02>SXh0T92@09BDU02GUiL0T92@09VIV@2EUID0Ti>C096AT@2EUID0UiNG
0080UIFE00l0X:2P08n?S`2MWId0WinO09JFUP27QhL0Ti>C09FEU@2BTY80UYJF09FEU@2FUYH0UiNG
09FEU@2BTY800P2=SHd0<@2KVi/0T92@09>CT`2;Rh/0UYJF08b<S02HV9P0UIFE08f=S@2HV9P0Shn?
092@T02ATI40RHV9096AT@28R8P0RXZ:08N7Q`28R8P0RHV908N7Q`24Q8@0Ph>308F5Q@2?Shl0S8b<
08N7Q`1oOgl0T92@07UiN@24Q8@0Ogmo08B4Q022PX80SHf=08^;R`21PH40Q8B40861P@25QHD0OWin
07YjNP28R8P0OWin07alO01nOWh0NWYj07QhN01mOGd00P1hN7P00`1fMWH0OGem07IfMP0307YjNP0e
07UiN@1fMWH0LG5a07UiN@1cLg<0MGEe06m_K`1[Jf/0MGEe06][J`1^KVh0J6QX075aL@1bLW80KFe]
06i^KP1/K6`0KFe]071`L01/K6`0L71`06MWI`1/K6`0J6QX06YZJP1YJFT0I6AT06][J`1_Kfl0IVIV
06ATI01^KVh0LW9b06EUI@1YJFT0HV9R061PH01UIFD0H61P06QXJ01^KVh0I6AT06IVIP1SHf<0IFEU
05iNGP1YJFT0GemO05MGE`1PH600IFEU069RHP1PH6000P1RHV804`1OGel0H61P061PH01VIVH0G5aL
05YJFP1MGEd0J6QX05ADE01OGel0GEeM065QH@1OGel0IVIV05eMG@1KFe/0EeMG05UIF@1HF5P01@3I
fMT200000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI01d0GEeM05]KF`1NGUh0GUiN06=S
H`1HF5P0GEeM05iNGP1TI6@0HV9R06ATI01FEUH0GUiN061PH01NGUh0HF5Q06=SH`1LG5`0HF5Q05iN
GP1QHF40H61P05eMG@1UIFD0G5aL05mOG`1SHf<0HV9R06EUI@0206IVIP0A06EUI@1[Jf/0HV9R06YZ
JP1RHV80KVi^06EUI@1WIfL0HF5Q06EUI@1]KFd0Jf][06QXJ01TI6@0J6QX06MWI`1QHF400P1ZJVX0
1P1^KVh0JFUY06MWI`1[Jf/0MWIf065QH@80LG5a0P1YJFT0101WIfL0JVYZ07AdM01/K6`206YZJP0A
07=cL`1ZJVX0LG5a071`L01/K6`0KVi^079bLP1]KFd0L71`06i^KP1fMWH0Lg=c07IfMP1eMGD0Ng]k
07AdM01hN7P00P1dM7@09@1aLG40Lg=c075aL@1_Kfl0MgMg075aL@1eMGD0Jf][07=cL`21PH40Ogmo
07alO01gMgL0MGEe07UiN@1lO7`0PX:20820P01nOWh0N7Qh08:2PP21PH40OWin07UiN@27QhL0P820
07UiN@1oOgl0OWin08:2PP20P800Q8B407alO01oOgl0OGem0820P024Q8@00P28R8P03P2@T900QHF5
08Z:RP27QhL0Q8B408R8R02?Shl0TI6A08n?S`24Q8@0Ti>C08f=S@2@T900TY:B0P2FUYH208n?S`04
08^;R`2>SXh0SXj>08j>SP80U9BD06H0UiNG09:BTP2IVIT0VIVI092@T02CTi<0T92@09:BTP2JVYX0
TY:B08n?S`2ATI40U9BD09>CT`2;Rh/0V9RH09VIV@2DU9@0V9RH09bLW02ATI40Shn?09>CT`2IVIT0
VYZJ09^KV`2IVIT0U9BD09JFUP2DU9@0W9bL09ZJVP2GUiL0UYJF09>CT`2EUID0VYZJ09^KV`2EUID0
V9RH09>CT`2JVYX0VIVI09JFUP2GUiL0UYJF08J6QP2DU9@0Q8B408j>SP2:RXX0SHf=08b<S02;Rh/0
QhN708V9R@28R8P0QXJ608>3P`20P800PH610820P026QXH0Ph>308B4Q026QXH0OWin08>3P`27QhL0
Rh^;08J6QP21PH40Ogmo08>3P`21PH40Ogmo08:2PP24Q8@0P82007inOP1mOGd0MgMg07UiN@1nOWh0
N7Qh07EeM@1aLG40N7Qh07IfMP1jNWX0Ogmo07QhN01gMgL0MWIf07EeM@1cLg<0M7Ad07MgM`1hN7P0
M7Ad06e]K@1ZJVX206m_K`0H079bLP1`L700LG5a06][J`1WIfL0K6a/06][J`1]KFd0K6a/07=cL`1[
Jf/0K6a/07AdM01]KFd0Jf][06MWI`1VIVH0H61P069RHP1OGel0IVIV06][J`1/K6`0Jf][0`1XJ6P0
401QHF40JFUY065QH@1OGel0IVIV05eMG@1QHF40Hf=S05eMG@1QHF40FUYJ065QH@1WIfL0HV9R06=S
H`1QHF4305iNGP0@05eMG@1SHf<0Fe]K065QH@1RHV80GemO05iNGP1PH600GEeM06IVIP1OGel0IFEU
05mOG`1HF5P0FEUI05mOG`H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0@
05mOG`1GEeL0Fe]K061PH01QHF40GemO05YJFP1MGEd0Hf=S05]KF`1PH600Fe]K05eMG@1TI6@0HV9R
05]KF`80G5aL00T0GUiN06=SH`1LG5`0FUYJ06QXJ01UIFD0HF5Q06=SH`1NGUh00P1ZJVX0@`1WIfL0
IFEU06EUI@1[Jf/0JVYZ06IVIP1TI6@0HF5Q05mOG`1XJ6P0H61P06ATI01PH600HF5Q06ATI01[Jf/0
IfMW05iNGP1VIVH0LG5a06ATI01[Jf/0I6AT06QXJ01/K6`0Hf=S06EUI@1]KFd0L71`06QXJ01YJFT0
Kfm_07AdM01WIfL0KVi^06][J`1aLG40Jf][079bLP1[Jf/0N7Qh075aL@1`L700K6a/06e]K@1^KVh0
Lg=c07EeM@1fMWH0LG5a07MgM`1fMWH0Lg=c07UiN@1]KFd0MGEe07=cL`1`L700Kfm_07=cL`1gMgL0
Lg=c07MgM`1fMWH0O7al07QhN01eMGD00P1jNWX01`1gMgL0PH610820P01lO7`0Ph>30820P01jNWX0
0`1lO7`0101jNWX0OWin07emO@1hN7P207moO`0?08B4Q02:RXX0R8R808V9R@1oOgl0R8R80861P@26
QXH0Q8B408R8R027QhL0S8b<08^;R`2=SHd0Shn?0080SHf=00<0RHV908^;R`2<S8`00`2=SHd00`2D
U9@0Rh^;09FEU@02096AT@0:08f=S@2CTi<0S8b<092@T02=SHd0T92@08j>SP2CTi<0V9RH09NGU`80
Ti>C00<0TY:B09bLW02?Shl00P2HV9P0202CTi<0V9RH09:BTP2?Shl0VIVI09NGU`2EUID0Shn?0P2H
V9P02P2KVi/0UYJF09>CT`2DU9@0UIFE09ZJVP2CTi<0UYJF096AT@2>SXh209>CT`0509VIV@2EUID0
Vi^K0:JVYP2LW9`00P2EUID04`2:RXX0UIFE09bLW02KVi/0UIFE09>CT`2BTY80Rh^;092@T02BTY80
T92@08:2PP2;Rh/0RHV908F5Q@2;Rh/0TI6A0820P02?Shl00P2>SXh04@22PX80QHF50861P@28R8P0
P82008J6QP2=SHd0R8R808B4Q021PH40QXJ60861P@24Q8@0OGem08:2PP21PH40NWYj00<0OWin00P0
NWYj0861P@1jNWX0NGUi07QhN01oOgl0NGUi07QhN080NWYj00L0MgMg07EeM@1iNGT0MGEe07AdM01^
KVh0Lg=c0080LW9b00<0Kfm_079bLP1bLW800P1ZJVX0401^KVh0LG5a06UYJ@1UIFD0K6a/06][J`1Y
JFT0J6QX06][J`1]KFd0Jf][06MWI`1aLG40KFe]06EUI@1[Jf/206QXJ080IFEU0100K6a/06QXJ01W
IfL0IfMW06=SH`1TI6@0H61P06UYJ@1VIVH0IfMW069RHP1NGUh0GemO065QH@1XJ6P0IVIV0P1UIFD0
1@1QHF40GemO069RHP1LG5`0IFEU0080Hf=S0100IfMW05iNGP1SHf<0FUYJ065QH@1SHf<0GUiN06MW
I`1NGUh0Hf=S06IVIP1SHf<0E5AD05]KF`1OGel0GEeM1P3IfMT100000040fMWI000F0=WIf@030000
003IfMT0fMWI00<0fMWI00l0FEUI05mOG`1RHV80J6QX05iNGP1LG5`0H61P069RHP1LG5`0IFEU05iN
GP1UIFD0GEeM061PH01VIVH00`1PH6007`1GEeL0GEeM069RHP1UIFD0GEeM05iNGP1MGEd0HF5Q05]K
F`1VIVH0JFUY06IVIP1UIFD0IVIV06EUI@1RHV80IVIV065QH@1YJFT0HV9R06IVIP1WIfL0I6AT06e]
K@1ZJVX0H61P069RHP1TI6@0Hf=S06MWI`1XJ6P00P1YJFT03P1VIVH0K6a/06MWI`1/K6`0LG5a06QX
J01/K6`0KVi^06m_K`1ZJVX0KFe]06m_K`1YJFT0KFe]0P1YJFT01P1hN7P0JVYZ06m_K`1aLG40KFe]
06][J`80Kfm_00X0MGEe06UYJ@1gMgL0M7Ad07QhN01bLW80MWIf079bLP1`L700MWIf0P1iNGT0101g
MgL0OGem07=cL`1_Kfl207inOP80N7Qh01L0NWYj07EeM@23Ph<0O7al07emO@1jNWX0PH6107QhN024
Q8@0O7al07emO@1lO7`0OGem08F5Q@1oOgl0RHV908J6QP2?Shl0RXZ:096AT@28R8P0S8b<08:2PP02
08F5Q@0C08N7Q`2:RXX0Rh^;08j>SP2:RXX0Shn?092@T02<S8`0R8R808V9R@28R8P0RXZ:08n?S`2=
SHd0TY:B08R8R02GUiL0Shn?09:BTP0208f=S@0709BDU02EUID0UIFE09JFUP2>SXh0Vi^K09ZJVP02
09VIV@80Vi^K00T0Ti>C09VIV@2LW9`0WYjN09BDU02PX:00V9RH096AT@2JVYX00P2GUiL00`2FUYH0
Ti>C09^KV`0209RHV00509ZJVP2NWYh0UiNG09>CT`2EUID00P2DU9@00`2ATI40V9RH09JFUP0209:B
TP0<09fMW@2HV9P0UYJF09JFUP2HV9P0Y:BT09JFUP2HV9P0VIVI09JFUP2GUiL0VYZJ0P2TY:@0102>
SXh0W9bL08f=S@2?Shl208b<S00908j>SP26QXH0TY:B096AT@28R8P0Q8B40861P@27QhL0QHF50080
QhN700d0QXJ608R8R020P800RHV908J6QP22PX80QXJ607]kN`26QXH0Ng]k08N7Q`20P800Rh^;0080
OWin0280O7al07moO`22PX80OGem07moO`1jNWX0Ng]k07IfMP23Ph<0OWin07=cL`1iNGT0NWYj06m_
K`1oOgl0MgMg07QhN01fMWH0Lg=c07AdM01gMgL0LW9b06i^KP1iNGT0Kfm_071`L01VIVH0L71`07=c
L`1^KVh0J6QX06e]K@1_Kfl0Jf][0P1ZJVX01@1_Kfl0Lg=c06YZJP1XJ6P0K6a/0080IFEU01D0Hf=S
069RHP1SHf<0Kfm_05eMG@1UIFD0K6a/06=SH`1WIfL0GEeM06a/K01VIVH0Hf=S06e]K@1VIVH0I6AT
05mOG`1RHV80F5QH05iNGP1LG5`00P1WIfL05P1RHV80H61P06=SH`1PH600J6QX065QH@1UIFD0GUiN
06QXJ01QHF40GemO05eMG@1IFET0G5aL05]KF`1UIFD0HV9R05aLG01OGel0G5aL05]KF`1JFUX60=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT205eMG@0805YJFP1SHf<0I6AT05QH
F01UIFD0H61P06=SH`1RHV8205mOG`0905eMG@1XJ6P0HV9R05YJFP1NGUh0HF5Q061PH01RHV80EeMG
0080GUiN00/0G5aL05iNGP1LG5`0I6AT05]KF`1UIFD0IVIV06=SH`1VIVH0IFEU06ATI00206MWI`0?
06i^KP1UIFD0KFe]06i^KP1WIfL0JFUY06IVIP1TI6@0H61P06MWI`1SHf<0IFEU06IVIP1[Jf/0KFe]
0080J6QX0P1[Jf/05`1XJ6P0IVIV06QXJ01`L700IFEU06i^KP1TI6@0K6a/06QXJ01`L700Lg=c07Ee
M@1`L700JFUY07=cL`1WIfL0KFe]06m_K`1`L700Lg=c079bLP1cLg<0KVi^0080MGEe00<0M7Ad07]k
N`1jNWX00P1fMWH0201hN7P0MWIf07IfMP1dM7@0L71`07emO@1jNWX0NGUi0P1fMWH07022PX80OGem
07alO021PH40P82008>3P`20P800OGem07MgM`20P800OWin07alO01mOGd0Q8B408:2PP21PH40S8b<
08f=S@29RHT0QhN708V9R@26QXH0RHV908N7Q`2:RXX0QhN708f=S@2EUID308R8R00H08N7Q`2@T900
RXZ:08b<S02?Shl0Ti>C08j>SP2;Rh/0T92@09JFUP2EUID0UYJF09NGU`2;Rh/0TY:B096AT@2LW9`0
T92@09>CT`2FUYH0XJ6Q09:BTP2EUID0Rh^;0P2GUiL02`2IVIT0W9bL09JFUP2LW9`0UIFE09:BTP2F
UYH0UiNG09BDU02FUYH0VIVI0080UYJF00L0Vi^K09nOW`2BTY80W9bL09RHV02EUID0VYZJ0080UiNG
01P0VYZJ09NGU`2GUiL0W9bL09fMW@2GUiL0V9RH09>CT`2EUID0WYjN09>CT`2MWId0UYJF09bLW02Q
XJ40UYJF09fMW@2QXJ40XZ:R09jNWP2EUID0Xj>S096AT@2CTi<208j>SP0j08f=S@2BTY80R8R808b<
S02=SHd0Q8B408V9R@21PH40QhN708B4Q01nOWh0R8R808J6QP25QHD0RXZ:08B4Q029RHT0NWYj08>3
P`1oOgl0Ng]k08>3P`27QhL0Ng]k08F5Q@21PH40O7al0861P@1kNg/0NWYj08:2PP23Ph<0Ogmo0861
P@1mOGd0O7al07inOP1gMgL0Ogmo07YjNP1iNGT0LG5a07UiN@1eMGD0Kfm_07IfMP1bLW80MGEe07Qh
N01dM7@0N7Qh06i^KP1eMGD0JFUY06m_K`1aLG40L71`06][J`80JVYZ00H0L71`06][J`1`L700JVYZ
06a/K01XJ6P206a/K00806EUI@1[Jf/0KFe]06YZJP1RHV80IVIV069RHP1[Jf/206QXJ00C06IVIP1/
K6`0IfMW06EUI@1TI6@0H61P07EeM@1SHf<0I6AT06MWI`1YJFT0IFEU06=SH`1XJ6P0I6AT065QH@1S
Hf<0I6AT05aLG003069RHP0>06IVIP1OGel0I6AT05mOG`1UIFD0JFUY06ATI01MGEd0HV9R05eMG@1O
Gel0HV9R05UIF@1JFUX60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT02`1T
I6@0HV9R05UIF@1NGUh0Hf=S05mOG`1MGEd0IFEU05mOG`1XJ6P0GUiN0080GEeM00L0GemO06=SH`1U
IFD0FUYJ065QH@1NGUh0I6AT0080H61P01<0Fe]K061PH01WIfL0GemO061PH01UIFD0JVYZ06EUI@1Q
HF40Hf=S06IVIP1UIFD0Jf][06MWI`1ZJVX0IfMW06][J`1UIFD0HV9R0080I6AT00<0JVYZ071`L01V
IVH0101[Jf/0601YJFT0Jf][06e]K@1UIFD0JVYZ069RHP1YJFT0K6a/06i^KP1ZJVX0KVi^06EUI@1`
L700IVIV06e]K@1^KVh0K6a/06][J`1_Kfl0KFe]06YZJP1aLG40Kfm_075aL@80Kfm_00<0Lg=c07em
O@1aLG400P1`L7000`1_Kfl0LW9b07YjNP0207YjNP0807MgM`1dM7@0NWYj07UiN@1kNg/0Ogmo07in
OP1iNGT207YjNP0@07alO01cLg<0P82007moO`27QhL0NWYj0861P@1nOWh0RXZ:0861P@29RHT0QhN7
07moO`22PX80PH6108J6QP80T92@00X0UIFE09JFUP2ATI40Shn?07emO@21PH40Ph>308Z:RP29RHT0
Rh^;0P2<S8`00`2ATI40RXZ:096AT@0208n?S`0W092@T02ATI40RXZ:08n?S`2ATI40UIFE09:BTP2G
UiL0Shn?09NGU`2CTi<0Shn?09ZJVP2HV9P0WinO0:6QX@2IVIT0VYZJ0::RXP2LW9`0XJ6Q09fMW@2H
V9P0WIfM09^KV`2MWId0W9bL09NGU`2OWil0W9bL09RHV02JVYX0VIVI0:6QX@2FUYH0WIfM0:6QX@2O
Wil0WIfM0080Vi^K01H0UYJF09^KV`2SXj<0WinO09^KV`2IVIT0X:2P09RHV02KVi/0W9bL0:>SX`2H
V9P0TY:B09JFUP2EUID0WinO09>CT`2MWId0WinO0:BTY02ZZZX0XJ6Q0P2FUYH0202CTi<0UiNG08b<
S02IVIT0T92@08f=S@2:RXX0QXJ60P2@T9003`25QHD0RHV908Z:RP25QHD0Ph>308Z:RP25QHD0OGem
08R8R02<S8`0P82007alO025QHD0OWin08B4Q00208>3P`090861P@1oOgl0OWin08>3P`21PH40Ng]k
07moO`1hN7P0O7al0080OGem02T0N7Qh08F5Q@1lO7`0P82007]kN`1lO7`0LW9b07AdM01eMGD0LW9b
07alO01cLg<0M7Ad07UiN@1[Jf/0Lg=c06e]K@1lO7`0LW9b06m_K`1ZJVX0M7Ad06i^KP1YJFT0M7Ad
06MWI`1YJFT0KVi^06QXJ01aLG40MWIf071`L01SHf<0M7Ad06e]K@1TI6@0Jf][06YZJP1UIFD0JFUY
06QXJ00206EUI@0D069RHP1/K6`0IVIV06ATI01QHF40H61P06a/K01TI6@0H61P06YZJP1OGel0HF5Q
06YZJP1LG5`0GEeM05mOG`1SHf<0GUiN069RHP1WIfL2069RHP07061PH01OGel0HV9R06=SH`1PH600
Hf=S06EUI@0205eMG@06061PH01RHV80GUiN065QH@1KFe/0H61P1P3IfMT100000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI00T0GUiN061PH01QHF40GEeM06IVIP1QHF40GEeM06ATI01MGEd0
0P1SHf<06@1WIfL0HV9R065QH@1RHV80JFUY06=SH`1QHF40I6AT06YZJP1PH600JVYZ05iNGP1MGEd0
IfMW06QXJ01WIfL0GEeM06][J`1RHV80IVIV069RHP1YJFT0IfMW061PH01TI6@00P1XJ6P0101^KVh0
JVYZ06MWI`1UIFD206QXJ00506a/K01XJ6P0K6a/06MWI`1aLG400P1XJ6P206a/K00A06EUI@1XJ6P0
Jf][06IVIP1YJFT0KVi^06EUI@1/K6`0JFUY079bLP1aLG40MWIf06a/K01fMWH0MgMg07=cL`1/K6`0
0P1`L7002P1]KFd0LW9b06i^KP1hN7P0M7Ad079bLP1dM7@0NWYj07AdM01bLW8207YjNP07075aL@1f
MWH0MGEe07=cL`1mOGd0MWIf07]kN`0207EeM@0B0820P01mOGd0NWYj07inOP20P800OWin0861P@1o
Ogl0P82007YjNP1oOgl0OGem08B4Q022PX80QXJ607alO02=SHd0RXZ:0P24Q8@03`2BTY80UYJF08F5
Q@24Q8@0QhN708R8R024Q8@0RXZ:08^;R`24Q8@0TI6A09>CT`28R8P0RHV908b<S00209BDU00308F5
Q@2@T900UiNG0080UYJF00l0U9BD09:BTP2DU9@0TI6A09fMW@2=SHd0WIfM09BDU02GUiL0V9RH09:B
TP2PX:00VYZJ09JFUP2IVIT00P2LW9`0202GUiL0VYZJ09JFUP2PX:00WYjN0:BTY02JVYX0U9BD0`2L
W9`05`2JVYX0WIfM0:6QX@2GUiL0UYJF09RHV02PX:00XJ6Q09nOW`2JVYX0WinO0:FUY@2OWil0VIVI
09JFUP2IVIT0WIfM0:2PX02MWId0WYjN09:BTP2UYJD0V9RH0080W9bL01L0VYZJ09bLW02MWId0WinO
0:6QX@2JVYX0VIVI08n?S`2BTY80U9BD092@T02;Rh/0SHf=09>CT`2?Shl0UIFE08^;R`2@T900Shn?
09BDU02BTY80Shn?08:2PP0208R8R00O08b<S024Q8@0QXJ60820P01lO7`0QhN708J6QP2=SHd0PH61
08>3P`27QhL0Ogmo08B4Q027QhL0PX:207emO@27QhL0Ogmo07]kN`21PH40Ng]k07inOP1eMGD0QHF5
07]kN`1fMWH0OWin07]kN`1cLg<0NGUi07QhN00207EeM@80Lg=c0140M7Ad079bLP1cLg<0K6a/06][
J`1_Kfl0KVi^06YZJP1aLG40Jf][06QXJ01bLW80KVi^07EeM@1bLW80IVIV06MWI`0306][J`0Y06i^
KP1VIVH0K6a/06YZJP1VIVH0LG5a06i^KP1TI6@0J6QX069RHP1OGel0IFEU06UYJ@1NGUh0IFEU06][
J`1PH600Hf=S069RHP1QHF40IfMW069RHP1OGel0GUiN05mOG`1RHV80G5aL05mOG`1UIFD0IfMW06IV
IP1OGel0G5aL06ATI01KFe/0F5QH069RHP1PH600F5QH05UIF@1PH6000P1IFET00`1SHf<0H61P05MG
E`060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0301MGEd0GemO061PH01K
Fe/0HF5Q061PH01QHF40F5QH05aLG01MGEd0Hf=S05]KF`80HF5Q0140HV9R06IVIP1PH600IFEU06MW
I`1QHF40GUiN05mOG`1KFe/0IVIV05iNGP1WIfL0IFEU05iNGP1TI6@0J6QX069RHP0206IVIP0?06UY
J@1/K6`0HV9R06ATI01]KFd0IVIV06QXJ01WIfL0GUiN06MWI`1XJ6P0IVIV06a/K01[Jf/0JFUY0080
KFe]00D0K6a/061PH01]KFd0K6a/06i^KP0206UYJ@0[06IVIP1^KVh0L71`06YZJP1/K6`0MWIf06e]
K@1_Kfl0JFUY06i^KP1eMGD0KFe]07=cL`1`L700LW9b075aL@1cLg<0M7Ad07QhN01eMGD0Kfm_07Ui
N@1mOGd0MGEe071`L01jNWX0LG5a07EeM@1`L700N7Qh0820P01lO7`0OGem07]kN`1lO7`0OWin07Mg
M`1mOGd0NWYj07moO`1mOGd0Ng]k07YjNP020820P00;07moO`21PH40OWin08B4Q027QhL0Ogmo08J6
QP28R8P0QXJ608V9R@2>SXh00P2EUID03@2ATI40S8b<08Z:RP28R8P0RXZ:08J6QP2<S8`0RHV909RH
V02?Shl0RHV908F5Q@2GUiL00P2ATI405P2;Rh/0T92@09:BTP2@T900UYJF09NGU`2DU9@0Rh^;08n?
S`2CTi<0WYjN09:BTP2LW9`0VYZJ09RHV02OWil0UIFE09^KV`2WYjL0WIfM0:6QX@2WYjL409bLW003
09jNWP2OWil0XZ:R0080W9bL01d0Y:BT09RHV02KVi/0X:2P09bLW02QXJ40W9bL0:JVYP2KVi/0Z:RX
09^KV`2HV9P0VYZJ09nOW`2QXJ40Y:BT09bLW02QXJ40V9RH09nOW`2LW9`0X:2P09NGU`2CTi<0V9RH
09^KV`2HV9P0VIVI09NGU`0209VIV@0K09fMW@2IVIT0VYZJ09VIV@2DU9@0S8b<09NGU`2>SXh0TI6A
09BDU02ATI40Ti>C08R8R02@T900R8R809:BTP27QhL0Rh^;08N7Q`28R8P0RHV908R8R023Ph<0Shn?
0820P02<S8`0PX:20080P82001D0Rh^;08J6QP1mOGd0OWin08>3P`1mOGd0P82008:2PP24Q8@0S8b<
07]kN`1mOGd0OWin07emO@1lO7`0MgMg07moO`20P800OWin07emO@1jNWX00P1fMWH00`1eMGD0M7Ad
07AdM00207IfMP0907EeM@1^KVh0Jf][06a/K01^KVh0Kfm_06YZJP1gMgL0M7Ad0080K6a/00l0KFe]
06][J`1ZJVX0LG5a07AdM01gMgL0LG5a06e]K@1WIfL0KFe]06MWI`1/K6`0Kfm_06e]K@1ZJVX00P1X
J6P0301VIVH0IFEU06ATI01PH600IFEU069RHP1SHf<0JFUY05iNGP1TI6@0HF5Q069RHP80GemO00D0
J6QX05YJFP1OGel0GemO06MWI`0306=SH`0=061PH01SHf<0Hf=S061PH01VIVH0GEeM05iNGP1HF5P0
GemO069RHP1NGUh0G5aL05]KF`0206=SH`H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WI
f@030=WIf@0B061PH01UIFD0GUiN061PH01TI6@0G5aL05mOG`1HF5P0H61P06EUI@1NGUh0Fe]K065Q
H@1PH600HV9R05mOG`1PH600GemO0P1TI6@0301KFe/0HF5Q06EUI@1OGel0IVIV06EUI@1LG5`0HV9R
06IVIP1`L700Jf][06QXJ080I6AT00/0KVi^079bLP1RHV80KFe]06ATI01/K6`0JFUY06IVIP1UIFD0
JFUY06MWI`0206][J`0N071`L01^KVh0KVi^06QXJ01[Jf/0JVYZ06a/K01]KFd0K6a/06][J`1/K6`0
JFUY06IVIP1]KFd0Kfm_071`L01]KFd0MgMg06i^KP1[Jf/0LG5a06][J`1aLG40MWIf07UiN@1bLW80
LG5a07=cL`1iNGT0Kfm_0P1iNGT00`1jNWX0MgMg07AdM00207IfMP0407=cL`1nOWh0MgMg07]kN`80
NWYj0200O7al07inOP1oOgl0O7al07UiN@1oOgl0MGEe07]kN`1nOWh0PH6108:2PP1nOWh0N7Qh08N7
Q`1oOgl0QXJ608:2PP1nOWh0Ph>308J6QP23Ph<0QhN708b<S029RHT0S8b<08>3P`2>SXh0S8b<08n?
S`29RHT0UiNG08b<S0<0Shn?0480Ti>C096AT@2EUID0T92@096AT@2GUiL0S8b<09:BTP2LW9`0XJ6Q
09:BTP2DU9@0UIFE09RHV02OWil0Vi^K0:VYZ@2EUID0Xj>S09ZJVP2SXj<0Vi^K0:>SX`2PX:00YJFU
0:6QX@2VYZH0WIfM0:6QX@2PX:00Xj>S09nOW`2LW9`0XZ:R0:6QX@2TY:@0YZJV0:>SX`2TY:@0XJ6Q
0:>SX`2QXJ40XZ:R09nOW`2TY:@0V9RH09nOW`2PX:00Xj>S0:2PX02HV9P0X:2P0::RXP2QXJ40Xj>S
09nOW`2GUiL0VYZJ09fMW@2JVYX0UiNG09RHV02OWil0XZ:R09JFUP2LW9`209BDU00>09ZJVP2FUYH0
V9RH09fMW@2GUiL0Shn?09>CT`2>SXh0UIFE09JFUP2<S8`0SXj>09JFUP2?Shl208^;R`0I092@T02:
RXX0XJ6Q08Z:RP23Ph<0Rh^;08V9R@25QHD0P82008B4Q029RHT0Q8B408:2PP20P800PX:208B4Q025
QHD0P82008Z:RP22PX80NWYj0861P@1nOWh0Ogmo07inOP020861P@0Z07UiN@1kNg/0M7Ad07QhN01n
OWh0LW9b07emO@1fMWH0MgMg06e]K@1gMgL0LG5a07MgM`1fMWH0K6a/07=cL`1]KFd0Lg=c079bLP1_
Kfl0L71`06i^KP1_Kfl0N7Qh075aL@1YJFT0Kfm_06e]K@1hN7P0LG5a06a/K01`L700I6AT06QXJ01W
IfL0JVYZ06e]K@1XJ6P0KVi^06m_K`1TI6@0IfMW0P1XJ6P01`1VIVH0J6QX06=SH`1YJFT0IFEU065Q
H@1TI6@00P1XJ6P0201VIVH0JFUY06=SH`1QHF40HV9R05mOG`1SHf<0IFEU0P1QHF401@1SHf<0Fe]K
065QH@1PH600HF5Q0080FUYJ00H0FEUI061PH01TI6@0HF5Q05aLG01TI6@205mOG`H0fMWI0@000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0I06UYJ@1OGel0HF5Q05aLG01WIfL0Hf=S06AT
I01OGel0GUiN05aLG01KFe/0IFEU06MWI`1KFe/0HV9R061PH01QHF40Hf=S06EUI@1OGel0Hf=S06AT
I01JFUX0GEeM06QXJ00305mOG`0B069RHP1SHf<0JFUY06ATI01VIVH0HV9R06a/K01RHV80GemO06=S
H`1WIfL0IFEU069RHP1MGEd0J6QX06a/K01RHV80KFe]0P1XJ6P02@1ZJVX0KFe]06UYJ@1YJFT0Kfm_
06i^KP1VIVH0KFe]06MWI`02071`L00;06YZJP1]KFd0I6AT06m_K`1bLW80Jf][06m_K`1^KVh0KFe]
06a/K01iNGT00P1fMWH206m_K`0C06e]K@1bLW80KFe]07QhN01eMGD0O7al079bLP1eMGD0O7al07]k
N`1eMGD0N7Qh07YjNP1gMgL0OWin07UiN@1gMgL0Ogmo08:2PP0207moO`0307]kN`22PX80OWin00@0
OWin00L0QHF508V9R@24Q8@0Q8B40861P@29RHT0Q8B40080Rh^;0140T92@08V9R@2?Shl0R8R808n?
S`2;Rh/0SXj>08n?S`2BTY80WIfM09>CT`2;Rh/0R8R808^;R`2EUID0S8b<09FEU@02096AT@0;09JF
UP2CTi<0VIVI08f=S@2HV9P0UiNG09:BTP2FUYH0W9bL09jNWP2LW9`00P2EUID03P2QXJ40WYjN09bL
W02OWil0Xj>S09ZJVP2FUYH0W9bL09nOW`2UYJD0VYZJ09nOW`2QXJ40X:2P0P2OWil0102MWId0WYjN
09^KV`2SXj<209jNWP0G09fMW@2NWYh0XJ6Q09RHV02JVYX0WYjN0:6QX@2JVYX0V9RH0::RXP2TY:@0
Xj>S0::RXP2OWil0W9bL0:2PX02FUYH0X:2P09fMW@2LW9`0X:2P0:6QX@2MWId00P2LW9`01`2SXj<0
X:2P09VIV@2KVi/0UIFE09^KV`2FUYH00P2HV9P07P2CTi<0RHV909NGU`2GUiL0SHf=08b<S02IVIT0
SHf=08V9R@2=SHd0RXZ:08N7Q`3oool0m_Kf08N7Q`25QHD0S8b<08J6QP28R8P0QHF508J6QP2<S8`0
PX:207moO`22PX80QHF507alO028R8P0RXZ:08>3P`80PX:200D0MWIf07YjNP1lO7`0Ng]k08>3P`03
08:2PP0807inOP1fMWH0NGUi07IfMP1gMgL0LW9b071`L01jNWX307AdM00=07=cL`1dM7@0IfMW071`
L01]KFd0J6QX06YZJP1`L700K6a/06i^KP1/K6`0JVYZ075aL@0206e]K@0=06][J`1/K6`0JFUY06AT
I01YJFT0IfMW06QXJ01ZJVX0IVIV06ATI01WIfL0GemO06UYJ@0206QXJ00806YZJP1XJ6P0Hf=S06=S
H`1PH600IVIV069RHP1SHf<206ATI00506IVIP1QHF40Fe]K061PH01TI6@00`1SHf<03P1PH600I6AT
05mOG`1MGEd0IfMW065QH@1MGEd0GemO06UYJ@1LG5`0IFEU05mOG`1IFET0H61P0P1KFe/60=WIf@40
00000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT05P1PH600GemO06IVIP1WIfL0IFEU05aL
G01TI6@0Hf=S065QH@1RHV80IVIV065QH@1MGEd0IFEU05mOG`1PH600Fe]K06=SH`1GEeL0IVIV05eM
G@1TI6@205mOG`0A06=SH`1NGUh0IFEU06QXJ01PH600HV9R06MWI`1RHV80HF5Q05eMG@1WIfL0JFUY
06=SH`1/K6`0I6AT06IVIP1XJ6P00P1SHf<0401UIFD0JFUY06MWI`1VIVH0I6AT06][J`1UIFD0Jf][
06QXJ01^KVh0JFUY06MWI`1]KFd0LW9b06e]K@1YJFT2071`L00306e]K@1[Jf/0MGEe0080JFUY01h0
JVYZ06a/K01dM7@0L71`07EeM@1lO7`0JFUY06YZJP1cLg<0NWYj07IfMP1aLG40Lg=c07EeM@1dM7@0
Ogmo07emO@1hN7P0Lg=c07MgM`1kNg/0N7Qh07UiN@1jNWX0OGem07]kN`1iNGT0O7al08>3P`1mOGd2
07moO`0808B4Q022PX80RHV907UiN@22PX80PH6108:2PP24Q8@208J6QP80QHF502X0Q8B408b<S02=
SHd0SHf=08N7Q`2?Shl0Ti>C08Z:RP2ATI40RXZ:09JFUP2=SHd0UIFE08^;R`2FUYH0SHf=08j>SP2A
TI40VIVI08j>SP2BTY80UYJF09BDU02BTY80U9BD09VIV@2MWId0WYjN08j>SP2KVi/0W9bL09jNWP2K
Vi/0VYZJ0:2PX02KVi/0VYZJ0:RXZ02SXj<0WIfM09nOW`2YZJT209nOW`0=09fMW@2OWil0XZ:R09ZJ
VP2TY:@0[:b/0:FUY@2XZ:P0YJFU0:6QX@2PX:00Vi^K0:FUY@020:6QX@060:j^[P2VYZH0YJFU0::R
XP2KVi/0W9bL0P2QXJ401`2PX:00ZJVY0::RXP2SXj<0WIfM0:2PX02RXZ800P2LW9`06P2QXJ40W9bL
09fMW@2RXZ80WYjN0:NWY`2MWId0Vi^K09NGU`2IVIT0WIfM09RHV02FUYH0VIVI08b<S02GUiL0SHf=
096AT@2GUiL0U9BD08b<S02?Shl0SHf=08n?S`2:RXX0RHV90P2;Rh/08P24Q8@0R8R808:2PP20P800
SHf=08Z:RP28R8P0QHF508V9R@22PX80RHV90861P@22PX80OWin07UiN@22PX80O7al08J6QP23Ph<0
PX:208B4Q01nOWh0R8R807emO@1nOWh0PX:207UiN@1bLW80Q8B4079bLP1oOgl0MGEe07QhN01eMGD2
079bLP0=07=cL`2XZ:P0R8R807AdM01cLg<0Jf][07AdM01bLW80MWIf071`L01dM7@0IfMW071`L002
07=cL`0306EUI@1]KFd0LG5a0080IVIV02P0K6a/061PH01UIFD0JVYZ06][J`1/K6`0IFEU06a/K01S
Hf<0GemO065QH@1LG5`0JVYZ069RHP1YJFT0IFEU06=SH`1[Jf/0HV9R065QH@1TI6@0G5aL05mOG`1P
H600GemO06EUI@1TI6@0H61P05mOG`1UIFD0HF5Q05iNGP1TI6@0HF5Q06=SH`1KFe/0I6AT065QH@1N
GUh0HV9R0P1QHF400`1OGel0Hf=S0=WIf@050=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3I
fMT00`3IfMT06@1NGUh0Hf=S05mOG`1VIVH0Hf=S06ATI01MGEd0IFEU05eMG@1PH600HV9R06EUI@1Q
HF40I6AT061PH01/K6`0IfMW069RHP1WIfL0JVYZ06=SH`1OGel0H61P06=SH`1PH6000P1WIfL08P1Z
JVX0I6AT06EUI@1RHV80JVYZ06MWI`1SHf<0Fe]K06ATI01XJ6P0JFUY06YZJP1WIfL0Hf=S06QXJ01T
I6@0KVi^06][J`1SHf<0JVYZ06QXJ01QHF40JVYZ06ATI01[Jf/0JFUY06i^KP1`L700K6a/06m_K`1W
IfL0Kfm_06][J`1/K6`206m_K`0I075aL@1YJFT0Lg=c06][J`1aLG40K6a/07EeM@1iNGT0KFe]075a
L@1bLW80NGUi071`L01[Jf/0L71`07IfMP1cLg<0NWYj07=cL`1hN7P0MGEe07IfMP20P800N7Qh07]k
N`0207UiN@0607inOP27QhL0N7Qh07moO`27QhL0O7al0P22PX806P1lO7`0OGem08V9R@1kNg/0S8b<
0861P@22PX80Q8B408N7Q`2;Rh/0R8R808^;R`25QHD0R8R808f=S@2<S8`0SXj>08n?S`2=SHd0S8b<
09JFUP2@T900UYJF08^;R`2CTi<0T92@0P2DU9@0102GUiL0UYJF096AT@2JVYX309JFUP0A0:2PX02N
WYh0UYJF09RHV02NWYh0XJ6Q09VIV@2GUiL0XZ:R09jNWP2SXj<0Vi^K09nOW`2UYJD0WinO0:JVYP2W
YjL00P2VYZH30:FUY@0S09fMW@2YZJT0ZZZZ09fMW@2XZ:P0X:2P0:6QX@2PX:00Y:BT0:RXZ02QXJ40
Xj>S0:NWY`2][Jd0WinO0::RXP2QXJ40ZJVY09fMW@2[Zj/0WYjN0:NWY`2RXZ80XJ6Q0:VYZ@2XZ:P0
W9bL09RHV02LW9`0XZ:R09fMW@2IVIT0X:2P09ZJVP2KVi/00P2IVIT0E02RXZ80WYjN09fMW@2EUID0
UYJF09RHV02ATI40UIFE09NGU`2KVi/0T92@09RHV02CTi<0T92@09FEU@2CTi<0TY:B09>CT`2IVIT0
SXj>08f=S@2;Rh/0RHV908J6QP28R8P0RXZ:08R8R02LW9`0RXZ:08n?S`22PX80Ogmo08B4Q023Ph<0
QHF507inOP1iNGT0QXJ60820P02;Rh/0PX:207alO025QHD0QhN707inOP20P800PX:20861P@1hN7P0
Ng]k07EeM@1dM7@0Lg=c07QhN01^KVh0NGUi07IfMP1bLW80LG5a07EeM@1_Kfl0M7Ad07UiN@1bLW80
JVYZ079bLP1hN7P0M7Ad06IVIP1bLW80K6a/06ATI01]KFd0K6a/075aL@1[Jf/0L71`06i^KP1XJ6P0
IVIV06a/K01]KFd0Kfm_06EUI@80IVIV00L0IfMW06EUI@1QHF40J6QX06MWI`1VIVH0H61P0080HV9R
01/0I6AT06e]K@1XJ6P0IFEU05mOG`1VIVH0GemO061PH01WIfL0GEeM06ATI01RHV80F5QH05iNGP1Q
HF40IFEU065QH@1WIfL0H61P06MWI`1PH600HV9R05eMG@1GEeL0GEeM061PH01TI6@01P3IfMT10000
0040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI01D0IfMW06UYJ@1SHf<0J6QX05mOG`1QHF40
GEeM05iNGP1SHf<0HV9R06=SH`1RHV80FUYJ05aLG01NGUh0HF5Q06][J`1RHV80Hf=S05iNGP1PH600
0P1IFET03`1QHF40FUYJ06UYJ@1MGEd0H61P05mOG`1PH600IVIV06YZJP1XJ6P0IVIV069RHP1XJ6P0
K6a/05mOG`0206UYJ@80I6AT0100Kfm_06MWI`1XJ6P0Lg=c06IVIP1^KVh0JVYZ07=cL`1WIfL0JFUY
06IVIP1UIFD0KVi^06a/K01_Kfl0LW9b0P1^KVh07@1/K6`0NGUi06i^KP1/K6`0IVIV06a/K01^KVh0
MWIf07AdM01hN7P0LW9b075aL@1iNGT0LW9b06][J`1cLg<0K6a/079bLP1gMgL0L71`07UiN@1jNWX0
M7Ad07]kN`1hN7P0M7Ad07QhN01jNWX0NGUi0080OGem00h0QXJ607]kN`20P800PX:208J6QP1mOGd0
QHF508>3P`25QHD0Ogmo08B4Q01mOGd0QHF508R8R080QXJ600D0RXZ:08f=S@21PH40S8b<08V9R@02
08R8R00/092@T02>SXh0SXj>09:BTP2@T900R8R8092@T02HV9P0RXZ:09VIV@2DU9@0UiNG096AT@2H
V9P0Ti>C09NGU`2IVIT0X:2P09RHV02PX:00Ti>C09BDU02RXZ80UYJF09VIV@2KVi/0XJ6Q09^KV`2T
Y:@0VYZJ0:ZZZP2TY:@0YjNW0:2PX02XZ:P0ZJVY0:2PX02XZ:P0ZJVY0:RXZ02UYJD0Z:RX0:ZZZP2T
Y:@20:FUY@0/0:JVYP2RXZ80ZZZZ0:b/[02PX:00WinO0:FUY@2RXZ80YZJV0:ZZZP2TY:@0Z:RX0::R
XP2UYJD0Xj>S0:n_[`2WYjL0ZJVY09RHV02MWId0W9bL0::RXP2SXj<0XZ:R0:FUY@2RXZ80W9bL0:BT
Y02RXZ80Vi^K09ZJVP2NWYh0WIfM09bLW02VYZH0Y:BT0:2PX02FUYH0VYZJ09NGU`2DU9@0Shn?092@
T02GUiL309>CT`0F09BDU02ATI40S8b<09JFUP2EUID0SXj>08b<S02=SHd0PX:2092@T025QHD0RHV9
08j>SP29RHT0R8R808Z:RP21PH40QXJ607alO022PX80QXJ60861P@80Ng]k00h0QhN708F5Q@1oOgl0
Ogmo08F5Q@22PX80QhN707UiN@1kNg/0NGUi07moO`1nOWh0MGEe07QhN080NWYj00@0O7al07]kN`1h
N7P0Lg=c0P1hN7P0301cLg<0N7Qh07MgM`1`L700JFUY07AdM01[Jf/0MGEe06a/K01VIVH0K6a/06e]
K@<0Jf][01h0IVIV06YZJP1[Jf/0KVi^075aL@1[Jf/0JFUY06YZJP1TI6@0IFEU06QXJ01VIVH0IfMW
065QH@1VIVH0Hf=S06IVIP1UIFD0Hf=S06EUI@1NGUh0IFEU061PH01OGel0IVIV061PH01QHF40HV9R
06=SH`1TI6@206=SH`0>05eMG@1ZJVX0HV9R05iNGP1QHF40GEeM05iNGP1KFe/0J6QX05eMG@1QHF40
GEeM06ATI01NGUh60=WIf@4000000@3IfMT001H0fMWI0P0000040=WIf@0X06ATI01VIVH0GUiN061P
H01MGEd0IfMW05UIF@1PH600GemO069RHP1MGEd0HF5Q06IVIP1UIFD0I6AT05eMG@1WIfL0HF5Q05iN
GP1SHf<0GUiN06IVIP1]KFd0HF5Q05mOG`1PH600GEeM06UYJ@1PH600IfMW06a/K01SHf<0H61P06IV
IP1UIFD0JVYZ069RHP1TI6@0HF5Q06IVIP80Hf=S02<0IFEU069RHP1SHf<0LG5a07=cL`1RHV80J6QX
06YZJP1/K6`0KVi^06e]K@1aLG40Jf][06m_K`1/K6`0IfMW071`L01]KFd0Kfm_06IVIP1`L700K6a/
06m_K`1`L700IfMW06i^KP1bLW80LG5a07]kN`1]KFd0O7al079bLP1kNg/0Lg=c07AdM00207IfMP0;
07EeM@1gMgL0LW9b07YjNP1kNg/0M7Ad07UiN@21PH40Ogmo07inOP1kNg/00`20P800102;Rh/0R8R8
07QhN022PX8208f=S@0;08j>SP2=SHd0QHF508F5Q@23Ph<0RHV908>3P`29RHT0Shn?08Z:RP24Q8@0
0P2<S8`0:02@T900TY:B08j>SP2FUYH0RXZ:09>CT`2?Shl0UIFE09:BTP2GUiL0TY:B08n?S`2HV9P0
UYJF09BDU02ATI40W9bL0:6QX@2LW9`0VYZJ0:6QX@2MWId0WinO0:6QX@2OWil0VIVI09^KV`2OWil0
X:2P0:FUY@2KVi/0XJ6Q09jNWP2PX:00Y:BT0:ZZZP2XZ:P0YjNW0:ZZZP2UYJD20:>SX`80XJ6Q00/0
YZJV0:j^[P2UYJD0Zj^[0;2`/02PX:00YjNW0:j^[P2ZZZX0WYjN0:^[Z`020:FUY@0:0:BTY02_[jl0
ZZZZ0::RXP2YZJT0YZJV0:NWY`2YZJT0[Jf]09jNWP80Zj^[00<0[Jf]0:BTY02VYZH00P2QXJ406@2N
WYh0WinO0:>SX`2VYZH0XJ6Q0:JVYP2RXZ80XJ6Q09nOW`2JVYX0W9bL096AT@2LW9`0TY:B09bLW02<
S8`0UiNG092@T02JVYX0VIVI09NGU`2>SXh0UiNG09:BTP2HV9P00P2@T9000`2DU9@0T92@08n?S`02
08N7Q`0M08^;R`2FUYH0Ti>C08b<S02ATI40Ph>30820P024Q8@0QXJ607alO027QhL0SHf=07inOP24
Q8@0PX:207inOP27QhL0OWin07]kN`26QXH0MWIf07moO`1lO7`0OWin08:2PP1fMWH0NWYj07alO01k
Ng/00P1eMGD04@1dM7@0OGem07EeM@1dM7@0MGEe07UiN@1cLg<0KVi^07=cL`1]KFd0MWIf06m_K`1c
Lg<0JFUY079bLP1[Jf/0LG5a0080K6a/0140L71`06QXJ01_Kfl0KFe]06EUI@1_Kfl0IFEU06a/K01]
KFd0IfMW061PH01XJ6P0K6a/06YZJP1VIVH0JFUY06EUI@0206IVIP0G061PH01WIfL0HF5Q06EUI@1R
HV80KVi^06IVIP1QHF40IFEU05aLG01NGUh0HV9R06ATI01UIFD0IfMW05]KF`1SHf<0HF5Q06=SH`1G
EeL0IFEU05iNGP1KFe/00P1LG5`00`1NGUh0Fe]K0=WIf@040=WIf@8000000@3IfMT001H0fMWI00<0
00000=WIf@3IfMT00`3IfMT02`1TI6@0GUiN061PH01LG5`0HV9R06QXJ01QHF40GemO06ATI01PH600
IfMW0080IFEU03<0IfMW05eMG@1QHF40Jf][061PH01[Jf/0I6AT069RHP1ZJVX0I6AT06UYJ@1TI6@0
HV9R06ATI01`L700J6QX06IVIP1[Jf/0I6AT06EUI@1VIVH0KFe]06QXJ01[Jf/0IFEU06IVIP1RHV80
GemO06=SH`1aLG40I6AT06YZJP1]KFd0HV9R05aLG01XJ6P0JVYZ06EUI@1[Jf/0IfMW06][J`1`L700
J6QX06][J`1ZJVX0Hf=S06m_K`1^KVh0JVYZ075aL@1]KFd00P1aLG40101[Jf/0J6QX06UYJ@1dM7@2
07EeM@0J079bLP1eMGD0MgMg071`L01iNGT0NWYj07EeM@1gMgL0M7Ad07MgM`1nOWh0MgMg07alO026
QXH0OWin0820P01oOgl0Lg=c07MgM`20P800Ph>308N7Q`22PX80Ph>308b<S02:RXX208R8R00708f=
S@28R8P0QHF508F5Q@2=SHd0S8b<08V9R@0208N7Q`0T08b<S02:RXX0Ph>308f=S@2EUID0QhN709FE
U@2ATI40VIVI096AT@2LW9`0Ti>C09:BTP2EUID0TY:B09>CT`2EUID0Vi^K09RHV02EUID0VYZJ09bL
W02HV9P0W9bL09fMW@2NWYh0Vi^K09fMW@2PX:00XZ:R0:JVYP2OWil0YjNW0:6QX@2PX:00Zj^[0P2W
YjL20:VYZ@050:JVYP2/[:`0YJFU0:JVYP2ZZZX00P2WYjL02@2][Jd0[:b/0:>SX`2g]kL0[jn_0:^[
Z`2VYZH0[Jf]0:VYZ@020:n_[`0Y0:j^[P2YZJT0[Zj^0;6a/@2`/;00[Jf]0:VYZ@2VYZH0ZJVY0:NW
Y`2XZ:P0Xj>S0:ZZZP2[Zj/0Z:RX0::RXP2YZJT0YjNW09fMW@2_[jl0YZJV0:6QX@2VYZH0WIfM0:2P
X02ZZZX0YjNW0::RXP2NWYh0XZ:R09nOW`2MWId0VYZJ09nOW`2JVYX0UiNG09:BTP2HV9P0VIVI09:B
TP2FUYH00P2DU9@08P2JVYX0VIVI09NGU`2GUiL0T92@08n?S`2;Rh/0TY:B09>CT`2NWYh0S8b<08j>
SP2?Shl0OGem08:2PP21PH40PX:20861P@24Q8@0NGUi08:2PP1nOWh0PH6107moO`23Ph<0Ogmo07al
O020P800OWin07IfMP1nOWh0MgMg079bLP1gMgL207UiN@0h07QhN01dM7@0NGUi07=cL`1jNWX0M7Ad
07EeM@1hN7P0M7Ad071`L01ZJVX0MWIf06e]K@1bLW80KFe]06QXJ01aLG40J6QX06i^KP1/K6`0Jf][
06i^KP1`L700JVYZ071`L01/K6`0KFe]06=SH`1WIfL0J6QX06IVIP1UIFD0I6AT06MWI`1XJ6P0IVIV
05eMG@1VIVH0HV9R06][J`1SHf<0IVIV06=SH`1RHV80Hf=S06QXJ01VIVH0J6QX06UYJ@1RHV80JFUY
065QH@1PH600JFUY065QH@1WIfL206=SH`0:05mOG`1NGUh0GemO06YZJP1VIVH0Fe]K05IFEP1PH600
GUiN065QH@H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0I06EUI@1RHV80
H61P06UYJ@1UIFD0HF5Q05QHF01OGel0G5aL06=SH`1JFUX0H61P06EUI@1RHV80I6AT069RHP1YJFT0
GEeM05iNGP1QHF40Hf=S065QH@1PH600I6AT06IVIP02061PH00P06IVIP1SHf<0Jf][06i^KP1RHV80
IVIV06a/K01XJ6P0IVIV06YZJP1[Jf/0Hf=S069RHP1]KFd0I6AT06IVIP1YJFT0K6a/07=cL`1^KVh0
IfMW06ATI01^KVh0IfMW06a/K01ZJVX0J6QX06IVIP1[Jf/0KVi^06m_K`1^KVh206m_K`0M06i^KP1a
LG40Kfm_06a/K01^KVh0Lg=c07QhN01/K6`0Kfm_071`L01kNg/0M7Ad07IfMP1dM7@0LW9b07=cL`1d
M7@0MGEe07YjNP1cLg<0NWYj079bLP1gMgL0O7al07UiN@1cLg<0MWIf08F5Q@1nOWh00P20P8003P24
Q8@0PH6108N7Q`25QHD0TY:B08N7Q`2LW9`0TI6A08Z:RP29RHT0Shn?08J6QP2@T900Ogmo0P2:RXX0
5@2ATI40T92@08j>SP2BTY80V9RH096AT@2=SHd0UiNG08j>SP2<S8`0Shn?09>CT`2=SHd0Vi^K09RH
V02KVi/0V9RH0:BTY02HV9P0Vi^K0:JVYP0209nOW`0:09RHV02PX:00Vi^K0:FUY@2LW9`0ZZZZ09bL
W02UYJD0YZJV0:NWY`80YJFU0P2TY:@0802VYZH0Z:RX0:BTY02YZJT0ZZZZ0:j^[P2VYZH0[:b/0:VY
Z@2UYJD0Zj^[0:VYZ@2TY:@0[Jf]0:RXZ02^[Zh0ZZZZ0;Ng]`2[Zj/0]KFe0:ZZZP2g]kL0/k>c0:b/
[02b/[80ZJVY0:^[Z`2_[jl0/;2`0:JVYP2QXJ40YjNW0P2YZJT0402SXj<0ZJVY0:f][@2XZ:P0ZZZZ
0:NWY`2TY:@0Z:RX0:VYZ@2OWil0Y:BT0:VYZ@2VYZH0Z:RX0:NWY`2RXZ8209bLW00:09^KV`2HV9P0
VYZJ09bLW02JVYX0Vi^K0:2PX02GUiL0VIVI09NGU`80UYJF04H0SXj>09nOW`2KVi/0UYJF08j>SP2A
TI40U9BD09VIV@2<S8`0Rh^;09RHV02;Rh/0Shn?0861P@2:RXX0SHf=08V9R@25QHD0QhN708V9R@2@
T900OWin08F5Q@2:RXX0PH6107moO`1kNg/0OWin07emO@21PH40OWin07alO01gMgL0O7al07IfMP1n
OWh0MGEe07MgM`1fMWH0Ng]k07EeM@1cLg<0Kfm_06e]K@1`L700MGEe07=cL`1bLW80Kfm_079bLP1_
Kfl0LW9b06m_K`1^KVh0Jf][075aL@1bLW80KFe]06m_K`1]KFd0IVIV06m_K`1bLW80K6a/06YZJP1T
I6@0IfMW069RHP1WIfL0I6AT0P1VIVH01P1QHF40IFEU069RHP1/K6`0H61P06a/K0<0IVIV01<0JFUY
06EUI@1TI6@0H61P05iNGP1TI6@0GEeM06EUI@1RHV80HF5Q05iNGP1[Jf/0GemO06QXJ01SHf<0HV9R
06ATI01PH600Hf=S0080HF5Q00<0GUiN06IVIP1KFe/01P3IfMT100000040fMWI000F0=WIf@030000
003IfMT0fMWI00<0fMWI01/0I6AT05aLG01OGel0F5QH05]KF`1TI6@0IVIV061PH01UIFD0GUiN06MW
I`1PH600HF5Q06ATI01KFe/0GemO06MWI`1TI6@0HV9R06IVIP1PH600IVIV06QXJ01RHV80GUiN06AT
I01NGUh00P1QHF40<P1]KFd0GUiN06EUI@1WIfL0IFEU06UYJ@1_Kfl0JFUY06ATI01RHV80I6AT06UY
J@1ZJVX0KFe]06=SH`1ZJVX0IFEU06ATI01aLG40I6AT06QXJ01^KVh0Kfm_06e]K@1`L700JVYZ06][
J`1dM7@0LG5a07EeM@1/K6`0NWYj06e]K@1TI6@0K6a/07IfMP1_Kfl0L71`07AdM01aLG40MGEe07Ad
M01aLG40M7Ad079bLP1fMWH0Lg=c06i^KP1eMGD0N7Qh0P1fMWH03@1gMgL0M7Ad07UiN@1hN7P0MgMg
07emO@25QHD0Ph>307inOP22PX80Q8B40861P@29RHT00P25QHD208f=S@0H096AT@2<S8`0SHf=08J6
QP2<S8`0SXj>07inOP2>SXh0QHF5096AT@23Ph<0SXj>08n?S`2BTY80U9BD096AT@2LW9`0WIfM096A
T@2IVIT0VYZJ09FEU@2GUiL0TI6A0P2FUYH04P2EUID0WYjN09:BTP2JVYX0WIfM09^KV`2PX:00WYjN
09fMW@2RXZ80WinO09bLW02TY:@0XZ:R09fMW@2UYJD0WYjN0:f][@80ZJVY01<0YJFU0:j^[P2[Zj/0
YjNW0:^[Z`2YZJT0Y:BT0:FUY@2[Zj/0[jn_0;:b/P2_[jl0[Jf]0:FUY@2`/;00Xj>S0:^[Z`2][Jd0
];Bd0080[Zj^02T0^k^k0;Zj^P2c/k<0Zj^[0:j^[P2WYjL0/;2`0;:b/P2[Zj/0ZJVY0:n_[`2^[Zh0
Zj^[0:ZZZP2c/k<0[Jf]0;6a/@2[Zj/0Xj>S0:^[Z`2YZJT0[:b/0:ZZZP2UYJD0WIfM0:>SX`2VYZH0
XZ:R0:>SX`2KVi/0Xj>S0:6QX@2JVYX0W9bL09VIV@2FUYH0W9bL09fMW@2HV9P0WIfM09>CT`0209RH
V00C092@T02EUID0VIVI09FEU@2GUiL0Shn?09JFUP2EUID0Ti>C092@T02DU9@0Ti>C08^;R`2?Shl0
R8R808>3P`27QhL0QXJ608N7Q`0208b<S00307inOP2;Rh/0QhN70080P8200180QHF507alO01oOgl0
OWin07]kN`1gMgL0MGEe07alO01bLW80OWin07MgM`1lO7`0OGem07alO01fMWH0Ng]k071`L01aLG42
07UiN@0607AdM01aLG40M7Ad06e]K@1gMgL0Kfm_0P1^KVh0:`1[Jf/0K6a/06i^KP1aLG40IfMW06m_
K`1cLg<0Jf][06i^KP1/K6`0KFe]06=SH`1TI6@0IfMW06EUI@1QHF40J6QX06a/K01OGel0J6QX05iN
GP1PH600J6QX069RHP1YJFT0HF5Q069RHP1QHF40K6a/065QH@1UIFD0GEeM06a/K01VIVH0HF5Q06UY
J@1TI6@0Hf=S06EUI@1XJ6P0HV9R061PH01RHV800P1SHf<01`1NGUh0H61P06IVIP1QHF40EUIF05mO
G`1LG5`01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00@0HV9R05mOG`1O
Gel0Fe]K0P1SHf<0201VIVH0H61P06QXJ01TI6@0H61P05eMG@1TI6@0HF5Q0P1TI6@0101XJ6P0HV9R
06=SH`1WIfL206UYJ@0C06EUI@1RHV80G5aL05UIF@1TI6@0IfMW06IVIP1WIfL0KFe]06ATI01YJFT0
J6QX06=SH`1YJFT0Hf=S06UYJ@1SHf<0JFUY06MWI`0306][J`0706i^KP1[Jf/0K6a/06YZJP1[Jf/0
HF5Q06e]K@0206=SH`1C06YZJP1^KVh0M7Ad079bLP1WIfL0MWIf07=cL`1aLG40KVi^06m_K`1^KVh0
Jf][07=cL`1bLW80KVi^07EeM@1[Jf/0M7Ad07MgM`1jNWX0Lg=c079bLP1aLG40MWIf07emO@1jNWX0
N7Qh07]kN`1lO7`0OGem07YjNP1hN7P0Ph>307inOP1iNGT0Ng]k08B4Q020P800OWin07emO@29RHT0
Ph>308Z:RP2DU9@0SHf=096AT@2<S8`0RXZ:08R8R024Q8@0RHV908J6QP2=SHd0RHV908J6QP29RHT0
Q8B408f=S@2DU9@0TI6A092@T02?Shl0QhN709BDU02BTY80V9RH09FEU@2LW9`0WIfM09RHV02GUiL0
UIFE09nOW`2IVIT0V9RH09fMW@2NWYh0V9RH0:BTY02VYZH0W9bL09jNWP2VYZH00P2SXj<0302UYJD0
YZJV0:FUY@2[Zj/0YJFU0:j^[P2SXj<0[Jf]0:j^[P2[Zj/0YZJV0:f][@80ZJVY03D0/K6a0:j^[P2_
[jl0Y:BT0;Bd]02`/;00];Bd0;2`/02j^[X0/K6a0:b/[02g]kL0]KFe0<71`@2g]kL0/K6a0;:b/P2/
[:`0[Zj^0;>c/`2_[jl0];Bd0:VYZ@2a/K40/;2`0:n_[`2YZJT0Z:RX0;2`/02][Jd0Z:RX0;:b/P2d
];@0Y:BT0:2PX02ZZZX0Xj>S0:^[Z`2XZ:P0ZZZZ0:NWY`2NWYh0WinO0:2PX02SXj<0WYjN09ZJVP2O
Wil0Vi^K0:FUY@2LW9`0VIVI09jNWP0209RHV00Q09NGU`2FUYH0Vi^K092@T02CTi<0UIFE09NGU`2<
S8`0T92@09NGU`2;Rh/0U9BD09JFUP2CTi<0R8R808F5Q@28R8P0QXJ607moO`22PX80Ng]k08^;R`23
Ph<0RHV908F5Q@1oOgl0OGem08V9R@23Ph<0O7al07moO`23Ph<0P8200080MgMg0100P82007UiN@1h
N7P0MgMg07YjNP1bLW80O7al07=cL`1_Kfl0MGEe07IfMP1^KVh0NGUi06i^KP1bLW80K6a/0P1`L700
3`1cLg<0Kfm_071`L01hN7P0K6a/06MWI`1^KVh0KFe]06UYJ@1ZJVX0IfMW06i^KP1/K6`0IfMW06UY
J@0206a/K00<069RHP1TI6@0K6a/06i^KP1/K6`0KFe]07IfMP1SHf<0JFUY06QXJ01OGel0H61P0P1V
IVH0101TI6@0GEeM06=SH`1RHV8206UYJ@0306=SH`1[Jf/0HF5Q0080IfMW00`0I6AT05aLG01JFUX0
H61P05eMG@1SHf<0GUiN05eMG@1OGel0FEUI05YJFP1LG5`60=WIf@4000000@3IfMT001H0fMWI00<0
00000=WIf@3IfMT00`3IfMT0501PH600GemO05eMG@1QHF40Fe]K05QHF01RHV80FUYJ069RHP1[Jf/0
H61P06EUI@1VIVH0GUiN06EUI@1VIVH0GUiN06IVIP1OGel0HV9R0P1SHf<01P1YJFT0HV9R06MWI`1P
H600GUiN06ATI0<0IFEU00H0IfMW06UYJ@1ZJVX0IFEU06YZJP1TI6@206e]K@0P069RHP1SHf<0IFEU
06QXJ01aLG40H61P06m_K`1WIfL0KVi^065QH@1WIfL0JVYZ075aL@1_Kfl0J6QX06a/K01]KFd0JVYZ
071`L01jNWX0Kfm_07=cL`1bLW80Lg=c06e]K@1`L700Kfm_079bLP1cLg<0M7Ad07YjNP1hN7P207Ad
M00606m_K`1cLg<0Lg=c07AdM01kNg/0MgMg0P1hN7P00`1dM7@0OGem07YjNP020861P@0907]kN`22
PX80R8R80861P@1oOgl0Q8B407moO`27QhL0Q8B40080QhN701D0RXZ:08N7Q`2:RXX0Ph>308V9R@2?
Shl0QXJ608R8R029RHT0Rh^;08V9R@2:RXX0T92@09JFUP2;Rh/0UYJF09FEU@2=SHd0Ti>C08j>SP2E
UID00P2DU9@0402GUiL0WIfM09VIV@2CTi<0WinO0:6QX@2PX:00WIfM0:>SX`2LW9`0WYjN09ZJVP2V
YZH0ZZZZ0:b/[02YZJT20:FUY@0Y0:BTY02VYZH0ZZZZ0:RXZ02VYZH0/k>c0:b/[02YZJT0Z:RX0;>c
/`2][Jd0[jn_0;:b/P2f][H0/;2`0;6a/@2_[jl0/K6a0;Fe]@2a/K40];Bd0:^[Z`2c/k<0ZJVY0;Zj
^P2h^;P0[Jf]0:n_[`2h^;P0];Bd0;6a/@2c/k<0^KVi0;Jf]P2d];@0/;2`0:j^[P2b/[80Zj^[0:VY
Z@2a/K400P2b/[802@2c/k<0Z:RX0:RXZ02][Jd0[jn_0:JVYP2YZJT0[:b/0:VYZ@020:^[Z`0_0:NW
Y`2MWId0ZZZZ0:BTY02RXZ80WIfM0:6QX@2NWYh0YZJV0:BTY02QXJ40WinO0:6QX@2LW9`0WinO09FE
U@2GUiL0XZ:R09FEU@2@T900TY:B09VIV@2<S8`0SXj>08f=S@2FUYH0VYZJ08b<S02BTY80SHf=08^;
R`2CTi<0SXj>08f=S@21PH40SXj>08b<S02:RXX0SHf=096AT@29RHT0R8R808Z:RP23Ph<0PX:207Qh
N01oOgl00P1kNg/01`22PX80OWin07inOP1mOGd0OWin07QhN01lO7`00P1iNGT207AdM00;07IfMP1`
L700MWIf07EeM@1]KFd0Kfm_071`L01aLG40KVi^07alO01eMGD00P1_Kfl02`1/K6`0M7Ad06YZJP1]
KFd0JFUY06e]K@1aLG40IVIV06UYJ@1/K6`0IfMW0080JFUY0100IfMW065QH@1bLW80LG5a06UYJ@1]
KFd0IFEU069RHP1SHf<0H61P06IVIP1QHF40IfMW06ATI01SHf<0KFe]0P1QHF403`1OGel0J6QX05mO
G`1SHf<0HV9R06ATI01OGel0HV9R05YJFP1[Jf/0Hf=S05iNGP1KFe/0HF5Q069RHP0205iNGP03065Q
H@3IfMT0fMWI00@0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@08065QH@1O
Gel0H61P06ATI01XJ6P0HV9R065QH@1TI6@206EUI@0<05mOG`1TI6@0JFUY06EUI@1MGEd0IFEU05mO
G`1QHF40H61P06a/K01TI6@0HF5Q0P1TI6@0701PH600HV9R06a/K01[Jf/0JFUY06EUI@1TI6@0HV9R
071`L01YJFT0K6a/06][J`1TI6@0J6QX06EUI@1^KVh0IfMW06=SH`1/K6`0KFe]06IVIP1[Jf/0Kfm_
06e]K@1/K6`0I6AT06YZJP1UIFD3075aL@0706i^KP1kNg/0JVYZ07MgM`1eMGD0LG5a06a/K00207Ad
M00n07MgM`1fMWH0K6a/07EeM@1WIfL0LW9b06i^KP1_Kfl0KVi^07AdM01bLW80MWIf07UiN@1jNWX0
P82007=cL`1lO7`0MgMg07YjNP1iNGT0NWYj08:2PP20P800PX:20861P@22PX80P82008F5Q@23Ph<0
S8b<08J6QP21PH40QHF508V9R@27QhL0P82008N7Q`2@T900S8b<08N7Q`2=SHd0RHV908^;R`2>SXh0
Vi^K08N7Q`2CTi<0SXj>09FEU@2=SHd0TI6A08n?S`2GUiL0V9RH09jNWP2MWId0W9bL0::RXP2QXJ40
WYjN09fMW@2NWYh20:6QX@050::RXP2MWId0[:b/0:NWY`2QXJ400P2TY:@03`2SXj<0YZJV0:n_[`2^
[Zh0YZJV0;>c/`2XZ:P0/k>c0;Bd]02/[:`0[jn_0;>c/`2^[Zh0/;2`0;Ng]`020;6a/@070;Fe]@2f
][H0]kNg0;:b/P2`/;00];Bd0;2`/0020;>c/`080;Rh^02m_Kd0/K6a0<;2`P30`<00^KVi0;>c/`2i
^KT20;:b/P070;Zj^P2`/;00];Bd0;Ng]`2ZZZX0];Bd0:n_[`020;Bd]0050:n_[`2][Jd0/K6a0:^[
Z`2a/K400P2[Zj/01@2XZ:P0ZJVY0:^[Z`2TY:@0Z:RX0080YjNW00D0WinO0::RXP2EUID0Vi^K0:BT
Y0020::RXP080:2PX02LW9`0VIVI09RHV02MWId0Vi^K09JFUP2JVYX309VIV@80U9BD0100TY:B096A
T@2FUYH0Ti>C09FEU@2<S8`0T92@08b<S02BTY80QXJ608B4Q02=SHd0RXZ:08R8R02?Shl0Ti>C0P2?
Shl03@24Q8@0RHV908b<S01mOGd0P82008:2PP1lO7`0Ng]k0861P@1kNg/0NWYj07moO`1jNWX00P1h
N7P0201kNg/0KVi^07YjNP1iNGT0Kfm_06a/K01kNg/0MWIf0P1cLg<01P1_Kfl0LG5a07=cL`1aLG40
KVi^07=cL`80M7Ad00P0KVi^075aL@1/K6`0IfMW06YZJP1WIfL0K6a/06UYJ@80JVYZ02L0IVIV06QX
J01^KVh0JVYZ06QXJ01bLW80IFEU06QXJ01OGel0IVIV06a/K01ZJVX0J6QX06=SH`1[Jf/0JFUY05eM
G@1SHf<0H61P06YZJP1SHf<0IfMW069RHP1XJ6P0GemO061PH01TI6@0JFUY06e]K@1SHf<0H61P06=S
H`1QHF40G5aL061PH01SHf<0GEeM05mOG`1JFUX01P3IfMT100000040fMWI000F0=WIf@030000003I
fMT0fMWI00<0fMWI02L0GemO05YJFP1PH600G5aL065QH@1NGUh0Hf=S05aLG01YJFT0GUiN069RHP1U
IFD0Hf=S06IVIP1OGel0I6AT065QH@1ZJVX0HV9R06ATI01VIVH0I6AT06EUI@1RHV80J6QX069RHP1P
H600IFEU06=SH`1ZJVX0JFUY06EUI@1VIVH0I6AT06][J`1]KFd0JVYZ06MWI`1UIFD00P1XJ6P03`1Z
JVX0IfMW06IVIP1VIVH0L71`06e]K@1YJFT0KFe]06MWI`1[Jf/0Kfm_06a/K01WIfL0IVIV07EeM@02
06i^KP80L71`02L0KFe]07AdM01cLg<0Jf][07QhN01bLW80NWYj079bLP1_Kfl0MGEe07MgM`1iNGT0
MWIf07=cL`1fMWH0Ng]k07YjNP1]KFd0O7al07UiN@1kNg/0MgMg07YjNP1kNg/0Ogmo08N7Q`1oOgl0
Q8B40820P022PX80QXJ608V9R@1nOWh0RXZ:08:2PP2=SHd0RXZ:08:2PP1lO7`00P25QHD04P2;Rh/0
QhN708B4Q02>SXh0UYJF092@T02FUYH0TI6A08V9R@2BTY80UiNG09:BTP2@T900UIFE09RHV02JVYX0
UiNG09bLW080VYZJ0340XZ:R09bLW02MWId0W9bL0:BTY02OWil0UYJF09jNWP2GUiL0Z:RX0:JVYP2Z
ZZX0Xj>S0:2PX02XZ:P0[Jf]0:VYZ@2[Zj/0[Zj^0:n_[`2UYJD0/k>c0;Jf]P2c/k<0];Bd0;:b/P2c
/k<0^;Rh0;^k^`2h^;P0[jn_0;Fe]@2`/;00]kNg0;Bd]02c/k<0^[Zj0;Ng]`2m_Kd0][Jf0;Vi^@2g
]kL0]KFe0<K6aP2j^[X0/[:b0:n_[`2i^KT0/k>c0080^KVi00<0];Bd0;Jf]P2i^KT00`2^[Zh0=P2`
/;00^;Rh0;6a/@2b/[80[Zj^0:b/[02YZJT0[Jf]0:ZZZP2/[:`0ZJVY0:b/[02XZ:P0[:b/0:NWY`2U
YJD0Xj>S0:NWY`2JVYX0XZ:R0:2PX02WYjL0X:2P09jNWP2EUID0W9bL09jNWP2PX:00XZ:R09ZJVP2?
Shl0Vi^K09>CT`2NWYh0UYJF096AT@2<S8`0UYJF08f=S@27QhL0S8b<09FEU@2ATI40RHV909>CT`2;
Rh/0RXZ:08n?S`24Q8@0Ph>308j>SP2<S8`0Rh^;08J6QP80RHV900P0S8b<07inOP1iNGT0PH6108N7
Q`1oOgl0PH610820P0<0OWin00<0Q8B407alO01mOGd00P1eMGD207UiN@0V07AdM01eMGD0MGEe07Mg
M`1eMGD0JFUY07QhN01cLg<0LG5a06i^KP1]KFd0LG5a07=cL`1bLW80KVi^06UYJ@1`L700Jf][06e]
K@1_Kfl0M7Ad071`L01/K6`0LW9b06MWI`1bLW80IfMW06i^KP1bLW80JVYZ06m_K`1aLG40KVi^06UY
J@1WIfL0JVYZ06ATI01[Jf/2069RHP0406EUI@1VIVH0J6QX065QH@80GEeM00H0GemO06=SH`1RHV80
H61P06e]K@1TI6@2061PH080HF5Q00H0HV9R05aLG01EEED0GemO05MGE`1RHV860=WIf@4000000@3I
fMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT02@1PH600EeMG05mOG`1PH600Hf=S05iNGP1UIFD0
HV9R06=SH`0205eMG@0F06ATI01SHf<0HF5Q06ATI01QHF40H61P06QXJ01OGel0J6QX069RHP1QHF40
J6QX06=SH`1OGel0J6QX05mOG`1MGEd0G5aL06=SH`1XJ6P0HF5Q06YZJP80I6AT01D0JVYZ05iNGP1Y
JFT0HF5Q06MWI`1]KFd0IVIV06a/K01XJ6P0IVIV06YZJP1XJ6P0IFEU06][J`1YJFT0Jf][06e]K@1b
LW80JFUY06a/K01]KFd00P1`L700901^KVh0KFe]06][J`1/K6`0N7Qh06m_K`1[Jf/0MGEe075aL@1c
Lg<0L71`07EeM@1aLG40MWIf06m_K`1bLW80Ng]k07UiN@1hN7P0NWYj07]kN`1mOGd0P82007EeM@1l
O7`0P82007alO01oOgl0Q8B408V9R@27QhL0Ph>307UiN@1oOgl0P82008N7Q`80Q8B401/0QXJ608F5
Q@24Q8@0RHV908N7Q`26QXH0SHf=08j>SP2BTY80SHf=08n?S`2@T900SXj>096AT@2DU9@0SXj>09BD
U02JVYX0UIFE09ZJVP2MWId0WinO09VIV@2LW9`0WIfM0:^[Z`2NWYh00P2QXJ403P2OWil0Z:RX0::R
XP2WYjL0Xj>S09jNWP2YZJT0XZ:R09nOW`2][Jd0YJFU0:^[Z`2_[jl0[:b/0`2b/[800`2d];@0][Jf
0:n_[`020;>c/`80/[:b0180];Bd0;Ng]`2g]kL0_[jn0;no_`2e]KD0^;Rh0;Vi^@2j^[X0^k^k0;bl
_02g]kL0^;Rh0<71`@2n_[h0_;bl0;^k^`33`l<20;bl_0080;Rh^02n_[h0/k>c0;^k^`2n_[h0_Kfm
0;Jf]P2a/K420;Zj^P80]KFe01T0/;2`0:j^[P2e]KD0]KFe0;6a/@2c/k<0ZJVY0;>c/`2a/K40]KFe
0:JVYP2_[jl0[:b/0:VYZ@2VYZH0Y:BT0:^[Z`2TY:@0XZ:R0:NWY`2RXZ80W9bL09fMW@2SXj<0V9RH
0080Vi^K0140WYjN092@T02@T900XZ:R09^KV`2>SXh0V9RH092@T02GUiL0Ti>C09NGU`2:RXX0U9BD
08n?S`2=SHd0RHV908n?S`0208R8R00<08B4Q02;Rh/0RHV908^;R`27QhL0R8R808:2PP2<S8`0PX:2
07moO`21PH40PX:20P1mOGd01`1kNg/0Ogmo07alO01hN7P0NGUi0820P01kNg/00P1lO7`02P1dM7@0
LW9b075aL@1bLW80N7Qh07AdM01`L700LG5a06QXJ01fMWH206e]K@0I07=cL`1aLG40Kfm_06IVIP1^
KVh0Kfm_071`L01]KFd0Jf][06e]K@1WIfL0JFUY071`L01VIVH0JFUY071`L01/K6`0IVIV06ATI01a
LG40Lg=c06m_K`1^KVh0L71`06=SH`0206YZJP0>06=SH`1ZJVX0K6a/065QH@1SHf<0IFEU069RHP1Q
HF40IVIV06EUI@1QHF40JFUY05aLG01XJ6P206=SH`0905eMG@1QHF40GUiN06EUI@1OGel0JFUY065Q
H@1MGEd0GemO00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@19061PH01K
Fe/0FUYJ05iNGP1@D500JFUY06ATI01KFe/0I6AT05eMG@1NGUh0JFUY06=SH`1TI6@0HV9R06EUI@1Y
JFT0J6QX065QH@1SHf<0HV9R05iNGP1/K6`0IVIV06YZJP1SHf<0I6AT069RHP1MGEd0Hf=S06UYJ@1P
H600HV9R06ATI01WIfL0HV9R06UYJ@1VIVH0Jf][06a/K01PH600KFe]06ATI01ZJVX0IfMW06QXJ01^
KVh0IfMW06m_K`1aLG40IfMW06IVIP1/K6`0KVi^07EeM@1/K6`0L71`06i^KP1[Jf/0KVi^06][J`1g
MgL0LW9b07UiN@1aLG40L71`06a/K01dM7@0JVYZ079bLP1^KVh0NWYj07UiN@0207IfMP0707YjNP1h
N7P0N7Qh07]kN`22PX80P82007]kN`0207emO@0507YjNP1kNg/0P82008F5Q@1oOgl00P23Ph<05P20
P800RXZ:08^;R`28R8P0Ph>309>CT`21PH40RHV90861P@2<S8`0T92@08b<S02ATI40Q8B408R8R02D
U9@0TY:B08R8R02DU9@0QXJ609VIV@2ATI4209NGU`0509^KV`2IVIT0W9bL09JFUP2LW9`0102QXJ40
5P2XZ:P0YjNW0:VYZ@2WYjL0XJ6Q0:RXZ02ZZZX0[Jf]0:VYZ@2[Zj/0[Zj^0:b/[02e]KD0[Jf]0;Fe
]@2g]kL0/K6a0;2`/02b/[80[Zj^0;Rh^02a/K420;fm_@070;Fe]@2a/K40`L710;jn_P30`<00_kno
0;Zj^P020;Rh^00B0;^k^`2g]kL0_Kfm0<C4a02n_[h0a<C40<30`031`L40_;bl0;^k^`2m_Kd0]KFe
0;no_`2h^;P0_;bl0;jn_P2i^KT0_[jn0P2k^k/0:P2h^;P0_[jn0;2`/02h^;P0/[:b0;Ng]`2i^KT0
]KFe0;:b/P2k^k/0Zj^[0;Ng]`2_[jl0][Jf0;Ng]`2SXj<0[Jf]0:NWY`2/[:`0Z:RX0:f][@2YZJT0
[:b/09nOW`2VYZH0Z:RX09jNWP2HV9P0WinO0:>SX`2QXJ40Xj>S09^KV`2FUYH0WinO09bLW02JVYX0
Vi^K09FEU@2<S8`0U9BD08b<S080T92@00P0SXj>08N7Q`26QXH0RXZ:08J6QP2;Rh/0RHV908b<S080
QXJ600d0OWin08B4Q01nOWh0Ph>308F5Q@2<S8`0QXJ60861P@1kNg/0N7Qh08B4Q01oOgl0P8200080
MWIf00L0P82007YjNP1kNg/0MWIf07=cL`1kNg/0LG5a0080N7Qh0240Lg=c07QhN01eMGD0LW9b07Ui
N@1]KFd0L71`06m_K`1eMGD0Kfm_06UYJ@1/K6`0KFe]06][J`1^KVh0Hf=S06][J`1aLG40K6a/06][
J`1bLW80L71`06e]K@1WIfL0K6a/06YZJP1^KVh0KFe]06a/K01[Jf/0KVi^06=SH`1UIFD00P1TI6@0
1@1SHf<0GemO06ATI01RHV80H61P0080I6AT00`0GemO06ATI01UIFD0I6AT05YJFP1OGel0HV9R06MW
I`1NGUh0Fe]K069RHP1KFe/2065QH@0305aLG01MGEd0HF5Q00H0fMWI0@0000010=WIf@0000<0fMWI
0000000000000`0000020=WIf@800000103IfMT2000000H0fMWI00<000000=WIf@3IfMT00`3IfMT0
0`1QHF40GEeM069RHP0205mOG`0506ATI01SHf<0J6QX065QH@1TI6@00P1RHV8206EUI@80H61P00<0
IVIV065QH@1XJ6P00P1SHf<02P1PH600HF5Q061PH01WIfL0HV9R06EUI@1PH600GUiN06=SH`1ZJVX2
06IVIP0=06=SH`1WIfL0Jf][06YZJP1XJ6P0IVIV071`L01VIVH0LG5a06a/K01YJFT0J6QX06][J`02
06m_K`0306e]K@1YJFT0Kfm_0080L71`01h0Kfm_06e]K@1XJ6P0KFe]071`L01cLg<0LG5a079bLP1c
Lg<0Kfm_07=cL`1bLW80M7Ad07QhN01cLg<0K6a/07EeM@1fMWH0O7al07=cL`1eMGD0Ogmo07UiN@1e
MGD0OWin0820P01mOGd0NWYj07inOP1lO7`208B4Q00307alO020P800P8200080P8200100QhN70820
P028R8P0SXj>08:2PP2<S8`0Q8B408N7Q`2=SHd0Q8B408^;R`2<S8`0Rh^;09>CT`2@T900S8b<0P2B
TY801P2CTi<0SXj>08f=S@2ATI40UIFE09JFUP80VYZJ00h0WYjN09NGU`2RXZ80WIfM0:BTY02RXZ80
XJ6Q0:NWY`2VYZH0XJ6Q09bLW02/[:`0YjNW0:>SX`80[jn_00P0[:b/0;2`/02VYZH0Z:RX0:JVYP2_
[jl0/K6a0;Fe]@<0/;2`00h0][Jf0;Zj^P2c/k<0/K6a0;Ng]`30`<00][Jf0<W9b@2m_Kd0^k^k0;Vi
^@36a/H0^;Rh0;Ng]`80aLG50P2j^[X0402l_;`0d];B0<G5a@2o_kl0a/K60;Rh^030`<00_kno0;^k
^`2n_[h0^KVi0;no_`2`/;00`L710;jn_P30`<020;jn_P80^k^k00P0`<300;^k^`2k^k/0][Jf0;Fe
]@2j^[X0/K6a0:f][@80/k>c0P2XZ:P02P2c/k<0/[:b0:VYZ@2VYZH0Zj^[0:BTY02RXZ80WinO0:f]
[@2PX:020::RXP0509ZJVP2LW9`0YJFU09bLW02KVi/00P2PX:001P2DU9@0UiNG09>CT`2ATI40TY:B
08^;R`80RXZ:00L0UYJF09:BTP2BTY80S8b<08j>SP2=SHd0S8b<0080QXJ600<0Rh^;08R8R02=SHd0
0P22PX800`1nOWh0O7al08:2PP0208:2PP0:08B4Q01gMgL0O7al08>3P`1nOWh0OGem07moO`1hN7P0
M7Ad07MgM`80MGEe0P1hN7P0501gMgL0Lg=c07QhN01bLW80MGEe07IfMP1`L700KFe]075aL@1cLg<0
L71`06m_K`1[Jf/0LG5a071`L01/K6`0LW9b06ATI01bLW80L71`0P1^KVh07P1XJ6P0Kfm_06a/K01Y
JFT0IFEU06][J`1ZJVX0Jf][06YZJP1VIVH0K6a/069RHP1XJ6P0GemO06UYJ@1ZJVX0IFEU065QH@1T
I6@0IFEU06=SH`1TI6@0IFEU06UYJ@1JFUX0HV9R06EUI@1XJ6P0IFEU06ATI080IFEU00@0GemO06IV
IP1VIVH0HF5Q0P1PH6000`1NGUh0fMWI0=WIf@040=WIf@4000000@3IfMT000<0fMWI00D000000=WI
f@3IfMT0fMWI000000020=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT00`3I
fMT00`000000fMWI0=WIf@030=WIf@0F06IVIP1OGel0IVIV061PH01SHf<0HV9R05eMG@1SHf<0HF5Q
061PH01KFe/0IVIV05mOG`1NGUh0G5aL06EUI@1^KVh0HV9R06ATI01RHV80IfMW06][J`80IVIV00h0
FUYJ06=SH`1TI6@0Hf=S06ATI01NGUh0IFEU06=SH`1NGUh0J6QX061PH01RHV80I6AT065QH@80JVYZ
00<0IVIV061PH01ZJVX00P1YJFT04P1[Jf/0KFe]06m_K`1^KVh0LG5a06][J`1^KVh0JVYZ079bLP1Y
JFT0K6a/06EUI@1]KFd0L71`07UiN@1eMGD0JVYZ07IfMP80LG5a01L0Kfm_07IfMP1`L700Ng]k07Ee
M@1/K6`0Ng]k071`L01cLg<0MWIf07AdM01nOWh0OGem07alO01kNg/0PH6108B4Q01hN7P0P82007]k
N`1iNGT0Ph>30861P@0207emO@0907moO`2;Rh/0QXJ608f=S@2<S8`0RXZ:08^;R`20P800QXJ60080
RHV900<0RXZ:08n?S`2<S8`00P28R8P309:BTP0609VIV@2HV9P0VYZJ09nOW`2JVYX0UYJF0P2MWId0
;P2LW9`0YJFU09nOW`2KVi/0YJFU09fMW@2RXZ80YjNW0:6QX@2e]KD0ZJVY0:j^[P2/[:`0Xj>S0:JV
YP2YZJT0/[:b0:RXZ02/[:`0]KFe0;fm_@2c/k<0][Jf0;:b/P2i^KT0^[Zj0;:b/P2d];@0^KVi0;bl
_035aLD0`/;20;jn_P2k^k/0`/;20;^k^`33`l<0];Bd0<O7a`2i^KT0`/;20<_;b`33`l<0aLG50<O7
a`39bLT20<?3``0^0<71`@32`/80^k^k0<71`@32`/80_[jn0;fm_@30`<00_;bl0<;2`P33`l<0alO7
0<C4a02n_[h0`L710<;2`P2k^k/0]KFe0;^k^`2l_;`0]kNg0;fm_@2i^KT0]kNg0;Bd]02c/k<0/[:b
0:b/[02[Zj/0[Zj^09nOW`2a/K40[Jf]0:ZZZP2WYjL0[Jf]0:BTY02/[:`0Vi^K0:6QX@2VYZH0WYjN
09VIV@2KVi/0XZ:R09jNWP80Vi^K01@0V9RH09bLW02IVIT0UYJF09bLW02HV9P0SXj>08^;R`2<S8`0
SXj>09JFUP2ATI40RHV908j>SP2<S8`0Shn?08V9R@22PX80Ph>308J6QP80P82000X0RXZ:08J6QP27
QhL0P82007emO@1nOWh0PX:208B4Q01oOgl0QHF50P1nOWh0@`22PX80O7al07inOP1lO7`0Ng]k07=c
L`1bLW80L71`07emO@1dM7@0LW9b07=cL`1fMWH0M7Ad06i^KP1gMgL0N7Qh071`L01gMgL0K6a/0861
P@1eMGD0L71`06QXJ01hN7P0MWIf07=cL`1ZJVX0LW9b071`L01bLW80I6AT06UYJ@1/K6`0IVIV06QX
J01MGEd0Hf=S06IVIP1/K6`0JFUY06YZJP1TI6@0J6QX06MWI`1`L700H61P06=SH`1TI6@0GemO05YJ
FP1QHF40Hf=S06MWI`1]KFd0Jf][06IVIP1NGUh0IfMW05iNGP1PH600GUiN069RHP1OGel0IFEU061P
H01SHf<01P3IfMT100000040fMWI00030=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT01000
0000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00<0fMWI0`0000030=WIf@0?05aLG01WIfL0
GUiN065QH@1XJ6P0HV9R061PH01WIfL0Hf=S06IVIP1LG5`0Fe]K065QH@1XJ6P0HV9R0080IVIV00/0
HV9R05mOG`1XJ6P0H61P06YZJP1VIVH0IFEU061PH01XJ6P0Hf=S06][J`0206ATI00306QXJ01YJFT0
HF5Q0080IFEU00H0I6AT06UYJ@1RHV80J6QX06MWI`1]KFd206][J`0@06YZJP1_Kfl0KVi^06e]K@1_
Kfl0JVYZ06m_K`1hN7P0Kfm_075aL@1_Kfl0JFUY075aL@1WIfL0L71`06UYJ@80Jf][01l0LG5a06i^
KP1gMgL0LW9b07AdM01hN7P0MGEe079bLP1aLG40L71`07emO@1bLW80M7Ad07MgM`1lO7`0NWYj071`
L021PH40Ogmo0861P@22PX80OGem07QhN020P800Ph>308j>SP1nOWh0OGem08:2PP1mOGd0R8R80080
QXJ600L0QhN708f=S@29RHT0RHV908B4Q02<S8`0RXZ:0080R8R802X0Rh^;08R8R02ATI40SXj>09BD
U02KVi/0W9bL09JFUP2IVIT0UYJF0:2PX02HV9P0XZ:R0:6QX@2OWil0U9BD09VIV@2RXZ80X:2P0:BT
Y02VYZH0Y:BT0:ZZZP2TY:@0YZJV0:f][@2^[Zh0ZJVY0:^[Z`2b/[80_;bl0:j^[P2e]KD0[:b/0;Bd
]02`/;00];Bd0;Rh^02k^k/0a/K60;^k^`2g]kL20;Zj^P0/0;jn_P32`/80a/K60<;2`P2h^;P0`<30
0;fm_@2l_;`0a<C40<30`033`l<0`L710<C4a02n_[h0bLW90<C4a03;bl/0_kno0<?3``2n_[h0`<30
0<71`@2k^k/0`/;20<[:bP3=cLd0a<C40<O7a`2m_Kd0`L710<;2`P33`l<0^k^k0<30`02m_Kd0]kNg
0<;2`P34a<@0_[jn0;fm_@2i^KT0]KFe0;Zj^P2f][H20;:b/P0E0:^[Z`2VYZH0Y:BT0:NWY`2UYJD0
Zj^[0:RXZ02TY:@0Z:RX0:2PX02XZ:P0WYjN09nOW`2MWId0Y:BT09fMW@2OWil0VYZJ0::RXP2MWId0
W9bL0080UYJF00D0TY:B092@T02JVYX0TY:B09>CT`0209:BTP0P08J6QP2=SHd0TI6A08n?S`2<S8`0
R8R808B4Q026QXH0SXj>08V9R@25QHD0PX:208^;R`23Ph<0PX:208N7Q`22PX80OWin0861P@1jNWX0
O7al07MgM`1oOgl0P82007MgM`1_Kfl0N7Qh07IfMP1jNWX0MgMg07moO`1iNGT207AdM00A07QhN01b
LW80L71`071`L01gMgL0L71`06a/K01cLg<0Jf][07MgM`1]KFd0Kfm_071`L01aLG40KVi^075aL@1X
J6P00`1ZJVX01P1YJFT0I6AT06QXJ01XJ6P0Jf][06MWI`80JFUY01P0KVi^069RHP1TI6@0JVYZ06MW
I`1^KVh0J6QX06a/K01QHF40IFEU069RHP1WIfL0IFEU06a/K01KFe/0Hf=S071`L01/K6`0LG5a06QX
J01VIVH0H61P05YJFP1TI6@2069RHP0305UIF@1RHV80GUiN00@0fMWI0`0000010=WIf@000`3IfMT0
1@000000fMWI0=WIf@3IfMT000000080fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI
0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI0400GemO05aLG01SHf<0GUiN05mOG`1RHV80G5aL
05eMG@1JFUX0GUiN05mOG`1PH600HF5Q06ATI01SHf<0JFUY06ATI01SHf<0IFEU05iNGP1SHf<0IfMW
05mOG`1TI6@0Hf=S06EUI@1RHV80I6AT06UYJ@1[Jf/0Hf=S06ATI01[Jf/0Hf=S06EUI@1TI6@0IVIV
06UYJ@1ZJVX0K6a/06EUI@1TI6@0IfMW06a/K01]KFd0JFUY06][J`1/K6`0MGEe06IVIP1hN7P0M7Ad
07=cL`1`L700KVi^06e]K@1[Jf/0KFe]06][J`1fMWH0LW9b07=cL`1gMgL0L71`0P1]KFd06`1eMGD0
Lg=c07=cL`1fMWH0N7Qh075aL@1cLg<0N7Qh07AdM01hN7P0Ng]k07inOP1iNGT0PH6107alO021PH40
O7al08J6QP1oOgl0OGem08:2PP24Q8@0OWin08N7Q`23Ph<0Ogmo08J6QP0208Z:RP0E08F5Q@21PH40
Rh^;08Z:RP26QXH0TI6A08n?S`2;Rh/0U9BD08n?S`29RHT0V9RH092@T02FUYH0SHf=09jNWP2EUID0
X:2P09bLW02PX:00W9bL00<0WinO01H0XJ6Q0:JVYP2WYjL0X:2P09jNWP2YZJT0YJFU0:>SX`2XZ:P0
/[:b0:j^[P2a/K40Zj^[0;6a/@2g]kL0/[:b0;6a/@2g]kL0/k>c0;6a/@2h^;P0^KVi0P2j^[X01P34
a<@0^KVi0<71`@31`L40c<c<0;fm_@80`/;200d0a<C40<[:bP3=cLd0`<300<W9b@36a/H0c<c<0<O7
a`3;bl/0b/[:0<o?c`3Cdm<0bl_;0080b<S800L0cLg=0<[:bP33`l<0alO70<S8b03AdM40`l?30080
b/[:00l0`L710;fm_@2o_kl0a<C40<30`031`L40aLG50;no_`2h^;P0_[jn0;no_`2j^[X0^;Rh0;no
_`2k^k/00P2`/;020;>c/`80][Jf00H0[Zj^0:VYZ@2QXJ40YJFU0:ZZZP2WYjL20:RXZ00O0::RXP2N
WYh0XZ:R0:BTY02QXJ40XZ:R09^KV`2JVYX0WinO09bLW02OWil0UYJF09^KV`2DU9@0UYJF09RHV02E
UID0UYJF09>CT`2DU9@0TI6A08f=S@2IVIT0TY:B08b<S02>SXh0QHF508V9R@27QhL0R8R808N7Q`02
08>3P`0808F5Q@20P800Ogmo0820P01nOWh0Ogmo08:2PP1jNWX20861P@0d07inOP1iNGT0Ng]k07Ee
M@1mOGd0LG5a07IfMP1eMGD0Lg=c07UiN@1gMgL0LW9b06i^KP1eMGD0K6a/07=cL`1gMgL0L71`06m_
K`1gMgL0J6QX071`L01]KFd0MWIf071`L01YJFT0N7Qh06][J`1/K6`0Kfm_06][J`1ZJVX0GUiN075a
L@1`L700KFe]06IVIP1XJ6P0KFe]06UYJ@1UIFD0IfMW061PH01]KFd0HF5Q06IVIP1QHF40J6QX06MW
I`1XJ6P0IFEU05mOG`80IVIV00d0JVYZ06][J`1RHV80JFUY06MWI`1NGUh0FUYJ05aLG01MGEd0H61P
05]KF`1OGel0Hf=S00H0fMWI0@0000010=WIf@000`3IfMT01@000000fMWI0=WIf@3IfMT000000080
fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
00<0fMWI00L0H61P06=SH`1LG5`0H61P06=SH`1RHV80GUiN0080HF5Q01`0FUYJ05mOG`1PH600HV9R
061PH01SHf<0J6QX06IVIP1WIfL0HF5Q069RHP1KFe/0IfMW06IVIP1TI6@0J6QX06=SH`1UIFD0Hf=S
06EUI@1SHf<0IfMW06IVIP1SHf<0JFUY06][J`1_Kfl0Hf=S0P1QHF402`1YJFT0K6a/06YZJP1YJFT0
Lg=c06a/K01YJFT0Lg=c071`L01]KFd0LG5a0080JFUY03<0J6QX06m_K`1UIFD0JVYZ06ATI01]KFd0
LW9b07AdM01bLW80Kfm_07inOP1iNGT0MGEe07UiN@1dM7@0K6a/07UiN@1eMGD0NWYj07QhN01gMgL0
OGem07IfMP1hN7P0MGEe07moO`21PH40Ogmo07emO@26QXH0RXZ:0820P01jNWX0PH610820P027QhL0
PH6108B4Q021PH40Rh^;08Z:RP2>SXh0R8R808^;R`2>SXh0S8b<08^;R`2=SHd0Q8B408^;R`2GUiL0
0P2?Shl02`2@T900TI6A09fMW@2NWYh0TY:B09FEU@2DU9@0W9bL09VIV@2SXj<0VYZJ0080WinO00P0
YZJV0::RXP2WYjL0Xj>S0:BTY02_[jl0Zj^[0:VYZ@80/k>c00d0ZJVY0:b/[02^[Zh0[Jf]0;6a/@2c
/k<0]kNg0;>c/`2j^[X0_Kfm0;bl_035aLD0`l?30080`/;20P33`l<02`3>c/h0b<S80<c<c037alL0
bLW90<O7a`3=cLd0a/K60=3@d03De=@0a<C40080c<c<02/0alO70<?3``3?cll0bl_;0=;BdP3Fe]H0
e=CD0<g=c@3:b/X0bl_;0<g=c@3:b/X0alO70<k>cP3:b/X0a/K60<[:bP3=cLd0alO70<?3``34a<@0
a/K60;no_`33`l<0bLW90<71`@2l_;`0^k^k0;Ng]`2o_kl0][Jf0;no_`2j^[X0/[:b0;6a/@2g]kL0
_[jn0;6a/@2[Zj/0YJFU0:f][@2_[jl0YjNW0080ZJVY00@0YjNW0:RXZ02NWYh0W9bL0P2QXJ406P2M
WId0WinO09fMW@2LW9`0WYjN09:BTP2ATI40UYJF09^KV`2GUiL0V9RH09JFUP2GUiL0TY:B09^KV`2A
TI40TY:B092@T02;Rh/0SXj>092@T02:RXX0RHV908N7Q`24Q8@0O7al0P25QHD01P23Ph<0PX:207em
O@1mOGd0P82008R8R0<0O7al0P1nOWh04P1bLW80NWYj07EeM@1iNGT0MWIf075aL@1gMgL0P82007=c
L`1_Kfl0K6a/07EeM@1aLG40O7al075aL@1bLW80KVi^071`L080KFe]00d0MgMg075aL@1^KVh0Kfm_
07AdM01_Kfl0KVi^075aL@1YJFT0J6QX06MWI`1bLW80KVi^0080IVIV01l0GEeM06UYJ@1UIFD0KFe]
069RHP1XJ6P0JVYZ065QH@1RHV80K6a/069RHP1QHF40IVIV05iNGP1LG5`0I6AT069RHP1LG5`0K6a/
06EUI@1OGel0J6QX065QH@1WIfL0Fe]K06=SH`1UIFD0G5aL065QH@1KFe/0F5QH00H0fMWI0@000001
0=WIf@000P3IfMT2000000@0fMWI0P0000040=WIf@8000001P3IfMT00`000000fMWI0=WIf@030=WI
f@0606=SH`1PH600HF5Q06YZJP1EEED0HF5Q0P1OGel02`1LG5`0Hf=S05eMG@1UIFD0IVIV06MWI`1Z
JVX0IVIV06=SH`1RHV80JVYZ0080HV9R00@0I6AT06UYJ@1RHV80IVIV0P1RHV80501ZJVX0HV9R069R
HP1VIVH0JFUY06e]K@1UIFD0I6AT05mOG`1XJ6P0H61P06QXJ01WIfL0J6QX06YZJP1YJFT0LG5a06YZ
JP1YJFT0JVYZ0P1dM7@01P1^KVh0JFUY06ATI01`L700IFEU07EeM@80Jf][00/0LG5a071`L01hN7P0
Lg=c07UiN@1eMGD0MWIf07YjNP1gMgL0MGEe06i^KP0207MgM`0@06m_K`1bLW80MWIf07QhN01lO7`0
P82007moO`1hN7P0O7al07MgM`1nOWh0MWIf08B4Q021PH40OWin08F5Q@80OGem00P0P8200861P@29
RHT0QHF508B4Q022PX80QhN708f=S@80T92@00X0Ph>308Z:RP2=SHd0UIFE09NGU`2ATI40Ti>C09^K
V`2BTY80V9RH0P2JVYX05`2QXJ40Y:BT0:2PX02ZZZX0Vi^K09VIV@2RXZ80XJ6Q0:>SX`2WYjL0Zj^[
0;Vi^@2ZZZX0Y:BT0;2`/02][Jd0[jn_0;:b/P2^[Zh0[Jf]0;Ng]`2o_kl0^;Rh0080][Jf00`0`L71
0<30`02j^[X0`<300<S8b034a<@0aLG50<71`@2j^[X0a/K60<?3``32`/820<_;b`060<k>cP3:b/X0
cLg=0<W9b@38b<P0fm_K0`38b<P0303AdM40c/k>0=GEe@3Cdm<0d=3@0<[:bP3AdM40cLg=0=CDe03@
d=00aLG50<_;b`80b/[:00d0emOG0<_;b`35aLD0eMGE0<S8b03<c<`0bLW90<71`@35aLD0b<S80<C4
a030`<00^KVi0080`/;201<0_[jn0;Vi^@31`L40^[Zj0;Rh^02j^[X0/K6a0;Fe]@2f][H0/k>c0:n_
[`2c/k<0YJFU0;2`/02XZ:P0Zj^[0:VYZ@2TY:@0XZ:R0080Y:BT02H0WinO0:6QX@2TY:@0X:2P09nO
W`2LW9`0UiNG09RHV02MWId0VIVI09BDU02@T900Ti>C08f=S@2KVi/0UIFE09ZJVP28R8P0SHf=08b<
S02?Shl0RXZ:08^;R`2BTY80Ph>308b<S028R8P0S8b<08V9R@26QXH0PX:20820P028R8P0OWin07mo
O`1kNg/0Ogmo07YjNP80OGem0280Ogmo07UiN@1dM7@0MWIf07QhN01fMWH0Lg=c07AdM01gMgL0LW9b
07=cL`1dM7@0MgMg07=cL`1fMWH0Kfm_071`L01_Kfl0Jf][06m_K`1]KFd0KVi^071`L01fMWH0K6a/
07EeM@1/K6`0Lg=c06][J`1]KFd0JFUY06e]K@1VIVH0JVYZ0P1WIfL03@1UIFD0IfMW065QH@1XJ6P0
JVYZ06EUI@1]KFd0H61P06IVIP1NGUh0IFEU061PH01[Jf/00P1SHf<01`1QHF40GemO06ATI01VIVH0
J6QX069RHP1TI6@00P1WIfL01P1KFe/0IVIV06=SH`1TI6@0HF5Q05iNGPH0fMWI0@0000010=WIf@00
5P3IfMT00`000000fMWI0=WIf@030=WIf@0506=SH`1OGel0H61P05eMG@1YJFT00P1RHV806`1HF5P0
HV9R05mOG`1UIFD0Hf=S05iNGP1OGel0HF5Q06=SH`1RHV80Hf=S06EUI@1QHF40Hf=S06UYJ@1TI6@0
JFUY069RHP1TI6@0IfMW06YZJP1SHf<0IFEU06MWI`1VIVH0GemO06IVIP0206UYJ@0S06ATI01WIfL0
IFEU06i^KP1`L700Jf][06UYJ@1ZJVX0Jf][071`L01[Jf/0LG5a06ATI01aLG40L71`07=cL`1_Kfl0
JFUY06YZJP1aLG40Lg=c06a/K01fMWH0N7Qh07inOP1gMgL0Lg=c07IfMP1gMgL0J6QX06a/K01eMGD0
N7Qh07MgM`1mOGd00P1eMGD04`1gMgL0Ogmo07]kN`1mOGd0P8200861P@1lO7`0Ng]k08F5Q@1lO7`0
Q8B40820P022PX80QXJ607UiN@29RHT0S8b<0820P02:RXX00P2;Rh/08P28R8P0RHV908J6QP24Q8@0
Ti>C09JFUP2?Shl0TI6A08f=S@2FUYH0UIFE09fMW@2NWYh0VYZJ09bLW02UYJD0Xj>S09ZJVP2KVi/0
WIfM09RHV02TY:@0X:2P0:FUY@2XZ:P0ZZZZ0:VYZ@2VYZH0ZJVY0:b/[02i^KT0/;2`0:b/[02g]kL2
0;Bd]00K0:n_[`2n_[h0][Jf0;^k^`30`<00_[jn0<C4a02i^KT0_kno0;bl_036a/H0dM7A0<S8b036
a/H0bl_;0<C4a03?cll0c/k>0=3@d03?cll0c<c<0=3@d03AdM40emOG0=GEe@39bLT0g=cL0080clo?
01`0d];B0=OGe`3Jf]X0clo?0=KFeP35aLD0f][J0=GEe@3?cll0emOG0<_;b`3Bd]80fm_K0<g=c@3G
emL0d=3@0<W9b@3>c/h0bl_;0=3@d037alL0c/k>0=3@d037alL0cLg=0<[:bP3;bl/0a<C40P31`L40
102n_[h0`l?30;Zj^P32`/820;Zj^P0:0;^k^`2h^;P0^[Zj0;Fe]@2g]kL0/K6a0:RXZ02ZZZX0ZJVY
0:RXZ080YjNW00T0YZJV0:RXZ02OWil0Y:BT09^KV`2VYZH0UIFE09bLW02OWil00P2KVi/02@2GUiL0
UIFE09fMW@2FUYH0Ti>C09RHV02=SHd0T92@09>CT`02092@T00=08N7Q`2=SHd0Ti>C08>3P`28R8P0
PH6108N7Q`2<S8`0PX:208V9R@26QXH0Q8B408>3P`0207emO@0307IfMP21PH40MgMg0080NWYj0140
OGem0861P@1nOWh0Lg=c07moO`1lO7`0MWIf07MgM`1lO7`0N7Qh07AdM01^KVh0M7Ad07=cL`1iNGT0
KFe]06][J`0306m_K`0A06a/K01bLW80LW9b06m_K`1dM7@0JFUY06EUI@1XJ6P0L71`075aL@1_Kfl0
KFe]06EUI@1^KVh0JVYZ06i^KP1VIVH00P1XJ6P00`1TI6@0IFEU06YZJP02069RHP80IfMW00P0IFEU
06e]K@1YJFT0IfMW06EUI@1WIfL0IVIV06UYJ@80HV9R00T0JVYZ069RHP1PH600Hf=S05aLG01PH600
IfMW05YJFP1RHV801P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00<0FUYJ
06ATI01LG5`00P1KFe/02@1NGUh0I6AT061PH01SHf<0HV9R06ATI01UIFD0I6AT05mOG`02065QH@09
06EUI@1VIVH0I6AT05UIF@1SHf<0I6AT05aLG01UIFD0H61P0080IVIV00@0J6QX061PH01SHf<0IfMW
0P1UIFD05@1YJFT0KVi^06IVIP1WIfL0I6AT06MWI`1/K6`0Jf][06YZJP1^KVh0HV9R071`L01eMGD0
Jf][06ATI01aLG40Jf][06e]K@1YJFT0K6a/06YZJP02079bLP0506a/K01^KVh0L71`07QhN01cLg<0
0P1fMWH0101dM7@0NGUi07AdM01dM7@207QhN00<07=cL`1lO7`0KVi^07inOP1jNWX0O7al07UiN@1h
N7P0PH6107]kN`29RHT0Ng]k0P21PH407`27QhL0OGem08R8R020P800QXJ608V9R@26QXH0QHF508N7
Q`2=SHd0SXj>08V9R@26QXH0RXZ:08j>SP2=SHd0RHV908R8R02DU9@0S8b<09BDU02EUID0U9BD09FE
U@2JVYX0X:2P0:BTY02YZJT0XJ6Q0:BTY02QXJ400P2NWYh0=@2RXZ80Xj>S0:^[Z`2^[Zh0[Jf]0:NW
Y`2c/k<0^k^k0:b/[02c/k<0_[jn0;2`/02b/[80^;Rh0;>c/`2m_Kd0a<C40;fm_@2o_kl0_;bl0;Bd
]037alL0aLG50<S8b036a/H0alO70<W9b@3:b/X0bLW90<c<c03MgMd0clo?0=3@d03IfMT0gMgM0=WI
f@3MgMd0e=CD0=gMg@3QhN40gMgM0=WIf@3Kfm/0gMgM0=_Kf`3Hf=P0g=cL0=CDe03Shn<0fMWI0=OG
e`3De=@0dm?C0080e]KF01l0eMGE0<k>cP3De=@0emOG0=CDe03Cdm<0f=SH0=7Ad@3EeMD0cLg=0<[:
bP3AdM40b/[:0<c<c037alL0aLG50<;2`P34a<@0_kno0;Rh^02l_;`0_kno0;bl_02e]KD0^k^k0;Rh
^02l_;`0];Bd0;Ng]`2c/k<0[Zj^0080/K6a02h0[Jf]0:b/[02][Jd0ZJVY0:BTY02VYZH0Xj>S0:2P
X02MWId0X:2P09nOW`2LW9`0Vi^K09VIV@2CTi<0TY:B09FEU@2DU9@0Shn?09VIV@2@T900TI6A09VI
V@2;Rh/0SHf=09BDU02;Rh/0QXJ608b<S02?Shl0SHf=08V9R@27QhL0QHF508J6QP25QHD0QhN70820
P021PH40OWin07alO01eMGD0O7al0861P@1lO7`0OGem0P1hN7P0<`1aLG40NWYj07QhN01gMgL0MGEe
07emO@1cLg<0LG5a06i^KP1dM7@0NWYj07IfMP1_Kfl0MGEe07=cL`1/K6`0Ng]k07=cL`1aLG40JVYZ
06e]K@1_Kfl0MgMg06YZJP1NGUh0LG5a07AdM01/K6`0JFUY06IVIP1UIFD0KFe]06MWI`1NGUh0IFEU
06i^KP1ZJVX0K6a/06ATI01PH600IFEU069RHP1VIVH0IfMW06IVIP1/K6`0Hf=S06ATI01RHV80J6QX
05iNGP03069RHP0805UIF@1TI6@0IVIV05iNGP1VIVH0GEeM06EUI@1SHf<60=WIf@4000000@3IfMT0
01H0fMWI00<000000=WIf@3IfMT00`3IfMT01@1SHf<0G5aL05mOG`1UIFD0GemO0080HF5Q02T0IFEU
06IVIP1OGel0EeMG05iNGP1[Jf/0IfMW06ATI01RHV80JFUY06=SH`1UIFD0HV9R06i^KP1PH600Hf=S
06i^KP1NGUh0HV9R06ATI01UIFD0Hf=S06EUI@1TI6@0IfMW06=SH`1_Kfl0J6QX069RHP1YJFT0Jf][
06e]K@1[Jf/0IfMW06YZJP1]KFd0Jf][06e]K@1UIFD0JFUY06i^KP0206UYJ@0906][J`1ZJVX0KVi^
07AdM01/K6`0Jf][06m_K`1gMgL0LW9b0080NWYj00@0M7Ad075aL@1aLG40M7Ad0P1aLG401@1fMWH0
MGEe07QhN01jNWX0O7al0080MWIf0340N7Qh07moO`1nOWh0N7Qh0861P@1iNGT0PX:20820P024Q8@0
QXJ608B4Q027QhL0QHF5092@T025QHD0R8R808>3P`2CTi<0RHV908F5Q@2:RXX0R8R808^;R`2CTi<0
S8b<08Z:RP2@T900QXJ6092@T02?Shl0V9RH09FEU@2OWil0WIfM0:NWY`2TY:@0YjNW0:f][@2UYJD0
Y:BT0:>SX`2WYjL0XJ6Q0:ZZZP2`/;00YjNW0:^[Z`2e]KD0[Jf]00<0/[:b02D0/;2`0;Ng]`2m_Kd0
_[jn0<C4a031`L40_[jn0<C4a03<c<`0_kno0<S8b03:b/X0`/;20<K6aP35aLD0b/[:0=3@d03=cLd0
c/k>0=?Cd`3EeMD0f=SH0=CDe03Lg=`0gmoO0=GEe@3Lg=`0eMGE0=WIf@3MgMd0d];B0<o?c`3UiND0
g]kN0=_Kf`3QhN40emOG0080f][J00d0hn?S0=gMg@3Ng]h0gmoO0=cLg03Fe]H0f][J0=WIf@3EeMD0
f][J0=OGe`3EeMD0dm?C0080clo?01<0dM7A0=;BdP3EeMD0b<S80<O7a`36a/H0b<S80<30`02l_;`0
^k^k0<?3``2n_[h0`<300;Zj^P33`l<0_;bl0;Vi^@2e]KD0_Kfm0080[Zj^0140YJFU0:f][@2WYjL0
Zj^[0;:b/P2YZJT0Z:RX0:FUY@2RXZ80Z:RX0:6QX@2NWYh0WinO09jNWP2HV9P0WIfM09ZJVP0209fM
W@0?09JFUP2JVYX0UIFE08n?S`2DU9@0T92@08f=S@2@T900SXj>08b<S02?Shl0T92@08V9R@2:RXX0
RHV90080Shn?00T0QhN707inOP28R8P0P82008J6QP1jNWX0OWin07]kN`21PH400`1jNWX307QhN00I
08:2PP1cLg<0MWIf07UiN@1fMWH0NGUi06][J`1iNGT0LG5a071`L01^KVh0L71`06][J`1bLW80KVi^
071`L01bLW80MgMg06i^KP1_Kfl0K6a/06e]K@1aLG40K6a/06][J`0207=cL`0906MWI`1_Kfl0KFe]
06a/K01TI6@0IFEU06YZJP1SHf<0J6QX0080IfMW01P0J6QX06ATI01ZJVX0IVIV06EUI@1RHV80Fe]K
06IVIP1QHF40Hf=S06m_K`1SHf<0K6a/05]KF`1OGel0IVIV069RHP1NGUh0HV9R05mOG`1RHV80JFUY
059BDP1MGEd60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT01@1NGUh0HV9R
069RHP1JFUX0JFUY0080IFEU00X0GEeM06QXJ01QHF40IfMW065QH@1WIfL0HV9R06ATI01UIFD0IfMW
0P1SHf<01@1TI6@0IVIV065QH@1VIVH0Jf][0080HF5Q01L0K6a/06=SH`1SHf<0Jf][06IVIP1SHf<0
J6QX069RHP1TI6@0GemO06IVIP1RHV80I6AT071`L01ZJVX0HF5Q06][J`1`L700Lg=c06i^KP1ZJVX0
J6QX075aL@0206][J`0@075aL@1]KFd0LG5a079bLP1^KVh0N7Qh07AdM01aLG40LW9b06i^KP1cLg<0
LG5a06i^KP1eMGD0Lg=c07IfMP80MGEe00h0NWYj07EeM@1jNWX0MWIf07moO`20P800O7al07=cL`1f
MWH0N7Qh08:2PP1nOWh0R8R808>3P`<0Rh^;00P0PX:208F5Q@2;Rh/0R8R808>3P`2:RXX0Ti>C096A
T@80S8b<01`0RHV908n?S`2?Shl0SXj>09BDU02BTY80W9bL09FEU@2;Rh/0VYZJ09fMW@2EUID0Xj>S
09jNWP2TY:@0Zj^[09nOW`2WYjL0Vi^K0:>SX`2UYJD0YjNW0:ZZZP2[Zj/0YZJV0;6a/@2c/k<0][Jf
0P2e]KD08P2k^k/0^[Zj0;>c/`31`L40a<C40<G5a@2n_[h0a/K60<71`@32`/80a/K60<_;b`39bLT0
c<c<0<o?c`3De=@0fMWI0=[JfP3EeMD0e]KF0=kNgP3QhN40kno_0>;RhP3Jf]X0fm_K0>;RhP3QhN40
j^[Z0>7Qh@3MgMd0fMWI0=_Kf`3Ti>@20>;RhP030=kNgP3UiND0g]kN0080hN7Q00/0fMWI0>CTi03L
g=`0f][J0>?Sh`3Ph>00fm_K0=OGe`3Ng]h0fm_K0<o?c`020=[JfP0S0=CDe03Cdm<0dM7A0<g=c@3<
c<`0dm?C0<W9b@37alL0`l?30<g=c@33`l<0c<c<0<;2`P2l_;`0^k^k0;Ng]`2e]KD0`L710;Zj^P30
`<00/;2`0;6a/@2`/;00/[:b0:^[Z`2ZZZX0[Zj^0:^[Z`2RXZ80Xj>S0:2PX02WYjL0Y:BT0:2PX02R
XZ800P2LW9`03P2VYZH0VYZJ09fMW@2OWil0V9RH09nOW`2FUYH0VIVI09BDU02EUID0Shn?09BDU02?
Shl0R8R80P29RHT02@25QHD0SXj>08Z:RP2=SHd0S8b<08V9R@2;Rh/0O7al08>3P`020861P@1608J6
QP20P800Ng]k07emO@1kNg/0O7al07emO@1hN7P0Ng]k07emO@1kNg/0Lg=c07QhN01eMGD0LW9b071`
L01kNg/0Kfm_071`L01cLg<0MgMg075aL@1[Jf/0Kfm_07MgM`1]KFd0Lg=c07IfMP1[Jf/0L71`06QX
J01`L700IVIV06i^KP1ZJVX0Jf][06e]K@1bLW80KVi^06e]K@1TI6@0IVIV06YZJP1/K6`0J6QX06UY
J@1SHf<0J6QX06ATI01SHf<0IFEU061PH01TI6@0HF5Q06EUI@1WIfL0G5aL06IVIP1TI6@0IFEU06=S
H`1TI6@0GUiN05mOG`1LG5`0Hf=S05IFEP1IFET0GUiN05mOG`H0fMWI0@0000010=WIf@005P3IfMT0
0`000000fMWI0=WIf@030=WIf@0606=SH`1VIVH0HV9R06=SH`1VIVH0JVYZ0P1QHF400`1`L700HV9R
06ATI002061PH00706ATI01RHV80J6QX06m_K`1YJFT0K6a/061PH00206ATI00F06IVIP1QHF40Hf=S
06ATI01SHf<0HF5Q06ATI01ZJVX0J6QX06ATI01XJ6P0IVIV06e]K@1WIfL0Jf][06MWI`1TI6@0KVi^
071`L01dM7@0Kfm_071`L080JVYZ00d0K6a/06e]K@1/K6`0L71`06i^KP1[Jf/0KFe]06a/K01aLG40
Kfm_06YZJP1fMWH0Kfm_0080K6a/0P1cLg<00`1gMgL0L71`07EeM@0207UiN@0D07QhN01mOGd0N7Qh
07UiN@1eMGD0MgMg07QhN024Q8@0PH6107inOP21PH40QHF508:2PP20P800Ph>308N7Q`26QXH0PH61
08J6QP2?Shl208J6QP80R8R801X0RXZ:08F5Q@2>SXh0UYJF096AT@2DU9@0Ti>C09BDU02@T900V9RH
09>CT`2FUYH0TI6A09RHV02NWYh0WIfM0::RXP2OWil0Xj>S09VIV@2TY:@0Z:RX0:BTY02VYZH0ZZZZ
0:FUY@80[jn_0240/k>c0;2`/02ZZZX0_;bl0;Zj^P2d];@0][Jf0;Ng]`35aLD0_kno0<C4a036a/H0
b/[:0;no_`36a/H0_[jn0<[:bP30`<00`l?30<o?c`3De=@0clo?0=?Cd`3;bl/0g=cL0=_Kf`3EeMD0
iNGU0=oOg`3YjNT0hN7Q0>?Sh`3UiND00P3Xj>P0303QhN40f=SH0>OWi`3[jn/0inOW0>[ZjP3QhN40
h>3P0=oOg`3Xj>P0h>3P0>;RhP80h>3P00X0gMgM0=kNgP3Jf]X0iNGU0>7Qh@3WinL0hN7Q0=KFeP3P
h>00dm?C0P3EeMD01`3De=@0dm?C0=_Kf`39bLT0f][J0<o?c`37alL00P3<c<`01P36a/H0`L710;jn
_P35aLD0c<c<0<71`@80`<3002`0^k^k0;:b/P2j^[X0^;Rh0;Jf]P2`/;00][Jf0:j^[P2b/[80/;2`
0:NWY`2QXJ40XZ:R09jNWP2LW9`0Y:BT09jNWP2TY:@0WinO0:FUY@2PX:00W9bL09ZJVP2DU9@0UIFE
09BDU02LW9`0TY:B096AT@2=SHd0TI6A08f=S@2<S8`0Rh^;09BDU02=SHd0QHF508Z:RP28R8P0Rh^;
08F5Q@29RHT0OWin08>3P`80Q8B400H0QhN70861P@1kNg/0O7al07YjNP1lO7`207UiN@0407QhN01d
M7@0N7Qh07YjNP80MGEe00X0MgMg07AdM01hN7P0NGUi079bLP1fMWH0MGEe075aL@1^KVh0MgMg101]
KFd0801`L700Kfm_06e]K@1eMGD0K6a/06][J`1ZJVX0KVi^06IVIP1/K6`0Jf][06MWI`1/K6`0Jf][
06YZJP1TI6@0HF5Q05iNGP1TI6@0J6QX06IVIP1YJFT0JVYZ06UYJ@1MGEd0Hf=S06QXJ01UIFD0IVIV
06UYJ@1ZJVX0Hf=S0P1TI6@0201OGel0H61P05YJFP1UIFD0H61P065QH@1RHV80GEeM1P3IfMT10000
0040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0P1TI6@00`1NGUh0H61P05]KF`04069RHP0K
05mOG`1ZJVX0JVYZ061PH01SHf<0H61P06=SH`1UIFD0IfMW05mOG`1SHf<0IVIV069RHP1NGUh0GEeM
065QH@1/K6`0HF5Q06IVIP1SHf<0HV9R06QXJ01ZJVX0IVIV06MWI`1ZJVX0IfMW0080KVi^00<0Jf][
06UYJ@1TI6@00P1/K6`02`1XJ6P0Kfm_07AdM01YJFT0J6QX06i^KP1XJ6P0KVi^06e]K@1[Jf/0KVi^
0080LW9b00h0KVi^079bLP1[Jf/0K6a/06m_K`1hN7P0MgMg07YjNP1dM7@0Lg=c07EeM@1dM7@0NWYj
07AdM080OWin02T0MGEe07alO01hN7P0NWYj08B4Q01bLW80N7Qh07moO`1lO7`0QhN708J6QP29RHT0
P82008:2PP27QhL0R8R808J6QP24Q8@0QXJ608f=S@24Q8@0RHV9096AT@2@T900RXZ:08V9R@2ATI40
T92@08f=S@2BTY80T92@09BDU02BTY80Vi^K0::RXP2SXj<0WYjN09^KV`2QXJ40YjNW0:JVYP020:VY
Z@0A0:RXZ02WYjL0XZ:R0;Bd]02`/;00]kNg0:b/[02^[Zh0/k>c0;Rh^02b/[80_kno0<30`02m_Kd0
^[Zj0;fm_@31`L400P38b<P04`35aLD0c<c<0=CDe03Bd]80c/k>0=;BdP3De=@0gMgM0=3@d03IfMT0
e]KF0=gMg@3Xj>P0j^[Z0>CTi03Rh^80gMgM0>_[j`3Rh^800P3WinL01`3Ti>@0kNg]0>;RhP3`l?00
jn_[0>GUi@3Vi^H00P3[jn/0403]kNd0jn_[0>GUi@3[jn/0h^;R0>WYj@3`l?00l_;b0=gMg@3WinL0
g=cL0>;RhP3Lg=`0fm_K0=SHf03Kfm/20=7Ad@0M0=_Kf`3@d=00f][J0=SHf03EeMD0b<S80<o?c`3;
bl/0bLW90<g=c@31`L40`l?30<30`03?cll0_[jn0;>c/`2g]kL0]KFe0;Ng]`2f][H0];Bd0:n_[`2h
^;P0/;2`0;Bd]02][Jd0Zj^[0:ZZZP2XZ:P00P2TY:@03@2YZJT0XJ6Q0:BTY02XZ:P0Y:BT0:>SX`2K
Vi/0WYjN09JFUP2EUID0WYjN09VIV@2?Shl00P2GUiL01`2ATI40S8b<08B4Q02<S8`0UYJF08J6QP2=
SHd00P2?Shl04@2=SHd0S8b<08>3P`22PX80R8R808:2PP20P800OGem07alO01hN7P0MWIf07inOP1j
NWX0MgMg08>3P`1gMgL0P82000<0NWYj00/0LG5a07MgM`1fMWH0M7Ad075aL@1bLW80MGEe07=cL`1^
KVh0KFe]06m_K`02075aL@0506e]K@1_Kfl0Jf][079bLP1^KVh00P1XJ6P06`1/K6`0HV9R06e]K@1Z
JVX0Hf=S061PH01VIVH0JVYZ06ATI01UIFD0IfMW05QHF01ZJVX0IfMW069RHP1VIVH0H61P06=SH`1Q
HF40GUiN06=SH`1ZJVX0Hf=S06i^KP1TI6@0IVIV06=SH`02061PH080J6QX00H0IFEU06=SH`1MGEd0
HF5Q05eMG@1RHV860=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT05`1QHF40
H61P06ATI01TI6@0GEeM06=SH`1VIVH0GemO06YZJP1PH600Hf=S06YZJP1KFe/0Hf=S05iNGP1WIfL0
Hf=S05mOG`1]KFd0GUiN061PH01LG5`0JVYZ0080Hf=S00L0IFEU05YJFP1TI6@0IfMW06][J`1YJFT0
J6QX00<0IfMW00H0IFEU06IVIP1OGel0JVYZ069RHP1_Kfl206][J`0g06e]K@1/K6`0J6QX07IfMP1[
Jf/0Kfm_06MWI`1TI6@0LW9b06m_K`1dM7@0Kfm_07=cL`1/K6`0LG5a071`L01jNWX0Kfm_07=cL`1h
N7P0MgMg07AdM01hN7P0MWIf07MgM`20P800NGUi08B4Q01oOgl0O7al08N7Q`1nOWh0Ogmo07alO022
PX80PH6107inOP23Ph<0P82008R8R022PX80QHF508J6QP2;Rh/0QXJ608b<S02;Rh/0RHV908f=S@2?
Shl0RXZ:09FEU@2<S8`0UYJF09RHV00309NGU`0X09RHV02@T900TY:B09nOW`2NWYh0YJFU0::RXP2S
Xj<0WinO0:BTY02VYZH0Y:BT0:>SX`2UYJD0ZZZZ0;2`/02][Jd0]KFe0:n_[`2/[:`0];Bd0;Rh^02i
^KT0_[jn0;^k^`2n_[h0`<300<O7a`39bLT0aLG50<K6aP39bLT0cLg=0<o?c`3Bd]80clo?0=?Cd`3J
f]X0fm_K0=[JfP80g]kN00`0f=SH0=[JfP3Shn<0iNGU0?3`l03WinL0jn_[0>SXj03_knl0jn_[0>o_
k`3[jn/20?3`l00M0?Shn03/k>`0j>SX0?Cdm03Xj>P0n?Sh0>g]k@3^k^h0m_Kf0>k^kP3YjNT0nOWi
0>g]k@3`l?00i^KV0>o_k`3^k^h0h>3P0>WYj@3Shn<0hN7Q0=_Kf`3Vi^H0f][J0=WIf@3Ogml0f][J
0=CDe03Jf]X00P3Kfm/06P3>c/h0f][J0=;BdP3;bl/0aLG50<K6aP30`<00^KVi0;fm_@30`<00_[jn
0;fm_@2h^;P0/k>c0;Ng]`2a/K40Zj^[0:f][@2[Zj/0[:b/0:^[Z`2ZZZX0Z:RX0:ZZZP2VYZH0XZ:R
0P2YZJT04@2NWYh0[:b/09RHV02OWil0W9bL09JFUP2OWil0VYZJ09:BTP2CTi<0SHf=08Z:RP2BTY80
V9RH09:BTP2>SXh0TI6A0080RHV900D0Shn?08J6QP27QhL0Q8B407moO`0208F5Q@0d08Z:RP26QXH0
O7al07alO02;Rh/0P820075aL@1nOWh0Ng]k08B4Q01dM7@0Lg=c07EeM@1cLg<0O7al07AdM01hN7P0
Kfm_07EeM@1dM7@0NGUi07IfMP1dM7@0Kfm_06e]K@1fMWH0KVi^07=cL`1YJFT0MGEe06QXJ01[Jf/0
IfMW06i^KP1[Jf/0J6QX07=cL`1[Jf/0J6QX06e]K@1WIfL0I6AT06a/K01VIVH0Hf=S07=cL`1UIFD0
Hf=S06YZJP1SHf<0J6QX06a/K080IVIV00X0K6a/069RHP1XJ6P0HV9R06MWI`1QHF40Hf=S06QXJ01U
IFD0JFUY0P1UIFD0101KFe/0H61P05aLG01KFe/205iNGPH0fMWI0@0000010=WIf@005P3IfMT00`00
0000fMWI0=WIf@030=WIf@0N06MWI`1JFUX0IfMW061PH01UIFD0GUiN065QH@1IFET0GemO06=SH`1Q
HF40Fe]K05mOG`1SHf<0HV9R06YZJP1WIfL0Jf][05mOG`1WIfL0H61P06UYJ@1/K6`0JVYZ06=SH`1R
HV80JVYZ06QXJ01TI6@0Jf][0P1/K6`05`1^KVh0J6QX071`L01TI6@0K6a/065QH@1YJFT0IFEU06QX
J01YJFT0IFEU079bLP1XJ6P0JVYZ06IVIP1[Jf/0MGEe06a/K01ZJVX0Jf][06e]K@1bLW80Jf][0080
LG5a0P1`L7000`1_Kfl0LG5a071`L00207AdM003071`L01jNWX0MGEe0080MWIf00<0N7Qh07]kN`1e
MGD00P1oOgl20820P00V07inOP27QhL0OWin07YjNP27QhL0Ph>308J6QP25QHD0Ogmo08V9R@25QHD0
SHf=08J6QP25QHD0T92@08V9R@2;Rh/0TY:B08^;R`2@T900U9BD09NGU`2>SXh0U9BD0:2PX02EUID0
Vi^K09VIV@2RXZ80XJ6Q09nOW`2ZZZX0XZ:R0:2PX02ZZZX0YjNW09nOW`2[Zj/30:FUY@0L0:VYZ@2W
YjL0_;bl0;Fe]@2g]kL0[Zj^0;Rh^02j^[X0`<300<71`@33`l<0bLW90<30`031`L40bl_;0<O7a`39
bLT0clo?0=?Cd`3AdM40emOG0=GEe@3IfMT0eMGE0=;BdP3Shn<0h^;R0>WYj@80inOW0240h>3P0>[Z
jP3/k>`0kno_0>k^kP3[jn/0k^k^0?Gem@3dm?@0l_;b0?[jnP3clo<0k^k^0?ooo`3bl_80moOg0>SX
j03/k>`0n_[j0??cl`3`l?00lO7a0>WYj@3alO40n?Sh0>WYj@3`l?00j>SX0>CTi03/k>`0hn?S0>3P
h03Ng]h00P3Rh^806P3Lg=`0fm_K0=gMg@3GemL0g]kN0=OGe`3Kfm/0bLW90<_;b`3>c/h0a/K60<G5
a@38b<P0`L710<O7a`2i^KT0_;bl0;^k^`2h^;P0^KVi0;Zj^P2h^;P0/k>c0;6a/@2f][H0/;2`0P2[
Zj/03`2ZZZX0X:2P0:VYZ@2SXj<0ZJVY0:>SX`2WYjL0X:2P0:6QX@2LW9`0XZ:R09bLW02FUYH0VIVI
09JFUP0209ZJVP0409:BTP2DU9@0Shn?09:BTP80Rh^;01<0SXj>08b<S02;Rh/0SXj>08F5Q@2:RXX0
Ogmo08B4Q025QHD0P82008:2PP28R8P0NWYj08>3P`1mOGd0O7al0820P01hN7P0Ng]k0080OGem02P0
Ng]k07=cL`1jNWX0Ogmo07AdM01/K6`0Lg=c07AdM01gMgL0KFe]075aL@1gMgL0K6a/07EeM@1`L700
KVi^06a/K01[Jf/0K6a/06e]K@1/K6`0IFEU06IVIP1]KFd0Kfm_06YZJP1YJFT0I6AT06QXJ01WIfL0
K6a/06EUI@1RHV80JVYZ05iNGP1WIfL0JFUY06=SH`1OGel0Jf][0`1SHf<01@1VIVH0Hf=S069RHP1T
I6@0J6QX0080JFUY00@0Hf=S065QH@1TI6@0Hf=S0P1NGUh0101LG5`0HF5Q05YJFP1QHF460=WIf@40
00000@3IfMT001H0fMWI0P0000040=WIf@80IFEU00L0HF5Q061PH01SHf<0H61P05eMG@1TI6@0J6QX
0080HF5Q01@0Hf=S05eMG@1TI6@0IVIV069RHP1UIFD0J6QX06][J`1KFe/0I6AT06IVIP1SHf<0J6QX
06=SH`1WIfL0JFUY06=SH`1PH600IfMW06EUI@80J6QX00/0JVYZ07=cL`1XJ6P0GUiN06m_K`1XJ6P0
HF5Q06e]K@1XJ6P0H61P06a/K002071`L00`06i^KP1VIVH0LW9b06i^KP1UIFD0KFe]07AdM01`L700
Kfm_07EeM@1_Kfl0KVi^079bLP1`L700KFe]07AdM01`L700M7Ad07]kN`1gMgL0LG5a07EeM@1gMgL0
Ng]k07YjNP21PH40OWin07IfMP21PH40Ogmo08:2PP20P800PX:208F5Q@20P800Q8B408N7Q`23Ph<0
QhN708R8R026QXH0RHV90820P02JVYX0SXj>08f=S@2:RXX0SXj>0P2ATI400`2HV9P0Ti>C08n?S`02
09FEU@0<092@T02LW9`0Ti>C09RHV02OWil0Ti>C09fMW@2SXj<0Y:BT0:2PX02TY:@0YJFU0P2/[:`0
6`2YZJT0]KFe0;Rh^02e]KD0ZZZZ0;2`/02b/[80][Jf0<G5a@37alL0^k^k0<K6aP35aLD0cLg=0<k>
cP36a/H0c<c<0<K6aP3AdM40fMWI0=;BdP3Hf=P0g]kN0>WYj@3Lg=`0l?3`0>GUi@020>CTi00D0>KV
iP3[jn/0jn_[0?7al@3hn?P0m?Cd0?Win@3emOD0kNg]0?3`l03bl_80m?Cd0?gmo@3gmoL0no_k0?Kf
mP3oool0lO7a0??cl`3oool20?_kn`0X0?gmo@3hn?P0lo?c0?ooo`3emOD0moOg0?;blP3hn?P0lO7a
0>[ZjP3alO40kno_0=cLg03Ph>00i^KV0>CTi03Ph>00g=cL0=kNgP3GemL0h^;R0=?Cd`3IfMT0eMGE
0=;BdP3=cLd0b/[:0=?Cd`3?cll0bLW90<?3``36a/H0`L710<C4a02o_kl0_[jn0;bl_02h^;P0/[:b
0;2`/080/k>c00/0Z:RX0:BTY02g]kL0Y:BT0:NWY`2XZ:P0ZJVY0:NWY`2QXJ40Y:BT09^KV`0209nO
W`80X:2P00L0VIVI0:2PX02EUID0UYJF09FEU@2@T900TY:B0080Shn?00/0SHf=09FEU@2<S8`0QhN7
08R8R029RHT0QHF507emO@22PX80RXZ:08>3P`0208F5Q@0L08Z:RP22PX80O7al08>3P`1nOWh0NWYj
08:2PP1oOgl0O7al07EeM@1oOgl0OGem07QhN01aLG40Lg=c07]kN`1eMGD0KFe]07AdM01aLG40LW9b
06m_K`1/K6`0Lg=c071`L01^KVh0Kfm_06e]K@80Kfm_00H0Jf][06e]K@1cLg<0J6QX06i^KP1UIFD2
06QXJ00:06YZJP1[Jf/0I6AT06IVIP1^KVh0JVYZ06MWI`1/K6`0JFUY06EUI@80JFUY00<0JVYZ06QX
J01]KFd00P1VIVH03P1XJ6P0IVIV06EUI@1YJFT0Hf=S06a/K01UIFD0JVYZ061PH01GEeL0H61P05]K
F`1ZJVX0HV9R1@3IfMT200000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI01<0HF5Q061P
H01MGEd0Hf=S06MWI`1OGel0H61P06MWI`1SHf<0HF5Q06=SH`1RHV80Jf][06=SH`1PH600I6AT05iN
GP1RHV80I6AT0080IVIV00<0HF5Q061PH01XJ6P00P1VIVH01`1RHV80IFEU06ATI01XJ6P0IfMW06i^
KP1TI6@00P1XJ6P0301/K6`0IVIV06QXJ01YJFT0MGEe06UYJ@1VIVH0M7Ad06i^KP1cLg<0K6a/06QX
J080LG5a01T0KFe]071`L01/K6`0KFe]07IfMP1cLg<0LG5a079bLP1fMWH0LW9b075aL@1cLg<0LW9b
07IfMP1nOWh0MGEe07UiN@1dM7@0N7Qh07IfMP21PH40NGUi07inOP1dM7@0N7Qh0080Ogmo0P22PX80
1`28R8P0QXJ607inOP1oOgl0Ph>308F5Q@22PX800P2:RXX05`2<S8`0SXj>08^;R`27QhL0Rh^;08R8
R02<S8`0SXj>08b<S02>SXh0Shn?096AT@2LW9`0UYJF09VIV@2KVi/0UYJF09ZJVP2VYZH0X:2P09fM
W@2][Jd0Z:RX0080ZJVY01X0YJFU0:f][@2a/K40/K6a0:j^[P2b/[80/;2`0;:b/P2h^;P0a/K60<C4
a02n_[h0_kno0;^k^`37alL0bLW90<G5a@3:b/X0c<c<0<k>cP3Cdm<0d=3@0=GEe@3Jf]X0iNGU0>7Q
h@80h>3P00X0i^KV0>SXj03Shn<0l?3`0>c/k03dm?@0jn_[0?Gem@3fm_H0mOGe0`3oool00`3hn?P0
l_;b0?ooo`020?ooo`030?knoP3oool0oooo00D0oooo00D0oOgm0?Win@3kno/0n_[j0?knoP020?Og
m`030?_kn`3`l?00n_[j0080kno_01L0iNGU0>k^kP3UiND0jn_[0>CTi03[jn/0i>CT0>OWi`3Shn<0
f][J0>?Sh`3Jf]X0clo?0<S8b03Fe]H0clo?0<g=c@36a/H0b<S80<c<c039bLT0`L710<30`0020<;2
`P0L0;^k^`2e]KD0`<300;Rh^02c/k<0/[:b0:b/[02ZZZX0/;2`0:b/[02WYjL0Z:RX0:BTY02WYjL0
ZZZZ09nOW`2XZ:P0XZ:R09RHV02CTi<0V9RH09FEU@2FUYH0SXj>0:6QX@2IVIT0UIFE09VIV@80S8b<
00P0RXZ:08f=S@2>SXh0Rh^;0820P021PH40QhN708^;R`80Ph>300P0QhN707inOP25QHD0QXJ608:2
PP1oOgl0PH610820P080Ogmo0180MWIf07EeM@1oOgl0MGEe07IfMP1eMGD0NGUi07EeM@1gMgL0NGUi
07QhN01bLW80MGEe07MgM`1dM7@0KVi^06m_K`1jNWX206m_K`06079bLP1/K6`0Kfm_06i^KP1_Kfl0
KFe]0P1XJ6P08@1[Jf/0Hf=S06i^KP1/K6`0IfMW06EUI@1SHf<0Kfm_065QH@1SHf<0KFe]06QXJ01U
IFD0K6a/06QXJ01[Jf/0JFUY06QXJ01QHF40HV9R06IVIP1PH600GemO06ATI01VIVH0H61P069RHP1Q
HF40Fe]K06=SH`1TI6@0F5QH06=SH`060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT0
0`3IfMT0FP1SHf<0J6QX05aLG01UIFD0Hf=S061PH01OGel0HV9R065QH@1VIVH0H61P069RHP1WIfL0
Hf=S05eMG@1RHV80IfMW06UYJ@1UIFD0HF5Q06EUI@1WIfL0Hf=S06IVIP1WIfL0GemO06UYJ@1VIVH0
Hf=S06ATI01UIFD0J6QX06i^KP1VIVH0I6AT06IVIP1`L700JVYZ06a/K01^KVh0IFEU07EeM@1XJ6P0
KFe]06m_K`1aLG40KVi^06a/K01dM7@0L71`06a/K01bLW80JVYZ07=cL`1dM7@0Ng]k07IfMP1eMGD0
JVYZ07MgM`1bLW80MGEe075aL@1hN7P0MWIf07emO@1jNWX0LW9b07moO`1mOGd0Q8B407]kN`1iNGT0
Ogmo07inOP1oOgl0QHF508:2PP25QHD0PX:208b<S022PX80TY:B08R8R02;Rh/0S8b<08>3P`29RHT0
TI6A08f=S@80S8b<01D0TI6A09:BTP2JVYX0UYJF09FEU@2FUYH0U9BD09FEU@2?Shl0VIVI09^KV`2J
VYX0WYjN0:>SX`2VYZH0XZ:R0:2PX02UYJD0Zj^[0:j^[P2ZZZX00P2b/[802@2c/k<0/[:b0;2`/02c
/k<0^k^k0;no_`31`L40`<300;fm_@020<71`@030<?3``39bLT0d=3@0080dM7A00L0clo?0=;BdP3D
e=@0g]kN0>CTi03Lg=`0gmoO0080i^KV0`3[jn/20>k^kP090>o_k`3dm?@0no_k0?ooo`3dm?@0oooo
0?KfmP3jn_X0lo?c00L0oooo00<0oOgm0?knoP3oool00P3oool04@3moOd0oooo0?ooo`3emOD0n_[j
0?_kn`3gmoL0l_;b0>o_k`3hn?P0kno_0?Gem@3bl_80kNg]0>k^kP3]kNd0jNWY0080i>CT03@0j>SX
0>?Sh`3Ng]h0f][J0>7Qh@3Rh^80d];B0=3@d03?cll0d=3@0<o?c`32`/80d=3@0<k>cP37alL0a/K6
0;^k^`31`L40^k^k0<C4a02h^;P0/K6a0;>c/`2g]kL0Zj^[0:j^[P2][Jd0/K6a0:RXZ02RXZ80Y:BT
0:6QX@2MWId0Vi^K0:6QX@2MWId0U9BD09RHV02GUiL0U9BD09FEU@2ATI40UIFE09JFUP2ATI40Shn?
09NGU`2@T900Shn?092@T02ATI40SHf=0P25QHD01P26QXH0Q8B40820P020P800PX:20861P@80Ogmo
00X0OGem08N7Q`1kNg/0O7al07QhN01oOgl0Ng]k06m_K`1iNGT0N7Qh0P1gMgL0601oOgl0L71`07Qh
N01gMgL0L71`06e]K@1^KVh0JVYZ075aL@1`L700LW9b06e]K@1gMgL0Lg=c079bLP1/K6`0KVi^06=S
H`1_Kfl0KFe]071`L01eMGD0Kfm_06QXJ080K6a/00P0JFUY06IVIP1UIFD0Jf][061PH01WIfL0I6AT
069RHP80JFUY01<0J6QX079bLP1nOWh0JVYZ06EUI@1VIVH0IfMW06UYJ@1VIVH0Hf=S06UYJ@1VIVH0
GEeM065QH@1PH600I6AT05iNGP1RHV80HF5Q00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI
0=WIf@030=WIf@0706ATI01NGUh0I6AT06EUI@1RHV80IfMW069RHP0206ATI00706IVIP1[Jf/0JFUY
05iNGP1TI6@0G5aL061PH00206ATI00506UYJ@1TI6@0IfMW06=SH`1[Jf/00P1QHF40301YJFT0I6AT
06IVIP1RHV80I6AT06IVIP1WIfL0JFUY06a/K01ZJVX0KFe]06IVIP80JFUY0P1ZJVX0401_Kfl0KFe]
06ATI01_Kfl0I6AT06IVIP1^KVh0M7Ad06m_K`1aLG40KFe]07AdM01^KVh0LG5a07IfMP1`L70207Mg
M`0a06m_K`1aLG40L71`079bLP1fMWH0NGUi079bLP1fMWH0MGEe071`L01eMGD0Ogmo07emO@1lO7`0
OWin07]kN`21PH40MgMg0861P@1oOgl0O7al08N7Q`23Ph<0QXJ608>3P`22PX80RXZ:08R8R02>SXh0
SHf=08n?S`2>SXh0Rh^;096AT@2<S8`0TI6A08j>SP2DU9@0VIVI09bLW02HV9P0UIFE09jNWP2MWId0
WYjN09VIV@2OWil0YZJV0:RXZ0020:>SX`0V0:FUY@2e]KD0bl_;0:j^[P2[Zj/0_Kfm0;Rh^02b/[80
^KVi0;>c/`2n_[h0`/;20;no_`32`/80b<S80;no_`3=cLd0alO70<k>cP3@d=00e=CD0=WIf@3Lg=`0
dM7A0>?Sh`3QhN40j>SX0=cLg03Vi^H0kNg]0>k^kP3clo<0nOWi0?3`l03gmoL0m_Kf0?ooo`3no_h2
0?ooo`030?gmo@3oool0oooo0140oooo00X0n?Sh0?ooo`3oool0o?cl0?KfmP3oool0no_k0?KfmP3a
lO40n?Sh0P3[jn/06@3inOT0kno_0?3`l03alO40i^KV0=kNgP3Jf]X0g]kN0>3Ph03]kNd0i^KV0=3@
d03Kfm/0c/k>0=?Cd`3?cll0bl_;0<30`037alL0cLg=0;fm_@34a<@0`L710<30`02m_Kd00P2c/k<0
302`/;00[jn_0:b/[02YZJT0[Zj^0;:b/P2WYjL0ZJVY0:f][@2PX:00WYjN0:>SX`80WIfM01H0VYZJ
09FEU@2FUYH0U9BD09bLW02HV9P0UiNG09JFUP2CTi<0Rh^;09FEU@2=SHd0R8R809BDU02ATI40SHf=
08F5Q@20P800Ng]k092@T025QHD0PH610P23Ph<02P1nOWh0PH6107moO`1gMgL0P82007emO@1nOWh0
P820075aL@1eMGD307AdM00507=cL`1hN7P0Ng]k071`L01bLW800P1`L7002P1aLG40LW9b071`L01]
KFd0LG5a06][J`1cLg<0IfMW06i^KP1_Kfl206a/K00506EUI@1YJFT0IFEU06QXJ01fMWH00P1[Jf/0
1P1]KFd0JFUY06EUI@1YJFT0HV9R06YZJP80IVIV00`0I6AT06YZJP1gMgL0Kfm_06i^KP1PH600JVYZ
06QXJ01SHf<0IfMW06ATI01UIFD206QXJ00606UYJ@1RHV80JFUY06EUI@1PH600G5aL1P3IfMT10000
0040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00T0H61P05YJFP1TI6@0HF5Q069RHP1NGUh0
IFEU06ATI01NGUh00P1SHf<02@1OGel0IfMW06=SH`1RHV80GUiN069RHP1TI6@0JFUY06MWI`02069R
HP0:065QH@1TI6@0K6a/06ATI01SHf<0IFEU06MWI`1XJ6P0IVIV06ATI080K6a/01<0J6QX06ATI01T
I6@0J6QX06=SH`1ZJVX0IfMW06IVIP1fMWH0LG5a06][J`1^KVh0K6a/06m_K`1fMWH0JFUY06m_K`1c
Lg<0KFe]0080LW9b00h0MgMg079bLP1gMgL0Lg=c07UiN@1aLG40MWIf07EeM@1jNWX0Lg=c07MgM`1j
NWX0NGUi07]kN`80O7al00@0P82007QhN01gMgL0QXJ60`1nOWh01`25QHD0RXZ:0820P021PH40Ph>3
07moO`2=SHd00P2:RXX06@25QHD0R8R808b<S02<S8`0QhN708^;R`2EUID0VYZJ09JFUP2@T900TI6A
09VIV@2FUYH0Vi^K09NGU`2IVIT0W9bL09RHV02UYJD0X:2P0:BTY02VYZH0ZZZZ0:VYZ@2^[Zh00P2[
Zj/01`2`/;00];Bd0;Vi^@2l_;`0_kno0;^k^`31`L400P30`<003035aLD0b<S80<W9b@3:b/X0c/k>
0=;BdP3@d=00aLG50=[JfP3MgMd0fm_K0>;RhP80i>CT00X0j>SX0?3`l03/k>`0lO7a0>g]k@3kno/0
mOGe0?ooo`3moOd0n?Sh0P3oool00`3dm?@0oooo0?ooo`0G0?ooo`80no_k02L0n?Sh0??cl`3no_h0
no_k0>o_k`3/k>`0mOGe0>k^kP3`l?00k>c/0>;RhP3Ph>00f][J0>7Qh@3Shn<0g]kN0=[JfP3EeMD0
c/k>0<o?c`3EeMD0c/k>0<71`@3;bl/0aLG50;bl_039bLT0`<300;:b/P30`<00][Jf0;Zj^P2b/[80
][Jf0;Vi^@2a/K40[:b/0:f][@2_[jl00P2XZ:P0A02RXZ80Xj>S0::RXP2OWil0WYjN09ZJVP2DU9@0
UIFE09:BTP2EUID0Ti>C09ZJVP2FUYH0WYjN09JFUP28R8P0TY:B08b<S02>SXh0RHV9096AT@2>SXh0
QXJ608F5Q@2=SHd0R8R808^;R`21PH40QXJ607moO`1kNg/0Lg=c0861P@1fMWH0MgMg07EeM@1iNGT0
NWYj07UiN@1jNWX0Lg=c07MgM`23Ph<0MgMg075aL@1dM7@0MgMg079bLP1_Kfl0L71`06a/K01aLG40
Lg=c06m_K`1bLW80IfMW06a/K01_Kfl0L71`06i^KP1]KFd0LG5a06QXJ01dM7@0L71`07=cL`1YJFT0
LG5a0P1/K6`03@1[Jf/0IFEU06ATI01WIfL0Jf][06UYJ@1]KFd0HV9R07IfMP1]KFd0KVi^06QXJ01W
IfL00P1QHF402@1^KVh0H61P061PH01OGel0IFEU06ATI01QHF40H61P05mOG`02069RHPH0fMWI0@00
00010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0;06=SH`1OGel0HF5Q05mOG`1SHf<0IFEU
06=SH`1VIVH0HF5Q05mOG`1SHf<00`1TI6@04@1RHV80I6AT06UYJ@1[Jf/0KVi^06MWI`1ZJVX0GUiN
06ATI01RHV80K6a/06YZJP1QHF40IVIV06e]K@1PH600HF5Q0080IfMW01`0KVi^06IVIP1ZJVX0HF5Q
06EUI@1ZJVX0IfMW071`L01[Jf/0K6a/06][J`1_Kfl0I6AT06a/K01^KVh0Kfm_07EeM@1dM7@0Jf][
07=cL`1^KVh0Kfm_07QhN01eMGD0L71`07QhN01cLg<0MgMg0P1bLW80601lO7`0M7Ad07QhN01iNGT0
MWIf0861P@27QhL0NWYj07alO01kNg/0NWYj07emO@1lO7`0PH6108B4Q022PX80QhN708:2PP21PH40
QHF508Z:RP24Q8@0QXJ608V9R@80QXJ601<0RXZ:08^;R`2@T900UYJF09BDU02;Rh/0UYJF09>CT`2B
TY80VYZJ09fMW@2NWYh0UYJF0:6QX@2NWYh0WIfM0:^[Z`2OWil0Z:RX0080Xj>S0280ZJVY0:^[Z`2/
[:`0^[Zj0;6a/@2h^;P0_[jn0<;2`P2l_;`0`<300<S8b033`l<0alO70<K6aP37alL0b/[:0<_;b`3=
cLd0dm?C0=cLg03MgMd0h^;R0=[JfP3QhN40i>CT0>OWi`3[jn/0j>SX0?Ogm`3fm_H0n?Sh0?Ogm`3o
ool0n_[j8`3oool0103moOd0m_Kf0?Ogm`3lo?`20?Gem@0C0?3`l03^k^h0j>SX0??cl`3QhN40j>SX
0>OWi`3Ng]h0gmoO0=WIf@3Cdm<0dM7A0<g=c@3@d=00b/[:0<O7a`3=cLd0b<S80<?3``020;^k^`0M
0;Ng]`30`<00_;bl0;Rh^02a/K40_[jn0:b/[02][Jd0YjNW0:VYZ@2ZZZX0XJ6Q0:>SX`2RXZ80YJFU
09fMW@2QXJ40U9BD09RHV02JVYX0UYJF09nOW`2IVIT0Shn?09NGU`2EUID0S8b<08j>SP2?Shl00P29
RHT0702=SHd0T92@08B4Q02:RXX0Q8B407emO@21PH40NGUi08>3P`1oOgl0OGem0820P01jNWX0O7al
07emO@1jNWX0NGUi07inOP1mOGd0O7al07moO`1lO7`0NWYj07AdM01`L700MWIf075aL@1gMgL2079b
LP0O06m_K`1[Jf/0Lg=c07]kN`1gMgL0MGEe07AdM01bLW80N7Qh07IfMP1^KVh0KFe]07AdM01^KVh0
IVIV06][J`1UIFD0JVYZ071`L01VIVH0L71`06UYJ@1TI6@0Hf=S06ATI01XJ6P0HF5Q069RHP1TI6@0
JFUY069RHP0206MWI`0506ATI01XJ6P0Hf=S05mOG`1TI6@00P1RHV801`1^KVh0GemO069RHP1RHV80
HF5Q05aLG01OGel01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00<0IVIV
065QH@1LG5`00P1RHV80=@1TI6@0IFEU065QH@1XJ6P0Jf][06ATI01PH600Hf=S06UYJ@1/K6`0GEeM
06=SH`1VIVH0H61P06][J`1QHF40K6a/06UYJ@1SHf<0IFEU06=SH`1VIVH0HV9R06][J`1QHF40J6QX
06EUI@1XJ6P0K6a/06e]K@1ZJVX0Jf][06i^KP1bLW80JFUY06ATI01/K6`0Kfm_06i^KP1_Kfl0LG5a
079bLP1ZJVX0KVi^06][J`1eMGD0K6a/07IfMP1`L700LG5a079bLP1`L700MWIf0080Lg=c01d0Ng]k
07YjNP1fMWH0MGEe07AdM01eMGD0N7Qh07inOP1jNWX0MgMg07IfMP1lO7`0Ogmo07YjNP1gMgL0PH61
07moO`20P800QHF50820P025QHD0P82008N7Q`29RHT0S8b<08Z:RP2>SXh0T92@08V9R@0208f=S@07
09BDU02=SHd0Vi^K09:BTP2KVi/0TY:B09nOW`0209VIV@0;09FEU@2LW9`0XJ6Q0:2PX02`/;00Y:BT
09bLW02VYZH0Zj^[0:VYZ@2XZ:P00P2_[jl02@2i^KT0/k>c0;Bd]02i^KT0_kno0<?3``31`L40`l?3
0<C4a0020<k>cP0A0<o?c`3;bl/0fm_K0=?Cd`3Fe]H0h>3P0=kNgP3Shn<0fm_K0>GUi@3YjNT0l?3`
0>[ZjP3bl_80oooo0?_kn`3lo?`0:@3oool0?03inOT0m_Kf0?knoP3inOT0j^[Z0?;blP3dm?@0j^[Z
0?7al@3UiND0g=cL0=_Kf`3Ng]h0f=SH0=CDe03Bd]80bLW90=7Ad@3>c/h0b<S80<G5a@3:b/X0`/;2
0;Vi^@31`L40_[jn0;Fe]@2j^[X0][Jf0:j^[P2g]kL0];Bd0;Jf]P2/[:`0YJFU0:6QX@2TY:@0[:b/
0:6QX@2MWId0Xj>S0:2PX02KVi/0X:2P09fMW@2LW9`0UYJF09bLW02EUID0UYJF09>CT`2ATI40T92@
08n?S`2<S8`0RXZ:08R8R026QXH0QHF508J6QP80R8R800`0Q8B408^;R`27QhL0PH6108B4Q021PH40
PX:207UiN@24Q8@0Ng]k07UiN@1kNg/207emO@0D07UiN@1kNg/0MgMg07EeM@1^KVh0LW9b07AdM01/
K6`0LW9b07=cL`1fMWH0MgMg07=cL`1dM7@0MWIf06MWI`1[Jf/0K6a/06m_K`1YJFT206YZJP0@06UY
J@1WIfL0KVi^075aL@1[Jf/0KVi^07=cL`1_Kfl0Jf][06IVIP1SHf<0JVYZ06MWI`1UIFD0IVIV06EU
I@80HV9R00P0IFEU06MWI`1TI6@0GemO06YZJP1OGel0IfMW06IVIP80IFEU00@0HV9R06=SH`1PH600
IfMW0P1QHF460=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT04P1SHf<0H61P
05mOG`1RHV80H61P05mOG`1SHf<0G5aL05eMG@1QHF40Hf=S061PH01ZJVX0I6AT06YZJP1VIVH0JFUY
061PH080J6QX00H0IVIV069RHP1RHV80Hf=S06EUI@1QHF4206MWI`0?06ATI01[Jf/0JFUY06EUI@1N
GUh0MgMg06QXJ01_Kfl0LG5a06][J`1WIfL0Jf][06QXJ01UIFD0IfMW0080Jf][00P0L71`06i^KP1^
KVh0KVi^06UYJ@1XJ6P0LW9b06m_K`80MGEe00T0Lg=c06m_K`1cLg<0KFe]06m_K`1kNg/0LG5a07=c
L`1mOGd00P1gMgL0201hN7P0OWin07MgM`1oOgl0P82007moO`22PX80NWYj0P22PX80<020P800OWin
08V9R@23Ph<0QXJ608B4Q025QHD0S8b<08^;R`20P800Shn?08Z:RP29RHT0U9BD09JFUP2>SXh0RHV9
09>CT`2?Shl0V9RH0::RXP2QXJ40VYZJ096AT@2GUiL0Vi^K0:6QX@2UYJD0YjNW0;2`/02SXj<0YJFU
0:>SX`2RXZ80XJ6Q0:j^[P2][Jd0]kNg0;bl_033`l<0`/;20<71`@2o_kl0`/;20<G5a@2l_;`0alO7
0<W9b@80d=3@00h0dM7A0<k>cP3Jf]X0g=cL0>_[j`3Ti>@0hN7Q0>;RhP3_knl0kNg]0>WYj@3hn?P0
o?cl0?GemB/0oooo0680o?cl0?knoP3no_h0m_Kf0?Cdm03hn?P0kNg]0>OWi`3Ogml0j>SX0=kNgP3Q
hN40f][J0=SHf03MgMd0c/k>0<g=c@3?cll0b<S80<?3``3:b/X0`L710;no_`31`L40_Kfm0<71`@2g
]kL0^[Zj0:n_[`2c/k<0/[:b0;Fe]@2TY:@0YJFU0:RXZ02VYZH0XJ6Q09bLW02IVIT0YZJV09^KV`2D
U9@0WinO09VIV@2KVi/0V9RH09:BTP2EUID0TY:B096AT@2BTY80RXZ:09>CT`29RHT0Shn?08J6QP29
RHT0R8R808F5Q@22PX80Rh^;0820P023Ph<0QXJ607moO`1lO7`0QHF50820P021PH40OWin07]kN`1o
Ogl0Ng]k07IfMP1jNWX0NGUi079bLP1cLg<0LG5a07MgM`1aLG40MGEe07MgM`21PH40Jf][071`L01d
M7@0Lg=c06QXJ01^KVh0JVYZ06e]K@1gMgL0JVYZ071`L01XJ6P0IVIV06YZJP80IVIV00H0IfMW06QX
J01RHV80Jf][065QH@1]KFd206=SH`0:065QH@1WIfL0J6QX065QH@1ZJVX0Hf=S06MWI`1UIFD0HF5Q
06EUI@80IVIV00/0HF5Q06IVIP1TI6@0JVYZ06IVIP1TI6@0GUiN05eMG@1TI6@0FUYJ065QH@060=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0<P1UIFD0Hf=S05mOG`1PH600Hf=S
06EUI@1RHV80FUYJ069RHP1IFET0GemO06YZJP1SHf<0I6AT069RHP1WIfL0JVYZ061PH01SHf<0JFUY
06a/K01TI6@0Hf=S06EUI@1WIfL0Jf][06=SH`1ZJVX0IFEU069RHP1TI6@0GemO071`L01NGUh0MgMg
06IVIP1TI6@0Jf][06EUI@1_Kfl0JVYZ06i^KP1/K6`0JVYZ06m_K`1`L700KVi^06e]K@1`L700KVi^
0P1dM7@0501_Kfl0LW9b06i^KP1aLG40Kfm_07MgM`1bLW80Lg=c075aL@1fMWH0M7Ad07YjNP1aLG40
NGUi08F5Q@24Q8@0OGem07inOP24Q8@0NGUi0P22PX803`1lO7`0P82008F5Q@21PH40OGem08>3P`25
QHD0OGem08Z:RP2>SXh0R8R8092@T02;Rh/0RHV908n?S`0208b<S00A08f=S@2CTi<0Vi^K09NGU`2M
WId0U9BD09RHV02IVIT0WIfM09nOW`2PX:00XZ:R0:6QX@2OWil0Z:RX0:BTY02ZZZX00P2WYjL04P2X
Z:P0/;2`0;2`/02e]KD0]kNg0<[:bP35aLD0^KVi0<O7a`38b<P0a<C40<W9b@3;bl/0c/k>0=kNgP3E
eMD0emOG0=SHf080g]kN00P0iNGU0>[ZjP3Zj^X0jn_[0?KfmP3alO40m_Kf0?[jnRd0oooo01h0n_[j
0?ooo`3oool0m_Kf0?Cdm03bl_80k^k^0>c/k03bl_80j>SX0>CTi03Vi^H0hN7Q0=_Kf`3EeMD0emOG
0=7Ad@3Hf=P0clo?0=3@d03>c/h0bLW90;^k^`30`<00a<C40;Vi^@2j^[X0]KFe0;:b/P2`/;020:j^
[P0:0:ZZZP2YZJT0ZJVY0:RXZ02VYZH0YJFU09nOW`2LW9`0YZJV09fMW@80WYjN0P2EUID0802HV9P0
TI6A09JFUP2GUiL0Shn?08V9R@27QhL0UiNG08^;R`23Ph<0RHV908R8R020P800RHV908R8R02;Rh/0
Ogmo08N7Q`22PX80Q8B408F5Q@1oOgl0OWin07]kN`1mOGd0NWYj07UiN@1jNWX0NGUi07emO@1dM7@0
MWIf0P1jNWX03`1dM7@0L71`06i^KP1]KFd0Kfm_07MgM`1_Kfl0Lg=c06][J`1cLg<0M7Ad06YZJP1f
MWH0IVIV06m_K`0306e]K@0Q06m_K`1WIfL0JFUY06m_K`1WIfL0Hf=S071`L01]KFd0Jf][06m_K`1T
I6@0IfMW06][J`1SHf<0LG5a06UYJ@1OGel0IfMW06ATI01SHf<0H61P06EUI@1YJFT0Hf=S05mOG`1Z
JVX0IVIV06QXJ01TI6@0HF5Q05mOG`1NGUh0GEeM00H0fMWI0@0000010=WIf@005P3IfMT00`000000
fMWI0=WIf@030=WIf@04069RHP1MGEd0GEeM05iNGP80GemO00<0I6AT06EUI@1QHF400P1QHF42069R
HP1F06=SH`1TI6@0I6AT06IVIP1WIfL0H61P06EUI@1WIfL0JFUY06IVIP1PH600IfMW06a/K01VIVH0
JFUY06MWI`1bLW80L71`06UYJ@1ZJVX0Hf=S069RHP1YJFT0IfMW05mOG`1]KFd0LG5a06m_K`1]KFd0
LG5a06a/K01^KVh0JFUY06][J`1]KFd0LW9b06m_K`1fMWH0K6a/07QhN01`L700JVYZ07MgM`1fMWH0
M7Ad07QhN01cLg<0MgMg07IfMP20P800Lg=c0820P01lO7`0MGEe07QhN022PX80NGUi07YjNP27QhL0
Ng]k07UiN@20P800R8R807inOP24Q8@0QhN707inOP27QhL0QHF508b<S02=SHd0Rh^;08j>SP2:RXX0
TI6A08f=S@2BTY80RHV909RHV02<S8`0Shn?09FEU@2DU9@0VYZJ09BDU02GUiL209ZJVP0T09nOW`2U
YJD0WIfM09nOW`2WYjL0ZZZZ0:VYZ@2][Jd0[Zj^0;2`/02_[jl0_;bl0;Zj^P2o_kl0_[jn0<30`02o
_kl0alO70<S8b039bLT0dm?C0=OGe`3Cdm<0emOG0=CDe03IfMT0e=CD0>?Sh`3Xj>P0k>c/0>_[j`3`
l?00l_;b0?Ogm`3jn_X0n?Sh<03oool01`3lo?`0oOgm0?knoP3dm?@0m_Kf0?Win@3bl_800P3^k^h0
1P3/k>`0i^KV0=cLg03Jf]X0f=SH0=;BdP80dm?C01<0d=3@0=7Ad@3?cll0`L710<S8b032`/80`<30
0;Vi^@2h^;P0^[Zj0;6a/@2/[:`0/;2`0;Ng]`2a/K40[:b/0:ZZZP2QXJ40Xj>S0080YZJV00X0Z:RX
0::RXP2JVYX0W9bL09fMW@2IVIT0U9BD08n?S`2DU9@0VYZJ0P2:RXX01@2=SHd0TI6A096AT@2CTi<0
SHf=0080QHF502D0P82008b<S020P800QXJ608:2PP1mOGd0PH6107emO@2;Rh/0OGem08B4Q026QXH0
Ng]k07UiN@1hN7P0Ng]k07YjNP1gMgL0Ng]k06a/K01iNGT0M7Ad07UiN@1dM7@0L71`06m_K`1eMGD0
MgMg075aL@1_Kfl0L71`07=cL`1WIfL0LG5a079bLP1[Jf/0JFUY0080LG5a0P1^KVh206EUI@0M06IV
IP1YJFT0IFEU06EUI@1/K6`0J6QX06ATI01SHf<0GEeM06m_K`1WIfL0H61P069RHP1]KFd0IFEU06QX
J01QHF40Hf=S06IVIP1[Jf/0J6QX06IVIP1OGel0IVIV061PH01NGUh0G5aL05iNGP1MGEd01P3IfMT1
00000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00l0HF5Q05QHF01MGEd0HF5Q069RHP1T
I6@0GemO06=SH`1RHV80IfMW06EUI@1WIfL0I6AT06IVIP1SHf<00P1QHF405@1XJ6P0Hf=S06IVIP1Z
JVX0J6QX06MWI`1YJFT0IFEU06MWI`1SHf<0IFEU06UYJ@1TI6@0J6QX06][J`1OGel0IfMW071`L01T
I6@0K6a/06e]K@0206a/K00606i^KP1XJ6P0KFe]06UYJ@1`L700I6AT101^KVh0;P1ZJVX0Lg=c071`
L01/K6`0LG5a07AdM01gMgL0L71`07AdM01iNGT0O7al06m_K`1dM7@0OGem07alO01eMGD0NGUi07]k
N`21PH40OWin08>3P`1mOGd0P82008:2PP21PH40RHV90861P@1lO7`0RHV908Z:RP1oOgl0SXj>08:2
PP2@T900RHV908b<S02@T900QhN7096AT@2DU9@0Ti>C09BDU02KVi/0UIFE09VIV@2EUID209VIV@0T
09ZJVP2TY:@0WIfM0:NWY`2QXJ40YZJV0:2PX02[Zj/0[Jf]0:^[Z`2][Jd0/;2`0;Bd]02m_Kd0^;Rh
0;Bd]02h^;P0^[Zj0<G5a@2l_;`0bl_;0<?3``39bLT0f][J0=GEe@3Jf]X0dM7A0=cLg03Hf=P0hn?S
0>KViP3YjNT0i^KV0>c/k03]kNd0n?Sh=03oool01P3kno/0o?cl0?Gem@3kno/0oooo0>c/k080jn_[
0240j>SX0>3Ph03Jf]X0fm_K0=SHf03Cdm<0bl_;0=?Cd`3GemL0dM7A0<?3``2o_kl0a<C40;no_`2k
^k/0^KVi0;^k^`2h^;P0][Jf0;>c/`2^[Zh0Zj^[0:ZZZP2`/;00Z:RX0:FUY@2PX:00XZ:R09jNWP2S
Xj<0WIfM0:BTY02PX:000P2GUiL09P2HV9P0UYJF09:BTP2>SXh0RXZ:08b<S02?Shl0QHF508V9R@23
Ph<0T92@08Z:RP2;Rh/0QHF507]kN`26QXH0PX:20820P01mOGd0RXZ:07QhN01iNGT0N7Qh07]kN`1o
Ogl0Ph>307emO@1nOWh0Ogmo0861P@1jNWX0M7Ad07=cL`1dM7@0LG5a079bLP1iNGT0MgMg0P1`L700
5@1eMGD0M7Ad06m_K`1/K6`0JFUY06m_K`1bLW80KVi^06a/K01VIVH0Lg=c06e]K@1/K6`0IVIV06UY
J@1WIfL0Kfm_06EUI@1VIVH0HV9R06ATI00306MWI`0:06QXJ01VIVH0IFEU06EUI@1YJFT0G5aL06UY
J@1TI6@0IVIV05iNGP80I6AT00@0JFUY05mOG`1PH600HF5Q0P1MGEd00`1PH600GEeM06ATI0060=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT03`1WIfL0GemO06=SH`1OGel0G5aL
069RHP1OGel0I6AT069RHP1SHf<0GemO06=SH`1YJFT0HF5Q06=SH`0206IVIP0T06QXJ01TI6@0I6AT
06ATI01UIFD0H61P06][J`1PH600Hf=S06IVIP1ZJVX0J6QX065QH@1VIVH0JVYZ06m_K`1XJ6P0KFe]
06][J`1aLG40JVYZ079bLP1ZJVX0J6QX06IVIP1UIFD0LG5a071`L01_Kfl0IfMW06i^KP1bLW80Lg=c
07IfMP1aLG40NWYj0`1eMGD01P21PH40MgMg07QhN01iNGT0LG5a079bLP80Ng]k00<0MGEe07alO01k
Ng/0101nOWh03P1jNWX0P82007emO@1nOWh0QHF507moO`26QXH0S8b<08:2PP2<S8`0QhN708B4Q02;
Rh/0T92@0P2;Rh/03P24Q8@0T92@08n?S`2FUYH0TY:B09JFUP2OWil0UiNG09VIV@2JVYX0V9RH0::R
XP2KVi/0X:2P0P2VYZH0302XZ:P0Zj^[0:>SX`2XZ:P0]kNg0:n_[`2m_Kd0_;bl0;Zj^P2e]KD0]kNg
0<C4a080_Kfm0180aLG50<;2`P3;bl/0a/K60=KFeP3?cll0f][J0=oOg`3Jf]X0hn?S0>WYj@3QhN40
i^KV0>g]k@3fm_H0kno_0?Win@3no_hh0?ooo`0E0?_kn`3emOD0moOg0>c/k03]kNd0jNWY0>KViP3O
gml0g=cL0=KFeP3Ph>00c<c<0<k>cP39bLT0`l?30;no_`37alL0^k^k0;fm_@2j^[X0_Kfm0080]KFe
00D0_Kfm0:ZZZP2][Jd0ZJVY0:f][@020:^[Z`0S0::RXP2WYjL0WIfM09^KV`2MWId0Xj>S09ZJVP2I
VIT0X:2P09FEU@2DU9@0T92@09ZJVP2=SHd0UYJF08j>SP2GUiL0QXJ608b<S02>SXh0Rh^;08j>SP29
RHT0QhN707moO`1mOGd0PX:20861P@1nOWh0Ogmo0820P021PH40R8R80820P021PH400P1jNWX01`1o
Ogl0Lg=c07emO@20P800N7Qh07EeM@1dM7@00P1`L700701cLg<0LW9b06i^KP1dM7@0KFe]07MgM`1U
IFD0KVi^07EeM@1`L700JVYZ079bLP1^KVh0JFUY07=cL`1SHf<0Kfm_06IVIP1^KVh0JFUY06IVIP1U
IFD0KFe]06YZJP1/K6`0KFe]06i^KP1[Jf/206IVIP0306YZJP1VIVH0GEeM0080H61P00<0HV9R06MW
I`1PH6000P1UIFD01`1LG5`0HV9R05iNGP1RHV80I6AT05]KF`1OGel01P3IfMT100000040fMWI000F
0=WIf@800000103IfMT206=SH`09069RHP1MGEd0GemO069RHP1SHf<0H61P05eMG@1YJFT0H61P00<0
HF5Q0280I6AT05mOG`1PH600J6QX06=SH`1RHV80Hf=S06][J`1bLW80J6QX069RHP1VIVH0IfMW06e]
K@1cLg<0IVIV06MWI`1UIFD0KFe]06][J`1VIVH0Jf][071`L01_Kfl0Jf][075aL@1_Kfl0KFe]06MW
I`1[Jf/0L71`06YZJP1[Jf/0LG5a0P1_Kfl02P1^KVh0Kfm_07AdM01aLG40M7Ad071`L01hN7P0Lg=c
07AdM01jNWX207inOP0^07IfMP1eMGD0O7al079bLP1fMWH0NWYj07QhN021PH40P82008N7Q`26QXH0
Ph>30861P@28R8P0PH6108:2PP1oOgl0Q8B408F5Q@28R8P0Rh^;07emO@27QhL0SHf=096AT@2MWId0
UIFE096AT@2?Shl0W9bL09BDU029RHT0WYjN09RHV02FUYH0UiNG09fMW@2PX:00Y:BT09nOW`2WYjL0
Z:RX0:>SX`2WYjL0/;2`0:f][@80[Zj^01P0^KVi0;>c/`2f][H0`/;20;bl_02n_[h0bLW90<[:bP39
bLT0dM7A0<C4a03@d=00e]KF0=gMg@3Lg=`0h>3P0>SXj03Ti>@0kNg]0>o_k`3alO40lo?c0?ooo`3m
oOdh0?ooo`0D0?Gem@3gmoL0nOWi0?_kn`3_knl0j^[Z0>GUi@3Ogml0hN7Q0=[JfP3Shn<0clo?0<_;
b`3@d=00b/[:0<O7a`3;bl/0b/[:0<30`02o_kl30;bl_00;0;6a/@2][Jd0[jn_0:^[Z`2/[:`0[Zj^
0:VYZ@2ZZZX0XJ6Q0:JVYP2][Jd00P2RXZ802P2KVi/0UYJF09VIV@2FUYH0Vi^K09VIV@2GUiL0SXj>
09:BTP29RHT208Z:RP0808b<S024Q8@0P82008f=S@25QHD0Ph>308B4Q02:RXX20820P00707moO`25
QHD0P82008:2PP1nOWh0P82007inOP020861P@0708>3P`1fMWH0Lg=c07moO`1eMGD0MWIf079bLP02
07AdM00B07IfMP1]KFd0L71`06a/K01`L700KFe]06i^KP1aLG40K6a/06i^KP1aLG40M7Ad069RHP1^
KVh0K6a/06MWI`1XJ6P0K6a/0P1ZJVX03@1SHf<0KFe]06UYJ@1VIVH0GemO06EUI@1VIVH0HV9R06YZ
JP1WIfL0GUiN065QH@1UIFD00P1PH6002@1XJ6P0IFEU06IVIP1OGel0IVIV05iNGP1YJFT0Hf=S05]K
F`02061PH00305iNGP1OGel0fMWI00@0fMWI0P0000010=WIf@005P3IfMT00`000000fMWI0=WIf@03
0=WIf@0=06ATI01QHF40H61P06EUI@1TI6@0IfMW05mOG`1SHf<0HV9R06IVIP1TI6@0HF5Q069RHP02
06ATI00305eMG@1OGel0JVYZ00<0IVIV00L0HF5Q06IVIP1WIfL0H61P06=SH`1TI6@0K6a/0080JFUY
00<0I6AT06EUI@1WIfL00P1TI6@0;01aLG40IVIV06m_K`1[Jf/0KFe]075aL@1WIfL0K6a/079bLP1]
KFd0JVYZ06e]K@1/K6`0Lg=c07IfMP1dM7@0KFe]07AdM01`L700NGUi07MgM`1eMGD0MgMg07YjNP1g
MgL0OWin07UiN@1gMgL0M7Ad07MgM`22PX80PH6108>3P`24Q8@0PH6107emO@20P800RHV907UiN@23
Ph<0P82008V9R@20P800Ogmo0P2;Rh/208>3P`0A09FEU@2IVIT0Ti>C092@T02IVIT0SXj>09>CT`2B
TY80V9RH09:BTP2CTi<0Vi^K09VIV@2PX:00UYJF0:BTY02LW9`00P2ZZZX06P2[Zj/0/[:b0;:b/P2]
[Jd0YjNW0:n_[`2/[:`0/k>c0;Bd]038b<P0/k>c0;fm_@2i^KT0bl_;0<c<c03@d=00dM7A0=GEe@3D
e=@0f=SH0=WIf@3Ph>00gmoO0>GUi@3Rh^80l?3`0P3Zj^X00`3gmoL0o?cl0?knoP0l0?ooo`0;0?_k
n`3dm?@0oooo0?7al@3YjNT0j^[Z0=oOg`3Ng]h0fMWI0=gMg@3Jf]X00P3De=@20<?3``030;no_`33
`l<0_;bl0080^;Rh0480/K6a0;Vi^@2`/;00]kNg0:j^[P2[Zj/0YZJV0:FUY@2NWYh0XJ6Q0:2PX02S
Xj<0XJ6Q09nOW`2JVYX0W9bL09fMW@2ATI40U9BD09VIV@2FUYH0T92@08n?S`2DU9@0TY:B08n?S`2<
S8`0Shn?08j>SP2?Shl0RHV908J6QP2=SHd0Ogmo08:2PP24Q8@0QHF508N7Q`20P800NWYj0861P@1h
N7P0Ogmo07UiN@1hN7P0Ng]k07emO@1gMgL0MGEe07inOP1eMGD0MgMg07=cL`1gMgL0M7Ad07EeM@1f
MWH0K6a/06i^KP1aLG40JVYZ079bLP1]KFd0K6a/07EeM@1gMgL206e]K@0Q071`L01YJFT0KFe]05mO
G`1XJ6P0MWIf06][J`1YJFT0IFEU069RHP1]KFd0IfMW06YZJP1UIFD0HF5Q06a/K01_Kfl0Hf=S06a/
K01WIfL0JFUY065QH@1WIfL0GUiN069RHP1VIVH0G5aL05iNGP1RHV80GemO05eMG@1NGUh0Hf=S00H0
fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0;06ATI01WIfL0JVYZ069RHP1O
Gel0H61P065QH@1WIfL0IVIV065QH@1LG5`00P1VIVH0301MGEd0H61P06ATI01PH600IFEU069RHP1T
I6@0HF5Q069RHP1TI6@0HV9R075aL@80JFUY00P0IfMW06EUI@1XJ6P0IfMW06][J`1YJFT0Kfm_06MW
I`80J6QX01l0M7Ad075aL@1]KFd0KVi^06a/K01_Kfl0KFe]06m_K`1/K6`0L71`06MWI`1^KVh0JFUY
07AdM01aLG40KVi^079bLP1aLG40MGEe07MgM`1fMWH0L71`07YjNP1hN7P0Lg=c07alO028R8P0O7al
07YjNP1oOgl0Ng]k0080Q8B400P0P82008:2PP1oOgl0OWin07]kN`29RHT0Ph>30861P@80QXJ60P24
Q8@02P26QXH0RHV908f=S@2:RXX0TY:B08f=S@2ATI40SXj>096AT@2FUYH209NGU`0A09RHV02OWil0
Xj>S09FEU@2QXJ40Y:BT0:b/[02XZ:P0ZJVY0;Zj^P2`/;00/[:b0:b/[02c/k<0/;2`0;Fe]@30`<00
0P2i^KT04`2l_;`0a<C40<K6aP3<c<`0a<C40<_;b`3<c<`0d];B0=OGe`3Kfm/0hN7Q0>CTi03Xj>P0
k>c/0>SXj03_knl0no_k0?Cdm03lo?`0?03oool01`3no_h0oooo0>[ZjP3kno/0kNg]0?3`l03/k>`0
0P3YjNT0H@3Vi^H0emOG0=OGe`3>c/h0clo?0=SHf03:b/X0bl_;0<71`@30`<00^k^k0;jn_P2i^KT0
];Bd0:j^[P2g]kL0]KFe0;:b/P2/[:`0YjNW0:BTY02RXZ80YZJV0:FUY@2TY:@0X:2P09ZJVP2OWil0
VIVI09^KV`2DU9@0UiNG09:BTP2EUID0T92@08j>SP2:RXX0RHV909BDU02:RXX0Shn?08N7Q`29RHT0
RXZ:08:2PP28R8P0Ng]k07moO`1nOWh0Ogmo07emO@1lO7`0NWYj07inOP1jNWX0MWIf07]kN`1lO7`0
LG5a07inOP1eMGD0LW9b07UiN@1gMgL0NGUi07=cL`1eMGD0Kfm_06i^KP1gMgL0MGEe06MWI`1YJFT0
K6a/06e]K@1cLg<0JVYZ06m_K`1ZJVX0J6QX06MWI`1_Kfl0K6a/06QXJ01TI6@0IFEU06][J`1XJ6P0
IfMW06=SH`1]KFd0K6a/06UYJ@1RHV80J6QX06EUI@1QHF400P1VIVH03P1]KFd0HF5Q065QH@1LG5`0
I6AT05aLG01NGUh0I6AT061PH01QHF40JVYZ05eMG@1XJ6P0IVIV1P3IfMT100000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI00<0HF5Q061PH01RHV800P1SHf<02P1UIFD0K6a/06EUI@1]KFd0
I6AT061PH01UIFD0H61P06MWI`1VIVH2069RHP0K061PH01WIfL0H61P05mOG`1UIFD0IfMW06EUI@1Y
JFT0IfMW06IVIP1XJ6P0H61P06QXJ01/K6`0Jf][06EUI@1/K6`0I6AT06UYJ@1]KFd0LG5a079bLP1_
Kfl0J6QX07=cL`1fMWH0L71`0080KVi^02X0Kfm_06e]K@1`L700MgMg075aL@1gMgL0MWIf07YjNP1d
M7@0NWYj07UiN@1eMGD0NWYj07QhN01dM7@0NWYj07moO`20P800PX:207inOP1oOgl0PH6107emO@1o
Ogl0NGUi07]kN`1jNWX0QHF507emO@2>SXh0QXJ607inOP2?Shl0Q8B408Z:RP24Q8@0S8b<08R8R027
QhL0U9BD09VIV@2ATI4208f=S@0F08j>SP2IVIT0UIFE09FEU@2LW9`0VYZJ09BDU02OWil0[:b/09fM
W@2VYZH0[Zj^0:JVYP2^[Zh0Z:RX0;>c/`2`/;00[jn_0;Vi^@30`<00^[Zj0;Bd]080`/;20180`l?3
0<K6aP37alL0c<c<0<g=c@3Jf]X0emOG0>;RhP3Xj>P0gmoO0>KViP3dm?@0jn_[0>[ZjP3kno/0o?cl
0?ooo`3no_ho0?ooo`0:0?Shn03gmoL0j^[Z0?;blP3Shn<0inOW0>7Qh@3IfMT0iNGU0=KFeP80clo?
0140bl_;0<K6aP3;bl/0cLg=0<W9b@2f][H0`l?30;Vi^@2d];@0]kNg0:b/[02a/K40];Bd0:n_[`2X
Z:P0YZJV0:BTY00209nOW`0=09jNWP2RXZ80W9bL09ZJVP2GUiL0V9RH09jNWP2DU9@0UiNG08n?S`2A
TI40S8b<08f=S@0208b<S00H08>3P`28R8P0QXJ607moO`28R8P0PH6107YjNP1oOgl0Q8B40820P026
QXH0Ogmo07inOP1iNGT0MWIf07inOP1kNg/0NWYj07inOP1eMGD0LG5a07QhN01iNGT0OGem0P1hN7P0
501eMGD0LW9b079bLP1/K6`0LW9b075aL@1cLg<0IVIV06e]K@1/K6`0JVYZ06IVIP1YJFT0K6a/06][
J`1_Kfl0JFUY06ATI01UIFD0JVYZ0P1UIFD00`1WIfL0L71`06MWI`0206YZJP0606a/K01XJ6P0GemO
06=SH`1YJFT0J6QX0P1VIVH0301PH600J6QX06EUI@1YJFT0HV9R06e]K@1PH600Hf=S06ATI01UIFD0
GEeM06ATI0H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@06065QH@1UIFD0
GEeM05mOG`1TI6@0GUiN201RHV80301TI6@0Fe]K06EUI@1]KFd0HF5Q06e]K@1QHF40K6a/06IVIP1Y
JFT0LG5a06UYJ@80J6QX00<0IFEU06MWI`1XJ6P00P1[Jf/02@1WIfL0Jf][06IVIP1^KVh0JVYZ06i^
KP1gMgL0L71`06i^KP02075aL@0S06e]K@1`L700Kfm_06a/K01cLg<0Kfm_07=cL`1`L700MWIf071`
L01fMWH0MgMg07UiN@1fMWH0Lg=c07UiN@1jNWX0N7Qh07YjNP1nOWh0O7al07UiN@1jNWX0RHV907Qh
N026QXH0PX:208N7Q`1oOgl0QXJ607alO01nOWh0Q8B408>3P`27QhL00P26QXH02P2<S8`0QhN708B4
Q02>SXh0UIFE08f=S@2<S8`0TI6A09:BTP2JVYX209NGU`0S09RHV02LW9`0Vi^K0::RXP2LW9`0Y:BT
0:6QX@2PX:00WYjN0:^[Z`2][Jd0]KFe0:n_[`2YZJT0/k>c0;Bd]02c/k<0^;Rh0;Zj^P2o_kl0^[Zj
0<K6aP3?cll0a<C40=?Cd`3De=@0fMWI0>SXj03Lg=`0j^[Z0>OWi`3]kNd0k^k^0?3`l03emOD00P3i
nOU00?ooo`050?[jnP3moOd0o?cl0>k^kP3bl_800P3[jn/04@3Rh^80inOW0>;RhP3MgMd0f=SH0=GE
e@3:b/X0d=3@0<c<c034a<@0b<S80<;2`P2n_[h0/[:b0;Vi^@2b/[80][Jf0080/[:b00@0Y:BT0:VY
Z@2MWId0YJFU0P2PX:003P2TY:@0XZ:R09RHV02PX:00W9bL08b<S02MWId0Ti>C09VIV@2GUiL0T92@
09BDU029RHT0TY:B0P28R8P0102:RXX0QXJ608J6QP1oOgl208>3P`0>0820P01mOGd0MgMg08B4Q021
PH40O7al0861P@1hN7P0M7Ad07UiN@1hN7P0Ogmo07UiN@1eMGD207UiN@0B06e]K@1cLg<0Ogmo079b
LP1^KVh0JVYZ071`L01_Kfl0J6QX075aL@1YJFT0JVYZ071`L01ZJVX0KVi^071`L01^KVh0JVYZ0P1[
Jf/01@1aLG40JFUY071`L01WIfL0KFe]0080Hf=S00P0KVi^06YZJP1/K6`0IFEU06ATI01NGUh0HF5Q
06IVIP<0I6AT0P1UIFD02P1PH600F5QH05iNGP1RHV80G5aL065QH@1GEeL0JVYZ05QHF01TI6@60=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT02P1PH600GUiN06=SH`1OGel0HF5Q
06UYJ@1WIfL0JVYZ06ATI01JFUX206=SH`0906a/K01_Kfl0IfMW06=SH`1WIfL0HV9R06ATI01XJ6P0
HV9R0080J6QX00`0IVIV06a/K01[Jf/0Jf][06IVIP1ZJVX0J6QX06UYJ@1[Jf/0JVYZ06e]K@1_Kfl2
075aL@0X06m_K`1`L700LW9b079bLP1YJFT0L71`06e]K@1/K6`0KFe]06i^KP1cLg<0N7Qh07alO01c
Lg<0Jf][06i^KP1dM7@0OWin07=cL`20P800M7Ad07YjNP1dM7@0O7al07=cL`1lO7`0NWYj07UiN@20
P800Ogmo07IfMP27QhL0OGem07inOP23Ph<0PX:20861P@26QXH0RHV907moO`80Ph>301<0QHF508J6
QP2BTY80RXZ:08n?S`2;Rh/0SHf=09>CT`2BTY80WinO09VIV@2EUID0Vi^K0::RXP2IVIT0WinO09jN
WP2QXJ40YjNW00<0Xj>S01D0YJFU0:n_[`2b/[80[Jf]0;2`/02^[Zh0^[Zj0;6a/@2j^[X0`/;20<C4
a03=cLd0_kno0<G5a@3@d=00b<S80=;BdP3Hf=P0h>3P0=kNgP3Ogml00P3Ti>@01@3Vi^H0lo?c0?Ge
m@3lo?`0o_kn04<0oooo00@0n_[j0?Shn03fm_H0kNg]0P3WinL01`3Ph>00f][J0=;BdP3Hf=P0eMGE
0<c<c03AdM400P39bLT03@3?cll0^KVi0;jn_P2g]kL0/;2`0;Rh^02/[:`0/[:b0:ZZZP2[Zj/0[Jf]
0:FUY@2YZJT00`2SXj<04`2PX:00VIVI08n?S`2HV9P0U9BD096AT@2KVi/0UYJF09NGU`2BTY80TI6A
08n?S`2>SXh0Q8B408R8R02;Rh/0OWin08>3P`25QHD00P23Ph<0301cLg<0OGem07moO`1mOGd0Ogmo
08:2PP1oOgl0O7al07IfMP1oOgl0OGem07UiN@80M7Ad00/0NWYj07UiN@1gMgL0NGUi071`L01WIfL0
LW9b07QhN01^KVh0JVYZ075aL@0207EeM@0306m_K`1/K6`0Kfm_0080J6QX00/0I6AT06m_K`1YJFT0
LW9b06][J`1XJ6P0JVYZ06ATI01VIVH0H61P06UYJ@0206ATI00E06MWI`1^KVh0IVIV06EUI@1ZJVX0
HF5Q06UYJ@1]KFd0KVi^05mOG`1VIVH0HV9R06IVIP1RHV80IFEU065QH@1PH600G5aL069RHP1PH600
G5aL00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0906=SH`1KFe/0GEeM
069RHP1WIfL0GemO061PH01KFe/0HF5Q0080I6AT00X0Jf][05eMG@1WIfL0I6AT06UYJ@1UIFD0J6QX
06=SH`1XJ6P0H61P0P1RHV801@1XJ6P0GemO06][J`1YJFT0J6QX0080IVIV00H0KVi^06MWI`1UIFD0
Jf][06YZJP1/K6`2075aL@0R07IfMP1_Kfl0Lg=c079bLP1]KFd0KVi^06UYJ@1dM7@0K6a/071`L01_
Kfl0Lg=c07IfMP1]KFd0KVi^06][J`1fMWH0MgMg0861P@1hN7P0Ng]k07=cL`1mOGd0MGEe07YjNP1k
Ng/0Ogmo08>3P`1mOGd0OWin07alO022PX80P82008B4Q080QHF500T0T92@08^;R`28R8P0TI6A08F5
Q@2;Rh/0SXj>08b<S02DU9@00P2@T900102EUID0TY:B08Z:RP2ATI4209ZJVP80V9RH00<0UYJF09jN
WP2OWil00P2LW9`01@2KVi/0WYjN0:RXZ02ZZZX0ZJVY0080/;2`00D0/[:b0:n_[`2g]kL0_Kfm0;Rh
^0020;bl_0070;no_`35aLD0c/k>0=7Ad@3Bd]80e=CD0=[JfP030>3Ph0030>[ZjP3`l?00k>c/0080
n?ShAP3oool03`3fm_H0kno_0>o_k`3Zj^X0jNWY0=kNgP3Kfm/0gmoO0=GEe@37alL0clo?0=GEe@3?
cll0b<S80;no_`020;fm_@0:0<G5a@2k^k/0][Jf0;6a/@2[Zj/0/K6a0:b/[02_[jl0Z:RX0:^[Z`80
Vi^K00`0X:2P09>CT`2HV9P0WinO09FEU@2DU9@0Vi^K09NGU`2HV9P0TI6A08b<S02=SHd208n?S`0O
08>3P`2=SHd0QXJ608Z:RP24Q8@0Ph>308B4Q027QhL0O7al07inOP1lO7`0Q8B407moO`1mOGd0PX:2
07UiN@1nOWh0Ng]k08:2PP1jNWX0O7al07MgM`1lO7`0MWIf07UiN@1dM7@0LW9b07=cL`1]KFd0LW9b
06a/K002075aL@07079bLP1[Jf/0KFe]06][J`1YJFT0J6QX06m_K`0206UYJ@0606=SH`1ZJVX0K6a/
06IVIP1TI6@0Jf][0P1/K6`0201TI6@0JVYZ06ATI01WIfL0IVIV061PH01QHF40H61P0`1RHV803@1Y
JFT0Jf][06MWI`1KFe/0Hf=S065QH@1SHf<0HV9R05]KF`1TI6@0GUiN05aLG01UIFD01P3IfMT10000
0040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00d0Hf=S069RHP1FEUH0GemO06=SH`1PH600
IVIV06QXJ01OGel0GEeM06ATI01RHV80IVIV0080IFEU00h0J6QX06YZJP1WIfL0HV9R06UYJ@1[Jf/0
Hf=S06a/K01[Jf/0I6AT06IVIP1]KFd0IFEU061PH080I6AT0P1WIfL02`1aLG40IVIV06m_K`1`L700
MWIf07UiN@1/K6`0LW9b06e]K@1aLG40MGEe0080KFe]01l0Kfm_06QXJ01/K6`0LG5a06QXJ01gMgL0
LG5a07=cL`1gMgL0LG5a07IfMP1dM7@0O7al07QhN01lO7`0NGUi07]kN`1hN7P0OGem07YjNP1kNg/0
O7al0820P01lO7`0PX:207inOP24Q8@0PH6108:2PP21PH40QhN70080QXJ602@0Rh^;09>CT`2:RXX0
R8R8092@T02DU9@0VIVI09BDU02<S8`0Shn?09ZJVP2?Shl0XJ6Q09ZJVP2NWYh0XJ6Q0::RXP2WYjL0
Y:BT0::RXP2YZJT0W9bL0:>SX`2^[Zh0ZZZZ0:b/[02l_;`0^KVi0;Fe]@2g]kL0`l?30<G5a@31`L40
bl_;0<o?c`3=cLd20<_;b`0:0=oOg`3Ng]h0i>CT0>CTi03/k>`0inOW0?KfmP3dm?@0k^k^0?gmoDD0
oooo00P0o?cl0?knoP3lo?`0k>c/0>SXj03^k^h0j>SX0=kNgP80g=cL01<0f=SH0=;BdP3@d=00dm?C
0<O7a`38b<P0`l?30;^k^`2j^[X0`<300;Jf]P2d];@0^;Rh0;no_`2[Zj/0Z:RX0:VYZ@2`/;00WYjN
0080X:2P01D0W9bL09RHV02KVi/0W9bL0:2PX02?Shl0WYjN092@T02DU9@0V9RH08j>SP2ATI40QhN7
08B4Q025QHD0SXj>08N7Q`21PH40QhN708J6QP25QHD00P22PX804P23Ph<0Q8B407IfMP1jNWX0PX:2
07moO`1fMWH0NGUi0820P01lO7`0NWYj07moO`1cLg<0MWIf071`L01kNg/0LG5a07=cL`80LW9b01<0
MGEe07IfMP1bLW80Kfm_075aL@1]KFd0KVi^075aL@1]KFd0KVi^06m_K`1NGUh0JVYZ05mOG`1VIVH0
KVi^06YZJP1[Jf/0IFEU0080K6a/0140I6AT065QH@1SHf<0Hf=S071`L01SHf<0IFEU06=SH`1NGUh0
I6AT06=SH`1QHF40Hf=S06EUI@1SHf<0Jf][06=SH`02061PH00405eMG@1QHF40I6AT065QH@H0fMWI
0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0S06QXJ01NGUh0JVYZ061PH01TI6@0
IFEU05QHF01SHf<0IFEU05iNGP1WIfL0GemO06EUI@1RHV80IVIV06=SH`1RHV80Hf=S06MWI`1[Jf/0
J6QX06e]K@1PH600K6a/06IVIP1_Kfl0KVi^06a/K01`L700IfMW06m_K`1QHF40J6QX06i^KP1`L700
0P1]KFd01P1[Jf/0N7Qh06a/K01^KVh0L71`07=cL`80KVi^0P1bLW802@1cLg<0KVi^07]kN`1fMWH0
M7Ad06a/K01fMWH0MgMg075aL@0207EeM@0N079bLP1kNg/0LG5a07moO`1eMGD0QXJ60861P@1cLg<0
Ng]k07inOP1oOgl0Ph>30820P025QHD0Ogmo08Z:RP2?Shl0R8R80820P025QHD0R8R808:2PP2>SXh0
QXJ608n?S`2@T900R8R809BDU02CTi<0UiNG0P2JVYX03P2GUiL0VIVI09fMW@2KVi/0YJFU0:6QX@2N
WYh0ZJVY0:NWY`2][Jd0YJFU0:b/[02[Zj/0[:b/0P2^[Zh0502g]kL0_kno0;Vi^@2l_;`0`/;20<?3
``35aLD0d];B0=?Cd`3Jf]X0gmoO0=KFeP3Jf]X0h>3P0>SXj03[jn/0kno_0>_[j`3dm?@0no_kA`3o
ool07P3moOd0n?Sh0>k^kP3alO40jn_[0>[ZjP3Ogml0gMgM0>7Qh@3Jf]X0eMGE0=7Ad@33`l<0c<c<
0<C4a036a/H0`l?30;Ng]`2c/k<0]KFe0;Ng]`2e]KD0[Jf]0;>c/`2/[:`0/K6a0:NWY`2TY:@0XJ6Q
09bLW080WIfM00H0WinO0:2PX02@T900VIVI092@T02LW9`209FEU@0G09ZJVP2ATI40Rh^;08V9R@2@
T900R8R808j>SP26QXH0R8R807moO`27QhL0R8R808>3P`21PH40MgMg07emO@1kNg/0PH6107emO@20
P800OGem07IfMP1bLW800P1hN7P03`20P800MWIf075aL@1iNGT0L71`07MgM`1dM7@0NWYj07EeM@1b
LW80Lg=c07EeM@1bLW80KFe]071`L00206m_K`0706=SH`1]KFd0IfMW06ATI01ZJVX0I6AT06m_K`02
06YZJP0=069RHP1WIfL0J6QX06EUI@1^KVh0J6QX06][J`1WIfL0J6QX071`L01WIfL0I6AT05eMG@02
069RHP0;06][J`1WIfL0Hf=S06IVIP1NGUh0K6a/065QH@1SHf<0G5aL05]KF`1OGel01P3IfMT10000
0040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI03H0Hf=S065QH@1TI6@0IVIV06QXJ01UIFD0
I6AT05aLG01YJFT0Hf=S06EUI@1QHF40HV9R06ATI01VIVH0HV9R06ATI01UIFD0I6AT06UYJ@1PH600
JFUY06QXJ01VIVH0IFEU05eMG@1QHF40JFUY06MWI`1[Jf/0K6a/079bLP1UIFD0L71`06IVIP1_Kfl0
KVi^07QhN01jNWX0L71`06m_K`1dM7@0Kfm_06UYJ@1dM7@0MGEe075aL@1`L700M7Ad07YjNP1hN7P0
LW9b07IfMP1dM7@2071`L00507EeM@1dM7@0M7Ad07EeM@20P8000P1jNWX02@1kNg/0N7Qh07emO@22
PX80QhN707alO01oOgl0R8R807inOP020820P00T08B4Q02=SHd0Rh^;08F5Q@29RHT0SHf=08n?S`2=
SHd0TI6A09NGU`2@T900Ti>C09JFUP2@T900TY:B08b<S02JVYX0Ti>C09nOW`2LW9`0Vi^K0:2PX02L
W9`0Vi^K0:j^[P2UYJD0[jn_0:JVYP2a/K40]kNg0;>c/`2n_[h0^[Zj0<30`02i^KT0_[jn0P34a<@0
1@33`l<0d];B0=7Ad@3Hf=P0hn?S0080h^;R00H0hN7Q0>[ZjP3[jn/0lO7a0?;blP3jn_Y90?ooo`03
0?[jnP3gmoL0l?3`0080l_;b02d0jNWY0=[JfP3Lg=`0h>3P0=_Kf`3Bd]80dM7A0=3@d02n_[h0`l?3
0<[:bP2h^;P0^k^k0;2`/02l_;`0/[:b0;>c/`2/[:`0Zj^[0:f][@2XZ:P0YjNW0:2PX02[Zj/0V9RH
09bLW02MWId0Vi^K09VIV@2=SHd0WIfM09:BTP2CTi<0TI6A09>CT`29RHT0Shn?096AT@2EUID0Shn?
08^;R`29RHT0R8R808^;R`21PH400P23Ph<30820P00307inOP1cLg<0OWin00<0OWin01L0NGUi07If
MP1kNg/0MGEe07QhN01kNg/0Ph>307IfMP1`L700MWIf07UiN@1aLG40LW9b075aL@1bLW80KFe]07=c
L`1_Kfl0LG5a06][J`1WIfL0KFe]06a/K00206][J`0306IVIP1[Jf/0JFUY0080IfMW00h0JVYZ069R
HP1QHF40Hf=S06a/K01TI6@0K6a/06ATI01/K6`0IVIV061PH01UIFD0I6AT061PH080GemO00T0IVIV
061PH01RHV80GUiN069RHP1VIVH0IFEU05mOG`1QHF401P3IfMT100000040fMWI000F0=WIf@030000
003IfMT0fMWI00<0fMWI01P0GemO069RHP1TI6@0GemO069RHP1UIFD0IfMW05mOG`1MGEd0HV9R06IV
IP1WIfL0JFUY065QH@1ZJVX0HF5Q06UYJ@1SHf<0JVYZ06ATI01QHF40Kfm_06QXJ01VIVH206UYJ@0=
06MWI`1YJFT0L71`06][J`1WIfL0JVYZ075aL@1[Jf/0IfMW06e]K@1ZJVX0KVi^06a/K002071`L003
06YZJP1eMGD0Kfm_0080Lg=c02X0L71`07EeM@1]KFd0KVi^06a/K01`L700OGem07AdM01nOWh0Lg=c
07moO`1kNg/0MGEe07moO`1hN7P0MgMg07UiN@1gMgL0O7al07inOP23Ph<0P82008Z:RP1mOGd0PX:2
08R8R022PX80O7al08V9R@2=SHd0S8b<08Z:RP2;Rh/0QHF5092@T02<S8`0Shn?09BDU02FUYH0SXj>
09:BTP2JVYX209FEU@0C09JFUP2IVIT0V9RH0:JVYP2SXj<0Z:RX09bLW02][Jd0[:b/0:2PX02XZ:P0
YZJV0;6a/@2VYZH0/k>c0;6a/@2h^;P0`L710<30`0020<K6aP060<G5a@39bLT0alO70=GEe@3?cll0
gmoO0P3QhN401@3Vi^H0jn_[0?3`l03dm?@0nOWi04X0oooo00`0oOgm0?Ogm`3jn_X0moOg0>KViP3R
h^80hN7Q0=kNgP3GemL0f=SH0=OGe`3Fe]H20<K6aP0<0<S8b03<c<`0_;bl0;Jf]P31`L40]kNg0;6a
/@2e]KD0[:b/0;2`/02ZZZX0X:2P0P2TY:@01@2VYZH0Xj>S09jNWP2WYjL0VYZJ00<0V9RH00@0UiNG
09JFUP2IVIT0T92@0P2;Rh/07P2@T900SHf=08b<S027QhL0UIFE08F5Q@2:RXX0S8b<0820P01nOWh0
QhN70820P01iNGT0PH610820P01jNWX0P820079bLP1]KFd0MGEe07MgM`1hN7P0Ph>307IfMP1lO7`0
Lg=c07AdM01fMWH0M7Ad07UiN@80OGem00<0KVi^075aL@1`L7000P1bLW803P1/K6`0JVYZ06YZJP1[
Jf/0Kfm_06YZJP1YJFT0KFe]06EUI@1aLG40Kfm_06MWI`1TI6@0JVYZ0P1XJ6P00`1UIFD0I6AT06YZ
JP0306EUI@0306a/K01TI6@0I6AT0080HV9R00<0Hf=S06IVIP1OGel00P1QHF42061PH00305aLG01S
Hf<0G5aL00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0606EUI@1MGEd0
I6AT06IVIP1MGEd0HV9R0P1UIFD0;01NGUh0JFUY06ATI01SHf<0I6AT06a/K01VIVH0HF5Q06=SH`1Y
JFT0J6QX06][J`1VIVH0HV9R06][J`1TI6@0KFe]075aL@1XJ6P0IVIV06i^KP1WIfL0Jf][06e]K@1X
J6P0KFe]071`L01[Jf/0M7Ad075aL@1]KFd0Jf][06i^KP1aLG40MGEe079bLP1fMWH0LW9b06m_K`1[
Jf/0N7Qh07=cL`1eMGD0LW9b0P1gMgL00`1jNWX0MWIf07AdM00207AdM00907IfMP1nOWh0NWYj07If
MP1oOgl0N7Qh07]kN`1lO7`0MWIf0080Ng]k00@0PX:208Z:RP1mOGd0Ph>30P29RHT208Z:RP0508b<
S022PX80TI6A08^;R`2DU9@00P2>SXh03P2HV9P0Ti>C09bLW02JVYX0U9BD09:BTP2HV9P0UiNG0:6Q
X@2[Zj/0ZZZZ0:6QX@2[Zj/0ZJVY0P2XZ:P05`2][Jd0ZZZZ0;Fe]@2c/k<0[Zj^0<;2`P2n_[h0`l?3
0<71`@34a<@0_[jn0<c<c03Cdm<0e]KF0=GEe@3Kfm/0iNGU0>3Ph03Ti>@0l_;b0?3`l03dm?@0n?Sh
04d0oooo00@0l_;b0?7al@3UiND0h^;R0P3Shn<01`3Jf]X0dm?C0=_Kf`3=cLd0b/[:0<;2`P3AdM40
0P38b<P20;^k^`080;Bd]02b/[80]KFe0:j^[P2[Zj/0Z:RX0;2`/02TY:@20:ZZZP0309jNWP2MWId0
YJFU0080VYZJ0P2HV9P0202?Shl0V9RH08V9R@2ATI40RXZ:08^;R`2@T900RHV90P27QhL01@2=SHd0
RXZ:08:2PP1lO7`0PX:20080Q8B400@0O7al07inOP1oOgl0PX:20P1jNWX04P1hN7P0MgMg07AdM01g
MgL0MWIf07MgM`1iNGT0N7Qh07MgM`1cLg<0OGem07=cL`1dM7@0N7Qh079bLP1hN7P0KVi^06m_K`80
LG5a01<0Kfm_06e]K@1`L700Lg=c06i^KP1cLg<0KFe]06a/K01XJ6P0K6a/06YZJP1XJ6P0K6a/06IV
IP1YJFT0Jf][065QH@1YJFT0HV9R0080I6AT00d0HV9R06UYJ@1QHF40GUiN065QH@1PH600EeMG065Q
H@1PH600GemO061PH01YJFT0H61P0080GemO1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0
fMWI00<0fMWI00L0IVIV05mOG`1VIVH0GemO06][J`1WIfL0IFEU0080GemO03D0HF5Q06UYJ@1XJ6P0
IFEU06=SH`1VIVH0IFEU06QXJ01PH600JFUY06ATI01/K6`0JFUY06][J`1RHV80KVi^06a/K01ZJVX0
GemO06MWI`1^KVh0Jf][06QXJ01[Jf/0KVi^071`L01_Kfl0JVYZ07AdM01WIfL0Lg=c06a/K01_Kfl0
Lg=c06][J`1`L700LW9b06i^KP1hN7P0MGEe06UYJ@1eMGD0JVYZ07AdM01eMGD0OWin07IfMP1jNWX0
N7Qh07MgM`1eMGD0OGem07=cL`0207UiN@0907moO`20P800OWin07YjNP21PH40P82008N7Q`20P800
Ph>30080RHV900P0PX:208V9R@2?Shl0SHf=08j>SP2CTi<0TI6A08V9R@<0U9BD00@0TY:B09JFUP2H
V9P0W9bL0P2JVYX0802MWId0ZZZZ0:>SX`2MWId0Vi^K0:ZZZP2PX:00[:b/0:j^[P2ZZZX0];Bd0;Jf
]P2j^[X0[Zj^0;Fe]@2i^KT0_kno0<;2`P3;bl/0a/K60<g=c@3@d=00e=CD0=;BdP3Ogml0gMgM0>SX
j03dm?@0l_;b0?Shn03bl_80o?clB`3oool20?_kn`0L0>g]k@3/k>`0lO7a0>g]k@3Vi^H0h>3P0=kN
gP3IfMT0f][J0<k>cP3:b/X0dm?C0<C4a036a/H0^k^k0;Zj^P2b/[80[jn_0;Bd]02/[:`0[Jf]0;2`
/02WYjL0ZJVY0:^[Z`2WYjL0XJ6Q09jNWP80XZ:R01@0VIVI09nOW`2IVIT0V9RH092@T02GUiL0UYJF
08B4Q02>SXh0R8R809:BTP2?Shl0QHF508V9R@24Q8@0RHV908B4Q020P800QHF507YjNP80OGem00X0
OWin07]kN`1mOGd0PH6107alO01aLG40Lg=c07EeM@1iNGT0N7Qh0P1iNGT01@1dM7@0MgMg07YjNP1b
LW80L71`0080Lg=c02X0MgMg079bLP1dM7@0Kfm_07=cL`1aLG40K6a/06i^KP1aLG40KFe]06QXJ01[
Jf/0J6QX06YZJP1VIVH0K6a/075aL@1YJFT0JVYZ06IVIP1/K6`0Jf][06QXJ01QHF40IFEU06IVIP1Y
JFT0J6QX06UYJ@1SHf<0IfMW061PH01SHf<0IFEU069RHP1JFUX0Hf=S065QH@1NGUh0GemO065QH@1L
G5`60=WIf@4000000@3IfMT001H0fMWI0P0000040=WIf@07065QH@1WIfL0IfMW06IVIP1ZJVX0I6AT
06e]K@0206=SH`0406MWI`1YJFT0J6QX06UYJ@80Hf=S00D0IVIV05iNGP1SHf<0HF5Q06IVIP0206UY
J@0506EUI@1ZJVX0JVYZ06EUI@1WIfL00P1XJ6P08@1WIfL0L71`06e]K@1/K6`0Jf][06MWI`1[Jf/0
JFUY06EUI@1TI6@0M7Ad06m_K`1dM7@0Jf][075aL@1gMgL0JVYZ071`L01cLg<0LG5a06a/K01fMWH0
MGEe07UiN@1bLW80Ogmo0820P01hN7P0O7al07emO@1lO7`0OWin07]kN`0207emO@0<08B4Q01iNGT0
P82007IfMP20P800Ogmo08:2PP2<S8`0Ph>307YjNP26QXH0RXZ:0P24Q8@02P26QXH0Ph>3092@T027
QhL0U9BD09JFUP2;Rh/0TY:B09FEU@2KVi/209bLW00R096AT@2NWYh0Xj>S09fMW@2VYZH0XJ6Q0:^[
Z`2][Jd0YJFU0::RXP2XZ:P0Y:BT0;:b/P2m_Kd0^;Rh0;Fe]@2l_;`0^[Zj0<30`037alL0c/k>0<W9
b@3@d=00emOG0=7Ad@3Jf]X0emOG0>?Sh`3_knl0lo?c0?3`l03no_h0oooo0?knoT`0oooo01T0n?Sh
0?knoP3^k^h0lo?c0>CTi03Zj^X0i^KV0=gMg@3IfMT0e]KF0=7Ad@3@d=00bl_;0<S8b03;bl/0`/;2
0;^k^`2h^;P0^[Zj0;jn_P2l_;`0]KFe0;6a/@2`/;00[jn_0080YZJV00T0ZJVY0:BTY02GUiL0W9bL
0:6QX@2CTi<0W9bL09^KV`2@T9000P2EUID00`2;Rh/0SHf=08j>SP0208j>SP0B096AT@23Ph<0SXj>
092@T01lO7`0Ph>308B4Q022PX80Ogmo08B4Q01mOGd0MGEe07=cL`20P800OGem07MgM`1jNWX0LW9b
0P1fMWH07`1hN7P0LW9b07QhN01dM7@0Lg=c07EeM@1aLG40Lg=c06a/K01iNGT0L71`06e]K@1XJ6P0
Kfm_06i^KP1bLW80KFe]06MWI`1aLG40HV9R071`L01YJFT0K6a/06UYJ@1XJ6P0JVYZ07AdM01/K6`0
IfMW06QXJ01/K6`00`1WIfL04@1SHf<0IFEU065QH@1UIFD0IVIV06e]K@1VIVH0FUYJ06EUI@1WIfL0
HF5Q069RHP1UIFD0K6a/06IVIP1TI6@0H61P00D0fMWI0P0000010=WIf@005P3IfMT00`000000fMWI
0=WIf@030=WIf@0I06ATI01QHF40HV9R06EUI@1XJ6P0HV9R06QXJ01QHF40K6a/06IVIP1LG5`0HV9R
06ATI01VIVH0H61P069RHP1TI6@0JFUY06][J`1UIFD0JFUY06QXJ01WIfL0K6a/06e]K@0206m_K`0@
06e]K@1VIVH0LG5a06QXJ01UIFD0M7Ad071`L01UIFD0IfMW06][J`1]KFd0JFUY06i^KP1XJ6P0LG5a
06QXJ080MWIf0140J6QX07AdM01_Kfl0LG5a07YjNP1bLW80MGEe07MgM`1eMGD0MWIf07QhN01kNg/0
NWYj07alO01iNGT0OGem0820P00207YjNP0P07alO024Q8@0OGem08>3P`1lO7`0Ogmo08Z:RP1mOGd0
QhN708B4Q01nOWh0QXJ608V9R@28R8P0TY:B08n?S`2BTY80RXZ:08f=S@2HV9P0VIVI09^KV`2IVIT0
VYZJ09RHV02KVi/0YZJV09bLW02VYZH0VIVI09nOW`2XZ:P20:NWY`80YZJV01H0/k>c0:n_[`2d];@0
]KFe0;Ng]`32`/80^k^k0<30`032`/80d=3@0<g=c@36a/H0f=SH0=GEe@3Hf=P0f][J0=SHf03Rh^80
kno_0?Cdm03`l?00o?clC`3oool20?Win@0V0??cl`3Zj^X0jn_[0>;RhP3Ti>@0dm?C0=3@d03:b/X0
d=3@0<[:bP3?cll0c/k>0;Rh^032`/80^[Zj0;jn_P2d];@0][Jf0:n_[`2c/k<0ZJVY0:b/[02][Jd0
WinO0:>SX`2QXJ40VIVI09fMW@2UYJD0V9RH09^KV`2FUYH0T92@09VIV@2GUiL0UYJF08Z:RP2BTY82
08f=S@0>08^;R`2>SXh0Ph>3096AT@28R8P0NWYj08R8R027QhL0P82008:2PP28R8P0OWin08:2PP1m
OGd307EeM@0E079bLP1hN7P0MgMg07EeM@1`L700Kfm_06e]K@1/K6`0JFUY07AdM01bLW80MWIf075a
L@1cLg<0L71`07EeM@1cLg<0LG5a06a/K01`L700Jf][0080J6QX00<0Jf][06i^KP1ZJVX00P1WIfL0
1@1ZJVX0J6QX06=SH`1WIfL0H61P0080IVIV0100HV9R06MWI`1QHF40IFEU06i^KP1VIVH0HV9R06AT
I01UIFD0GEeM05mOG`1MGEd0GUiN06MWI`1TI6@0IfMW0P1MGEd00`1OGel0fMWI0=WIf@040=WIf@40
00000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0201UIFD0G5aL06ATI01WIfL0IFEU065Q
H@1SHf<0IFEU0P1YJFT05P1RHV80H61P06ATI01SHf<0IVIV06UYJ@1[Jf/0GUiN06QXJ01]KFd0JFUY
06e]K@1VIVH0J6QX06][J`1VIVH0Jf][06a/K01VIVH0H61P079bLP1^KVh206a/K00?06QXJ01bLW80
LG5a079bLP1YJFT0J6QX07YjNP1WIfL0LG5a06i^KP1]KFd0MgMg06e]K@1cLg<0MWIf0080LW9b00D0
MgMg07]kN`1gMgL0MgMg07YjNP0207alO00507inOP1dM7@0QHF507]kN`21PH400P22PX801P1oOgl0
PX:207UiN@1nOWh0QXJ607inOP80PX:200`0PH6108F5Q@24Q8@0S8b<08V9R@2ATI40QHF508f=S@2<
S8`0UYJF09BDU02BTY8209RHV00T09ZJVP2GUiL0WIfM09^KV`2TY:@0VYZJ0:RXZ02TY:@0YjNW0:2P
X02VYZH0[Jf]0:j^[P2ZZZX0];Bd0;Vi^@2l_;`0_Kfm0;bl_030`<00`/;20;jn_P2o_kl0c<c<0=7A
d@3<c<`0f=SH0=cLg03Bd]80hN7Q0?3`l03UiND0k>c/0?Ogm`3jn_X0mOGeCP3oool06@3inOT0oOgm
0>c/k03Ng]h0jNWY0>;RhP3Kfm/0inOW0>?Sh`3Lg=`0a/K60<k>cP39bLT0`<300<[:bP2k^k/0_[jn
0;^k^`2i^KT0]kNg0;2`/02YZJT0[:b/0:n_[`2e]KD00P2PX:002`2XZ:P0Vi^K0:6QX@2NWYh0WinO
09fMW@2CTi<0WYjN09BDU02@T900QXJ60080SXj>00X0VYZJ08b<S02;Rh/0Shn?08J6QP22PX80RHV9
08F5Q@22PX80Ph>30P21PH406@1lO7`0OGem07emO@1iNGT0MGEe07AdM01gMgL0Ogmo07MgM`1iNGT0
O7al07AdM01ZJVX0MWIf07MgM`1aLG40NWYj071`L01fMWH0Lg=c06e]K@1gMgL0Jf][06e]K@1bLW80
0`1_Kfl08@1bLW80JVYZ07=cL`1^KVh0JVYZ06IVIP1/K6`0J6QX06i^KP1[Jf/0IFEU06QXJ01UIFD0
JFUY06YZJP1/K6`0IfMW06a/K01PH600JVYZ06QXJ01QHF40IVIV06=SH`1MGEd0GemO06MWI`1MGEd0
HF5Q05MGE`1OGel0H61P05]KF`060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3I
fMT03`1LG5`0Fe]K065QH@1OGel0IfMW06ATI01VIVH0JFUY069RHP1SHf<0JVYZ06=SH`1QHF40IFEU
065QH@0206EUI@0=06YZJP1WIfL0K6a/06m_K`1UIFD0J6QX06YZJP1/K6`0IVIV06][J`1XJ6P0IVIV
06m_K`0206ATI00I079bLP1/K6`0JVYZ079bLP1_Kfl0KFe]06UYJ@1dM7@0JVYZ071`L01cLg<0LW9b
06UYJ@1`L700MGEe07MgM`1nOWh0LG5a071`L01dM7@0Lg=c071`L01mOGd0NWYj07AdM00307YjNP0F
07]kN`21PH40Ph>307UiN@23Ph<0P82007alO020P800QXJ607emO@2:RXX0RHV908>3P`21PH40QhN7
08F5Q@26QXH0R8R808n?S`2@T900QhN709>CT`80TY:B0P2ATI404P2BTY80UIFE0::RXP2JVYX0WinO
0:BTY02LW9`0Y:BT0:NWY`2/[:`0YJFU0:NWY`2`/;00[jn_0;2`/02f][H0^[Zj0;Vi^@80]kNg0P30
`<003`32`/80c/k>0=CDe03Bd]80dM7A0=[JfP3Fe]H0fm_K0>GUi@3Ph>00kno_0??cl`3Zj^X0oooo
0?knoP1>0?ooo`0Z0?_kn`3`l?00moOg0>WYj@3[jn/0h>3P0>?Sh`3UiND0emOG0=7Ad@3=cLd0clo?
0<k>cP36a/H0`l?30;Zj^P2o_kl0/K6a0;Zj^P2e]KD0ZZZZ0:n_[`2YZJT0[:b/0:n_[`2WYjL0Z:RX
0:JVYP2SXj<0W9bL0:>SX`2OWil0UiNG09BDU02CTi<0V9RH08n?S`2DU9@0UIFE08n?S`2<S8`0RHV9
0P2<S8`04@28R8P0OWin08:2PP2:RXX0QXJ608>3P`28R8P0O7al07]kN`1oOgl0O7al07IfMP1nOWh0
P82007EeM@1bLW80MgMg0080NWYj00D0Kfm_07EeM@1^KVh0LW9b07QhN002075aL@0607IfMP1YJFT0
K6a/07AdM01bLW80IfMW0P1fMWH03`1dM7@0Jf][06i^KP1fMWH0LG5a06e]K@1ZJVX0IVIV06i^KP1S
Hf<0IVIV06MWI`1OGel0K6a/079bLP0206EUI@0506UYJ@1NGUh0IVIV06QXJ01SHf<00P1VIVH02`1Z
JVX0H61P05mOG`1YJFT0I6AT06QXJ01LG5`0Hf=S05mOG`1YJFT0GemO00H0fMWI0@0000010=WIf@00
5P3IfMT00`000000fMWI0=WIf@030=WIf@0Z069RHP1UIFD0GUiN06MWI`1TI6@0J6QX05mOG`1VIVH0
I6AT065QH@1WIfL0JFUY05mOG`1SHf<0JVYZ06EUI@1aLG40IfMW05iNGP1ZJVX0HF5Q06MWI`1UIFD0
J6QX06IVIP1ZJVX0KFe]06][J`1YJFT0JVYZ06=SH`1_Kfl0J6QX06UYJ@1XJ6P0Jf][06EUI@1YJFT0
KVi^071`L01_Kfl0Lg=c0P1eMGD02P1cLg<0J6QX07IfMP1ZJVX0KVi^07EeM@1kNg/0N7Qh06a/K01i
NGT2075aL@80OWin03l0P8200861P@1oOgl0NWYj07IfMP1jNWX0OGem0861P@1mOGd0PX:208J6QP22
PX80PH6108J6QP27QhL0Ogmo08V9R@27QhL0QHF508b<S026QXH0RHV908f=S@2:RXX0UYJF096AT@2B
TY80VIVI09^KV`2IVIT0W9bL09FEU@2LW9`0YZJV0:2PX02ZZZX0Xj>S0:^[Z`2][Jd0[Zj^0::RXP2_
[jl0[Zj^0;Rh^02k^k/0];Bd0;Rh^02f][H0b<S80;Vi^@2o_kl0c<c<0<_;b`3?cll0gmoO0=[JfP3Q
hN40i^KV0>7Qh@3Ti>@0k>c/0>_[j`3no_h0D@3oool01P3gmoL0kNg]0>k^kP3Zj^X0i^KV0>;RhP80
f][J0180a<C40=3@d03Bd]80clo?0<?3``31`L40_kno0<;2`P2h^;P0/;2`0;Bd]02`/;00/k>c0:j^
[P2[Zj/0YZJV0:ZZZP2SXj<20:6QX@0M09NGU`2MWId0V9RH09nOW`2ATI40VYZJ09:BTP2DU9@0V9RH
08j>SP2FUYH0TI6A08b<S02=SHd0SXj>08f=S@2;Rh/0QXJ608V9R@23Ph<0PH6108:2PP20P800NWYj
07alO01jNWX0NGUi07MgM`1hN7P00P1fMWH02`1kNg/0O7al07EeM@1jNWX0MgMg07YjNP1fMWH0KFe]
06m_K`1fMWH0K6a/0080LG5a00D0IVIV06e]K@1bLW80L71`07YjNP0206i^KP80JVYZ00<0Jf][06a/
K01SHf<00P1TI6@306UYJ@80IVIV00<0Jf][061PH01TI6@00P1WIfL0401QHF40Jf][06UYJ@1]KFd0
KVi^06EUI@1TI6@0JVYZ06i^KP1RHV80I6AT05ADE01NGUh0GEeM05]KF`1QHF460=WIf@4000000@3I
fMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT02@1RHV80Hf=S06MWI`1XJ6P0IFEU06QXJ01WIfL0
JFUY06IVIP0206=SH`1;06MWI`1VIVH0Jf][069RHP1VIVH0I6AT061PH01QHF40J6QX06YZJP1XJ6P0
JFUY06a/K01XJ6P0JVYZ06i^KP1[Jf/0KFe]06MWI`1^KVh0HF5Q06e]K@1YJFT0Hf=S06i^KP1[Jf/0
LW9b06IVIP1aLG40MgMg071`L01^KVh0KFe]071`L01aLG40Lg=c07IfMP1bLW80KVi^07UiN@1`L700
Ng]k07EeM@1jNWX0N7Qh08:2PP1nOWh0P82007]kN`1nOWh0Ph>30861P@1oOgl0Q8B408J6QP27QhL0
OWin07emO@21PH40Ph>308:2PP2;Rh/0Q8B408:2PP26QXH0QhN708F5Q@28R8P0U9BD09:BTP2<S8`0
UYJF09FEU@2IVIT0V9RH0080U9BD00D0UYJF09NGU`2LW9`0Zj^[0:>SX`030:JVYP0=0;2`/02ZZZX0
/;2`0:j^[P2`/;00/K6a0;Vi^@30`<00]kNg0<C4a02n_[h0`L710<W9b@020<o?c`0:0<71`@3Fe]H0
g]kN0=WIf@3Kfm/0h^;R0?Gem@3clo<0jNWY0?Cdm580oooo01<0m_Kf0>c/k03Xj>P0j^[Z0>CTi03L
g=`0hN7Q0<g=c@3GemL0d=3@0<O7a`38b<P0`l?30<30`02o_kl0/k>c0;fm_@2c/k<0^KVi0080];Bd
00d0/K6a0:VYZ@2ZZZX0Xj>S0:f][@2UYJD0XZ:R0:>SX`2JVYX0Ti>C09NGU`2KVi/0Ti>C0080TI6A
01@0SXj>09:BTP2DU9@0S8b<0820P027QhL0R8R808V9R@26QXH0QhN707moO`21PH40PX:207inOP1k
Ng/0Ogmo07EeM@23Ph<0MWIf07]kN`@0NGUi00L0L71`075aL@1kNg/0MgMg06i^KP1bLW80Lg=c0080
LW9b00X0Jf][07IfMP1cLg<0MGEe079bLP1hN7P0NWYj071`L01fMWH0JVYZ0P1XJ6P0101RHV80KFe]
06=SH`1/K6`206MWI`0<06IVIP1WIfL0Kfm_06QXJ01YJFT0GemO06m_K`1XJ6P0KFe]06][J`1WIfL0
I6AT0P1ZJVX206MWI`<0HV9R00D0H61P05MGE`1UIFD0H61P05mOG`060=WIf@4000000@3IfMT001H0
fMWI00<000000=WIf@3IfMT00`3IfMT02P1TI6@0IfMW065QH@1UIFD0HF5Q06EUI@1XJ6P0HF5Q06=S
H`1[Jf/206QXJ00B06UYJ@1VIVH0J6QX05eMG@1/K6`0I6AT06MWI`1]KFd0J6QX06a/K01WIfL0K6a/
06EUI@1ZJVX0Jf][06ATI01XJ6P0KVi^0P1YJFT02@1XJ6P0Lg=c06m_K`1bLW80KFe]06YZJP1[Jf/0
M7Ad06e]K@0206a/K00C06i^KP1/K6`0Lg=c075aL@1bLW80MWIf071`L01ZJVX0N7Qh07EeM@1bLW80
MWIf07AdM01jNWX0N7Qh08B4Q01nOWh0OGem08Z:RP020861P@0C0820P025QHD0OGem08F5Q@1oOgl0
RHV908>3P`24Q8@0R8R808N7Q`2:RXX0T92@08J6QP27QhL0RXZ:08J6QP2@T900Shn?09BDU00209JF
UP0@0:BTY02LW9`0VYZJ09bLW02CTi<0UIFE0:6QX@2OWil0YJFU0:f][@2WYjL0ZJVY0:RXZ02[Zj/0
[:b/0:ZZZP80^[Zj00`0]KFe0<71`@32`/80_Kfm0<71`@3:b/X0d=3@0<k>cP38b<P0emOG0=gMg@3N
g]h20>CTi0030>SXj03lo?`0n_[j0580oooo0P3moOd02@3clo<0i^KV0>WYj@3Vi^H0gMgM0=kNgP3J
f]X0gMgM0<g=c@020<O7a`0<0<?3``2n_[h0_;bl0;Ng]`2m_Kd0^k^k0:ZZZP2`/;00/[:b0:^[Z`2Y
ZJT0[jn_0P2SXj<0102LW9`0XZ:R09jNWP2JVYX209:BTP030:6QX@2JVYX0W9bL0080Ti>C00H0SHf=
09:BTP28R8P0SHf=08j>SP2:RXX208J6QP80QhN700H0QXJ607inOP20P800P82007]kN`1nOWh207]k
N`0M07QhN01gMgL0N7Qh07YjNP1gMgL0Lg=c07EeM@1^KVh0Ng]k07MgM`1dM7@0Kfm_06][J`1bLW80
MgMg075aL@1gMgL0KFe]07AdM01cLg<0K6a/07QhN01^KVh0I6AT06][J`1WIfL0KVi^06e]K@1/K6`0
0P1XJ6P04P1VIVH0Jf][06YZJP1QHF40JVYZ06EUI@1YJFT0J6QX06ATI01YJFT0IVIV06MWI`1YJFT0
IVIV06YZJP1WIfL0I6AT06EUI@80HV9R00D0H61P069RHP1MGEd0H61P05mOG`060=WIf@4000000@3I
fMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT03@1TI6@0HF5Q069RHP1VIVH0K6a/06UYJ@1TI6@0
JFUY06MWI`1XJ6P0EeMG05mOG`1LG5`00P1SHf<05`1TI6@0J6QX06EUI@1XJ6P0H61P06UYJ@1[Jf/0
KVi^071`L01YJFT0HV9R06i^KP1_Kfl0KFe]06UYJ@1ZJVX0KFe]06i^KP1YJFT0K6a/06YZJP1UIFD0
IfMW0080KVi^00H0LG5a06e]K@1aLG40MgMg06m_K`1cLg<2079bLP0307IfMP1kNg/0M7Ad0080Lg=c
01T0Ng]k07AdM01eMGD0MWIf07moO`1lO7`0Ogmo0820P01oOgl0O7al0820P01mOGd0PX:20861P@28
R8P0O7al0820P01lO7`0R8R808b<S023Ph<0Rh^;08f=S@2@T900Ph>30080T92@00`0TY:B09BDU02B
TY80V9RH09VIV@2FUYH0VIVI09RHV02LW9`0WinO0:JVYP2ZZZX20:>SX`0>0:FUY@2ZZZX0YjNW0:j^
[P2ZZZX0/;2`0:f][@2k^k/0][Jf0;Fe]@32`/80_Kfm0<O7a`33`l<20<S8b00:0=7Ad@3Hf=P0g=cL
0>CTi03IfMT0m?Cd0>c/k03^k^h0n_[j0?_kne@0oooo02H0l_;b0>g]k@3YjNT0hN7Q0=gMg@3Lg=`0
e=CD0=?Cd`3IfMT0bl_;0<W9b@36a/H0aLG50;jn_P38b<P0_kno0;6a/@2f][H0/K6a0;>c/`2/[:`0
Xj>S0:JVYP2TY:@0Xj>S0:6QX@2RXZ80WIfM09JFUP2GUiL0UIFE09VIV@2CTi<0S8b<08f=S@2HV9P0
Rh^;09:BTP80RXZ:00D0Ph>308^;R`29RHT0RHV908J6QP0208:2PP0_08>3P`25QHD0Ogmo07]kN`1l
O7`0Ogmo07]kN`1dM7@0MGEe07inOP1bLW80MGEe07MgM`1hN7P0Ogmo07QhN01eMGD0L71`07=cL`1[
Jf/0MGEe06a/K01]KFd0JFUY07EeM@1cLg<0L71`06a/K01_Kfl0K6a/06QXJ01ZJVX0JFUY06EUI@1W
IfL0KVi^06a/K01SHf<0K6a/06i^KP1YJFT0IfMW06EUI@1VIVH0Hf=S069RHP1XJ6P00P1/K6`00`1Z
JVX0JFUY065QH@0206EUI@0905mOG`1UIFD0GUiN06QXJ01PH600GemO06EUI@1QHF40HV9R00H0fMWI
0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@80IVIV00<0Hf=S069RHP1XJ6P00P1U
IFD02@1aLG40HF5Q06IVIP1OGel0Hf=S061PH01UIFD0I6AT06QXJ00206a/K00A071`L01UIFD0HF5Q
06IVIP1]KFd0JFUY075aL@1VIVH0Hf=S06ATI01XJ6P0LG5a06YZJP1_Kfl0KVi^06a/K01bLW800`1/
K6`02@1[Jf/0KVi^06][J`1`L700M7Ad06YZJP1cLg<0OGem07]kN`0207AdM00E079bLP1cLg<0NGUi
07EeM@1fMWH0NGUi07IfMP1jNWX0O7al07emO@21PH40Ogmo08F5Q@21PH40NWYj07emO@1iNGT0PH61
08Z:RP22PX80RXZ:0080Ph>300@0QhN708V9R@2=SHd0T92@0P2:RXX03@27QhL0SHf=09JFUP2@T900
UiNG09>CT`2GUiL0UIFE096AT@2LW9`0Y:BT09^KV`2MWId00P2QXJ420:b/[080Z:RX01L0/K6a0:^[
Z`2a/K40/k>c0;Fe]@2m_Kd0];Bd0;no_`36a/H0`L710<G5a@3;bl/0cLg=0=OGe`3Lg=`0g]kN0=cL
g03UiND0jNWY0>?Sh`3Zj^X0m?Cd0?Shn01B0?ooo`0<0?gmo@3lo?`0inOW0?KfmP3Shn<0k>c/0>GU
i@3Rh^80fMWI0=[JfP3De=@0c/k>0P32`/808P2n_[h0a<C40<;2`P2k^k/0^KVi0;Ng]`2c/k<0[jn_
0:FUY@2_[jl0YjNW0:6QX@2WYjL0XZ:R0:6QX@2KVi/0WinO09ZJVP2GUiL0V9RH09>CT`2HV9P0Vi^K
08j>SP2DU9@0Ti>C08Z:RP2=SHd0RXZ:08N7Q`2<S8`0PX:208B4Q027QhL207moO`0407]kN`2:RXX0
NGUi07emO@80MGEe00l0O7al075aL@1jNWX0N7Qh07UiN@1fMWH0NGUi07inOP1fMWH0Ng]k075aL@1b
LW80MgMg06a/K01`L7000P1/K6`01`1cLg<0LG5a06m_K`1WIfL0Jf][06m_K`1YJFT00P1^KVh07P1X
J6P0IfMW06e]K@1TI6@0LW9b06a/K01SHf<0K6a/06m_K`1VIVH0IFEU06ATI01RHV80Jf][069RHP1[
Jf/0I6AT069RHP1YJFT0J6QX06e]K@1TI6@0HF5Q06e]K@1LG5`0Hf=S05iNGP1RHV80GemO05]KF`H0
fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@05065QH@1OGel0IfMW06ATI01U
IFD00P1WIfL0201SHf<0GemO06ATI01RHV80IfMW06EUI@1SHf<0JVYZ0P1VIVH0301WIfL0IVIV06UY
J@1RHV80IVIV06EUI@1XJ6P0JVYZ06EUI@1YJFT0K6a/06IVIP80K6a/00@0KVi^06MWI`1WIfL0LW9b
0`1^KVh306m_K`0J075aL@1bLW80Kfm_079bLP1eMGD0LG5a06m_K`1iNGT0Kfm_07]kN`1dM7@0LW9b
071`L01iNGT0N7Qh07EeM@1kNg/0OWin07alO01mOGd0N7Qh08>3P`1iNGT0QHF507emO@1jNWX20820
P00A0861P@22PX80QhN708b<S01nOWh0RXZ:09>CT`22PX80SXj>08f=S@2CTi<0T92@096AT@2DU9@0
TY:B08n?S`2FUYH00P2HV9P0802KVi/0WIfM0:BTY02VYZH0WYjN0::RXP2XZ:P0XJ6Q0:n_[`2WYjL0
[Jf]0;Bd]02f][H0]KFe0;jn_P2o_kl0^KVi0;no_`33`l<0bl_;0<g=c@3;bl/0fMWI0=3@d03IfMT0
lO7a0>SXj03Ti>@0lo?c0?Win@3gmoL0o_knD`3oool03`3moOd0lo?c0>_[j`3WinL0kno_0>k^kP3K
fm/0gMgM0=_Kf`3:b/X0d=3@0=GEe@38b<P0bl_;0;no_`020<71`@0D0;Vi^@2h^;P0][Jf0;Fe]@2Z
ZZX0YjNW0:VYZ@2XZ:P0WIfM0:6QX@2NWYh0WinO0:2PX02HV9P0VYZJ09NGU`2CTi<0UiNG08f=S@2C
Ti<208^;R`0708f=S@29RHT0RHV908:2PP2;Rh/0R8R80820P00207inOP0Y07moO`1lO7`0O7al07=c
L`1lO7`0P8200861P@1hN7P0OWin07EeM@1nOWh0MGEe07alO01aLG40NWYj06i^KP1aLG40MGEe07al
O01dM7@0N7Qh071`L01]KFd0MGEe06i^KP1aLG40Lg=c06QXJ01VIVH0KFe]06UYJ@1]KFd0Jf][06a/
K01UIFD0IVIV06=SH`1[Jf/0L71`06QXJ01_Kfl00P1XJ6P0501TI6@0HV9R06MWI`1UIFD0I6AT05aL
G01/K6`0JFUY06EUI@1RHV80H61P065QH@1VIVH0H61P065QH@1UIFD0H61P06IVIP1[Jf/0GUiN1P3I
fMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00@0Hf=S05mOG`1TI6@0I6AT0P1U
IFD01P1VIVH0IfMW06MWI`1QHF40JVYZ05mOG`80I6AT01L0IfMW05]KF`1]KFd0K6a/061PH01/K6`0
JVYZ06][J`1/K6`0JVYZ06MWI`1^KVh0J6QX06EUI@1VIVH0KFe]06QXJ01[Jf/0IVIV06m_K`1[Jf/0
JFUY06QXJ00206e]K@0A07AdM01aLG40L71`06m_K`1eMGD0NGUi07IfMP1bLW80MgMg07EeM@1bLW80
NWYj07inOP1eMGD0NGUi07EeM@1fMWH00P1dM7@0401lO7`0OGem08:2PP21PH40Ogmo07alO024Q8@0
RXZ:0861P@23Ph<0PH61092@T027QhL0QHF508R8R020P80308V9R@0;08J6QP2ATI40QhN708Z:RP28
R8P0RXZ:09FEU@2GUiL0WinO09JFUP2DU9@00P2LW9`07@2JVYX0YjNW0;2`/02RXZ80ZZZZ0:NWY`2a
/K40][Jf0;>c/`2e]KD0/;2`0;Rh^02j^[X0`<300<G5a@38b<P0a/K60<_;b`3=cLd0f=SH0=?Cd`3F
e]H0hN7Q0=oOg`3Ti>@0l_;b0?Ogm`3^k^h0moOg05D0oooo00@0m?Cd0>[ZjP3^k^h0k>c/0P3Ng]h0
6`3GemL0gMgM0=;BdP3<c<`0alO70;bl_03=cLd0^k^k0;bl_02i^KT0`l?30;Fe]@2h^;P0YjNW0:n_
[`2/[:`0Zj^[0:VYZ@2RXZ80YZJV0:BTY02YZJT0WYjN09nOW`2IVIT0VYZJ09bLW00208j>SP0408b<
S02CTi<0SHf=09FEU@<0Rh^;00P0QXJ608N7Q`1oOgl0QXJ608:2PP1oOgl0OWin07YjNP80O7al00H0
Ng]k07inOP1jNWX0P82007IfMP1nOWh207=cL`0:07EeM@1fMWH0MgMg071`L01gMgL0NGUi079bLP1Y
JFT0Kfm_07YjNP80KVi^00L0KFe]06UYJ@1aLG40MWIf079bLP1`L700LG5a0080K6a/01@0J6QX06AT
I01/K6`0IVIV06EUI@1TI6@0JFUY06QXJ01[Jf/0HV9R06UYJ@1TI6@0IFEU06ATI01YJFT0Hf=S06QX
J01QHF40J6QX06][J`80GUiN00L0G5aL065QH@1OGel0J6QX06=SH`1MGEd0HF5Q00H0fMWI0@000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@80Hf=S01X0H61P06=SH`1XJ6P0IfMW06IVIP1S
Hf<0I6AT06EUI@1SHf<0HF5Q05mOG`1RHV80JFUY06EUI@1[Jf/0IfMW06UYJ@1UIFD0Jf][06ATI01W
IfL0IFEU06IVIP1YJFT0JVYZ06i^KP80JVYZ00D0I6AT06i^KP1VIVH0KFe]071`L00206e]K@0C06][
J`1aLG40JFUY06m_K`1cLg<0MGEe06m_K`1iNGT0N7Qh07AdM01[Jf/0Ogmo07YjNP1hN7P0OGem07Ee
M@1iNGT0N7Qh07alO00207emO@0@07alO01kNg/0Ogmo07IfMP1jNWX0NGUi08R8R01hN7P0QhN708Z:
RP2=SHd0R8R808V9R@2?Shl0QhN708b<S080Q8B400X0Rh^;08J6QP2<S8`0Shn?09JFUP2?Shl0TY:B
09BDU02ATI40Ti>C0P2HV9P03@2OWil0Xj>S09nOW`2UYJD0Y:BT0:ZZZP2/[:`0YZJV0;:b/P2WYjL0
^;Rh0;Bd]02b/[800P2h^;P04@2l_;`0`/;20<K6aP38b<P0d=3@0<g=c@3IfMT0f][J0>CTi03Hf=P0
hn?S0>GUi@3^k^h0j^[Z0?Gem@3gmoL0oOgm05<0oooo01/0no_k0?Gem@3gmoL0kNg]0>c/k03]kNd0
fm_K0=KFeP3Jf]X0fMWI0<G5a@3?cll0c/k>0<;2`P37alL0_;bl0;Vi^@2l_;`0^;Rh0;:b/P2`/;00
[Jf]0;2`/02UYJD0[:b/0:>SX`2QXJ400P2TY:@0302HV9P0W9bL09>CT`2GUiL0U9BD092@T02CTi<0
UYJF09RHV02DU9@0Shn?08b<S080QXJ600h0Q8B408R8R029RHT0OGem08V9R@1oOgl0O7al07emO@1l
O7`0P82007QhN01mOGd0M7Ad07MgM`80OGem0180NWYj07UiN@1eMGD0N7Qh07alO01nOWh0P820075a
L@1bLW80K6a/06i^KP1`L700K6a/07=cL`1/K6`0JFUY07EeM@1]KFd206YZJP0406m_K`1/K6`0I6AT
06UYJ@<0J6QX01T0GUiN06EUI@1[Jf/0Jf][06IVIP1XJ6P0IFEU06IVIP1PH600GemO06ATI01VIVH0
HV9R06ATI01LG5`0HV9R06MWI`1TI6@0IFEU05]KF`1IFET0H61P06EUI@1OGel0HV9R00H0fMWI0@00
00010=WIf@005P3IfMT2000000@0fMWI00T0IVIV06QXJ01TI6@0JFUY06MWI`1RHV80HF5Q06YZJP1W
IfL00P1RHV80<01QHF40IVIV05eMG@1UIFD0H61P06e]K@1[Jf/0IfMW06IVIP1[Jf/0HF5Q06QXJ01S
Hf<0I6AT06EUI@1VIVH0IfMW071`L01WIfL0Jf][069RHP1cLg<0L71`06YZJP1YJFT0Jf][06a/K01Y
JFT0K6a/06m_K`1ZJVX0K6a/07EeM@1dM7@0NGUi079bLP1eMGD0KFe]06m_K`1bLW80OWin07]kN`1l
O7`0MgMg08>3P`1hN7P0PH6107alO080Ng]k01D0N7Qh07]kN`1lO7`0NWYj07inOP24Q8@0RHV907mo
O`2>SXh0QXJ608N7Q`2<S8`0PH6108b<S028R8P0QXJ6096AT@2;Rh/0SHf=08^;R`2BTY800P2JVYX0
6P2DU9@0UIFE09jNWP2JVYX0Vi^K0:>SX`2VYZH0Zj^[0:RXZ02/[:`0Z:RX0:b/[02[Zj/0Z:RX0;:b
/P2c/k<0/[:b0;>c/`32`/80_[jn0<?3``34a<@0`L710<W9b@3?cll0c/k>0P3Cdm<01@3Ng]h0k^k^
0>o_k`3`l?00m?Cd05L0oooo0P3kno/0203/k>`0jNWY0>g]k@3UiND0gMgM0=cLg03AdM40d];B0P36
a/H02`34a<@0`/;20;jn_P2n_[h0_;bl0:f][@2g]kL0[:b/0:ZZZP2TY:@0[Jf]0080Y:BT00P0X:2P
0:>SX`2KVi/0W9bL0::RXP2EUID0VYZJ09FEU@80TI6A00H0TY:B096AT@29RHT0T92@08^;R`2<S8`2
08B4Q00908R8R02=SHd0Ogmo08V9R@23Ph<0O7al08B4Q020P800OGem0080NGUi00@0O7al07moO`1l
O7`0Ng]k0P1fMWH06@1hN7P0OWin07QhN01dM7@0NWYj071`L01cLg<0JVYZ075aL@1_Kfl0LW9b075a
L@1`L700LG5a06a/K01cLg<0L71`075aL@1YJFT0KFe]06i^KP1_Kfl0J6QX06][J`1RHV800P1]KFd0
101ZJVX0IfMW06IVIP1ZJVX206MWI`0A06ATI01UIFD0J6QX06EUI@1PH600Jf][065QH@1XJ6P0IFEU
05eMG@1PH600J6QX05mOG`1RHV80H61P05eMG@1GEeL01@3IfMT200000040fMWI000F0=WIf@030000
003IfMT0fMWI00<0fMWI0P1VIVH0;@1]KFd0IVIV05iNGP1UIFD0G5aL06MWI`1UIFD0IfMW069RHP1T
I6@0J6QX06=SH`1RHV80JFUY06IVIP1WIfL0JFUY06YZJP1WIfL0IFEU06QXJ01WIfL0KFe]06EUI@1[
Jf/0JVYZ06i^KP1RHV80KVi^06IVIP1`L700Kfm_06QXJ01_Kfl0Lg=c071`L01[Jf/0Kfm_06YZJP1k
Ng/0Kfm_07MgM`1]KFd0MgMg07AdM00207=cL`0>07QhN01cLg<0NWYj07moO`1gMgL0N7Qh07MgM`1o
Ogl0Ng]k07YjNP1kNg/0O7al07UiN@1nOWh20820P00307]kN`22PX80Q8B400<0RXZ:01L0RHV907in
OP28R8P0UIFE08J6QP2:RXX0SHf=08^;R`2ATI40T92@09BDU02GUiL0UYJF09VIV@2LW9`0UiNG09fM
W@2NWYh0VYZJ0:>SX`2WYjL0[Zj^0:RXZ0020:ZZZP080;>c/`2/[:`0[Zj^0;6a/@2_[jl0]kNg0;fm
_@31`L420<G5a@080<W9b@3De=@0d=3@0=WIf@3Fe]H0fm_K0>GUi@3Rh^820?Ogm`030?Gem@3hn?P0
no_k05@0oooo0100n?Sh0?ooo`3[jn/0l?3`0>SXj03Vi^H0hN7Q0=gMg@3Fe]H0emOG0=CDe03>c/h0
aLG50<?3``2o_kl0`<300P2n_[h0502b/[80[Jf]0:n_[`2f][H0YZJV09bLW02][Jd0ZZZZ0:6QX@2O
Wil0Z:RX0:2PX02EUID0Vi^K09>CT`2EUID0TI6A092@T02?Shl0U9BD0P2>SXh08`2;Rh/0R8R808N7
Q`2=SHd0PX:208Z:RP25QHD0Ph>308B4Q01kNg/0Ph>307IfMP25QHD0Lg=c07UiN@20P800Ng]k07Yj
NP1dM7@0O7al07AdM01fMWH0LW9b07IfMP1lO7`0NGUi07IfMP1dM7@0Jf][07=cL`1dM7@0LW9b06a/
K01XJ6P0LG5a0080JFUY0180MGEe06e]K@1WIfL0J6QX06a/K01]KFd0IFEU05iNGP1XJ6P0IVIV06i^
KP1XJ6P0Hf=S06MWI`1ZJVX0K6a/06ATI01PH60206IVIP0>06i^KP1PH600I6AT06ATI01XJ6P0I6AT
065QH@1SHf<0HF5Q061PH01OGel0IfMW065QH@1SHf<60=WIf@4000000@3IfMT001H0fMWI00<00000
0=WIf@3IfMT00`3IfMT02@1SHf<0F5QH06EUI@1XJ6P0GUiN069RHP1ZJVX0I6AT061PH00206ATI00T
06YZJP1WIfL0Hf=S061PH01[Jf/0Fe]K06a/K01VIVH0IfMW06ATI01UIFD0HV9R065QH@1WIfL0KFe]
06EUI@1/K6`0JFUY06YZJP1WIfL0J6QX06a/K01[Jf/0K6a/06e]K@1^KVh0KFe]06a/K01aLG40KVi^
06YZJP1bLW80K6a/07AdM01]KFd0M7Ad0P1fMWH0101jNWX0Lg=c07EeM@1cLg<207YjNP80O7al00<0
Ng]k08F5Q@1hN7P00`1jNWX01020P800PH6107QhN026QXH208B4Q00<08F5Q@2:RXX0RXZ:08F5Q@2@
T900Ogmo08n?S`2>SXh0RXZ:09:BTP2CTi<0Shn?0P2BTY80602GUiL0UIFE09BDU02HV9P0WinO09bL
W02PX:00YZJV0:ZZZP2[Zj/0XZ:R0:NWY`2^[Zh0ZZZZ0;:b/P2^[Zh0^KVi0;6a/@2k^k/0^[Zj0;bl
_033`l<0_Kfm0<c<c080clo?00P0c<c<0=[JfP3Lg=`0g]kN0>g]k@3dm?@0no_k0?OgmeL0oooo00`0
n_[j0?ooo`3`l?00k>c/0?;blP3Ogml0g]kN0>3Ph03Cdm<0d];B0=KFeP2n_[h20<;2`P0^0;bl_02g
]kL0^[Zj0;Zj^P2i^KT0[jn_0;Fe]@2c/k<0YjNW0:VYZ@2WYjL0XJ6Q0:2PX02LW9`0WYjN09nOW`2I
VIT0UiNG09RHV02OWil0TI6A08j>SP28R8P0QXJ608N7Q`2;Rh/0RHV908b<S02>SXh0Rh^;0861P@2;
Rh/0QhN708R8R01oOgl0Ng]k07YjNP21PH40O7al07UiN@1cLg<0Ph>307IfMP1gMgL0OWin0820P080
MGEe00T0O7al06e]K@1aLG40Lg=c07AdM01ZJVX0Jf][07EeM@1[Jf/00P1fMWH08@1[Jf/0LG5a07Ad
M01UIFD0HF5Q06i^KP1ZJVX0KFe]06UYJ@1/K6`0GemO06MWI`1^KVh0Hf=S06MWI`1TI6@0J6QX05mO
G`1XJ6P0IfMW06QXJ01SHf<0HV9R061PH01UIFD0H61P05mOG`1LG5`0H61P06a/K01WIfL0IFEU065Q
H@0205mOG`03069RHP1OGel0fMWI00D0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@03
0=WIf@80HV9R01`0Hf=S069RHP1OGel0GEeM06ATI01RHV80JVYZ069RHP1TI6@0IVIV05mOG`1WIfL0
IVIV06ATI01VIVH0Hf=S06e]K@1ZJVX0Jf][06ATI01SHf<0IfMW06ATI01`L700I6AT06IVIP1ZJVX0
Kfm_0P1[Jf/0:01/K6`0Jf][06a/K01ZJVX0Jf][071`L01]KFd0Kfm_06e]K@1dM7@0N7Qh07AdM01]
KFd0Jf][07UiN@1cLg<0MGEe07IfMP1cLg<0NGUi07inOP1fMWH0MgMg0820P023Ph<0Ng]k07QhN01k
Ng/0OGem08B4Q021PH40OWin08>3P`1nOWh0Q8B408R8R01gMgL0Ogmo08B4Q022PX8208V9R@0Q09:B
TP2>SXh0T92@08R8R02@T900U9BD09JFUP2@T900TY:B09VIV@2BTY80VYZJ09bLW02HV9P0WYjN09bL
W02NWYh0XZ:R0:ZZZP2SXj<0[Zj^0:^[Z`2XZ:P0[:b/0:VYZ@2c/k<0_Kfm0;bl_02n_[h0a/K60<S8
b03:b/X0a<C40080bl_;00<0dm?C0=;BdP3Kfm/00P3Zj^X00`3_knl0k>c/0??cl`1H0?ooo`0N0?Cd
m03no_h0jNWY0>WYj@3Xj>P0g=cL0=oOg`3EeMD0bl_;0=;BdP37alL0_[jn0<71`@36a/H0_Kfm0;Zj
^P2a/K40/;2`0;:b/P2][Jd0ZZZZ0:BTY02`/;00ZZZZ0::RXP2UYJD0W9bL09JFUP2CTi<0UYJF0P2I
VIT04P29RHT0Ti>C08f=S@2=SHd0TY:B096AT@29RHT0Rh^;0861P@2BTY80RXZ:08N7Q`1oOgl0P820
07moO`1lO7`0NGUi08:2PP80Ogmo01T0P82007moO`22PX80Lg=c07alO01hN7P0OWin07IfMP1kNg/0
MGEe06i^KP1gMgL0MWIf07QhN01aLG40L71`06m_K`1bLW80Lg=c06i^KP1VIVH0JFUY06a/K01YJFT0
M7Ad0080KVi^00D0Jf][06UYJ@1UIFD0JFUY06=SH`0206MWI`0G06UYJ@1QHF40H61P06EUI@1SHf<0
KFe]06IVIP1XJ6P0JVYZ06ATI01NGUh0Hf=S06IVIP1XJ6P0IfMW06EUI@1XJ6P0IfMW06EUI@1SHf<0
IVIV061PH01NGUh01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI03d0Hf=S
06EUI@1SHf<0HF5Q05]KF`1WIfL0I6AT06YZJP1QHF40GEeM061PH01RHV80IVIV06ATI01YJFT0IVIV
079bLP1WIfL0IFEU06MWI`1VIVH0JFUY06QXJ01TI6@0L71`06MWI`1VIVH0LG5a06e]K@1`L700Jf][
06UYJ@1[Jf/0JVYZ06a/K01]KFd0MWIf06m_K`1aLG40KVi^07=cL`1aLG40L71`06YZJP1WIfL0LG5a
06m_K`1eMGD0KVi^075aL@1kNg/0OWin07]kN`1mOGd0PH6107]kN`20P800OGem07inOP1oOgl0Ph>3
0080QHF500`0Ph>308:2PP21PH40PH6108>3P`1nOWh0QhN708J6QP22PX80Q8B408j>SP29RHT208j>
SP0E096AT@28R8P0RXZ:08b<S02ATI40U9BD08^;R`2ATI40T92@0:BTY02MWId0XZ:R09^KV`2VYZH0
XZ:R0:JVYP2XZ:P0ZJVY0:^[Z`2^[Zh0Z:RX0080/k>c0180[jn_0<71`@31`L40`l?30<O7a`3Cdm<0
b/[:0<S8b03EeMD0e=CD0=gMg@3GemL0h^;R0?3`l03Zj^X0lo?c0?[jnP3no_iG0?ooo`1?0?Cdm03c
lo<0i>CT0?Cdm03Ph>00i>CT0=OGe`3EeMD0dM7A0<K6aP3:b/X0`l?30;fm_@2l_;`0_kno0;Rh^02d
];@0/[:b0;Fe]@2a/K40[jn_0;6a/@2YZJT0YZJV0:BTY02QXJ40VYZJ09nOW`2GUiL0W9bL09RHV02M
WId0TY:B09JFUP2?Shl0Rh^;08f=S@21PH40Ti>C092@T026QXH0RHV908f=S@28R8P0QXJ60861P@26
QXH0QHF507inOP22PX80Ph>307emO@1kNg/0P82007IfMP1oOgl0NGUi07IfMP1bLW80O7al07MgM`1c
Lg<0M7Ad07]kN`1bLW80LG5a079bLP1aLG40L71`06a/K01^KVh0K6a/06e]K@1YJFT0Jf][075aL@1/
K6`0HF5Q06e]K@0206UYJ@0:06QXJ01TI6@0K6a/06UYJ@1^KVh0KFe]05mOG`1TI6@0K6a/069RHP<0
Hf=S00/0Fe]K05eMG@1WIfL0IVIV06EUI@1QHF40JFUY06][J`1NGUh0G5aL06EUI@02065QH@0305YJ
FP1UIFD0fMWI00D0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0V06UYJ@1U
IFD0H61P06IVIP1YJFT0IfMW06ATI01XJ6P0GEeM06=SH`1PH600JVYZ06QXJ01QHF40I6AT06=SH`1Z
JVX0IVIV079bLP1XJ6P0H61P07]kN`1ZJVX0Hf=S06a/K01^KVh0Jf][06m_K`1`L700JFUY06IVIP1^
KVh0KFe]06a/K01YJFT0L71`06YZJP1aLG4206e]K@0307AdM01cLg<0MGEe0080KFe]00l0Lg=c06e]
K@1kNg/0KVi^075aL@1dM7@0MgMg07YjNP1kNg/0Lg=c07emO@1eMGD0OWin07AdM01iNGT00P1oOgl0
9@22PX80OGem0861P@21PH40R8R808F5Q@22PX80Rh^;08J6QP25QHD0PX:208N7Q`29RHT0QXJ608^;
R`28R8P0Ti>C09FEU@2?Shl0VIVI09BDU02IVIT0UiNG09VIV@2JVYX0W9bL0:6QX@2RXZ80XJ6Q0:NW
Y`2VYZH0Zj^[0;6a/@2][Jd0[:b/0;6a/@2][Jd00P2g]kL20;bl_00>0<K6aP39bLT0a/K60<o?c`3J
f]X0dM7A0=OGe`3Rh^80fm_K0>7Qh@3alO40k>c/0?clo03inOUG0?ooo`0;0?;blP3kno/0m_Kf0>OW
i`3Vi^H0inOW0=gMg@3Hf=P0clo?0<O7a`3De=@00P36a/H01034a<@0`/;20;Rh^02l_;`20;Fe]@09
0:VYZ@2ZZZX0YZJV0:^[Z`2_[jl0YZJV0:BTY02QXJ40WIfM0080X:2P00T0U9BD09FEU@2FUYH0U9BD
09FEU@2?Shl0TY:B08^;R`28R8P00P29RHT03@2>SXh0Q8B408V9R@27QhL0PH6108F5Q@1mOGd0RHV9
07moO`1nOWh0P82007MgM`1kNg/00P1fMWH00`1kNg/0N7Qh07inOP0207YjNP0507=cL`1iNGT0OGem
07moO`1fMWH00P1dM7@0401_Kfl0M7Ad06m_K`1/K6`0KVi^06e]K@1/K6`0M7Ad06a/K01XJ6P0JFUY
06YZJP1^KVh0K6a/06QXJ01UIFD206MWI`0:065QH@1[Jf/0IFEU06EUI@1PH600IfMW06IVIP1YJFT0
IVIV06UYJ@80HF5Q00`0IVIV05EEE@1ZJVX0FEUI05]KF`1NGUh0IFEU05aLG01QHF40GEeM065QH@1L
G5`60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT02P1WIfL0HV9R069RHP1[
Jf/0JVYZ069RHP1YJFT0IFEU06IVIP1RHV8206UYJ@0406EUI@1XJ6P0IFEU06a/K080IfMW0P1/K6`0
1@1`L700Jf][079bLP1`L700J6QX0080JVYZ00`0L71`06YZJP1XJ6P0IVIV06a/K01ZJVX0Lg=c06m_
K`1cLg<0MgMg07AdM01_Kfl2071`L00706i^KP1aLG40NGUi06i^KP1_Kfl0Lg=c07AdM00207IfMP04
07=cL`1hN7P0M7Ad07MgM`80MGEe02X0NWYj0820P01iNGT0O7al07moO`1mOGd0O7al08F5Q@1oOgl0
QHF508B4Q020P800PH6108N7Q`21PH40QHF508J6QP2<S8`0QXJ608n?S`24Q8@0R8R808f=S@27QhL0
UIFE09ZJVP2EUID0W9bL09BDU02BTY80WYjN09JFUP2RXZ80Xj>S0:BTY02LW9`0Z:RX0:b/[02^[Zh0
];Bd0:j^[P2b/[820:n_[`0B0;2`/02d];@0_kno0<;2`P3:b/X0`<300<k>cP3<c<`0d=3@0=OGe`3Q
hN40h>3P0>[ZjP3clo<0k^k^0?gmo@3hn?P0o?clE`3oool01`3no_h0k^k^0>k^kP3`l?00iNGU0=oO
g`3Jf]X00P3EeMD20<c<c0040<;2`P38b<P0`<300;^k^`80^[Zj00X0^k^k0;Rh^02c/k<0[:b/0:VY
Z@2VYZH0YJFU0:BTY02YZJT0XJ6Q0P2LW9`03@2JVYX0WIfM09NGU`2IVIT0UIFE08n?S`2IVIT0S8b<
09FEU@2<S8`0TI6A08N7Q`29RHT00P2;Rh/05`27QhL0RXZ:08F5Q@22PX80Q8B40861P@20P800MGEe
07]kN`1oOgl0N7Qh07emO@1kNg/0NGUi07=cL`1fMWH0OGem07]kN`1bLW80MGEe07AdM01bLW80MGEe
0080Kfm_00L0LG5a06a/K01cLg<0L71`06m_K`1^KVh0Kfm_00<0KVi^00`0L71`06IVIP1[Jf/0K6a/
06=SH`1XJ6P0I6AT06UYJ@1XJ6P0K6a/069RHP1ZJVX206EUI@0=06YZJP1TI6@0Hf=S06=SH`1WIfL0
H61P06EUI@1TI6@0JVYZ06e]K@1PH600HV9R05aLG00206ATI003061PH03IfMT0fMWI00@0fMWI0@00
00010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0:06ATI01WIfL0H61P05mOG`1QHF40I6AT
06][J`1XJ6P0I6AT06EUI@80Hf=S01`0H61P05mOG`1PH600IVIV06YZJP1UIFD0I6AT06MWI`1ZJVX0
KVi^06YZJP1]KFd0JFUY071`L01cLg<0IfMW06YZJP1]KFd0Hf=S06e]K@1^KVh0LW9b06i^KP1dM7@0
LW9b07EeM@1iNGT0N7Qh0P1]KFd02P1[Jf/0Lg=c06i^KP1ZJVX0M7Ad07EeM@1`L700MGEe07=cL`1g
MgL207inOP0>07EeM@1fMWH0OWin07alO01fMWH0P82007inOP1mOGd0P82007inOP22PX80O7al08:2
PP1oOgl208N7Q`0C08F5Q@2>SXh0RXZ:08R8R02>SXh0TY:B08V9R@2?Shl0TY:B09RHV02<S8`0TI6A
09FEU@2KVi/0VYZJ09nOW`2HV9P0WYjN09nOW`030::RXP060:6QX@2YZJT0/[:b0;6a/@2][Jd0/K6a
0`2d];@03P2h^;P0a<C40;no_`3<c<`0c/k>0<G5a@3<c<`0e=CD0=SHf03Rh^80hn?S0>OWi`3alO40
k>c/0P3inOUI0?ooo`050?gmo@3Shn<0k>c/0=oOg`3IfMT00P3Hf=P05P3Fe]H0c<c<0<71`@38b<P0
a<C40<;2`P31`L40^KVi0;Bd]02f][H0/k>c0:NWY`2^[Zh0Xj>S0:RXZ02SXj<0WYjN0:6QX@2RXZ80
WYjN0:2PX02TY:@209FEU@0Z08n?S`2<S8`0Shn?092@T02;Rh/0R8R808F5Q@27QhL0RXZ:08:2PP23
Ph<0QXJ608R8R020P800PX:208>3P`22PX80RHV907emO@1kNg/0OGem07MgM`1iNGT0MgMg07alO01j
NWX0NGUi07MgM`1lO7`0KVi^07IfMP1hN7P0Lg=c07]kN`1dM7@0Kfm_07=cL`1/K6`0KFe]07=cL`1`
L700KVi^0P1/K6`306YZJP08075aL@1]KFd0IVIV06ATI01[Jf/0J6QX06MWI`1^KVh206ATI00=06MW
I`1_Kfl0KFe]06MWI`1UIFD0IfMW06][J`1XJ6P0H61P06QXJ01PH600J6QX06=SH`0206EUI@05069R
HP1UIFD0I6AT06ATI01RHV801P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI
00P0IFEU06ATI01NGUh0GemO06EUI@1YJFT0HF5Q05eMG@80JFUY00L0I6AT06UYJ@1XJ6P0J6QX06YZ
JP1TI6@0LG5a0080Jf][0100JFUY06e]K@1]KFd0J6QX07=cL`1_Kfl0JVYZ06][J`1/K6`0J6QX06YZ
JP1`L700Kfm_07AdM01_Kfl0L71`0`1gMgL01`1/K6`0M7Ad06UYJ@1`L700K6a/071`L01^KVh00P1`
L700101aLG40Kfm_06e]K@1]KFd207YjNP06079bLP1lO7`0OGem07emO@1kNg/0OGem0P1lO7`0901m
OGd0PH6108>3P`21PH40P82007moO`29RHT0Ph>308:2PP24Q8@0PH6108V9R@26QXH0RXZ:08b<S027
QhL0UIFE08b<S02:RXX0UYJF09NGU`2FUYH0Vi^K09VIV@2FUYH0XJ6Q09bLW02KVi/0Y:BT0:2PX02X
Z:P0Y:BT0:NWY`2`/;00[Zj^0:f][@80/k>c0180]KFe0<C4a02n_[h0`l?30<30`035aLD0c/k>0<O7
a`33`l<0d=3@0=?Cd`3Ng]h0i>CT0>GUi@3YjNT0l_;b0?Gem@3jn_YG0?ooo`090?gmo@3hn?P0nOWi
0?7al@3QhN40i>CT0=kNgP3UiND0clo?0080e=CD0100cLg=0<c<c03:b/X0`<300<S8b02o_kl0^[Zj
0;no_`2`/;00ZZZZ0:JVYP2][Jd0XZ:R0:JVYP2RXZ80Vi^K0`2RXZ803P2DU9@0VYZJ09NGU`2ATI40
UIFE09>CT`2<S8`0UIFE09NGU`2<S8`0RHV909BDU02;Rh/0RXZ:0P2=SHd02P26QXH0P82007inOP1o
Ogl0P8200861P@1gMgL0Ng]k0861P@1gMgL207EeM@0>071`L01kNg/0N7Qh07alO01eMGD0KVi^07Ad
M01cLg<0KFe]07EeM@1]KFd0Jf][06a/K01YJFT206a/K00T06IVIP1[Jf/0KFe]06QXJ01/K6`0KVi^
06YZJP1XJ6P0JFUY07AdM01/K6`0Hf=S06MWI`1]KFd0K6a/06EUI@1_Kfl0LG5a06m_K`1XJ6P0JVYZ
06MWI`1ZJVX0J6QX06EUI@1XJ6P0GemO06QXJ01WIfL0HV9R061PH01MGEd0H61P06ATI01NGUh0I6AT
1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI01h0Hf=S06QXJ01YJFT0H61P
069RHP1^KVh0IFEU06=SH`1RHV80GemO06=SH`1YJFT0Hf=S06MWI`1XJ6P0Hf=S06MWI`1`L700K6a/
06YZJP1`L700KVi^06m_K`1/K6`0Kfm_06YZJP1cLg<0Jf][071`L01eMGD206][J`0:06YZJP1[Jf/0
N7Qh07QhN01jNWX0MgMg06m_K`1]KFd0JFUY071`L080MWIf00H0LW9b071`L01dM7@0LW9b07AdM01`
L70207alO00:07MgM`1lO7`0LW9b07IfMP1mOGd0MGEe0861P@1jNWX0R8R808>3P`80NGUi0240Ng]k
07inOP24Q8@0P82007inOP22PX80Ph>308J6QP27QhL0S8b<096AT@2>SXh0RXZ:08N7Q`2=SHd0TY:B
092@T02FUYH0U9BD09FEU@2OWil0UIFE09>CT`2GUiL0VYZJ0::RXP2VYZH0ZJVY09fMW@2UYJD0[Zj^
0:ZZZP2c/k<00P2e]KD02`2g]kL0][Jf0;Zj^P2l_;`0a<C40<S8b03De=@0cLg=0=7Ad@3Bd]80c/k>
0080fm_K00D0j^[Z0?Gem@3emOD0oOgm0?Shn01I0?ooo`0;0?7al@3UiND0inOW0>WYj@3MgMd0g=cL
0>3Ph03;bl/0d=3@0<k>cP34a<@00P32`/802`2o_kl0^;Rh0;Zj^P2_[jl0/[:b0;Bd]02`/;00Y:BT
0:^[Z`2SXj<0Y:BT0080W9bL0140WYjN09VIV@2HV9P0UYJF09NGU`2<S8`0UYJF09:BTP2=SHd0SXj>
09>CT`2@T900Shn?08:2PP29RHT0QXJ6096AT@020820P00608Z:RP2<S8`0PX:207alO01kNg/0OWin
0P1mOGd00`1`L700LG5a07=cL`0207alO00:07UiN@1gMgL0MWIf06i^KP1`L700M7Ad071`L01_Kfl0
MGEe06m_K`80KVi^0P1cLg<01`1fMWH0LW9b06i^KP1]KFd0L71`06e]K@1[Jf/00`1VIVH01`1aLG40
J6QX06QXJ01/K6`0HV9R06MWI`1YJFT00P1XJ6P0301_Kfl0HF5Q06MWI`1SHf<0H61P06MWI`1QHF40
JFUY06EUI@1MGEd0HV9R06EUI@80H61P00<0GUiN05mOG`1OGel01P3IfMT100000040fMWI00000`3I
fMT0000000000002000000<0fMWI0P0000040=WIf@8000001P3IfMT00`000000fMWI0=WIf@030=WI
f@80HV9R00h0Fe]K06EUI@1PH600JVYZ06EUI@1OGel0GUiN061PH01[Jf/0IFEU05mOG`1TI6@0JVYZ
06UYJ@80KFe]00L0L71`06m_K`1VIVH0I6AT06][J`1/K6`0JFUY0080J6QX01/0LG5a06YZJP1]KFd0
K6a/071`L01_Kfl0JFUY07AdM01lO7`0MgMg071`L01fMWH0JVYZ06i^KP1gMgL0M7Ad071`L01bLW80
MWIf079bLP1cLg<0L71`075aL@1hN7P0Lg=c07AdM01`L7000P1gMgL0101eMGD0O7al07MgM`20P802
07QhN00@07]kN`1fMWH0OWin08>3P`1mOGd0PH6108J6QP2:RXX0Rh^;08B4Q028R8P0S8b<08j>SP29
RHT0QhN708f=S@80S8b<01D0SXj>08n?S`2CTi<0UYJF09BDU02GUiL0VIVI09NGU`2VYZH0WYjN0:BT
Y02ZZZX0YZJV0:f][@2/[:`0ZZZZ0:JVYP2`/;00][Jf0;Ng]`2j^[X00P30`<00202g]kL0b<S80<_;
b`3?cll0bl_;0=KFeP3Hf=P0h^;R0P3QhN400`3_knl0j^[Z0?clo0020?_kneH0oooo0100mOGe0?Sh
n03gmoL0k^k^0>c/k03Xj>P0fMWI0>3Ph03;bl/0d=3@0=7Ad@3>c/h0cLg=0<O7a`30`<00^[Zj0P2m
_Kd0802k^k/0[Zj^0:b/[02a/K40ZJVY0:^[Z`2WYjL0WYjN0:BTY02QXJ40YJFU09jNWP2KVi/0UiNG
09FEU@2>SXh0Ti>C08f=S@2DU9@0S8b<08^;R`29RHT0T92@08V9R@2:RXX0RHV908F5Q@27QhL0PH61
08>3P`1mOGd0Ng]k0P1nOWh0101iNGT0N7Qh07]kN`1fMWH207YjNP0407alO022PX80PH6107emO@80
MgMg00L0M7Ad079bLP1kNg/0M7Ad07IfMP1XJ6P0Kfm_0080L71`00/0Lg=c079bLP1^KVh0MGEe06i^
KP1`L700Kfm_07QhN01[Jf/0KVi^06QXJ00206UYJ@0D079bLP1UIFD0IFEU06ATI01ZJVX0I6AT06MW
I`1UIFD0HV9R06IVIP1ZJVX0IfMW069RHP1SHf<0GUiN065QH@1SHf<0IFEU06IVIP1SHf<2069RHP03
05mOG`1QHF40fMWI00D0fMWI0@0000010=WIf@0000<0fMWI0000003IfMT0103IfMT010000000fMWI
0=WIf@0000020=WIf@040000003IfMT0fMWI000000D0fMWI00<000000=WIf@3IfMT00`3IfMT08`1K
Fe/0Jf][05YJFP1MGEd0IFEU069RHP1SHf<0IFEU06YZJP1WIfL0GemO06QXJ01MGEd0IfMW06ATI01/
K6`0IVIV06MWI`1^KVh0L71`06UYJ@1ZJVX0Kfm_071`L01/K6`0Jf][06m_K`1]KFd0J6QX06YZJP1^
KVh0M7Ad06UYJ@1_Kfl0Lg=c0080LW9b00@0L71`079bLP1`L700Kfm_0P1`L700101iNGT0Lg=c06YZ
JP1YJFT207=cL`0<07IfMP1aLG40MgMg075aL@1oOgl0OWin07=cL`1kNg/0OGem07alO01mOGd0NGUi
0P23Ph<09029RHT0PH6107moO`26QXH0PH6108B4Q020P800R8R808B4Q01mOGd0SXj>08b<S027QhL0
QXJ6096AT@2FUYH0QXJ608f=S@2DU9@0T92@09:BTP2FUYH0WIfM0:>SX`2RXZ80VYZJ09fMW@2SXj<0
X:2P0:NWY`2UYJD0Z:RX0;6a/@2_[jl0/[:b0;Ng]`80^;Rh00X0`L710<C4a034a<@0`l?30<K6aP3:
b/X0d=3@0=;BdP3Ogml0hN7Q0P3Rh^80103_knl0l?3`0?gmo@3kno]H0?ooo`0B0>o_k`3`l?00jn_[
0>OWi`3Ph>00i>CT0=[JfP3<c<`0fm_K0<_;b`37alL0b<S80<;2`P34a<@0_kno0<71`@2k^k/0/K6a
0P2_[jl0202XZ:P0Zj^[0:6QX@2YZJT0UiNG0::RXP2IVIT0W9bL0`2HV9P01`2EUID0Shn?096AT@2:
RXX0SXj>08F5Q@2>SXh00P2<S8`01`25QHD0Shn?08J6QP29RHT0PX:208N7Q`24Q8@00P1lO7`0<01i
NGT0Ng]k07QhN020P800OGem07UiN@1fMWH0Ogmo07IfMP1jNWX0O7al07IfMP20P800PH61071`L01c
Lg<0Kfm_06][J`1ZJVX0K6a/07AdM01bLW80KVi^06][J`1cLg<0KVi^079bLP1XJ6P0L71`07AdM01a
LG40Jf][071`L01^KVh0KFe]06a/K01XJ6P0I6AT06MWI`1YJFT0K6a/06e]K@1XJ6P0Hf=S06][J`1T
I6@0IfMW06ATI080IFEU00X0IVIV065QH@1QHF40I6AT061PH01IFET0GemO065QH@1SHf<0GemO1P3I
fMT100000040fMWI00020=WIf@030000003IfMT0fMWI0080fMWI00@000000=WIf@3IfMT000000P3I
fMT010000000fMWI0=WIf@0000050=WIf@<000000`3IfMT01@1XJ6P0HV9R06IVIP1LG5`0Fe]K0080
J6QX02/0HV9R06UYJ@1YJFT0IVIV065QH@1/K6`0IFEU06a/K01YJFT0KVi^06a/K01YJFT0Lg=c06MW
I`1ZJVX0KFe]06UYJ@1[Jf/0K6a/06UYJ@1ZJVX0IfMW06YZJP1YJFT0J6QX06UYJ@1_Kfl0KVi^075a
L@1eMGD0KVi^06m_K`1dM7@0LG5a06e]K@1iNGT0KFe]079bLP1mOGd0LW9b075aL@1_Kfl0Lg=c0080
MWIf00D0N7Qh079bLP1bLW80Ng]k07EeM@0207inOP0_07MgM`1nOWh0QXJ607moO`23Ph<0Q8B40820
P01lO7`0Ogmo0820P01oOgl0TY:B08Z:RP2;Rh/0TI6A08V9R@2<S8`0T92@08n?S`2CTi<0SXj>08f=
S@2GUiL0TI6A09ZJVP2HV9P0Vi^K0:6QX@2KVi/0VIVI0::RXP2XZ:P0Y:BT0:JVYP2^[Zh0ZZZZ0:j^
[P2d];@0/[:b0;6a/@2m_Kd0_[jn0;Rh^034a<@0a/K60<W9b@3De=@00P3EeMD0203@d=00dm?C0=gM
g@3Ph>00i>CT0>GUi@3kno/0lO7aF03oool0803moOd0no_k0??cl`3/k>`0hN7Q0>_[j`3Ng]h0fMWI
0=OGe`3Kfm/0d=3@0=[JfP36a/H0aLG50;jn_P2i^KT0^k^k0;Fe]@2i^KT0/k>c0;:b/P2e]KD0ZJVY
0;Bd]02WYjL0[jn_09nOW`2MWId0YJFU09FEU@2NWYh0Shn?0P2ATI405`2CTi<0UiNG08N7Q`2?Shl0
QhN708^;R`23Ph<0Ogmo08J6QP2>SXh0RHV908f=S@26QXH0NGUi08>3P`22PX80NWYj07QhN023Ph<0
N7Qh08F5Q@1nOWh0MgMg0080Lg=c01T0M7Ad07=cL`1lO7`0OGem07MgM`1bLW80OGem07AdM01bLW80
K6a/07QhN01/K6`0MgMg071`L01ZJVX0KVi^07=cL`1_Kfl0KFe]06][J`1cLg<0LG5a07IfMP1iNGT0
Lg=c0080IFEU00D0KVi^06IVIP1ZJVX0K6a/06YZJP0206MWI`0A06][J`1WIfL0IFEU06UYJ@1VIVH0
JVYZ06IVIP1QHF40IFEU06ATI01OGel0Fe]K065QH@1TI6@0HV9R065QH@1LG5`0103IfMT300000040
fMWI00030=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT010000000fMWI0=WIf@0000020=WI
f@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT206EUI@0=05mOG`1XJ6P0JFUY
06YZJP1UIFD0IfMW06ATI01SHf<0GemO069RHP1YJFT0IfMW06e]K@0206UYJ@0606YZJP1_Kfl0Lg=c
06][J`1`L700IFEU0P1]KFd01`1YJFT0KFe]06UYJ@1/K6`0LW9b071`L01/K6`00P1^KVh02P1/K6`0
Kfm_06m_K`1^KVh0K6a/06][J`1_Kfl0Lg=c06m_K`1bLW8207AdM00F06i^KP1iNGT0L71`07AdM01j
NWX0L71`07UiN@1nOWh0LG5a06i^KP1mOGd0Ng]k07IfMP1lO7`0PH6108F5Q@27QhL0NGUi07moO`23
Ph<0R8R808V9R@80PX:200L0Rh^;08R8R021PH40P82008Z:RP2<S8`0RXZ:0080TY:B00H0UYJF08f=
S@2@T900V9RH09FEU@2JVYX209^KV`0N09bLW02SXj<0YJFU0:>SX`2UYJD0[:b/0:RXZ02ZZZX0YjNW
0;Vi^@2b/[80^;Rh0;:b/P2l_;`0_Kfm0;no_`2h^;P0`l?30<[:bP3AdM40gMgM0<o?c`3GemL0hN7Q
0=OGe`3^k^h0kno_0>[ZjP3no_h0kno_E`3oool01@3lo?`0m?Cd0>k^kP3YjNT0iNGU0080i>CT01X0
e]KF0=3@d03GemL0d=3@0=;BdP32`/80`<300;fm_@2k^k/0]KFe0:f][@2a/K40^[Zj0:n_[`2[Zj/0
[jn_0:RXZ02VYZH0YJFU0:>SX`2JVYX0WIfM09>CT`2IVIT0VYZJ08Z:RP80UIFE00/0V9RH09BDU02=
SHd0RHV908Z:RP29RHT0Rh^;08f=S@2>SXh0QXJ608>3P`020820P00308>3P`20P800MWIf00<0O7al
00`0NWYj07UiN@1nOWh0MgMg07moO`1kNg/0N7Qh07UiN@1jNWX0MgMg07]kN`1[Jf/207EeM@0706YZ
JP1[Jf/0LG5a079bLP1TI6@0JFUY06MWI`0206i^KP0K07=cL`1fMWH0KVi^07MgM`1hN7P0O7al07Ee
M@1XJ6P0JFUY06IVIP1YJFT0J6QX06MWI`1ZJVX0I6AT06YZJP1KFe/0H61P06EUI@1TI6@0Hf=S06MW
I`1RHV80Hf=S06QXJ01TI6@0FUYJ0080IFEU00@0JFUY05aLG01IFET0Hf=S1P3IfMT100000040fMWI
00001@3IfMT000000=WIf@3IfMT000000080fMWI00@000000=WIf@3IfMT000000P3IfMT010000000
fMWI0=WIf@0000050=WIf@030000003IfMT0fMWI00<0fMWI00@0GemO069RHP1KFe/0IfMW0P1PH603
06=SH`0?06QXJ01YJFT0J6QX06UYJ@1WIfL0Hf=S06QXJ01YJFT0J6QX06][J`1/K6`0IVIV06YZJP1U
IFD0L71`0080K6a/00<0J6QX06e]K@1_Kfl00P1^KVh06@1bLW80KFe]065QH@1]KFd0LG5a06m_K`1/
K6`0Jf][07EeM@1XJ6P0LG5a06a/K01dM7@0MWIf07QhN01fMWH0NWYj07QhN01bLW80N7Qh07=cL`1e
MGD0Lg=c07UiN@20P8000P1eMGD0201iNGT0O7al0820P01nOWh0QhN707]kN`1nOWh0OGem0P29RHT0
<02:RXX0QXJ608>3P`2;Rh/0QHF508Z:RP28R8P0T92@08V9R@2=SHd0U9BD08n?S`2IVIT0TI6A08b<
S02JVYX0T92@09:BTP2HV9P0WinO09jNWP2QXJ40XZ:R0:VYZ@2VYZH0[:b/0:VYZ@2[Zj/0ZJVY0;Rh
^02i^KT0/k>c0;Ng]`2e]KD0_[jn0;fm_@34a<@0`/;20<o?c`3@d=00e]KF0=WIf@3EeMD0gmoO0>k^
kP3/k>`0l?3`0?OgmeP0oooo02@0no_k0?Cdm03bl_80k^k^0=cLg03Xj>P0fMWI0>7Qh@3AdM40clo?
0<W9b@3:b/X0^;Rh0<G5a@31`L40a<C40;bl_02^[Zh0/K6a0:j^[P2/[:`0YjNW0:6QX@2YZJT0Zj^[
0:2PX02LW9`0YJFU08j>SP2FUYH0X:2P09FEU@29RHT0Rh^;092@T02=SHd208j>SP0B08R8R027QhL0
SHf=07moO`25QHD0TI6A08>3P`21PH40QHF507moO`1mOGd0N7Qh07MgM`1jNWX0Ng]k07YjNP1nOWh0
P8200P1oOgl02@1mOGd0MgMg07AdM01dM7@0MGEe07MgM`1fMWH0N7Qh06][J`0207=cL`0807AdM01f
MWH0KFe]06YZJP1eMGD0M7Ad06e]K@1_Kfl207=cL`0>07UiN@1jNWX0N7Qh07IfMP1`L700Kfm_071`
L01fMWH0K6a/06UYJ@1TI6@0IfMW06ATI01UIFD2065QH@0?061PH01NGUh0IfMW069RHP1WIfL0Hf=S
069RHP1OGel0IfMW05eMG@1WIfL0GUiN05eMG@1XJ6P0Hf=S00H0fMWI0@0000010=WIf@000P3IfMT2
000000@0fMWI0P0000040=WIf@8000001P3IfMT00`000000fMWI0=WIf@030=WIf@0D06UYJ@1OGel0
IVIV05mOG`1TI6@0H61P06EUI@1SHf<0HF5Q069RHP1SHf<0I6AT06IVIP1YJFT0KFe]06UYJ@1SHf<0
JVYZ06ATI01VIVH306UYJ@0?075aL@1/K6`0JVYZ06UYJ@1]KFd0Jf][06m_K`1XJ6P0JVYZ06i^KP1T
I6@0IfMW075aL@1ZJVX0L71`0080KFe]00<0Kfm_07EeM@1bLW800P1`L700=`1cLg<0LW9b07MgM`1j
NWX0LG5a071`L01eMGD0NGUi079bLP1gMgL0PX:207UiN@1mOGd0Ng]k08:2PP1lO7`0Ph>308b<S021
PH40R8R808J6QP22PX80QhN708R8R021PH40R8R807emO@27QhL0Rh^;08>3P`24Q8@0QXJ608j>SP2?
Shl0Ti>C092@T02<S8`0Shn?09JFUP2CTi<0XZ:R09ZJVP2GUiL0XJ6Q09nOW`2SXj<0WIfM0:ZZZP2/
[:`0Zj^[0;Fe]@2[Zj/0/[:b0;Jf]P30`<000P2f][H0302m_Kd0a/K60<30`03<c<`0d=3@0<g=c@3@
d=00hN7Q0=KFeP3QhN40lo?c0>k^kP80l_;bF@3oool0803dm?@0l_;b0>SXj03/k>`0g=cL0=kNgP3H
f=P0dM7A0<W9b@35aLD0b/[:0<g=c@2n_[h0`L710<K6aP2g]kL0^[Zj0;>c/`2][Jd0[:b/0;2`/02Y
ZJT0YjNW0::RXP2LW9`0XJ6Q09NGU`2OWil0V9RH09VIV@2CTi<0W9bL0P2FUYH0<02>SXh0RHV909RH
V028R8P0QHF508Z:RP29RHT0Q8B408^;R`22PX80R8R807YjNP1gMgL0Ogmo0820P01nOWh0QHF507]k
N`1lO7`0NGUi07QhN01dM7@0N7Qh07alO01gMgL0N7Qh07inOP1`L700M7Ad075aL@1_Kfl0L71`07Mg
M`1eMGD0KFe]079bLP1`L700Jf][06m_K`1`L700MgMg06m_K`1aLG40JVYZ07AdM01jNWX0NGUi07Ad
M080KVi^00@0K6a/06=SH`1YJFT0H61P0P1QHF403@1XJ6P0Hf=S06MWI`1SHf<0JVYZ06ATI01PH600
IVIV069RHP1SHf<0IVIV05aLG01RHV800P1UIFD0101GEeL0GEeM061PH01VIVH60=WIf@4000000@3I
fMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT01P1SHf<0DE5A05iNGP1MGEd0H61P06ATI080IVIV
03L0J6QX065QH@1VIVH0H61P06EUI@1ZJVX0IfMW06e]K@1WIfL0Kfm_06UYJ@1]KFd0J6QX069RHP1X
J6P0IVIV071`L01_Kfl0K6a/06][J`1]KFd0K6a/06YZJP1YJFT0Hf=S06UYJ@1VIVH0Lg=c06m_K`1]
KFd0LG5a06m_K`1^KVh0L71`07=cL`1`L700LG5a06a/K01cLg<0K6a/07=cL`20P800Lg=c06][J`1g
MgL0O7al07QhN01mOGd0M7Ad07MgM`1lO7`0MWIf07MgM`1oOgl0O7al00D0P82002L0PH6108J6QP23
Ph<0RHV908B4Q029RHT0Ph>308n?S`2>SXh0Rh^;09BDU029RHT0Shn?096AT@2HV9P0UYJF092@T02K
Vi/0UYJF09bLW02UYJD0XJ6Q09RHV02VYZH0ZZZZ0:VYZ@2/[:`0[Zj^0:n_[`2a/K40_;bl0;Fe]@2f
][H0^KVi0;Zj^P2o_kl0b/[:0<S8b03:b/X00P3Bd]801`3IfMT0g=cL0=_Kf`3Shn<0k^k^0??cl`3e
mOD0EP3oool01P3moOd0oooo0?ooo`3jn_X0m_Kf0>c/k080hn?S0100emOG0=[JfP39bLT0b/[:0<k>
cP31`L40cLg=0<C4a030`<00^[Zj0;Ng]`2WYjL0/k>c0;Bd]02][Jd0Z:RX0P2ZZZX20::RXP0409^K
V`2QXJ40WinO09:BTP80VIVI0240UYJF08f=S@2?Shl0SXj>08f=S@2<S8`0SHf=08N7Q`26QXH0QhN7
08Z:RP1nOWh0P82008F5Q@1lO7`0QhN707YjNP20P800OWin0861P@1lO7`0PH6107YjNP1mOGd0N7Qh
07EeM@1jNWX0N7Qh07YjNP1fMWH0NGUi07AdM01_Kfl00P1aLG4206i^KP0J071`L01^KVh0K6a/07]k
N`1_Kfl0KVi^07AdM01XJ6P0JFUY071`L01bLW80Jf][075aL@1^KVh0Kfm_06MWI`1UIFD0KFe]06QX
J01QHF40IFEU06ATI01UIFD0IVIV06YZJP1XJ6P206=SH`05065QH@1SHf<0IFEU065QH@1RHV800`1T
I6@2065QH@0306IVIP1QHF40Hf=S00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@03
0=WIf@0306EUI@1KFe/0I6AT0080I6AT00H0Hf=S06UYJ@1]KFd0IfMW05mOG`1WIfL2065QH@0406QX
J01]KFd0JFUY075aL@80J6QX00@0Kfm_06MWI`1XJ6P0Jf][0P1/K6`0201^KVh0J6QX06UYJ@1[Jf/0
LG5a06e]K@1aLG40K6a/0P1[Jf/0301ZJVX0Jf][075aL@1/K6`0M7Ad06a/K01eMGD0LG5a06i^KP1g
MgL0L71`07IfMP80MgMg03X0KFe]071`L01dM7@0Kfm_07IfMP1gMgL0MGEe075aL@24Q8@0Ng]k07al
O01oOgl0PH6107moO`1lO7`0Q8B408:2PP28R8P0QHF508J6QP27QhL0OWin08F5Q@28R8P0RHV908B4
Q029RHT0R8R808V9R@2BTY80U9BD092@T02=SHd0V9RH09nOW`2LW9`0VYZJ09bLW02GUiL0XJ6Q0:FU
Y@2TY:@0YZJV0:RXZ02TY:@0]KFe0;2`/02_[jl0/k>c0;^k^`2m_Kd0`/;20<30`031`L40^;Rh0<W9
b@33`l<0b<S80P3EeMD02@3>c/h0fm_K0=cLg03Vi^H0k^k^0?KfmP3dm?@0lo?c0?[jnP1F0?ooo`0_
0?7al@3oool0lO7a0>?Sh`3Ti>@0hN7Q0=[JfP3Ogml0dM7A0<O7a`3>c/h0`<300;jn_P35aLD0`/;2
0;Zj^P2^[Zh0/;2`0;Ng]`2a/K40ZJVY0;2`/02LW9`0Z:RX0:NWY`2RXZ80UYJF09jNWP2SXj<0UYJF
09NGU`2CTi<0TY:B09JFUP2JVYX0TY:B09BDU026QXH0VIVI08J6QP2=SHd0TI6A08J6QP28R8P0PX:2
08J6QP1mOGd00P1iNGT07020P800O7al07QhN01gMgL0MWIf08N7Q`1gMgL0Lg=c079bLP1kNg/0M7Ad
07IfMP1iNGT0Ng]k071`L01cLg<0JVYZ075aL@1bLW80MgMg06i^KP1gMgL0Kfm_06MWI`1YJFT0N7Qh
071`L01XJ6P2075aL@0706MWI`1ZJVX0KVi^071`L01]KFd0LG5a06QXJ00206a/K00>06UYJ@1ZJVX0
IFEU06=SH`1VIVH0IfMW06YZJP1MGEd0H61P06IVIP1OGel0J6QX06EUI@1OGel206=SH`0606UYJ@1T
I6@0HF5Q06IVIP1MGEd0Hf=S1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI
00h0IFEU06MWI`1MGEd0H61P06MWI`1OGel0IFEU069RHP1QHF40G5aL06MWI`1XJ6P0IFEU06IVIP80
I6AT00L0K6a/06QXJ01UIFD0Jf][06i^KP1]KFd0J6QX0080IfMW00P0Kfm_06UYJ@1VIVH0Kfm_06MW
I`1^KVh0Jf][06i^KP80Kfm_0100KFe]06QXJ01VIVH0Kfm_06][J`1`L700LG5a07AdM01eMGD0KVi^
07AdM01eMGD0MgMg07=cL`1aLG40MgMg0P1eMGD00`1aLG40Q8B407YjNP0207UiN@0;07QhN01lO7`0
OWin07emO@27QhL0MgMg08B4Q020P800PX:208B4Q02;Rh/00P27QhL0902:RXX0R8R808F5Q@2;Rh/0
QhN708B4Q028R8P0TY:B08j>SP2CTi<0T92@08n?S`2IVIT0TY:B09VIV@2LW9`0Z:RX0:BTY02LW9`0
XJ6Q0:VYZ@2b/[80Y:BT0::RXP2c/k<0Zj^[0;6a/@2b/[80];Bd0;2`/02f][H0`/;20;fm_@39bLT0
`l?30=;BdP80e=CD00P0emOG0=SHf03QhN40gmoO0>[ZjP3/k>`0o_kn0??cleH0oooo0180l_;b0?[j
nP3jn_X0l?3`0>[ZjP3WinL0g]kN0>;RhP3De=@0d=3@0=CDe035aLD0a/K60<S8b030`<00^KVi0;Ng
]`2d];@20:j^[P030;:b/P2RXZ80Y:BT0080Z:RX00T0YJFU0:6QX@2NWYh0Ti>C09^KV`2LW9`0VYZJ
0:2PX02>SXh00P2CTi<02`2BTY80SXj>08V9R@2=SHd0RXZ:08F5Q@28R8P0Ogmo08F5Q@2;Rh/0MgMg
0080OGem00@0PH6107]kN`1oOgl0Ogmo0P21PH4207YjNP0407EeM@1iNGT0NGUi079bLP80NGUi00X0
Lg=c075aL@1eMGD0N7Qh075aL@1bLW80JVYZ06m_K`1aLG40M7Ad0P1XJ6P01@1^KVh0Jf][06][J`1c
Lg<0K6a/0080KFe]00h0Kfm_075aL@1XJ6P0IVIV06e]K@1UIFD0K6a/071`L01YJFT0IFEU06UYJ@1X
J6P0HF5Q06MWI`80I6AT00d0IVIV06YZJP1ZJVX0H61P05eMG@1PH600HF5Q05mOG`1QHF40H61P065Q
H@1LG5`0IVIV00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0H069RHP1K
Fe/0I6AT061PH01RHV80J6QX06=SH`1UIFD0IfMW06EUI@1XJ6P0GUiN06=SH`1OGel0HF5Q069RHP1/
K6`0Kfm_06ATI01]KFd0Kfm_06YZJP1XJ6P0IVIV0P1`L7002@1ZJVX0LW9b07=cL`1^KVh0JVYZ061P
H01/K6`0LG5a06a/K00206i^KP0>071`L01VIVH0Jf][079bLP1dM7@0LG5a07=cL`1fMWH0JVYZ07Qh
N01cLg<0KVi^06m_K`1gMgL307UiN@0407EeM@1aLG40Ng]k07QhN080Ng]k03P0NWYj08F5Q@20P800
Ng]k08F5Q@21PH40QHF507emO@22PX80QHF508N7Q`29RHT0QXJ608B4Q02>SXh0Shn?08Z:RP2;Rh/0
S8b<096AT@2BTY80TI6A092@T02DU9@0VIVI09fMW@2KVi/0Ti>C0::RXP2OWil0X:2P0:BTY02UYJD0
ZJVY0:f][@2TY:@0/;2`0:n_[`2f][H0]KFe0<30`02k^k/0bl_;0;jn_P36a/H0c<c<0<o?c`3Hf=P0
eMGE0=[JfP3Lg=`0g]kN0>OWi`3alO40k^k^0?GemEH0oooo0280oOgm0?knoP3hn?P0kno_0?gmo@3]
kNd0i>CT0=gMg@3Kfm/0c/k>0<O7a`3@d=00`l?30<;2`P2k^k/0a<C40;>c/`2g]kL0^;Rh0;Jf]P2a
/K40/;2`0:NWY`2][Jd0Zj^[0:NWY`2TY:@0YJFU0:JVYP2RXZ80U9BD0:2PX02IVIT0T92@0P2BTY80
4@29RHT0TY:B08N7Q`2<S8`0R8R808j>SP23Ph<0Q8B408F5Q@27QhL0PH6108B4Q02;Rh/0Ng]k07al
O01eMGD0O7al0080MWIf0140N7Qh07YjNP1cLg<0OGem07=cL`1eMGD0L71`07YjNP1dM7@0KFe]07Ad
M01hN7P0MgMg06e]K@1bLW80K6a/075aL@0206][J`0V079bLP1[Jf/0NGUi071`L01/K6`0Kfm_06QX
J01^KVh0Jf][06e]K@1/K6`0IfMW06e]K@1[Jf/0IfMW06EUI@1VIVH0KFe]06UYJ@1MGEd0GemO069R
HP1VIVH0JVYZ05]KF`1RHV80Fe]K06YZJP1QHF40I6AT06=SH`1QHF40JFUY05mOG`1PH600IFEU05YJ
FP1NGUh60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT03`1QHF40IFEU06IV
IP1PH600GemO06=SH`1PH600K6a/06QXJ01UIFD0I6AT06YZJP1TI6@0Hf=S06EUI@0206ATI080LW9b
00P0K6a/06][J`1_Kfl0Jf][06IVIP1]KFd0JFUY06i^KP80Jf][02<0JVYZ06a/K01YJFT0JFUY06i^
KP1[Jf/0JVYZ079bLP1]KFd0M7Ad07EeM@1dM7@0LW9b07IfMP1dM7@0LW9b07EeM@1fMWH0LW9b07If
MP1]KFd0LG5a07alO01jNWX0MgMg07QhN01iNGT0P82007YjNP26QXH0N7Qh07UiN@25QHD0Ng]k07em
O@0308>3P`0;08B4Q023Ph<0R8R808>3P`25QHD0S8b<08N7Q`28R8P0RXZ:08^;R`2>SXh00`2BTY80
102CTi<0U9BD09FEU@2GUiL209ZJVP0B09nOW`2QXJ40YJFU0:BTY02PX:00YjNW0:b/[02YZJT0[Jf]
0:j^[P2UYJD0/K6a0;Bd]02c/k<0_Kfm0<?3``31`L40bl_;0P37alL02P3<c<`0bLW90<o?c`3EeMD0
emOG0>3Ph03YjNT0k>c/0?ooo`3moOeG0?ooo`040?Gem@3^k^h0jNWY0>_[j`80g]kN01L0fm_K0=cL
g03Bd]80bLW90<c<c02o_kl0`<300;Zj^P2i^KT0][Jf0;2`/02/[:`0/K6a0:b/[02][Jd0Xj>S0:ZZ
ZP2SXj<0WIfM09RHV02PX:00UiNG09ZJVP0209NGU`0509VIV@2DU9@0Ti>C08n?S`2ATI400P2BTY80
702:RXX0QhN708R8R02=SHd0R8R808N7Q`21PH40Ogmo0861P@26QXH0PX:207emO@1lO7`0MWIf07Yj
NP1dM7@0LW9b07AdM01mOGd0MgMg07]kN`1dM7@0Lg=c07AdM01lO7`0Kfm_07UiN@1bLW8206m_K`0Z
06i^KP1]KFd0LG5a06e]K@1YJFT0KVi^06UYJ@1[Jf/0Kfm_06][J`1eMGD0KVi^07IfMP1WIfL0KVi^
06][J`1WIfL0JFUY06QXJ01/K6`0IVIV06QXJ01YJFT0IVIV06QXJ01WIfL0H61P06=SH`1RHV80GemO
05iNGP1PH600HV9R05mOG`1SHf<0IFEU069RHP1XJ6P0H61P05mOG`1LG5`0GemO1P3IfMT100000040
fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0140IVIV05mOG`1WIfL0H61P06IVIP1OGel0HV9R
06ATI01SHf<0JFUY06IVIP1RHV80KVi^06=SH`1[Jf/0JVYZ06QXJ00206MWI`80KVi^00@0IVIV06YZ
JP1^KVh0LW9b0P1XJ6P206e]K@80IFEU01<0KVi^06QXJ01]KFd0Kfm_071`L01ZJVX0Lg=c06i^KP1_
Kfl0M7Ad06i^KP1cLg<0N7Qh07=cL`1hN7P0LW9b075aL@1gMgL0O7al0080Lg=c02`0OGem07alO01n
OWh0N7Qh07inOP24Q8@0O7al0820P01lO7`0NGUi08>3P`1nOWh0Ng]k07YjNP24Q8@0QHF50820P023
Ph<0PX:208J6QP27QhL0SXj>08^;R`29RHT0Rh^;096AT@2EUID0Ti>C09BDU02FUYH0U9BD09>CT`2K
Vi/0W9bL09RHV02FUYH0XZ:R09fMW@2WYjL0WYjN0:JVYP2YZJT0Z:RX0:ZZZP80Zj^[00l0[Jf]0:n_
[`2h^;P0/;2`0<C4a031`L40b<S80<G5a@39bLT0e]KF0=CDe03Bd]80hN7Q0=cLg03WinL00P3YjNT0
0`3gmoL0oooo0?ooo`1D0?ooo`0?0?Win@3kno/0oooo0?7al@3Vi^H0inOW0=gMg@3Ng]h0c/k>0=3@
d032`/80`l?30<[:bP37alL0];Bd0080^[Zj00T0/k>c0;Ng]`2_[jl0/K6a0:n_[`2^[Zh0XZ:R0:2P
X02/[:`00P2RXZ8209nOW`0G09fMW@2HV9P0VYZJ096AT@2HV9P0VIVI09FEU@26QXH0SXj>08b<S02:
RXX0PH6108F5Q@27QhL0R8R807inOP22PX80QhN70820P01iNGT0R8R807inOP1iNGT00P1nOWh00`1l
O7`0OGem07AdM00207QhN00<07alO01fMWH0M7Ad06i^KP1bLW80KVi^07=cL`1`L700Jf][06m_K`1`
L700Lg=c0P1`L7006P1ZJVX0Lg=c06a/K01]KFd0Jf][06QXJ01SHf<0KVi^06][J`1aLG40JFUY06][
J`1WIfL0KVi^06IVIP1XJ6P0K6a/06UYJ@1bLW80H61P06=SH`1TI6@0IFEU06=SH`1OGel0IVIV0P1S
Hf<0101QHF40J6QX06MWI`1PH602065QH@0405aLG01RHV80HV9R06EUI@H0fMWI0@0000010=WIf@00
5P3IfMT00`000000fMWI0=WIf@030=WIf@0>06QXJ01NGUh0G5aL06UYJ@1UIFD0HF5Q06e]K@1SHf<0
J6QX05mOG`1YJFT0J6QX06ATI01VIVH206MWI`80JVYZ01h0Kfm_06MWI`1YJFT0K6a/06MWI`1/K6`0
L71`06e]K@1YJFT0L71`06][J`1]KFd0K6a/06MWI`1YJFT0K6a/06][J`1/K6`0JVYZ06i^KP1cLg<0
LG5a06][J`1`L700KVi^06a/K01jNWX0LW9b06a/K01[Jf/2079bLP0B07QhN01]KFd0MGEe07YjNP1l
O7`0Ng]k07inOP1iNGT0Ng]k08B4Q01mOGd0NGUi07inOP1oOgl0QXJ606m_K`28R8P0OGem0P24Q8@0
7@2;Rh/0QhN708:2PP2;Rh/0Shn?08b<S02ATI40Rh^;08b<S02;Rh/0VIVI08n?S`2@T900YJFU09fM
W@2GUiL0UYJF0:VYZ@2NWYh0UIFE09ZJVP2VYZH0Y:BT0:^[Z`2XZ:P0YjNW0:RXZ02a/K40]KFe0080
_Kfm00H0`<300<71`@31`L40`<300<C4a038b<P20<_;b`080=SHf03QhN40emOG0>GUi@3inOT0h^;R
0?3`l03hn?QF0?ooo`0:0?[jnP3clo<0g]kN0>c/k03WinL0hn?S0>3Ph03AdM40f=SH0<[:bP80cLg=
00T0a/K60;fm_@2o_kl0]kNg0;Rh^02f][H0/k>c0;6a/@2[Zj/00P2XZ:P01P2LW9`0[Jf]0:FUY@2Q
XJ40X:2P09nOW`80WIfM00`0U9BD09FEU@2;Rh/0RXZ:08f=S@29RHT0TY:B08f=S@29RHT0PX:208F5
Q@22PX8208V9R@0707inOP20P800N7Qh07]kN`1mOGd0Ng]k07IfMP0207alO00>07QhN01fMWH0NWYj
07alO01kNg/0MWIf07MgM`1bLW80MgMg07YjNP1kNg/0MgMg07=cL`1/K6`206][J`0P07UiN@1bLW80
Lg=c06e]K@1cLg<0KFe]06UYJ@1_Kfl0LG5a079bLP1WIfL0J6QX06MWI`1^KVh0HV9R06UYJ@1QHF40
JFUY06ATI01ZJVX0IfMW06EUI@1[Jf/0J6QX061PH01UIFD0HF5Q06EUI@1SHf<0IVIV05eMG@1UIFD3
05iNGP0605mOG`1SHf<0HV9R05mOG`1PH600G5aL1P3IfMT100000040fMWI000F0=WIf@030000003I
fMT0fMWI00<0fMWI00h0Hf=S065QH@1TI6@0GUiN06=SH`1UIFD0GemO065QH@1^KVh0IFEU06MWI`1Y
JFT0IfMW06YZJP80I6AT0P1ZJVX09`1`L700LG5a06e]K@1YJFT0K6a/06YZJP1^KVh0J6QX06IVIP1`
L700JFUY06a/K01bLW80LG5a06][J`1bLW80Kfm_06e]K@1`L700KVi^079bLP1_Kfl0KFe]06a/K01d
M7@0LG5a071`L01dM7@0N7Qh07IfMP1`L700N7Qh079bLP1_Kfl0OWin07YjNP1kNg/0NWYj07moO`02
07IfMP0j07=cL`1fMWH0OGem07UiN@1nOWh0O7al0820P01nOWh0Ph>30861P@22PX80RHV908F5Q@29
RHT0QXJ608F5Q@29RHT0QHF508V9R@2DU9@0RXZ:09ZJVP2FUYH0U9BD09FEU@2HV9P0VYZJ09VIV@2W
YjL0Y:BT09fMW@2SXj<0YZJV0:NWY`2^[Zh0Zj^[0:JVYP2ZZZX0[Jf]0;:b/P2^[Zh0^KVi0;Jf]P2m
_Kd0`/;20<71`@34a<@0b<S80=3@d03<c<`0g=cL0=CDe03Ng]h0i>CT0>7Qh@3/k>`0j>SX0?Cdm5D0
oooo04T0lO7a0?clo03_knl0k>c/0>KViP3YjNT0hN7Q0=gMg@3Jf]X0f=SH0=?Cd`3:b/X0a<C40<30
`037alL0_[jn0;^k^`2c/k<0/K6a0:f][@2/[:`0XZ:R0:2PX02TY:@0YjNW0:FUY@2/[:`0Y:BT0:>S
X`2^[Zh0X:2P09fMW@2ATI40UYJF09:BTP2GUiL0QXJ609>CT`2@T900S8b<08V9R@27QhL0Q8B408^;
R`25QHD0RHV908F5Q@28R8P0OWin07QhN01lO7`0Ogmo07emO@1kNg/0PH6107alO01jNWX0OWin07Yj
NP1]KFd0MGEe0820P01jNWX0P82007UiN@1hN7P0MGEe06e]K@1_Kfl0K6a/07=cL`1[Jf/0Kfm_0080
KVi^00`0Kfm_06YZJP1aLG40Jf][06m_K`1SHf<0KFe]06i^KP1[Jf/0IFEU06m_K`1ZJVX206][J`0<
06ATI01WIfL0IFEU06ATI01XJ6P0GUiN06=SH`1RHV80JFUY06a/K01RHV80JFUY0`1MGEd0201ZJVX0
Hf=S065QH@1NGUh0HF5Q06ATI01LG5`0HF5Q1P3IfMT100000040fMWI000F0=WIf@800000103IfMT0
201PH600IfMW06QXJ01XJ6P0Hf=S06IVIP1SHf<0HF5Q0P1SHf<0401LG5`0HF5Q06ATI01VIVH0IfMW
06m_K`1]KFd0Kfm_06YZJP1UIFD0GUiN06a/K01]KFd0IfMW06m_K`1[Jf/206QXJ00P06i^KP1`L700
MWIf06i^KP1_Kfl0MGEe06m_K`1/K6`0Jf][07AdM01`L700Lg=c06m_K`1^KVh0Lg=c07inOP1`L700
K6a/079bLP1/K6`0MWIf075aL@1fMWH0NGUi07=cL`1kNg/0N7Qh0861P@25QHD0OGem07UiN@1jNWX2
07alO0060820P01kNg/0OWin08:2PP1mOGd0OWin0P23Ph<01024Q8@0Shn?08Z:RP28R8P208V9R@0F
096AT@2<S8`0TI6A08J6QP2DU9@0TY:B09>CT`2@T900UiNG09^KV`2ZZZX0^;Rh0:^[Z`2QXJ40Xj>S
0:BTY02UYJD0Y:BT0::RXP2[Zj/0ZJVY0:^[Z`80/k>c0180^;Rh0;Vi^@2k^k/0_kno0<;2`P3:b/X0
c<c<0<g=c@3;bl/0emOG0=cLg03Ng]h0gmoO0>?Sh`3Zj^X0k>c/0?7al@3dm?AE0?ooo`0]0??cl`3m
oOd0l?3`0=kNgP3MgMd0i>CT0=_Kf`3?cll0e]KF0<c<c032`/80c<c<0<S8b02g]kL0_kno0;fm_@2a
/K40[jn_0;Zj^P2`/;00[:b/0:ZZZP2QXJ40XZ:R0:2PX02SXj<0ZJVY09nOW`2RXZ80WYjN09bLW02F
UYH0UiNG09>CT`2DU9@0TY:B08Z:RP2BTY80TI6A08J6QP20P800Ph>30820P023Ph<0Ogmo0080PH61
00<0Ogmo08>3P`1nOWh00P1kNg/02@1mOGd0NGUi0861P@1fMWH0O7al07UiN@1hN7P0NGUi07]kN`02
07IfMP0I07MgM`1lO7`0LW9b07MgM`1^KVh0NGUi075aL@1/K6`0MgMg06][J`1]KFd0JVYZ06QXJ01e
MGD0L71`079bLP1eMGD0JVYZ06e]K@1[Jf/0Hf=S06IVIP1YJFT0HF5Q06QXJ00206MWI`0E069RHP1Q
HF40IVIV06ATI01UIFD0GEeM06=SH`1OGel0Hf=S06EUI@1QHF40I6AT06YZJP1VIVH0HV9R05YJFP1P
H600G5aL06=SH`1NGUh0HV9R00D0fMWI0P0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WI
f@06069RHP1TI6@0IFEU06QXJ01TI6@0JVYZ0`1VIVH0801UIFD0J6QX069RHP1QHF40H61P06QXJ01W
IfL0J6QX06a/K01XJ6P0IVIV06a/K01dM7@0KFe]075aL@1ZJVX0I6AT07=cL`1ZJVX0LG5a06UYJ@1`
L700KVi^06a/K01bLW80Kfm_06][J`1bLW80Jf][06e]K@1/K6`0KFe]0P1bLW803@1eMGD0MWIf079b
LP1aLG40LW9b07MgM`1hN7P0MgMg06UYJ@1fMWH0MGEe07UiN@22PX800P1oOgl01`20P800MgMg07]k
N`1jNWX0OWin08F5Q@1hN7P00P1mOGd0<`21PH40Ph>308R8R026QXH0RXZ:08J6QP2@T900RHV908f=
S@2;Rh/0SXj>08f=S@2ATI40Ti>C09RHV02@T900Ti>C09bLW02>SXh0WIfM0:BTY02SXj<0X:2P09bL
W02TY:@0X:2P0:NWY`2YZJT0XJ6Q0:FUY@2/[:`0Z:RX0:n_[`2][Jd0^;Rh0;Vi^@2h^;P0^KVi0<O7
a`3=cLd0b/[:0<W9b@3Cdm<0eMGE0=_Kf`3Lg=`0hn?S0>OWi`3bl_80m?Cd0?3`l0020?gmoE80oooo
0P3]kNd03P3Vi^H0jn_[0>WYj@3Rh^80fMWI0=GEe@3Hf=P0dM7A0<o?c`2l_;`0cLg=0<30`02n_[h0
]kNg0P2f][H0402d];@0Zj^[0:NWY`2TY:@0YZJV0:^[Z`2MWId0Xj>S09jNWP2UYJD0[:b/09jNWP2G
UiL0VIVI09JFUP2>SXh209:BTP0A09FEU@2>SXh0Rh^;08f=S@2<S8`0RHV908R8R029RHT0Q8B408:2
PP1iNGT0PH610820P01jNWX0OWin07YjNP20P8000P1iNGT0101dM7@0MgMg07QhN01gMgL207EeM@0K
07QhN01`L700MgMg07EeM@1dM7@0L71`075aL@1^KVh0MWIf07=cL`1_Kfl0LG5a071`L01WIfL0M7Ad
06a/K01ZJVX0J6QX05iNGP1ZJVX0Kfm_07=cL`1_Kfl0IfMW06QXJ01^KVh0IVIV0080KFe]0140Jf][
06EUI@1YJFT0J6QX065QH@1OGel0HF5Q06ATI01YJFT0Jf][06IVIP1YJFT0H61P05eMG@1TI6@0GUiN
06IVIP0206ATI00305eMG@1OGel0G5aL00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WI
f@030=WIf@0B06ATI01PH600GemO05eMG@1WIfL0IFEU06IVIP1UIFD0Jf][06QXJ01UIFD0JFUY065Q
H@1]KFd0K6a/06e]K@1^KVh0HV9R0P1^KVh01@1/K6`0Kfm_06UYJ@1YJFT0LG5a0080KFe]01<0JFUY
07=cL`1aLG40Jf][071`L01^KVh0L71`07EeM@1cLg<0Kfm_06e]K@1/K6`0Jf][06m_K`1^KVh0LW9b
06i^KP1dM7@0LG5a0080MgMg00/0LW9b07emO@1lO7`0MWIf07=cL`1hN7P0OWin07UiN@1lO7`0Ng]k
07QhN00207moO`0<07YjNP1lO7`0OGem07inOP29RHT0NGUi0820P022PX80QhN708B4Q01oOgl0R8R8
0P2=SHd07029RHT0QXJ608R8R02DU9@0Shn?08V9R@2DU9@0T92@09>CT`2GUiL0U9BD09VIV@2QXJ40
WinO0:JVYP2NWYh0WIfM0:2PX02XZ:P0YjNW0:RXZ02][Jd0/;2`0:n_[`2h^;P0][Jf0;Vi^@2m_Kd2
0;jn_P030<30`02o_kl0alO70080d];B00X0fm_K0=;BdP3Ti>@0hN7Q0>KViP3[jn/0mOGe0?Cdm03k
no/0n_[jD03oool00`3no_h0o?cl0?_kn`020>o_k`080>KViP3Xj>P0e]KF0=gMg@3IfMT0eMGE0=7A
d@3;bl/20<S8b0080<C4a036a/H0]KFe0;6a/@2i^KT0]KFe0;2`/02WYjL20:JVYP0U0:6QX@2YZJT0
WIfM09bLW02PX:00WIfM0::RXP2KVi/0VIVI09JFUP2IVIT0UYJF08f=S@2<S8`0QhN708b<S02@T900
Rh^;08V9R@2:RXX0OGem08B4Q025QHD0Q8B408F5Q@21PH40Ogmo08B4Q01mOGd0N7Qh07YjNP1hN7P0
MgMg0820P01eMGD0NWYj079bLP0207QhN00906a/K01dM7@0MGEe07]kN`1/K6`0Jf][075aL@1_Kfl0
L71`0080LW9b01P0Jf][06QXJ01WIfL0Kfm_06YZJP1]KFd0KVi^075aL@1^KVh0JVYZ06e]K@1ZJVX0
L71`06YZJP1/K6`0IfMW06m_K`1XJ6P0JFUY06][J`1VIVH0Jf][05iNGP1ZJVX2069RHP80IVIV00<0
Jf][06=SH`1PH6000P1SHf<01P1QHF40GUiN06ATI01OGel0G5aL05iNGPH0fMWI0@0000010=WIf@00
5P3IfMT00`000000fMWI0=WIf@030=WIf@0e069RHP1LG5`0GemO06ATI01YJFT0HF5Q06QXJ01UIFD0
I6AT06EUI@1WIfL0GemO069RHP1UIFD0JFUY065QH@1aLG40HV9R06ATI01`L700J6QX06][J`1/K6`0
JVYZ06m_K`1SHf<0KFe]06QXJ01cLg<0L71`06m_K`1VIVH0JFUY06a/K01dM7@0MWIf06i^KP1bLW80
JFUY07AdM01[Jf/0KFe]07EeM@1^KVh0L71`07AdM01`L700KVi^079bLP1fMWH0O7al07UiN@1jNWX0
0P1iNGT0701nOWh0N7Qh07emO@1kNg/0O7al07MgM`1mOGd0NWYj079bLP24Q8@0P82007emO@1oOgl0
Shn?08B4Q028R8P0PH6108b<S02;Rh/0O7al08F5Q@2=SHd0SXj>08n?S`2ATI40Ti>C09VIV@2>SXh2
09>CT`0509^KV`2JVYX0V9RH09fMW@2KVi/00P2QXJ400`2RXZ80ZZZZ0:RXZ0020;6a/@0H0:FUY@2e
]KD0/;2`0;6a/@2l_;`0^KVi0;Fe]@39bLT0b<S80<[:bP3@d=00e]KF0<o?c`3Hf=P0fMWI0>OWi`3U
iND0lO7a0>g]k@3alO40lo?c0?ooo`3jn_X0moOgC`3oool0203kno/0oooo0?clo03emOD0i^KV0=WI
f@3Ti>@0f=SH0P3De=@0703AdM40b/[:0<W9b@35aLD0a<C40;no_`33`l<0]kNg0:f][@2f][H0[:b/
0:ZZZP2VYZH0Xj>S0:6QX@2[Zj/0WinO0:NWY`2RXZ80Y:BT09VIV@2JVYX0UYJF09FEU@2DU9@0UYJF
096AT@2DU9@208n?S`0408V9R@24Q8@0S8b<08Z:RP80QXJ600<0PX:208>3P`22PX800P23Ph<02@20
P800NWYj07MgM`1hN7P0NWYj07QhN01gMgL0N7Qh07IfMP0207QhN00307YjNP1eMGD0KVi^0080NGUi
01T0M7Ad07EeM@1dM7@0JFUY071`L01eMGD0LG5a06m_K`1aLG40KVi^06a/K01]KFd0Jf][06a/K01^
KVh0I6AT06a/K01WIfL0JVYZ06IVIP1WIfL0J6QX06UYJ@1XJ6P0IfMW0080Hf=S00H0JVYZ06UYJ@1R
HV80IFEU06QXJ01PH602065QH@0:061PH01SHf<0IfMW06EUI@1SHf<0IFEU06IVIP1UIFD0GEeM06AT
I080HF5Q1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00D0J6QX065QH@1U
IFD0J6QX06a/K00206ATI00:065QH@1TI6@0IFEU06IVIP1QHF40JFUY05mOG`1RHV80IVIV06EUI@80
K6a/01d0IFEU06QXJ01ZJVX0IfMW06QXJ01ZJVX0I6AT06][J`1]KFd0IfMW079bLP1^KVh0KFe]069R
HP1_Kfl0M7Ad06ATI01^KVh0Kfm_071`L01bLW80Kfm_06i^KP1`L700LG5a06i^KP1fMWH0LW9b07Ad
M00307IfMP0H07EeM@1lO7`0MWIf07EeM@1kNg/0PX:207YjNP1gMgL0Ng]k07IfMP22PX80Ng]k07em
O@2>SXh0R8R808J6QP1mOGd0Q8B408:2PP1kNg/0QhN708J6QP2:RXX0QhN70P2:RXX01@2>SXh0RHV9
08R8R02?Shl0TY:B0080UIFE01L0WIfM09nOW`2HV9P0W9bL09nOW`2IVIT0WinO09RHV02XZ:P0YJFU
0:VYZ@2UYJD0XJ6Q09nOW`2i^KT0/K6a0;>c/`2h^;P0_;bl0;Vi^@34a<@0`/;20<c<c0020<S8b00;
0=KFeP3GemL0e=CD0>;RhP3Lg=`0iNGU0>CTi03[jn/0l_;b0?ooo`3kno/0D@3oool04P3dm?@0k^k^
0>_[j`3YjNT0i>CT0>SXj03Hf=P0fm_K0=3@d036a/H0c<c<0<[:bP35aLD0a<C40<?3``2`/;00^[Zj
0;>c/`80/K6a0100ZZZZ0:j^[P2][Jd0WinO0:JVYP2KVi/0Y:BT09fMW@2NWYh0X:2P0:6QX@2GUiL0
WIfM096AT@2@T900UIFE0P2BTY804026QXH0U9BD08^;R`24Q8@0Ph>308B4Q01oOgl0QHF508B4Q01l
O7`0Q8B407UiN@29RHT0OWin07QhN01jNWX207QhN00J07emO@1^KVh0MgMg07YjNP1fMWH0NGUi07Mg
M`1eMGD0KFe]06a/K01cLg<0LG5a079bLP1cLg<0NWYj079bLP1YJFT0L71`06i^KP1`L700KVi^06YZ
JP1/K6`0LG5a06QXJ01ZJVX206MWI`0406m_K`1YJFT0KFe]06IVIP80JFUY00@0KFe]06EUI@1RHV80
IfMW0P1VIVH00`1PH600IVIV06UYJ@0206UYJ@80I6AT00@0Hf=S069RHP1UIFD0GEeM0P1QHF40101O
Gel0GUiN069RHP1UIFD60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0601R
HV80JVYZ06=SH`1TI6@0HV9R06QXJ01/K6`0Hf=S06ATI01UIFD0GUiN06YZJP1VIVH0JVYZ06a/K01S
Hf<0HV9R06MWI`1aLG40IfMW065QH@1YJFT0JVYZ06][J`80J6QX00<0L71`06m_K`1`L7000P1^KVh0
4@1[Jf/0KVi^06EUI@1]KFd0Jf][079bLP1/K6`0Kfm_06i^KP1iNGT0K6a/075aL@1eMGD0M7Ad07Ee
M@1bLW80NWYj0080LG5a02`0NWYj07UiN@1aLG40O7al075aL@1bLW80M7Ad07QhN01cLg<0NWYj07in
OP1jNWX0OWin07emO@24Q8@0Ogmo08F5Q@20P800OGem0861P@23Ph<0QXJ608B4Q029RHT0SHf=08Z:
RP27QhL0Shn?08V9R@2=SHd0V9RH08n?S`2>SXh0SHf=09ZJVP2OWil0Vi^K09bLW02MWId0W9bL0:2P
X02QXJ40WIfM0:ZZZP80ZJVY0P2/[:`0202_[jl0/K6a0:n_[`2c/k<0^k^k0;bl_02m_Kd0dM7A0P39
bLT03@3>c/h0c<c<0<o?c`3UiND0emOG0=SHf03Shn<0jn_[0>g]k@3emOD0nOWi0?Shn03no_h0D03o
ool00`3dm?@0kno_0?3`l0020>OWi`0>0>3Ph03De=@0g]kN0=GEe@3<c<`0c/k>0<W9b@2g]kL0`L71
0<K6aP2h^;P0^KVi0;:b/P2h^;P20:b/[0030:FUY@2/[:`0YJFU0080YJFU0380W9bL09JFUP2LW9`0
Y:BT09RHV02ATI40VIVI09bLW02KVi/0UiNG09:BTP27QhL0R8R809:BTP2<S8`0PH6108F5Q@1nOWh0
PX:208F5Q@21PH40QXJ60820P01lO7`0Ogmo08:2PP1fMWH0O7al07UiN@1kNg/0MWIf07EeM@1mOGd0
MWIf07inOP1eMGD0N7Qh06i^KP1cLg<0M7Ad06e]K@1fMWH0MgMg07AdM01iNGT0LW9b07EeM@1`L700
Jf][06i^KP80KFe]00P0LW9b07=cL`1_Kfl0LG5a079bLP1/K6`0JFUY05iNGP80IFEU00`0L71`06AT
I01[Jf/0J6QX06][J`1UIFD0Jf][06EUI@1_Kfl0JFUY06a/K01[Jf/206QXJ00;06YZJP1WIfL0IfMW
06ATI01JFUX0HF5Q05mOG`1LG5`0IVIV05mOG`1NGUh01P3IfMT100000040fMWI000F0=WIf@030000
003IfMT0fMWI00<0fMWI00l0J6QX06EUI@1ZJVX0GEeM06QXJ01PH600HV9R06QXJ01SHf<0GemO06AT
I01SHf<0I6AT065QH@1YJFT00P1TI6@01@1/K6`0JVYZ06UYJ@1WIfL0KVi^0080J6QX0180Jf][06IV
IP1^KVh0KFe]06UYJ@1XJ6P0KVi^06UYJ@1WIfL0Lg=c06m_K`1WIfL0KFe]07QhN01[Jf/0LG5a07=c
L`1_Kfl207EeM@04075aL@1cLg<0L71`075aL@80Lg=c04L0M7Ad07QhN01iNGT0LW9b07MgM`1hN7P0
OGem07inOP1hN7P0K6a/07]kN`1oOgl0Ng]k07alO01oOgl0Ph>30820P027QhL0PX:207inOP25QHD0
Ti>C08J6QP23Ph<0S8b<08V9R@23Ph<0TI6A08b<S027QhL0U9BD096AT@2FUYH0Ti>C09ZJVP2@T900
VYZJ09>CT`2DU9@0X:2P0:6QX@2SXj<0X:2P0:JVYP2UYJD0[Zj^0:FUY@2ZZZX0Zj^[0;6a/@2e]KD0
]kNg0;Zj^P2f][H0_kno0<71`@33`l<0a/K60=WIf@37alL0d=3@0=OGe`3Kfm/0f][J0>;RhP3Ph>00
m?Cd0?7al@3gmoL0n_[j0?7al@1@0?ooo`0=0??cl`3^k^h0mOGe0>OWi`3MgMd0h>3P0=GEe@3Cdm<0
bl_;0<S8b03;bl/0c/k>0;Rh^0020;bl_0080;>c/`2i^KT0]KFe0;:b/P2^[Zh0];Bd0:BTY02WYjL2
0:FUY@0c0::RXP2SXj<0Y:BT09bLW02IVIT0V9RH09jNWP2QXJ40Vi^K09RHV02=SHd0SXj>09>CT`2>
SXh0Ti>C092@T023Ph<0P82008>3P`1mOGd0Q8B407alO023Ph<0Ogmo08B4Q01lO7`0PH6107alO01i
NGT0Ogmo07inOP1lO7`0NGUi07IfMP1mOGd0MGEe06YZJP1hN7P0LW9b071`L01nOWh0KFe]079bLP1d
M7@0KVi^07EeM@1aLG40K6a/06i^KP1WIfL0KFe]0080L71`0P1]KFd0101^KVh0Jf][05mOG`1^KVh2
06IVIP0>05iNGP1UIFD0J6QX06][J`1ZJVX0HV9R06=SH`1TI6@0JVYZ06IVIP1SHf<0L71`06YZJP1S
Hf<206MWI`0;06EUI@1SHf<0I6AT06MWI`1UIFD0GemO06ATI01PH600Fe]K05eMG@1KFe/01P3IfMT1
00000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00H0IFEU06MWI`1SHf<0I6AT06EUI@1V
IVH206EUI@0706QXJ01RHV80Hf=S06e]K@1XJ6P0IFEU06a/K00206e]K@0706IVIP1/K6`0JVYZ06QX
J01]KFd0K6a/06QXJ00206a/K080Jf][00L0JVYZ06m_K`1_Kfl0JFUY06IVIP1`L700Hf=S0080K6a/
00d0Jf][07MgM`1_Kfl0MWIf071`L01fMWH0KVi^07YjNP1_Kfl0LW9b07]kN`1lO7`0KFe]0080Ng]k
00@0MWIf071`L01`L700M7Ad0P1kNg/04@1lO7`0MgMg07EeM@1nOWh0NWYj07QhN01lO7`0P82008J6
QP24Q8@0QHF507inOP22PX80R8R808:2PP23Ph<0T92@0080Shn?01T0SXj>08V9R@2@T900SHf=092@
T02=SHd0W9bL09:BTP2ATI40UYJF09fMW@2OWil0W9bL09ZJVP2LW9`0Xj>S0:ZZZP2YZJT0[:b/0:VY
Z@2XZ:P0^[Zj0:ZZZP2a/K40^;Rh0080^KVi00T0`/;20;^k^`2k^k/0dM7A0<o?c`3>c/h0clo?0>3P
h03Jf]X00P3Ph>001P3[jn/0gmoO0?7al@3kno/0m?Cd0?clo4h0oooo00/0no_k0?Shn03emOD0j>SX
0?3`l03Lg=`0iNGU0>OWi`3Fe]H0emOG0=7Ad@020<c<c0030<71`@2j^[X0^;Rh0080^KVi00L0/;2`
0;Jf]P2a/K40/[:b0:ZZZP2XZ:P0WYjN0080X:2P00L0XZ:R0:6QX@2VYZH0WinO09NGU`2HV9P0VYZJ
0080UYJF00T0TY:B08b<S02EUID0TI6A09:BTP28R8P0SXj>08R8R027QhL00P2;Rh/01P1nOWh0P820
0820P01oOgl0OGem07]kN`80M7Ad0280MgMg07YjNP1iNGT0OGem07YjNP1dM7@0MWIf07inOP1fMWH0
M7Ad07=cL`1]KFd0LW9b07IfMP1]KFd0Kfm_07=cL`1aLG40Lg=c06a/K01eMGD0Lg=c075aL@1_Kfl0
K6a/06UYJ@1dM7@0J6QX06e]K@1^KVh0J6QX06a/K01UIFD0I6AT0P1ZJVX0601WIfL0Hf=S069RHP1W
IfL0KVi^06m_K`1VIVH0G5aL069RHP1WIfL0Jf][06EUI@1SHf<0KVi^06ATI01SHf<0IFEU069RHP1P
H600Hf=S061PH01TI6@0GemO05IFEPH0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@03
0=WIf@0=065QH@1LG5`0H61P06QXJ01VIVH0Hf=S06EUI@1YJFT0I6AT06UYJ@1VIVH0JVYZ06IVIP02
069RHP0606QXJ01TI6@0JFUY06MWI`1VIVH0L71`0P1XJ6P0>01]KFd0K6a/06UYJ@1ZJVX0IFEU06YZ
JP1]KFd0Kfm_06e]K@1TI6@0JFUY06a/K01eMGD0JVYZ06a/K01cLg<0JFUY079bLP1`L700KVi^07Ee
M@1bLW80M7Ad07EeM@1cLg<0LW9b07MgM`1hN7P0LW9b07MgM`1fMWH0MGEe07=cL`1gMgL0NGUi07in
OP1fMWH0MGEe07]kN`1mOGd0OWin0820P01hN7P0P82007inOP25QHD0R8R808J6QP2<S8`0PX:208f=
S@27QhL0S8b<08j>SP29RHT0SXj>0P2=SHd02P2?Shl0TY:B09FEU@2HV9P0WYjN08Z:RP2KVi/0UIFE
09ZJVP2OWil209RHV0070:RXZ02TY:@0Y:BT0:BTY02YZJT0Xj>S0;6a/@020:j^[P0D0;Bd]02m_Kd0
_Kfm0;Rh^036a/H0clo?0<g=c@3@d=00d];B0=SHf03Fe]H0f][J0>CTi03Ph>00h^;R0>k^kP3inOT0
kNg]0?ooo`3no_i=0?ooo`0C0?clo03`l?00lo?c0>SXj03Vi^H0hn?S0=gMg@3Ogml0clo?0=GEe@3?
cll0b/[:0<O7a`30`<00_kno0;jn_P2g]kL0/[:b0:f][@020:n_[`0F0:NWY`2/[:`0Xj>S0::RXP2Q
XJ40X:2P0:6QX@2RXZ80X:2P09BDU02NWYh0VYZJ08j>SP2DU9@0V9RH09NGU`2HV9P0Rh^;08f=S@2?
Shl0S8b<08F5Q@80Ph>30P1oOgl02@28R8P0O7al07alO01kNg/0QhN70820P01hN7P0Ng]k07=cL`03
07alO00407MgM`1dM7@0NWYj07AdM080LW9b00d0MWIf07EeM@1_Kfl0LG5a06a/K01bLW80LG5a07If
MP1]KFd0NWYj071`L01dM7@0I6AT0080Jf][00D0JVYZ06a/K01[Jf/0J6QX06UYJ@0206YZJP0407=c
L`1XJ6P0Kfm_06IVIP80IfMW01H0J6QX06EUI@1YJFT0JFUY06IVIP1WIfL0HF5Q06IVIP1YJFT0IVIV
06UYJ@1PH600IfMW06EUI@1TI6@0Fe]K05iNGP1XJ6P0H61P06IVIP1SHf<0G5aL1P3IfMT100000040
fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00<0I6AT065QH@1XJ6P00P1RHV801@1TI6@0H61P
05aLG01NGUh0JFUY0080KFe]00`0IVIV06a/K01SHf<0JFUY06][J`1RHV80I6AT075aL@1_Kfl0JFUY
065QH@1ZJVX206UYJ@0706=SH`1_Kfl0Jf][06a/K01[Jf/0Kfm_06][J`0206e]K@0>079bLP1_Kfl0
LW9b07AdM01/K6`0JVYZ06i^KP1dM7@0LW9b07IfMP1bLW80K6a/07]kN`1eMGD207MgM`0C07=cL`1a
LG40MGEe07MgM`1_Kfl0N7Qh07MgM`1kNg/0NGUi07alO01iNGT0NWYj07inOP21PH40Ng]k08:2PP1i
NGT0OGem07inOP0208F5Q@0707emO@27QhL0QXJ608>3P`2?Shl0RXZ:0861P@0208b<S00609:BTP2@
T900VIVI09>CT`2LW9`0S8b<0P2HV9P0102JVYX0Xj>S09RHV02XZ:P20::RXP0L0:ZZZP2WYjL0[Zj^
0:b/[02[Zj/0[:b/0;:b/P30`<00]kNg0;>c/`31`L40alO70<71`@3:b/X0clo?0<k>cP3AdM40f=SH
0>3Ph03GemL0g=cL0>OWi`3/k>`0i^KV0>7Qh@3fm_H0oooo0?Ogmd`0oooo00L0nOWi0>o_k`3/k>`0
kNg]0>?Sh`3Ph>00eMGE0080f=SH01d0c/k>0<O7a`39bLT0_kno0;jn_P2l_;`0_Kfm0;Bd]02g]kL0
/k>c0;2`/02ZZZX0[jn_0:BTY02XZ:P0YZJV09nOW`2RXZ80VYZJ0:6QX@2VYZH0X:2P09JFUP2JVYX0
WIfM09NGU`2KVi/0U9BD09>CT`0308^;R`0608b<S02?Shl0Q8B408b<S022PX80QHF50P20P8003@1o
Ogl0PX:207inOP1nOWh0NWYj079bLP1lO7`0NGUi07AdM01lO7`0Ph>307alO01mOGd00P1_Kfl0101e
MGD0N7Qh07alO01]KFd2071`L00@07AdM01`L700M7Ad079bLP1]KFd0KVi^069RHP1YJFT0MGEe06i^
KP1/K6`0IFEU06m_K`1^KVh0IVIV06][J`80L71`01H0KFe]06MWI`1`L700K6a/06YZJP1WIfL0J6QX
06UYJ@1TI6@0H61P06=SH`1UIFD0Hf=S069RHP1XJ6P0Hf=S06IVIP1OGel0J6QX06MWI`1QHF40H61P
0P1TI6@00`1OGel0HF5Q061PH0060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3I
fMT03P1RHV80J6QX05mOG`1OGel0IFEU06=SH`1/K6`0HF5Q06MWI`1YJFT0HV9R06ATI01SHf<0KVi^
0P1VIVH06P1RHV80IfMW06QXJ01VIVH0L71`06YZJP1[Jf/0IfMW06UYJ@1TI6@0Kfm_06QXJ01SHf<0
IFEU061PH01YJFT0LG5a06UYJ@1]KFd0IVIV06UYJ@1]KFd0Jf][079bLP1fMWH0KVi^0P1aLG400`1h
N7P0LW9b07EeM@0207IfMP0606i^KP1dM7@0N7Qh06m_K`1eMGD0LW9b0P1kNg/207IfMP0?07YjNP1o
Ogl0Ng]k0861P@1mOGd0PH6107]kN`23Ph<0Q8B408:2PP20P800QhN708j>SP26QXH0PX:20080R8R8
02h0Shn?08R8R02<S8`0Shn?092@T02?Shl0UYJF09ZJVP2?Shl0V9RH096AT@2IVIT0WYjN09nOW`2I
VIT0X:2P0:6QX@2KVi/0X:2P0:FUY@2YZJT0YjNW0:^[Z`2g]kL0YjNW0;6a/@2d];@0/[:b0;2`/02e
]KD0a<C40<;2`P3;bl/0cLg=0<W9b@3?cll0dm?C0=_Kf`3Ph>00f=SH0>CTi03Xj>P0m?Cd0?[jnP3i
nOT0oOgmB`3oool0203moOd0no_k0>o_k`3emOD0jn_[0=oOg`3Rh^80f=SH0P3GemL06P3Cdm<0a<C4
0=CDe032`/80aLG50<K6aP2l_;`0/K6a0;Fe]@2b/[80][Jf0:f][@2d];@0[Zj^0:FUY@2[Zj/0X:2P
0:BTY02KVi/0X:2P09jNWP2MWId0X:2P09RHV02KVi/0TY:B0P2FUYH03@2EUID0VIVI08j>SP2ATI40
T92@08R8R027QhL0PH6108R8R022PX80O7al08>3P`24Q8@00P21PH4207inOP0F07emO@1nOWh0PH61
07emO@1nOWh0MGEe07MgM`1fMWH0NWYj07UiN@1`L700MgMg075aL@1bLW80NWYj075aL@1dM7@0NWYj
06i^KP1aLG40LW9b06IVIP80KVi^00d0LG5a07=cL`1YJFT0LG5a071`L01VIVH0L71`06MWI`1]KFd0
KVi^06IVIP1bLW80K6a/0080JVYZ01L0JFUY06a/K01WIfL0IVIV06=SH`1PH600HF5Q06IVIP1QHF40
G5aL06IVIP1RHV80IfMW06=SH`1RHV80H61P06UYJ@1QHF40GEeM05]KF`1PH600GEeM05YJFP060=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT05P1SHf<0H61P05mOG`1SHf<0J6QX
05]KF`1RHV80J6QX06EUI@1VIVH0JVYZ065QH@1]KFd0JVYZ06UYJ@1[Jf/0JVYZ06a/K01ZJVX0J6QX
06IVIP1OGel206a/K00=069RHP1]KFd0KVi^075aL@1^KVh0JVYZ06e]K@1/K6`0LG5a071`L01UIFD0
KFe]075aL@0206m_K`09071`L01bLW80MGEe06i^KP1ZJVX0KFe]07=cL`1aLG40N7Qh0080MgMg00H0
L71`07MgM`1dM7@0NGUi07EeM@1iNGT207YjNP0507inOP1hN7P0Ng]k08>3P`1eMGD00P20P800401i
NGT0P82007emO@1lO7`0RXZ:08J6QP25QHD0P82008R8R029RHT0QXJ608^;R`28R8P0T92@08Z:RP2B
TY8209BDU00P09bLW02GUiL0V9RH09NGU`2LW9`0YJFU09ZJVP2LW9`0VYZJ0:2PX02NWYh0ZJVY0::R
XP2PX:00YJFU0:f][@2_[jl0/[:b0;6a/@2e]KD0_[jn0;Zj^P2l_;`0_Kfm0<?3``34a<@0bl_;0<o?
c`3@d=00eMGE0=?Cd`3Fe]H30>7Qh@030>SXj03^k^h0l_;b0080n_[j00<0mOGe0?ooo`3oool0AP3o
ool30?_kn`080?7al@3_knl0j^[Z0>CTi03WinL0eMGE0=?Cd`3EeMD20<c<c00K0=3@d030`<00bLW9
0;^k^`2h^;P0^k^k0;2`/02g]kL0[jn_0;Fe]@2a/K40Zj^[0:j^[P2XZ:P0Xj>S0:FUY@2KVi/0V9RH
0:6QX@2JVYX0UYJF09^KV`2GUiL0WYjN09>CT`2HV9P0U9BD0080Rh^;00D0S8b<08Z:RP25QHD0Shn?
08R8R00208b<S00@08B4Q01lO7`0OGem07inOP21PH40PX:207inOP1jNWX0O7al0820P01kNg/0M7Ad
07MgM`1dM7@0N7Qh07IfMP80MgMg00l0MWIf07alO01gMgL0MGEe06e]K@1eMGD0K6a/079bLP1aLG40
KFe]06m_K`1dM7@0L71`07QhN01]KFd00P1[Jf/03`1^KVh0JVYZ06YZJP1ZJVX0K6a/06QXJ01_Kfl0
Jf][06YZJP1YJFT0HV9R06MWI`1VIVH0J6QX06MWI`0306EUI@0@069RHP1XJ6P0IVIV06MWI`1UIFD0
I6AT05mOG`1SHf<0IVIV06EUI@1OGel0IfMW05iNGP1RHV80GEeM05UIF@H0fMWI0@0000010=WIf@00
5P3IfMT00`000000fMWI0=WIf@030=WIf@0W06MWI`1UIFD0Hf=S061PH01UIFD0Hf=S069RHP1OGel0
HF5Q06UYJ@1RHV80I6AT06QXJ01/K6`0JFUY06][J`1^KVh0IVIV06i^KP1UIFD0Hf=S06m_K`1VIVH0
J6QX06YZJP1WIfL0J6QX06MWI`1]KFd0LW9b06a/K01YJFT0KVi^06m_K`1WIfL0LW9b06m_K`1/K6`0
Jf][00<0KFe]01`0M7Ad07IfMP1`L700M7Ad06e]K@1dM7@0K6a/07IfMP1eMGD0LG5a07IfMP1dM7@0
O7al07UiN@1hN7P0MgMg07IfMP23Ph<0P82007emO@1oOgl0OGem08:2PP20P800OGem08B4Q01oOgl0
Q8B40P1oOgl02`27QhL0QXJ608>3P`24Q8@0QXJ608^;R`2ATI40Shn?09RHV02<S8`0UYJF0080TY:B
01H0SXj>09NGU`2HV9P0VYZJ09VIV@2HV9P0VIVI09^KV`2RXZ80Y:BT0:j^[P2[Zj/0[Zj^0:b/[02^
[Zh0/[:b0;>c/`2`/;00[:b/0;bl_033`l<0c<c<0P31`L40103:b/X0clo?0<k>cP3AdM420=GEe@08
0=[JfP3UiND0i>CT0>[ZjP3/k>`0mOGe0?clo03hn?Q:0?ooo`0?0?;blP3lo?`0lo?c0>_[j`3Jf]X0
eMGE0=gMg@3IfMT0eMGE0=?Cd`38b<P0c<c<0<W9b@2l_;`0b<S80080^KVi0280_;bl0;Vi^@2_[jl0
ZZZZ0;Fe]@2][Jd0XJ6Q0:RXZ02[Zj/0YZJV0:2PX02SXj<0V9RH09fMW@2EUID0T92@09fMW@2HV9P0
TY:B08n?S`2ATI40S8b<08:2PP26QXH0Shn?08Z:RP25QHD0RXZ:08R8R023Ph<0R8R807moO`1mOGd0
R8R80P21PH402023Ph<0PH6107emO@1mOGd0MgMg07AdM01eMGD0NWYj0P1dM7@05P1cLg<0N7Qh06e]
K@1gMgL0Kfm_06a/K01`L700Kfm_071`L01_Kfl0KVi^06e]K@1dM7@0MGEe07QhN01`L700LG5a06m_
K`1]KFd0Jf][06e]K@1XJ6P206UYJ@0N06m_K`1^KVh0IVIV06i^KP1[Jf/0JVYZ06][J`1UIFD0J6QX
06i^KP1UIFD0JFUY06IVIP1YJFT0IFEU05mOG`1PH600IVIV06YZJP1TI6@0H61P05mOG`1SHf<0JFUY
065QH@1LG5`0HF5Q05aLG01PH600I6AT1P3IfMT100000040fMWI000F0=WIf@800000103IfMT0201S
Hf<0IFEU06=SH`1QHF40IFEU065QH@1ZJVX0IVIV0P1WIfL206ATI00707EeM@1[Jf/0KFe]06UYJ@1R
HV80IVIV06EUI@0206YZJP0A06UYJ@1[Jf/0LW9b06QXJ01WIfL0JVYZ069RHP1ZJVX0L71`06][J`1S
Hf<0JFUY06ATI01UIFD0JVYZ079bLP1/K6`00P1^KVh01`1cLg<0K6a/071`L01aLG40KFe]07EeM@1a
LG400`1eMGD01@1fMWH0N7Qh07QhN01bLW80L71`0080Ogmo00T0OGem08>3P`21PH40N7Qh07]kN`21
PH40OGem0820P01nOWh00P24Q8@02@23Ph<0Ogmo08>3P`24Q8@0QhN708j>SP21PH40PX:208F5Q@02
08j>SP0709BDU02>SXh0TI6A09FEU@2HV9P0UiNG09jNWP02096AT@0S09BDU02LW9`0XJ6Q09bLW02H
V9P0X:2P0:>SX`2XZ:P0WinO0;:b/P2a/K40Zj^[0:b/[02c/k<0Zj^[0;Jf]P2b/[80`<300<;2`P2j
^[X0aLG50<O7a`38b<P0b/[:0<o?c`3De=@0eMGE0=OGe`3Lg=`0inOW0?3`l03Rh^80k^k^0?KfmP3n
o_h00P3oool00`3lo?`0oooo0?ooo`130?ooo`0M0?Gem@3lo?`0lo?c0?Shn03^k^h0hn?S0>CTi03J
f]X0gMgM0=SHf03;bl/0emOG0<G5a@3AdM40`<300;bl_035aLD0`L710;>c/`2f][H0^;Rh0:RXZ02`
/;00Zj^[0:FUY@2ZZZX0YjNW0:JVYP2PX:000P2LW9`00`2IVIT0UIFE09JFUP02092@T00809ZJVP2A
TI40UiNG096AT@2@T900SXj>08Z:RP2?Shl208R8R00:08>3P`2CTi<0Ph>308R8R022PX80Ph>30820
P021PH40Ph>30820P080NGUi03/0N7Qh07YjNP1kNg/0MgMg07=cL`1dM7@0Kfm_07IfMP1dM7@0Kfm_
075aL@1^KVh0NGUi06e]K@1_Kfl0LG5a06e]K@1[Jf/0M7Ad079bLP1^KVh0MGEe06i^KP1bLW80JVYZ
075aL@1XJ6P0KVi^07EeM@1aLG40JVYZ06m_K`1^KVh0IfMW075aL@1SHf<0IVIV06YZJP1QHF40I6AT
06UYJ@1WIfL0IFEU065QH@1^KVh0Hf=S06ATI01WIfL0GEeM065QH@1[Jf/0HF5Q05iNGP1QHF40H61P
06IVIP1MGEd0IFEU05]KF`0205YJFPD0fMWI0P0000010=WIf@005P3IfMT00`000000fMWI0=WIf@03
0=WIf@0D05]KF`1OGel0GUiN069RHP1PH600JFUY06QXJ01VIVH0KFe]06ATI01WIfL0IVIV06e]K@1Z
JVX0Jf][06QXJ01UIFD0IVIV061PH01RHV8206QXJ080JVYZ00D0Jf][06e]K@1[Jf/0M7Ad06m_K`02
06i^KP80KFe]03H0Jf][06m_K`1cLg<0Kfm_061PH01aLG40KVi^07=cL`1dM7@0K6a/07IfMP1[Jf/0
LW9b075aL@1gMgL0LW9b07=cL`1`L700MGEe071`L01_Kfl0PH6107IfMP1/K6`0OWin07MgM`1oOgl0
Ph>307IfMP1eMGD0QHF507]kN`1nOWh0Ogmo0861P@1lO7`0Ph>307moO`1nOWh0Ph>308V9R@2:RXX0
R8R808^;R`27QhL0R8R809:BTP2=SHd0Rh^;09>CT`2ATI40VIVI09>CT`2GUiL209ZJVP0909^KV`2N
WYh0WIfM09fMW@2KVi/0Xj>S09jNWP2XZ:P0Y:BT0080YjNW01T0/k>c09jNWP2_[jl0[Zj^0;:b/P2j
^[X0_;bl0<30`037alL0`<300<C4a03=cLd0d=3@0=;BdP3Jf]X0g=cL0=gMg@3Lg=`0jn_[0>GUi@3^
k^h0jn_[0?[jnP3inOT0o_kn04L0oooo00/0l_;b0?Cdm03Zj^X0iNGU0>3Ph03Rh^80g=cL0=[JfP3L
g=`0c/k>0<g=c@020<W9b@0?0<[:bP2n_[h0]KFe0<71`@2j^[X0^KVi0;:b/P2][Jd0^;Rh0:b/[02]
[Jd0YJFU0:BTY02NWYh0XZ:R0080XJ6Q00D0VIVI09FEU@2DU9@0UIFE09bLW002096AT@0X09RHV02>
SXh0Shn?08^;R`2=SHd0RHV908Z:RP1oOgl0QhN708F5Q@29RHT0QXJ60861P@1jNWX0QHF508>3P`1i
NGT0PX:207=cL`1dM7@0OGem07alO01jNWX0NGUi07]kN`1lO7`0JVYZ07MgM`1fMWH0L71`07QhN01c
Lg<0Jf][079bLP1gMgL0KFe]075aL@1^KVh0NGUi071`L080KFe]00@0Kfm_06UYJ@1_Kfl0LG5a0P1Z
JVX01P1YJFT0K6a/079bLP1ZJVX0KVi^06e]K@80K6a/0`1XJ6P00`1VIVH0J6QX06UYJ@0206UYJ@0A
065QH@1SHf<0GemO069RHP1YJFT0IVIV05mOG`1MGEd0I6AT061PH01QHF40GEeM06ATI01QHF40IVIV
06ATI01NGUh01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00/0GUiN06MW
I`1RHV80IFEU061PH01SHf<0IfMW06UYJ@1/K6`0IVIV06m_K`0206MWI`0G06IVIP1aLG40IfMW06][
J`1UIFD0Jf][06=SH`1ZJVX0GemO06QXJ01VIVH0IFEU06m_K`1]KFd0Jf][06i^KP1[Jf/0LW9b06AT
I01`L700IfMW06EUI@1]KFd00P1/K6`01P1bLW80JFUY06a/K01aLG40MGEe07=cL`80Kfm_00@0Lg=c
079bLP1gMgL0KVi^0P1eMGD00`1jNWX0KVi^07]kN`0207IfMP0@07UiN@1mOGd0NWYj0820P01mOGd0
NWYj0861P@22PX80Ogmo07inOP1oOgl0OWin0861P@27QhL0P82008^;R`80QHF50100RHV908Z:RP2=
SHd0S8b<08J6QP28R8P0T92@08j>SP2GUiL0TY:B092@T02EUID0VIVI09RHV02JVYX0VIVI0P2TY:@0
7P2OWil0VIVI0:JVYP2WYjL0XJ6Q0:>SX`2ZZZX0_Kfm0;Ng]`2`/;00/k>c0;:b/P33`l<0`<300;jn
_P3:b/X0`L710<?3``35aLD0clo?0=GEe@3=cLd0e]KF0=GEe@3Ti>@0i^KV0>c/k03gmoL0j^[Z0??c
ldL0oooo00D0oOgm0>o_k`3clo<0kno_0?Cdm0020>[ZjP0L0=OGe`3Ng]h0fMWI0<k>cP3;bl/0clo?
0<K6aP3:b/X0a/K60<;2`P2l_;`0`<300;bl_02c/k<0[Zj^0;Ng]`2h^;P0XZ:R0:JVYP2[Zj/0Xj>S
0:2PX02UYJD0WYjN09bLW02CTi<0VYZJ09JFUP80UiNG00<0TI6A09BDU02ATI400P2@T900202BTY80
Q8B408^;R`28R8P0Q8B408^;R`25QHD0Ph>30P22PX808`24Q8@0OWin07inOP1kNg/0OWin07EeM@1o
Ogl0OWin07emO@1jNWX0O7al075aL@1/K6`0MgMg071`L01kNg/0LG5a07IfMP1eMGD0LG5a07AdM01_
Kfl0LG5a07=cL`1fMWH0MGEe07IfMP1]KFd0KVi^06m_K`1eMGD0Jf][071`L01ZJVX0I6AT0080Jf][
00X0LG5a06EUI@1ZJVX0Jf][071`L01WIfL0Hf=S06YZJP1SHf<0K6a/0P1SHf<04`1WIfL0Jf][065Q
H@1UIFD0IfMW061PH01UIFD0J6QX06=SH`1IFET0J6QX06MWI`1MGEd0IVIV061PH01UIFD0FEUI05mO
G`1MGEd01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00H0HV9R061PH01X
J6P0HV9R06=SH`1TI6@206=SH`0;06UYJ@1QHF40J6QX06MWI`1YJFT0IVIV06YZJP1[Jf/0KFe]06IV
IP1ZJVX00P1WIfL206IVIP0;06a/K01[Jf/0Kfm_06UYJ@1ZJVX0L71`06][J`1_Kfl0L71`06i^KP1Z
JVX00P1bLW806P1_Kfl0KVi^06m_K`1]KFd0KVi^079bLP1eMGD0Lg=c075aL@1^KVh0M7Ad075aL@1b
LW80K6a/075aL@1cLg<0MWIf07EeM@1hN7P0OGem07UiN@24Q8@0OWin07MgM`1iNGT0MgMg0`20P800
3@1mOGd0Ng]k08>3P`1oOgl0QHF507]kN`20P800PX:208F5Q@23Ph<0R8R808B4Q02?Shl00P2>SXh0
1@2EUID0T92@096AT@2EUID0W9bL0080U9BD02L0UYJF0:>SX`2OWil0Vi^K0:BTY02PX:00WinO09bL
W02UYJD0X:2P0:FUY@2YZJT0Z:RX0:NWY`2^[Zh0/[:b0;^k^`2`/;00/[:b0;Zj^P2l_;`0a<C40<71
`@36a/H0alO70=3@d03>c/h0eMGE0=CDe03Ng]h0h^;R0>WYj@3IfMT0j>SX0?3`l03gmoL0lo?c0?_k
n`3no_h0A03oool02`3no_h0l?3`0>o_k`3_knl0iNGU0=oOg`3Rh^80g]kN0=_Kf`3Hf=P0d=3@0080
b<S80240alO70<C4a033`l<0alO70;bl_02f][H0/k>c0;Bd]02e]KD0[Zj^0:RXZ02VYZH0Z:RX0:BT
Y02SXj<0W9bL09nOW`2MWId0VIVI09ZJVP2GUiL0V9RH096AT@2JVYX0T92@09>CT`2?Shl0UiNG09:B
TP2:RXX0SXj>08N7Q`2<S8`00P2:RXX07023Ph<0PH6108^;R`22PX80Ng]k07moO`20P800R8R807Mg
M`1bLW80MGEe07IfMP1oOgl0MgMg07YjNP1iNGT0Lg=c07QhN01_Kfl0Jf][06i^KP1/K6`0NGUi07=c
L`1eMGD0LG5a06i^KP1YJFT206i^KP0O06][J`1`L700LG5a06i^KP1XJ6P0LG5a06UYJ@1WIfL0J6QX
06YZJP1XJ6P0KVi^06][J`1]KFd0J6QX06i^KP1ZJVX0Hf=S06MWI`1UIFD0Hf=S06UYJ@1RHV80GemO
06IVIP1WIfL0J6QX05aLG01NGUh0HF5Q06EUI@0206ATI00906MWI`1QHF40HF5Q06=SH`1HF5P0HV9R
06ATI01OGel0H61P00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0706IV
IP1TI6@0HF5Q069RHP1PH600IfMW05]KF`02061PH00<069RHP1QHF40GUiN06][J`1/K6`0JFUY06YZ
JP1cLg<0JFUY06=SH`1RHV80IFEU0P1VIVH03`1TI6@0K6a/06IVIP1XJ6P0KFe]05mOG`1[Jf/0J6QX
079bLP1VIVH0LW9b07EeM@1TI6@0Lg=c075aL@02071`L080Kfm_00D0KFe]06a/K01iNGT0LW9b07If
MP0207=cL`0B07EeM@1gMgL0MgMg079bLP1hN7P0Lg=c07QhN01gMgL0Ng]k07emO@1bLW80NGUi07em
O@1jNWX0NGUi08F5Q@20P800PH610P20P800>`24Q8@0O7al07emO@24Q8@0QhN708Z:RP28R8P0RXZ:
08b<S027QhL0SHf=08n?S`2DU9@0Shn?092@T02JVYX0VIVI09FEU@2DU9@0VYZJ09VIV@2BTY80VYZJ
09nOW`2RXZ80XJ6Q09VIV@2XZ:P0X:2P0:JVYP2[Zj/0ZZZZ0;:b/P2`/;00_;bl0;Bd]02c/k<0^KVi
0;Zj^P2m_Kd0a<C40<K6aP33`l<0b/[:0=;BdP3EeMD0e]KF0=?Cd`3@d=00g=cL0>?Sh`3Ng]h0kNg]
0>o_k`3bl_80n_[j0?ooo`3hn?P0n_[j03l0oooo01l0oOgm0?ooo`3dm?@0moOg0?KfmP3dm?@0iNGU
0>o_k`3Rh^80gmoO0>3Ph03EeMD0bl_;0<o?c`31`L40a<C40<K6aP30`<00_kno0;Vi^@2g]kL0]KFe
0;Bd]02b/[80Zj^[0:ZZZP2UYJD0YjNW0:ZZZP2MWId0XJ6Q0080WinO00/0XJ6Q09VIV@2@T900UYJF
09BDU02CTi<0S8b<08n?S`2DU9@0TY:B096AT@0208^;R`0?08f=S@2>SXh0RXZ:08Z:RP22PX80Ogmo
08:2PP23Ph<0R8R807alO022PX80Ph>307emO@1gMgL0OGem0080Lg=c0100N7Qh07alO01hN7P0Kfm_
07=cL`1hN7P0MGEe07QhN01bLW80KFe]07UiN@1aLG40M7Ad07=cL`1hN7P0L71`0P1]KFd04`1[Jf/0
K6a/06IVIP1[Jf/0L71`06a/K01YJFT0L71`06e]K@1WIfL0JVYZ06QXJ01UIFD0KVi^06QXJ01/K6`0
IVIV05mOG`1VIVH00P1SHf<01@1IFET0J6QX06QXJ01VIVH0GUiN0080Hf=S00h0H61P06MWI`1RHV80
Hf=S06ATI01QHF40IVIV069RHP1OGel0HV9R06ATI01UIFD0GUiN05eMG@H0fMWI0@0000010=WIf@00
5P3IfMT00`000000fMWI0=WIf@030=WIf@0<06IVIP1LG5`0J6QX06EUI@1SHf<0GEeM06UYJ@1UIFD0
IfMW06YZJP1XJ6P0HV9R0P1TI6@06@1[Jf/0JFUY06IVIP1UIFD0J6QX06MWI`1ZJVX0J6QX061PH01U
IFD0HV9R06YZJP1[Jf/0IfMW06YZJP1_Kfl0K6a/06UYJ@1]KFd0KVi^06][J`1ZJVX0LW9b07=cL`1W
IfL00P1ZJVX0501dM7@0KVi^06i^KP1fMWH0N7Qh06e]K@1cLg<0M7Ad07EeM@1gMgL0O7al07IfMP1k
Ng/0Lg=c07]kN`1hN7P0NWYj07MgM`1eMGD0NWYj0P1oOgl02@20P800NWYj07]kN`1kNg/0Ogmo07al
O027QhL0Ng]k0820P00208R8R00408J6QP2CTi<0SXj>08f=S@80Rh^;00H0QXJ6092@T02EUID0Vi^K
09JFUP2:RXX2096AT@0W09bLW02EUID0VYZJ09ZJVP2PX:00Vi^K09nOW`2NWYh0YZJV0:FUY@2/[:`0
ZZZZ0:RXZ02WYjL0[:b/0:ZZZP2^[Zh0][Jf0;Rh^033`l<0`/;20<71`@3;bl/0cLg=0<O7a`3:b/X0
bLW90=[JfP3@d=00f=SH0=oOg`3QhN40h>3P0=gMg@3/k>`0m?Cd0?Gem@3bl_80mOGe0400oooo00l0
o_kn0?gmo@3oool0k>c/0?7al@3QhN40j>SX0>GUi@3Hf=P0emOG0=WIf@3@d=00f][J0=SHf03=cLd0
0P38b<P05P2n_[h0`<300;Zj^P32`/80^k^k0;>c/`2a/K40[Zj^0:b/[02VYZH0[Jf]0:NWY`2TY:@0
Vi^K09RHV02MWId0VYZJ09JFUP2@T900Vi^K09:BTP2IVIT309>CT`0X092@T029RHT0Ti>C08f=S@2C
Ti<0U9BD07moO`25QHD0R8R808>3P`2;Rh/0QhN70861P@24Q8@0Ogmo0820P01nOWh0MgMg07YjNP22
PX80Ogmo07]kN`1cLg<0MWIf07AdM01fMWH0Jf][07IfMP1kNg/0N7Qh07AdM01]KFd0LG5a071`L01c
Lg<0LW9b07AdM01]KFd0MGEe06MWI`80Jf][00D0JVYZ06QXJ01bLW80KFe]06=SH`0206MWI`0=06IV
IP1WIfL0KFe]06UYJ@1TI6@0Kfm_069RHP1ZJVX0Hf=S06UYJ@1ZJVX0Hf=S06IVIP0206MWI`0806QX
J01[Jf/0G5aL06ATI01QHF40I6AT05]KF`1YJFT206ATI007069RHP1TI6@0HV9R05mOG`1SHf<0H61P
05mOG`060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0401UIFD0IfMW06MW
I`1TI6@0HV9R065QH@1ZJVX0KFe]06IVIP1WIfL0H61P06MWI`1VIVH0Jf][06QXJ01YJFT206QXJ00<
06UYJ@1XJ6P0I6AT06EUI@1YJFT0K6a/069RHP1]KFd0Jf][06YZJP1UIFD0K6a/0P1]KFd0901UIFD0
Jf][06UYJ@1/K6`0L71`06m_K`1^KVh0JVYZ07EeM@1`L700KVi^06e]K@1cLg<0LW9b075aL@1gMgL0
NGUi0820P01hN7P0MgMg06e]K@1dM7@0NWYj079bLP1iNGT0KFe]07YjNP1nOWh0MWIf07EeM@1iNGT0
OGem0820P022PX80QHF507emO@80Q8B401`0QHF508>3P`22PX80PX:20861P@20P800Ph>308f=S@29
RHT0UIFE09>CT`2<S8`0Shn?09JFUP2;Rh/0VIVI08f=S@2IVIT0V9RH08b<S02DU9@0W9bL0:6QX@2K
Vi/0XJ6Q0:>SX`2PX:00YJFU0P2TY:@05P2WYjL0/[:b0:^[Z`2c/k<0];Bd0;6a/@2h^;P0`/;20;^k
^`32`/80`L710<G5a@37alL0a/K60<k>cP3?cll0c<c<0=SHf03MgMd0h^;R0>SXj03Zj^X20>_[j`05
0?KfmP3dm?@0n_[j0?[jnP3inOT0?P3oool0703gmoL0o?cl0>[ZjP3]kNd0lO7a0>GUi@3Ph>00gmoO
0>7Qh@3MgMd0emOG0=?Cd`3@d=00b<S80;bl_037alL0`<300;Rh^02k^k/0_;bl0;:b/P2[Zj/0[Jf]
0;Fe]@2VYZH0/k>c0:f][@2PX:020:RXZ0060::RXP2OWil0WYjN09jNWP2HV9P0UiNG0P2FUYH02@2I
VIT0T92@09>CT`2>SXh0Rh^;096AT@2DU9@0SXj>08b<S00208R8R00;08>3P`2;Rh/0Q8B408N7Q`21
PH40QhN70861P@1oOgl0O7al08F5Q@1kNg/00P1mOGd04`1lO7`0NWYj0820P01fMWH0NGUi07QhN01n
OWh0MgMg07UiN@1lO7`0M7Ad06i^KP1hN7P0MGEe06i^KP1`L700KFe]07MgM`1aLG400`1/K6`03@1]
KFd0LG5a06a/K01^KVh0Kfm_06QXJ01aLG40K6a/06MWI`1ZJVX0IVIV06QXJ01/K6`00P1XJ6P0301/
K6`0HF5Q06=SH`1VIVH0I6AT06EUI@1TI6@0IVIV05iNGP1RHV80IFEU05eMG@80HV9R00X0IVIV06i^
KP1QHF40IfMW06EUI@1SHf<0IFEU06MWI`1NGUh0HV9R1P3IfMT100000040fMWI000F0=WIf@030000
003IfMT0fMWI00<0fMWI0200HV9R06=SH`1LG5`0IFEU06UYJ@1WIfL0J6QX069RHP1KFe/0HF5Q05mO
G`1VIVH0Hf=S06i^KP1VIVH0JFUY06][J`1/K6`0Hf=S06IVIP1SHf<0JFUY06e]K@1QHF40Kfm_06=S
H`1VIVH0Jf][06UYJ@1dM7@0KVi^06a/K080M7Ad00l0JFUY071`L01XJ6P0Kfm_06a/K01cLg<0JVYZ
07AdM01`L700LW9b06a/K01^KVh0Kfm_071`L01dM7@00P1gMgL0301hN7P0MgMg07EeM@1cLg<0Kfm_
07IfMP1iNGT0Lg=c07MgM`1eMGD0NWYj07=cL`80O7al00X0NGUi07alO022PX80RHV908:2PP25QHD0
R8R808:2PP28R8P0P8200P28R8P208f=S@0<08n?S`2ATI40UIFE08^;R`2HV9P0U9BD09:BTP2GUiL0
U9BD09JFUP2ATI40TY:B0P2KVi/0302JVYX0Vi^K0:FUY@2/[:`0XJ6Q0:BTY02WYjL0Z:RX0:j^[P2b
/[80Zj^[0;Jf]P80]KFe00P0^[Zj0;Vi^@2d];@0_kno0<30`035aLD0bl_;0<S8b080bLW900`0c<c<
0=;BdP3GemL0f][J0=SHf03Vi^H0hn?S0>_[j`3`l?00k^k^0??cl`3kno/m0?ooo`0F0?[jnP3^k^h0
lo?c0?Gem@3QhN40jNWY0>7Qh@3Ogml0g]kN0>;RhP3EeMD0f][J0<[:bP39bLT0alO70<;2`P37alL0
_[jn0;Rh^02k^k/0/[:b0;Bd]080/K6a00h0[jn_0;:b/P2h^;P0]kNg0:^[Z`2WYjL0XZ:R09nOW`2K
Vi/0W9bL0:2PX02JVYX0WIfM09:BTP80UIFE01<0UiNG08f=S@2DU9@0SHf=09BDU02<S8`0U9BD08F5
Q@26QXH0S8b<08>3P`26QXH0S8b<07emO@1jNWX0Ogmo07inOP1oOgl0NWYj0080Ogmo00D0P82007em
O@1dM7@0Lg=c07IfMP02075aL@0L07AdM01eMGD0Ng]k07YjNP1dM7@0MGEe079bLP1iNGT0N7Qh07Ee
M@1/K6`0JFUY075aL@1_Kfl0JFUY075aL@1_Kfl0J6QX06][J`1XJ6P0L71`06QXJ01/K6`0Jf][06YZ
JP1SHf<0I6AT06UYJ@80J6QX00`0I6AT06UYJ@1UIFD0JFUY069RHP1XJ6P0IVIV06MWI`1/K6`0IVIV
06YZJP1YJFT2069RHP0505iNGP1XJ6P0JVYZ05eMG@1VIVH00P1SHf<01@1MGEd0IVIV05mOG`1JFUX0
Hf=S00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0H06=SH`1QHF40IVIV
05aLG01QHF40GemO06IVIP1UIFD0Hf=S06IVIP1PH600HF5Q06=SH`1PH600IFEU06IVIP1YJFT0I6AT
06a/K01QHF40Hf=S06a/K01XJ6P0JVYZ0P1SHf<09`1`L700IVIV06][J`1YJFT0IVIV06i^KP1/K6`0
L71`06][J`1XJ6P0JFUY06m_K`1cLg<0MGEe06i^KP1_Kfl0JVYZ071`L01cLg<0LW9b06m_K`1fMWH0
N7Qh071`L01_Kfl0LW9b0820P01gMgL0MWIf07=cL`1bLW80Ng]k07emO@1jNWX0NGUi07]kN`1nOWh0
PX:207moO`020861P@0608>3P`1mOGd0OGem08J6QP24Q8@0QXJ60P23Ph<04025QHD0SHf=092@T02=
SHd0S8b<096AT@3Bd]80TI6A09NGU`28R8P0TY:B08V9R@2FUYH0U9BD09>CT`2IVIT209ZJVP0309NG
U`2IVIT0UYJF0080WIfM00D0YJFU0:VYZ@2WYjL0ZZZZ0:^[Z`020:n_[`80]kNg01H0]KFe0;Vi^@2m
_Kd0^;Rh0<S8b031`L40`l?30<G5a@34a<@0cLg=0=CDe03Ogml0fMWI0>KViP3Rh^80gMgM0>_[j`3W
inL0m?Cd0>k^kP3emOD0n?Sh0P3kno/h0?ooo`0B0?clo03oool0o_kn0?clo03dm?@0nOWi0>c/k03Q
hN40i>CT0>7Qh@3MgMd0e]KF0=;BdP3Jf]X0c<c<0<O7a`3:b/X0`<300P31`L406`2h^;P0][Jf0;Jf
]P2e]KD0ZJVY0:f][@2b/[80ZZZZ0;Rh^02`/;00[Zj^0:ZZZP2UYJD0ZJVY09fMW@2WYjL0UiNG09fM
W@2FUYH0V9RH09VIV@2EUID0Shn?08j>SP2DU9@0T92@08j>SP0208^;R`0<08j>SP29RHT0PX:208V9
R@23Ph<0RHV907inOP1mOGd0PH6108J6QP1iNGT0P8200P1hN7P0501oOgl0OWin07moO`1iNGT0LW9b
07QhN01aLG40MgMg07=cL`1aLG40Lg=c07YjNP1_Kfl0MGEe07]kN`1jNWX0KVi^071`L01]KFd0LG5a
0P1`L7000`1/K6`0J6QX071`L00206UYJ@80K6a/00`0LW9b06UYJ@1/K6`0Jf][06UYJ@1^KVh0IVIV
06QXJ01]KFd0Jf][06YZJP1_Kfl206UYJ@0<05]KF`1ZJVX0HF5Q06QXJ01VIVH0HV9R06UYJ@1[Jf/0
HF5Q05mOG`1SHf<0H61P0P1RHV801`1PH600Hf=S05aLG01KFe/0HV9R06QXJ01OGel01P3IfMT10000
0040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI02`0IFEU05QHF01KFe/0Hf=S06a/K01QHF40
J6QX06ATI01XJ6P0JVYZ06IVIP1WIfL0IFEU06YZJP1QHF40J6QX06ATI01^KVh0L71`06EUI@1[Jf/0
IfMW079bLP1/K6`0J6QX06a/K01[Jf/0KFe]06QXJ01_Kfl0K6a/06QXJ01ZJVX0IFEU071`L01eMGD0
MWIf06QXJ01]KFd0K6a/06i^KP1gMgL0L71`07]kN`80LG5a02/0Kfm_07QhN01aLG40KVi^06a/K01g
MgL0M7Ad07EeM@1hN7P0NGUi07YjNP1dM7@0N7Qh07inOP1fMWH0N7Qh08J6QP1hN7P0NWYj07inOP20
P800O7al07moO`1nOWh0P82008^;R`2>SXh0RHV908N7Q`25QHD0RHV907moO`23Ph<0RXZ:08j>SP2E
UID0SHf=08^;R`2@T900UYJF09BDU02CTi<0UIFE0080U9BD00L0WIfM0:BTY02FUYH0VYZJ0:BTY02R
XZ80VIVI0080WinO01P0Xj>S0:VYZ@2[Zj/0WYjN0;>c/`2i^KT0][Jf0;Bd]02b/[80^[Zj0;Bd]02b
/[80bLW90<G5a@31`L40`/;20<71`@3>c/h0e=CD0=WIf@3EeMD0hN7Q0=kNgP3Ogml20>c/k0060>OW
i`3clo<0k>c/0?gmo@3hn?P0n_[j=P3oool04P3kno/0oooo0?Shn03inOT0o?cl0>OWi`3_knl0hn?S
0>GUi@3Ph>00fMWI0=7Ad@3@d=00c/k>0=7Ad@3=cLd0a<C40<k>cP80_;bl00d0_kno0;Vi^@2l_;`0
][Jf0;Rh^02g]kL0[jn_0:ZZZP2_[jl0YJFU0:j^[P2WYjL0XZ:R0080XJ6Q0100WIfM09nOW`2JVYX0
Vi^K09nOW`2BTY80U9BD08j>SP26QXH0Shn?08b<S02?Shl0SXj>08f=S@24Q8@0R8R80P29RHT07@24
Q8@0Ogmo08:2PP1oOgl0QXJ607emO@23Ph<0QXJ607emO@25QHD0PX:207inOP1eMGD0M7Ad07moO`1i
NGT0M7Ad07IfMP1lO7`0MWIf071`L01gMgL0OWin06i^KP1fMWH0LG5a07YjNP1iNGT0MgMg0080JVYZ
00P0LG5a07EeM@1/K6`0K6a/06QXJ01]KFd0J6QX075aL@80IfMW0280L71`06MWI`1cLg<0JFUY07Ee
M@1VIVH0JFUY06][J`1WIfL0JVYZ06][J`1UIFD0I6AT06MWI`1RHV80JVYZ06ATI01VIVH0IfMW065Q
H@1PH600HV9R05aLG01SHf<0HV9R05mOG`1TI6@0HF5Q06EUI@1YJFT0I6AT065QH@1LG5`0GUiN1P3I
fMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0P1RHV80201[Jf/0HF5Q06MWI`1S
Hf<0Jf][06QXJ01WIfL0JFUY0P1TI6@05@1QHF40G5aL06IVIP1XJ6P0JFUY06a/K01^KVh0IVIV06MW
I`1/K6`0IVIV06UYJ@1ZJVX0KVi^06e]K@1[Jf/0JFUY06][J`1cLg<0LG5a06e]K@0206i^KP@0JVYZ
0100KFe]071`L01cLg<0K6a/07IfMP1_Kfl0LG5a07YjNP1aLG40LW9b07AdM01bLW80NGUi079bLP1e
MGD0N7Qh0P1fMWH00`1_Kfl0M7Ad07EeM@0207emO@0607IfMP21PH40Ogmo0820P01kNg/0QhN70P23
Ph<03@25QHD0R8R808>3P`26QXH0P82008Z:RP22PX80Ph>3092@T02?Shl0S8b<08Z:RP2<S8`00P2C
Ti<0202@T900UYJF08b<S02FUYH0TI6A092@T02BTY80TI6A0P2IVIT01P2PX:00WIfM09ZJVP2PX:00
ZZZZ0:NWY`80[:b/00L0Z:RX0;:b/P2^[Zh0[jn_0:ZZZP2b/[80^;Rh0080/[:b00/0^KVi0<[:bP3@
d=00b<S80<W9b@3@d=00dm?C0=SHf03GemL0f][J0=kNgP020>7Qh@060>GUi@3Vi^H0inOW0>WYj@3d
m?@0jn_[103oool00`3no_h0oooo0?ooo`0_0?ooo`040?gmo@3oool0oOgm0?7al@80l_;b00`0iNGU
0>KViP3IfMT0i^KV0>?Sh`3Jf]X0emOG0=kNgP3Hf=P0a/K60<_;b`37alL30<?3``040<71`@2g]kL0
^[Zj0;Bd]080/;2`01D0[Jf]0:RXZ02a/K40YjNW0:b/[02UYJD0WIfM0:RXZ02RXZ80U9BD09ZJVP2>
SXh0UYJF09BDU02@T900U9BD09NGU`2;Rh/0TY:B08f=S@2@T9000P2<S8`0;02:RXX0SHf=08N7Q`2?
Shl0SHf=08b<S01mOGd0QHF508:2PP1mOGd0Ph>307inOP24Q8@0OGem07=cL`1jNWX0Q8B407MgM`21
PH40N7Qh079bLP1cLg<0MgMg07EeM@1hN7P0LW9b07EeM@1bLW80MGEe06m_K`1`L700JFUY06a/K01a
LG40MWIf071`L01cLg<0L71`06m_K`1`L700Kfm_06YZJP1_Kfl0K6a/0`1YJFT01P1^KVh0GUiN06YZ
JP1[Jf/0HF5Q075aL@80IVIV00T0KFe]06YZJP1WIfL0IFEU06ATI01VIVH0GemO06EUI@1/K6`00P1S
Hf<03@1WIfL0I6AT06ATI01PH600IFEU06QXJ01[Jf/0GemO061PH01MGEd0GemO05aLG01QHF401P3I
fMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI01@0HV9R06MWI`1YJFT0I6AT06QX
J01OGel0H61P06=SH`1OGel0JFUY06IVIP1YJFT0I6AT05mOG`1YJFT0HV9R06YZJP1SHf<0H61P069R
HP80IfMW00`0JFUY06][J`1YJFT0K6a/06][J`1`L700IfMW06e]K@1WIfL0LW9b06i^KP1cLg<206a/
K00806e]K@1XJ6P0Jf][06i^KP1eMGD0K6a/06i^KP1[Jf/2071`L00;06i^KP1_Kfl0KVi^07AdM01c
Lg<0KFe]071`L01aLG40MGEe079bLP1jNWX00P1lO7`207emO@08079bLP1mOGd0Ng]k07QhN022PX80
QhN707inOP1oOgl208>3P`0408F5Q@26QXH0PX:208F5Q@80QhN700l0RHV9092@T02;Rh/0SHf=08b<
S02=SHd0Shn?09BDU02EUID0TY:B09NGU`2IVIT0UiNG09nOW`2IVIT00P2KVi/0902TY:@0Ti>C09VI
V@2GUiL0X:2P0:JVYP2NWYh0YZJV0:VYZ@2WYjL0[Zj^0:ZZZP2UYJD0/;2`0:n_[`2k^k/0`L710;6a
/@2g]kL0a<C40;jn_P3=cLd0a/K60<[:bP3Hf=P0e]KF0=OGe`3EeMD0f=SH0>3Ph03Jf]X0h>3P0>k^
kP3[jn/0k^k^0>c/k080jn_[00<0n?Sh0?ooo`3no_h0<@3oool03@3hn?P0no_k0?gmo@3^k^h0mOGe
0?;blP3Shn<0i^KV0>;RhP3MgMd0hn?S0=_Kf`3?cll00P3GemL0103;bl/0clo?0<S8b03<c<`20;no
_`0;0;Zj^P2k^k/0^KVi0;Rh^02i^KT0/k>c0;Rh^02b/[80[Jf]0:6QX@2WYjL00P2TY:@02`2SXj<0
YJFU09fMW@2KVi/0WinO09VIV@2FUYH0XZ:R09ZJVP2GUiL0T92@0080Rh^;02L0QhN709BDU02ATI40
Q8B408N7Q`2;Rh/0Q8B408F5Q@2=SHd0PH6108>3P`24Q8@0P82008:2PP1mOGd0NWYj07moO`1jNWX0
O7al07]kN`1iNGT0Ogmo07emO@1aLG40Lg=c07alO01dM7@0LG5a07]kN`1cLg<0MGEe075aL@1`L700
Kfm_07AdM01cLg<0NWYj06e]K@1^KVh00P1aLG404@1bLW80Kfm_06ATI01^KVh0IVIV06e]K@1/K6`0
Kfm_06QXJ01SHf<0J6QX06m_K`1VIVH0Jf][06QXJ01VIVH0I6AT0080JVYZ00P0HV9R06e]K@1WIfL0
H61P065QH@1RHV80H61P05mOG`80IFEU00D0H61P05iNGP1LG5`0H61P06=SH`02069RHP0606YZJP1N
GUh0GUiN05UIF@1EEED0EeMG1P3IfMT100000040fMWI000F0=WIf@800000103IfMT01P1RHV80Hf=S
065QH@1VIVH0I6AT06QXJ080HV9R00P0GUiN06][J`1UIFD0HF5Q06UYJ@1RHV80IFEU06=SH`80JVYZ
00@0Jf][06IVIP1UIFD0Kfm_0P1/K6`0101SHf<0KFe]06a/K01RHV82071`L00A06e]K@1[Jf/0K6a/
06ATI01_Kfl0Jf][06a/K01`L700K6a/06i^KP1aLG40K6a/07EeM@1bLW80KFe]07EeM@1^KVh00P1_
Kfl0601eMGD0Kfm_079bLP1_Kfl0KFe]07=cL`1nOWh0Lg=c079bLP1iNGT0LW9b07UiN@1lO7`0OGem
08F5Q@1oOgl0OWin07IfMP23Ph<0P82008:2PP2<S8`0P82008:2PP80R8R800P0P82008N7Q`2<S8`0
QhN708J6QP2?Shl0TY:B08b<S080TY:B0240QXJ609:BTP2IVIT0Ti>C08n?S`2JVYX0UiNG09RHV02I
VIT0TI6A09NGU`2PX:00W9bL09^KV`2XZ:P0UYJF0:2PX02`/;00/K6a0:f][@2^[Zh0ZJVY0:f][@2e
]KD0^[Zj0;Rh^02j^[X0_Kfm0<;2`P33`l<0_;bl0<;2`P39bLT00P3;bl/0403AdM40bl_;0=7Ad@3M
gMd0iNGU0>OWi`3UiND0i>CT0?3`l03UiND0kno_0?;blP3dm?@0moOg0?Win@3lo?`]0?ooo`0H0?kn
oP3oool0o_kn0?knoP3`l?00lo?c0>k^kP3]kNd0j^[Z0>7Qh@3Zj^X0gMgM0>CTi03Kfm/0clo?0=7A
d@3GemL0clo?0<;2`P3:b/X0b<S80;no_`33`l<0_;bl0P2a/K401@2g]kL0^k^k0;:b/P2ZZZX0/;2`
0080[:b/0140WYjN0:VYZ@2KVi/0YZJV09nOW`2NWYh0W9bL09JFUP2HV9P0UiNG09>CT`2=SHd0Ti>C
09NGU`2DU9@0Shn?09JFUP02096AT@0:08n?S`22PX80R8R808f=S@24Q8@0RXZ:08V9R@23Ph<0OGem
08N7Q`80Ph>301D0NWYj07alO020P800Ogmo07EeM@1hN7P0NWYj07QhN01aLG40NGUi07AdM01cLg<0
KFe]06m_K`1lO7`0LW9b07=cL`1/K6`0Kfm_07EeM@1^KVh00P1/K6`0:@1[Jf/0JFUY06m_K`1^KVh0
Jf][06YZJP1`L700JFUY06e]K@1^KVh0Jf][06UYJ@1ZJVX0J6QX06MWI`1UIFD0I6AT06QXJ01YJFT0
L71`06QXJ01/K6`0I6AT061PH01[Jf/0IfMW06EUI@1OGel0H61P05YJFP1SHf<0IfMW065QH@1SHf<0
HF5Q061PH01RHV80GUiN06IVIP1TI6@0HV9R0080HF5Q00<0IVIV05iNGP1RHV801@3IfMT200000040
fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI02L0Hf=S05YJFP1NGUh0HF5Q06QXJ01YJFT0FUYJ
06EUI@1MGEd0I6AT065QH@1WIfL0GUiN06UYJ@1XJ6P0Jf][069RHP1YJFT0J6QX06YZJP1^KVh0Jf][
06ATI01ZJVX0JFUY06][J`1ZJVX0L71`06EUI@1/K6`0J6QX06MWI`1YJFT0Jf][06YZJP1[Jf/0KFe]
071`L01]KFd00`1`L700101/K6`0KVi^079bLP1bLW8207AdM00A075aL@1fMWH0K6a/06e]K@1eMGD0
L71`07AdM01lO7`0Ng]k07IfMP1cLg<0NGUi07EeM@1kNg/0NWYj07moO`1mOGd00P21PH404P1nOWh0
QXJ607UiN@24Q8@0Ph>307]kN`24Q8@0RHV908N7Q`1mOGd0S8b<08^;R`1mOGd0Ti>C096AT@2:RXX0
Shn?08j>SP80UYJF00`0Shn?09FEU@2>SXh0TI6A09BDU02EUID0TY:B09VIV@2EUID0XJ6Q09jNWP2Q
XJ420:>SX`0I0:^[Z`2ZZZX0ZZZZ0:b/[02YZJT0YJFU0:n_[`2`/;00][Jf0;Zj^P2m_Kd0`l?30;jn
_P2j^[X0a<C40<S8b036a/H0aLG50<_;b`34a<@0c<c<0=?Cd`3Jf]X0dm?C0>3Ph0020>7Qh@070>?S
h`3Ti>@0kno_0>c/k03`l?00h^;R0?Win@020?knoR`0oooo01@0o?cl0??cl`3oool0nOWi0?gmo@3^
k^h0kno_0>g]k@3Lg=`0h>3P0>7Qh@3Kfm/0e=CD0=KFeP3Hf=P0clo?0=3@d03EeMD0bl_;0<;2`P80
_kno0180`<300;jn_P2g]kL0]kNg0;fm_@2j^[X0^;Rh0:ZZZP2^[Zh0];Bd0:>SX`2ZZZX0XZ:R0:ZZ
ZP2PX:00Vi^K09nOW`2DU9@209VIV@0?09RHV02ATI40VYZJ08n?S`2DU9@0RXZ:096AT@28R8P0S8b<
08^;R`29RHT0RXZ:08N7Q`25QHD0RXZ:0080Q8B401<0QhN708F5Q@1mOGd0O7al07]kN`25QHD0OGem
07UiN@1hN7P0PH6108:2PP1kNg/0Lg=c07YjNP1iNGT0MWIf07MgM`1cLg<0Ng]k0080Kfm_00`0Lg=c
071`L01WIfL0Jf][06m_K`1UIFD0JFUY06a/K01dM7@0Jf][06a/K01XJ6P206][J`0406m_K`1UIFD0
J6QX06i^KP80IfMW00T0IFEU06IVIP1YJFT0IfMW071`L01WIfL0Jf][06IVIP1[Jf/00P1SHf<05P1R
HV80I6AT06EUI@1VIVH0J6QX06=SH`1PH600GUiN06EUI@1KFe/0H61P06=SH`1WIfL0IFEU05eMG@1V
IVH0GemO065QH@1NGUh0HV9R05eMG@1HF5P60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3I
fMT00`3IfMT05@1UIFD0HF5Q061PH01TI6@0IVIV061PH01UIFD0H61P05]KF`1RHV80J6QX06EUI@1X
J6P0I6AT06EUI@1VIVH0IFEU06UYJ@1/K6`0KVi^06QXJ00206][J`0606i^KP1ZJVX0JVYZ06i^KP1]
KFd0J6QX0P1[Jf/02P1YJFT0Jf][06YZJP1aLG40K6a/06QXJ01_Kfl0KFe]071`L01_Kfl206i^KP0:
075aL@1/K6`0Kfm_06a/K01_Kfl0LG5a071`L01/K6`0Jf][06m_K`80MGEe01H0L71`07YjNP1gMgL0
NGUi07emO@1lO7`0NWYj07inOP1iNGT0O7al07inOP22PX80QHF507moO`27QhL0R8R80820P023Ph<0
P82008N7Q`20P800S8b<0P25QHD01@24Q8@0R8R808^;R`29RHT0Rh^;0080T92@01<0TY:B096AT@2@
T900UiNG09VIV@2JVYX0W9bL09fMW@2JVYX0UYJF09>CT`2LW9`0VYZJ09^KV`2UYJD0YjNW0:JVYP2/
[:`0ZJVY0080/;2`00d0ZJVY0:^[Z`2e]KD0`L710;Vi^@2k^k/0`<300;^k^`2g]kL0c<c<0<?3``3:
b/X0bLW90080e=CD0P3EeMD03`3MgMd0g]kN0>7Qh@3Ogml0iNGU0>7Qh@3Ogml0j^[Z0?Gem@3bl_80
lo?c0?Gem@3moOd0nOWi0?_kn`0V0?ooo`070?knoP3lo?`0oooo0?Cdm03oool0mOGe0?3`l0020>k^
kP0N0>WYj@3^k^h0hN7Q0=[JfP3Ng]h0f][J0=gMg@3EeMD0f][J0=3@d03:b/X0cLg=0<_;b`3De=@0
b/[:0<G5a@37alL0_[jn0;Vi^@2a/K40]KFe0;Bd]02h^;P0Zj^[0:2PX02XZ:P0WinO0:^[Z`2TY:@0
VYZJ0P2QXJ403P2LW9`0WinO09NGU`2GUiL0UYJF09VIV@2@T900UIFE08V9R@2@T900VYZJ09:BTP2:
RXX0SXj>0P2?Shl00`26QXH0Q8B408>3P`0208>3P`0j08Z:RP1nOWh0Q8B40820P01mOGd0Ng]k07mo
O`1jNWX0OWin07YjNP1mOGd0NWYj07emO@1nOWh0MGEe07UiN@1^KVh0NGUi07=cL`1]KFd0M7Ad075a
L@1VIVH0Lg=c07AdM01_Kfl0KVi^06][J`1]KFd0M7Ad071`L01WIfL0JFUY07=cL`1/K6`0KFe]06QX
J01aLG40J6QX06e]K@1SHf<0J6QX069RHP1^KVh0J6QX069RHP1[Jf/0KVi^06EUI@1TI6@0IVIV06UY
J@1[Jf/0IfMW061PH01SHf<0I6AT05QHF080Hf=S00l0HV9R05eMG@1OGel0HV9R05YJFP1WIfL0IFEU
065QH@1MGEd0HF5Q06=SH`1UIFD0HV9R05iNGP1SHf<01P3IfMT100000040fMWI000F0=WIf@030000
003IfMT0fMWI00<0fMWI04L0Hf=S06][J`1HF5P0H61P06=SH`1YJFT0H61P06a/K01VIVH0HV9R06][
J`1VIVH0Jf][06EUI@1[Jf/0IVIV06EUI@1TI6@0K6a/075aL@1ZJVX0IVIV06MWI`1YJFT0HF5Q06EU
I@1WIfL0JVYZ06m_K`1bLW80KVi^06YZJP1^KVh0L71`06YZJP1bLW80KFe]071`L01XJ6P0KVi^071`
L01/K6`0KFe]075aL@1[Jf/0Kfm_075aL@1gMgL0Kfm_07IfMP1aLG40Kfm_07]kN`1gMgL0LG5a07Qh
N01fMWH0MgMg07=cL`1gMgL0O7al07UiN@1jNWX0O7al07]kN`1iNGT0Q8B407EeM@25QHD0Ng]k08B4
Q00207]kN`0608>3P`2:RXX0S8b<08N7Q`22PX80SXj>0P25QHD05`28R8P0Ph>308^;R`2ATI40T92@
08f=S@2?Shl0UIFE08R8R02ATI40SXj>09bLW02FUYH0VIVI09^KV`2OWil0WYjN09VIV@2LW9`0Y:BT
09jNWP2OWil0XZ:R0080YjNW00`0ZZZZ0:NWY`2ZZZX0[Zj^0;Vi^@2`/;00/k>c0;Jf]P2m_Kd0`<30
0;Zj^P33`l<20<_;b`0=0<G5a@3Jf]X0c/k>0=KFeP3>c/h0h>3P0=SHf03Lg=`0dm?C0>;RhP3Ph>00
jNWY0>_[j`020>c/k0080>o_k`3hn?P0lo?c0?ooo`3inOT0oooo0?Win@3no_hS0?ooo`030?gmo@3n
o_h0no_k0080lO7a01D0l?3`0?Shn03Zj^X0g=cL0=oOg`3WinL0i>CT0=gMg@3De=@0fm_K0=3@d03F
e]H0cLg=0=;BdP33`l<0`/;20<g=c@31`L40_kno0;Vi^@35aLD00P2b/[802`2a/K40/;2`0;6a/@2V
YZH0[:b/0:RXZ02MWId0WYjN0:BTY02NWYh0W9bL0080WinO00D0VIVI09:BTP2CTi<0V9RH08j>SP02
08n?S`0508j>SP2DU9@0VIVI08R8R027QhL00`25QHD04`27QhL0R8R808F5Q@2=SHd0RXZ:08J6QP21
PH40P8200861P@1oOgl0NWYj07MgM`22PX80NWYj07]kN`1gMgL0P82008:2PP1nOWh00P1hN7P00`1d
M7@0N7Qh07emO@0207IfMP0=06m_K`1`L700Jf][06i^KP1bLW80LG5a06i^KP1[Jf/0Lg=c06][J`1]
KFd0K6a/06][J`0206IVIP0506][J`1dM7@0LW9b06UYJ@1]KFd00P1XJ6P04`1[Jf/0J6QX06UYJ@1P
H600Jf][06EUI@1WIfL0K6a/06IVIP1_Kfl0JVYZ069RHP1VIVH0Hf=S06EUI@1SHf<0IVIV06MWI`1J
FUX00P1XJ6P01`1TI6@0GUiN061PH01NGUh0IVIV061PH01MGEd00P1TI6@205iNGPH0fMWI0@000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0P061PH01MGEd0JFUY069RHP1YJFT0GemO061P
H01UIFD0H61P06IVIP1SHf<0JVYZ05mOG`1RHV80IFEU06QXJ01VIVH0JVYZ079bLP1SHf<0J6QX06AT
I01UIFD0JFUY071`L01ZJVX0K6a/06QXJ01/K6`0LW9b06YZJP1[Jf/206YZJP0M06MWI`1[Jf/0KFe]
06IVIP1_Kfl0L71`06m_K`1]KFd0KVi^06UYJ@1aLG40Kfm_06][J`1`L700N7Qh06i^KP1bLW80MGEe
06][J`1lO7`0Kfm_07IfMP1jNWX0N7Qh06i^KP1kNg/0O7al0820P01mOGd00P1oOgl03P1jNWX0Ogmo
08>3P`1kNg/0P82007inOP23Ph<0QHF508R8R02:RXX0QHF508b<S023Ph<0RHV90P27QhL0102:RXX0
QXJ608Z:RP2ATI4209:BTP0E08b<S02BTY80Shn?09NGU`2EUID0W9bL09ZJVP2FUYH0UiNG0:FUY@2O
Wil0VIVI09jNWP2PX:00WinO0:FUY@2RXZ80Zj^[0:FUY@2_[jl0/k>c0080ZZZZ0P2a/K401P2][Jd0
^[Zj0;Jf]P31`L40]kNg0;fm_@80`l?30P38b<P04P3De=@0f=SH0=OGe`3QhN40gMgM0=CDe03QhN40
g=cL0>_[j`3Lg=`0f=SH0>GUi@3^k^h0lO7a0>GUi@3fm_H0lo?c0?Ogmb<0oooo02`0oOgm0?ooo`3j
n_X0oooo0?_kn`3/k>`0mOGe0?;blP3`l?00k>c/0>OWi`3Ogml0dm?C0=GEe@3Ng]h0hN7Q0=WIf@3C
dm<0fMWI0=CDe039bLT0bl_;0<W9b@32`/80`<300<;2`P36a/H0^[Zj0;Bd]02i^KT0/K6a0:f][@2f
][H0/K6a0:n_[`2VYZH0Z:RX0:6QX@2TY:@0Zj^[0:JVYP2PX:00Xj>S09fMW@80VYZJ00T0UiNG09>C
T`2HV9P0Ti>C092@T02FUYH0Shn?09JFUP26QXH00P25QHD03P27QhL0RHV908^;R`29RHT0QhN708B4
Q01oOgl0QHF507alO01mOGd0Rh^;08>3P`1nOWh0Ph>30P22PX801@1kNg/0N7Qh0820P01dM7@0O7al
0080Lg=c00H0N7Qh0820P01hN7P0MGEe07AdM01_Kfl206e]K@0C06UYJ@1cLg<0KFe]06e]K@1SHf<0
L71`06a/K01TI6@0L71`06MWI`1^KVh0JFUY06e]K@1/K6`0J6QX06=SH`1YJFT0IfMW06][J`0206EU
I@0506YZJP1TI6@0IfMW06EUI@1YJFT00P1TI6@0201UIFD0IfMW069RHP1XJ6P0IFEU065QH@1UIFD0
HV9R0P1QHF403@1OGel0H61P069RHP1QHF40I6AT065QH@1SHf<0GEeM06MWI`1NGUh0Hf=S05eMG@1O
Gel01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00P0Hf=S05iNGP1OGel0
Hf=S06MWI`1KFe/0H61P06EUI@80JVYZ00<0HF5Q05eMG@1WIfL00P1QHF409@1RHV80HF5Q06IVIP1U
IFD0KFe]06MWI`1]KFd0JFUY06QXJ01ZJVX0J6QX06IVIP1_Kfl0JFUY06MWI`1XJ6P0LW9b075aL@1Z
JVX0Kfm_06UYJ@1/K6`0M7Ad06ATI01`L700KFe]07EeM@1`L700Kfm_079bLP1^KVh0Kfm_06i^KP1c
Lg<0K6a/06YZJP1^KVh00P1fMWH03@1`L700LW9b079bLP1iNGT0M7Ad07UiN@1aLG40Ogmo07QhN01l
O7`0Ng]k07moO`21PH400`1nOWh01`1jNWX0PX:20820P022PX80RHV908Z:RP25QHD00P27QhL02P26
QXH0Shn?08>3P`2<S8`0QXJ608R8R02>SXh0T92@09FEU@28R8P208f=S@0:09JFUP2ATI40WinO09^K
V`2HV9P0WIfM09RHV02SXj<0WinO0:2PX080WYjN02`0XJ6Q09nOW`2][Jd0Xj>S0:^[Z`2][Jd0Z:RX
0;2`/02[Zj/0[Zj^0;bl_02^[Zh0a<C40;Rh^035aLD0_[jn0<O7a`3=cLd0`/;20<W9b@38b<P0e=CD
0=7Ad@3Fe]H0f][J0=gMg@3Lg=`0g]kN0=gMg@3Shn<0l?3`0>KViP3WinL0hN7Q0>k^kP3bl_80k^k^
0?Shn03moOd0oooo0?knoP3lo?`0oooo0?gmoA/0oooo00`0kno_0?KfmP3fm_H0o?cl0?Cdm03bl_80
jNWY0>[ZjP3]kNd0j>SX0>WYj@3Ti>@20=[JfP0;0=;BdP3IfMT0d=3@0=GEe@3Cdm<0c<c<0=?Cd`3<
c<`0alO70<[:bP3;bl/00P2o_kl01@2l_;`0^KVi0;Fe]@2f][H0]kNg0080/[:b0180[Zj^0:^[Z`2X
Z:P0ZZZZ0:f][@2ZZZX0XZ:R09fMW@2OWil0Vi^K09JFUP2MWId0VYZJ09fMW@2?Shl0U9BD09JFUP2E
UID209BDU00309:BTP29RHT0Shn?0080R8R800@0QXJ608:2PP1nOWh0NWYj0P22PX802`1kNg/0P820
07inOP1jNWX0R8R807moO`1iNGT0PX:207UiN@1nOWh0O7al0080NGUi01T0Ogmo08>3P`1gMgL0KFe]
07AdM01fMWH0MgMg06a/K01aLG40KVi^07EeM@1]KFd0LG5a06][J`1dM7@0KFe]06i^KP1]KFd0JVYZ
06EUI@1[Jf/0KVi^075aL@1]KFd0Hf=S0080Jf][01/0IFEU06e]K@1UIFD0JVYZ06][J`1WIfL0GEeM
06YZJP1RHV80IFEU06IVIP1UIFD0FUYJ06ATI01OGel0Hf=S06ATI01PH600HF5Q05iNGP1YJFT0IfMW
06=SH`1OGel0I6AT05eMG@1OGel00P1QHF401P1OGel0IFEU06MWI`1MGEd0GUiN06ATI0H0fMWI0@00
00010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0406MWI`1SHf<0I6AT065QH@80IfMW0340
I6AT06YZJP1VIVH0HV9R06][J`1SHf<0IVIV07=cL`1TI6@0Jf][06IVIP1ZJVX0JFUY065QH@1WIfL0
KVi^06UYJ@1QHF40JVYZ06EUI@1[Jf/0HV9R06EUI@1YJFT0JVYZ06m_K`1VIVH0J6QX06YZJP1^KVh0
IFEU06][J`1XJ6P0IfMW06m_K`1^KVh0LW9b06m_K`1aLG40Lg=c06m_K`1/K6`0MGEe06e]K@1cLg<0
OGem079bLP1iNGT0Lg=c0080M7Ad00l0MgMg07IfMP1gMgL0O7al07AdM01bLW80M7Ad07EeM@1mOGd0
NWYj07]kN`1nOWh0PX:207inOP21PH400P1nOWh02P26QXH0Ph>308R8R025QHD0Rh^;07inOP2:RXX0
Q8B408J6QP2=SHd208n?S`0908b<S02?Shl0T92@09:BTP2>SXh0Ti>C09VIV@2HV9P0WIfM0080VYZJ
01h0U9BD09bLW02VYZH0Z:RX0:BTY02b/[80Y:BT0:JVYP2WYjL0[Zj^0:BTY02YZJT0Zj^[0::RXP2a
/K40[Zj^0;no_`2f][H0_kno0;Zj^P2o_kl0^[Zj0;jn_P2l_;`0cLg=0;bl_037alL0bl_;0<S8b03=
cLd20<k>cP050>7Qh@3Lg=`0gmoO0>3Ph03UiND00P3Shn<01`3Zj^X0kNg]0?Cdm03WinL0l?3`0>_[
j`3emOD00P3kno/0103oool0o?cl0?ooo`3moOd30?ooo`030?_kn`3oool0oooo00T0oooo0140no_k
0?ooo`3oool0oooo0?clo03no_h0n_[j0?_kn`3inOT0o_kn0?3`l03alO40moOg0??cl`3Vi^H0h^;R
0?3`l0030>KViP0C0>CTi03QhN40h>3P0=;BdP3?cll0e=CD0<S8b03?cll0c/k>0<O7a`33`l<0_Kfm
0<W9b@33`l<0_Kfm0<30`02n_[h0_kno0;bl_0020;:b/P0?0:VYZ@2g]kL0[:b/0:FUY@2ZZZX0Y:BT
0:VYZ@2WYjL0XZ:R0:6QX@2KVi/0Xj>S09ZJVP2EUID0VIVI0080Vi^K00L0SXj>09VIV@2@T900T92@
08f=S@2;Rh/0S8b<0080RHV900<0TY:B08J6QP23Ph<00P25QHD01024Q8@0QHF508B4Q022PX830820
P00<08F5Q@1eMGD0Ng]k07inOP1dM7@0Ogmo07AdM01iNGT0MGEe07YjNP1cLg<0MgMg0P1]KFd03`1`
L700MWIf06a/K01_Kfl0LG5a06YZJP1bLW80K6a/06i^KP1]KFd0L71`06e]K@1/K6`0JVYZ06e]K@02
06MWI`0?06][J`1RHV80Kfm_06e]K@1ZJVX0J6QX06a/K01WIfL0IFEU06=SH`1VIVH0IfMW06=SH`1U
IFD0I6AT0080HV9R01@0JFUY06e]K@1VIVH0IfMW06EUI@1RHV80GemO06=SH`1QHF40IFEU05]KF`1M
GEd0IFEU06MWI`1SHf<0HF5Q06ATI01PH600I6AT061PH080GEeM00<0GemO0=WIf@3IfMT0103IfMT1
00000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00T0I6AT05mOG`1MGEd0GemO069RHP1X
J6P0I6AT05iNGP1SHf<00P1RHV809P1YJFT0IVIV065QH@1QHF40LW9b06a/K01XJ6P0K6a/06UYJ@1^
KVh0I6AT06MWI`1UIFD0IVIV06MWI`1[Jf/0IVIV06YZJP1YJFT0JVYZ069RHP1bLW80KVi^06][J`1/
K6`0Kfm_06a/K01cLg<0Jf][06e]K@1XJ6P0KVi^071`L01^KVh0JFUY06=SH`1gMgL0MWIf0P1aLG40
5`1]KFd0L71`07AdM01aLG40Ng]k07MgM`1eMGD0OGem07AdM01cLg<0MgMg07=cL`1dM7@0Ng]k07Ui
N@1kNg/0O7al07EeM@1jNWX0OGem0820P024Q8@0P82000<0QHF501@0Ph>30861P@22PX80R8R808b<
S025QHD0SXj>09>CT`2BTY80SHf=09:BTP2EUID0T92@096AT@2EUID0Ti>C09bLW02OWil0VIVI09NG
U`80VYZJ00H0ZJVY09ZJVP2MWId0Vi^K0:6QX@2OWil20:NWY`0P0:2PX02YZJT0/[:b0:j^[P2][Jd0
];Bd0;Vi^@2`/;00^;Rh0;Vi^@2f][H0^[Zj0;Vi^@32`/80_kno0<C4a039bLT0`l?30=KFeP3;bl/0
c/k>0=?Cd`3GemL0f][J0>CTi03YjNT0j^[Z0=kNgP3UiND0h^;R0>CTi03Vi^H20>[ZjP050>WYj@3c
lo<0mOGe0?Win@3gmoL01@3oool0203kno/0o_kn0?_kn`3oool0no_k0?ooo`3kno/0o_kn1`3oool0
1`3no_h0oooo0?[jnP3no_h0m_Kf0?clo03emOD00P3gmoL0703clo<0l?3`0?7al@3QhN40k^k^0>CT
i03[jn/0h^;R0=gMg@3Jf]X0f=SH0=cLg03Fe]H0emOG0=;BdP37alL0aLG50<S8b03@d=00_Kfm0<?3
``2l_;`0_[jn0;no_`2n_[h0^k^k0;Zj^P2f][H20:f][@0J0;6a/@2^[Zh0/K6a0:JVYP2[Zj/0Z:RX
0:ZZZP2WYjL0WYjN09VIV@2KVi/0WYjN09fMW@2GUiL0WIfM09^KV`2HV9P0SHf=09>CT`2>SXh0Shn?
08^;R`2EUID0Shn?08b<S02=SHd208B4Q00508^;R`1mOGd0Ogmo08F5Q@1lO7`00P23Ph<05P22PX80
Ph>308>3P`20P800PX:207UiN@1nOWh0P82007inOP1iNGT0O7al07IfMP1kNg/0MWIf06m_K`1`L700
M7Ad071`L01^KVh0LW9b07EeM@1kNg/206i^KP0906YZJP1`L700LG5a06i^KP1cLg<0JFUY06e]K@1W
IfL0I6AT0080K6a/00D0LG5a06][J`1^KVh0K6a/069RHP0206a/K00>06][J`1VIVH0HF5Q05mOG`1R
HV80KVi^061PH01YJFT0HF5Q06IVIP1RHV80J6QX06=SH`1WIfL2069RHP0@06IVIP1SHf<0JFUY05mO
G`1NGUh0IfMW05]KF`1WIfL0Hf=S06EUI@1XJ6P0GUiN05YJFP1MGEd0H61P05eMG@H0fMWI0@000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0S065QH@1TI6@0GEeM06EUI@1PH600IFEU065Q
H@1MGEd0I6AT06IVIP1YJFT0I6AT06YZJP1UIFD0J6QX06IVIP1XJ6P0IfMW06=SH`1YJFT0J6QX06YZ
JP1UIFD0IfMW06=SH`1YJFT0J6QX06EUI@1[Jf/0Hf=S06MWI`1[Jf/0IfMW06EUI@1]KFd00P1/K6`0
801_Kfl0KFe]079bLP1cLg<0K6a/06IVIP1YJFT0KVi^06a/K01fMWH0KFe]07UiN@1bLW80P82007If
MP1`L700Lg=c07EeM@1iNGT0M7Ad06m_K`1jNWX0MgMg07]kN`1nOWh0O7al07UiN@1hN7P0OWin07]k
N`1nOWh0Ogmo0P20P8003`1lO7`0OWin07QhN01mOGd0Ogmo07emO@22PX80SHf=08>3P`20P800R8R8
08N7Q`2=SHd0UiNG096AT@0208V9R@1609BDU02?Shl0Shn?08b<S02EUID0UiNG09BDU02FUYH0U9BD
09nOW`2ATI40VYZJ09bLW02VYZH0WIfM0:NWY`2VYZH0XZ:R09jNWP2ZZZX0YZJV0:RXZ02[Zj/0]KFe
0:f][@2e]KD0/K6a0;no_`2h^;P0][Jf0;>c/`2n_[h0`L710<;2`P2j^[X0`L710<S8b031`L40_[jn
0<g=c@3@d=00clo?0=cLg03Rh^80g=cL0>?Sh`3MgMd0fMWI0>CTi03Ng]h0inOW0>CTi03`l?00j>SX
0>_[j`3_knl0m?Cd0??cl`3emOD0nOWi0?ooo`3emOD0no_k0?[jnP3bl_80nOWi0?gmo@3_knl0n?Sh
0?;blP80no_k02@0moOg0?ooo`3no_h0oooo0?Shn03lo?`0n?Sh0?7al@3emOD0kno_0>WYj@3]kNd0
i^KV0>c/k03clo<0kno_0>SXj03Vi^H0kno_0>3Ph03[jn/0h^;R0=WIf@3Ng]h0g=cL0=7Ad@3Jf]X0
dM7A0<k>cP3AdM40`L710<W9b@3:b/X0a/K60;fm_@3;bl/20;Vi^@040<71`@2k^k/0][Jf0;no_`80
[Zj^01X0/[:b0;Jf]P2][Jd0YZJV0:^[Z`2WYjL0[:b/0::RXP2[Zj/0YJFU0:JVYP2KVi/0UYJF09^K
V`2EUID0UYJF09:BTP2=SHd0Shn?096AT@2IVIT0UYJF092@T02:RXX0S8b<08f=S@80R8R800L0QXJ6
08>3P`27QhL0O7al07emO@24Q8@0P8200080PH6100H0QHF50861P@21PH40O7al07UiN@1mOGd207Ee
M@0G07IfMP1gMgL0MgMg079bLP1dM7@0LW9b07=cL`1eMGD0MgMg07UiN@1fMWH0LW9b06][J`1dM7@0
MWIf06m_K`1^KVh0JVYZ075aL@1SHf<0Lg=c06YZJP1]KFd00P1/K6`05`1VIVH0K6a/06EUI@1ZJVX0
K6a/06UYJ@1ZJVX0IVIV06a/K01TI6@0K6a/06EUI@1PH600I6AT06QXJ01VIVH0JFUY05QHF01PH600
IfMW05mOG`1QHF40I6AT0080JFUY00l0J6QX061PH01QHF40GEeM06EUI@1TI6@0IFEU05aLG01PH600
G5aL06MWI`1OGel0Fe]K069RHP1PH6001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI
00<0fMWI01L0IVIV06MWI`1RHV80J6QX06IVIP1QHF40Hf=S06IVIP1WIfL0I6AT06=SH`1UIFD0KFe]
06m_K`1RHV80IFEU06UYJ@1PH600Jf][06e]K@1RHV80Jf][06=SH`0206YZJP0>06MWI`1aLG40IVIV
06ATI01XJ6P0Lg=c06a/K01UIFD0IfMW06i^KP1VIVH0Jf][07MgM`1TI6@206m_K`0907=cL`1YJFT0
LW9b06UYJ@1`L700Lg=c07QhN01dM7@0MGEe0080LG5a0100N7Qh07IfMP1eMGD0MgMg07QhN01eMGD0
MWIf07EeM@1bLW80MWIf07YjNP1hN7P0O7al07EeM@1gMgL0NWYj0P20P800101hN7P0LW9b08R8R01o
Ogl208:2PP040861P@1nOWh0QXJ607inOP80Ogmo00D0RHV908Z:RP28R8P0QXJ608^;R`0308n?S`80
SXj>02`0U9BD09FEU@2IVIT0V9RH09>CT`2KVi/0UYJF09nOW`2HV9P0WYjN0:>SX`2NWYh0Z:RX0:>S
X`2TY:@0WIfM0:JVYP2d];@0Z:RX0:f][@2b/[80/K6a0;Jf]P2a/K40^k^k0<C4a02d];@0[Zj^0<30
`02i^KT0_[jn0<71`@34a<@0aLG50<c<c039bLT0b/[:0<g=c@3@d=00fm_K0>GUi@3Hf=P0hN7Q0=GE
e@@0h^;R00l0jn_[0>WYj@3YjNT0lO7a0>g]k@3dm?@0kno_0?3`l03hn?P0mOGe0?Shn03alO40n?Sh
0??cl`3inOT00P3gmoL04`3inOT0j^[Z0?clo03dm?@0n?Sh0?KfmP3moOd0lO7a0?Ogm`3clo<0l_;b
0?3`l03bl_80i^KV0>o_k`3bl_80iNGU0>_[j`3]kNd00P3QhN401`3Ng]h0iNGU0>KViP3Ng]h0g=cL
0=SHf03:b/X00P3AdM403`3:b/X0dm?C0<o?c`33`l<0c<c<0<C4a02i^KT0_Kfm0<;2`P2j^[X0^;Rh
0;no_`30`<00_Kfm0;>c/`020;:b/P0;0:^[Z`2YZJT0[jn_0:>SX`2VYZH0VIVI0:VYZ@2VYZH0YJFU
0:2PX02NWYh00P2IVIT07P2BTY80UIFE09bLW02=SHd0WYjN08n?S`2@T900TI6A08b<S02=SHd0TI6A
092@T02:RXX0QHF508V9R@1nOWh0Q8B408^;R`24Q8@0Shn?07inOP1oOgl0P82007inOP1iNGT0Q8B4
07alO01mOGd0NWYj07UiN@80MgMg0280MGEe07UiN@1fMWH0MGEe06i^KP1gMgL0K6a/07IfMP1jNWX0
JVYZ06i^KP1fMWH0M7Ad06i^KP1iNGT0KFe]07=cL`1`L700I6AT06][J`1RHV80KVi^06YZJP1bLW80
MgMg06][J`1XJ6P0JFUY071`L01/K6`0KFe]06IVIP1/K6`0IfMW0P1UIFD01`1YJFT0IFEU065QH@1W
IfL0HV9R06QXJ01VIVH00P1TI6@2061PH00306IVIP1PH600HV9R0080HV9R00L0HF5Q05]KF`1UIFD0
GEeM06IVIP1IFET0IVIV0080GUiN00@0HV9R05YJFP1MGEd0Fe]K1P3IfMT100000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI00<0J6QX061PH01TI6@00P1TI6@08@1XJ6P0HF5Q06ATI01[Jf/0
HV9R06QXJ01UIFD0IfMW06m_K`1YJFT0IFEU05mOG`1PH600IVIV06MWI`1UIFD0I6AT06EUI@1YJFT0
IfMW06i^KP1`L700IfMW06m_K`1]KFd0JFUY06a/K01XJ6P0JVYZ06a/K01`L700LG5a06m_K`0206i^
KP0?06YZJP1WIfL0L71`06MWI`1^KVh0N7Qh071`L01]KFd0MWIf07EeM@1cLg<0OGem07AdM01`L700
LW9b0080MgMg00d0MGEe07MgM`1gMgL0KFe]07MgM`1bLW80M7Ad08B4Q01eMGD0O7al07EeM@1oOgl0
O7al0080Ng]k00/0OGem07alO023Ph<0Q8B408F5Q@26QXH0P82007alO029RHT0QHF508R8R00208V9
R@80RXZ:00d0SXj>09RHV02=SHd0R8R8092@T02?Shl0T92@09NGU`2DU9@0Shn?09^KV`2HV9P0XZ:R
0080WYjN00l0Xj>S09nOW`2SXj<0Y:BT0:6QX@2ZZZX0YZJV0:^[Z`2ZZZX0[Zj^0;Vi^@2a/K40][Jf
0;Vi^@2d];@00P2j^[X05`2^[Zh0];Bd0<;2`P2j^[X0`/;20<_;b`2l_;`0bLW90<G5a@37alL0c<c<
0=;BdP3AdM40e]KF0=cLg03Bd]80dM7A0=[JfP3Ph>00gMgM0>7Qh@3WinL0gmoO00<0i^KV01`0j>SX
0>g]k@3`l?00kno_0>OWi`3_knl0k^k^0?KfmP3Xj>P0m?Cd0?7al@3^k^h0kno_0?Cdm03Zj^X0lO7a
0?Shn03_knl0l?3`0>o_k`3^k^h0mOGe0>c/k03Zj^X0j>SX0??cl`3Shn<0j^[Z0P3Ti>@04P3GemL0
iNGU0>?Sh`3WinL0f=SH0>;RhP3De=@0g]kN0=;BdP3Cdm<0dM7A0<[:bP2o_kl0cLg=0<[:bP3AdM40
c<c<0;jn_P80`l?302L0/k>c0;^k^`2h^;P0/K6a0;>c/`2f][H0]kNg0:RXZ02/[:`0ZJVY0:b/[02Q
XJ40Y:BT0:FUY@2ZZZX0YZJV0:>SX`2TY:@0UYJF09VIV@2LW9`0TY:B09NGU`2ATI40Vi^K09VIV@2D
U9@0Shn?096AT@2HV9P0T92@08^;R`2>SXh0S8b<08f=S@2;Rh/0SHf=08:2PP27QhL00P23Ph<08P22
PX80P82008:2PP1nOWh0QXJ607]kN`21PH40Ogmo07emO@1hN7P0MWIf079bLP1nOWh0OGem07YjNP1d
M7@0MWIf07MgM`1bLW80KVi^07=cL`1aLG40L71`06YZJP1cLg<0JVYZ06i^KP1aLG40JFUY075aL@1_
Kfl0KVi^06][J`1]KFd206a/K00G06EUI@1VIVH0Jf][05mOG`1^KVh0K6a/06IVIP1ZJVX0KFe]079b
LP1UIFD0JVYZ06EUI@1OGel0IfMW06EUI@1PH600GUiN061PH01RHV80Hf=S05iNGP1QHF400P1RHV80
4@1QHF40Hf=S05mOG`1VIVH0HF5Q069RHP1NGUh0H61P065QH@1SHf<0H61P05YJFP1MGEd0IVIV06=S
H`1TI6@0Fe]K00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0L06EUI@1S
Hf<0JVYZ06QXJ01UIFD0Jf][06EUI@1XJ6P0HF5Q06MWI`1XJ6P0IVIV06a/K01VIVH0Hf=S06ATI01[
Jf/0IfMW06ATI01[Jf/0HV9R06MWI`1NGUh0K6a/05mOG`1^KVh0JFUY06a/K080IVIV01d0I6AT06e]
K@1WIfL0Kfm_06IVIP1TI6@0LG5a06m_K`1[Jf/0KVi^071`L01UIFD0JFUY06MWI`1cLg<0J6QX06i^
KP1fMWH0Kfm_06][J`1hN7P0MWIf075aL@1`L700MGEe07YjNP1gMgL0K6a/07=cL`02079bLP0V07Ui
N@1cLg<0MWIf07UiN@1nOWh0MgMg07QhN025QHD0NGUi07alO01nOWh0OGem07UiN@21PH40Q8B408>3
P`26QXH0RHV908>3P`21PH40RHV908J6QP24Q8@0QhN708n?S`2>SXh0QXJ609ZJVP2BTY80SXj>08Z:
RP2DU9@0UiNG09VIV@2DU9@0UiNG09RHV02FUYH209jNWP0;09RHV02NWYh0YJFU0:6QX@2JVYX0YJFU
09ZJVP2QXJ40Y:BT0:^[Z`2TY:@00P2VYZH0302`/;00[jn_0;Bd]02d];@0^[Zj0;Rh^02n_[h0]KFe
0<30`036a/H0^k^k0<O7a`80a<C401@0`l?30<[:bP39bLT0bl_;0<k>cP3Bd]80d=3@0=7Ad@3Jf]X0
d=3@0=SHf03Cdm<0gMgM0>CTi03Rh^80hn?S0=oOg`3Ti>@0k>c/0>3Ph080j^[Z0140i>CT0>GUi@3X
j>P0m?Cd0>g]k@3YjNT0lo?c0>_[j`3Ti>@0j>SX0>OWi`3Vi^H0kno_0>g]k@3alO40iNGU0?3`l002
0>OWi`060>3Ph03Zj^X0h^;R0>[ZjP3Ti>@0i^KV0P3Shn<0103Ogml0e]KF0=gMg@3Jf]X20=CDe007
0<g=c@3Bd]80cLg=0<_;b`39bLT0b<S80<G5a@020<30`00Z0<C4a02i^KT0];Bd0;Jf]P2h^;P0/;2`
0;Bd]02^[Zh0/K6a0;>c/`2a/K40/;2`0:b/[02YZJT0ZZZZ0:JVYP2LW9`0Vi^K09jNWP2SXj<0X:2P
09VIV@2LW9`0UiNG096AT@2@T900Vi^K08Z:RP2BTY80UYJF092@T02:RXX0TI6A08Z:RP2=SHd0Shn?
08b<S02BTY80QHF508^;R`27QhL0SHf=0P23Ph<04028R8P0O7al0861P@2:RXX0Ph>307moO`1hN7P0
MgMg08F5Q@1iNGT0P82007MgM`1cLg<0M7Ad07]kN`1dM7@207=cL`0<079bLP1gMgL0Kfm_071`L01c
Lg<0J6QX07QhN01_Kfl0LG5a06MWI`1`L700LW9b0P1YJFT03@1ZJVX0KFe]06a/K01RHV80K6a/06AT
I01VIVH0JVYZ06QXJ01PH600Hf=S06i^KP1]KFd00P1XJ6P02`1OGel0JFUY069RHP1XJ6P0IVIV069R
HP1QHF40Hf=S06e]K@1PH600JVYZ0080Hf=S00<0IFEU065QH@1TI6@00P1RHV803@1OGel0IFEU06AT
I01VIVH0HV9R065QH@1WIfL0KFe]05eMG@1QHF40EUIF05aLG01NGUh01P3IfMT100000040fMWI000F
0=WIf@800000103IfMT0201RHV80FUYJ069RHP1TI6@0IfMW06QXJ01QHF40J6QX0P1YJFT0;01ZJVX0
JFUY06MWI`1/K6`0JFUY06ATI01]KFd0KVi^06MWI`1YJFT0IFEU06UYJ@1[Jf/0IVIV06UYJ@1WIfL0
I6AT06i^KP1TI6@0Kfm_06EUI@1[Jf/0J6QX06YZJP1aLG40KFe]075aL@1`L700MGEe07YjNP1^KVh0
JVYZ07EeM@1^KVh0M7Ad079bLP1gMgL0MWIf06i^KP1nOWh0M7Ad06a/K01dM7@0Lg=c0P1_Kfl06P1f
MWH0N7Qh07EeM@1lO7`0MWIf079bLP1jNWX0M7Ad07MgM`1dM7@0LW9b07MgM`1oOgl0MGEe07inOP1i
NGT0O7al07emO@1hN7P0Q8B40820P024Q8@0QXJ608f=S@20P800Q8B40P28R8P02P23Ph<0Rh^;09NG
U`2<S8`0R8R808n?S`2FUYH0SXj>09FEU@2@T90209RHV00g096AT@2DU9@0UIFE08j>SP2OWil0VYZJ
09fMW@2HV9P0VYZJ0:6QX@2VYZH0XZ:R0:JVYP2SXj<0/[:b0:b/[02a/K40ZZZZ0:n_[`2c/k<0]KFe
0;Ng]`2i^KT0^;Rh0<71`@2g]kL0`l?30;no_`2h^;P0^[Zj0;no_`2l_;`0^KVi0<W9b@37alL0b/[:
0<o?c`3AdM40alO70<c<c03;bl/0c/k>0=cLg03EeMD0e]KF0>;RhP3Ng]h0emOG0>;RhP3Ti>@0jn_[
0>;RhP3Shn<0i^KV0>OWi`020>GUi@080>c/k03_knl0hn?S0=cLg03/k>`0inOW0>WYj@3_knl20>GU
i@0S0>WYj@3Vi^H0jn_[0>CTi03Shn<0h^;R0>c/k03Ng]h0j^[Z0=kNgP3Shn<0g]kN0=OGe`3Ogml0
eMGE0=CDe03@d=00eMGE0=?Cd`31`L40cLg=0<o?c`37alL0b/[:0<G5a@3<c<`0a<C40<71`@2m_Kd0
^k^k0;Rh^02l_;`0][Jf0;Vi^@2`/;000`2a/K403`2][Jd0[:b/0:f][@2WYjL0[Jf]0:RXZ02SXj<0
WYjN0:BTY02XZ:P0XZ:R09jNWP2SXj<0U9BD09RHV00209>CT`0508n?S`2ATI40T92@08>3P`2BTY80
0P29RHT0202>SXh0QHF508f=S@2>SXh0Shn?08J6QP2;Rh/0QXJ60P25QHD05@1jNWX0QXJ608B4Q025
QHD0NGUi0820P023Ph<0Ogmo0820P01jNWX0OWin07UiN@1lO7`0OWin07AdM01gMgL0Lg=c06m_K`1b
LW80Kfm_07EeM@0306m_K`0;07MgM`1^KVh0KVi^06e]K@1/K6`0JVYZ06MWI`1YJFT0K6a/06m_K`1X
J6P00`1ZJVX0401[Jf/0KVi^06QXJ01UIFD0JVYZ06a/K01YJFT0KFe]06EUI@1/K6`0IFEU06UYJ@1V
IVH0Hf=S06QXJ01PH60206IVIP0>069RHP1QHF40IFEU069RHP1UIFD0HV9R06ATI01QHF40J6QX061P
H01QHF40IFEU05mOG`1VIVH2065QH@0705]KF`1PH600IFEU05YJFP1SHf<0GemO065QH@050=WIf@80
00000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT08@1UIFD0GUiN05mOG`1WIfL0Hf=S06EU
I@1VIVH0GUiN06MWI`1VIVH0J6QX06a/K01[Jf/0IfMW065QH@1WIfL0JFUY06EUI@1TI6@0IFEU06e]
K@1QHF40JVYZ06e]K@1XJ6P0Hf=S071`L01/K6`0LG5a06][J`1WIfL0J6QX06e]K@0206QXJ00:06][
J`1YJFT0KFe]07=cL`1_Kfl0MGEe06m_K`1/K6`0L71`075aL@80M7Ad0P1bLW803`1^KVh0LG5a079b
LP1/K6`0Kfm_075aL@1^KVh0MGEe06m_K`1fMWH0LG5a07IfMP1eMGD0MWIf07EeM@0207alO080OGem
00P0Ng]k07EeM@1gMgL0MgMg07alO020P800PH6107alO080P82002L0Q8B408F5Q@25QHD0QXJ6096A
T@2?Shl0SHf=08j>SP29RHT0TI6A08j>SP2:RXX0TY:B08f=S@2ATI40UiNG09BDU02@T900Ti>C09FE
U@2FUYH0V9RH09:BTP2CTi<0Y:BT0::RXP2PX:00XJ6Q09FEU@2JVYX0XZ:R0:6QX@2VYZH0YjNW0::R
XP2ZZZX0/K6a0;Vi^@2g]kL00P2a/K402P2j^[X0]kNg0;Bd]02l_;`0_Kfm0;Rh^02j^[X0_Kfm0<;2
`P2g]kL20<;2`P070<C4a035aLD0b<S80=3@d03:b/X0c/k>0=SHf0020=KFeP0=0=3@d03Kfm/0gMgM
0=[JfP3?cll0eMGE0=SHf03QhN40i>CT0=_Kf`3QhN40gmoO0>SXj0020>GUi@0V0=kNgP3Ogml0inOW
0>CTi03UiND0j>SX0=kNgP3QhN40j>SX0=gMg@3UiND0j>SX0>GUi@3Shn<0emOG0>;RhP3Hf=P0emOG
0=kNgP3Hf=P0eMGE0=WIf@3:b/X0d];B0=?Cd`3De=@0cLg=0<[:bP36a/H0c<c<0<O7a`2l_;`0`<30
0;no_`2n_[h0`/;20;bl_035aLD20;jn_P0;0;>c/`2`/;00[jn_0;>c/`2/[:`0[jn_0;6a/@2][Jd0
YjNW0:VYZ@2VYZH00P2TY:@07P2MWId0YJFU09nOW`2SXj<0UYJF09ZJVP2HV9P0Ti>C09fMW@2NWYh0
T92@08f=S@2EUID0RXZ:08R8R02@T900V9RH092@T026QXH0R8R808Z:RP27QhL0S8b<0861P@1nOWh0
R8R80820P022PX80P82008:2PP<0Ogmo02L0Ng]k07moO`1kNg/0NWYj071`L01bLW80NGUi07EeM@1o
Ogl0NWYj06UYJ@1fMWH0K6a/06YZJP1iNGT0N7Qh06e]K@1^KVh0LG5a06YZJP1WIfL0KFe]06][J`1Z
JVX0KFe]06YZJP1]KFd0L71`06e]K@1YJFT0K6a/06ATI01YJFT0KFe]06m_K`1YJFT0J6QX06EUI@1X
J6P00P1YJFT0601^KVh0IVIV06IVIP1PH600Hf=S06EUI@1SHf<0HF5Q06UYJ@1TI6@0HV9R06MWI`1V
IVH0GemO069RHP1ZJVX0H61P05YJFP1KFe/0JFUY05YJFP1SHf<0H61P069RHP@0Hf=S00@0FUYJ05mO
G`1TI6@0GEeM1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00X0HF5Q05aL
G01YJFT0I6AT05]KF`1VIVH0Hf=S06ATI01ZJVX0I6AT0P1RHV800`1VIVH0HV9R06IVIP0206YZJP03
069RHP1SHf<0IfMW0080IfMW02<0JFUY06YZJP1UIFD0K6a/06IVIP1/K6`0IFEU06i^KP1ZJVX0KVi^
06][J`1`L700KFe]06QXJ01]KFd0K6a/06e]K@1XJ6P0Kfm_06a/K01TI6@0KVi^06e]K@1XJ6P0L71`
06UYJ@1gMgL0LW9b07MgM`1]KFd0JFUY07IfMP1aLG40MGEe071`L00207IfMP0306m_K`1gMgL0Lg=c
0080MgMg00P0OGem07EeM@1jNWX0MgMg07alO01mOGd0Ng]k07UiN@80Ng]k01l0R8R808B4Q020P800
P82007inOP21PH40Q8B408J6QP28R8P0RHV908n?S`21PH40T92@08J6QP2ATI40S8b<08f=S@2?Shl0
S8b<09:BTP2FUYH0UIFE09JFUP2?Shl0U9BD09VIV@2CTi<0UiNG09fMW@2PX:00XZ:R0080WinO00L0
XZ:R0:BTY02WYjL0XZ:R0:f][@2XZ:P0ZJVY0080[Jf]00X0/;2`0;6a/@2c/k<0[jn_0;Zj^P2a/K40
`<300;Jf]P2g]kL0/k>c0P2j^[X00`2k^k/0_[jn0;Zj^P020;fm_@0?0;^k^`33`l<0aLG50<G5a@38
b<P0dM7A0=;BdP3?cll0eMGE0=[JfP3Hf=P0eMGE0=OGe`3AdM40d=3@0080eMGE01l0emOG0=CDe03F
e]H0fm_K0>?Sh`3Hf=P0h^;R0>CTi03Kfm/0hn?S0=kNgP3IfMT0f][J0>3Ph03EeMD0e]KF0=?Cd`3R
h^80g=cL0=SHf03Fe]H0f=SH0=GEe@3@d=00emOG0<g=c@3;bl/0dM7A0<c<c03?cll0`L7100<0alO7
0180`/;20<?3``2j^[X0aLG50;Ng]`2n_[h0^;Rh0;>c/`32`/80]KFe0;6a/@2f][H0/K6a0;2`/02/
[:`0[jn_0;:b/P2][Jd20:BTY0030:f][@2UYJD0Y:BT0080YJFU01L0WYjN09ZJVP2DU9@0XZ:R09fM
W@2EUID0U9BD08n?S`2GUiL0U9BD08f=S@29RHT0T92@08n?S`2>SXh0QhN708f=S@22PX80QXJ607in
OP24Q8@0PX:208J6QP020861P@0@08R8R01nOWh0Ogmo07emO@1kNg/0Ph>307moO`23Ph<0OGem07Qh
N01cLg<0O7al07IfMP1lO7`0MGEe07IfMP80L71`0140M7Ad07=cL`1lO7`0MGEe079bLP1/K6`0L71`
07AdM01]KFd0JVYZ06EUI@1[Jf/0K6a/07=cL`1/K6`0JFUY06MWI`0206UYJ@0B06=SH`1RHV80GUiN
06YZJP1WIfL0IVIV06=SH`1ZJVX0IFEU06MWI`1XJ6P0I6AT06UYJ@1NGUh0IFEU07AdM01RHV80KFe]
0P1VIVH05`1QHF40HV9R06EUI@1VIVH0J6QX06UYJ@1RHV80G5aL06IVIP1UIFD0H61P06ATI01NGUh0
IVIV05QHF01NGUh0H61P05eMG@1SHf<0Fe]K05mOG`1JFUX0H61P00H0fMWI0@0000010=WIf@005P3I
fMT00`000000fMWI0=WIf@030=WIf@0406QXJ01WIfL0Jf][069RHP80JFUY00L0I6AT061PH01WIfL0
G5aL06IVIP1TI6@0IfMW0080I6AT02`0IfMW06YZJP1PH600Jf][069RHP1YJFT0HF5Q06QXJ01SHf<0
IFEU071`L01YJFT0IVIV06QXJ01VIVH0LG5a06i^KP1[Jf/0K6a/06IVIP1_Kfl0K6a/06m_K`1WIfL0
K6a/06i^KP1/K6`0JVYZ071`L01[Jf/0Lg=c07QhN01/K6`0Kfm_071`L01aLG40MWIf06m_K`1^KVh0
M7Ad075aL@1eMGD0MWIf07MgM`80N7Qh0100Ogmo07EeM@1hN7P0N7Qh07alO01iNGT0Ng]k07emO@1h
N7P0Ph>307emO@1jNWX0PX:20820P026QXH0NWYj0P22PX806@25QHD0Q8B40861P@25QHD0RHV908F5
Q@2?Shl0R8R808f=S@2CTi<0S8b<09BDU02?Shl0U9BD08n?S`2;Rh/0UIFE09:BTP2CTi<0V9RH08f=
S@2BTY80VIVI0:6QX@2JVYX00P2TY:@01@2MWId0X:2P0:RXZ02UYJD0Y:BT0080XJ6Q04T0];Bd0:^[
Z`2b/[80/[:b0;Jf]P2][Jd0/;2`0:j^[P2i^KT0/k>c0;fm_@2k^k/0]kNg0;Rh^02o_kl0]KFe0;jn
_P32`/80^k^k0;jn_P33`l<0`<300<W9b@36a/H0alO70<[:bP3=cLd0eMGE0<c<c03Cdm<0e=CD0<g=
c@3De=@0h>3P0=_Kf`3Fe]H0e=CD0=WIf@3Lg=`0eMGE0>7Qh@3Jf]X0hN7Q0=WIf@3MgMd0fMWI0=oO
g`3MgMd0eMGE0=cLg03De=@0f][J0=oOg`3Jf]X0e=CD0<o?c`3GemL0dm?C0<_;b`3EeMD0fm_K0<g=
c@3@d=00c/k>0<c<c038b<P0bl_;0<[:bP32`/80a/K60;jn_P30`<00^k^k0080_Kfm00@0a/K60;jn
_P2j^[X0`L710P2j^[X03@2^[Zh0/k>c0;Ng]`2XZ:P0ZZZZ0:VYZ@2SXj<0YjNW0:VYZ@2VYZH0Zj^[
0:NWY`2SXj<00P2PX:004@2IVIT0XZ:R09NGU`2DU9@0UiNG09ZJVP2GUiL0Ti>C09:BTP26QXH0TY:B
08Z:RP2DU9@0QHF508N7Q`2;Rh/0S8b<0080PH6100d0R8R808n?S`27QhL0QXJ608R8R021PH40Q8B4
07emO@1jNWX0OWin07YjNP1eMGD0P8200080O7al0280N7Qh08>3P`1eMGD0M7Ad07alO01oOgl0NWYj
06i^KP1gMgL0OGem06YZJP1hN7P0MGEe06a/K01^KVh0LW9b07AdM01_Kfl0LG5a071`L01]KFd0Jf][
06ATI01aLG40KFe]075aL@1UIFD0Jf][06IVIP1dM7@0JVYZ06QXJ01YJFT0JVYZ0P1YJFT00`1XJ6P0
JFUY06IVIP0206UYJ@80IFEU01D0IfMW06UYJ@1VIVH0J6QX06e]K@1WIfL0K6a/061PH01VIVH0HV9R
06MWI`1]KFd0IfMW06IVIP1PH600GemO069RHP1SHf<0GEeM069RHP1WIfL00P1QHF400`1UIFD0F5QH
061PH00205QHF0H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0>06ATI01X
J6P0I6AT06IVIP1RHV80J6QX06EUI@1WIfL0HV9R06=SH`1VIVH0IfMW06YZJP1SHf<206MWI`80JFUY
00<0Hf=S06][J`1VIVH00`1VIVH03`1WIfL0H61P06e]K@1RHV80IfMW06UYJ@1VIVH0K6a/06UYJ@1V
IVH0IfMW06i^KP1XJ6P0IfMW06e]K@02075aL@09079bLP1/K6`0JVYZ06m_K`1^KVh0IVIV06YZJP1Y
JFT0IVIV0080Lg=c0P1bLW804P1hN7P0JVYZ07AdM01`L700M7Ad07UiN@1lO7`0MWIf07YjNP1dM7@0
O7al071`L01fMWH0LW9b07QhN01mOGd0N7Qh08:2PP80O7al00X0QHF507YjNP1mOGd0PX:208V9R@23
Ph<0Q8B408R8R024Q8@0QXJ60P28R8P00`2:RXX0Shn?08Z:RP0208j>SP0b09RHV02=SHd0SXj>09>C
T`2?Shl0SXj>096AT@2>SXh0TI6A09>CT`2HV9P0UiNG09jNWP2OWil0WYjN0:NWY`2PX:00WinO0:f]
[@2UYJD0XZ:R0:^[Z`2JVYX0ZJVY0:NWY`2[Zj/0ZZZZ0:f][@2_[jl0]kNg0:n_[`2c/k<0^;Rh0;Bd
]02g]kL0^[Zj0;^k^`2^[Zh0^;Rh0<?3``2h^;P0_Kfm0;^k^`34a<@0aLG50<S8b02k^k/0`L710<_;
b`3Bd]820<W9b@0?0<c<c03De=@0d];B0=7Ad@3=cLd0c<c<0=CDe03?cll0emOG0=GEe@3@d=00dm?C
0=_Kf`3Bd]80emOG0080eMGE00P0dm?C0=7Ad@3IfMT0dM7A0=CDe03Hf=P0d=3@0<g=c@80d];B00/0
eMGE0<W9b@38b<P0b/[:0=3@d03Fe]H0d=3@0<_;b`38b<P0_Kfm0;no_`020<?3``0E0;^k^`2o_kl0
^[Zj0<30`02f][H0_;bl0;Rh^02g]kL0/k>c0;Fe]@2j^[X0YJFU0:ZZZP2j^[X0Zj^[0:NWY`2_[jl0
ZZZZ0:6QX@2PX:00Xj>S0080YjNW00L0YZJV0::RXP2WYjL0VYZJ09bLW02ATI40VIVI0080T92@0200
SXj>092@T02=SHd0TY:B09JFUP2@T900Shn?08:2PP2:RXX0QHF508f=S@2>SXh0PX:208j>SP23Ph<0
QHF508>3P`22PX80P82008F5Q@20P800Ogmo0820P01oOgl0NWYj0820P01jNWX0LW9b07EeM@1iNGT0
LW9b07]kN`80O7al01H0M7Ad06m_K`1iNGT0M7Ad07UiN@1gMgL0LG5a07EeM@1_Kfl0KFe]06i^KP1X
J6P0L71`06a/K01YJFT0M7Ad06a/K01XJ6P0JFUY07=cL`1YJFT0Jf][0P1SHf<0301WIfL0JVYZ06e]
K@1XJ6P0IfMW06YZJP1WIfL0I6AT06IVIP1[Jf/0Hf=S06ATI080IFEU00D0IfMW06YZJP1TI6@0IVIV
06EUI@02069RHP0706UYJ@1SHf<0JFUY061PH01WIfL0Hf=S061PH002065QH@0;061PH01OGel0HF5Q
05aLG01QHF40GEeM05iNGP1QHF40H61P05QHF01OGel01P3IfMT100000040fMWI000F0=WIf@030000
003IfMT0fMWI00<0fMWI00X0IVIV06=SH`1XJ6P0IfMW06=SH`1RHV80IVIV06ATI01VIVH0Hf=S0P1Z
JVX00`1SHf<0JFUY06=SH`02069RHP0506UYJ@1[Jf/0JFUY06IVIP1OGel00P1VIVH00`1UIFD0IfMW
06a/K00206UYJ@0406][J`1YJFT0K6a/06QXJ080JVYZ00/0LG5a06YZJP1YJFT0LW9b06e]K@1[Jf/0
Lg=c075aL@1cLg<0KFe]075aL@0206m_K`0E075aL@1iNGT0JVYZ06e]K@1aLG40N7Qh07IfMP1dM7@0
MGEe071`L01fMWH0P82007=cL`1fMWH0NWYj07EeM@1dM7@0MgMg07YjNP1mOGd0NGUi0080MWIf00L0
P82007YjNP1lO7`0NWYj08>3P`21PH40PX:20080Q8B40140R8R807inOP1oOgl0PH6108B4Q026QXH0
RXZ:08>3P`2=SHd0RHV908f=S@28R8P0Rh^;08V9R@2>SXh0Rh^;09BDU002096AT@0K08Z:RP2IVIT0
T92@09BDU02GUiL0WIfM0:6QX@2GUiL0Vi^K0:2PX02HV9P0Zj^[09bLW02NWYh0YjNW0:FUY@2YZJT0
YJFU0:ZZZP2UYJD0ZZZZ0;>c/`2^[Zh0[Jf]0;Ng]`2`/;00/[:b0080^;Rh01D0[Zj^0;Jf]P2f][H0
_;bl0;fm_@2l_;`0_[jn0;no_`34a<@0alO70<_;b`33`l<0c<c<0=7Ad@3>c/h0d=3@0<o?c`3:b/X0
a/K60<k>cP3Bd]800P3?cll00`3AdM40d];B0=7Ad@030=;BdP080=_Kf`3Cdm<0f][J0=CDe03MgMd0
bl_;0=7Ad@3?cll20=GEe@80b/[:00P0c<c<0=;BdP3Cdm<0a/K60<k>cP3:b/X0b<S80<c<c080alO7
0140b<S80<30`03:b/X0alO70;no_`2m_Kd0^k^k0;fm_@2e]KD0_Kfm0<W9b@2g]kL0][Jf0;^k^`2Y
ZJT0];Bd0;2`/0020:ZZZP070:RXZ02ZZZX0YZJV0:JVYP2TY:@0XZ:R0:>SX`020:FUY@0F0:6QX@2Z
ZZX0WYjN09JFUP2EUID0W9bL09BDU02MWId0R8R809RHV029RHT0RXZ:08j>SP2?Shl0Ti>C08:2PP2?
Shl0Rh^;08f=S@2ATI40QHF508R8R080PH6101X0R8R808F5Q@1lO7`0PX:208J6QP2;Rh/0Ph>307em
O@1kNg/0O7al07YjNP1iNGT0O7al07AdM01mOGd0L71`07alO01hN7P0O7al07IfMP1eMGD0M7Ad06i^
KP1aLG40KVi^06QXJ080LW9b00T0Lg=c06][J`1]KFd0Kfm_069RHP1]KFd0KVi^075aL@1]KFd00P1W
IfL01`1UIFD0JFUY06EUI@1]KFd0J6QX06EUI@1VIVH00P1XJ6P0301NGUh0I6AT065QH@1YJFT0HF5Q
069RHP1SHf<0IFEU06=SH`1PH600Hf=S06EUI@<0GemO01@0I6AT065QH@1UIFD0IFEU065QH@1OGel0
HF5Q05aLG01TI6@0IFEU06IVIP1YJFT0IFEU069RHP1TI6@0IFEU06=SH`1MGEd0IFEU065QH@H0fMWI
0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0K06MWI`1ZJVX0KFe]05iNGP1VIVH0
KFe]06YZJP1WIfL0IVIV06=SH`1PH600IfMW06=SH`1QHF40KVi^06][J`1ZJVX0KFe]06MWI`1YJFT0
GemO06MWI`1YJFT0LG5a06MWI`1TI6@0H61P0080JVYZ01D0J6QX06i^KP1`L700JVYZ06][J`1`L700
KVi^06][J`1_Kfl0Jf][06a/K01_Kfl0K6a/06m_K`1^KVh0M7Ad06YZJP1bLW80L71`06e]K@1bLW80
0P1]KFd01`1bLW80M7Ad07IfMP1dM7@0KVi^07AdM01eMGD00P1kNg/0601cLg<0NWYj06a/K01iNGT0
MGEe07moO`21PH40O7al07]kN`1fMWH0Ogmo07alO01jNWX0OWin07IfMP1kNg/0QhN70820P01kNg/0
Rh^;08Z:RP24Q8@0Ogmo08N7Q`80PH6100X0QXJ608V9R@2:RXX0Shn?08R8R029RHT0SXj>096AT@2?
Shl0RHV90P2EUID0102JVYX0WIfM096AT@2HV9P209^KV`0>09jNWP2SXj<0UYJF09RHV02PX:00YjNW
0:2PX02XZ:P0XJ6Q0:FUY@2MWId0YZJV0:VYZ@2/[:`20:^[Z`030:f][@2/[:`0[jn_0080[Jf]0180
];Bd0;2`/02i^KT0];Bd0;bl_02e]KD0^[Zj0<71`@30`<00_Kfm0<C4a030`<00_[jn0<C4a033`l<0
`L710<[:bP35aLD20<k>cP0>0<[:bP3>c/h0b<S80<W9b@3AdM40b<S80<O7a`3?cll0aLG50<_;b`36
a/H0eMGE0<g=c@3Cdm<20<k>cP0@0=CDe03;bl/0clo?0<k>cP3<c<`0clo?0<[:bP34a<@0a/K60<W9
b@37alL0c<c<0<S8b035aLD0_[jn0<30`080alO700T0a<C40<71`@36a/H0^KVi0<C4a02i^KT0^;Rh
0;Jf]P2g]kL00P2e]KD0<`2d];@0/;2`0:n_[`2e]KD0[:b/0:RXZ02UYJD0[jn_09VIV@2QXJ40YJFU
09jNWP2WYjL0Vi^K0:>SX`2KVi/0WinO09bLW02JVYX0UYJF09:BTP28R8P0UYJF09ZJVP2?Shl0S8b<
09:BTP29RHT0TI6A08j>SP2=SHd0SXj>08R8R025QHD0QhN708B4Q02<S8`0RXZ:08N7Q`1oOgl0Ng]k
08J6QP1oOgl0Q8B407alO028R8P0OGem0861P@1mOGd0O7al07IfMP0207AdM00]07UiN@1nOWh0Ng]k
07EeM@1gMgL0OWin075aL@1fMWH0M7Ad07MgM`1`L700M7Ad07EeM@1aLG40Kfm_06YZJP1`L700KFe]
06QXJ01TI6@0HV9R07EeM@1^KVh0IFEU06m_K`1VIVH0IfMW061PH01RHV80Jf][06a/K01UIFD0J6QX
06MWI`1QHF40IfMW06IVIP1QHF40Hf=S065QH@1^KVh0IVIV061PH01NGUh0GemO0080IVIV00@0IFEU
06QXJ01UIFD0G5aL0P1TI6@01`1PH600JFUY061PH01SHf<0HF5Q061PH01WIfL00P1OGel0201RHV80
FEUI061PH01RHV80F5QH05mOG`1NGUh0FEUI1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0
fMWI00<0fMWI00L0L71`06UYJ@1YJFT0IFEU06=SH`1VIVH0JVYZ0080HF5Q00<0IFEU06=SH`1VIVH0
0P1YJFT306IVIP0:065QH@1ZJVX0I6AT065QH@1WIfL0KFe]061PH01SHf<0J6QX071`L080IfMW02X0
JFUY06EUI@1WIfL0H61P06QXJ01ZJVX0Lg=c06m_K`1dM7@0LW9b06a/K01YJFT0Kfm_06e]K@1aLG40
Jf][06m_K`1/K6`0KFe]07MgM`1aLG40JVYZ06a/K01cLg<0M7Ad06i^KP1bLW80LG5a06e]K@1`L700
LW9b07]kN`1eMGD0MWIf07alO01eMGD0M7Ad07UiN@1nOWh0OGem07UiN@1lO7`208:2PP0E08>3P`1o
Ogl0PH6107YjNP1oOgl0Ng]k08N7Q`29RHT0Ph>308F5Q@28R8P0PX:208^;R`22PX80QHF508j>SP22
PX80SHf=08Z:RP2CTi<0PX:20080SHf=00l0SXj>096AT@2FUYH0TY:B09FEU@2LW9`0UiNG09ZJVP2L
W9`0Ti>C0::RXP2OWil0TY:B09jNWP2PX:000P2QXJ401@2OWil0Xj>S0:BTY02_[jl0YJFU0080Zj^[
01`0ZJVY0:ZZZP2a/K40[jn_0:ZZZP2c/k<0]KFe0:j^[P2a/K40_;bl0;Rh^02k^k/0_;bl0;Rh^036
a/H0][Jf0;^k^`2o_kl0`L710;no_`32`/80_kno0;bl_02n_[h0_Kfm0<c<c039bLT0a/K60P3:b/X0
4@36a/H0cLg=0<_;b`3?cll0d=3@0<W9b@3=cLd0b/[:0<O7a`3;bl/0clo?0<k>cP37alL0b<S80=CD
e037alL0dm?C0080a/K600T0b<S80<G5a@2o_kl0b/[:0<K6aP39bLT0`l?30<O7a`31`L400P33`l<0
9`2j^[X0_[jn0;Jf]P2m_Kd0alO70;bl_02i^KT0^k^k0;Jf]P2c/k<0Zj^[0;Zj^P2YZJT0/k>c0:JV
YP2ZZZX0XJ6Q0:f][@2KVi/0YZJV09bLW02VYZH0YjNW0:FUY@2KVi/0Z:RX09RHV02PX:00W9bL09RH
V02EUID0UYJF096AT@2=SHd0TI6A09NGU`2BTY80UYJF096AT@0208Z:RP0908f=S@26QXH0QXJ608R8
R02;Rh/0P82008R8R026QXH0Q8B40080QXJ60140Ng]k08N7Q`23Ph<0N7Qh07YjNP25QHD0P82007Yj
NP1mOGd0MWIf07YjNP1bLW80NGUi07IfMP1hN7P0MgMg07=cL`0207AdM00R07UiN@1eMGD0LW9b079b
LP1cLg<0L71`075aL@1VIVH0KFe]07MgM`1[Jf/0KFe]06QXJ01UIFD0Jf][06MWI`1_Kfl0IFEU075a
L@1[Jf/0KFe]06ATI01WIfL0GemO05iNGP1[Jf/0HF5Q06ATI01WIfL0HV9R06=SH`1LG5`0HF5Q06AT
I080Hf=S00@0HV9R06ATI01XJ6P0FEUI0P1QHF405@1/K6`0H61P06][J`1RHV80J6QX065QH@1PH600
I6AT05MGE`1SHf<0H61P065QH@1/K6`0Hf=S069RHP1SHf<0Fe]K05QHF01CDe<0GEeM05iNGP060=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT00`1dM7@0K6a/06MWI`02069RHP0C
06EUI@1MGEd0IVIV06IVIP1NGUh0G5aL06EUI@1YJFT0GEeM06QXJ01TI6@0IVIV06MWI`1[Jf/0GUiN
06YZJP1/K6`0IfMW05mOG`0206EUI@0<06QXJ01WIfL0Hf=S06ATI01YJFT0L71`06a/K01ZJVX0KVi^
06a/K01TI6@0KFe]0P1bLW806@1aLG40L71`06i^KP1VIVH0KVi^075aL@1eMGD0M7Ad06a/K01eMGD0
Kfm_071`L01_Kfl0M7Ad06i^KP1gMgL0LW9b06i^KP1`L700LG5a07MgM`1fMWH0NGUi07AdM01iNGT0
0`1dM7@01@1iNGT0PX:207inOP1oOgl0NGUi0080P82000@0Ogmo07emO@22PX80NWYj0P20P800901k
Ng/0Q8B408Z:RP25QHD0Ogmo08V9R@2:RXX0QhN709>CT`28R8P0RXZ:08^;R`28R8P0TI6A092@T02F
UYH0Rh^;08V9R@2;Rh/0SXj>08b<S02IVIT0Xj>S09:BTP2MWId0Vi^K09NGU`2IVIT0X:2P0:JVYP2G
UiL0V9RH0::RXP2WYjL0Xj>S0:RXZ080YZJV00T0[Zj^0:RXZ02SXj<0Z:RX0:VYZ@2[Zj/0/;2`0:f]
[@2PX:000P2a/K402@2h^;P0/k>c0;>c/`2g]kL0^KVi0;Bd]02b/[80^[Zj0;:b/P020<;2`P0G0;jn
_P36a/H0_Kfm0<;2`P37alL0`L710<S8b03=cLd0alO70<30`036a/H0a<C40<o?c`36a/H0cLg=0<O7
a`3Cdm<0eMGE0=3@d039bLT0d=3@0<[:bP3>c/h00P3=cLd03@39bLT0`L710;Vi^@35aLD0a<C40;Vi
^@2k^k/0`<300<71`@32`/80_[jn0<G5a@2i^KT00P2j^[X06P2c/k<0/K6a0;>c/`2h^;P0_kno0:j^
[P2j^[X0/[:b0:b/[02b/[80/k>c0:j^[P2b/[80YjNW0:JVYP2XZ:P0ZZZZ0:FUY@2OWil0X:2P0::R
XP2QXJ40YJFU0:>SX`2PX:00WIfM0P2LW9`06P2HV9P0TY:B09NGU`2:RXX0SXj>09FEU@2=SHd0UiNG
08j>SP2@T900SXj>08^;R`2:RXX0TY:B08:2PP2<S8`0O7al07UiN@24Q8@0Ph>30861P@24Q8@0PX:2
07inOP21PH40Q8B40P1nOWh02@1hN7P0Ng]k07MgM`1dM7@0NWYj07alO01cLg<0OWin079bLP0207em
O@0=07EeM@1aLG40Lg=c079bLP1aLG40KVi^07UiN@1jNWX0L71`06QXJ01aLG40Kfm_06a/K00206YZ
JP0906QXJ01^KVh0JVYZ06e]K@1aLG40JFUY065QH@1UIFD0JFUY0080J6QX00@0IfMW061PH01ZJVX0
JVYZ0P1UIFD06`1TI6@0JFUY06EUI@1XJ6P0IVIV05eMG@1RHV80JFUY06ATI01IFET0I6AT06MWI`1Q
HF40GEeM065QH@1LG5`0HV9R065QH@1OGel0HV9R05]KF`1PH600GUiN069RHP1TI6@0GEeM05YJFP02
05mOG`0506=SH`1PH600Fe]K065QH@1OGel01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0
fMWI00<0fMWI00H0PX:206a/K01[Jf/0GemO06EUI@1QHF42069RHP0706EUI@1NGUh0I6AT05iNGP1U
IFD0HV9R05iNGP02069RHP07065QH@1PH600Hf=S06IVIP1TI6@0IfMW06UYJ@0206=SH`0C06][J`1T
I6@0HV9R06QXJ01ZJVX0H61P06ATI01[Jf/0IVIV06YZJP1[Jf/0JFUY06][J`1]KFd0Jf][06a/K01X
J6P0JFUY06i^KP02075aL@0406YZJP1[Jf/0IfMW06a/K080L71`0P1aLG40<01`L700Kfm_07=cL`1c
Lg<0NWYj07UiN@1gMgL0Ng]k07AdM01iNGT0MGEe07]kN`1dM7@0OGem0861P@1oOgl0Ng]k08>3P`20
P800O7al07emO@1oOgl0NWYj08N7Q`1oOgl0Q8B408F5Q@22PX80OWin08N7Q`29RHT0QhN708F5Q@27
QhL0SXj>09>CT`23Ph<0Rh^;08J6QP22PX80S8b<08Z:RP2BTY80Rh^;092@T02ATI40S8b<09VIV@80
UIFE01/0WYjN09bLW02ATI40VIVI0:6QX@2UYJD0Y:BT0:6QX@2JVYX0Vi^K09fMW@2RXZ80YZJV0:6Q
X@2YZJT0Z:RX0:JVYP2XZ:P0Xj>S0;Bd]02[Zj/0ZZZZ0:^[Z`2/[:`0/;2`0:n_[`2j^[X00P2d];@0
5`2c/k<0][Jf0;bl_02o_kl0_[jn0<71`@37alL0_[jn0<;2`P2i^KT0_Kfm0<C4a02i^KT0`L710;no
_`2i^KT0`<300;no_`32`/80b<S80=3@d033`l<0b<S80080aLG500D0c/k>0<K6aP3AdM40_kno0<_;
b`020<30`00d0<;2`P3:b/X0`<300<71`@2l_;`0^k^k0;no_`36a/H0^k^k0<71`@2k^k/0^;Rh0;>c
/`2g]kL0/[:b0;Jf]P2b/[80]KFe0;Jf]P2d];@0[jn_0:f][@2`/;00];Bd0:f][@2c/k<0XZ:R0:^[
Z`2][Jd0Xj>S0:VYZ@2XZ:P0YZJV0:VYZ@2RXZ80YJFU09nOW`2TY:@0WinO0:>SX`2PX:00V9RH09nO
W`2?Shl0VYZJ09NGU`2DU9@0RHV909BDU02ATI40Rh^;08V9R@80RXZ:02@0Shn?08N7Q`2<S8`0R8R8
08J6QP24Q8@0O7al08B4Q01oOgl0PH6107YjNP23Ph<0NWYj08:2PP1mOGd0Q8B40861P@1nOWh0NWYj
07alO01`L700M7Ad0820P01eMGD0MgMg07AdM01eMGD0LG5a07MgM`1lO7`0MWIf071`L01jNWX0Kfm_
07=cL`1YJFT2075aL@0L07=cL`1hN7P0LW9b06][J`1NGUh0JVYZ06][J`1VIVH0IfMW071`L01[Jf/0
JVYZ069RHP1SHf<0Kfm_06MWI`1[Jf/0I6AT06][J`1]KFd0IfMW06UYJ@1SHf<0IfMW06UYJ@1VIVH0
Hf=S06MWI`80GUiN00D0Jf][06=SH`1QHF40GUiN05mOG`0206EUI@0:06ATI01PH600I6AT06EUI@1F
EUH0IfMW061PH01LG5`0GUiN06][J`<0Fe]K00<0H61P065QH@1MGEd00P1OGel00`1NGUh0fMWI0=WI
f@040=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT07020P800KFe]05iNGP1V
IVH0IFEU06=SH`1JFUX0HF5Q06IVIP1QHF40I6AT06=SH`1VIVH0HV9R06ATI01KFe/0I6AT069RHP1U
IFD0Hf=S06QXJ01UIFD0JVYZ069RHP1OGel0IFEU06QXJ01UIFD206ATI00706][J`1RHV80IVIV06][
J`1VIVH0I6AT06a/K00206i^KP0?06UYJ@1_Kfl0KFe]06YZJP1YJFT0Jf][06UYJ@1aLG40JFUY06e]
K@1ZJVX0LW9b071`L01ZJVX0Kfm_0080M7Ad00/0KVi^075aL@1jNWX0Ogmo07UiN@1hN7P0MGEe071`
L01bLW80L71`07UiN@02075aL@1807inOP1mOGd0QXJ607]kN`1oOgl0OWin07emO@21PH40P82007mo
O`21PH40O7al0820P01oOgl0P82007alO023Ph<0Q8B408:2PP26QXH0Ph>308N7Q`25QHD0R8R808j>
SP24Q8@0TI6A09>CT`29RHT0T92@08V9R@2=SHd0RHV909NGU`2BTY80UiNG09VIV@2DU9@0TI6A0:2P
X02HV9P0W9bL09JFUP2SXj<0WIfM0::RXP2ZZZX0YZJV0:FUY@2YZJT0Z:RX0:>SX`2WYjL0XZ:R0:ZZ
ZP2a/K40ZJVY0;>c/`2VYZH0[Zj^0:VYZ@2/[:`0[Zj^0;Jf]P2`/;00[Jf]0;:b/P2`/;00_Kfm0<71
`@2n_[h0^k^k0P2j^[X05@2i^KT0][Jf0;Zj^P2i^KT0`<300;Ng]`2h^;P0`l?30;no_`31`L40`/;2
0;Fe]@34a<@0`/;20<G5a@2k^k/0_Kfm0<K6aP3<c<`0bLW90<30`0020;no_`080<K6aP33`l<0a/K6
0;^k^`34a<@0^k^k0;Rh^02l_;`20;Ng]`0K0;Rh^02][Jd0^KVi0;Rh^02a/K40^KVi0:j^[P2`/;00
/k>c0;Jf]P2/[:`0/K6a0:j^[P2a/K40[Zj^0:RXZ02YZJT0[Jf]0:BTY02RXZ80X:2P0:NWY`2RXZ80
YJFU09JFUP2RXZ80XJ6Q0080Xj>S00<0Vi^K0:2PX02MWId00`2DU9@02`2HV9P0U9BD09:BTP2>SXh0
QXJ609FEU@2>SXh0TY:B08V9R@2;Rh/0SHf=00<0R8R800@0QXJ608:2PP28R8P0P8200P1lO7`01020
P800OGem08>3P`1oOgl407emO@0707alO01gMgL0OWin07QhN01iNGT0Lg=c07AdM002075aL@0X06e]
K@1aLG40M7Ad06e]K@1WIfL0L71`06m_K`1^KVh0Kfm_06][J`1eMGD0J6QX06m_K`1XJ6P0Jf][06EU
I@1`L700JFUY06EUI@1XJ6P0Jf][06ATI01ZJVX0Hf=S06EUI@1VIVH0IFEU06MWI`1PH600IfMW06AT
I01QHF40IFEU06IVIP1TI6@0IFEU065QH@1PH600IFEU05eMG@80I6AT0P1RHV80401QHF40IVIV05YJ
FP1OGel0JFUY06YZJP1OGel0I6AT05iNGP1UIFD0H61P065QH@1TI6@0GUiN05UIF@1XJ6P205eMG@80
FUYJ00<0Fe]K05YJFP3IfMT01@3IfMT100000040fMWI00020=WIf@800000103IfMT2000000@0fMWI
0P0000060=WIf@030000003IfMT0fMWI00<0fMWI00@0Ng]k06YZJP1QHF40GEeM0P1VIVH04@1SHf<0
IFEU06IVIP1RHV80IFEU06ATI01ZJVX0Jf][05eMG@1UIFD0H61P06UYJ@1SHf<0I6AT06QXJ01PH600
J6QX0080IVIV00d0JVYZ06QXJ01TI6@0I6AT06UYJ@1aLG40K6a/06UYJ@1RHV80HF5Q06YZJP1WIfL0
Jf][0080JVYZ00X0I6AT06m_K`1^KVh0J6QX06MWI`1kNg/0MWIf079bLP1^KVh0JFUY0P1aLG40501e
MGD0LW9b079bLP1[Jf/0N7Qh07MgM`1iNGT0Lg=c06i^KP1aLG40NWYj07=cL`1kNg/0MWIf07alO01n
OWh0N7Qh07alO01jNWX0Ng]k0P1mOGd0501gMgL0PX:20861P@1nOWh0Ng]k0820P022PX80O7al08N7
Q`1oOgl0OGem07moO`2<S8`0R8R808J6QP28R8P0QHF508R8R02;Rh/0S8b<0P29RHT0=P2;Rh/0R8R8
08b<S02CTi<0Rh^;092@T02CTi<0T92@09>CT`2IVIT0UiNG09BDU02LW9`0WYjN09ZJVP2NWYh0XJ6Q
0:BTY02DU9@0YJFU09jNWP2QXJ40YZJV0:FUY@2TY:@0YZJV0:6QX@2SXj<0Zj^[0::RXP2UYJD0YjNW
0:RXZ02b/[80/K6a0:^[Z`2_[jl0[Jf]0;:b/P2c/k<0/;2`0;Rh^02f][H0`<300;Bd]02a/K40_kno
0;bl_02i^KT0^[Zj0;no_`2h^;P0_kno0;Rh^080^k^k00<0_kno0;fm_@2g]kL00P31`L40AP34a<@0
_Kfm0<C4a038b<P0`<300<71`@33`l<0^;Rh0;bl_032`/80^KVi0;Ng]`2l_;`0]kNg0;bl_02f][H0
^;Rh0;Vi^@2][Jd0][Jf0<71`@2c/k<0^KVi0:f][@2c/k<0[Jf]0;:b/P2a/K40ZZZZ0;6a/@2d];@0
ZJVY0;6a/@2_[jl0YjNW0:JVYP2_[jl0Y:BT0:JVYP2PX:00Y:BT0:NWY`2FUYH0Vi^K09nOW`2UYJD0
V9RH09VIV@2NWYh0V9RH08f=S@2DU9@0Vi^K08n?S`2<S8`0U9BD08f=S@2;Rh/0TY:B08n?S`2CTi<0
RXZ:08R8R02;Rh/0RHV908J6QP1mOGd0Rh^;0861P@25QHD208>3P`0407alO01jNWX0P82007moO`80
Ng]k02@0PX:20861P@1oOgl0MWIf07moO`20P800LW9b07]kN`1hN7P0NWYj07QhN01fMWH0LW9b06e]
K@1iNGT0M7Ad071`L01eMGD0L71`07QhN01eMGD0KFe]06][J`1YJFT0L71`075aL@1^KVh0Kfm_06e]
K@1XJ6P0Hf=S06UYJ@1UIFD0Jf][06=SH`1YJFT206][J`0B06IVIP1`L700IfMW05iNGP1TI6@0Jf][
06=SH`1VIVH0Hf=S061PH01SHf<0IfMW06=SH`1TI6@0HF5Q069RHP1SHf<0HV9R0P1SHf<0201PH600
GEeM05eMG@1RHV80F5QH06=SH`1RHV80HF5Q0P1RHV8205eMG@0906=SH`1MGEd0IFEU05eMG@1SHf<0
IFEU05YJFP1NGUh0GEeM00H0fMWI0@0000010=WIf@0000D0fMWI0000003IfMT0fMWI000000020=WI
f@040000003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT000001@3IfMT00`000000fMWI0=WI
f@030=WIf@0:06i^KP1XJ6P0H61P06YZJP1QHF40Hf=S06UYJ@1XJ6P0HF5Q06EUI@80I6AT00@0Hf=S
06MWI`1VIVH0IfMW0P1TI6@02P1XJ6P0JVYZ06EUI@1UIFD0GUiN061PH01VIVH0GemO06MWI`1UIFD3
06IVIP0406ATI01^KVh0KVi^06IVIP80JVYZ00d0Kfm_06IVIP1]KFd0J6QX06e]K@1ZJVX0JFUY075a
L@1XJ6P0IVIV06a/K01YJFT0KVi^0080L71`00X0M7Ad079bLP1bLW80KFe]079bLP1dM7@0N7Qh07If
MP1aLG40N7Qh0P1eMGD0301kNg/0O7al07IfMP1mOGd0MGEe079bLP1nOWh0OGem0820P01gMgL0PH61
07MgM`80PX:200d0Q8B407]kN`1mOGd0P82008>3P`20P800NWYj07moO`22PX80Q8B407moO`1hN7P0
PX:20080RHV900T0QhN708R8R025QHD0S8b<08n?S`2CTi<0T92@08b<S02HV9P00P2BTY800`2IVIT0
U9BD09BDU00209JFUP0U09^KV`2CTi<0UIFE09jNWP2HV9P0WinO09fMW@2OWil0X:2P09VIV@2SXj<0
Z:RX0:^[Z`2YZJT0[:b/0:BTY02OWil0ZJVY0:^[Z`2XZ:P0[:b/0:JVYP2^[Zh0[Jf]0:ZZZP2[Zj/0
ZJVY0;:b/P2f][H0/[:b0;>c/`2g]kL0]KFe0;6a/@2f][H0]kNg0<?3``020;^k^`0:0;jn_P2i^KT0
/k>c0;fm_@2h^;P0_;bl0;Ng]`2k^k/0_Kfm0<71`@80`/;200<0`<300;no_`2j^[X00P2o_kl01P2f
][H0^k^k0;6a/@2f][H0]KFe0;6a/@80];Bd03H0/[:b0:n_[`2b/[80/[:b0:b/[02][Jd0/;2`0:n_
[`2b/[80/k>c0;6a/@2][Jd0Zj^[0:2PX02][Jd0/;2`0:ZZZP2YZJT0Z:RX0:VYZ@2IVIT0XZ:R0:RX
Z02VYZH0Vi^K09nOW`2QXJ40VYZJ09RHV02IVIT0WinO0:2PX02LW9`0VYZJ08b<S02>SXh0U9BD08f=
S@2DU9@0S8b<096AT@2@T900S8b<08f=S@2@T900TY:B08Z:RP24Q8@0QhN708>3P`2?Shl0Ph>307al
O022PX8208>3P`0A0820P024Q8@0Ogmo0820P01oOgl0NWYj0820P01aLG40NWYj07EeM@1kNg/0O7al
07QhN01lO7`0N7Qh07YjNP1eMGD0101cLg<0301^KVh0Kfm_07AdM01_Kfl0IfMW07AdM01UIFD0K6a/
06e]K@1/K6`0IfMW06QXJ080Kfm_01<0IfMW06m_K`1UIFD0K6a/06m_K`1VIVH0JVYZ06MWI`1ZJVX0
Jf][06a/K01PH600JVYZ06UYJ@1VIVH0K6a/06EUI@1VIVH0J6QX0080GemO01T0GUiN05eMG@1TI6@0
H61P05]KF`1PH600GemO06EUI@1YJFT0IfMW06QXJ01MGEd0HV9R065QH@1RHV80IfMW069RHP1KFe/0
HF5Q05MGE`1UIFD0Fe]K069RHP1SHf<0H61P0080GEeM00<0Fe]K05YJFP3IfMT01@3IfMT100000040
fMWI00030=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT010000000fMWI0=WIf@0000020=WI
f@030000003IfMT0fMWI00<0fMWI0`0000030=WIf@0606e]K@1TI6@0Hf=S06QXJ01UIFD0IVIV0P1X
J6P00`1PH600KFe]06QXJ00206ATI00506IVIP1YJFT0IFEU06EUI@1VIVH00`1SHf<05@1TI6@0JFUY
06ATI01WIfL0L71`06EUI@1^KVh0K6a/06=SH`1VIVH0KFe]06MWI`1/K6`0IFEU075aL@1RHV80L71`
06e]K@1aLG40KFe]06IVIP0207=cL`0Z071`L01VIVH0K6a/06MWI`1]KFd0Kfm_06IVIP1]KFd0K6a/
07AdM01eMGD0L71`07AdM01gMgL0J6QX06m_K`1cLg<0O7al07AdM01bLW80NGUi07EeM@1bLW80PX:2
07EeM@1iNGT0NWYj07UiN@1gMgL0NWYj07inOP20P800NWYj07EeM@1lO7`0OWin07]kN`23Ph<0MWIf
07]kN`1lO7`0PH610P1nOWh03@25QHD0QXJ607inOP2=SHd0RXZ:08b<S024Q8@0RXZ:08n?S`2;Rh/0
S8b<08n?S`2@T9000P2ATI403P2EUID0Shn?08^;R`2?Shl0UYJF096AT@2FUYH0WYjN09FEU@2JVYX0
W9bL09NGU`2QXJ40V9RH0P2/[:`02@2NWYh0X:2P0::RXP2UYJD0WinO0:>SX`2YZJT0Y:BT0:2PX002
0:FUY@050:ZZZP2/[:`0/k>c0:b/[02`/;000P2c/k<04P2h^;P0]kNg0:b/[02c/k<0`L710:n_[`2n
_[h0]KFe0;fm_@2h^;P0_kno0;>c/`2i^KT0^k^k0<30`02g]kL0_;bl0;no_`@0^k^k0440a<C40;no
_`2k^k/0]KFe0;bl_02f][H0]kNg0<71`@2i^KT0Z:RX0;^k^`2d];@0]kNg0;6a/@2`/;00[:b/0:FU
Y@2i^KT0][Jf0;Bd]02][Jd0/;2`0:b/[02^[Zh0[Jf]0:NWY`2UYJD0[:b/0:ZZZP2WYjL0YJFU0:BT
Y02YZJT0Xj>S0:^[Z`2TY:@0Vi^K09BDU02MWId0XZ:R0:2PX02IVIT0Ti>C0:BTY02KVi/0UYJF09>C
T`2EUID0Vi^K09>CT`2?Shl0SXj>09:BTP2<S8`0TY:B09JFUP2;Rh/0T92@09FEU@29RHT0QhN709:B
TP23Ph<0O7al08F5Q@0208:2PP0b0861P@20P800Ogmo07UiN@1oOgl0QXJ607]kN`1mOGd0Ng]k07em
O@23Ph<0M7Ad07IfMP1cLg<0MGEe07AdM01hN7P0MgMg07AdM01nOWh0Ng]k07IfMP1eMGD0Jf][06m_
K`1bLW80LG5a06][J`1_Kfl0LW9b06i^KP1hN7P0Jf][06i^KP1_Kfl0IfMW06m_K`1]KFd0IfMW06e]
K@1UIFD0K6a/06YZJP1UIFD0Hf=S06a/K01VIVH0Hf=S06i^KP1YJFT306i^KP0306ATI01[Jf/0IVIV
0080HV9R0140HF5Q06ATI01UIFD0HF5Q06MWI`1PH600HV9R06=SH`1PH600I6AT05iNGP1OGel0IFEU
06MWI`1XJ6P0IfMW06ATI00205aLG006065QH@1KFe/0GUiN05iNGP1JFUX0HV9R0P1NGUh00`1IFET0
FUYJ05mOG`040=WIf@<000000@3IfMT000@0fMWI00@000000=WIf@3IfMT000000P3IfMT010000000
fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`1[
Jf/0JFUY05mOG`0206EUI@0T06MWI`1VIVH0K6a/05mOG`1RHV80IfMW061PH01ZJVX0Fe]K05mOG`1W
IfL0IVIV06=SH`1YJFT0J6QX069RHP1TI6@0JVYZ06=SH`1UIFD0IVIV06MWI`1UIFD0I6AT06e]K@1S
Hf<0IFEU06i^KP1YJFT0K6a/06QXJ01VIVH0K6a/06QXJ01`L700JVYZ0P1]KFd01@1aLG40Kfm_06i^
KP1YJFT0Jf][0080LG5a00H0L71`06m_K`1cLg<0L71`07EeM@1_Kfl2071`L004075aL@1lO7`0MWIf
06e]K@80N7Qh00d0PX:207YjNP1cLg<0MWIf07YjNP1fMWH0N7Qh07AdM021PH40N7Qh08F5Q@1nOWh0
P8200080Ng]k00/0O7al07moO`1nOWh0Ng]k07emO@22PX80PH6108F5Q@20P800Ph>308Z:RP0208F5
Q@0408J6QP25QHD0R8R808n?S`80RXZ:01<0TI6A08n?S`2>SXh0RXZ:092@T02<S8`0TI6A09BDU02A
TI40UYJF09FEU@2GUiL0VYZJ08f=S@2IVIT0UYJF09bLW02GUiL0WIfM0080WYjN0240X:2P09bLW02N
WYh0Z:RX09jNWP2YZJT0Xj>S0:JVYP2RXZ80[Zj^0:f][@2TY:@0Z:RX0:VYZ@2UYJD0[Zj^0:ZZZP2]
[Jd0]kNg0;2`/02^[Zh0/[:b0:f][@2h^;P0^[Zj0;Bd]02][Jd0]kNg0;6a/@2g]kL0/[:b0;fm_@2i
^KT00`2e]KD03`2i^KT0];Bd0;Zj^P2g]kL0^;Rh0;6a/@30`<00_Kfm0<71`@2e]KD0]kNg0;^k^`2b
/[80^[Zj0:j^[P020;>c/`0G0;Bd]02VYZH0/[:b0:n_[`2^[Zh0/K6a0;2`/02[Zj/0[Zj^0:f][@2Y
ZJT0[Jf]0:JVYP2WYjL0YJFU0:RXZ02UYJD0ZJVY0::RXP2XZ:P0W9bL09fMW@2VYZH00P2RXZ804`2P
X:00UIFE09VIV@2IVIT0WIfM09BDU02IVIT0UIFE09fMW@2JVYX0Ti>C09BDU02:RXX0SHf=08^;R`2:
RXX0Rh^;08b<S02=SHd00P2>SXh01`29RHT0SHf=08>3P`24Q8@0PH6108B4Q02=SHd00P22PX806026
QXH0RHV908:2PP1nOWh0P82008F5Q@1kNg/0MWIf07inOP1iNGT0NWYj07emO@1lO7`0N7Qh07=cL`1i
NGT0Lg=c07]kN`1eMGD0L71`06i^KP1fMWH0LG5a07=cL`80MGEe02h0L71`06i^KP1bLW80LG5a07Ad
M01[Jf/0JFUY079bLP1RHV80Hf=S071`L01ZJVX0K6a/06YZJP1WIfL0HF5Q06][J`1YJFT0J6QX061P
H01UIFD0GEeM06EUI@1/K6`0J6QX05eMG@1UIFD0IfMW069RHP1UIFD0H61P06=SH`1WIfL0IVIV06EU
I@1RHV80GUiN05]KF`1TI6@0GUiN06QXJ01MGEd0HF5Q069RHP1JFUX0Hf=S0P1QHF403@1SHf<0IVIV
06EUI@1LG5`0H61P06IVIP1JFUX0HV9R05eMG@1KFe/0HF5Q06EUI@1TI6@01P3IfMT100000040fMWI
00001@3IfMT000000=WIf@3IfMT000000080fMWI00@000000=WIf@3IfMT000000P3IfMT010000000
fMWI0=WIf@0000050=WIf@030000003IfMT0fMWI00<0fMWI01H0IVIV065QH@1JFUX0HF5Q061PH01X
J6P0IFEU06=SH`1YJFT0GemO065QH@1UIFD0J6QX05mOG`1NGUh0GemO06=SH`1XJ6P0GUiN061PH01Y
JFT0IVIV0P1]KFd0201NGUh0JFUY06IVIP1VIVH0Hf=S06EUI@1VIVH0KFe]101YJFT04@1[Jf/0K6a/
06UYJ@1[Jf/0KVi^06e]K@1/K6`0JFUY06MWI`1]KFd0LG5a06a/K01ZJVX0L71`06m_K`1eMGD0Lg=c
0080MgMg0100P82007IfMP1dM7@0L71`06m_K`1aLG40M7Ad07QhN01bLW80NGUi07YjNP1iNGT0OWin
07YjNP1nOWh0M7Ad0P1gMgL03@1eMGD0OGem075aL@1kNg/0OGem08>3P`1lO7`0OGem07IfMP1oOgl0
PH6107YjNP25QHD00P20P800101kNg/0OWin08B4Q023Ph<208V9R@0308R8R023Ph<0S8b<0080R8R8
01<0TY:B08Z:RP2=SHd0TI6A08f=S@2<S8`0Shn?09BDU02BTY80UYJF096AT@2;Rh/0TI6A09BDU02F
UYH0VIVI09ZJVP2KVi/0XJ6Q0080XZ:R01P0Vi^K09jNWP2PX:00XZ:R0:>SX`2a/K40YJFU0::RXP2^
[Zh0YZJV0:2PX02VYZH0ZJVY0:^[Z`2ZZZX0Z:RX0:NWY`2a/K40Zj^[0;:b/P2ZZZX0];Bd0;>c/`2d
];@20;:b/P030;6a/@2_[jl0Zj^[0080/K6a00P0/[:b0:n_[`2g]kL0^;Rh0;Vi^@2j^[X0^;Rh0;6a
/@80/k>c0180^;Rh0;Zj^P2m_Kd0^;Rh0:NWY`2a/K40/k>c0:n_[`2f][H0[Jf]0:n_[`2b/[80^KVi
0:VYZ@2[Zj/0/;2`0:JVYP2XZ:P20:f][@0N0:ZZZP2WYjL0[Jf]0:NWY`2VYZH0XZ:R0:ZZZP2TY:@0
X:2P0::RXP2MWId0XJ6Q0:NWY`2JVYX0X:2P09fMW@2EUID0VYZJ09nOW`2IVIT0VYZJ08b<S02GUiL0
SHf=092@T02DU9@0Ti>C096AT@2=SHd0SXj>0P2:RXX06P25QHD0RHV908R8R02@T900QHF508j>SP22
PX80RHV908N7Q`25QHD0OGem07moO`1nOWh0PH6108:2PP20P800O7al07EeM@22PX80N7Qh07EeM@20
P800N7Qh07alO01fMWH0LW9b0P1kNg/05@1cLg<0MWIf07AdM01lO7`0Kfm_075aL@1eMGD0LG5a06YZ
JP1_Kfl0Jf][079bLP1]KFd0LG5a071`L01/K6`0KFe]07EeM@1XJ6P0IFEU06e]K@0206m_K`0306QX
J01SHf<0IfMW0080IfMW00T0KFe]06ATI01UIFD0Hf=S065QH@1RHV80IfMW06ATI01UIFD00P1SHf<0
8P1VIVH0H61P06EUI@1LG5`0GUiN05aLG01QHF40GUiN069RHP1XJ6P0EeMG05mOG`1XJ6P0H61P06=S
H`1TI6@0G5aL06ATI01MGEd0GemO061PH01IFET0GemO05iNGP1HF5P0IFEU05]KF`1HF5P0JFUY05]K
F`1LG5`0H61P05iNGP1MGEd60=WIf@4000000@3IfMT00080fMWI0P0000040=WIf@800000103IfMT2
000000H0fMWI00<000000=WIf@3IfMT00`3IfMT0<@1VIVH0GUiN06ATI01VIVH0HV9R065QH@1YJFT0
J6QX05YJFP1QHF40Hf=S06YZJP1QHF40IVIV069RHP1SHf<0JFUY06QXJ01TI6@0GemO061PH01OGel0
HV9R065QH@1YJFT0Hf=S05mOG`1QHF40I6AT06EUI@1SHf<0I6AT06EUI@1/K6`0JVYZ06MWI`1[Jf/0
L71`06i^KP1dM7@0HF5Q06EUI@1[Jf/0KFe]06m_K`1/K6`0KFe]075aL@1]KFd00P1`L700101/K6`0
N7Qh07emO@22PX8207QhN00D07IfMP1bLW80N7Qh06i^KP1jNWX0N7Qh07]kN`1bLW80MWIf079bLP1k
Ng/0MgMg07]kN`1fMWH0NGUi07inOP1fMWH0Ogmo07QhN01mOGd207moO`0808F5Q@1lO7`0O7al07Yj
NP28R8P0OGem0820P01nOWh208>3P`0708:2PP23Ph<0RXZ:08^;R`27QhL0Ph>308R8R00208b<S00@
092@T027QhL0QHF508j>SP29RHT0SXj>08n?S`2DU9@0Shn?09>CT`2EUID0SHf=09VIV@2ATI40U9BD
09>CT`80V9RH01@0Ti>C09RHV02SXj<0WIfM09nOW`2NWYh0WIfM0::RXP2TY:@0XJ6Q0:f][@2MWId0
YZJV0:VYZ@2[Zj/0XZ:R0:NWY`2VYZH0Y:BT0:f][@80Zj^[00<0[jn_0:JVYP2[Zj/00P2[Zj/03@2/
[:`0Zj^[0:ZZZP2`/;00/k>c0:b/[02^[Zh0]KFe0;6a/@2/[:`0/k>c0;6a/@2d];@00P2h^;P01@2X
Z:P0^KVi0;Zj^P2k^k/0^[Zj0080/[:b0280[Zj^0:FUY@2^[Zh0Zj^[0:VYZ@2[Zj/0/k>c0:n_[`2b
/[80[Jf]0:j^[P2UYJD0[:b/0;2`/02][Jd0YjNW0:RXZ02TY:@0WYjN0:NWY`2SXj<0YjNW0:2PX02O
Wil0X:2P0:JVYP2NWYh0YZJV09ZJVP2OWil0WYjN0:2PX02CTi<0VIVI0P2KVi/0102LW9`0WIfM092@
T02>SXh209>CT`80SXj>0P2DU9@03@2ATI40SXj>08f=S@2<S8`0SXj>096AT@2:RXX0Rh^;08F5Q@2;
Rh/0QHF508B4Q022PX800P26QXH09@27QhL0OWin0861P@20P800Ph>307inOP1iNGT0MWIf07]kN`23
Ph<0MgMg07UiN@1gMgL0NWYj06i^KP1hN7P0M7Ad07IfMP1kNg/0LG5a071`L01ZJVX0MGEe06e]K@1_
Kfl0Jf][06m_K`1ZJVX0LW9b06YZJP1^KVh0LG5a07QhN01VIVH0KVi^06EUI@1]KFd00P1WIfL0101`
L700HV9R06UYJ@1RHV8206ATI00L06IVIP1KFe/0JVYZ06IVIP1UIFD0J6QX061PH01TI6@0Fe]K06AT
I01ZJVX0GEeM069RHP1QHF40GEeM06MWI`1RHV80GEeM05mOG`1QHF40Hf=S05iNGP1SHf<0HV9R05QH
F01KFe/0IVIV065QH@80GUiN00X0HF5Q05eMG@1PH600Hf=S065QH@1YJFT0I6AT05YJFP1SHf<0Fe]K
0P1MGEd00`1GEeL0fMWI0=WIf@040=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3I
fMT02@1WIfL0GEeM06=SH`1WIfL0JFUY05YJFP1TI6@0IVIV05aLG00206QXJ00j069RHP1_Kfl0HF5Q
06EUI@1WIfL0IFEU06MWI`1XJ6P0JVYZ06EUI@1OGel0IFEU06][J`1XJ6P0IfMW06UYJ@1TI6@0J6QX
06YZJP1_Kfl0LG5a06IVIP1_Kfl0JFUY06a/K01ZJVX0KVi^06EUI@1[Jf/0L71`06i^KP1YJFT0Jf][
06e]K@1^KVh0Kfm_07=cL`1/K6`0LG5a079bLP1aLG40O7al08:2PP1nOWh0LW9b06i^KP1dM7@0LG5a
07=cL`1dM7@0KVi^079bLP1_Kfl0N7Qh07AdM01gMgL0MWIf07=cL`<0NWYj00h0Ng]k07emO@1oOgl0
OGem07UiN@24Q8@0P82007moO`20P800MgMg07alO022PX80Ph>308:2PP80QXJ600@0Q8B40861P@22
PX80PX:20P24Q8@06@26QXH0R8R808b<S02>SXh0Rh^;08J6QP2BTY80SXj>08b<S023Ph<0Q8B408f=
S@2CTi<0Rh^;092@T02ATI40TY:B09BDU02IVIT0UiNG09FEU@2MWId0UYJF0:2PX02MWId00P2LW9`0
2@2VYZH0Y:BT0:NWY`2RXZ80Vi^K0:BTY02FUYH0XZ:R0:RXZ00209jNWP80Y:BT00/0[Zj^0:RXZ02[
Zj/0Zj^[0:VYZ@2ZZZX0[Zj^0:b/[02a/K40YZJV0:ZZZP020;6a/@80[Zj^00H0/K6a0;Bd]02_[jl0
ZJVY0:b/[02[Zj/20;2`/00;0:NWY`2YZJT0[:b/0:NWY`2f][H0^;Rh0:b/[02^[Zh0/K6a0;>c/`2^
[Zh00P2YZJT0402XZ:P0[Jf]0;6a/@2/[:`0YZJV0:RXZ02WYjL0ZZZZ0:^[Z`2UYJD0Z:RX0:2PX02X
Z:P0YZJV0::RXP2TY:@209jNWP0P0:2PX02SXj<0XZ:R09^KV`2LW9`0WinO09bLW02EUID0V9RH09NG
U`2NWYh0TI6A092@T02LW9`0UIFE096AT@2=SHd0Shn?09FEU@2GUiL0Shn?08V9R@2<S8`0SHf=092@
T026QXH0Rh^;08Z:RP23Ph<0Q8B408^;R`20P80208N7Q`0408F5Q@23Ph<0Ph>308J6QP80PX:20140
Ogmo07UiN@1mOGd0OWin07UiN@20P800PH6107=cL`1fMWH0MGEe07QhN01gMgL0LG5a07QhN01fMWH0
LG5a07UiN@0207MgM`0?071`L01_Kfl0KFe]06a/K01eMGD0LG5a06m_K`1eMGD0L71`075aL@1[Jf/0
IVIV06m_K`1]KFd0IfMW0080L71`0380Hf=S06IVIP1[Jf/0IVIV06EUI@1NGUh0HF5Q06][J`1WIfL0
IVIV06ATI01aLG40JFUY06=SH`1NGUh0HF5Q06IVIP1QHF40JFUY05aLG01VIVH0H61P05IFEP1SHf<0
J6QX061PH01QHF40Hf=S05mOG`1QHF40GemO06MWI`1QHF40G5aL065QH@1PH600IVIV06UYJ@1SHf<0
GUiN065QH@1RHV80GemO05YJFP1TI6@0G5aL06=SH`1FEUH0GEeM069RHPH0fMWI0@0000010=WIf@00
5P3IfMT00`000000fMWI0=WIf@030=WIf@0506ATI01OGel0IfMW06EUI@1WIfL00P1QHF406P1XJ6P0
Hf=S06ATI01ZJVX0H61P065QH@1RHV80IFEU061PH01]KFd0J6QX06IVIP1SHf<0HF5Q06YZJP1[Jf/0
IFEU065QH@1XJ6P0I6AT065QH@1YJFT0HV9R06=SH`1ZJVX0Jf][0P1`L7009@1^KVh0KFe]06QXJ01V
IVH0K6a/06e]K@1WIfL0IVIV06e]K@1bLW80Kfm_06e]K@1aLG40IfMW071`L01VIVH0LW9b06m_K`1c
Lg<0PX:207QhN01bLW80KVi^07YjNP1iNGT0Lg=c06i^KP1YJFT0MGEe071`L01kNg/0M7Ad07=cL`1d
M7@0N7Qh079bLP1eMGD00P1hN7P08P20P800OGem07inOP1eMGD0N7Qh0820P025QHD0NWYj08R8R022
PX80NGUi07moO`1iNGT0Q8B408N7Q`1oOgl0OWin08V9R@1mOGd0PX:208B4Q026QXH0RXZ:08R8R02;
Rh/0QhN708R8R02>SXh0Rh^;08V9R@2:RXX0PH6108f=S@2<S8`2096AT@0/09>CT`2EUID0SXj>09ZJ
VP2>SXh0VYZJ09JFUP2BTY80V9RH09ZJVP2RXZ80Ti>C0:JVYP2PX:00XZ:R0:FUY@2EUID0WIfM0:BT
Y02MWId0Y:BT0:f][@2UYJD0Y:BT0:VYZ@2SXj<0WYjN0:NWY`2RXZ80ZZZZ0:BTY02][Jd0/K6a0:n_
[`2][Jd0/;2`0:FUY@2][Jd0ZJVY0:RXZ02ZZZX0[Jf]0;6a/@2/[:`20:j^[P80[:b/00L0Y:BT0:j^
[P2/[:`0YJFU0:^[Z`2f][H0WinO0080/;2`01P0XZ:R0:JVYP2][Jd0[Jf]0;>c/`2[Zj/0ZJVY0:FU
Y@2XZ:P0YJFU0::RXP2][Jd0YZJV0:2PX02QXJ40Xj>S0::RXP2NWYh0XJ6Q09jNWP2IVIT0Vi^K092@
T02JVYX209VIV@0D0::RXP2KVi/0TY:B09FEU@2GUiL0V9RH09:BTP2CTi<0UiNG09FEU@2>SXh0Vi^K
09BDU028R8P0S8b<09>CT`2?Shl0RXZ:08V9R@24Q8@208J6QP0I07inOP2<S8`0Ph>308J6QP1nOWh0
Ogmo08Z:RP20P800Ph>308N7Q`1oOgl0SXj>08B4Q01oOgl0Ng]k07QhN01fMWH0MgMg07QhN022PX80
Ng]k07emO@20P800O7al07EeM@0207MgM`0J07EeM@1cLg<0N7Qh06m_K`1hN7P0MgMg07EeM@1WIfL0
LW9b06][J`1cLg<0JVYZ06e]K@1/K6`0LG5a06a/K01fMWH0K6a/06UYJ@1SHf<0IVIV06][J`1]KFd0
Jf][06QXJ01VIVH206ATI00A061PH01YJFT0I6AT06ATI01QHF40Fe]K06ATI01VIVH0HF5Q06EUI@1X
J6P0HV9R05mOG`1UIFD0GemO069RHP1UIFD00P1OGel06@1PH600IfMW06=SH`1QHF40HV9R06UYJ@1O
Gel0IVIV05mOG`1QHF40I6AT05]KF`1OGel0F5QH05mOG`1GEeL0I6AT06YZJP1KFe/0F5QH061PH01I
FET0GEeM05QHF01LG5`01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00D0
HV9R05aLG01TI6@0I6AT06QXJ002069RHP0906ATI01UIFD0HV9R06=SH`1OGel0HV9R06IVIP1UIFD0
IVIV0080H61P00@0GemO06EUI@1QHF40IFEU0P1SHf<03P1/K6`0JFUY069RHP1[Jf/0G5aL06=SH`1Y
JFT0JVYZ06e]K@1cLg<0KFe]075aL@1^KVh0Jf][0P1ZJVX00`1XJ6P0KVi^06a/K00206YZJP0406IV
IP1ZJVX0JFUY071`L080KVi^00X0KFe]07YjNP1dM7@0NGUi06m_K`1bLW80L71`06m_K`1eMGD0OGem
0P1cLg<01@1_Kfl0JVYZ07IfMP1iNGT0MWIf0080Lg=c00P0MWIf07inOP1gMgL0N7Qh07emO@1kNg/0
NWYj07]kN`<0OGem02D0PX:207inOP1kNg/0PX:20861P@1iNGT0QHF507moO`1lO7`0MWIf08B4Q022
PX80OWin08^;R`2<S8`0RXZ:08j>SP28R8P0PX:208B4Q027QhL0Shn?08N7Q`2CTi<0R8R808b<S02@
T900RHV908n?S`2HV9P0TY:B09RHV02FUYH0Shn?09VIV@2KVi/0W9bL0080TY:B00P0XZ:R09ZJVP2F
UYH0WinO0::RXP2EUID0W9bL09RHV080WYjN00H0Xj>S0:2PX02YZJT0ZJVY0::RXP2QXJ420:NWY`03
0:FUY@2XZ:P0[Zj^0080[Jf]00L0YZJV0:ZZZP2_[jl0ZJVY0:>SX`2PX:00]KFe0080[Jf]01T0^;Rh
0:^[Z`2][Jd0ZJVY0:JVYP2[Zj/0[Jf]0:ZZZP2e]KD0Zj^[0:ZZZP2`/;00/K6a0:ZZZP2XZ:P0ZJVY
0:BTY02WYjL0Z:RX0:JVYP2NWYh0ZZZZ0:>SX`2XZ:P0[Zj^0080XZ:R00h0ZJVY0:>SX`2YZJT0YZJV
09nOW`2KVi/0U9BD0:RXZ02PX:00WinO09fMW@2CTi<0VIVI09>CT`80Vi^K01X0TI6A09RHV02EUID0
WIfM08R8R02BTY80UYJF09:BTP2?Shl0SXj>096AT@2:RXX0Shn?092@T02:RXX0Rh^;08n?S`28R8P0
QXJ608B4Q028R8P0Shn?08f=S@23Ph<0QXJ608F5Q@80Q8B400D0PX:207]kN`1nOWh0NWYj08:2PP02
07inOP0607emO@1jNWX0OGem07moO`1iNGT0MgMg0P1eMGD06P1_Kfl0MWIf07AdM01aLG40MGEe079b
LP1gMgL0N7Qh07EeM@1dM7@0KVi^06][J`1bLW80Jf][06UYJ@1[Jf/0IfMW06i^KP1_Kfl0MWIf06i^
KP1/K6`0JVYZ06ATI01ZJVX0I6AT0P1ZJVX04P1[Jf/0IVIV06EUI@1PH600Hf=S06QXJ01YJFT0IfMW
06UYJ@1UIFD0IVIV05aLG01SHf<0J6QX05IFEP1LG5`0H61P05iNGP80I6AT01`0HF5Q05]KF`1RHV80
Hf=S065QH@1/K6`0GemO061PH01QHF40HV9R06MWI`1PH600IVIV06ATI01UIFD0HV9R06=SH`1VIVH0
H61P065QH@1UIFD0IfMW06=SH`1KFe/0F5QH05]KF`1NGUh0FUYJ1P3IfMT100000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI01`0HF5Q06IVIP1RHV80IVIV05aLG01WIfL0Hf=S061PH01OGel0
Hf=S05eMG@1WIfL0H61P065QH@1YJFT0HF5Q069RHP1OGel0IFEU069RHP1UIFD0HF5Q06][J`1WIfL0
HF5Q06ATI01MGEd0L71`0P1ZJVX0701SHf<0GUiN06m_K`1ZJVX0Kfm_06e]K@1_Kfl0KVi^06][J`1Y
JFT0IfMW06YZJP1XJ6P0JFUY06][J`1VIVH0Kfm_075aL@1]KFd0K6a/06e]K@1aLG40Kfm_07EeM@1d
M7@0Kfm_07EeM@1cLg<2071`L00506e]K@1_Kfl0Kfm_075aL@1bLW800P1iNGT01`1fMWH0LG5a07Ad
M01`L700NWYj07]kN`1cLg<00P1jNWX0101kNg/0O7al07QhN023Ph<20861P@0:08F5Q@1mOGd0P820
08:2PP21PH40QHF508:2PP23Ph<0OWin07moO`80P82001<0OWin08:2PP24Q8@0Rh^;08V9R@28R8P0
S8b<08n?S`23Ph<0QhN708f=S@2<S8`0SHf=08Z:RP2>SXh0S8b<08^;R`2@T900Shn?0080TI6A0P2F
UYH0202EUID0U9BD09NGU`2BTY80W9bL09ZJVP2LW9`0WinO0P2MWId00`2QXJ40UIFE09^KV`020:2P
X00=0:FUY@2PX:00YJFU09nOW`2ZZZX0WIfM09jNWP2OWil0YZJV0::RXP2ZZZX0YZJV0:j^[P020:6Q
X@<0YjNW01@0/;2`0:j^[P2XZ:P0[jn_0:ZZZP2PX:00[Jf]0:VYZ@2WYjL0[Zj^0:^[Z`2SXj<0YjNW
0:f][@2a/K40[Zj^0:JVYP2NWYh0YJFU0:6QX@80YJFU01h0YZJV09nOW`2PX:00YjNW0:RXZ02RXZ80
W9bL0:BTY02KVi/0WinO09^KV`2GUiL0X:2P09nOW`2QXJ40VIVI09jNWP2OWil0VIVI0:2PX02HV9P0
W9bL09:BTP2ATI40T92@09>CT`2OWil0UiNG09:BTP2@T90208b<S00>096AT@28R8P0RXZ:08n?S`2=
SHd0T92@08^;R`22PX80SHf=08J6QP2<S8`0PX:207alO028R8P208:2PP0:07moO`25QHD0OWin08N7
Q`1jNWX0P82007QhN01lO7`0Ng]k07emO@80NWYj0280Ng]k07QhN01gMgL0N7Qh07alO020P800NWYj
07IfMP24Q8@0M7Ad071`L01gMgL0M7Ad06e]K@1gMgL0Lg=c071`L01_Kfl0JFUY06e]K@1_Kfl0LG5a
06YZJP1[Jf/0KVi^06e]K@1/K6`0KFe]06UYJ@1UIFD0IfMW06e]K@1XJ6P0IVIV0`1YJFT0901SHf<0
HV9R06EUI@1VIVH0IfMW06IVIP1ZJVX0J6QX05aLG01UIFD0H61P065QH@1PH600I6AT06IVIP1SHf<0
IFEU075aL@1QHF40HV9R06YZJP1TI6@0HF5Q06EUI@1QHF40JVYZ05iNGP1RHV80IfMW05aLG01OGel0
GEeM06ATI01RHV80GEeM069RHP80GEeM00L0FUYJ05UIF@1TI6@0G5aL05eMG@1JFUX0GEeM00H0fMWI
0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0O06ATI01OGel0GUiN05eMG@1WIfL0
HV9R05mOG`1XJ6P0IVIV065QH@1TI6@0JVYZ05iNGP1ZJVX0K6a/065QH@1SHf<0IVIV06=SH`1OGel0
I6AT06YZJP1UIFD0IVIV065QH@1YJFT0GUiN06QXJ01SHf<0L71`07=cL`0206YZJP0;06][J`1_Kfl0
Jf][06a/K01YJFT0JVYZ06IVIP1TI6@0JVYZ06i^KP1_Kfl00P1XJ6P05`1VIVH0LW9b06i^KP1/K6`0
KFe]06m_K`1`L700Lg=c07QhN01aLG40MWIf07AdM01]KFd0M7Ad07]kN`1bLW80M7Ad07YjNP1aLG40
M7Ad079bLP1fMWH0Lg=c0080MGEe00P0MWIf07alO01eMGD0NGUi07=cL`1mOGd0P82007QhN080PH61
00@0OWin0861P@21PH40QHF50P20P8007P29RHT0Q8B40820P021PH40O7al0820P01mOGd0RXZ:08>3
P`21PH40Q8B407emO@26QXH0RHV908N7Q`2?Shl0Ti>C08B4Q02;Rh/0QXJ608V9R@2@T900SXj>09:B
TP2IVIT0UYJF09NGU`2EUID0V9RH09NGU`80UIFE0140Vi^K09BDU02IVIT0WYjN09RHV02OWil0WIfM
09jNWP2IVIT0W9bL0:>SX`2MWId0XJ6Q0:JVYP2SXj<0WIfM0:JVYP0209jNWP0:0:JVYP2ZZZX0WIfM
0:FUY@2ZZZX0ZJVY0:BTY02SXj<0YJFU0:BTY080ZJVY00D0Xj>S0:NWY`2][Jd0YjNW0:b/[0020:ZZ
ZP0I0::RXP2SXj<0Y:BT0:n_[`2QXJ40[Jf]0;:b/P2QXJ40Y:BT0:2PX02UYJD0Xj>S0:ZZZP2NWYh0
XJ6Q0:ZZZP2OWil0X:2P0:BTY02SXj<0Vi^K0::RXP2MWId0Xj>S09nOW`0209^KV`0J09bLW02PX:00
W9bL09bLW02KVi/0U9BD09^KV`2GUiL0U9BD09VIV@2>SXh0XJ6Q09FEU@2FUYH0U9BD09>CT`2?Shl0
UIFE08f=S@2?Shl0RHV908b<S028R8P0TY:B09bLW02<S8`208^;R`0A08R8R024Q8@0R8R808b<S027
QhL0Ogmo08J6QP25QHD0QXJ608:2PP1kNg/0OWin0820P024Q8@0OWin08>3P`1lO7`00P1jNWX00`1l
O7`0NGUi07emO@0207YjNP0907AdM01hN7P0NWYj075aL@1^KVh0Lg=c07EeM@1UIFD0MgMg0080Kfm_
02P0Lg=c071`L01cLg<0KFe]06QXJ01]KFd0MWIf06YZJP1WIfL0JVYZ06e]K@1TI6@0J6QX06i^KP1S
Hf<0IFEU075aL@1TI6@0Jf][061PH01]KFd0IfMW065QH@1XJ6P0I6AT06][J`1SHf<0HF5Q06IVIP1]
KFd0IFEU05iNGP1TI6@0HV9R05]KF`1YJFT0HF5Q061PH01LG5`0HF5Q0P1MGEd0201NGUh0J6QX05mO
G`1PH600GUiN06IVIP1PH600Hf=S0`1OGel02`1IFET0H61P05iNGP1PH600Fe]K05YJFP1NGUh0H61P
065QH@1EEED0GemO00<0GEeM1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI
00P0H61P05mOG`1PH600FEUI06EUI@1KFe/0GemO06EUI@80I6AT00X0IFEU06IVIP1TI6@0Hf=S061P
H01UIFD0HF5Q06ATI01YJFT0IfMW0P1TI6@00`1WIfL0K6a/065QH@0206=SH`0B06][J`1]KFd0J6QX
069RHP1XJ6P0KVi^06e]K@1^KVh0KFe]075aL@1UIFD0KFe]06MWI`1ZJVX0IfMW06e]K@1_Kfl0IFEU
0P1XJ6P01P1aLG40IfMW06MWI`1YJFT0L71`07=cL`80LG5a00h0Jf][07MgM`1[Jf/0MWIf06i^KP1c
Lg<0JFUY06][J`1/K6`0KFe]07MgM`1dM7@0OGem07EeM@80Lg=c00@0LW9b07EeM@1hN7P0N7Qh0P1f
MWH05P1cLg<0NGUi07]kN`1mOGd0MgMg07YjNP20P800Ogmo07alO01jNWX0Ogmo07alO01jNWX0OWin
08J6QP24Q8@0PH6108n?S`2:RXX0RHV908F5Q@2>SXh208V9R@0C08B4Q029RHT0R8R808b<S029RHT0
Rh^;092@T02>SXh0TI6A08^;R`2:RXX0T92@08b<S02@T900U9BD08R8R02>SXh0WYjN09bLW00209FE
U@0;09bLW02EUID0UIFE0:2PX02KVi/0VIVI0:2PX02OWil0Vi^K0::RXP2KVi/00P2IVIT09@2RXZ80
WYjN0::RXP2SXj<0Y:BT0:>SX`2MWId0Zj^[0:>SX`2XZ:P0XJ6Q09fMW@2UYJD0Vi^K0:FUY@2WYjL0
YZJV0:NWY`2TY:@0Z:RX0:f][@2PX:00YJFU09jNWP2][Jd0XZ:R0:>SX`2NWYh0WinO0:>SX`2PX:00
XJ6Q0:BTY02IVIT0WinO0::RXP2OWil00P2XZ:P0=`2TY:@0Xj>S09fMW@2TY:@0Vi^K09jNWP2RXZ80
VIVI09ZJVP2HV9P0VYZJ09JFUP2KVi/0Xj>S09fMW@2RXZ80Vi^K09JFUP2EUID0V9RH09>CT`2BTY80
UiNG09VIV@2DU9@0SXj>08n?S`2DU9@0TI6A092@T02;Rh/0SHf=09JFUP2<S8`0RXZ:08n?S`2=SHd0
S8b<08B4Q026QXH0Q8B40820P01lO7`0Q8B407moO`25QHD0PH6107YjNP26QXH0PX:20861P@23Ph<0
Ng]k07UiN@20P8000P1nOWh01P1oOgl0N7Qh07AdM01cLg<0Ogmo07IfMP80M7Ad00L0LG5a06i^KP1i
NGT0Lg=c075aL@1^KVh0LG5a0080Lg=c01@0L71`06e]K@1bLW80J6QX06][J`1cLg<0J6QX06i^KP1[
Jf/0KVi^06e]K@1XJ6P0IVIV06YZJP1PH600JVYZ06m_K`1VIVH0HV9R06e]K@80GUiN02@0I6AT06MW
I`1QHF40GemO06=SH`1RHV80IVIV06QXJ01UIFD0JFUY061PH01RHV80HF5Q06=SH`1NGUh0H61P069R
HP1YJFT0IfMW06ATI01PH600GEeM05aLG01IFET0IVIV061PH01WIfL0HV9R06=SH`1QHF40IVIV05YJ
FP1QHF40FEUI05iNGP1IFET2065QH@0605mOG`1JFUX0Fe]K05iNGP1LG5`0HF5Q1P3IfMT100000040
fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0P1TI6@0101NGUh0I6AT069RHP1KFe/206IVIP0F
06MWI`1RHV80KVi^06EUI@1PH600HV9R06QXJ01ZJVX0J6QX06MWI`1UIFD0Kfm_06EUI@1SHf<0H61P
06IVIP1WIfL0KVi^06EUI@1WIfL0Jf][06MWI`80HF5Q00D0J6QX06MWI`1^KVh0Kfm_06][J`0206YZ
JP0J06QXJ01aLG40K6a/06EUI@1XJ6P0IVIV06UYJ@1ZJVX0K6a/06UYJ@1bLW80Kfm_06MWI`1[Jf/0
KVi^06m_K`1cLg<0LG5a07EeM@1^KVh0M7Ad07IfMP1/K6`0Kfm_07IfMP1aLG42071`L00307MgM`1f
MWH0LW9b0080MWIf01D0MgMg07IfMP1aLG40Lg=c07YjNP1iNGT0O7al07UiN@1nOWh0PH610820P022
PX80OWin07moO`1mOGd0Ogmo07alO023Ph<0NGUi0861P@24Q8@00P23Ph<00`28R8P0RXZ:08J6QP02
08B4Q00=08N7Q`28R8P0RHV908N7Q`2=SHd0QhN708F5Q@2ATI40RXZ:08V9R@24Q8@0Rh^;08j>SP02
08V9R@80SHf=00D0TI6A092@T02CTi<0TY:B09JFUP0209BDU00A09^KV`2MWId0UiNG0:ZZZP2@T900
UIFE09bLW02GUiL0UYJF09bLW02HV9P0W9bL09^KV`2OWil0YJFU09jNWP2OWil00P2RXZ801@2TY:@0
Zj^[0:6QX@2UYJD0XZ:R0080X:2P00H0YJFU0:ZZZP2RXZ80Xj>S0:FUY@2RXZ820:RXZ00U09nOW`2P
X:00YJFU0:BTY02UYJD0W9bL0:FUY@2PX:00YZJV09RHV02MWId0YZJV0::RXP2KVi/0XJ6Q0:NWY`2R
XZ80WYjN0:BTY02NWYh0UIFE09JFUP2NWYh0VIVI09ZJVP2KVi/0TY:B09nOW`2GUiL0VIVI09BDU02<
S8`0W9bL09JFUP2CTi<0U9BD09>CT`02096AT@0908f=S@2>SXh0S8b<09BDU028R8P0T92@09:BTP2A
TI40Rh^;0080SXj>0180Q8B408V9R@21PH40QhN708^;R`27QhL0PH6108N7Q`1lO7`0QXJ60820P01n
OWh0Ogmo07alO022PX80PH6107inOP1hN7P207alO00707IfMP1gMgL0MGEe07]kN`1gMgL0MWIf079b
LP0207IfMP0m07AdM01eMGD0Lg=c075aL@1dM7@0MGEe06a/K01dM7@0L71`079bLP1_Kfl0KVi^06m_
K`1XJ6P0K6a/07QhN01]KFd0K6a/07EeM@1`L700JVYZ06QXJ01]KFd0K6a/06][J`1XJ6P0IfMW06EU
I@1TI6@0IFEU06e]K@1UIFD0Kfm_06a/K01YJFT0K6a/06EUI@1YJFT0H61P06IVIP1WIfL0IVIV065Q
H@1RHV80GEeM06IVIP1OGel0Fe]K05EEE@1QHF40IFEU061PH01WIfL0HV9R06EUI@1WIfL0GUiN06AT
I01KFe/0FEUI05iNGP02061PH00>05mOG`1LG5`0IFEU065QH@1RHV80GemO06=SH`1MGEd0G5aL05QH
F01RHV80GUiN05YJFP1MGEd60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0
2@1TI6@0GEeM05]KF`1PH600IFEU065QH@1FEUH0Hf=S061PH002069RHP0406QXJ01ZJVX0KFe]06MW
I`<0KFe]00l0J6QX071`L01]KFd0K6a/06YZJP1YJFT0K6a/06e]K@1[Jf/0HF5Q06EUI@1WIfL0K6a/
06YZJP1VIVH00P1ZJVX01@1WIfL0HF5Q06YZJP1`L700KFe]0080J6QX02D0IfMW06a/K01UIFD0IFEU
06MWI`1QHF40KVi^06YZJP1]KFd0KVi^06m_K`1^KVh0Kfm_06YZJP1]KFd0Kfm_06e]K@1bLW80LG5a
06i^KP1eMGD0L71`07UiN@1^KVh0LG5a07AdM01aLG40LW9b07AdM01iNGT0NWYj06m_K`1hN7P0M7Ad
07IfMP1mOGd0NGUi0080NWYj0100Ng]k07AdM01iNGT0M7Ad0820P01oOgl0QhN708:2PP21PH40P820
07alO01oOgl0QHF507emO@2;Rh/0P8200P23Ph<0;P24Q8@0RHV907moO`2<S8`0R8R808Z:RP28R8P0
RXZ:08R8R026QXH0RXZ:092@T02EUID0SHf=09FEU@2?Shl0SXj>09VIV@2=SHd0Shn?08f=S@2@T900
V9RH09ZJVP2ATI40UIFE09^KV`2JVYX0UYJF09ZJVP2LW9`0Xj>S09NGU`2OWil0VIVI0:>SX`2KVi/0
XJ6Q0:2PX02NWYh0WinO0:2PX02NWYh0VIVI0::RXP2OWil20::RXP0F09jNWP2TY:@0XZ:R09ZJVP2O
Wil0YJFU0:RXZ02FUYH0YJFU0:NWY`2NWYh0Z:RX0:6QX@2OWil0XJ6Q09^KV`2SXj<0W9bL0:FUY@2W
YjL0Y:BT0:2PX080XJ6Q01D0WIfM09^KV`2MWId0XZ:R0:>SX`2RXZ80WinO09^KV`2PX:00W9bL09RH
V02VYZH0Vi^K09jNWP2HV9P0U9BD09>CT`2GUiL0VIVI096AT@2CTi<00P2GUiL01`2EUID0TI6A09JF
UP2CTi<0RXZ:08f=S@2?Shl00P2;Rh/04@2?Shl0TY:B08Z:RP2<S8`0RHV908b<S01oOgl0R8R808n?
S`28R8P0QhN708B4Q025QHD0PX:208R8R024Q8@0Ph>30080Ogmo00T0NGUi0861P@21PH40NWYj08F5
Q@1nOWh0NWYj07emO@1oOgl00P1jNWX03P1hN7P0L71`07EeM@1fMWH0Lg=c071`L01fMWH0M7Ad06a/
K01`L700K6a/07IfMP1XJ6P0KFe]0P1cLg<04P1OGel0L71`079bLP1ZJVX0KFe]06][J`1VIVH0LW9b
06IVIP1_Kfl0HV9R06=SH`1XJ6P0IFEU06IVIP1WIfL0I6AT06YZJP80Hf=S01L0JFUY06ATI01/K6`0
JFUY069RHP1VIVH0GEeM06=SH`1XJ6P0HF5Q06ATI01RHV80Jf][05iNGP1QHF40I6AT05mOG`1VIVH0
GemO069RHP1OGel0FUYJ06ATI00306=SH`0;06IVIP1[Jf/0Hf=S061PH01HF5P0HF5Q05UIF@1PH600
GUiN05QHF01LG5`00P1MGEd01P1NGUh0HV9R06=SH`1KFe/0FEUI05YJFPH0fMWI0@0000010=WIf@00
5P3IfMT2000000@0fMWI00D0HV9R05YJFP1UIFD0HV9R06][J`0205mOG`80Hf=S01T0IVIV06EUI@1Z
JVX0KVi^06a/K01iNGT0N7Qh07AdM01hN7P0JVYZ06m_K`1]KFd0IVIV061PH01/K6`0H61P06ATI01Y
JFT0I6AT061PH01UIFD0IfMW06i^KP1YJFT0IfMW0080J6QX00<0I6AT06a/K01ZJVX00`1VIVH02@1[
Jf/0JFUY07AdM01YJFT0K6a/06][J`1cLg<0Jf][06QXJ002079bLP06075aL@1cLg<0Kfm_06IVIP1Y
JFT0L71`0P1]KFd02`1`L700Lg=c07=cL`1aLG40NGUi06i^KP1]KFd0MWIf07=cL`1aLG40KFe]00<0
N7Qh00d0L71`079bLP1eMGD0PX:207YjNP1nOWh0M7Ad07inOP1lO7`0MWIf07MgM`1oOgl0NWYj0080
P82002<0PH6108:2PP1oOgl0PX:208B4Q01mOGd0P8200861P@23Ph<0QHF508V9R@2:RXX0Ph>308B4
Q022PX80SXj>0861P@2>SXh0S8b<096AT@21PH40S8b<08n?S`2=SHd0QHF508j>SP2@T900PX:209:B
TP2@T900Shn?08b<S02?Shl0UiNG09RHV00209bLW00:09NGU`2JVYX0V9RH09ZJVP2GUiL0VIVI09fM
W@2QXJ40X:2P09nOW`80Vi^K00D0VYZJ09jNWP2TY:@0XZ:R09RHV00209fMW@0T0:>SX`2TY:@0Y:BT
09jNWP2QXJ40WIfM09nOW`2LW9`0Z:RX0:2PX02KVi/0W9bL0::RXP2OWil0YJFU09^KV`2JVYX0XJ6Q
0::RXP2GUiL0UIFE09NGU`2MWId0VIVI09fMW@2PX:00WIfM0:BTY02GUiL0WinO09BDU02OWil0W9bL
09>CT`2GUiL0V9RH0P2GUiL05@2KVi/0V9RH09JFUP2FUYH0Ti>C092@T02BTY80W9bL09NGU`2>SXh0
SHf=092@T02ATI40Rh^;08b<S02GUiL0TI6A08j>SP26QXH0S8b<08^;R`0208J6QP0C07inOP2<S8`0
QhN708B4Q023Ph<0R8R808V9R@1nOWh0QHF50820P022PX80OWin08N7Q`1kNg/0NWYj07]kN`1mOGd0
O7al07EeM@0207YjNP0<07emO@1eMGD0OGem07]kN`1lO7`0N7Qh07EeM@1/K6`0M7Ad075aL@1^KVh0
Lg=c0P1aLG40201lO7`0Jf][07EeM@1[Jf/0KFe]071`L01_Kfl0JVYZ0P1YJFT0201ZJVX0KVi^06IV
IP1`L700LW9b06UYJ@1_Kfl0JVYZ0P1XJ6P0701VIVH0I6AT06QXJ01XJ6P0Hf=S065QH@1WIfL0JFUY
06YZJP1TI6@0JVYZ06i^KP1WIfL0J6QX05mOG`1PH600J6QX06EUI@1KFe/0GemO06YZJP1UIFD0GUiN
05aLG01IFET0HV9R05EEE@1KFe/206=SH`0905eMG@1JFUX0Fe]K06ATI01RHV80GemO05iNGP1HF5P0
Fe]K0080GUiN00/0GemO06=SH`1NGUh0Fe]K05mOG`1FEUH0FUYJ065QH@1OGel0FUYJ05aLG0050=WI
f@8000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT06`1RHV80G5aL05mOG`1YJFT0Jf][
065QH@1TI6@0HV9R061PH01TI6@0K6a/06i^KP23Ph<0SHf=09BDU02SXj<0YZJV09ZJVP1jNWX0MgMg
06a/K01[Jf/0GemO061PH01SHf<0L71`06QXJ00206IVIP0306][J`1RHV80Jf][0080IfMW0P1ZJVX0
1`1[Jf/0KVi^06MWI`1VIVH0Kfm_06MWI`1ZJVX00P1_Kfl0B@1YJFT0J6QX06MWI`1/K6`0JVYZ06a/
K01_Kfl0JVYZ07MgM`1bLW80JVYZ07=cL`1WIfL0L71`079bLP1aLG40KVi^075aL@1gMgL0NGUi06i^
KP1eMGD0LW9b06m_K`1bLW80MgMg079bLP1`L700JVYZ07EeM@1nOWh0MGEe07MgM`1eMGD0M7Ad07Mg
M`1iNGT0MGEe07AdM01kNg/0NGUi07moO`1eMGD0OGem0861P@20P800PH6107emO@20P800Q8B40861
P@26QXH0Rh^;08:2PP27QhL0PH6108J6QP25QHD0PH6108>3P`27QhL0PX:208J6QP27QhL0SHf=08n?
S`23Ph<0QXJ608F5Q@2:RXX0RHV908J6QP2CTi<00P2@T900802:RXX0SXj>08j>SP2DU9@0V9RH09>C
T`2BTY80TI6A09VIV@2DU9@0UiNG09FEU@2GUiL0X:2P09JFUP2EUID0UYJF09RHV02PX:00VIVI09bL
W02HV9P0W9bL09ZJVP2PX:00VYZJ09VIV@2QXJ40VYZJ09jNWP2JVYX0XZ:R0P2MWId209nOW`0609JF
UP2KVi/0WIfM09bLW02OWil0UYJF0P2JVYX01P2PX:00XJ6Q09ZJVP2NWYh0Xj>S09ZJVP80Y:BT01P0
XZ:R09:BTP2LW9`0X:2P09NGU`2HV9P0Vi^K09JFUP2DU9@0V9RH09VIV@2DU9@0TY:B09nOW`2BTY80
TI6A09RHV02ATI40T92@09BDU02CTi<0T92@08V9R@28R8P208j>SP0@096AT@2BTY80R8R808j>SP2;
Rh/0SXj>08F5Q@27QhL0PX:208Z:RP29RHT0Q8B40820P027QhL0QXJ607emO@80QHF501`0QXJ60861
P@1kNg/0NWYj08>3P`1nOWh0P82007emO@1kNg/0QXJ607UiN@1jNWX0O7al075aL@1fMWH0LG5a07]k
N`1fMWH0LG5a07]kN`1eMGD0LG5a07=cL`1dM7@0Kfm_07EeM@1_Kfl0JFUY0P1^KVh01@1bLW80Jf][
071`L01ZJVX0KFe]0080KVi^01@0Jf][06YZJP1TI6@0HV9R06QXJ01WIfL0KFe]06a/K01^KVh0Jf][
06=SH`1_Kfl0J6QX06e]K@1QHF40HV9R06EUI@1NGUh0IFEU06IVIP80JVYZ00P0Hf=S069RHP1NGUh0
I6AT061PH01QHF40Hf=S06EUI@80GemO00`0IVIV05iNGP1VIVH0HV9R05]KF`1NGUh0GemO06][J`1S
Hf<0GEeM069RHP1VIVH305eMG@0306MWI`1SHf<0IFEU0080Fe]K00L0FUYJ06ATI01OGel0GUiN06IV
IP1LG5`0Fe]K0080FUYJ1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI02<0
G5aL05mOG`1QHF40GEeM069RHP1YJFT0IFEU065QH@1VIVH0Jf][06e]K@1jNWX0Ng]k0:FUY@2g]kL0
emOG0=GEe@2f][H0RHV907inOP1aLG40JFUY06MWI`1ZJVX0I6AT06UYJ@1XJ6P0HF5Q06UYJ@1XJ6P0
KVi^06YZJP1TI6@0GUiN06ATI00306UYJ@80Jf][00/0I6AT06IVIP1WIfL0JFUY06ATI01WIfL0IVIV
06][J`1/K6`0JVYZ06i^KP0206MWI`0<06YZJP1[Jf/0KFe]06UYJ@1ZJVX0KVi^06e]K@1_Kfl0LW9b
06a/K01[Jf/0LW9b0P1dM7@207=cL`0=07EeM@1nOWh0MWIf07=cL`1^KVh0NWYj06e]K@1fMWH0N7Qh
07EeM@1hN7P0MWIf07QhN00207YjNP0=07inOP1`L700O7al07emO@1gMgL0OGem0861P@1nOWh0O7al
07moO`25QHD0PX:207emO@0208F5Q@0:08R8R02;Rh/0QhN708B4Q022PX80QXJ608^;R`29RHT0O7al
08b<S080QXJ600h0Ogmo08J6QP2>SXh0Ph>308N7Q`2>SXh0TY:B09JFUP2ATI40R8R809JFUP2GUiL0
TY:B09JFUP80UiNG00D0V9RH096AT@2BTY80Ti>C09VIV@0209^KV`80UYJF00/0WinO09^KV`2LW9`0
U9BD09^KV`2NWYh0Vi^K09bLW02GUiL0X:2P08n?S`0209ZJVP0m09^KV`2JVYX0VIVI09ZJVP2WYjL0
WinO09ZJVP2UYJD0XZ:R09bLW02JVYX0VIVI09NGU`2JVYX0V9RH09jNWP2JVYX0W9bL09jNWP2JVYX0
W9bL09ZJVP2DU9@0WIfM0:2PX02KVi/0Ti>C09ZJVP2HV9P0WinO09^KV`2EUID0Ti>C09NGU`2DU9@0
VYZJ09VIV@2DU9@0Ti>C09FEU@2DU9@0VIVI092@T02FUYH0RXZ:08j>SP2DU9@0TI6A08R8R026QXH0
QhN708Z:RP2<S8`0SXj>08N7Q`21PH40PX:208R8R022PX80RHV908>3P`0208V9R@0708>3P`1iNGT0
Ng]k07inOP1mOGd0MgMg08J6QP020820P0050861P@20P800OWin07YjNP1gMgL00P1kNg/0701aLG40
M7Ad07UiN@1kNg/0LG5a07QhN01]KFd0KVi^071`L01eMGD0L71`07IfMP1aLG40MGEe06m_K`1bLW80
KFe]071`L01[Jf/0IVIV06m_K`1UIFD0JVYZ079bLP1^KVh0Jf][065QH@1_Kfl206][J`0406ATI01/
K6`0HF5Q06=SH`80J6QX0380JFUY06YZJP1TI6@0IfMW05eMG@1SHf<0EeMG06QXJ01OGel0H61P06MW
I`1ZJVX0FUYJ06ATI01ZJVX0HF5Q05aLG01TI6@0HV9R05iNGP1PH600FUYJ06IVIP1TI6@0IFEU065Q
H@1SHf<0IfMW05YJFP1QHF40J6QX05QHF01UIFD0I6AT069RHP1QHF40Hf=S06EUI@1NGUh0HF5Q05iN
GP1MGEd0H61P069RHP1OGel0HF5Q06MWI`1OGel0H61P06=SH`H0fMWI0@0000010=WIf@005P3IfMT0
0`000000fMWI0=WIf@030=WIf@0=05eMG@1SHf<0F5QH06EUI@1RHV80H61P06ATI01XJ6P0H61P06a/
K01gMgL0PX:20:VYZ@050?ooo`0=0:b/[02HV9P0L71`06UYJ@1^KVh0IFEU06=SH`1ZJVX0H61P06EU
I@1QHF40GUiN06ATI00206IVIP0406UYJ@1ZJVX0I6AT06YZJP80JFUY0100Kfm_06e]K@1ZJVX0IVIV
06UYJ@1UIFD0IVIV071`L01bLW80J6QX06UYJ@1WIfL0JVYZ075aL@1YJFT0K6a/0P1]KFd0501_Kfl0
JVYZ06m_K`1VIVH0KVi^07=cL`1^KVh0JVYZ06a/K01aLG40Lg=c06e]K@1cLg<0MGEe075aL@1[Jf/0
Lg=c07EeM@1aLG40M7Ad0`1^KVh02P1lO7`0OWin07]kN`1lO7`0M7Ad071`L01mOGd0NWYj07QhN01o
Ogl207emO@060820P01mOGd0MWIf07=cL`23Ph<0OGem0P20P8001026QXH0O7al08^;R`2;Rh/208:2
PP0=08N7Q`1jNWX0OWin08V9R@2:RXX0RHV908B4Q02BTY80Ph>308N7Q`2>SXh0SHf=08R8R00208j>
SP03096AT@2CTi<0Rh^;0080UIFE00D0SXj>09JFUP2CTi<0UYJF09FEU@0209>CT`0409VIV@2CTi<0
Shn?092@T080VIVI00X0TY:B09jNWP2HV9P0V9RH09:BTP2HV9P0UYJF09NGU`2MWId0VYZJ0P2OWil0
2P2QXJ40VIVI0:>SX`2JVYX0Vi^K09ZJVP2GUiL0Ti>C09^KV`2PX:0209ZJVP0C096AT@2HV9P0UIFE
09BDU02GUiL0VYZJ0:6QX@2DU9@0TY:B09VIV@2MWId0U9BD09JFUP2EUID0UiNG09bLW02JVYX0U9BD
08^;R`0209>CT`0O09FEU@2IVIT0S8b<09>CT`2BTY80S8b<08n?S`2>SXh0TY:B08f=S@20P800QhN7
08R8R024Q8@0QXJ608V9R@27QhL0Ph>3092@T029RHT0RXZ:08>3P`27QhL0OGem0861P@26QXH0OWin
08>3P`22PX80P82007alO0020861P@0=07]kN`1lO7`0OWin0820P01mOGd0OWin07QhN01fMWH0NGUi
07AdM01lO7`0OWin07]kN`0207MgM`0J07=cL`1/K6`0L71`07IfMP1lO7`0MgMg071`L01[Jf/0Lg=c
06YZJP1WIfL0JVYZ06UYJ@1]KFd0Kfm_071`L01/K6`0MgMg06QXJ01/K6`0GemO06MWI`1ZJVX0Kfm_
06QXJ01YJFT206MWI`0906ATI01YJFT0HV9R069RHP1]KFd0IFEU06QXJ01WIfL0IVIV0080HV9R02/0
GEeM06EUI@1RHV80JVYZ06][J`1RHV80GEeM065QH@1PH600HV9R06EUI@1SHf<0HF5Q061PH01JFUX0
JVYZ05iNGP1OGel0GUiN069RHP1TI6@0IVIV05eMG@1SHf<0IVIV05eMG@1OGel0GEeM05iNGP1QHF40
Hf=S065QH@1LG5`0GemO05]KF`1OGel0EEEE05IFEP1OGel0H61P05aLG01RHV80G5aL00H0fMWI0@00
00010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0=065QH@1TI6@0G5aL05mOG`1YJFT0H61P
06MWI`1VIVH0Kfm_06UYJ@21PH40UIFE0<o?c`050?ooo`050<30`02KVi/0Ng]k06i^KP1[Jf/00P1X
J6P0:@1WIfL0JFUY061PH01YJFT0HV9R05mOG`1UIFD0KFe]06UYJ@1SHf<0HV9R06UYJ@1WIfL0Kfm_
06UYJ@1SHf<0IfMW06IVIP1YJFT0JVYZ06a/K01_Kfl0JFUY06m_K`1/K6`0LW9b06i^KP1YJFT0Kfm_
06e]K@1^KVh0KFe]07=cL`1/K6`0Lg=c06a/K01cLg<0L71`06a/K01]KFd0JVYZ0080L71`00T0Lg=c
06i^KP1iNGT0M7Ad07MgM`1/K6`0Lg=c07UiN@1fMWH00P1gMgL0101^KVh0Ng]k06i^KP1kNg/20820
P00?07AdM01hN7P0MgMg07MgM`1eMGD0O7al08>3P`1oOgl0Ph>30820P022PX80Ph>308B4Q021PH40
S8b<0080R8R801l0QXJ60861P@29RHT0R8R808:2PP21PH40PX:208Z:RP29RHT0T92@08F5Q@26QXH0
SHf=08b<S02=SHd0Q8B408Z:RP2>SXh0TI6A08f=S@2BTY80Rh^;09>CT`2ATI40UYJF092@T02EUID0
UYJF09>CT`2ATI40VIVI0080TY:B00`0WYjN09:BTP2GUiL0TI6A09FEU@2JVYX0Shn?09^KV`2DU9@0
WYjN09VIV@2GUiL209^KV`80V9RH01`0VIVI09:BTP2HV9P0VIVI09^KV`2GUiL0WYjN09JFUP2GUiL0
Shn?09:BTP2PX:00SXj>09bLW02IVIT0Shn?09fMW@2GUiL0VIVI09bLW02BTY80UIFE09ZJVP2GUiL0
SHf=08n?S`2BTY80U9BD0P2BTY80202ATI40UiNG09RHV02GUiL0T92@09NGU`2DU9@0Shn?0P2<S8`0
1`2@T900RXZ:08V9R@28R8P0RHV9096AT@2@T9000P2<S8`02@29RHT0PH6108^;R`2<S8`0RHV90820
P02:RXX0P82008:2PP020861P@0:08B4Q01oOgl0PX:208>3P`24Q8@0O7al07emO@1jNWX0Ng]k07al
O080OGem01@0O7al07]kN`21PH40Ng]k07IfMP1]KFd0NWYj07]kN`1eMGD0LG5a07EeM@1aLG40Kfm_
07=cL`1ZJVX0L71`07YjNP1bLW80LG5a06][J`80M7Ad01d0Kfm_06YZJP1aLG40L71`075aL@1[Jf/0
JVYZ06a/K01aLG40IVIV06a/K01YJFT0IfMW06e]K@1XJ6P0HV9R06QXJ01VIVH0GEeM06EUI@1LG5`0
HV9R06MWI`1YJFT0K6a/06IVIP1UIFD0GUiN06][J`0206=SH`0R06MWI`1]KFd0HV9R065QH@1OGel0
IFEU05]KF`1UIFD0HV9R05UIF@1TI6@0GEeM06=SH`1XJ6P0G5aL06e]K@1TI6@0H61P05mOG`1HF5P0
HF5Q05eMG@1TI6@0JVYZ06EUI@1NGUh0EEEE05YJFP1PH600G5aL05iNGP1FEUH0EeMG05mOG`80F5QH
00<0H61P05]KF`3IfMT01@3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00`0
HV9R05aLG01LG5`0Hf=S06EUI@1TI6@0GemO065QH@1TI6@0LW9b08^;R`2WYjL60?ooo`070=CDe02N
WYh0MGEe06UYJ@1[Jf/0IFEU06IVIP0206UYJ@0Z06MWI`1XJ6P0JFUY061PH01RHV80Jf][06QXJ01[
Jf/0IFEU06=SH`1RHV80IfMW06][J`1WIfL0JFUY06IVIP1WIfL0JFUY06e]K@1[Jf/0JFUY06][J`1/
K6`0LW9b06IVIP1_Kfl0MGEe06YZJP1cLg<0Kfm_07AdM01/K6`0L71`07AdM01bLW80JFUY06QXJ01a
LG40O7al06UYJ@1eMGD0Lg=c0P1aLG40301_Kfl0KVi^075aL@1gMgL0LW9b07YjNP1dM7@0MWIf07Yj
NP1gMgL0OWin079bLP80NGUi00<0N7Qh0820P01bLW800P1iNGT20820P00:07QhN01lO7`0PH6107in
OP1oOgl0P82008B4Q021PH40OGem08B4Q080RXZ:00L0QXJ608:2PP25QHD0QHF508>3P`22PX80Rh^;
0080SXj>03@0TI6A092@T02:RXX0Q8B408Z:RP2?Shl0T92@08j>SP2CTi<0RHV908j>SP2:RXX0Shn?
09>CT`2?Shl0SXj>096AT@2>SXh0V9RH09FEU@2GUiL0SXj>09^KV`2DU9@0VYZJ09JFUP2IVIT0U9BD
09FEU@2MWId0UIFE09:BTP2DU9@0VIVI09jNWP2FUYH0TY:B09bLW02BTY80UYJF08^;R`2MWId0UIFE
096AT@2QXJ40UiNG09>CT`2JVYX0UIFE09BDU02ATI40UIFE0P2CTi<01P2FUYH0VYZJ09ZJVP2FUYH0
WIfM09:BTP80Vi^K0100UIFE09bLW02?Shl0Rh^;08n?S`2DU9@0Ti>C09BDU02FUYH0Ti>C096AT@2H
V9P0T92@08^;R`2:RXX0T92@0P2:RXX03P24Q8@0R8R808b<S02>SXh0T92@08F5Q@2<S8`0RXZ:08j>
SP21PH40RXZ:08:2PP20P800Q8B40P23Ph<04P22PX80P82007emO@28R8P0PH6107YjNP20P800NWYj
0861P@23Ph<0MWIf07]kN`1nOWh0O7al07EeM@1nOWh0O7al07UiN@80MWIf00L0MGEe07MgM`1fMWH0
LG5a0861P@1kNg/0MGEe0080LG5a00<0Kfm_06i^KP1hN7P00P1`L70206m_K`09079bLP1`L700KVi^
06a/K01XJ6P0JVYZ06ATI01^KVh0IVIV0080IfMW00`0LG5a06e]K@1]KFd0IVIV06=SH`1RHV80Hf=S
06MWI`1YJFT0IfMW06IVIP1UIFD2061PH00;065QH@1]KFd0JFUY06=SH`1VIVH0HV9R065QH@1RHV80
I6AT06IVIP1RHV800P1TI6@07`1JFUX0HV9R05mOG`1MGEd0F5QH05mOG`1TI6@0HF5Q06ATI01WIfL0
G5aL06ATI01IFET0Hf=S05aLG01OGel0H61P05mOG`1PH600I6AT05YJFP1RHV80I6AT05eMG@1LG5`0
FEUI05aLG01PH600GemO05UIF@1PH6001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI
00<0fMWI00D0I6AT05]KF`1MGEd0Fe]K05YJFP0206ATI00506YZJP1bLW80KVi^09>CT`2`/;001P3o
ool0202ZZZX0Ti>C06i^KP1bLW80JVYZ06ATI01XJ6P0IfMW0P1/K6`01@1QHF40Hf=S06EUI@1XJ6P0
IVIV0080IfMW00L0IVIV069RHP1VIVH0J6QX06ATI01[Jf/0I6AT0080IfMW00`0Hf=S06][J`1ZJVX0
JFUY06YZJP1UIFD0K6a/06MWI`1/K6`0KFe]06][J`1XJ6P206YZJP0Z06][J`1gMgL0JVYZ06i^KP1_
Kfl0KVi^06e]K@1hN7P0KFe]06a/K01bLW80MGEe071`L01/K6`0MGEe07AdM01mOGd0M7Ad07=cL`1d
M7@0MWIf07YjNP1iNGT0N7Qh07]kN`1dM7@0J6QX07inOP1mOGd0O7al07emO@20P800Ogmo0820P01k
Ng/0MgMg07inOP1mOGd0Ph>30820P022PX80QhN70P23Ph<0@P1jNWX0Ph>308B4Q02;Rh/0Ogmo08B4
Q01jNWX0Q8B408b<S02@T900/[:b08Z:RP2;Rh/0QHF508J6QP29RHT0SXj>08V9R@26QXH0SXj>08b<
S023Ph<0TY:B08f=S@2DU9@0SHf=08R8R02BTY80Ti>C09VIV@2HV9P0WinO09JFUP2JVYX0Ti>C09NG
U`2ATI40UYJF092@T02CTi<0Vi^K09>CT`2DU9@0V9RH08j>SP2EUID0Shn?092@T02CTi<0VIVI09FE
U@2GUiL0UIFE08n?S`2HV9P0Vi^K09ZJVP2GUiL0U9BD08j>SP2CTi<0U9BD096AT@2IVIT0UYJF096A
T@80Shn?02<0Ti>C09BDU02?Shl0UYJF09VIV@2ATI40UIFE09>CT`2?Shl0SXj>08f=S@2DU9@0PX:2
08j>SP2?Shl0SHf=08j>SP2;Rh/0SXj>08b<S02;Rh/0Ti>C08j>SP2<S8`0Q8B408R8R023Ph<0QHF5
08J6QP23Ph<0QXJ608F5Q@26QXH0P82008N7Q`020820P00:08R8R024Q8@0PH6107EeM@1jNWX0NGUi
08N7Q`1nOWh0PX:207emO@80MGEe01<0Ng]k07UiN@1hN7P0KVi^07]kN`1dM7@0MWIf07UiN@1mOGd0
NWYj07MgM`1bLW80MgMg07UiN@1dM7@0Lg=c071`L01bLW80Jf][0080M7Ad0P1]KFd08`1`L700Lg=c
06UYJ@1]KFd0JVYZ071`L01aLG40JFUY06=SH`1YJFT0KVi^06][J`1UIFD0K6a/06][J`1WIfL0HV9R
06EUI@1OGel0J6QX06][J`1QHF40GemO06ATI01VIVH0HV9R06=SH`1WIfL0J6QX06][J`1UIFD0HV9R
06ATI01RHV80GEeM0080GUiN0P1RHV80401VIVH0HV9R061PH01MGEd0I6AT05iNGP1PH600HF5Q069R
HP1SHf<0IFEU06YZJP1OGel0GUiN061PH01OGel206=SH`0?06ATI01RHV80IVIV05]KF`1IFET0GemO
05iNGP1MGEd0EEEE06=SH`1QHF40H61P05]KF`1PH600F5QH00H0fMWI0@0000010=WIf@005P3IfMT0
0`000000fMWI0=WIf@030=WIf@0<06ATI01QHF40GemO06=SH`1XJ6P0Jf][06EUI@1XJ6P0K6a/07Yj
NP2LW9`0/K6a1P3oool0A`2NWYh0OWin07QhN01YJFT0IVIV06m_K`1YJFT0I6AT06MWI`1VIVH0I6AT
06EUI@1QHF40J6QX06UYJ@1UIFD0IVIV06EUI@1VIVH0H61P05mOG`1WIfL0KFe]06ATI01YJFT0L71`
06=SH`1ZJVX0J6QX06][J`1]KFd0LW9b06YZJP1VIVH0KFe]06UYJ@1/K6`0Jf][06m_K`1/K6`0Jf][
06m_K`1]KFd0M7Ad07EeM@1bLW80M7Ad079bLP1^KVh0K6a/06][J`1aLG40L71`07QhN01`L700Lg=c
07MgM`1[Jf/0LW9b07MgM`1dM7@0MGEe07UiN@1fMWH0MGEe07YjNP1gMgL0OWin07YjNP1mOGd0NGUi
0080Ogmo01`0Ph>307UiN@1oOgl0P82007moO`1jNWX0Rh^;0820P01iNGT0PX:207UiN@20P800Q8B4
08:2PP28R8P0PX:208>3P`1gMgL0R8R808J6QP2<S8`0TI6A08^;R`27QhL0Ogmo08V9R@2DU9@0QHF5
0`2;Rh/03`2>SXh0Ti>C096AT@26QXH0SHf=08V9R@2?Shl0TI6A08b<S02;Rh/0T92@09FEU@2?Shl0
UYJF08n?S`0208^;R`0609:BTP2EUID0UYJF08n?S`2JVYX0S8b<0P2?Shl208j>SP0<09^KV`2IVIT0
V9RH09BDU02:RXX0SXj>09BDU02EUID0T92@096AT@2BTY80T92@0P2DU9@0202HV9P0Ti>C09BDU02H
V9P0UIFE092@T02DU9@0UYJF0P2>SXh0702@T900TI6A09BDU02CTi<0SHf=08j>SP2;Rh/0T92@08n?
S`2;Rh/0T92@08J6QP29RHT0Ti>C092@T028R8P0RHV908b<S02ATI40R8R808j>SP29RHT0QHF508f=
S@1nOWh0RHV908^;R`2>SXh208F5Q@0:08>3P`22PX80PH6107emO@1kNg/0RXZ:07]kN`1iNGT0QXJ6
08F5Q@80NGUi00T0Ogmo079bLP1oOgl0OGem07EeM@1gMgL0NWYj07QhN01kNg/00P1hN7P02`1iNGT0
MGEe07=cL`1dM7@0Kfm_07]kN`1fMWH0Lg=c06m_K`1^KVh0LG5a00<0KFe]02P0K6a/079bLP1lO7`0
Kfm_06i^KP1`L700Kfm_06i^KP1ZJVX0J6QX061PH01[Jf/0KFe]06EUI@1ZJVX0Hf=S06MWI`1]KFd0
Jf][06UYJ@1/K6`0I6AT06UYJ@1RHV80IFEU065QH@1VIVH0GUiN06EUI@1WIfL0KVi^06YZJP1WIfL0
JVYZ06ATI01WIfL0H61P06EUI@1TI6@0HV9R0P1WIfL04`1VIVH0J6QX06=SH`1SHf<0GemO05eMG@1I
FET0I6AT06=SH`1TI6@0GUiN06EUI@1SHf<0I6AT05iNGP1PH600HV9R05eMG@1RHV800P1QHF40201R
HV80GUiN05QHF01QHF40Hf=S05mOG`1PH600I6AT0P1IFET00`1JFUX0fMWI0=WIf@040=WIf@400000
0@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0301KFe/0FUYJ05]KF`1MGEd0IFEU06UYJ@1X
J6P0IFEU06QXJ01aLG40RHV90::RXPD0oooo00@0][Jf08J6QP1mOGd0LG5a0P1TI6@0D`1XJ6P0IVIV
061PH01[Jf/0IfMW06ATI01UIFD0H61P06=SH`1YJFT0I6AT06e]K@1PH600IFEU06QXJ01UIFD0KVi^
05mOG`1YJFT0J6QX06e]K@1VIVH0JFUY06YZJP1SHf<0K6a/06EUI@1ZJVX0J6QX06MWI`1YJFT0KFe]
06][J`1cLg<0Jf][06YZJP1VIVH0KFe]06i^KP1cLg<0LG5a07inOP1^KVh0L71`06a/K01_Kfl0JFUY
075aL@1gMgL0LW9b06QXJ01hN7P0KVi^07EeM@1iNGT0OWin07YjNP1oOgl0MGEe07MgM`1hN7P0Lg=c
07AdM01cLg<0N7Qh07EeM@1jNWX0MWIf07QhN01mOGd0Ng]k07IfMP1oOgl0P82007IfMP1nOWh0Ogmo
07emO@22PX80PH6107alO025QHD0Ng]k0080OGem00D0QXJ608:2PP2;Rh/0QXJ607]kN`0208:2PP0_
07moO`23Ph<0Ph>308>3P`29RHT0QhN708^;R`2=SHd0SXj>08R8R02CTi<0TI6A092@T02EUID0QhN7
09NGU`2BTY80WIfM08j>SP2BTY80UYJF08j>SP2@T900RXZ:092@T02>SXh0UYJF09FEU@2DU9@0UYJF
09NGU`2EUID0Shn?09>CT`2EUID0TI6A09FEU@2=SHd0TY:B09RHV027QhL0Shn?09>CT`2FUYH0Ti>C
09ZJVP2DU9@00P2BTY803`2EUID0Ti>C09>CT`2DU9@0SHf=09JFUP2BTY80SXj>09JFUP2<S8`0TY:B
09>CT`2BTY80SHf=08R8R00208f=S@0:09FEU@2<S8`0T92@08^;R`2?Shl0QHF508f=S@2<S8`0SXj>
08N7Q`80QHF501X0S8b<08N7Q`2>SXh0RHV908N7Q`22PX80NWYj08N7Q`24Q8@0Ogmo07alO028R8P0
QHF508N7Q`1gMgL0PH6108F5Q@1jNWX0LW9b07YjNP1lO7`0PX:207EeM@1dM7@0O7al0861P@80Ogmo
0140MWIf07]kN`1fMWH0O7al07IfMP1^KVh0NWYj07QhN01dM7@0MGEe06a/K01fMWH0MgMg06i^KP1d
M7@0KFe]07MgM`0307=cL`0R07EeM@1/K6`0L71`06e]K@1/K6`0LW9b06m_K`1XJ6P0JVYZ06i^KP1[
Jf/0IVIV06QXJ01`L700J6QX06YZJP1YJFT0IfMW06EUI@1ZJVX0Hf=S06UYJ@1ZJVX0GemO06QXJ01R
HV80J6QX06ATI01QHF40GUiN065QH@1OGel0HF5Q06MWI`80IFEU00<0Hf=S06IVIP1IFET00P1PH600
601SHf<0G5aL05mOG`1LG5`0EUIF05YJFP1LG5`0GUiN061PH01OGel0I6AT05iNGP1UIFD0EEEE06AT
I01RHV80HF5Q06EUI@1YJFT0GemO06=SH`1NGUh0F5QH05mOG`80H61P0P1NGUh0101YJFT0H61P05eM
G@1IFET60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT07`1PH600IFEU069R
HP1VIVH0GUiN069RHP1SHf<0IfMW06][J`1]KFd0OWin08f=S@2n_[h0h^;R0>c/k03<c<`0^[Zj08^;
R`1dM7@0KFe]071`L01WIfL0IFEU06ATI01RHV80Jf][069RHP1SHf<0IFEU06ATI01RHV800P1SHf<0
7`1XJ6P0IFEU069RHP1WIfL0I6AT06UYJ@1RHV80J6QX06a/K01[Jf/0J6QX075aL@1ZJVX0IVIV06QX
J01UIFD0KFe]06MWI`1`L700J6QX06EUI@1dM7@0L71`06i^KP1XJ6P0KFe]06a/K01aLG40Kfm_07=c
L`1/K6`00P1^KVh01@1dM7@0LG5a07IfMP1_Kfl0IfMW0080Kfm_00<0KVi^06][J`1dM7@00P1gMgL0
3`1fMWH0NGUi07EeM@1_Kfl0MgMg07IfMP1hN7P0OGem07UiN@1kNg/0MgMg07emO@1jNWX0PX:207]k
N`0307moO`0B07QhN01kNg/0Ph>30820P01kNg/0OGem07UiN@21PH40Ng]k08>3P`1kNg/0QHF50820
P02=SHd0RXZ:08F5Q@2;Rh/0Ph>30P25QHD01`26QXH0Q8B408N7Q`27QhL0S8b<08N7Q`2@T9000P2:
RXX01`27QhL0S8b<08Z:RP2CTi<0UYJF08b<S02EUID00P29RHT0=P2?Shl0SXj>08j>SP2=SHd0UIFE
09>CT`2:RXX0TI6A09NGU`2?Shl0SHf=09>CT`2>SXh0V9RH096AT@2@T900Rh^;096AT@2?Shl0S8b<
08V9R@2ATI40UIFE09:BTP2>SXh0VIVI08^;R`2>SXh0V9RH08Z:RP2IVIT0R8R809RHV02@T900SXj>
08f=S@29RHT0T92@08^;R`2@T900U9BD096AT@2CTi<0Vi^K08f=S@2:RXX0RHV909fMW@2BTY80SHf=
08N7Q`25QHD0T92@08V9R@80QhN702/0TY:B0820P025QHD0PX:208V9R@24Q8@0PH6108>3P`2:RXX0
PH6108Z:RP2<S8`0QHF50861P@27QhL0OWin08>3P`1lO7`0Ogmo08:2PP1lO7`0MWIf07QhN01fMWH0
OWin07=cL`21PH40PX:20861P@1gMgL0O7al07EeM@1gMgL0N7Qh07YjNP1iNGT0LG5a079bLP1dM7@0
MWIf07UiN@1aLG40MWIf0080L71`0200MGEe079bLP1`L700Lg=c079bLP1XJ6P0Kfm_06e]K@1WIfL0
LW9b06e]K@1VIVH0K6a/06i^KP1ZJVX0JFUY06a/K01[Jf/0JFUY06EUI@1QHF40IFEU06QXJ01[Jf/0
HV9R06UYJ@1PH600I6AT06EUI@1RHV80IfMW06ATI080IFEU00D0Jf][061PH01VIVH0J6QX05iNGP02
06=SH`0;05iNGP1OGel0I6AT065QH@1LG5`0GUiN06QXJ01VIVH0GemO06EUI@1VIVH00P1QHF406@1L
G5`0H61P06IVIP1JFUX0G5aL05UIF@1PH600GEeM065QH@1JFUX0G5aL05YJFP1QHF40GEeM061PH01R
HV80G5aL069RHP1JFUX0Hf=S05aLG01MGEd0FEUI061PH01IFET01P3IfMT100000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI01l0HF5Q05eMG@1PH600IfMW061PH01TI6@0HF5Q06][J`1UIFD0
JFUY07UiN@21PH40V9RH0:f][@2b/[80WIfM09:BTP25QHD0LG5a07=cL`1ZJVX0JFUY069RHP1VIVH0
I6AT06MWI`1VIVH0HF5Q05mOG`1PH600IFEU0080Hf=S02@0HV9R06IVIP1XJ6P0IfMW06YZJP1PH600
Kfm_06ATI01YJFT0Hf=S06UYJ@1XJ6P0IVIV069RHP1/K6`0I6AT06IVIP1[Jf/0J6QX06i^KP1cLg<0
KFe]06a/K01fMWH0Kfm_06UYJ@1^KVh0L71`06e]K@1dM7@0NGUi079bLP1hN7P0Lg=c06a/K01dM7@2
06][J`0907UiN@1bLW80KFe]079bLP1cLg<0MWIf07emO@1cLg<0MGEe0080M7Ad00/0MWIf07]kN`1m
OGd0NWYj07AdM01hN7P0Ng]k0820P01lO7`0P82007QhN00207UiN@0607]kN`21PH40O7al0861P@22
PX80OWin0P1lO7`0<P21PH40Ogmo07alO022PX80Ph>30820P01mOGd0R8R808N7Q`1nOWh0Ph>308V9
R@1nOWh0PH6108n?S`20P800Q8B408^;R`1oOgl0R8R8092@T022PX80T92@08:2PP2=SHd0SXj>08f=
S@2ATI40RXZ:092@T02HV9P0Ti>C08j>SP2@T900U9BD08b<S02BTY80Rh^;08Z:RP2ATI40T92@08N7
Q`2@T900S8b<092@T02>SXh0Rh^;08b<S02ATI40T92@0P2=SHd05@2ATI40T92@08b<S02@T900TI6A
09>CT`2;Rh/0S8b<08f=S@2<S8`0UIFE09bLW02>SXh0SHf=09RHV02@T900SHf=096AT@2=SHd0Shn?
08V9R@0208f=S@0808Z:RP2=SHd0T92@08b<S02?Shl0S8b<08j>SP28R8P208N7Q`0708J6QP2<S8`0
S8b<07inOP2=SHd0PH6108N7Q`0208B4Q00N08>3P`29RHT0S8b<08F5Q@1kNg/0P82008>3P`24Q8@0
OGem0861P@1nOWh0O7al0820P01mOGd0MWIf07]kN`1mOGd0OWin07UiN@1nOWh0M7Ad07YjNP1cLg<0
NWYj07EeM@1iNGT0JVYZ07AdM01^KVh0M7Ad0P1eMGD307=cL`0U075aL@1kNg/0LG5a071`L01bLW80
KFe]079bLP1TI6@0Jf][071`L01/K6`0LG5a06][J`1WIfL0IVIV06i^KP1YJFT0Kfm_07=cL`1dM7@0
Jf][06QXJ01ZJVX0GemO06EUI@1ZJVX0IfMW06YZJP1[Jf/0I6AT06QXJ01]KFd0GemO069RHP1]KFd0
Hf=S06UYJ@0206IVIP0905mOG`1TI6@0IVIV06ATI01QHF40HV9R06UYJ@1MGEd0IVIV0080GUiN01X0
H61P05YJFP1PH600IFEU06=SH`1LG5`0GEeM05iNGP1UIFD0Fe]K061PH01SHf<0GUiN06=SH`1OGel0
Fe]K06MWI`1TI6@0HV9R06ATI01NGUh0Fe]K06=SH`1OGel0EeMG05EEE@80GEeM00@0Hf=S05aLG01K
Fe/0HF5Q1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0200EeMG05mOG`1X
J6P0GemO06QXJ01TI6@0HF5Q061PH01SHf<0IVIV06EUI@1eMGD0M7Ad07IfMP1gMgL0LG5a07UiN@1a
LG40K6a/069RHP1UIFD0Kfm_06YZJP1RHV80Jf][069RHP1WIfL0HF5Q069RHP1]KFd0H61P06=SH`80
IFEU00<0I6AT06MWI`1SHf<00P1YJFT0101UIFD0Hf=S05eMG@1XJ6P206YZJP0906ATI01VIVH0KFe]
06EUI@1eMGD0IfMW065QH@1^KVh0JVYZ0080KVi^01X0IfMW06YZJP1^KVh0MGEe06e]K@1ZJVX0IFEU
071`L01WIfL0K6a/06m_K`1^KVh0JVYZ079bLP1]KFd0K6a/06m_K`1eMGD0JFUY07AdM01bLW80M7Ad
06m_K`1gMgL0MWIf07=cL`80MGEe00h0MgMg07AdM01fMWH0MWIf07]kN`1hN7P0MgMg079bLP1kNg/0
MgMg07moO`1gMgL0MWIf07YjNP80Ogmo0240Ph>307=cL`1iNGT0QhN708:2PP23Ph<0OGem0861P@22
PX80Ogmo07emO@23Ph<0RHV908J6QP23Ph<0OWin08F5Q@2;Rh/0Ph>308R8R025QHD0Rh^;0820P024
Q8@0SHf=08J6QP29RHT0S8b<08Z:RP26QXH0TI6A09FEU@2;Rh/00P2>SXh03`2<S8`0SHf=08Z:RP27
QhL0RXZ:08j>SP27QhL0UiNG09:BTP2@T900QHF5096AT@28R8P0Shn?08Z:RP0208n?S`06096AT@29
RHT0SHf=08^;R`2EUID0S8b<0P2?Shl04P2:RXX0Rh^;08R8R02@T900Shn?08f=S@2KVi/0TY:B08b<
S02BTY80RXZ:092@T029RHT0Vi^K08>3P`2GUiL0Shn?092@T080RXZ:00`0QhN708b<S027QhL0Rh^;
08J6QP29RHT0Rh^;08J6QP2;Rh/0QXJ608F5Q@20P80208V9R@0608J6QP25QHD0PH6108N7Q`23Ph<0
QXJ60P1oOgl02P22PX80OGem07moO`1oOgl0P82008>3P`1nOWh0MgMg07moO`1lO7`207UiN@80O7al
02H0N7Qh07alO01mOGd0MGEe07YjNP1eMGD0NWYj07UiN@1gMgL0LW9b07YjNP1hN7P0KVi^07MgM`1a
LG40Lg=c07EeM@1/K6`0L71`07UiN@1[Jf/0L71`06m_K`1]KFd0KVi^06m_K`1WIfL0KVi^06UYJ@1/
K6`0JVYZ06IVIP1TI6@0Kfm_06MWI`1]KFd0JVYZ07AdM080Jf][00H0JFUY06MWI`1/K6`0GemO06UY
J@1/K6`206UYJ@07069RHP1UIFD0Jf][06IVIP1]KFd0G5aL06e]K@0206EUI@0E065QH@1MGEd0HF5Q
065QH@1TI6@0GemO06EUI@1RHV80GUiN06MWI`1MGEd0GUiN06IVIP1OGel0G5aL06=SH`1OGel0I6AT
06EUI@1MGEd0IfMW0080HF5Q00X0IFEU06IVIP1MGEd0IVIV069RHP1MGEd0GUiN065QH@1GEeL0F5QH
0P1IFET01P1OGel0G5aL05aLG01PH600Fe]K05YJFPH0fMWI0@0000010=WIf@005P3IfMT2000000@0
fMWI00T0GEeM069RHP1KFe/0H61P06ATI01QHF40GemO06=SH`1QHF400P1UIFD0701WIfL0Jf][07=c
L`1gMgL0Kfm_07IfMP1YJFT0H61P06UYJ@1UIFD0Hf=S06IVIP1PH600Hf=S06YZJP1WIfL0JVYZ065Q
H@1SHf<0GUiN069RHP1TI6@0H61P069RHP1XJ6P0H61P06ATI01XJ6P206MWI`0806IVIP1RHV80J6QX
06UYJ@1SHf<0IVIV06a/K01[Jf/206IVIP0706QXJ01/K6`0K6a/06QXJ01]KFd0JFUY06a/K002075a
L@0Q06m_K`1]KFd0Lg=c06YZJP1`L700Kfm_06a/K01cLg<0NWYj071`L01bLW80LG5a079bLP1`L700
M7Ad07]kN`1cLg<0L71`07IfMP1mOGd0Lg=c07AdM01cLg<0MWIf079bLP1^KVh0MGEe07IfMP21PH40
O7al07emO@21PH40MgMg0080Ph>300L0Lg=c07alO01hN7P0Ogmo07MgM`23Ph<0O7al0080NWYj00<0
Ph>308B4Q01oOgl00P1oOgl09@1mOGd0P82008>3P`1jNWX0Q8B408N7Q`29RHT0Ng]k08B4Q027QhL0
RXZ:08b<S026QXH0RXZ:08^;R`2:RXX0R8R809:BTP2=SHd0QhN709BDU02<S8`0QXJ608Z:RP28R8P0
QHF508J6QP2;Rh/0SXj>096AT@2?Shl0W9bL08n?S`2BTY80PH6108f=S@2;Rh/00P2=SHd03@27QhL0
SHf=08N7Q`2>SXh0R8R808f=S@2GUiL0Ti>C08N7Q`29RHT0Rh^;08Z:RP2BTY80102@T900;`2;Rh/0
UIFE09JFUP2>SXh0T92@08F5Q@2<S8`0U9BD08f=S@2>SXh0U9BD08N7Q`2;Rh/0RXZ:08f=S@23Ph<0
SHf=08^;R`2<S8`0Ph>309:BTP24Q8@0QHF508V9R@2=SHd0OWin08>3P`25QHD0PX:207moO`21PH40
OWin08:2PP21PH40QhN708B4Q020P800Ogmo07inOP1oOgl0OGem07YjNP1kNg/0OWin08:2PP1mOGd0
N7Qh0080NWYj00D0OGem07UiN@1fMWH0N7Qh07emO@0207UiN@0D07QhN01gMgL0MWIf07=cL`1gMgL0
MGEe07YjNP1dM7@0Lg=c071`L01cLg<0JVYZ079bLP1fMWH0L71`06m_K`1^KVh0L71`06a/K01bLW82
06][J`0406a/K01YJFT0KFe]06QXJ080IfMW00/0J6QX06UYJ@1]KFd0MWIf06EUI@1VIVH0Kfm_069R
HP1PH600IfMW06][J`0206EUI@80HF5Q00<0IFEU06MWI`1TI6@00P1XJ6P2069RHP0@06IVIP1RHV80
H61P065QH@1TI6@0IfMW06YZJP1VIVH0IfMW069RHP1VIVH0FUYJ05eMG@1OGel0IFEU06ATI0@0HV9R
00H0Fe]K06EUI@1SHf<0IFEU05eMG@1OGel2069RHP0?05aLG01MGEd0GemO065QH@1MGEd0H61P065Q
H@1GEeL0Hf=S05aLG01KFe/0FEUI05mOG`1LG5`0GemO00D0fMWI0P0000010=WIf@005P3IfMT00`00
0000fMWI0=WIf@030=WIf@0:06=SH`1OGel0HF5Q05iNGP1[Jf/0GEeM06ATI01/K6`0IfMW06=SH`80
J6QX0100IfMW06a/K01WIfL0H61P06MWI`1UIFD0JVYZ06ATI01SHf<0GEeM06IVIP1MGEd0IfMW06=S
H`1NGUh0JFUY0P1UIFD03`1MGEd0GemO05iNGP1RHV80JVYZ05aLG01TI6@0KFe]06YZJP1OGel0Jf][
06EUI@1YJFT0JVYZ06EUI@0206=SH`0K06ATI01XJ6P0JFUY06e]K@1PH600JFUY06m_K`1^KVh0IfMW
06ATI01ZJVX0KFe]07AdM01ZJVX0KVi^06QXJ01[Jf/0MWIf06e]K@1[Jf/0MWIf06UYJ@1XJ6P0KVi^
06e]K@1cLg<0L71`00<0Lg=c01<0LW9b07AdM01`L700Lg=c071`L01bLW80NWYj07IfMP1aLG40MgMg
079bLP1iNGT0LW9b075aL@1gMgL0MGEe07=cL`1dM7@0N7Qh00@0NWYj01/0P82007YjNP1mOGd0P820
0861P@22PX80P82008:2PP26QXH0PH6107YjNP2;Rh/0Ogmo07]kN`24Q8@0QXJ608:2PP1mOGd0QXJ6
07emO@25QHD0P82008:2PP27QhL0RHV908n?S`25QHD00P2;Rh/06`26QXH0R8R808^;R`2:RXX0Rh^;
08b<S02@T900QXJ609>CT`2EUID0QXJ608^;R`2ATI40SXj>08b<S02;Rh/0QXJ608j>SP2;Rh/0RHV9
08J6QP2?Shl0RXZ:09FEU@2?Shl0R8R808n?S`02096AT@0<092@T02>SXh0SXj>08b<S02ATI40T92@
08j>SP2;Rh/0S8b<08j>SP2@T900TY:B0P28R8P01P2>SXh0RHV908R8R02=SHd0UIFE08V9R@80Q8B4
00`0Rh^;08R8R02;Rh/0QXJ608R8R022PX80S8b<08^;R`29RHT0SHf=0861P@25QHD207moO`0?0820
P01kNg/0PH6107IfMP20P800PH6108V9R@22PX80PH6107QhN01mOGd0PH6107emO@24Q8@0Ogmo0080
O7al00D0MgMg07]kN`1fMWH0NWYj07alO002079bLP0807QhN01gMgL0O7al075aL@1jNWX0MgMg06m_
K`1aLG42079bLP0I07QhN01fMWH0M7Ad071`L01^KVh0Jf][06m_K`1`L700KFe]07=cL`1^KVh0KFe]
06i^KP1[Jf/0K6a/06][J`1WIfL0KVi^065QH@1[Jf/0KVi^06a/K01]KFd0GUiN06ATI00206IVIP09
06ATI01PH600Hf=S06ATI01YJFT0Jf][065QH@1XJ6P0HV9R0080J6QX00D0JFUY06YZJP1VIVH0IVIV
06UYJ@0206=SH`07061PH01VIVH0GUiN05YJFP1VIVH0GEeM05mOG`0206ATI080Hf=S01@0H61P05iN
GP1WIfL0GemO069RHP1PH600GEeM05mOG`1NGUh0IFEU05aLG01RHV80GEeM065QH@1SHf<0IFEU06MW
I`1IFET0HV9R06EUI@80GemO00D0IFEU05eMG@1PH600GemO05IFEP0205]KF`0305YJFP3IfMT0fMWI
00@0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0Y05YJFP1OGel0H61P06QX
J01WIfL0I6AT06UYJ@1TI6@0IfMW06=SH`1QHF40Fe]K065QH@1]KFd0IVIV06QXJ01[Jf/0IFEU06IV
IP1SHf<0J6QX06=SH`1QHF40J6QX06=SH`1YJFT0HF5Q06=SH`1UIFD0JFUY06IVIP1NGUh0IVIV065Q
H@1SHf<0IfMW065QH@1SHf<0IfMW06EUI@1YJFT00P1SHf<01`1RHV80IVIV06QXJ01/K6`0JFUY06a/
K01QHF400P1[Jf/07`1]KFd0L71`061PH01]KFd0LG5a06][J`1ZJVX0K6a/06][J`1bLW80Jf][06UY
J@1^KVh0K6a/06e]K@1_Kfl0Jf][07EeM@1WIfL0L71`06a/K01cLg<0KVi^07QhN01fMWH0MGEe075a
L@1eMGD0LW9b06i^KP1`L7000P1eMGD03@1kNg/0Lg=c07UiN@1dM7@0L71`07EeM@1`L700NGUi07em
O@1cLg<0NGUi07QhN01jNWX00P1nOWh0601lO7`0Ng]k0820P020P800PX:20861P@1kNg/0PH610820
P024Q8@0NGUi08>3P`1gMgL0O7al07inOP29RHT0RXZ:0820P029RHT0PH6108b<S024Q8@0SXj>08^;
R`80PH610P28R8P0<`25QHD0SHf=08Z:RP26QXH0QhN708Z:RP2=SHd0QhN708j>SP2:RXX0SXj>08b<
S02=SHd0T92@08f=S@27QhL0RXZ:08^;R`2CTi<0TI6A08V9R@2>SXh0QhN708j>SP2<S8`0RXZ:08f=
S@2ATI40SXj>08b<S029RHT0U9BD08f=S@2ATI40U9BD08n?S`28R8P0Q8B408j>SP2HV9P0Rh^;08R8
R026QXH0RHV908B4Q02ATI40QhN708B4Q026QXH0PX:208Z:RP0208>3P`0508F5Q@29RHT0T92@08R8
R021PH400P27QhL00`25QHD0PX:207emO@0208>3P`0C0861P@1iNGT0QHF507moO`24Q8@0OGem08J6
QP1mOGd0MGEe08B4Q01oOgl0NGUi07inOP1mOGd0Ng]k07moO`1jNWX0Ogmo07emO@0207IfMP0S07Yj
NP1gMgL0MgMg06m_K`1aLG40MWIf07YjNP1fMWH0MGEe079bLP1`L700OGem07UiN@1eMGD0IfMW06e]
K@1bLW80JFUY079bLP1`L700Kfm_06i^KP1bLW80JVYZ06m_K`1^KVh0JVYZ06ATI01aLG40K6a/06YZ
JP1/K6`0KVi^06UYJ@1RHV800P1[Jf/02`1]KFd0KVi^06][J`1YJFT0H61P06UYJ@1UIFD0Jf][06i^
KP1ZJVX0Jf][0080HV9R00`0IfMW06=SH`1WIfL0HF5Q06IVIP1UIFD0KVi^05aLG01UIFD0Hf=S05YJ
FP1YJFT2069RHP0;061PH01TI6@0GEeM065QH@1YJFT0Hf=S06i^KP1VIVH0HV9R06ATI01NGUh00P1S
Hf<2061PH00>06=SH`1QHF40GUiN06=SH`1PH600F5QH06e]K@1QHF40GemO05aLG01EEED0Hf=S05aL
G01OGel205aLG005069RHP1KFe/0GEeM05IFEP1MGEd01P3IfMT100000040fMWI000F0=WIf@030000
003IfMT0fMWI00<0fMWI0100GemO05eMG@1MGEd0IFEU05iNGP1[Jf/0Hf=S05eMG@1PH600IVIV06AT
I01YJFT0HF5Q06EUI@1RHV80Jf][0P1SHf<0101OGel0J6QX05YJFP1NGUh2069RHP80HF5Q00l0IVIV
06ATI01PH600IfMW06UYJ@1OGel0J6QX065QH@1WIfL0HV9R06UYJ@1TI6@0HV9R05mOG`1_Kfl00P1V
IVH03@1RHV80JFUY06ATI01cLg<0Jf][06a/K01VIVH0LW9b06MWI`1XJ6P0JVYZ06MWI`1ZJVX00P1/
K6`0201ZJVX0Lg=c06YZJP1_Kfl0IFEU079bLP1ZJVX0M7Ad0P1]KFd00`1[Jf/0LG5a06a/K00406e]
K@0:07QhN01aLG40KFe]075aL@1`L700KFe]07AdM01iNGT0NWYj07AdM080MGEe00D0NGUi06e]K@1n
OWh0Lg=c07UiN@0207EeM@0307=cL`1hN7P0Lg=c0080O7al00H0OGem0820P01kNg/0P82007moO`23
Ph<207emO@0N07inOP1lO7`0Ng]k07UiN@1oOgl0PH6108B4Q01nOWh0PH6107emO@21PH40OGem07al
O021PH40Q8B407emO@29RHT0Q8B408^;R`28R8P0QhN708J6QP2<S8`0SHf=08:2PP28R8P0Shn?08V9
R@26QXH0QhN70P2;Rh/20861P@0708J6QP2<S8`0R8R808n?S`1oOgl0R8R808>3P`0308V9R@0N08f=
S@2BTY80Ph>307emO@22PX80Ph>308N7Q`2;Rh/0RHV908J6QP2=SHd0RXZ:08b<S02:RXX0R8R8092@
T02>SXh0T92@08Z:RP2=SHd0S8b<08j>SP26QXH0QHF508V9R@2>SXh0PX:20861P@24Q8@0Shn?0P2>
SXh0;@1oOgl0RHV908F5Q@28R8P0Rh^;08N7Q`23Ph<0OWin08B4Q01iNGT0Ph>307emO@2>SXh0OWin
07UiN@1jNWX0MgMg07UiN@26QXH0NWYj07inOP1iNGT0OGem07YjNP1iNGT0MWIf07QhN021PH40NGUi
07YjNP1mOGd0NWYj07EeM@1iNGT0Ng]k07YjNP1gMgL0NGUi07IfMP1jNWX0Lg=c07EeM@1iNGT0MWIf
06i^KP02079bLP1=06m_K`1^KVh0KFe]06i^KP1ZJVX0KFe]06MWI`1]KFd0Jf][075aL@1VIVH0J6QX
06m_K`1OGel0JVYZ06QXJ01]KFd0Jf][075aL@1XJ6P0K6a/06UYJ@1TI6@0JVYZ07=cL`1VIVH0J6QX
069RHP1YJFT0IFEU06YZJP1XJ6P0K6a/06=SH`1VIVH0HF5Q06=SH`1/K6`0J6QX06EUI@1WIfL0K6a/
069RHP1VIVH0IFEU05eMG@1SHf<0H61P065QH@1LG5`0GEeM06EUI@1SHf<0HF5Q069RHP1MGEd0GUiN
05aLG01VIVH0Hf=S065QH@1SHf<0H61P06=SH`1QHF40Hf=S06MWI`1LG5`0GEeM06ATI01OGel0GEeM
05aLG01TI6@0HV9R05iNGP1OGel00P1RHV801@1IFET0HV9R05UIF@1NGUh0FEUI00H0fMWI0@000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0;05mOG`1MGEd0G5aL06EUI@1PH600GEeM06EU
I@1OGel0G5aL05mOG`1WIfL00P1PH6001`1TI6@0HF5Q06=SH`1VIVH0J6QX06IVIP1WIfL00P1RHV80
301MGEd0IVIV061PH01QHF40H61P069RHP1YJFT0I6AT06EUI@1IFET0Hf=S06ATI080IVIV00@0Hf=S
06a/K01UIFD0Hf=S0P1RHV80701XJ6P0LG5a069RHP1^KVh0IFEU06a/K01XJ6P0Hf=S069RHP1UIFD0
J6QX06][J`1VIVH0JFUY06e]K@1YJFT0J6QX06m_K`1[Jf/0LG5a06][J`1^KVh0KFe]06QXJ01[Jf/0
JVYZ06a/K01_Kfl306a/K00>06UYJ@1_Kfl0NGUi079bLP1TI6@0KVi^07QhN01cLg<0LW9b07EeM@1c
Lg<0LG5a079bLP1jNWX207UiN@0?07IfMP1dM7@0LW9b07EeM@1nOWh0MGEe07IfMP20P800O7al07em
O@1gMgL0P82007]kN`1cLg<0O7al0080PX:201@0Ph>307YjNP1lO7`0OGem07IfMP1nOWh0NGUi08J6
QP1mOGd0OWin08>3P`21PH40OWin08R8R024Q8@0NWYj08F5Q@21PH40QXJ608R8R080Rh^;01d0QXJ6
08>3P`23Ph<0R8R808f=S@21PH40QXJ608^;R`24Q8@0RHV908B4Q02=SHd0QHF50820P02<S8`0RXZ:
08B4Q02;Rh/0QhN708V9R@24Q8@0RHV908J6QP1oOgl0SHf=08^;R`24Q8@0RHV908F5Q@0208f=S@0=
08B4Q02;Rh/0RXZ:08b<S02EUID0RHV908:2PP26QXH0NWYj08N7Q`2<S8`0SXj>08F5Q@0208:2PP<0
Q8B400l0Rh^;08>3P`2:RXX0QhN708:2PP2@T900R8R80820P027QhL0RXZ:08J6QP27QhL0Ogmo0861
P@1mOGd00`1oOgl01`1lO7`0Ogmo0861P@1kNg/0OGem08:2PP1lO7`00P20P8004@1iNGT0N7Qh07Ui
N@24Q8@0Ogmo07QhN01lO7`0MgMg06i^KP1hN7P0M7Ad07inOP1dM7@0MGEe079bLP1dM7@0Lg=c0080
NWYj00<0MgMg07=cL`1eMGD00P1gMgL03@1cLg<0LG5a07AdM01]KFd0LG5a07=cL`1^KVh0LW9b06m_
K`1]KFd0JVYZ079bLP1[Jf/00P1/K6`0201^KVh0K6a/079bLP1XJ6P0KVi^075aL@1ZJVX0L71`0P1/
K6`05P1ZJVX0IFEU06QXJ01`L700KFe]06UYJ@1ZJVX0Hf=S06ATI01YJFT0HF5Q069RHP1YJFT0JVYZ
065QH@1TI6@0GUiN06][J`1RHV80IFEU069RHP1SHf<206MWI`0506=SH`1VIVH0IVIV06IVIP1LG5`0
0P1PH6007P1WIfL0GUiN06][J`1SHf<0GUiN065QH@1PH600Hf=S069RHP1PH600HV9R065QH@1RHV80
J6QX065QH@1OGel0IfMW065QH@1MGEd0G5aL05mOG`1QHF40GUiN05mOG`1KFe/0GemO05YJFP1TI6@0
FUYJ05eMG@H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0H05mOG`1MGEd0
GEeM06UYJ@1QHF40Hf=S05UIF@1PH600HV9R05aLG01PH600JVYZ069RHP1SHf<0IfMW05eMG@1RHV80
Hf=S06ATI01WIfL0Hf=S06IVIP1UIFD0JFUY0P1QHF40:01RHV80IfMW06UYJ@1SHf<0HF5Q05mOG`1T
I6@0IVIV06QXJ01YJFT0I6AT06MWI`1VIVH0IfMW06YZJP1WIfL0IFEU06][J`1PH600L71`06YZJP1Y
JFT0IFEU06][J`1XJ6P0Hf=S06UYJ@1[Jf/0K6a/06e]K@1XJ6P0KFe]065QH@1XJ6P0JVYZ06a/K01]
KFd0K6a/07=cL`1`L702075aL@0>06][J`1ZJVX0Jf][06IVIP1aLG40N7Qh06m_K`1iNGT0LW9b07Qh
N01]KFd0LW9b075aL@1bLW8307=cL`0407UiN@1dM7@0Lg=c07moO`80M7Ad0180N7Qh07=cL`1cLg<0
MGEe07AdM01mOGd0NGUi07]kN`1iNGT0MGEe07]kN`1hN7P0Ph>307YjNP1mOGd0O7al07UiN@1nOWh2
07]kN`0G07inOP1oOgl0NWYj07emO@2<S8`0Ogmo07emO@25QHD0PX:208B4Q01nOWh0Q8B407moO`24
Q8@0Ogmo08F5Q@1kNg/0QhN708b<S026QXH0OWin0820P024Q8@00P27QhL05`26QXH0OWin07inOP25
QHD0Q8B408F5Q@29RHT0QhN708B4Q027QhL0R8R808:2PP24Q8@0PH6108J6QP28R8P0OGem08B4Q025
QHD0PX:207QhN028R8P0QHF50080QXJ600L0RXZ:08b<S025QHD0Ph>308F5Q@1oOgl0Ph>30080QHF5
01H0RHV908R8R024Q8@0PX:208B4Q022PX80OWin0861P@2;Rh/0QXJ608N7Q`22PX80QHF50820P027
QhL0Q8B408F5Q@27QhL0OWin08J6QP28R8P0Ph>30P1mOGd02022PX80Q8B407YjNP1oOgl0Ng]k07al
O01nOWh0Ng]k0P22PX801P1iNGT0Ogmo07]kN`1cLg<0O7al07UiN@80M7Ad0100Kfm_07MgM`23Ph<0
O7al07IfMP1eMGD0Ng]k075aL@1jNWX0M7Ad07MgM`1jNWX0MgMg06][J`1_Kfl0Lg=c0P1dM7@0<01i
NGT0N7Qh07MgM`1dM7@0LW9b06m_K`1cLg<0JVYZ079bLP1YJFT0K6a/06UYJ@1[Jf/0IfMW06IVIP1S
Hf<0IFEU06YZJP1eMGD0LG5a06UYJ@1ZJVX0IVIV06i^KP1UIFD0L71`075aL@1WIfL0J6QX06EUI@1[
Jf/0JVYZ06=SH`1MGEd0Jf][065QH@1VIVH0J6QX069RHP1XJ6P0IFEU06=SH`1IFET0HV9R06=SH`1T
I6@0IVIV06QXJ0<0IVIV00h0FUYJ065QH@1WIfL0GUiN065QH@1NGUh0GemO06ATI01SHf<0I6AT069R
HP1LG5`0Hf=S06YZJP80IFEU00<0Hf=S05iNGP1OGel00`1KFe/205mOG`05061PH01QHF40GUiN06=S
H`1IFET00P1QHF400`1LG5`0GUiN0=WIf@050=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3I
fMT00`3IfMT06`1RHV80F5QH05iNGP1UIFD0GEeM069RHP1PH600FUYJ065QH@1LG5`0IVIV069RHP1U
IFD0GemO069RHP1SHf<0I6AT06UYJ@1QHF40HV9R06MWI`1PH600IFEU065QH@1UIFD0Hf=S06ATI002
06EUI@0W069RHP1WIfL0HV9R06IVIP1TI6@0JVYZ06ATI01QHF40I6AT065QH@1RHV80J6QX06EUI@1X
J6P0IVIV06EUI@1YJFT0Hf=S065QH@1ZJVX0IFEU06YZJP1LG5`0Jf][06QXJ01_Kfl0IfMW06a/K01[
Jf/0KVi^07=cL`1/K6`0Jf][06YZJP1^KVh0KFe]06a/K01bLW80KVi^0080K6a/00<0Jf][06m_K`1`
L7000P1eMGD0601]KFd0Lg=c06a/K01`L700K6a/079bLP1ZJVX0MGEe07MgM`1aLG40L71`07MgM`1`
L700NGUi07IfMP1hN7P0MWIf079bLP1hN7P0MGEe07YjNP1lO7`0MWIf07alO080NWYj0280MgMg07Qh
N01nOWh0MGEe07alO01gMgL0Ogmo0820P01iNGT0P8200861P@20P800OWin08F5Q@23Ph<0P82007]k
N`1lO7`0QXJ608V9R@1nOWh0PX:20820P022PX80N7Qh08:2PP25QHD0Ph>307alO02:RXX0QXJ607al
O023Ph<0Rh^;0P24Q8@07`22PX80Ph>308^;R`28R8P0S8b<08F5Q@24Q8@0Ph>308b<S02;Rh/0PX:2
08B4Q01nOWh0PX:208J6QP1kNg/0QXJ608Z:RP26QXH0QhN708B4Q02;Rh/0QXJ608b<S02>SXh0RHV9
08B4Q02;Rh/0QHF508J6QP29RHT00P20P8003P22PX80OWin08J6QP23Ph<0RHV907moO`1lO7`0SHf=
08N7Q`22PX80MGEe08f=S@26QXH0Ph>30P22PX803P26QXH0O7al0861P@21PH40QHF508:2PP21PH40
OWin08:2PP1fMWH0Q8B407inOP22PX80OGem0P1iNGT01P21PH40P8200820P01fMWH0LW9b07YjNP80
OGem00X0Ng]k07EeM@25QHD0OGem071`L01hN7P0PH6107MgM`1bLW80MGEe0P1aLG4207IfMP0606i^
KP1eMGD0L71`06i^KP1dM7@0LG5a0P1`L7000`1iNGT0N7Qh079bLP0207IfMP0M07=cL`1/K6`0IVIV
065QH@1[Jf/0KVi^071`L01^KVh0L71`075aL@1]KFd0KVi^06e]K@1^KVh0K6a/06][J`1UIFD0J6QX
06a/K01WIfL0HF5Q06e]K@1XJ6P0JFUY06EUI@1TI6@0G5aL06QXJ01RHV800P1XJ6P206IVIP0@06QX
J01RHV80GEeM06=SH`1UIFD0Hf=S05eMG@1PH600HF5Q06QXJ01ZJVX0HV9R05YJFP1UIFD0I6AT06=S
H`80G5aL00/0GUiN05aLG01RHV80IVIV06=SH`1UIFD0Fe]K06MWI`1MGEd0H61P06YZJP0206ATI00;
061PH01QHF40HF5Q05aLG01OGel0FEUI065QH@1IFET0G5aL05eMG@1NGUh00P1LG5`60=WIf@400000
0@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT2061PH00;065QH@1OGel0IFEU069RHP1UIFD0
G5aL069RHP1OGel0HV9R06ATI01JFUX00P1UIFD02@1PH600Hf=S06=SH`1TI6@0JVYZ06MWI`1RHV80
I6AT05iNGP0206ATI00706MWI`1VIVH0IVIV065QH@1WIfL0HF5Q06YZJP0206=SH`0G069RHP1TI6@0
IVIV069RHP1YJFT0J6QX06EUI@1XJ6P0I6AT06MWI`1[Jf/0G5aL06m_K`1[Jf/0IfMW06a/K01XJ6P0
KVi^06ATI01UIFD0K6a/06i^KP1[Jf/00`1/K6`03@1ZJVX0J6QX06a/K01`L700JFUY071`L01^KVh0
L71`07=cL`1`L700Lg=c06e]K@1`L7000`1^KVh02`1_Kfl0M7Ad06e]K@1^KVh0MGEe06i^KP1_Kfl0
J6QX06UYJ@1dM7@0KVi^0080M7Ad0P1gMgL04@1^KVh0MgMg07emO@1lO7`0MWIf07MgM`1dM7@0NGUi
07MgM`1jNWX0OGem07AdM01`L700O7al07emO@23Ph<0Ng]k0080O7al00L0PX:208B4Q01fMWH0PX:2
07YjNP1oOgl0PX:20080OGem00@0P82008J6QP24Q8@0O7al0P22PX803P23Ph<0RXZ:08V9R@22PX80
Q8B407UiN@2:RXX0PX:208Z:RP26QXH0OWin08R8R024Q8@0QHF50P24Q8@03@2:RXX0QhN708B4Q02:
RXX0NWYj07moO`20P800OGem07]kN`22PX80QHF508N7Q`1lO7`00P27QhL09P23Ph<0SXj>08F5Q@25
QHD0R8R808b<S02;Rh/0Ph>308b<S01nOWh0Q8B408>3P`24Q8@0S8b<0861P@28R8P0QXJ607inOP26
QXH0Ph>307emO@25QHD0Ph>30820P01oOgl0P82007alO020P800QXJ607inOP29RHT0Ph>308:2PP24
Q8@0O7al07moO`1jNWX0Ng]k0P1mOGd01P1nOWh0NGUi08B4Q01lO7`0N7Qh07alO080NWYj00<0NGUi
07moO`1kNg/00P1jNWX00`1oOgl0N7Qh07UiN@0207MgM`0607QhN01cLg<0MWIf07QhN01jNWX0LG5a
0P1dM7@0201hN7P0L71`07alO01hN7P0Lg=c07IfMP1`L700KVi^0P1jNWX0301`L700LW9b06a/K01b
LW80Jf][06m_K`1aLG40IVIV071`L01VIVH0JFUY06IVIP80JFUY00T0Hf=S06][J`1WIfL0K6a/06QX
J01]KFd0H61P06YZJP1QHF400P1TI6@00`1UIFD0H61P05eMG@02069RHP0:06MWI`1YJFT0IFEU06AT
I01RHV80I6AT06=SH`1QHF40Hf=S06EUI@80G5aL00/0JVYZ06ATI01YJFT0JFUY06QXJ01MGEd0FUYJ
05iNGP1RHV80IFEU06ATI00205]KF`0806QXJ01PH600Hf=S061PH01OGel0GUiN06MWI`1KFe/206=S
H`0605mOG`1QHF40GUiN05mOG`1MGEd0HF5Q0`1MGEd01`1UIFD0Hf=S06=SH`1PH600G5aL05mOG`1K
Fe/01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI01h0HV9R05iNGP1/K6`0
HV9R06=SH`1LG5`0JVYZ06=SH`1PH600G5aL06IVIP1TI6@0GUiN069RHP1MGEd0I6AT069RHP1OGel0
Hf=S065QH@1PH600HF5Q06ATI01SHf<0G5aL06=SH`1WIfL0Hf=S06YZJP1RHV8206EUI@0E05iNGP1X
J6P0HV9R06MWI`1TI6@0IFEU06IVIP1TI6@0HF5Q06MWI`1TI6@0IfMW06IVIP1SHf<0IfMW06ATI01V
IVH0HV9R06=SH`1YJFT0K6a/0080Jf][00H0IVIV06QXJ01XJ6P0JFUY06QXJ01SHf<206][J`0N07=c
L`1UIFD0IVIV071`L01/K6`0J6QX06e]K@1aLG40Kfm_06][J`1_Kfl0L71`06i^KP1`L700M7Ad06YZ
JP1aLG40Lg=c06i^KP1iNGT0Kfm_06e]K@1bLW80Ng]k06e]K@1^KVh0NGUi071`L01hN7P0MgMg0P1b
LW803@1fMWH0NGUi07IfMP1gMgL0NWYj07inOP1oOgl0PH61079bLP1kNg/0M7Ad07YjNP1lO7`00P1k
Ng/0:`1lO7`0Ng]k07QhN01hN7P0O7al07moO`1mOGd0Q8B40861P@28R8P0QXJ60820P01jNWX0QXJ6
0820P01nOWh0Ng]k07alO020P800OWin08J6QP22PX80QXJ608V9R@23Ph<0Q8B408>3P`20P800Rh^;
08J6QP2?Shl0Rh^;08V9R@2?Shl0QHF508B4Q023Ph<0Ng]k07alO01oOgl0PH6108Z:RP22PX800P1n
OWh07022PX80P82008F5Q@2;Rh/0Q8B407moO`22PX80RHV908N7Q`28R8P0S8b<08R8R021PH40R8R8
08F5Q@23Ph<0Ng]k07alO020P800OGem08>3P`1iNGT0OGem08:2PP21PH40OWin0861P@23Ph<30820
P00K07moO`22PX80PH6108V9R@24Q8@0N7Qh07inOP1hN7P0Ph>307YjNP24Q8@0Ogmo0820P01dM7@0
NWYj07]kN`1mOGd0Ng]k07alO01kNg/0N7Qh07moO`1hN7P0LG5a07]kN`1fMWH0NGUi00<0MWIf0140
MGEe06m_K`1bLW80MWIf07MgM`1fMWH0LW9b075aL@1cLg<0Ng]k07emO@1aLG40Kfm_06a/K01bLW80
OWin07YjNP0207EeM@0407=cL`1WIfL0IFEU06YZJP80JFUY02X0KFe]06i^KP1^KVh0Jf][06i^KP1W
IfL0K6a/06YZJP1XJ6P0K6a/06][J`1bLW80KVi^06IVIP1/K6`0JFUY05iNGP1QHF40JFUY061PH01R
HV80KFe]06MWI`1TI6@0IVIV05eMG@1UIFD0J6QX065QH@1RHV80IfMW05eMG@1QHF40GemO06UYJ@1X
J6P0HV9R05UIF@1TI6@0H61P06MWI`1PH60305]KF`0@06=SH`1TI6@0HF5Q069RHP1SHf<0GEeM06IV
IP1YJFT0GEeM06=SH`1PH600HF5Q05eMG@1JFUX0GEeM06ATI080GemO00X0IfMW05ADE01NGUh0EeMG
05mOG`1KFe/0G5aL05iNGP1GEeL0GEeM1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI
00<0fMWI00H0G5aL061PH01PH600HV9R05eMG@1VIVH205iNGP0<06EUI@1PH600H61P06=SH`1UIFD0
H61P069RHP1VIVH0GUiN06IVIP1TI6@0GUiN0P1RHV80301QHF40H61P069RHP1SHf<0IVIV06EUI@1V
IVH0Hf=S06MWI`1PH600I6AT06IVIP80J6QX01L0HF5Q06UYJ@1YJFT0HV9R06a/K01RHV80IFEU06UY
J@1WIfL0K6a/06=SH`1WIfL0JFUY06YZJP1[Jf/0H61P06EUI@1XJ6P0IVIV06QXJ01[Jf/0M7Ad065Q
H@0206UYJ@08079bLP1^KVh0KVi^06][J`1XJ6P0JFUY075aL@1YJFT306e]K@0506][J`1]KFd0IfMW
06m_K`1[Jf/00P1ZJVX04`1]KFd0KVi^06UYJ@1^KVh0Kfm_071`L01dM7@0L71`07AdM01eMGD0LG5a
06e]K@1dM7@0N7Qh06UYJ@1fMWH0MgMg075aL@1eMGD00P1iNGT0101fMWH0NGUi07EeM@1cLg<207Ee
M@0:07MgM`1iNGT0NWYj07alO01fMWH0NWYj08F5Q@20P800MgMg0861P@80P82004<0QHF507inOP1l
O7`0P82008F5Q@1mOGd0NGUi0861P@1oOgl0PH6107UiN@1mOGd0Q8B407emO@24Q8@0P82007moO`1m
OGd0QXJ60861P@2;Rh/0R8R807moO`28R8P0Ph>308B4Q029RHT0Rh^;0861P@20P800Q8B408N7Q`20
P800PH6108N7Q`21PH40Q8B408V9R@1nOWh0PX:208J6QP22PX80Ph>308F5Q@27QhL0RHV908b<S028
R8P0QHF508R8R01kNg/0Q8B408N7Q`1gMgL0QHF508B4Q021PH40Rh^;08F5Q@21PH40QXJ607alO01j
NWX0Ng]k08J6QP1iNGT0NWYj0080Ph>300`0O7al08F5Q@1mOGd0O7al07inOP1oOgl0MWIf08:2PP1n
OWh0OGem07AdM01lO7`20820P00:07alO020P800MgMg07QhN01eMGD0NGUi07IfMP1nOWh0M7Ad07=c
L`80N7Qh05X0L71`07UiN@1`L700M7Ad07]kN`1^KVh0LW9b07AdM01hN7P0L71`07=cL`1kNg/0Kfm_
07EeM@1aLG40M7Ad07MgM`1aLG40MgMg07=cL`21PH40Lg=c06m_K`1dM7@0JVYZ06UYJ@1aLG40KFe]
06a/K01]KFd0IVIV06UYJ@1]KFd0IFEU06][J`1/K6`0Kfm_06QXJ01]KFd0IVIV06MWI`1YJFT0IfMW
061PH01TI6@0Hf=S06UYJ@1WIfL0J6QX06i^KP1WIfL0IFEU05iNGP1XJ6P0HV9R061PH01YJFT0HF5Q
06IVIP1TI6@0Hf=S065QH@1UIFD0IVIV06QXJ01RHV80IFEU05aLG01MGEd0HF5Q069RHP1OGel0HF5Q
05UIF@1PH600F5QH061PH01WIfL0HF5Q06IVIP1WIfL0GUiN069RHP1QHF40HV9R06=SH`1JFUX0FEUI
069RHP1OGel2069RHP0905eMG@1NGUh0HF5Q05UIF@1NGUh0FUYJ05MGE`1DE5@0FEUI00H0fMWI0@00
00010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0:05]KF`1OGel0HV9R061PH01RHV80IVIV
069RHP1WIfL0HV9R065QH@80IVIV01`0H61P05aLG01RHV80FUYJ06MWI`1OGel0HV9R065QH@1RHV80
IfMW06EUI@1SHf<0H61P06=SH`1YJFT0HF5Q05mOG`1QHF40IVIV06QXJ01UIFD0K6a/06MWI`1RHV80
J6QX061PH01OGel0JFUY0P1XJ6P0201TI6@0JVYZ06YZJP1SHf<0H61P06IVIP1UIFD0H61P0P1TI6@0
2P1PH600IVIV06QXJ01VIVH0J6QX06IVIP1^KVh0Jf][071`L01WIfL206UYJ@0X07=cL`1/K6`0JFUY
06YZJP1UIFD0Jf][06UYJ@1ZJVX0HV9R06m_K`1fMWH0J6QX06UYJ@1ZJVX0KFe]079bLP1aLG40LW9b
06i^KP1fMWH0J6QX06][J`1/K6`0Kfm_06a/K01cLg<0M7Ad07IfMP1jNWX0MWIf07MgM`1^KVh0M7Ad
07UiN@1bLW80N7Qh079bLP1gMgL0Lg=c079bLP80N7Qh01D0LW9b07EeM@1iNGT0NGUi07QhN01eMGD0
NGUi0820P023Ph<0OWin0861P@1jNWX0P82007moO`1nOWh0QHF507inOP1kNg/0P82008F5Q@1oOgl0
0P24Q8@0301mOGd0RXZ:08V9R@1oOgl0O7al07moO`2@T900PX:207UiN@24Q8@0Rh^;08R8R0<0PX:2
04D0Ogmo08>3P`1jNWX0PH610820P024Q8@0Rh^;0861P@23Ph<0O7al08>3P`21PH40O7al07]kN`28
R8P0OWin08V9R@22PX80OWin08N7Q`23Ph<0Q8B408V9R@22PX80OGem07inOP26QXH0PH6107emO@1n
OWh0PX:207inOP1kNg/0Q8B40820P022PX80OWin07emO@1hN7P0MgMg07YjNP23Ph<0NWYj07alO01h
N7P0OWin0861P@1hN7P0NGUi07inOP1gMgL0Ogmo07MgM`1jNWX0Ng]k07IfMP1oOgl0NWYj07]kN`1n
OWh0O7al07QhN01fMWH0MgMg0820P01mOGd0Lg=c07YjNP1eMGD00P1fMWH02`1gMgL0NGUi06i^KP1h
N7P0J6QX071`L01dM7@0LW9b075aL@1gMgL0Kfm_0080LG5a00L0L71`06a/K01hN7P0KVi^07MgM`1f
MWH0L71`0080MWIf0100IfMW07=cL`1aLG40L71`06m_K`1/K6`0KFe]071`L01[Jf/0JVYZ06i^KP1W
IfL0KFe]06IVIP1/K6`0JVYZ0P1]KFd02@1WIfL0Jf][06EUI@1SHf<0JVYZ06i^KP1SHf<0HF5Q06=S
H`02065QH@0506ATI01SHf<0IVIV06=SH`1QHF400P1XJ6P02@1RHV80HF5Q06YZJP1UIFD0H61P065Q
H@1TI6@0HV9R06EUI@0205aLG00N06EUI@1PH600GemO069RHP1KFe/0EEEE05mOG`1MGEd0EeMG06a/
K01QHF40IFEU05aLG01PH600HV9R05IFEP1SHf<0FUYJ05mOG`1PH600G5aL05eMG@1IFET0GEeM05aL
G01NGUh0I6AT065QH@1KFe/0Hf=S1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0
fMWI00H0Hf=S061PH01KFe/0GUiN06=SH`1LG5`206=SH`80HV9R00P0I6AT06=SH`1VIVH0GemO05eM
G@1OGel0IfMW065QH@80H61P00<0Hf=S05mOG`1OGel00P1SHf<0101UIFD0HV9R05mOG`1KFe/306AT
I00=06QXJ01PH600GemO06MWI`1VIVH0Hf=S065QH@1RHV80IVIV06e]K@1NGUh0IfMW06=SH`0206IV
IP0606YZJP1VIVH0HV9R06ATI01YJFT0IfMW0P1ZJVX0201VIVH0IfMW06IVIP1UIFD0LW9b06IVIP1d
M7@0HV9R0P1^KVh01@1_Kfl0JFUY06m_K`1/K6`0J6QX0080KFe]00<0KVi^06YZJP1bLW800P1/K6`0
1P1gMgL0K6a/06QXJ01cLg<0K6a/071`L080Kfm_00D0K6a/075aL@1XJ6P0Kfm_06a/K00207=cL`0E
071`L01eMGD0NWYj075aL@1dM7@0Lg=c07EeM@1kNg/0NGUi079bLP1gMgL0M7Ad07]kN`1lO7`0NGUi
07inOP1lO7`0MGEe07MgM`1jNWX0OGem0080Ph>301@0Ogmo07alO022PX80Ph>307moO`1mOGd0PH61
08N7Q`1oOgl0PX:20820P01lO7`0PH6107YjNP21PH40MGEe07alO01oOgl0RXZ:0861P@<0Q8B400/0
PH6108B4Q022PX80PX:208F5Q@1jNWX0P82008F5Q@1mOGd0Ogmo08:2PP0207inOP090820P01kNg/0
O7al07emO@21PH40Q8B408F5Q@1jNWX0Ogmo0080R8R80P22PX804020P800PX:208:2PP26QXH0QHF5
07inOP22PX80Q8B407QhN01jNWX0OWin07moO`29RHT0Ogmo08>3P`22PX820861P@0<08^;R`21PH40
Ng]k07UiN@23Ph<0OGem07]kN`1nOWh0MgMg0861P@1nOWh0Ogmo0P1iNGT0101kNg/0P82007inOP1i
NGT207YjNP0507EeM@1dM7@0OGem07YjNP1mOGd00`1fMWH0301bLW80N7Qh07MgM`1eMGD0MWIf07=c
L`1]KFd0L71`079bLP1cLg<0MGEe06i^KP80M7Ad00P0L71`07AdM01aLG40K6a/06m_K`1^KVh0Lg=c
07IfMP80L71`01`0KFe]075aL@1iNGT0M7Ad06i^KP1]KFd0JVYZ079bLP1aLG40LW9b075aL@1]KFd0
LG5a071`L01ZJVX0J6QX07EeM@1_Kfl0Jf][06QXJ01WIfL0I6AT06UYJ@1^KVh0HV9R05iNGP1WIfL0
Hf=S0P1VIVH02P1NGUh0IVIV06IVIP1ZJVX0HV9R06UYJ@1TI6@0IFEU065QH@1VIVH206=SH`09069R
HP1SHf<0IfMW05iNGP1SHf<0G5aL06ATI01PH600FUYJ00<0HF5Q00@0GemO06IVIP1NGUh0IfMW0P1U
IFD02@1PH600G5aL05]KF`1JFUX0H61P06][J`1RHV80GEeM05mOG`02065QH@0905mOG`1IFET0GemO
05YJFP1RHV80GUiN05]KF`1LG5`0Hf=S00H0fMWI0@0000010=WIf@005P3IfMT2000000@0fMWI00L0
Fe]K05eMG@1MGEd0G5aL05mOG`1RHV80GemO0080H61P00T0JVYZ05mOG`1NGUh0Hf=S069RHP1TI6@0
GemO06ATI01JFUX00P1PH6002P1UIFD0FEUI05mOG`1SHf<0GEeM06MWI`1MGEd0HF5Q06QXJ01TI6@2
06EUI@0=06=SH`1RHV80JFUY06EUI@1TI6@0GEeM069RHP1YJFT0Hf=S06QXJ01PH600J6QX06=SH`02
06ATI00806IVIP1TI6@0Hf=S06QXJ01QHF40Kfm_06YZJP1[Jf/206MWI`0C06YZJP1PH600IVIV06i^
KP1_Kfl0J6QX06i^KP1YJFT0Jf][06UYJ@1`L700LG5a06i^KP1[Jf/0IVIV06m_K`1YJFT0KVi^06QX
J00206i^KP0?075aL@1cLg<0IVIV06][J`1bLW80Jf][06m_K`1XJ6P0KVi^06m_K`1`L700LG5a06m_
K`1aLG40KFe]00<0L71`00@0M7Ad079bLP1_Kfl0M7Ad0`1fMWH01`1cLg<0N7Qh07IfMP1iNGT0MgMg
07YjNP1iNGT00P1nOWh307EeM@0F07MgM`1kNg/0LW9b0861P@1nOWh0Ng]k08>3P`25QHD0N7Qh07]k
N`1jNWX0OGem07UiN@1kNg/0Q8B408N7Q`1oOgl0QXJ607]kN`28R8P0O7al07inOP80Q8B400D0PH61
07alO01oOgl0NGUi0820P00208:2PP0507]kN`24Q8@0PX:208F5Q@22PX800P23Ph<06`25QHD0PH61
08F5Q@20P800QXJ60861P@20P800QXJ608>3P`1nOWh0Q8B40861P@25QHD0SXj>08>3P`26QXH0PX:2
08B4Q01nOWh0O7al07YjNP1kNg/0OWin07moO`1mOGd0P82008:2PP0207inOP0;0820P021PH40O7al
07UiN@1lO7`0M7Ad07alO01hN7P0Ng]k07alO01mOGd00P1kNg/04P1eMGD0OGem07UiN@1fMWH0NWYj
07IfMP1cLg<0M7Ad07YjNP1bLW80MGEe07AdM01_Kfl0MWIf07emO@1iNGT0MWIf07UiN@80Lg=c00<0
MGEe079bLP1kNg/00P1cLg<04`1`L700Kfm_07=cL`1[Jf/0Kfm_06QXJ01YJFT0MGEe06m_K`1aLG40
M7Ad07IfMP1hN7P0Lg=c075aL@1jNWX0Kfm_06a/K01ZJVX00P1`L70206m_K`0=075aL@1]KFd0LG5a
071`L01_Kfl0KVi^06a/K01WIfL0K6a/06e]K@1XJ6P0IFEU06i^KP0206EUI@0<06ATI01VIVH0I6AT
06IVIP1ZJVX0HV9R06][J`1MGEd0HF5Q06e]K@1RHV80Jf][0P1QHF402@1JFUX0IfMW061PH01TI6@0
HV9R05iNGP1LG5`0Fe]K061PH00205iNGP0405]KF`1JFUX0IFEU069RHP80Fe]K00D0IFEU065QH@1N
GUh0IFEU065QH@0305iNGP03065QH@1MGEd0H61P0080HF5Q00`0GEeM05YJFP1SHf<0GemO069RHP1K
Fe/0HV9R05aLG01DE5@0GEeM05UIF@1NGUh50=WIf@8000000@3IfMT001H0fMWI00<000000=WIf@3I
fMT00`3IfMT03@1PH600G5aL06EUI@1YJFT0IFEU065QH@1SHf<0GemO06MWI`1QHF40IVIV05]KF`1S
Hf<00P1OGel05@1VIVH0IfMW069RHP1XJ6P0GemO06ATI01MGEd0I6AT05aLG01OGel0HV9R06MWI`1U
IFD0JFUY06EUI@1MGEd0GemO069RHP1YJFT0I6AT06EUI@0206IVIP0P06=SH`1XJ6P0IfMW06EUI@1S
Hf<0IFEU06][J`1QHF40IVIV061PH01VIVH0H61P06QXJ01aLG40J6QX06i^KP1TI6@0JVYZ06MWI`1a
LG40HV9R06ATI01XJ6P0Jf][06=SH`1TI6@0KFe]06MWI`1XJ6P0I6AT06e]K@1aLG4206UYJ@0O06][
J`1ZJVX0J6QX06YZJP1[Jf/0KFe]06a/K01`L700I6AT06m_K`1aLG40LW9b06][J`1]KFd0Jf][07=c
L`1ZJVX0Kfm_079bLP1^KVh0Lg=c06YZJP1jNWX0Kfm_07UiN@1_Kfl0NGUi07QhN01dM7@0MWIf07Ee
M@0207UiN@0:075aL@1dM7@0NWYj07EeM@1aLG40NWYj07inOP1jNWX0OWin07alO080MWIf0`1nOWh0
2@1lO7`0Ng]k0820P01iNGT0Ng]k0861P@1eMGD0MWIf08F5Q@0208B4Q01M07IfMP24Q8@0PX:207mo
O`20P800OWin07moO`2;Rh/0PX:207]kN`22PX80P82007]kN`1nOWh0Q8B407inOP1oOgl0QHF507Yj
NP1oOgl0O7al08>3P`21PH40Ph>308B4Q020P800NWYj07moO`1gMgL0OWin0861P@1mOGd0P82007Yj
NP25QHD0OWin0861P@20P800PX:207moO`22PX80OWin08F5Q@20P800Q8B407YjNP1mOGd0QXJ60861
P@1mOGd0PH6107emO@1_Kfl0NWYj07alO01jNWX0OGem07UiN@22PX80NGUi0820P01kNg/0Ogmo07If
MP1kNg/0KVi^07QhN01jNWX0NGUi07YjNP1fMWH0NGUi07=cL`1hN7P0L71`07MgM`1`L700M7Ad07If
MP1aLG40MgMg07IfMP1bLW80Lg=c06][J`1/K6`0Jf][07EeM@1ZJVX0LG5a079bLP1hN7P0MGEe00<0
LG5a00T0GemO06m_K`1`L700JVYZ06a/K01]KFd0M7Ad06m_K`1hN7P00P1`L7002@1bLW80N7Qh071`
L01XJ6P0L71`06e]K@1eMGD0M7Ad075aL@0206][J`0T06e]K@1[Jf/0KVi^06][J`1UIFD0J6QX06e]
K@1YJFT0HV9R075aL@1XJ6P0IfMW061PH01YJFT0HV9R05mOG`1WIfL0I6AT069RHP1WIfL0Hf=S06QX
J01TI6@0EUIF06][J`1NGUh0Hf=S06MWI`1YJFT0F5QH065QH@1OGel0FUYJ06EUI@1WIfL0GEeM0P1Q
HF402@1NGUh0IfMW05iNGP1MGEd0IFEU05iNGP1IFET0H61P05eMG@0205YJFP0=05iNGP1KFe/0HF5Q
05YJFP1RHV80GEeM05iNGP1bLW80GEeM05aLG01KFe/0IFEU05UIF@02065QH@03061PH03IfMT0fMWI
00@0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0Y05YJFP1PH600IFEU05]K
F`1MGEd0H61P06=SH`1RHV80GemO05iNGP1OGel0GUiN065QH@1FEUH0Fe]K06EUI@1QHF40EeMG069R
HP1NGUh0GEeM06EUI@1KFe/0Hf=S065QH@1MGEd0HF5Q06][J`1KFe/0H61P06MWI`1XJ6P0Hf=S06IV
IP1XJ6P0HV9R065QH@1VIVH0IFEU065QH@1OGel00P1VIVH02`1UIFD0G5aL06IVIP1ZJVX0I6AT06=S
H`1TI6@0IVIV06EUI@1PH600Hf=S0080HV9R00H0IVIV06=SH`1UIFD0JFUY06e]K@1WIfL206QXJ00I
06EUI@1]KFd0J6QX075aL@1VIVH0KVi^075aL@1WIfL0JFUY06=SH`1VIVH0L71`06i^KP1]KFd0K6a/
06MWI`1TI6@0KFe]06UYJ@1_Kfl0MGEe079bLP1aLG40JVYZ07AdM00207=cL`0:06YZJP1dM7@0MGEe
06m_K`1gMgL0MWIf07AdM01]KFd0M7Ad071`L080MWIf02/0LW9b07=cL`1eMGD0M7Ad07IfMP1iNGT0
N7Qh07IfMP1oOgl0OWin08B4Q01cLg<0Ng]k07emO@21PH40Ng]k08R8R01gMgL0O7al07YjNP1oOgl0
MgMg08B4Q01lO7`0Ng]k07alO01kNg/0NGUi07]kN`22PX80P82008:2PP1nOWh0NWYj07emO@20P800
OGem08:2PP24Q8@0Ogmo07alO020P800Ph>30080Q8B401H0PX:208J6QP1iNGT0NWYj07inOP21PH40
Ng]k07alO021PH40MgMg07QhN022PX80NWYj07alO01mOGd0OWin0820P023Ph<0PX:20861P@25QHD0
PH610P1iNGT01`1oOgl0P82007UiN@1jNWX0P82008:2PP26QXH00P1oOgl01@1iNGT0OGem07YjNP1n
OWh0Ph>30080OGem0240Ogmo07AdM01fMWH0O7al07MgM`1`L700MGEe07UiN@1gMgL0N7Qh07]kN`1i
NGT0N7Qh07alO01bLW80KVi^07EeM@1_Kfl0L71`07=cL`1eMGD0NWYj06i^KP1eMGD0M7Ad075aL@1Y
JFT0N7Qh07IfMP1ZJVX0LW9b07UiN@1ZJVX00P1cLg<00`1/K6`0LG5a071`L00206e]K@0806a/K01b
LW80JFUY07MgM`1ZJVX0LG5a07EeM@1fMWH2071`L00T06m_K`1aLG40MGEe07]kN`1^KVh0LW9b075a
L@1`L700MWIf06a/K01YJFT0K6a/06i^KP1eMGD0L71`06i^KP1ZJVX0Jf][06EUI@1YJFT0K6a/06e]
K@1SHf<0IfMW069RHP1VIVH0KVi^06UYJ@1]KFd0HF5Q06EUI@1TI6@0IFEU05eMG@1QHF40IFEU0P1K
Fe/07P1UIFD0H61P06ATI01QHF40GUiN05mOG`1MGEd0GUiN06ATI01SHf<0H61P069RHP1SHf<0GUiN
05MGE`1PH600GUiN065QH@1TI6@0IFEU065QH@1SHf<0EeMG05mOG`1QHF40GemO06=SH`1RHV80FUYJ
065QH@80H61P00H0HV9R05mOG`1QHF40GEeM05aLG01OGel60=WIf@4000000@3IfMT001H0fMWI00<0
00000=WIf@3IfMT00`3IfMT0=@1JFUX0H61P05iNGP1LG5`0HF5Q05aLG01OGel0I6AT06UYJ@1OGel0
I6AT05iNGP1OGel0FUYJ069RHP1TI6@0GEeM06QXJ01RHV80H61P05]KF`1NGUh0HV9R061PH01IFET0
H61P069RHP1HF5P0HF5Q05iNGP1PH600HF5Q061PH01YJFT0Jf][06EUI@1SHf<0IFEU06YZJP1PH600
JVYZ06MWI`1OGel0IVIV06UYJ@1UIFD0HF5Q06QXJ01`L700IVIV06EUI@1WIfL0I6AT0080J6QX0200
IVIV05eMG@1TI6@0JFUY06m_K`1TI6@0K6a/06m_K`1XJ6P0HV9R06QXJ01RHV80Hf=S06UYJ@1/K6`0
Jf][05eMG@1WIfL0M7Ad06][J`1aLG40M7Ad06QXJ01_Kfl0K6a/06i^KP1cLg<0IVIV06a/K01_Kfl0
Lg=c06a/K080Kfm_0180MgMg075aL@1`L700M7Ad06m_K`1`L700LG5a07IfMP1cLg<0MGEe079bLP1`
L700Lg=c07QhN01eMGD0MWIf07AdM01/K6`207IfMP0I07MgM`1eMGD0MWIf07UiN@1fMWH0Ph>307Ad
M01kNg/0Lg=c07QhN01oOgl0P82007moO`21PH40NGUi07]kN`1nOWh0MgMg07moO`20P800Ng]k07Yj
NP1nOWh0PH610820P00207inOP0:07emO@20P800N7Qh07YjNP1oOgl0NGUi08J6QP1lO7`0OGem07]k
N`80PH6102X0OWin0820P01oOgl0P82007moO`1hN7P0Ng]k08B4Q023Ph<0MWIf0820P01jNWX0NGUi
0861P@26QXH0PH6108B4Q020P800N7Qh07moO`22PX80NWYj08:2PP21PH40O7al07moO`1jNWX0Ogmo
08J6QP22PX80Ph>307]kN`20P800NGUi07alO01kNg/0MWIf07]kN`1oOgl0N7Qh07alO01mOGd207Yj
NP0407EeM@1gMgL0LW9b07moO`80MgMg00/0JVYZ07UiN@1lO7`0MWIf07emO@1jNWX0LW9b06a/K01d
M7@0OGem07EeM@0207=cL`0H07IfMP1gMgL0LW9b071`L01eMGD0Kfm_07AdM01`L700M7Ad075aL@1_
Kfl0LW9b06QXJ01aLG40LW9b06i^KP1cLg<0Jf][071`L01aLG40IfMW07=cL`1aLG40Kfm_0P1`L700
2`1fMWH0Kfm_06m_K`1iNGT0LG5a07AdM01_Kfl0L71`07EeM@1fMWH0Kfm_0080KVi^00X0Kfm_071`
L01bLW80KFe]075aL@1XJ6P0LG5a06EUI@1^KVh0HF5Q0P1PH6001P1QHF40I6AT069RHP1JFUX0I6AT
06EUI@80IVIV02@0H61P065QH@1IFET0GemO05eMG@1UIFD0H61P05]KF`1JFUX0Fe]K05YJFP1MGEd0
FEUI065QH@1PH600IVIV061PH01OGel0Hf=S065QH@1GEeL0GEeM065QH@1OGel0FEUI05YJFP1WIfL0
JFUY05mOG`1RHV80H61P05iNGP1JFUX0HV9R06ATI01NGUh205eMG@0605iNGP1TI6@0HV9R05mOG`1I
FET0HF5Q1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00h0Fe]K05iNGP1N
GUh0HV9R05mOG`1QHF40I6AT06=SH`1MGEd0Hf=S069RHP1TI6@0GUiN06][J`80GemO0300G5aL06EU
I@1SHf<0GUiN06=SH`1OGel0HV9R05iNGP1MGEd0J6QX05mOG`1SHf<0IFEU05iNGP1WIfL0I6AT05aL
G01VIVH0H61P06EUI@1YJFT0IfMW06ATI01WIfL0I6AT06IVIP1PH600Hf=S06ATI01SHf<0IVIV061P
H01YJFT0IVIV06=SH`1YJFT0HV9R06IVIP1QHF40Hf=S06ATI01RHV80JVYZ06MWI`1UIFD0LW9b06m_
K`1SHf<206UYJ@0<06IVIP1SHf<0J6QX06UYJ@1XJ6P0Jf][065QH@1ZJVX0J6QX06e]K@1`L700K6a/
0P1^KVh04P1dM7@0Kfm_06m_K`1YJFT0KFe]06m_K`1aLG40Kfm_06e]K@1`L700LG5a07=cL`1/K6`0
LW9b071`L01bLW80KFe]07AdM080MGEe00H0LW9b07]kN`1`L700Ng]k07alO01eMGD207IfMP0U07Ad
M01hN7P0MGEe07YjNP1gMgL0OGem07alO01fMWH0Ogmo07YjNP1lO7`0PX:207alO01kNg/0MWIf07]k
N`1aLG40PH610820P025QHD0P82007QhN023Ph<0N7Qh08N7Q`1oOgl0OGem08F5Q@1kNg/0LW9b07Yj
NP1kNg/0QXJ607]kN`1lO7`0PH6107]kN`0207EeM@0<08F5Q@22PX80NGUi08B4Q01oOgl0P82007al
O01fMWH0P82007moO`21PH40NWYj0P1lO7`03P1nOWh0N7Qh07alO01mOGd0Ogmo07alO01iNGT0OWin
07YjNP1eMGD0NGUi08B4Q01mOGd0PH610P1lO7`08P1kNg/0MWIf07UiN@1jNWX0MWIf07UiN@1dM7@0
MGEe079bLP1iNGT0MGEe07]kN`1iNGT0OGem07IfMP1hN7P0Ogmo07YjNP1hN7P0M7Ad07EeM@1dM7@0
MGEe071`L01jNWX0O7al06][J`1_Kfl0N7Qh071`L01]KFd0M7Ad07=cL`1^KVh2071`L00E06i^KP1h
N7P0Lg=c06e]K@1WIfL0M7Ad07EeM@1^KVh0Jf][06e]K@1dM7@0N7Qh07IfMP1[Jf/0JVYZ06i^KP1[
Jf/0KFe]06YZJP1`L700MGEe0080L71`00L0LW9b07=cL`1cLg<0MGEe07YjNP1`L700LW9b0080MgMg
0140LW9b07EeM@1aLG40Jf][07EeM@1`L700Lg=c06e]K@1[Jf/0JVYZ06IVIP1_Kfl0HV9R06UYJ@1U
IFD0IfMW06UYJ@0206QXJ00506=SH`1WIfL0Hf=S065QH@1UIFD00P1NGUh01`1PH600Fe]K069RHP1P
H600FUYJ06=SH`1NGUh00P1SHf<05P1PH600Fe]K061PH01MGEd0HV9R06a/K01SHf<0GUiN05mOG`1N
GUh0GEeM05UIF@1QHF40HV9R065QH@1OGel0De=C05mOG`1PH600G5aL05QHF01IFET305iNGP0905QH
F01KFe/0GUiN069RHP1HF5P0H61P05aLG01PH600FUYJ00H0fMWI0@0000010=WIf@005P3IfMT00`00
0000fMWI0=WIf@030=WIf@0E061PH01RHV80H61P05iNGP1QHF40GEeM05iNGP1KFe/0H61P05QHF01Q
HF40I6AT065QH@1UIFD0GEeM05]KF`1WIfL0HF5Q069RHP1UIFD0Fe]K0080GemO0200HV9R05iNGP1U
IFD0H61P06=SH`1TI6@0GemO061PH01RHV80Fe]K061PH01LG5`0I6AT06QXJ01NGUh0HV9R06][J`1T
I6@0HF5Q06IVIP1SHf<0Jf][065QH@1RHV80IFEU065QH@1XJ6P0I6AT06QXJ01KFe/0IfMW065QH@80
Hf=S00l0GUiN06EUI@1]KFd0IfMW06a/K01YJFT0Kfm_06QXJ01WIfL0I6AT06QXJ01TI6@0HV9R06AT
I01aLG400P1YJFT01@1_Kfl0LG5a06QXJ01ZJVX0IFEU0080IfMW0380IVIV06e]K@1]KFd0IVIV079b
LP1fMWH0K6a/06MWI`1aLG40KFe]075aL@1^KVh0JFUY071`L01aLG40KFe]06m_K`1`L700NGUi071`
L01dM7@0MGEe07QhN01aLG40OWin07alO01gMgL0MGEe07UiN@1mOGd0Ng]k07UiN@1hN7P0MWIf07=c
L`1iNGT0N7Qh07]kN`1jNWX0Ogmo07YjNP1iNGT0LG5a07alO01nOWh0OGem08:2PP1kNg/0Ogmo07Qh
N080PX:201d0PH6108:2PP25QHD0NWYj07moO`1mOGd0PX:20820P01nOWh0MWIf07MgM`1kNg/0NGUi
07alO020P800MWIf07YjNP1oOgl0PH6107inOP1gMgL0Ogmo08B4Q01hN7P0P820075aL@21PH40Ph>3
07alO00207YjNP0907inOP1lO7`0NGUi07MgM`1fMWH0PX:2079bLP1mOGd0NWYj0080MgMg00<0O7al
07YjNP22PX800P24Q8@01@1iNGT0Ogmo07YjNP1kNg/0MWIf0080N7Qh00T0MWIf07MgM`1iNGT0LW9b
07EeM@1hN7P0Kfm_07MgM`1hN7P00P1nOWh05P1eMGD0LW9b075aL@1hN7P0LW9b07=cL`1^KVh0NWYj
07EeM@1`L700MWIf06i^KP1bLW80MgMg071`L01]KFd0KVi^06m_K`1cLg<0Jf][06YZJP1cLg<2079b
LP0R06e]K@1^KVh0KFe]071`L01cLg<0LG5a07AdM01_Kfl0LW9b06i^KP1_Kfl0IFEU079bLP1_Kfl0
M7Ad07IfMP1bLW80NWYj07]kN`1oOgl0NGUi07YjNP1kNg/0MWIf07inOP20P800N7Qh07]kN`1hN7P0
LW9b06m_K`1^KVh0Jf][06UYJ@80L71`00@0IVIV06a/K01TI6@0IFEU0P1WIfL0201RHV80IFEU06IV
IP1XJ6P0GemO06=SH`1RHV80I6AT0P1RHV806@1KFe/0IVIV061PH01PH600IVIV05aLG01DE5@0GEeM
06EUI@1WIfL0GemO05YJFP1HF5P0IfMW05YJFP1GEeL0GemO05YJFP1MGEd0Jf][05aLG01NGUh0GemO
05UIF@1UIFD00P1LG5`2065QH@0405iNGP1IFET0FUYJ065QH@80F5QH00D0EeMG05eMG@1KFe/0FEUI
05QHF0060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT04P1TI6@0GemO06EU
I@1MGEd0HF5Q06=SH`1QHF40GemO05iNGP1JFUX0H61P065QH@1SHf<0HV9R061PH01OGel0H61P069R
HP80IfMW0100H61P065QH@1TI6@0GEeM06EUI@1JFUX0HF5Q05YJFP1SHf<0H61P06IVIP1PH600IVIV
06=SH`1OGel0I6AT0P1VIVH03@1WIfL0JFUY06YZJP1QHF40Fe]K06UYJ@1PH600G5aL05mOG`1SHf<0
HV9R05mOG`1WIfL00`1UIFD03@1[Jf/0H61P06YZJP1YJFT0IVIV06e]K@1VIVH0J6QX06UYJ@1UIFD0
JVYZ06ATI01/K6`00P1]KFd06`1VIVH0IFEU06][J`1/K6`0IFEU06MWI`1YJFT0KFe]06a/K01[Jf/0
J6QX07=cL`1[Jf/0J6QX079bLP1VIVH0JFUY07=cL`1WIfL0MWIf07=cL`1/K6`0KFe]06][J`1/K6`0
Lg=c07EeM@02075aL@0406e]K@1gMgL0L71`07EeM@80K6a/00L0KVi^07alO01_Kfl0MgMg07QhN01b
LW80MGEe0080MWIf00<0Lg=c07AdM01fMWH00P1cLg<01@1hN7P0NGUi07]kN`20P800OGem00<0N7Qh
00@0MgMg07EeM@1iNGT0Ng]k0P1lO7`20820P00;07alO01iNGT0P82007moO`1jNWX0N7Qh07inOP1j
NWX0Ph>307inOP1hN7P00P1fMWH00`1kNg/0NWYj07YjNP0207MgM`05071`L01hN7P0MgMg07QhN01l
O7`00P1mOGd06@1nOWh0Q8B407emO@1eMGD0OGem07=cL`1fMWH0N7Qh07MgM`1dM7@0Ogmo07alO01e
MGD0M7Ad07YjNP1lO7`0PH6107UiN@1eMGD0PH6107QhN01bLW80MgMg07=cL`1gMgL00P1jNWX0401f
MWH0NWYj07QhN01fMWH0PH6107=cL`1dM7@0LW9b07EeM@1jNWX0Lg=c06i^KP1gMgL0NWYj07=cL`1a
LG4207AdM080L71`01h0N7Qh06i^KP1dM7@0MGEe07AdM01aLG40KVi^07IfMP1bLW80Kfm_071`L01d
M7@0KVi^07=cL`1aLG40LW9b06i^KP1bLW80JVYZ06e]K@1aLG40J6QX07UiN@1_Kfl0LG5a06e]K@1c
Lg<0Jf][06i^KP1aLG4207MgM`0/0861P@1kNg/0Ng]k08B4Q02<S8`0Q8B408j>SP25QHD0QhN708J6
QP1lO7`0PH610820P01cLg<0MWIf07emO@1eMGD0NGUi06UYJ@1VIVH0J6QX065QH@1ZJVX0J6QX06YZ
JP1/K6`0I6AT06MWI`1PH600HF5Q061PH01RHV80J6QX05aLG01PH600Fe]K05YJFP1TI6@0FEUI05aL
G01QHF40GemO061PH01QHF42069RHP0>05eMG@1OGel0HF5Q05YJFP1PH600G5aL05UIF@1QHF40JFUY
05]KF`1MGEd0Fe]K05iNGP1TI6@3069RHP0=06ATI01JFUX0IVIV06ATI01LG5`0H61P05aLG01NGUh0
Fe]K05mOG`1NGUh0GemO05]KF`060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3I
fMT0201RHV80F5QH05MGE`1NGUh0Hf=S069RHP1NGUh0H61P0P1OGel02@1PH600IFEU069RHP1WIfL0
HF5Q069RHP1LG5`0GemO061PH00205mOG`0605eMG@1TI6@0GemO065QH@1JFUX0I6AT0P1MGEd02`1R
HV80IFEU06QXJ01PH600HV9R06=SH`1QHF40IVIV06QXJ01SHf<0J6QX0080I6AT00<0IVIV06QXJ01P
H6000P1PH6002P1]KFd0HF5Q069RHP1VIVH0IfMW065QH@1_Kfl0IFEU06YZJP1UIFD206IVIP0@07=c
L`1YJFT0J6QX06QXJ01YJFT0HV9R065QH@1WIfL0I6AT05mOG`1WIfL0JVYZ06a/K01[Jf/0J6QX06UY
J@80IfMW01/0K6a/06IVIP1]KFd0LG5a06YZJP1dM7@0JVYZ06QXJ01YJFT0KFe]06i^KP1YJFT0KVi^
06][J`1]KFd0KVi^07AdM01]KFd0MGEe06YZJP1]KFd0LW9b07=cL`1bLW80KVi^079bLP1_Kfl00P1b
LW807P1lO7`0LW9b07AdM01dM7@0LW9b07MgM`1dM7@0MgMg07UiN@1mOGd0MWIf07MgM`1bLW80NGUi
07alO01kNg/0NGUi07MgM`1nOWh0N7Qh07EeM@1bLW80MgMg07YjNP21PH40MWIf07MgM`1iNGT0Ng]k
07EeM@<0O7al0180Ogmo07]kN`1eMGD0Ogmo07YjNP1eMGD0MgMg07UiN@1mOGd0MWIf07EeM@1fMWH0
Ng]k07inOP1dM7@0N7Qh07alO01iNGT207MgM`0807UiN@1fMWH0NWYj07alO021PH40MgMg07IfMP1e
MGD207QhN00D07inOP1oOgl0LW9b07IfMP1mOGd0LW9b07emO@1eMGD0LG5a07alO01mOGd0M7Ad07]k
N`1lO7`0MgMg07alO01gMgL0NGUi07QhN01fMWH2075aL@0707QhN01gMgL0O7al07UiN@1aLG40L71`
07]kN`02075aL@80M7Ad01@0MgMg06m_K`1dM7@0Jf][06e]K@1cLg<0Kfm_06UYJ@1_Kfl0IfMW06a/
K01]KFd0Kfm_06EUI@1ZJVX0L71`06i^KP1WIfL0Jf][06i^KP80L71`00H0LG5a06m_K`1`L700KVi^
071`L01^KVh2079bLP0:06e]K@1eMGD0LW9b07UiN@1dM7@0P82007inOP21PH40OGem07inOP80S8b<
0240UIFE08R8R02ATI40T92@08f=S@28R8P0OGem07UiN@1gMgL0M7Ad06QXJ01eMGD0Kfm_06UYJ@1_
Kfl0J6QX075aL@1RHV80Hf=S06a/K01UIFD0JFUY06ATI01VIVH0KFe]06EUI@1QHF40G5aL05]KF`1Q
HF40HV9R05QHF01VIVH00`1NGUh03`1SHf<0I6AT06ATI01KFe/0H61P05]KF`1RHV80G5aL065QH@1M
GEd0Hf=S05mOG`1QHF40FEUI05aLG00205]KF`07069RHP1IFET0GUiN05YJFP1LG5`0FEUI069RHP02
05UIF@0805eMG@1KFe/0FEUI05YJFP1HF5P0FEUI05=CD`1IFET60=WIf@4000000@3IfMT001H0fMWI
00<000000=WIf@3IfMT00`3IfMT04P1NGUh0HF5Q05iNGP1JFUX0HV9R05mOG`1RHV80G5aL06MWI`1M
GEd0Hf=S05eMG@1YJFT0HF5Q05]KF`1NGUh0HF5Q05aLG080H61P00H0IFEU06=SH`1RHV80FUYJ05eM
G@1TI6@205eMG@0M05mOG`1LG5`0GEeM06EUI@1QHF40IfMW05mOG`1YJFT0I6AT065QH@1ZJVX0HV9R
06IVIP1SHf<0I6AT061PH01TI6@0HF5Q06MWI`1PH600I6AT069RHP1YJFT0IFEU06IVIP1]KFd0I6AT
069RHP1XJ6P00P1VIVH02`1UIFD0JVYZ06IVIP1YJFT0I6AT069RHP1WIfL0GEeM06e]K@1`L700IfMW
0080J6QX04d0JFUY07=cL`1XJ6P0IfMW06UYJ@1/K6`0Jf][06e]K@1[Jf/0IVIV06QXJ01ZJVX0KFe]
06MWI`1_Kfl0Lg=c06QXJ01/K6`0LW9b075aL@1]KFd0Lg=c06e]K@1_Kfl0LG5a07=cL`1bLW80Kfm_
07=cL`1bLW80M7Ad07UiN@1^KVh0LW9b07YjNP1dM7@0MWIf07EeM@1fMWH0M7Ad075aL@1jNWX0Lg=c
07MgM`1oOgl0NWYj075aL@1dM7@0MgMg0820P01eMGD0Ng]k06i^KP1gMgL0O7al07]kN`1nOWh0O7al
06i^KP1dM7@0Ng]k07EeM@1hN7P0PH6107alO023Ph<0MGEe07IfMP1jNWX0LW9b07YjNP1oOgl0NGUi
08>3P`1lO7`0OGem07]kN`0207YjNP0;07=cL`1lO7`0N7Qh07=cL`24Q8@0Ogmo07]kN`1oOgl0LW9b
0861P@1gMgL00P1kNg/03P1cLg<0OGem07YjNP1gMgL0N7Qh07emO@1nOWh0P82007MgM`1eMGD0N7Qh
07YjNP1`L700MgMg0P1fMWH02`1_Kfl0MgMg07]kN`1dM7@0NWYj075aL@1fMWH0KVi^07EeM@1`L700
NWYj0080MgMg01<0NGUi07EeM@1gMgL0M7Ad06i^KP1fMWH0KVi^07QhN01]KFd0K6a/075aL@1]KFd0
Kfm_079bLP1^KVh0Kfm_07=cL`1eMGD0Lg=c0080I6AT0140Lg=c075aL@1bLW80J6QX075aL@1dM7@0
KFe]06m_K`1[Jf/0J6QX07IfMP1/K6`0KVi^06][J`1_Kfl0MgMg06i^KP0207=cL`0507AdM01`L700
NWYj07emO@22PX800P20P8002`28R8P0QXJ608n?S`2TY:@0ZJVY0:b/[02a/K40/;2`0:^[Z`2MWId0
V9RH0080QXJ600P0OGem07IfMP1`L700L71`06a/K01dM7@0KVi^06IVIP<0JFUY00/0IfMW069RHP1P
H600HV9R06ATI01IFET0Hf=S05eMG@1NGUh0Hf=S065QH@02061PH00705mOG`1NGUh0GEeM061PH01K
Fe/0IFEU05mOG`02061PH080FEUI00H0I6AT05]KF`1LG5`0HF5Q069RHP1PH60206EUI@0B05aLG01P
H600GEeM05iNGP1GEeL0IVIV05iNGP1LG5`0FUYJ06ATI01UIFD0FUYJ05mOG`1IFET0GUiN061PH01M
GEd0G5aL1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00l0GemO05YJFP1R
HV80GemO06ATI01NGUh0G5aL069RHP1SHf<0FUYJ05mOG`1RHV80FUYJ05QHF01MGEd00P1LG5`03@1M
GEd0GemO061PH01IFET0HV9R06ATI01PH600FUYJ05]KF`1XJ6P0H61P05UIF@1NGUh00P1TI6@04`1L
G5`0IVIV065QH@1PH600I6AT06IVIP1UIFD0JFUY06ATI01OGel0FEUI06ATI01SHf<0I6AT069RHP1Y
JFT0IVIV06=SH`1WIfL00P1UIFD03P1QHF40I6AT065QH@1TI6@0IfMW06ATI01YJFT0IFEU06UYJ@1R
HV80JFUY061PH01ZJVX0Hf=S0P1UIFD05P1WIfL0JFUY06ATI01ZJVX0IVIV06m_K`1WIfL0L71`06AT
I01XJ6P0LG5a06a/K01^KVh0Jf][071`L01]KFd0Kfm_079bLP1TI6@0K6a/06UYJ@1`L70207EeM@0a
06m_K`1]KFd0KFe]06e]K@1/K6`0LW9b07QhN01]KFd0LG5a079bLP1YJFT0LG5a07EeM@1fMWH0KFe]
06i^KP1gMgL0N7Qh071`L01^KVh0OGem075aL@1fMWH0OGem07=cL`21PH40JVYZ07]kN`20P800M7Ad
07IfMP1dM7@0MGEe07UiN@1aLG40NGUi08F5Q@1jNWX0PH6107MgM`1iNGT0LW9b07UiN@1hN7P0MgMg
07AdM01kNg/0Lg=c07QhN00207YjNP0H0861P@1iNGT0NWYj07YjNP1lO7`0Ng]k07QhN01aLG40M7Ad
07EeM@1fMWH0MgMg079bLP1mOGd0Lg=c079bLP1gMgL0NGUi07EeM@1bLW80MGEe07QhN01dM7@0MgMg
0P1mOGd03@1lO7`0MWIf07moO`1hN7P0OGem07alO01hN7P0Kfm_07QhN023Ph<0M7Ad07YjNP1lO7`0
0P1fMWH09P1dM7@0MgMg07YjNP1aLG40MgMg07=cL`1^KVh0Ng]k07UiN@1`L700MgMg06][J`1`L700
NGUi07AdM01cLg<0JVYZ079bLP1YJFT0L71`07EeM@1bLW80M7Ad06a/K01_Kfl0K6a/07MgM`1_Kfl0
L71`06][J`1bLW80KFe]06YZJP1cLg<0L71`06QXJ01cLg<0LG5a0P1]KFd0101ZJVX0K6a/06e]K@1b
LW8206a/K00M06e]K@1ZJVX0NGUi07QhN01eMGD0PH61079bLP1mOGd0QXJ608R8R02HV9P0YJFU0:n_
[`34a<@0h^;R0>k^kP3WinL0g=cL0<G5a@2WYjL0V9RH08j>SP27QhL0P82007alO01_Kfl0Jf][06QX
J01VIVH00P1[Jf/04P1XJ6P0I6AT06IVIP1SHf<0HV9R06EUI@1QHF40GUiN06IVIP1NGUh0I6AT06=S
H`1RHV80JFUY05]KF`1ZJVX0Hf=S069RHP80GUiN0200IVIV069RHP1PH600GUiN06YZJP1QHF40GemO
069RHP1]KFd0Fe]K05iNGP1RHV80H61P05]KF`1LG5`0GemO05iNGP1MGEd0Hf=S05iNGP1SHf<0FEUI
05YJFP1MGEd0GemO05eMG@1KFe/0F5QH05UIF@1KFe/0F5QH05eMG@H0fMWI0@0000010=WIf@005P3I
fMT00`000000fMWI0=WIf@030=WIf@0T061PH01RHV80EeMG05YJFP1RHV80FEUI05eMG@1LG5`0HF5Q
06QXJ01MGEd0I6AT05mOG`1TI6@0Fe]K06QXJ01OGel0HF5Q05QHF01MGEd0IVIV06EUI@1MGEd0FUYJ
05aLG01NGUh0IFEU05YJFP1PH600I6AT06QXJ01UIFD0Hf=S06IVIP1RHV80H61P0P1OGel02P1SHf<0
IFEU06EUI@1UIFD0IfMW06ATI01PH600I6AT061PH01WIfL306ATI00]05aLG01YJFT0IFEU06=SH`1T
I6@0IFEU05aLG01OGel0JVYZ06MWI`1SHf<0IfMW06ATI01XJ6P0JFUY06MWI`1SHf<0I6AT065QH@1X
J6P0HV9R06YZJP1]KFd0JVYZ06QXJ01[Jf/0IVIV07=cL`1WIfL0KFe]06UYJ@1]KFd0JFUY06i^KP1W
IfL0JVYZ06QXJ01/K6`0I6AT079bLP1fMWH0KVi^075aL@1[Jf/0LW9b0080KVi^00P0IfMW07UiN@1d
M7@0MWIf07=cL`1`L700JFUY075aL@80Lg=c00@0LG5a071`L01bLW80Lg=c0P1iNGT0201mOGd0MWIf
079bLP1bLW80L71`07UiN@1aLG40Ng]k0P1jNWX05P1lO7`0NGUi079bLP1eMGD0LW9b07UiN@1dM7@0
MWIf07QhN021PH40Ogmo079bLP1iNGT0MgMg07]kN`1iNGT0MgMg07inOP1cLg<0O7al07MgM`1lO7`2
07AdM00F07]kN`1hN7P0NWYj07YjNP1oOgl0O7al07YjNP1gMgL0NGUi07inOP1fMWH0N7Qh0820P01f
MWH0OWin07YjNP1dM7@0OWin07YjNP1eMGD0Lg=c06e]K@80O7al02@0N7Qh07UiN@1lO7`0Lg=c07Ui
N@1eMGD0M7Ad07alO01iNGT0MgMg07AdM01eMGD0JVYZ07AdM01`L700LG5a07EeM@1`L700LW9b07]k
N`1bLW80MGEe079bLP1jNWX0N7Qh07IfMP1bLW80MWIf06m_K`1cLg<0MgMg06UYJ@1aLG40Kfm_07Qh
N01^KVh206e]K@0906i^KP1bLW80LW9b06m_K`1[Jf/0K6a/071`L01aLG40KVi^0080Kfm_00T0Lg=c
06a/K01aLG40Jf][06i^KP1]KFd0LG5a07EeM@1[Jf/00P1^KVh01@1]KFd0KVi^07IfMP20P800O7al
0080OWin00H0RHV909JFUP2IVIT0XJ6Q0<o?c`3AdM430?ooo`0C0>_[j`3Lg=`0^[Zj09BDU029RHT0
OWin07UiN@1bLW80Kfm_075aL@1`L700K6a/06i^KP1NGUh0J6QX06MWI`1RHV80I6AT06QXJ00206AT
I00T065QH@1LG5`0HV9R05YJFP1UIFD0Hf=S05]KF`1JFUX0IFEU05iNGP1FEUH0G5aL061PH01QHF40
HV9R05mOG`1EEED0GEeM061PH01NGUh0H61P06EUI@1NGUh0Hf=S069RHP1QHF40G5aL05eMG@1PH600
GEeM05aLG01OGel0Fe]K05eMG@1SHf<0G5aL0P1QHF401`1MGEd0HV9R05aLG01LG5`0EEEE05iNGP1P
H6001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00@0Fe]K05mOG`1UIFD0
Hf=S0P1NGUh0301SHf<0GEeM06IVIP1VIVH0GemO05YJFP1RHV80Hf=S05]KF`1MGEd0GemO05iNGP80
G5aL00T0I6AT061PH01VIVH0GUiN06ATI01RHV80IVIV06ATI01NGUh00P1QHF404`1TI6@0H61P069R
HP1MGEd0HV9R06=SH`1QHF40IFEU061PH01HF5P0H61P06i^KP1VIVH0JVYZ06=SH`1QHF40I6AT06=S
H`1PH6000P1UIFD04@1QHF40Hf=S06YZJP1RHV80GemO06ATI01WIfL0I6AT05mOG`1RHV80IVIV06AT
I01VIVH0K6a/061PH01TI6@0IVIV0080IfMW00@0J6QX06YZJP1TI6@0Jf][0P1XJ6P00`1WIfL0JVYZ
06YZJP0206UYJ@0E071`L01UIFD0JFUY06e]K@1WIfL0J6QX06e]K@1ZJVX0J6QX071`L01cLg<0Kfm_
06i^KP1`L700LG5a06a/K01`L700KVi^06e]K@1aLG40L71`00<0KVi^00D0NGUi06i^KP1^KVh0MgMg
06a/K002075aL@0;07MgM`1dM7@0OGem06a/K01dM7@0LW9b07IfMP1aLG40M7Ad07QhN01`L7000P1d
M7@01@1jNWX0MWIf07EeM@1hN7P0MGEe0080M7Ad00@0NWYj071`L01gMgL0N7Qh0P1dM7@0201kNg/0
MGEe07alO01oOgl0MWIf07UiN@1gMgL0L71`0P1gMgL01P1fMWH0Ng]k07YjNP1mOGd0Ogmo08>3P`<0
NGUi03D0MGEe07QhN01kNg/0N7Qh07IfMP1kNg/0LW9b07EeM@1hN7P0M7Ad07UiN@1dM7@0N7Qh075a
L@1jNWX0Ng]k07UiN@1eMGD0LG5a07EeM@1hN7P0L71`07UiN@1cLg<0LG5a079bLP1jNWX0Jf][07Ee
M@1hN7P0LW9b07IfMP1eMGD0NWYj07IfMP1gMgL0LG5a06e]K@1iNGT0Kfm_079bLP1aLG40L71`06a/
K01aLG40M7Ad075aL@1bLW80L71`07=cL`1^KVh0L71`06m_K`02075aL@0506i^KP1aLG40L71`071`
L01[Jf/00`1XJ6P206m_K`0F06][J`1/K6`0Jf][06a/K01^KVh0IFEU06QXJ01cLg<0L71`07=cL`1a
LG40O7al07MgM`1mOGd0OWin08>3P`2;Rh/0UYJF09fMW@2f][H0f=SH0>c/k0@0oooo00h0gMgM0;Jf
]P2GUiL0U9BD08N7Q`21PH40OWin07IfMP1^KVh0Kfm_06EUI@1WIfL0IVIV06UYJ@80IfMW00h0HF5Q
06ATI01JFUX0H61P06=SH`1OGel0Hf=S06ATI01NGUh0Fe]K05iNGP1PH600Fe]K05aLG0<0GemO00`0
HF5Q061PH01PH600IfMW061PH01UIFD0GemO06ATI01JFUX0G5aL06IVIP1QHF4205eMG@0>061PH01K
Fe/0GUiN065QH@1PH600HV9R061PH01LG5`0GEeM06=SH`1LG5`0Fe]K05iNGP1TI6@205UIF@0305]K
F`1NGUh0fMWI00D0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0?05aLG01R
HV80G5aL05]KF`1RHV80GEeM05mOG`1LG5`0FUYJ05]KF`1RHV80GemO05eMG@1RHV80GUiN00<0HV9R
00<0HF5Q06=SH`1MGEd00P1KFe/04`1RHV80H61P06=SH`1QHF40I6AT061PH01OGel0IFEU061PH01L
G5`0GEeM069RHP1NGUh0GemO069RHP1QHF40Hf=S05UIF@1SHf<00`1RHV801@1NGUh0H61P069RHP1Q
HF40Hf=S0080HV9R01@0HF5Q06EUI@1[Jf/0IfMW061PH01RHV80I6AT06EUI@1/K6`0Hf=S06MWI`1X
J6P0IVIV06YZJP1TI6@0H61P06MWI`1UIFD0IfMW06e]K@80IfMW00P0KFe]06IVIP1]KFd0KFe]06MW
I`1[Jf/0I6AT06][J`80KFe]00<0IfMW06a/K01YJFT00P1XJ6P0301WIfL0J6QX06UYJ@1/K6`0L71`
06][J`1`L700JVYZ06i^KP1_Kfl0LW9b06][J`80Kfm_01/0JVYZ07IfMP1]KFd0L71`06][J`1^KVh0
O7al07IfMP1]KFd0MGEe07]kN`1fMWH0Kfm_07AdM01iNGT0LW9b07alO01hN7P0KVi^06a/K01jNWX0
MWIf07MgM`1jNWX0M7Ad07QhN01cLg<00`1hN7P01@1iNGT0O7al07EeM@1eMGD0MWIf0080N7Qh00P0
Ng]k07moO`1cLg<0M7Ad07QhN01eMGD0O7al07IfMP80MgMg00D0NWYj07AdM01nOWh0Ogmo06i^KP02
07alO00D07emO@1bLW80MgMg07inOP1hN7P0MGEe07MgM`1eMGD0NGUi07]kN`1dM7@0Lg=c07IfMP1l
O7`0MWIf079bLP1fMWH0LG5a07AdM01iNGT2071`L00=07YjNP1dM7@0KVi^07=cL`1`L700Lg=c07Ui
N@1gMgL0MGEe071`L01_Kfl0N7Qh079bLP0207=cL`0306m_K`1`L700MWIf0080LG5a00T0MGEe075a
L@1fMWH0L71`07AdM01`L700IfMW06YZJP1VIVH00P1[Jf/08`1dM7@0KFe]06a/K01XJ6P0Jf][06YZ
JP1/K6`0Lg=c071`L01_Kfl0MgMg06][J`1YJFT0Jf][06UYJ@1dM7@0IFEU06i^KP1]KFd0IVIV06][
J`1eMGD0L71`07=cL`1bLW80O7al07inOP1jNWX0O7al08^;R`2LW9`0Vi^K0;>c/`3Kfm/0n?Sh00@0
oooo00/0inOW0;^k^`2LW9`0Ti>C08>3P`25QHD0OWin06m_K`1`L700KVi^06m_K`0206a/K00406QX
J01QHF40GemO06EUI@80Hf=S00l0I6AT06EUI@1UIFD0Fe]K065QH@1JFUX0Hf=S061PH01JFUX0E5AD
069RHP1QHF40HV9R05mOG`1KFe/00P1PH6005@1OGel0Fe]K05iNGP1RHV80GEeM05YJFP1RHV80H61P
05iNGP1QHF40G5aL05eMG@1LG5`0HF5Q05UIF@1QHF40GEeM061PH01UIFD0HV9R061PH00205YJFP06
05aLG01PH600EUIF05eMG@1HF5P0GUiN1P3IfMT100000040fMWI000F0=WIf@800000103IfMT03`1K
Fe/0EeMG05aLG01OGel0GUiN05]KF`1QHF40GemO06EUI@1OGel0G5aL05]KF`1MGEd0I6AT05aLG002
065QH@0B061PH01HF5P0GUiN06IVIP1RHV80H61P06ATI01RHV80HF5Q05UIF@1PH600HF5Q06EUI@1Q
HF40FUYJ061PH01RHV80GUiN0P1RHV80101TI6@0GUiN069RHP1TI6@3065QH@0:069RHP1OGel0GUiN
06MWI`1RHV80H61P06EUI@1PH600IfMW06UYJ@80I6AT00@0GemO06][J`1SHf<0Hf=S0P1YJFT05P1V
IVH0I6AT06IVIP1/K6`0Jf][06IVIP1ZJVX0IFEU06e]K@1XJ6P0JFUY06e]K@1^KVh0H61P06=SH`1U
IFD0GemO06YZJP1UIFD0J6QX06e]K@1[Jf/206UYJ@0K06m_K`1YJFT0Jf][06m_K`1XJ6P0MWIf06QX
J01/K6`0Kfm_06e]K@1[Jf/0Kfm_071`L01/K6`0Kfm_06MWI`1aLG40KFe]07IfMP1/K6`0KFe]07Ee
M@1bLW80LG5a079bLP1]KFd0LG5a0080N7Qh0140LW9b07MgM`1fMWH0L71`07UiN@1gMgL0MGEe071`
L01aLG40MWIf07EeM@1fMWH0MgMg07IfMP1lO7`0MGEe07YjNP02071`L00607MgM`1hN7P0M7Ad07mo
O`1]KFd0OWin0P1kNg/01`1fMWH0MGEe07YjNP1gMgL0OWin07YjNP1iNGT00`1dM7@0B@1iNGT0Ng]k
07]kN`1dM7@0Lg=c07AdM01lO7`0Ng]k07EeM@1gMgL0Jf][07QhN01fMWH0MGEe07AdM01jNWX0Ng]k
07=cL`1gMgL0LG5a07UiN@1]KFd0Kfm_071`L01dM7@0MgMg07QhN01eMGD0MWIf07EeM@1bLW80N7Qh
07YjNP1aLG40KFe]07EeM@1kNg/0Lg=c07QhN01gMgL0K6a/07=cL`1]KFd0Kfm_07AdM01/K6`0M7Ad
06i^KP1eMGD0LW9b071`L01_Kfl0MGEe06m_K`1cLg<0NGUi06a/K01eMGD0KFe]075aL@1`L700JVYZ
06e]K@1WIfL0KFe]06MWI`1^KVh0IVIV075aL@1_Kfl0IFEU06QXJ01^KVh00P1/K6`01P1WIfL0Kfm_
075aL@1/K6`0M7Ad06i^KP80Lg=c00X0NWYj07IfMP1kNg/0OWin08V9R@27QhL0VYZJ0:RXZ03=cLd0
i>CT0`3oool03`3WinL0c<c<0:j^[P2HV9P0Shn?0861P@26QXH0O7al07=cL`1_Kfl0LW9b06i^KP1[
Jf/0K6a/06YZJP02069RHP0D06MWI`1TI6@0H61P06IVIP1XJ6P0HV9R05eMG@1XJ6P0IFEU05iNGP1T
I6@0HF5Q06EUI@1SHf<0GUiN05UIF@1MGEd0Hf=S06EUI@1PH60205mOG`0506EUI@1/K6`0GemO065Q
H@1OGel00P1LG5`0501PH600GUiN05mOG`1GEeL0Fe]K05iNGP1JFUX0GemO05QHF01PH600HV9R05mO
G`1UIFD0HV9R05eMG@1NGUh0GEeM05UIF@1TI6@0GemO1@3IfMT200000040fMWI000F0=WIf@030000
003IfMT0fMWI00<0fMWI01d0G5aL05QHF01OGel0GUiN06=SH`1PH600HF5Q06=SH`1KFe/0GemO065Q
H@1MGEd0G5aL06=SH`1UIFD0FUYJ061PH01NGUh0Fe]K069RHP1XJ6P0HF5Q06=SH`1WIfL0GUiN061P
H01OGel0GUiN05]KF`03065QH@0605eMG@1UIFD0IFEU05mOG`1LG5`0JFUY0P1PH6003@1JFUX0FEUI
061PH01WIfL0HF5Q06=SH`1VIVH0IFEU05]KF`1RHV80I6AT06IVIP1OGel00P1VIVH0801NGUh0HV9R
06MWI`1/K6`0J6QX06MWI`1[Jf/0I6AT06QXJ01VIVH0I6AT06UYJ@1UIFD0I6AT06i^KP1TI6@0IVIV
06YZJP1UIFD0FEUI06e]K@1XJ6P0JVYZ06a/K01UIFD0K6a/071`L01[Jf/0IfMW06i^KP1]KFd0IfMW
0P1/K6`01@1XJ6P0KVi^06e]K@1WIfL0K6a/0080LG5a00@0IVIV07=cL`1aLG40M7Ad0P1`L7005@1h
N7P0Jf][06i^KP1bLW80JFUY075aL@1`L700LG5a07=cL`1bLW80L71`07IfMP1dM7@0LG5a079bLP1j
NWX0MgMg07=cL`1iNGT0LG5a07AdM00207=cL`0@07QhN01eMGD0L71`079bLP1gMgL0LW9b07alO01d
M7@0Lg=c07YjNP1`L700MgMg07alO01fMWH0M7Ad07=cL`80NWYj00L0KVi^07emO@1dM7@0NWYj07Ee
M@1hN7P0MgMg0080MWIf00h0Ng]k07AdM01iNGT0Ng]k07UiN@1_Kfl0N7Qh07UiN@1kNg/0LG5a07Mg
M`1fMWH0NGUi071`L080N7Qh00X0LW9b07IfMP1dM7@0LW9b07EeM@1dM7@0NGUi06m_K`1`L700MGEe
0P1aLG403@1^KVh0JFUY06i^KP1^KVh0MGEe079bLP1gMgL0LG5a07]kN`1eMGD0LW9b06i^KP1iNGT0
0P1_Kfl03P1[Jf/0MGEe07AdM01bLW80M7Ad071`L01]KFd0LG5a06][J`1dM7@0IfMW06IVIP1bLW80
Lg=c0P1_Kfl06`1cLg<0K6a/075aL@1[Jf/0HV9R06i^KP1`L700KVi^06e]K@1bLW80HF5Q07AdM01]
KFd0IFEU06a/K01^KVh0KFe]06][J`1^KVh0J6QX079bLP1]KFd0MGEe07IfMP1_Kfl0KVi^07inOP02
07emO@0A08b<S02CTi<0Vi^K0;Vi^@38b<P0d];B0=[JfP3Bd]80_Kfm0;:b/P2NWYh0R8R808^;R`21
PH40PX:207YjNP1cLg<00P1`L7000`1VIVH0KVi^05mOG`0206QXJ00405eMG@1LG5`0IVIV069RHP80
GEeM01X0IVIV065QH@1TI6@0GemO05QHF01RHV80GUiN05MGE`1KFe/0GemO06=SH`1PH600Fe]K05mO
G`1SHf<0FEUI06UYJ@1WIfL0GEeM069RHP1QHF40Fe]K05aLG01TI6@0HF5Q05aLG080HF5Q0100GUiN
05YJFP1RHV80HV9R065QH@1JFUX0H61P05eMG@1SHf<0F5QH05aLG01JFUX0E5AD05IFEP1HF5P0FUYJ
1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI02D0H61P05UIF@1HF5P0GUiN
06EUI@1RHV80G5aL061PH01HF5P0GemO05iNGP1PH600EeMG061PH01LG5`0IVIV05mOG`1TI6@0GUiN
06QXJ01UIFD0IfMW05iNGP1SHf<0IVIV061PH01KFe/0G5aL06UYJ@1NGUh0HV9R065QH@1NGUh0I6AT
065QH@1RHV80GemO0080Fe]K01H0I6AT061PH01QHF40G5aL061PH01NGUh0GEeM06EUI@1TI6@0Hf=S
05MGE`1PH600De=C06=SH`1RHV80K6a/06=SH`1OGel0HF5Q06ATI01UIFD0I6AT0P1UIFD06P1QHF40
K6a/06IVIP1TI6@0Jf][06e]K@1UIFD0HF5Q06i^KP1[Jf/0IfMW06UYJ@1]KFd0HV9R06MWI`1VIVH0
K6a/06YZJP1/K6`0LG5a06m_K`1XJ6P0L71`06QXJ01^KVh0KFe]0`1ZJVX02P1YJFT0LG5a079bLP1^
KVh0J6QX06=SH`1eMGD0NWYj06EUI@1YJFT206m_K`0=071`L01bLW80Kfm_06m_K`1cLg<0KVi^06e]
K@1cLg<0Jf][07emO@1aLG40Lg=c06i^KP0207AdM00307MgM`1hN7P0OWin0080MWIf0P1]KFd0301k
Ng/0Lg=c071`L01bLW80MGEe071`L01dM7@0K6a/07IfMP1eMGD0QhN706m_K`80Ng]k00P0NWYj07Mg
M`1hN7P0MGEe07AdM021PH40NGUi07QhN080MWIf0P1bLW80401`L700KVi^079bLP1hN7P0MgMg07]k
N`1]KFd0MWIf07=cL`1eMGD0Lg=c07AdM01iNGT0LG5a07]kN`1gMgL207EeM@0=06i^KP1eMGD0NGUi
08>3P`1]KFd0M7Ad07=cL`1hN7P0LG5a06m_K`1dM7@0K6a/07alO002079bLP0W07IfMP1bLW80NGUi
07]kN`1_Kfl0K6a/07=cL`1/K6`0Ng]k06][J`1^KVh0Lg=c06i^KP1aLG40NGUi07AdM01hN7P0L71`
07QhN01ZJVX0JFUY071`L01bLW80KVi^06UYJ@1_Kfl0J6QX07AdM01cLg<0L71`07AdM01[Jf/0K6a/
06i^KP1]KFd0LG5a06i^KP1_Kfl0J6QX00<0Jf][03d0JVYZ06e]K@1/K6`0Kfm_06i^KP1]KFd0MGEe
071`L01ZJVX0MGEe07IfMP1iNGT0NWYj08N7Q`2?Shl0UIFE09JFUP2m_Kd0_;bl0;fm_@2l_;`0Y:BT
0:b/[02KVi/0RXZ:08J6QP1jNWX0KVi^07UiN@1bLW80M7Ad06][J`1]KFd0Jf][06EUI@1VIVH0IfMW
061PH01TI6@0H61P05mOG`1TI6@0GemO069RHP1PH600GUiN061PH01KFe/0JVYZ06MWI`1QHF40H61P
065QH@1MGEd0GemO05iNGP1UIFD0I6AT05aLG01YJFT0Hf=S0080G5aL00`0IFEU05QHF01MGEd0H61P
065QH@1RHV80GUiN05]KF`1QHF40FUYJ06ATI01HF5P205iNGP05069RHP1OGel0GEeM05mOG`1LG5`0
0P1IFET00`1TI6@0F5QH06=SH`060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3I
fMT03@1JFUX0HF5Q05aLG01OGel0GEeM069RHP1QHF40GemO05]KF`1MGEd0GUiN05YJFP1RHV800P1Q
HF403`1PH600HF5Q06UYJ@1MGEd0Hf=S05mOG`1TI6@0FEUI06EUI@1WIfL0EeMG06EUI@1LG5`0IFEU
05iNGP0306ATI00>061PH01XJ6P0GUiN05mOG`1IFET0HV9R06=SH`1KFe/0GemO05]KF`1NGUh0J6QX
05eMG@1RHV8206MWI`1@06QXJ01MGEd0I6AT06=SH`1TI6@0IVIV061PH01VIVH0I6AT06EUI@1TI6@0
IVIV06MWI`1UIFD0HF5Q061PH01XJ6P0IVIV06EUI@1OGel0JFUY06MWI`1XJ6P0JFUY06ATI01]KFd0
IVIV06YZJP1XJ6P0JFUY069RHP1WIfL0JVYZ069RHP1`L700GemO06UYJ@1]KFd0IFEU06IVIP1]KFd0
L71`075aL@1_Kfl0K6a/06YZJP1bLW80Kfm_06e]K@1YJFT0Kfm_06EUI@1WIfL0L71`079bLP1[Jf/0
LG5a06YZJP1`L700KVi^07=cL`1_Kfl0Lg=c07UiN@1/K6`0KFe]079bLP1_Kfl0LW9b07QhN01cLg<0
LW9b06UYJ@1jNWX0L71`07IfMP1dM7@0MGEe07YjNP1kNg/207AdM00507EeM@1lO7`0NGUi07QhN01a
LG400P1eMGD0=`1jNWX0L71`07IfMP1/K6`0NGUi07QhN01kNg/0MgMg07YjNP1lO7`0KVi^07EeM@1b
LW80OGem07=cL`1^KVh0KFe]07EeM@1gMgL0KFe]07]kN`1bLW80Lg=c07EeM@1^KVh0MGEe07alO01d
M7@0KVi^07=cL`1gMgL0MWIf07UiN@1oOgl0MWIf07AdM01cLg<0M7Ad07MgM`1fMWH0M7Ad07QhN01c
Lg<0N7Qh07=cL`1fMWH0Lg=c07EeM@1]KFd0NWYj07IfMP1dM7@0MGEe07MgM`1]KFd00P1cLg<0701f
MWH0Jf][06m_K`1UIFD0Kfm_06QXJ01^KVh0Lg=c06e]K@1[Jf/0KVi^06UYJ@1aLG40LW9b06e]K@1Y
JFT0JVYZ06][J`1/K6`0JFUY06][J`1]KFd0J6QX07AdM01YJFT0I6AT06MWI`1XJ6P306a/K00<079b
LP1UIFD0Jf][06][J`1/K6`0LG5a06][J`1XJ6P0KVi^079bLP1WIfL0MGEe0P1`L7008022PX80OWin
08B4Q02:RXX0T92@09JFUP2ATI40UIFE08B4Q02CTi<0U9BD07emO@1kNg/0N7Qh07]kN`1aLG40MWIf
06UYJ@1XJ6P0L71`06IVIP1[Jf/0JFUY06IVIP1UIFD0I6AT06IVIP1UIFD0IVIV061PH01QHF40HV9R
0P1TI6@05@1SHf<0HV9R061PH01PH600GemO069RHP1VIVH0I6AT05eMG@1XJ6P0GemO05MGE`1YJFT0
GemO05eMG@1OGel0HV9R061PH01[Jf/0GemO06=SH`0205eMG@0905YJFP1PH600FEUI05eMG@1QHF40
FUYJ06EUI@1NGUh0G5aL0080EUIF00H0J6QX069RHP1GEeL0FEUI05mOG`1JFUX60=WIf@4000000@3I
fMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT07@1NGUh0FUYJ05YJFP1KFe/0GEeM05]KF`1QHF40
I6AT05mOG`1UIFD0GemO065QH@1KFe/0GEeM06=SH`1PH600Hf=S06EUI@1OGel0GUiN06ATI01RHV80
I6AT061PH01OGel0GUiN06EUI@1WIfL0GEeM0080Fe]K01D0H61P069RHP1LG5`0H61P05mOG`1IFET0
GemO05aLG01PH600G5aL05YJFP1QHF40HV9R05QHF01VIVH0J6QX061PH01LG5`0GemO05eMG@1TI6@0
0P1RHV803@1VIVH0HV9R06QXJ01VIVH0Jf][06QXJ01SHf<0KFe]05mOG`1WIfL0IVIV065QH@1UIFD0
0P1YJFT406ATI00E06IVIP1YJFT0J6QX06IVIP1[Jf/0I6AT06][J`1TI6@0K6a/079bLP1SHf<0I6AT
06][J`1XJ6P0I6AT06m_K`1XJ6P0JFUY075aL@1XJ6P0KVi^0080JVYZ00P0K6a/06][J`1^KVh0KVi^
06e]K@1/K6`0NWYj06QXJ080KVi^00L0L71`075aL@1bLW80LG5a06m_K`1dM7@0L71`0080LG5a00`0
LW9b075aL@1bLW80KFe]06a/K01cLg<0Kfm_071`L01cLg<0N7Qh079bLP1aLG4207MgM`0O07EeM@1`
L700Lg=c07EeM@1_Kfl0LW9b07EeM@1^KVh0Lg=c07alO01cLg<0NWYj07EeM@1mOGd0Kfm_06i^KP1f
MWH0MgMg07QhN01dM7@0Kfm_07=cL`1jNWX0M7Ad07EeM@1dM7@0MGEe071`L01dM7@0MWIf07AdM002
071`L004079bLP1hN7P0K6a/07MgM`80LW9b00D0M7Ad07MgM`1iNGT0MgMg06e]K@0207=cL`0@07Ad
M01_Kfl0MGEe06UYJ@1hN7P0Kfm_06a/K01dM7@0JVYZ079bLP1^KVh0LG5a07AdM01]KFd0MWIf07Mg
M`80LG5a01l0MgMg06m_K`1`L700LG5a06e]K@1^KVh0MGEe06UYJ@1_Kfl0KVi^06m_K`1YJFT0Hf=S
06a/K01`L700KVi^06EUI@1VIVH0Jf][06IVIP1`L700Jf][06QXJ01[Jf/0K6a/06YZJP1YJFT0HV9R
071`L01VIVH0LG5a0080KFe]00/0Jf][06IVIP1YJFT0KFe]07AdM01SHf<0Lg=c06][J`1dM7@0Kfm_
06][J`0206m_K`04075aL@1dM7@0Kfm_08B4Q080P82001`0PX:207alO01fMWH0Ph>30820P021PH40
Lg=c07emO@1]KFd0Lg=c06a/K01ZJVX0Lg=c06a/K01VIVH0IfMW06=SH`1XJ6P0IfMW06IVIP1SHf<0
IfMW06ATI01RHV80IVIV05iNGP1WIfL0Hf=S0`1RHV800`1PH600HV9R05mOG`0205mOG`0Q06MWI`1I
FET0G5aL06=SH`1KFe/0GUiN05aLG01QHF40GemO05eMG@1KFe/0IVIV05mOG`1MGEd0HV9R065QH@1K
Fe/0EeMG05UIF@1PH600G5aL061PH01LG5`0FEUI061PH01HF5P0GemO05IFEP1IFET0F5QH05eMG@1G
EeL0F5QH00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0;05aLG01OGel0
GEeM05aLG01RHV80GemO05UIF@1WIfL0HV9R061PH01QHF400`1NGUh03@1RHV80GemO06ATI01RHV80
IVIV065QH@1OGel0HV9R05mOG`1TI6@0H61P06=SH`1QHF400P1LG5`06@1QHF40FUYJ05eMG@1SHf<0
I6AT05eMG@1RHV80I6AT05iNGP1VIVH0Hf=S05iNGP1JFUX0HV9R061PH01KFe/0Hf=S06EUI@1OGel0
H61P065QH@1RHV80I6AT06EUI@1XJ6P00`1OGel206=SH`0706EUI@1WIfL0I6AT06IVIP1WIfL0J6QX
065QH@0206IVIP0@06YZJP1RHV80IFEU06UYJ@1UIFD0IfMW065QH@1XJ6P0Jf][06IVIP1YJFT0Jf][
06MWI`1/K6`0I6AT06YZJP80IfMW00/0IVIV06YZJP1[Jf/0K6a/071`L01UIFD0LG5a06YZJP1VIVH0
Lg=c06MWI`0206a/K007079bLP1]KFd0KFe]071`L01aLG40L71`06e]K@0206][J`0606a/K01`L700
MGEe075aL@1ZJVX0JFUY0P1`L7001@1dM7@0JVYZ07=cL`1[Jf/0Kfm_0080MgMg0`1bLW803P1eMGD0
KVi^07]kN`1^KVh0LW9b071`L01ZJVX0M7Ad07alO01gMgL0JVYZ075aL@1hN7P0MgMg0P1eMGD0501^
KVh0Lg=c07MgM`1bLW80MGEe07MgM`1fMWH0KVi^07QhN01jNWX0MWIf06a/K01YJFT0MgMg075aL@1h
N7P0MgMg07QhN01bLW80Kfm_0P1aLG40601`L700JFUY07=cL`1cLg<0NGUi075aL@1kNg/0MgMg07Ee
M@1gMgL0Lg=c06e]K@1XJ6P0LG5a06a/K01bLW80KFe]07EeM@1^KVh0LW9b07EeM@1^KVh0JFUY06m_
K`80LG5a00P0MgMg07EeM@1_Kfl0MGEe071`L01]KFd0MgMg06a/K080LW9b01@0MGEe06][J`1^KVh0
Lg=c06YZJP1WIfL0KVi^06UYJ@1aLG40KFe]07=cL`1XJ6P0K6a/06][J`1`L700KVi^06a/K01SHf<0
K6a/06YZJP80JFUY00`0K6a/06YZJP1YJFT0Jf][06UYJ@1WIfL0KFe]06][J`1YJFT0Jf][06m_K`1]
KFd206m_K`0806a/K01`L700KVi^07IfMP1dM7@0LW9b075aL@23Ph<207YjNP0607emO@1lO7`0MGEe
07YjNP1gMgL0KVi^0P1iNGT04`1]KFd0KVi^071`L01[Jf/0Fe]K06i^KP1YJFT0L71`06ATI01RHV80
KFe]06EUI@1SHf<0JFUY06ATI01RHV80Hf=S061PH01NGUh00P1QHF401P1NGUh0I6AT06ATI01JFUX0
I6AT05]KF`80HV9R00X0GemO06=SH`1NGUh0Hf=S06EUI@1JFUX0GUiN05eMG@1QHF40GemO0P1PH600
4`1OGel0EUIF05aLG01IFET0GemO065QH@1LG5`0FEUI05YJFP1MGEd0G5aL05iNGP1IFET0HV9R05eM
G@1JFUX0FEUI06ATI01FEUH01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI
0180GEeM05QHF01LG5`0HF5Q05iNGP1SHf<0HF5Q05mOG`1VIVH0Fe]K061PH01KFe/0GUiN05]KF`1M
GEd0I6AT065QH@1UIFD206=SH`0R06QXJ01WIfL0I6AT05mOG`1PH600FEUI065QH@1WIfL0H61P05aL
G01JFUX0HF5Q05mOG`1QHF40FEUI05eMG@1QHF40I6AT061PH01UIFD0GUiN05aLG01RHV80H61P069R
HP1QHF40HV9R061PH01NGUh0H61P06][J`1NGUh0HF5Q061PH080J6QX00@0I6AT06=SH`1QHF40IFEU
0P1YJFT08P1OGel0JFUY05eMG@1^KVh0K6a/06ATI01ZJVX0IfMW06EUI@1PH600J6QX065QH@1ZJVX0
J6QX06MWI`1SHf<0HF5Q071`L01PH600J6QX06YZJP1[Jf/0I6AT06a/K01ZJVX0KVi^06ATI01ZJVX0
Jf][06UYJ@1VIVH0J6QX06e]K@1YJFT206][J`0A071`L01YJFT0L71`06QXJ01aLG40KVi^06e]K@1W
IfL0JFUY06e]K@1bLW80Kfm_07=cL`1aLG40KVi^07AdM01iNGT00P1]KFd04@1bLW80MGEe06m_K`1]
KFd0KVi^06YZJP1gMgL0MWIf07QhN01fMWH0Lg=c079bLP1fMWH0LW9b07UiN@1eMGD0MgMg0080Kfm_
00X0KVi^07QhN01/K6`0KVi^079bLP1mOGd0MWIf075aL@1gMgL0K6a/0P1fMWH02P1`L700LG5a06m_
K`1jNWX0KVi^07UiN@1cLg<0KFe]071`L01dM7@2071`L00?06m_K`1dM7@0Lg=c07=cL`1/K6`0N7Qh
079bLP1dM7@0Kfm_075aL@1iNGT0Kfm_07EeM@1kNg/0LW9b0080KFe]00D0MGEe06e]K@1`L700Ng]k
07MgM`0207=cL`0C06][J`1^KVh0K6a/079bLP1iNGT0Kfm_06a/K01`L700Kfm_06e]K@1hN7P0K6a/
071`L01/K6`0M7Ad06UYJ@1cLg<0KFe]075aL@0206e]K@0306IVIP1YJFT0JFUY0080KVi^00d0Jf][
06m_K`1TI6@0JFUY06IVIP1dM7@0Jf][06MWI`1KFe/0Kfm_06MWI`1[Jf/0Kfm_0080I6AT0140KVi^
06YZJP1YJFT0J6QX06MWI`1XJ6P0JFUY061PH01`L700J6QX06MWI`1[Jf/0LG5a06i^KP1WIfL0KVi^
06][J`0206i^KP0807EeM@1lO7`0LW9b06i^KP1eMGD0Lg=c06i^KP1YJFT2079bLP0906][J`1/K6`0
K6a/069RHP1ZJVX0Hf=S06i^KP1WIfL0JVYZ0080IFEU00T0IfMW06IVIP1XJ6P0IfMW06=SH`1PH600
I6AT05eMG@1UIFD00P1PH6001`1MGEd0HF5Q06EUI@1MGEd0IVIV05]KF`1QHF400P1NGUh01P1MGEd0
HV9R06EUI@1LG5`0GUiN05aLG080GemO0100HV9R05QHF01EEED0EeMG05QHF01FEUH0F5QH05iNGP1H
F5P0FEUI05]KF`1IFET0GEeM05aLG01SHf<0FEUI0P1JFUX00`1PH600FEUI061PH0060=WIf@400000
0@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT01P1SHf<0GEeM05eMG@1OGel0IFEU069RHP<0
G5aL00X0HV9R065QH@1NGUh0GUiN06EUI@1LG5`0IVIV06=SH`1TI6@0IVIV0P1RHV801P1MGEd0IVIV
06=SH`1LG5`0EEEE05eMG@80GemO00l0GUiN05mOG`1QHF40FEUI061PH01HF5P0Hf=S05]KF`1MGEd0
IVIV069RHP1TI6@0Hf=S05aLG01PH6000P1OGel205]KF`0306EUI@1OGel0JVYZ0080HF5Q0240GUiN
05mOG`1OGel0IFEU06ATI01VIVH0JFUY06IVIP1bLW80GUiN05aLG01YJFT0Jf][06ATI01VIVH0GEeM
06MWI`1NGUh0GEeM061PH01RHV80JFUY06MWI`1]KFd0Hf=S06ATI01WIfL0J6QX06=SH`1XJ6P0Hf=S
075aL@1YJFT00P1ZJVX03`1_Kfl0KVi^06UYJ@1VIVH0I6AT06a/K01[Jf/0K6a/075aL@1dM7@0KVi^
06MWI`1/K6`0J6QX071`L00207=cL`0k07EeM@1`L700Jf][06QXJ01cLg<0LG5a079bLP1`L700Lg=c
06][J`1`L700LG5a06a/K01bLW80Lg=c06m_K`1bLW80Lg=c07EeM@1dM7@0Ng]k07QhN01aLG40KVi^
07UiN@1dM7@0Jf][07IfMP1aLG40K6a/07AdM01bLW80Kfm_075aL@1dM7@0K6a/07=cL`1_Kfl0KVi^
07EeM@1]KFd0MWIf06a/K01_Kfl0M7Ad075aL@1fMWH0K6a/079bLP1_Kfl0LG5a07=cL`1^KVh0L71`
06i^KP1cLg<0LG5a06UYJ@1jNWX00P1bLW802@1gMgL0Lg=c075aL@1`L700MgMg06i^KP1cLg<0LW9b
06a/K002071`L00606e]K@1_Kfl0LW9b075aL@1XJ6P0Lg=c0P1dM7@01`1^KVh0K6a/07=cL`1/K6`0
LG5a06m_K`1`L7000P1^KVh04P1_Kfl0L71`079bLP1`L700MGEe07AdM01bLW80KVi^06e]K@1_Kfl0
L71`06e]K@1YJFT0M7Ad06YZJP1[Jf/0I6AT06a/K080IFEU00H0KFe]061PH01]KFd0IVIV06MWI`1Z
JVX206][J`0]06YZJP1RHV80KVi^06MWI`1SHf<0JFUY075aL@1SHf<0I6AT06][J`1/K6`0JFUY07If
MP1QHF40K6a/06YZJP1]KFd0IfMW06m_K`1VIVH0Lg=c06][J`1]KFd0MgMg07IfMP1]KFd0Lg=c06m_
K`1]KFd0Lg=c06i^KP1ZJVX0IVIV06MWI`1`L700H61P06UYJ@1SHf<0IfMW06YZJP1YJFT0K6a/06MW
I`1ZJVX0IVIV0080IfMW00d0JFUY06IVIP1RHV80HF5Q069RHP1SHf<0I6AT05]KF`1NGUh0Hf=S06MW
I`1SHf<0GEeM0080IFEU0P1RHV80101TI6@0G5aL05eMG@1VIVH2065QH@0905eMG@1LG5`0GemO065Q
H@1JFUX0GUiN05YJFP1KFe/0EEEE0080EUIF00/0FUYJ05MGE`1FEUH0HV9R05QHF01LG5`0F5QH05iN
GP1UIFD0EEEE05ADE0060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT02`1O
Gel0FUYJ061PH01EEED0IfMW05mOG`1NGUh0HV9R05]KF`1IFET0H61P0080HF5Q00D0Fe]K05UIF@1P
H600GemO065QH@0205aLG00905]KF`1QHF40Fe]K05MGE`1DE5@0HV9R05iNGP1MGEd0FEUI0080I6AT
01`0GEeM059BDP1PH600FUYJ06UYJ@1LG5`0GUiN06EUI@1QHF40HV9R06EUI@1PH600I6AT06EUI@1N
GUh0I6AT06=SH`1RHV80I6AT06MWI`1XJ6P0GemO06ATI01XJ6P0IVIV065QH@1VIVH0HV9R0P1QHF40
8@1TI6@0GUiN05mOG`1QHF40IVIV069RHP1QHF40I6AT06=SH`1RHV80LG5a06MWI`1MGEd0HF5Q06=S
H`1TI6@0JFUY06EUI@1VIVH0IFEU06ATI01PH600GemO06EUI@1`L700IfMW06e]K@1TI6@0JFUY06YZ
JP1WIfL0JFUY06ATI00206IVIP0Q07AdM01XJ6P0JVYZ06e]K@1TI6@0Jf][06a/K01_Kfl0KVi^075a
L@1]KFd0Kfm_06][J`1^KVh0Kfm_075aL@1eMGD0KFe]06m_K`1gMgL0JVYZ06m_K`1]KFd0LW9b075a
L@1/K6`0KVi^06YZJP1]KFd0IfMW079bLP1cLg<0Kfm_0080MWIf00H0KVi^06e]K@1_Kfl0L71`07=c
L`1bLW8207=cL`0i07QhN01^KVh0NGUi07]kN`1aLG40MGEe079bLP1eMGD0MgMg06e]K@1^KVh0K6a/
075aL@1`L700MGEe071`L01cLg<0LG5a07AdM01iNGT0Kfm_07AdM01aLG40KFe]079bLP1`L700KFe]
071`L01ZJVX0Kfm_071`L01cLg<0MGEe06e]K@1cLg<0KVi^07AdM01aLG40Jf][06e]K@1aLG40Kfm_
07=cL`1bLW80MGEe07UiN@1`L700Jf][07=cL`1]KFd0JVYZ06i^KP1SHf<0M7Ad07=cL`1bLW80MgMg
0080Lg=c00d0K6a/071`L01]KFd0LG5a06QXJ01iNGT0IFEU06][J`1YJFT0Jf][071`L01ZJVX0IVIV
0080KFe]00L0IfMW06YZJP1]KFd0K6a/06EUI@1WIfL0J6QX0080IfMW00@0JFUY06e]K@1aLG40IfMW
0P1[Jf/0301XJ6P0IFEU06m_K`1^KVh0IFEU06][J`1TI6@0Kfm_06MWI`1YJFT0Hf=S06YZJP80KFe]
00D0Kfm_06YZJP1WIfL0Jf][079bLP0206a/K00D079bLP1cLg<0KFe]06QXJ01/K6`0Jf][06YZJP1X
J6P0I6AT069RHP1WIfL0Hf=S06EUI@1WIfL0JVYZ061PH01XJ6P0Jf][06IVIP1YJFT2069RHP0B06=S
H`1MGEd0H61P05iNGP1PH600IFEU06UYJ@1XJ6P0HF5Q05eMG@1PH600IfMW061PH01NGUh0FUYJ05eM
G@1OGel0Hf=S0P1MGEd05`1NGUh0K6a/06=SH`1QHF40Fe]K069RHP1NGUh0Fe]K05mOG`1GEeL0G5aL
05iNGP1KFe/0GEeM05EEE@1GEeL0GemO05iNGP1KFe/0H61P069RHP1JFUX0FEUI00H0fMWI0@000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@08061PH01KFe/0GUiN065QH@1RHV80FUYJ061P
H01MGEd205mOG`0606EUI@1NGUh0HF5Q06ATI01IFET0Hf=S0P1NGUh05P1QHF40GUiN05aLG01QHF40
GemO05eMG@1NGUh0HF5Q05mOG`1LG5`0I6AT061PH01NGUh0HF5Q05aLG01NGUh0FUYJ065QH@1KFe/0
H61P05aLG01NGUh2061PH00>05aLG01OGel0H61P05eMG@1OGel0Jf][06ATI01NGUh0IFEU069RHP1O
Gel0IFEU06ATI01QHF4205mOG`0P06=SH`1IFET0HF5Q06=SH`1RHV80IFEU061PH01XJ6P0IVIV065Q
H@1MGEd0I6AT06MWI`1VIVH0Hf=S05mOG`1UIFD0I6AT05mOG`1NGUh0Jf][06QXJ01TI6@0J6QX065Q
H@1TI6@0K6a/06=SH`1ZJVX0Hf=S06e]K@1YJFT206ATI00;06a/K01ZJVX0J6QX071`L01ZJVX0KFe]
06YZJP1XJ6P0IfMW069RHP1]KFd00P1aLG402`1`L700KVi^05eMG@1bLW80Jf][07AdM01^KVh0Lg=c
07AdM01bLW80Kfm_0080Jf][03l0Kfm_071`L01dM7@0JVYZ07=cL`1ZJVX0Kfm_075aL@1fMWH0K6a/
07AdM01aLG40L71`075aL@1YJFT0MGEe079bLP1iNGT0MgMg071`L01^KVh0K6a/079bLP1]KFd0LG5a
06][J`1`L700MWIf06i^KP1dM7@0K6a/07YjNP1`L700KVi^07IfMP1^KVh0K6a/079bLP1_Kfl0L71`
07AdM01^KVh0K6a/06m_K`1^KVh0LW9b071`L01_Kfl0MgMg07AdM01[Jf/0MGEe06m_K`1^KVh0K6a/
075aL@1fMWH0JVYZ06a/K01bLW80KVi^06a/K01ZJVX00P1[Jf/0201YJFT0KVi^06m_K`1dM7@0K6a/
06e]K@1_Kfl0JFUY0P1aLG40:01`L700JFUY06a/K01`L700OGem07AdM01bLW80MWIf079bLP1_Kfl0
MgMg071`L01/K6`0JFUY07=cL`1^KVh0JFUY06i^KP1cLg<0IFEU06MWI`1`L700IFEU06e]K@1TI6@0
J6QX06EUI@1XJ6P0IVIV06UYJ@1WIfL0JVYZ06ATI01QHF40J6QX06IVIP1ZJVX0IfMW06IVIP1SHf<2
06YZJP0H06MWI`1]KFd0IVIV06i^KP1cLg<0J6QX06ATI01ZJVX0Jf][06UYJ@1]KFd0Kfm_06EUI@1^
KVh0JVYZ06MWI`1VIVH0HV9R071`L01VIVH0JVYZ06UYJ@1[Jf/0K6a/0P1SHf<0<@1[Jf/0Hf=S06QX
J01[Jf/0GemO06EUI@1VIVH0Hf=S065QH@1XJ6P0I6AT06EUI@1MGEd0JVYZ06=SH`1QHF40Fe]K05mO
G`1QHF40GUiN05]KF`1QHF40GemO05]KF`1JFUX0HV9R06ATI01QHF40GEeM05aLG01SHf<0H61P05eM
G@1OGel0F5QH05iNGP1OGel0GEeM05aLG01GEeL0GemO05EEE@1OGel0HV9R05eMG@1FEUH0GUiN061P
H01OGel00P1KFe/00`1IFET0FUYJ0=WIf@050=WIf@4000000@3IfMT000<0fMWI0`0000020=WIf@80
0000103IfMT2000000H0fMWI00<000000=WIf@3IfMT00`3IfMT0=@1JFUX0GEeM06MWI`1FEUH0HF5Q
05aLG01MGEd0FUYJ05iNGP1LG5`0IFEU061PH01SHf<0H61P05UIF@1UIFD0GUiN065QH@1[Jf/0HV9R
06=SH`1PH600Hf=S06IVIP1OGel0H61P069RHP1VIVH0F5QH05iNGP1IFET0G5aL065QH@1MGEd0HF5Q
069RHP1NGUh0HF5Q05mOG`1NGUh0IVIV061PH01QHF40Hf=S065QH@1TI6@0GemO05eMG@1UIFD0HV9R
065QH@1TI6@0J6QX00<0IFEU00H0I6AT06a/K01LG5`0GEeM05mOG`1TI6@2065QH@0:06UYJ@1XJ6P0
Hf=S06ATI01RHV80GemO06YZJP1VIVH0J6QX06a/K080I6AT00@0IFEU065QH@1UIFD0IFEU0P1YJFT3
06MWI`1506YZJP1XJ6P0JFUY065QH@1ZJVX0Jf][06IVIP1SHf<0IFEU06YZJP1WIfL0JFUY06QXJ01^
KVh0JVYZ06QXJ01aLG40Jf][06i^KP1SHf<0KFe]06YZJP1]KFd0LW9b06YZJP1dM7@0J6QX06a/K01a
LG40KFe]06i^KP1bLW80LG5a06a/K01WIfL0NGUi079bLP1hN7P0KVi^07IfMP1`L700Lg=c06][J`1d
M7@0L71`07=cL`1XJ6P0N7Qh07=cL`1YJFT0KVi^06m_K`1cLg<0L71`06UYJ@1_Kfl0LW9b06i^KP1e
MGD0L71`06YZJP1dM7@0LW9b07]kN`1gMgL0MWIf075aL@1eMGD0KVi^0080Kfm_00@0IfMW071`L01/
K6`0LG5a0`1]KFd04@1_Kfl0KFe]06m_K`1WIfL0Kfm_075aL@1`L700JVYZ07=cL`1`L700M7Ad071`
L01]KFd0L71`06UYJ@1]KFd0K6a/0080KVi^00H0IVIV06e]K@1/K6`0Jf][06i^KP1`L70206m_K`0>
075aL@1cLg<0Jf][079bLP1cLg<0KVi^075aL@1cLg<0OWin07MgM`1kNg/0OGem07UiN@1eMGD2071`
L00?06m_K`1XJ6P0HV9R06ATI01/K6`0Jf][06e]K@1_Kfl0I6AT06UYJ@1]KFd0Hf=S075aL@1RHV80
Jf][0080Hf=S00@0IVIV06EUI@1QHF40JVYZ0P1/K6`02@1QHF40JVYZ06YZJP1XJ6P0IfMW06QXJ01T
I6@0GEeM06MWI`0206EUI@0U061PH01]KFd0IVIV06UYJ@1^KVh0J6QX06=SH`1]KFd0Hf=S05mOG`1Y
JFT0I6AT06YZJP1RHV80IFEU06MWI`1UIFD0I6AT06i^KP1XJ6P0Hf=S061PH01FEUH0JVYZ05iNGP1P
H600Hf=S06YZJP1QHF40Hf=S069RHP1VIVH0HV9R05YJFP1QHF40Hf=S05aLG00305mOG`0R069RHP1T
I6@0IfMW05mOG`1UIFD0GUiN05mOG`1PH600IfMW065QH@1YJFT0G5aL05UIF@1VIVH0HF5Q05mOG`1P
H600Fe]K05EEE@1KFe/0FUYJ05IFEP1NGUh0G5aL05QHF01JFUX0GemO06QXJ01NGUh0GemO05]KF`1I
FET0G5aL05UIF@H0fMWI0@0000010=WIf@00103IfMT010000000fMWI0=WIf@0000020=WIf@040000
003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@09
05IFEP1GEeL0EEEE05mOG`1NGUh0Fe]K05mOG`1NGUh0F5QH0080HV9R0140GUiN06EUI@1PH600GUiN
05aLG01OGel0Fe]K06IVIP1NGUh0Fe]K05iNGP1SHf<0I6AT05]KF`1LG5`0Fe]K05UIF@0205mOG`06
061PH01KFe/0Fe]K05QHF01MGEd0FUYJ0P1PH600201SHf<0GEeM05iNGP1KFe/0GUiN065QH@1RHV80
G5aL0P1RHV8206=SH`0906UYJ@1OGel0GemO06=SH`1OGel0IFEU065QH@1TI6@0IFEU0080H61P00H0
Hf=S065QH@1WIfL0IfMW06=SH`1OGel206=SH`08061PH01TI6@0IVIV06MWI`1[Jf/0KFe]06MWI`1T
I6@206i^KP80I6AT00H0IfMW06IVIP1XJ6P0I6AT061PH01YJFT206QXJ00406EUI@1YJFT0JVYZ06EU
I@80JFUY00P0K6a/06ATI01WIfL0KFe]06IVIP1ZJVX0J6QX06MWI`80L71`00<0IVIV06e]K@1[Jf/0
0P1aLG4206][J`0:06e]K@1^KVh0MGEe06i^KP1YJFT0KFe]06m_K`1[Jf/0Kfm_06MWI`80Jf][00X0
KVi^07EeM@1_Kfl0MWIf071`L01/K6`0Lg=c075aL@1^KVh0Kfm_0P1eMGD01`1`L700MWIf079bLP1Z
JVX0Kfm_07YjNP1bLW800P1[Jf/0101_Kfl0LW9b07=cL`1YJFT206m_K`0306e]K@1gMgL0MGEe0080
LW9b00T0K6a/079bLP1_Kfl0J6QX06][J`1bLW80LG5a07AdM01_Kfl00P1dM7@206e]K@0E07AdM01`
L700Jf][06][J`1^KVh0Lg=c06e]K@1[Jf/0L71`06EUI@1VIVH0Lg=c06YZJP1aLG40JVYZ06=SH`1b
LW80KFe]06a/K01bLW80L71`0080K6a/01@0JVYZ06e]K@1ZJVX0J6QX07AdM01bLW80Q8B408b<S02B
TY80WIfM08f=S@1lO7`0K6a/06][J`1ZJVX0IVIV06UYJ@1_Kfl0Jf][06YZJP80J6QX0140IfMW06IV
IP1PH600JFUY06][J`1QHF40J6QX06YZJP1^KVh0IFEU06IVIP1QHF40Kfm_06EUI@1XJ6P0Jf][06MW
I`0206IVIP0406e]K@1TI6@0KVi^06UYJ@80J6QX01@0JVYZ06IVIP1UIFD0KVi^06ATI01XJ6P0JFUY
06i^KP1LG5`0JFUY05mOG`1NGUh0JVYZ05aLG01WIfL0H61P06IVIP1RHV80H61P06EUI@80JFUY03D0
HV9R06=SH`1SHf<0GUiN06MWI`1SHf<0KVi^065QH@1TI6@0H61P05MGE`1PH600IfMW065QH@1UIFD0
IfMW05mOG`1RHV80GemO06EUI@1TI6@0Hf=S061PH01SHf<0GEeM06ATI01GEeL0HF5Q05iNGP1IFET0
HV9R05]KF`1VIVH0I6AT06=SH`1CDe<0H61P05UIF@1NGUh0EEEE05aLG01GEeL0FEUI05aLG01PH600
GEeM05aLG01MGEd0GUiN05MGE`1JFUX0EEEE061PH0060=WIf@4000000@3IfMT000030=WIf@000000
000000<0000000D0fMWI0000003IfMT0fMWI000000020=WIf@040000003IfMT0fMWI000000D0fMWI
0`0000030=WIf@0H05]KF`1GEeL0Fe]K05mOG`1QHF40FEUI069RHP1IFET0G5aL05IFEP1KFe/0GEeM
061PH01KFe/0G5aL05iNGP1PH600IFEU05eMG@1LG5`0HF5Q061PH01OGel0GUiN0P1OGel0201GEeL0
Fe]K05]KF`1RHV80GUiN06=SH`1OGel0HV9R0P1SHf<03@1RHV80GemO06=SH`1QHF40HV9R05mOG`1F
EUH0GEeM06IVIP1KFe/0HF5Q069RHP1VIVH0101PH600301ZJVX0EeMG05eMG@1VIVH0IfMW061PH01V
IVH0I6AT05iNGP1PH600GemO06EUI@80Hf=S0180GUiN06][J`1TI6@0J6QX06MWI`1UIFD0IfMW061P
H01/K6`0IVIV06][J`1QHF40IFEU06=SH`1MGEd0GemO06][J`1WIfL206YZJP0<06=SH`1VIVH0HV9R
06YZJP1WIfL0Hf=S06IVIP1YJFT0IfMW06m_K`1WIfL0I6AT101[Jf/0=`1^KVh0JVYZ06UYJ@1/K6`0
J6QX06a/K01`L700Jf][07EeM@1[Jf/0LW9b06a/K01VIVH0Lg=c079bLP1_Kfl0MGEe079bLP1aLG40
Kfm_06e]K@1gMgL0Jf][07IfMP1bLW80Kfm_07EeM@1]KFd0Lg=c071`L01aLG40KFe]06m_K`1ZJVX0
KVi^06a/K01eMGD0KVi^07AdM01[Jf/0LG5a079bLP1_Kfl0KFe]079bLP1iNGT0LW9b071`L01_Kfl0
J6QX071`L01VIVH0JVYZ06a/K01WIfL00P1/K6`07@1_Kfl0KFe]06][J`1aLG40KFe]06m_K`1bLW80
KFe]06i^KP1`L700Kfm_06YZJP1`L700KFe]06ATI01`L700KFe]06i^KP1_Kfl0IfMW06a/K01ZJVX0
Kfm_06i^KP1aLG40KVi^06YZJP1aLG40Jf][0080K6a/01h0KFe]06][J`1fMWH0L71`06e]K@1cLg<0
QHF5092@T02f][H0c<c<0>KViP2d];@0Ti>C071`L01VIVH0KFe]06UYJ@1QHF40J6QX06m_K`1UIFD0
KVi^06UYJ@1/K6`0Kfm_06=SH`1RHV80Hf=S06i^KP1PH60206ATI00306IVIP1_Kfl0IfMW0080IfMW
0100Hf=S06UYJ@1VIVH0Hf=S06QXJ01QHF40GemO06IVIP1XJ6P0GUiN06YZJP1UIFD0Hf=S06QXJ01Y
JFT0Hf=S0P1WIfL0901RHV80G5aL06MWI`1UIFD0EUIF06=SH`1RHV80HF5Q069RHP1NGUh0IfMW061P
H01VIVH0IfMW06QXJ01RHV80J6QX06ATI01NGUh0HF5Q06MWI`1TI6@0HV9R06ATI01OGel0GUiN06AT
I01UIFD0J6QX05mOG`1SHf<0J6QX065QH@1VIVH0GEeM069RHP<0IfMW00D0GEeM06ATI01JFUX0J6QX
05eMG@0205]KF`0C065QH@1GEeL0HF5Q05mOG`1LG5`0GemO06=SH`1NGUh0F5QH05eMG@1KFe/0GEeM
05EEE@1JFUX0GemO061PH01LG5`0GUiN061PH00205eMG@0305MGE`3IfMT0fMWI0080fMWI0`000001
0=WIf@0000D0fMWI0000003IfMT0fMWI000000020=WIf@040000003IfMT0fMWI00000080fMWI00@0
00000=WIf@3IfMT000001@3IfMT00`000000fMWI0=WIf@030=WIf@80GUiN0140FUYJ05mOG`1SHf<0
HV9R05]KF`1HF5P0GEeM05QHF01LG5`0IFEU05aLG01NGUh0Hf=S05UIF@1NGUh0HF5Q069RHP0205mO
G`0305iNGP1TI6@0FUYJ0080HV9R0P1MGEd02`1FEUH0GUiN05MGE`1IFET0G5aL06YZJP1QHF40EeMG
05mOG`1MGEd0GUiN0080GemO00P0G5aL065QH@1WIfL0Fe]K06=SH`1YJFT0GemO06=SH`80GemO01<0
F5QH06=SH`1NGUh0H61P05mOG`1QHF40I6AT05YJFP1SHf<0I6AT06MWI`1UIFD0GUiN06YZJP1MGEd0
J6QX06EUI@1XJ6P0GemO0080I6AT00`0IFEU06QXJ01XJ6P0K6a/06m_K`1/K6`0GemO06][J`1YJFT0
HF5Q061PH01XJ6P506YZJP0506e]K@1UIFD0JFUY06YZJP1RHV800P1YJFT01@1bLW80Hf=S06m_K`1Z
JVX0IVIV0080JFUY00T0IfMW06][J`1/K6`0KFe]06][J`1YJFT0JVYZ06i^KP1]KFd00P1_Kfl00`1b
LW80L71`06i^KP0206a/K080J6QX0100KFe]06m_K`1ZJVX0MGEe071`L01[Jf/0KFe]071`L01cLg<0
K6a/07EeM@1aLG40Kfm_075aL@1`L700Kfm_0P1cLg<01P1gMgL0LG5a07=cL`1/K6`0KVi^075aL@80
K6a/00T0M7Ad07IfMP1_Kfl0L71`07=cL`1/K6`0KVi^075aL@1YJFT00P1aLG40401[Jf/0KFe]06MW
I`1cLg<0LG5a06i^KP1YJFT0KVi^06e]K@1`L700Kfm_06UYJ@1gMgL0N7Qh06e]K@1iNGT206UYJ@0W
06e]K@1ZJVX0Lg=c06e]K@1_Kfl0LG5a07EeM@1aLG40M7Ad06a/K01VIVH0Lg=c079bLP1^KVh0IVIV
06e]K@1/K6`0N7Qh07IfMP1^KVh0N7Qh08B4Q02IVIT0g]kN0?Ogm`3`l?00`<3009bLW01dM7@0KVi^
079bLP1XJ6P0KFe]06m_K`1VIVH0K6a/06YZJP1VIVH0JVYZ0080I6AT00D0J6QX06ATI01YJFT0J6QX
061PH002069RHP0406][J`1VIVH0IfMW06][J`<0IfMW01D0I6AT069RHP1YJFT0IVIV06=SH`1PH600
J6QX06EUI@1XJ6P0JVYZ06][J`1LG5`0IFEU06MWI`1TI6@0IfMW05iNGP1TI6@0IVIV069RHP1YJFT0
0`1PH600101UIFD0GemO05mOG`1PH602069RHP0D061PH01QHF40I6AT06UYJ@1PH600J6QX06=SH`1U
IFD0HF5Q05eMG@1SHf<0I6AT061PH01XJ6P0GemO065QH@1SHf<0JFUY05iNGP1YJFT206IVIP0>06=S
H`1QHF40Hf=S05mOG`1MGEd0G5aL05eMG@1NGUh0HF5Q06=SH`1TI6@0H61P05aLG01MGEd205aLG007
05QHF01NGUh0GUiN05iNGP1LG5`0GemO05]KF`02069RHP0605IFEP1RHV80HF5Q05]KF`1LG5`0FUYJ
1P3IfMT100000040fMWI00020=WIf@030000003IfMT000000080fMWI00@000000=WIf@3IfMT00000
0P3IfMT010000000fMWI0=WIf@0000050=WIf@030000003IfMT0fMWI00<0fMWI01H0Fe]K05EEE@1P
H600FUYJ069RHP1OGel0HF5Q06ATI01SHf<0G5aL069RHP1QHF40GemO06MWI`1KFe/0EUIF05]KF`1M
GEd0G5aL05ADE01QHF40EUIF0P1HF5P03`1LG5`0H61P05aLG01IFET0HF5Q05aLG01JFUX0GUiN061P
H01EEED0Fe]K05iNGP1PH600G5aL069RHP0205iNGP0606EUI@1RHV80GemO05aLG01MGEd0De=C0P1P
H600301OGel0Fe]K065QH@1MGEd0HV9R05aLG01UIFD0Hf=S065QH@1RHV80G5aL065QH@80I6AT00d0
HV9R06MWI`1/K6`0IVIV06=SH`1WIfL0Hf=S065QH@1XJ6P0GUiN06YZJP1[Jf/0I6AT00@0J6QX01l0
JVYZ069RHP1SHf<0I6AT06m_K`1aLG40IVIV06YZJP1XJ6P0JFUY06=SH`1WIfL0JFUY06YZJP1UIFD0
Hf=S06EUI@1YJFT0IVIV06][J`1YJFT0K6a/06UYJ@1VIVH0KVi^06m_K`1VIVH0KFe]06i^KP1WIfL0
MWIf0080L71`00H0Kfm_06IVIP1aLG40MWIf07UiN@1dM7@206m_K`0I06YZJP1aLG40IVIV06a/K01Y
JFT0Jf][071`L01XJ6P0LG5a06MWI`1`L700KFe]06ATI01gMgL0KFe]07UiN@1fMWH0MGEe07IfMP1d
M7@0J6QX07AdM01iNGT0J6QX079bLP0206][J`0>07=cL`1YJFT0MWIf07IfMP1bLW80Lg=c06=SH`1[
Jf/0Lg=c079bLP1cLg<0Kfm_075aL@1_Kfl206e]K@0;07AdM01^KVh0JVYZ07=cL`1TI6@0JFUY06a/
K01[Jf/0Kfm_06i^KP1bLW800P1[Jf/00`1bLW80Lg=c06QXJ00206i^KP0A075aL@1/K6`0K6a/06a/
K01ZJVX0K6a/06YZJP1UIFD0Jf][07AdM01[Jf/0KFe]07MgM`1aLG40PX:209RHV02e]KD00`3oool0
302VYZH0RXZ:07EeM@1WIfL0JFUY06a/K01^KVh0J6QX06m_K`1`L700J6QX06][J`<0IVIV02X0GemO
06IVIP1RHV80J6QX06ATI01SHf<0JVYZ06MWI`1UIFD0IfMW065QH@1RHV80K6a/06IVIP1RHV80JVYZ
06UYJ@1PH600KVi^069RHP1SHf<0GEeM06QXJ01RHV80IFEU06MWI`1[Jf/0IVIV061PH01MGEd0I6AT
05iNGP1JFUX0GemO06IVIP1PH600Hf=S06UYJ@1TI6@0Hf=S05aLG01UIFD2069RHP0<05mOG`1RHV80
I6AT065QH@1NGUh0J6QX05iNGP1TI6@0HV9R061PH01UIFD0I6AT0P1YJFT08`1OGel0GEeM06ATI01K
Fe/0K6a/06][J`1TI6@0H61P069RHP1VIVH0G5aL065QH@1MGEd0GemO06IVIP1GEeL0HF5Q05aLG01W
IfL0EEEE05mOG`1SHf<0GemO05aLG01JFUX0EUIF05YJFP1IFET0EeMG05aLG01IFET0EUIF05iNGP1M
GEd0F5QH0080FUYJ00<0DU9B05QHF03IfMT01@3IfMT100000040fMWI00030=WIf@8000000`3IfMT2
000000@0fMWI0P0000060=WIf@030000003IfMT0fMWI00<0fMWI00@0GUiN05YJFP1KFe/0Fe]K0P1R
HV801`1IFET0G5aL05]KF`1NGUh0GEeM061PH01QHF400P1LG5`0201MGEd0GemO06=SH`1RHV80HF5Q
05]KF`1HF5P0H61P0P1NGUh0901IFET0GEeM05eMG@1MGEd0GUiN069RHP1KFe/0IVIV06EUI@1QHF40
IVIV05mOG`1NGUh0I6AT05eMG@1KFe/0FEUI06ATI01OGel0HF5Q05YJFP1VIVH0H61P05mOG`1QHF40
Fe]K069RHP1TI6@0JFUY06ATI01RHV80GEeM06ATI01OGel0GUiN05aLG080HF5Q00@0H61P06ATI01T
I6@0JVYZ0P1XJ6P02`1PH600HF5Q06YZJP1TI6@0IFEU069RHP1VIVH0I6AT06UYJ@1XJ6P0IfMW0080
I6AT00@0IVIV06YZJP1UIFD0K6a/0P1XJ6P01@1OGel0IfMW06UYJ@1/K6`0Jf][0080J6QX00X0JVYZ
06i^KP1^KVh0HF5Q06e]K@1UIFD0KVi^06a/K01^KVh0JFUY0P1]KFd01`1ZJVX0JFUY06i^KP1^KVh0
KFe]06i^KP1[Jf/00P1bLW806@1[Jf/0KVi^06QXJ01^KVh0KFe]06ATI01dM7@0Kfm_06YZJP1XJ6P0
Kfm_079bLP1gMgL0LW9b06a/K01dM7@0KFe]06][J`1`L700MGEe06a/K01[Jf/0Kfm_06a/K01^KVh0
0`1`L70206a/K003075aL@1eMGD0KFe]0080KVi^0180K6a/07EeM@1WIfL0Kfm_06MWI`1]KFd0Lg=c
06][J`1YJFT0J6QX06][J`1ZJVX0KFe]06i^KP1YJFT0LG5a079bLP1[Jf/206e]K@0A06i^KP1/K6`0
J6QX06a/K01[Jf/0K6a/06MWI`1ZJVX0KVi^06a/K01bLW80M7Ad079bLP1]KFd0JVYZ06UYJ@1[Jf/0
0P1_Kfl00`1^KVh0LG5a06a/K002071`L00407IfMP1jNWX0UiNG0;>c/`80oooo00L0j>SX09NGU`25
QHD0KFe]06m_K`1XJ6P0Jf][0080J6QX00P0IfMW069RHP1TI6@0IFEU06MWI`1ZJVX0HF5Q071`L080
IfMW00P0Jf][06=SH`1UIFD0HV9R06=SH`1/K6`0Jf][06MWI`80I6AT01d0Jf][06IVIP1YJFT0JFUY
06QXJ01WIfL0H61P06UYJ@1/K6`0KFe]05YJFP1RHV80GemO06=SH`1[Jf/0HF5Q069RHP1QHF40Hf=S
06ATI01/K6`0HF5Q05mOG`1NGUh0IVIV05mOG`1KFe/0HV9R06=SH`0205mOG`07069RHP1UIFD0IVIV
06ATI01RHV80I6AT05UIF@0206EUI@0406=SH`1YJFT0GEeM061PH080I6AT00L0HF5Q06IVIP1WIfL0
KVi^06YZJP1WIfL0GemO0080HV9R00H0GemO065QH@1KFe/0GEeM06IVIP1QHF42061PH00:06=SH`1P
H600FUYJ069RHP1TI6@0GEeM05]KF`1TI6@0GEeM05QHF080FEUI00T0H61P05mOG`1JFUX0GEeM05YJ
FP1TI6@0Fe]K05aLG01@D5001P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI
00D0G5aL05IFEP1IFET0GEeM05aLG00205iNGP0>05aLG01JFUX0Fe]K06MWI`1SHf<0GEeM06=SH`1Q
HF40I6AT05YJFP1MGEd0GUiN06=SH`1RHV8205]KF`0305aLG01OGel0FEUI0080H61P00X0GUiN05UI
F@1SHf<0H61P05eMG@1RHV80GemO05iNGP1KFe/0Hf=S0P1JFUX3065QH@80GUiN00T0HF5Q05mOG`1I
FET0I6AT05eMG@1PH600GemO06=SH`1TI6@00P1PH60205aLG006069RHP1QHF40GEeM06MWI`1PH600
I6AT0P1UIFD01`1ZJVX0H61P06=SH`1ZJVX0H61P06YZJP1OGel00P1XJ6P0201WIfL0K6a/06MWI`1[
Jf/0J6QX065QH@1_Kfl0J6QX0P1ZJVX206EUI@0<06MWI`1PH600Jf][06ATI01[Jf/0J6QX06MWI`1S
Hf<0JFUY06m_K`1HF5P0JFUY0P1WIfL0201]KFd0H61P06MWI`1YJFT0L71`06][J`1/K6`0JVYZ0P1/
K6`0301XJ6P0HV9R06m_K`1_Kfl0Jf][06e]K@1WIfL0JFUY06][J`1WIfL0KVi^075aL@80Kfm_00T0
M7Ad06m_K`1ZJVX0LG5a06m_K`1XJ6P0K6a/06e]K@1WIfL00`1cLg<0101/K6`0IfMW07AdM01]KFd2
06i^KP0407UiN@1gMgL0KVi^06EUI@<0L71`03T0Jf][06a/K01]KFd0J6QX06MWI`1_Kfl0Jf][06QX
J01^KVh0JFUY06e]K@1cLg<0KFe]06YZJP1aLG40IVIV06m_K`1YJFT0KFe]06QXJ01ZJVX0KFe]06][
J`1YJFT0IVIV06a/K01aLG40IfMW06YZJP1/K6`0Kfm_06=SH`1/K6`0JVYZ06][J`1/K6`0L71`075a
L@1`L700I6AT06UYJ@1^KVh0KFe]079bLP1[Jf/0LG5a07YjNP29RHT0YjNW0<K6aP39bLT0VYZJ07]k
N`1`L700Lg=c06=SH`1UIFD00P1SHf<0901/K6`0J6QX06MWI`1WIfL0J6QX06ATI01[Jf/0K6a/06AT
I01UIFD0I6AT06MWI`1QHF40GemO06UYJ@1/K6`0I6AT065QH@1TI6@0JFUY05]KF`1SHf<0IfMW05aL
G01PH600K6a/05mOG`1SHf<0I6AT06YZJP1YJFT0H61P06ATI01QHF40GEeM06QXJ080GemO01P0IVIV
05mOG`1SHf<0GEeM06=SH`1NGUh0HF5Q06=SH`1WIfL0GEeM069RHP1MGEd0GUiN06MWI`1LG5`0IFEU
05aLG01KFe/0GUiN06=SH`1TI6@0J6QX06ATI01OGel2065QH@0@06ATI01RHV80GUiN06ATI01VIVH0
FUYJ06IVIP1OGel0H61P06UYJ@1UIFD0I6AT06UYJ@1UIFD0Hf=S06a/K080Hf=S01L0GUiN05YJFP1P
H600GemO05]KF`1IFET0HF5Q05UIF@1PH600GEeM05]KF`1MGEd0GUiN05EEE@1BDU80E5AD05UIF@1J
FUX0G5aL05UIF@1JFUX0GEeM05UIF@060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT0
0`3IfMT0201OGel0Fe]K061PH01MGEd0FEUI05QHF01NGUh0GemO0P1JFUX02P1PH600F5QH05YJFP1M
GEd0Fe]K05iNGP1OGel0HF5Q06EUI@1HF5P2061PH00A05UIF@1OGel0I6AT061PH01DE5@0HV9R06IV
IP1MGEd0Hf=S05UIF@1MGEd0H61P06=SH`1TI6@0Fe]K069RHP1IFET00P1OGel02@1NGUh0IVIV05IF
EP1PH600HF5Q05eMG@1UIFD0G5aL06=SH`0205YJFP0;05iNGP1KFe/0HV9R05mOG`1YJFT0I6AT06QX
J01RHV80G5aL06QXJ01LG5`00P1PH600101VIVH0J6QX06ATI01RHV8206UYJ@06065QH@1TI6@0HF5Q
06ATI01ZJVX0JFUY0P1SHf<0=P1/K6`0GEeM06YZJP1YJFT0GEeM075aL@1VIVH0JVYZ06ATI01UIFD0
I6AT069RHP1UIFD0Kfm_06ATI01ZJVX0HV9R06m_K`1TI6@0K6a/06][J`1RHV80IFEU06QXJ01SHf<0
Jf][06YZJP1dM7@0JVYZ06][J`1]KFd0JVYZ06MWI`1/K6`0KFe]06IVIP1cLg<0HV9R06YZJP1WIfL0
L71`06QXJ01_Kfl0Jf][06YZJP1]KFd0Kfm_07EeM@1bLW80LG5a079bLP1aLG40JFUY06e]K@80Jf][
00L0NGUi07=cL`1`L700LG5a06a/K01_Kfl0JVYZ0080L71`00l0LW9b07=cL`1fMWH0M7Ad06m_K`1^
KVh0Lg=c06e]K@1aLG40Kfm_06e]K@1YJFT0IVIV06][J`1cLg<00P1]KFd00`1YJFT0KFe]06m_K`02
06UYJ@0:06e]K@1_Kfl0Kfm_07AdM01_Kfl0KFe]079bLP1_Kfl0LG5a06][J`80KVi^00<0IVIV07Ad
M01/K6`00P1[Jf/0J`1XJ6P0K6a/06][J`1WIfL0JVYZ06QXJ01_Kfl0JFUY071`L01dM7@0KFe]06][
J`1]KFd0Lg=c08J6QP1oOgl0TY:B096AT@1oOgl0LW9b06][J`1ZJVX0HV9R06QXJ01RHV80J6QX06EU
I@1XJ6P0JVYZ061PH01VIVH0I6AT05mOG`1WIfL0IFEU069RHP1YJFT0HV9R06=SH`1NGUh0HF5Q05mO
G`1PH600IfMW06=SH`1[Jf/0H61P06ATI01SHf<0I6AT069RHP1OGel0H61P065QH@1UIFD0I6AT06EU
I@1NGUh0J6QX061PH01OGel0I6AT05YJFP1VIVH0Hf=S06ATI01PH600FUYJ05iNGP1PH600IfMW06UY
J@1QHF40K6a/069RHP1UIFD0HV9R061PH01LG5`0IVIV069RHP1NGUh0IVIV06=SH`1QHF40GUiN05mO
G`1TI6@0GemO05aLG01YJFT0HF5Q06MWI`1UIFD0Hf=S06QXJ01UIFD0KVi^06e]K@1[Jf/0KFe]06EU
I@1RHV80I6AT06IVIP1RHV80Hf=S0080H61P0P1RHV802`1OGel0EeMG05]KF`1NGUh0GemO05QHF01F
EUH0GUiN05eMG@1OGel0G5aL0080GemO00L0GEeM05=CD`1HF5P0GEeM05iNGP1ADE40FEUI00H0fMWI
0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0405]KF`1NGUh0GemO069RHP<0G5aL
0P1OGel07@1NGUh0GEeM05]KF`1PH600HF5Q061PH01EEED0HV9R065QH@1RHV80FUYJ065QH@1NGUh0
Fe]K05MGE`1PH600G5aL05YJFP1UIFD0G5aL069RHP1KFe/0I6AT05eMG@1IFET0F5QH05YJFP1QHF40
F5QH0080GEeM01D0G5aL05iNGP1NGUh0EUIF05aLG01PH600HV9R06MWI`1QHF40G5aL05mOG`1ZJVX0
GemO06EUI@1RHV80HF5Q069RHP1QHF40Hf=S05aLG01SHf<00P1QHF40101WIfL0HV9R061PH01WIfL2
06ATI00;06MWI`1VIVH0I6AT06YZJP1VIVH0IfMW061PH01WIfL0H61P06YZJP1YJFT00P1UIFD0401T
I6@0IfMW06a/K01WIfL0JFUY061PH01QHF40IfMW06ATI01YJFT0IfMW06=SH`1UIFD0KFe]06IVIP1R
HV8206MWI`0906][J`1]KFd0Jf][06QXJ01RHV80Jf][06UYJ@1WIfL0KVi^00<0IfMW00`0KVi^071`
L01cLg<0Kfm_06i^KP1[Jf/0J6QX06e]K@1`L700IVIV06UYJ@1bLW8206a/K00F079bLP1aLG40LW9b
07=cL`1[Jf/0J6QX06YZJP1VIVH0K6a/079bLP1^KVh0Kfm_071`L01[Jf/0JVYZ06m_K`1dM7@0IVIV
06UYJ@1bLW80KFe]06i^KP80L71`00<0JFUY06m_K`1]KFd00P1cLg<05`1ZJVX0KVi^06UYJ@1YJFT0
KVi^06YZJP1aLG40LW9b06i^KP1VIVH0Hf=S06a/K01_Kfl0IfMW06YZJP1VIVH0KVi^06m_K`1[Jf/0
J6QX06UYJ@1cLg<0IFEU0080JVYZ01@0I6AT06UYJ@1TI6@0KVi^06UYJ@1`L700Jf][06=SH`1ZJVX0
JFUY06e]K@1aLG40IVIV06UYJ@1`L700Jf][06a/K01dM7@0MWIf07UiN@80NWYj0180LG5a07EeM@1[
Jf/0IVIV06QXJ01RHV80KVi^06MWI`1TI6@0J6QX06=SH`1VIVH0J6QX06UYJ@1QHF40KVi^06=SH`1T
I6@2069RHP0J06MWI`1QHF40IVIV06ATI01SHf<0I6AT06MWI`1UIFD0J6QX06MWI`1MGEd0Hf=S065Q
H@1VIVH0GUiN06EUI@1RHV80IfMW06IVIP1WIfL0H61P069RHP1TI6@0Fe]K06ATI01LG5`306=SH`06
061PH01VIVH0GEeM06QXJ01SHf<0HV9R0P1UIFD02@1IFET0HF5Q065QH@1RHV80GUiN06=SH`1WIfL0
H61P065QH@0205]KF`80I6AT00`0Hf=S061PH01VIVH0GemO061PH01UIFD0JVYZ061PH01YJFT0J6QX
06YZJP1/K6`206YZJP0L065QH@1OGel0FEUI06=SH`1JFUX0H61P06IVIP1QHF40GUiN05mOG`1LG5`0
GEeM069RHP1PH600G5aL05eMG@1JFUX0G5aL05IFEP1NGUh0HF5Q05UIF@1EEED0GUiN05QHF01LG5`0
FEUI05IFEPH0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0R05aLG01JFUX0
FEUI05iNGP1JFUX0GEeM05mOG`1MGEd0F5QH06=SH`1KFe/0F5QH06=SH`1VIVH0EeMG05]KF`1UIFD0
FEUI05eMG@1PH600Hf=S05aLG01GEeL0GUiN05IFEP1LG5`0GUiN05aLG01PH600HF5Q05aLG01NGUh0
GemO05UIF@80G5aL00H0HV9R05YJFP1LG5`0IVIV05iNGP1PH60205iNGP0:065QH@1TI6@0I6AT05]K
F`1NGUh0Fe]K05mOG`1MGEd0HF5Q05iNGP<0I6AT0200JVYZ05YJFP1JFUX0HF5Q06=SH`1MGEd0HF5Q
069RHP1IFET0IVIV05YJFP1TI6@0G5aL06QXJ01RHV80IFEU05mOG`1RHV80FUYJ06QXJ01RHV80Jf][
05mOG`1XJ6P0IFEU06IVIP1XJ6P0L71`06][J`1OGel0HF5Q06EUI@80KVi^0200IFEU06QXJ01MGEd0
GemO06UYJ@1SHf<0HV9R06ATI01WIfL0JFUY06YZJP1cLg<0Jf][06a/K01^KVh0LW9b06i^KP1YJFT0
IfMW065QH@1]KFd0JFUY06e]K@1/K6`0JVYZ06a/K01YJFT0Lg=c06QXJ01cLg<0I6AT06IVIP80Kfm_
00T0J6QX06YZJP1cLg<0J6QX06a/K01]KFd0LG5a06MWI`1]KFd00`1/K6`0=`1YJFT0Lg=c071`L01U
IFD0KFe]06IVIP1_Kfl0KVi^06UYJ@1SHf<0Lg=c06YZJP1/K6`0MWIf06YZJP1XJ6P0KFe]071`L01S
Hf<0KVi^075aL@1/K6`0JFUY07AdM01bLW80JFUY06m_K`1/K6`0JVYZ06][J`1WIfL0IVIV06UYJ@1Z
JVX0Kfm_06a/K01_Kfl0KVi^065QH@1aLG40L71`06=SH`1aLG40H61P065QH@1UIFD0KVi^06e]K@1^
KVh0IfMW071`L01[Jf/0J6QX06UYJ@1WIfL00`1`L7003@1]KFd0KVi^079bLP1ZJVX0LG5a06e]K@1V
IVH0JFUY06][J`1/K6`0Hf=S06MWI`1[Jf/00P1WIfL01`1PH600IVIV05iNGP1VIVH0J6QX06=SH`1X
J6P00P1UIFD01@1VIVH0H61P06i^KP1PH600JVYZ0080H61P00/0Hf=S06EUI@1NGUh0Hf=S061PH01T
I6@0H61P06ATI01VIVH0IfMW06IVIP03061PH00`06=SH`1ZJVX0GEeM061PH01UIFD0HV9R06EUI@1P
H600G5aL061PH01LG5`0HF5Q06EUI@1OGel0G5aL05]KF`1RHV80IVIV05iNGP1PH600I6AT06UYJ@1L
G5`0GEeM06=SH`1VIVH0GemO06MWI`1QHF40H61P065QH@1WIfL0GemO06MWI`1YJFT0Hf=S06IVIP1T
I6@0IfMW061PH01dM7@0Jf][06a/K01^KVh0LW9b06m_K`1[Jf/0J6QX0P1UIFD02P1TI6@0K6a/069R
HP1PH600FUYJ05ADE01LG5`0H61P05mOG`1LG5`205mOG`0<05YJFP1SHf<0GEeM05mOG`1NGUh0EeMG
05UIF@1GEeL0Fe]K05YJFP1LG5`0HV9R1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI
00<0fMWI00l0H61P05eMG@1LG5`0EEEE05iNGP1IFET0GEeM05MGE`1OGel0GUiN05YJFP1EEED0FUYJ
05]KF`1PH6000P1OGel2069RHP0T05QHF01FEUH0HF5Q05MGE`1KFe/0GemO061PH01IFET0FUYJ05]K
F`1IFET0FUYJ05iNGP1JFUX0I6AT05iNGP1KFe/0Hf=S05MGE`1QHF40Fe]K05MGE`1EEED0FEUI061P
H01LG5`0IFEU061PH01WIfL0HF5Q05mOG`1UIFD0HV9R05iNGP1LG5`0I6AT0`1SHf<206EUI@0305iN
GP1RHV80I6AT0080IfMW00<0HV9R06QXJ01VIVH00P1QHF403@1WIfL0H61P069RHP1NGUh0HF5Q061P
H01OGel0JVYZ06IVIP1RHV80I6AT069RHP1UIFD00P1WIfL00`1[Jf/0J6QX06e]K@0206EUI@0706QX
J01WIfL0IVIV06MWI`1SHf<0HV9R06a/K00206MWI`0<069RHP1QHF40Kfm_06=SH`1]KFd0JVYZ06a/
K01^KVh0K6a/06i^KP1UIFD0IVIV0P1YJFT0101VIVH0KVi^06][J`1_Kfl206UYJ@0406i^KP1WIfL0
KVi^06YZJP80J6QX00@0KFe]06ATI01]KFd0M7Ad0P1[Jf/02@1]KFd0JFUY06e]K@1aLG40KVi^071`
L01dM7@0K6a/06][J`03075aL@<0LW9b00L0Lg=c06e]K@1/K6`0KFe]06a/K01dM7@0Jf][0080JVYZ
0P1^KVh03@1/K6`0M7Ad06][J`1/K6`0LG5a06e]K@1WIfL0J6QX079bLP1YJFT0L71`06][J`1^KVh0
0`1ZJVX00`1^KVh0K6a/06UYJ@0206a/K008069RHP1WIfL0IfMW065QH@1OGel0K6a/06e]K@1`L702
06IVIP0L06EUI@1VIVH0KFe]06EUI@1TI6@0Jf][05mOG`1QHF40Hf=S06MWI`1ZJVX0I6AT05]KF`1R
HV80KFe]06MWI`1ZJVX0Jf][06QXJ01WIfL0IFEU075aL@1RHV80HF5Q06ATI01OGel0JVYZ06ATI080
Hf=S00@0IVIV06m_K`1WIfL0HV9R0P1UIFD01P1OGel0HF5Q069RHP1NGUh0IVIV069RHP80HF5Q0140
HV9R05iNGP1OGel0JFUY06ATI01ZJVX0Jf][06MWI`1NGUh0Hf=S06IVIP1UIFD0HV9R06=SH`1MGEd0
GUiN05aLG00206=SH`0[06MWI`1PH600H61P069RHP1WIfL0GUiN06ATI01ZJVX0FUYJ05]KF`1QHF40
I6AT05iNGP1UIFD0IfMW069RHP1TI6@0GemO061PH01SHf<0H61P05eMG@1RHV80HF5Q06ATI01VIVH0
H61P065QH@1SHf<0KFe]06MWI`1_Kfl0KFe]07EeM@1^KVh0KFe]06YZJP1VIVH0HF5Q061PH01NGUh0
Hf=S06MWI`0205mOG`0<06=SH`1QHF40G5aL065QH@1OGel0Fe]K069RHP1OGel0Fe]K05iNGP1DE5@0
GUiN0P1JFUX0101NGUh0EUIF05QHF01JFUX60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3I
fMT00`3IfMT205mOG`0505QHF01GEeL0GUiN05UIF@1MGEd00P1QHF408`1RHV80GemO05mOG`1PH600
G5aL061PH01KFe/0GEeM05aLG01OGel0FUYJ05eMG@1KFe/0FUYJ061PH01OGel0G5aL05YJFP1LG5`0
GUiN065QH@1JFUX0EeMG05IFEP1JFUX0F5QH05iNGP1IFET0HV9R05IFEP1MGEd0FUYJ065QH@1OGel0
Fe]K00@0GemO0140HV9R065QH@1OGel0Hf=S069RHP1SHf<0HF5Q05eMG@1SHf<0GemO061PH01QHF40
HV9R06EUI@1PH600FUYJ06EUI@02065QH@80H61P00/0FUYJ06ATI01RHV80HF5Q06ATI01SHf<0HV9R
06QXJ01WIfL0JVYZ06MWI`02061PH080IVIV0P1XJ6P0401]KFd0HV9R06QXJ01QHF40KVi^06MWI`1X
J6P0Jf][06a/K01[Jf/0IFEU071`L01/K6`0IFEU06a/K01XJ6P206=SH`0@06i^KP1[Jf/0IfMW06a/
K01YJFT0IFEU06QXJ01/K6`0IVIV06m_K`1/K6`0JFUY06a/K01`L700IfMW06IVIP80JVYZ05H0J6QX
06i^KP1WIfL0J6QX06i^KP1`L700KFe]071`L01/K6`0JFUY06ATI01^KVh0Lg=c06][J`1_Kfl0KVi^
06YZJP1/K6`0LG5a07EeM@1^KVh0L71`06e]K@1cLg<0MGEe071`L01XJ6P0KFe]06QXJ01_Kfl0K6a/
06=SH`1]KFd0KVi^079bLP1XJ6P0JVYZ06i^KP1[Jf/0JFUY06a/K01^KVh0HV9R06UYJ@1bLW80JVYZ
06IVIP1YJFT0KVi^06=SH`1XJ6P0K6a/06ATI01YJFT0Jf][06a/K01]KFd0L71`06i^KP1OGel0Hf=S
06m_K`1[Jf/0JVYZ06IVIP1]KFd0JVYZ06m_K`1/K6`0JVYZ06MWI`1_Kfl0Lg=c061PH01ZJVX0IFEU
06YZJP1[Jf/0Hf=S06EUI@1/K6`0IVIV06=SH`1/K6`0JFUY06EUI@80HF5Q00/0JVYZ06IVIP1XJ6P0
Hf=S069RHP1WIfL0HF5Q06MWI`1PH600IFEU06UYJ@0206MWI`04069RHP1TI6@0G5aL065QH@80IFEU
02@0H61P06EUI@1PH600F5QH061PH01WIfL0HV9R06QXJ01SHf<0H61P05aLG01QHF40H61P06UYJ@1K
Fe/0H61P05QHF01SHf<0GEeM05UIF@1LG5`0DU9B06EUI@1QHF40GUiN05YJFP1QHF40GemO05aLG01P
H600GemO06IVIP1WIfL0GEeM065QH@1WIfL205eMG@0305iNGP1PH600H61P0080IFEU00D0GemO069R
HP1SHf<0I6AT06EUI@0206QXJ00S06UYJ@1fMWH0K6a/075aL@1cLg<0LG5a07=cL`1aLG40KFe]06][
J`1SHf<0JFUY06IVIP1QHF40HV9R06=SH`1GEeL0J6QX05]KF`1MGEd0Fe]K05iNGP1HF5P0GEeM05IF
EP1PH600I6AT05eMG@1EEED0GUiN05UIF@1LG5`0Fe]K05iNGP1OGel01P3IfMT100000040fMWI000F
0=WIf@030000003IfMT0fMWI00<0fMWI01L0HF5Q05IFEP1HF5P0G5aL05eMG@1NGUh0GEeM05YJFP1C
De<0GEeM05QHF01OGel0I6AT061PH01KFe/0HV9R05QHF01QHF40G5aL05YJFP1LG5`0FEUI05QHF002
05iNGP0E05]KF`1LG5`0G5aL05]KF`1IFET0GUiN05aLG01KFe/0GUiN061PH01QHF40G5aL05YJFP1I
FET0Fe]K05mOG`1KFe/0EUIF05iNGP1IFET0GUiN00<0HV9R00L0GUiN05eMG@1OGel0GemO061PH01X
J6P0Hf=S0080I6AT00D0GUiN06=SH`1MGEd0K6a/05mOG`03065QH@07069RHP1TI6@0HV9R061PH01U
IFD0GUiN06=SH`0206ATI00C06][J`1XJ6P0Jf][06=SH`1VIVH0IfMW06ATI01SHf<0IfMW06e]K@1T
I6@0J6QX06UYJ@1LG5`0IfMW065QH@1SHf<0J6QX06MWI`0206ATI00_06=SH`1aLG40KFe]06i^KP1V
IVH0KFe]06][J`1]KFd0JFUY06][J`1VIVH0HV9R06YZJP1[Jf/0HV9R06ATI01/K6`0IfMW06=SH`1[
Jf/0G5aL06MWI`1PH600K6a/06QXJ01^KVh0JFUY06m_K`1XJ6P0JVYZ06e]K@1VIVH0I6AT06IVIP1_
Kfl0Jf][06EUI@1PH600JVYZ06ATI01gMgL0KFe]06a/K01UIFD0KFe]06YZJP1^KVh00P1_Kfl0701`
L700JVYZ06QXJ01WIfL0J6QX06m_K`1^KVh0IVIV075aL@1/K6`0J6QX06ATI01YJFT0K6a/06YZJP1/
K6`0Jf][06UYJ@1]KFd0J6QX071`L01/K6`0IVIV06][J`1/K6`0KFe]06IVIP1[Jf/206MWI`0:06UY
J@1XJ6P0Jf][06QXJ01SHf<0Kfm_06QXJ01VIVH0K6a/06UYJ@80KFe]00/0K6a/06i^KP1ZJVX0KVi^
06e]K@1^KVh0L71`06QXJ01WIfL0GUiN06YZJP02065QH@0306MWI`1UIFD0IfMW0080I6AT0P1YJFT0
1P1VIVH0I6AT06ATI01YJFT0IFEU061PH080Hf=S00<0IfMW06=SH`1MGEd00P1SHf<0401NGUh0H61P
06IVIP1YJFT0H61P06IVIP1YJFT0Hf=S061PH01QHF40Hf=S05]KF`1JFUX0I6AT05iNGP1XJ6P205eM
G@0>05]KF`1SHf<0HF5Q06ATI01PH600GUiN05mOG`1KFe/0HV9R05eMG@1QHF40I6AT05eMG@1QHF42
06=SH`0705eMG@1SHf<0GemO06EUI@1QHF40GEeM06MWI`0206=SH`0705=CD`1JFUX0Fe]K065QH@1P
H600Fe]K05mOG`0205iNGP0A06IVIP1SHf<0I6AT06YZJP1[Jf/0I6AT07EeM@1cLg<0JVYZ075aL@1g
MgL0NWYj07MgM`1bLW80MgMg07AdM01_Kfl00P1XJ6P05`1[Jf/0I6AT05UIF@1JFUX0GemO05YJFP1U
IFD0H61P05iNGP1LG5`0FEUI05]KF`1IFET0H61P069RHP1IFET0GEeM05aLG01HF5P0Fe]K05YJFP1L
G5`0F5QH00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0C05]KF`1OGel0
I6AT05aLG01JFUX0GEeM05UIF@1MGEd0EeMG05aLG01RHV80GEeM05YJFP1OGel0G5aL05iNGP1QHF40
HV9R05YJFP0205aLG00505UIF@1MGEd0GUiN05YJFP1KFe/00P1IFET0;01MGEd0FEUI05eMG@1NGUh0
Fe]K05IFEP1EEED0GUiN05YJFP1BDU80De=C05]KF`1OGel0HV9R061PH01LG5`0HV9R05QHF01PH600
Hf=S05aLG01OGel0IfMW065QH@1TI6@0H61P06QXJ01TI6@0HF5Q05mOG`1JFUX0I6AT06=SH`1NGUh0
GEeM06=SH`1PH600JVYZ065QH@1MGEd0HV9R05eMG@1NGUh0JVYZ0P1RHV802@1YJFT0KFe]06YZJP1W
IfL0I6AT06QXJ01TI6@0IVIV06EUI@02065QH@0Q06YZJP1VIVH0J6QX06][J`1WIfL0HV9R06MWI`1]
KFd0Jf][06IVIP1YJFT0J6QX06a/K01UIFD0JVYZ06i^KP1SHf<0IfMW06IVIP1_Kfl0J6QX06a/K01X
J6P0IFEU06a/K01`L700JFUY06QXJ01[Jf/0Hf=S06a/K01YJFT0IFEU0080JVYZ00@0JFUY06MWI`1U
IFD0IFEU0P1_Kfl01@1TI6@0KVi^06QXJ01XJ6P0IfMW0080J6QX00<0K6a/06IVIP1]KFd00P1[Jf/0
6@1VIVH0IfMW06][J`1YJFT0HV9R06MWI`1aLG40Kfm_06UYJ@1/K6`0Kfm_06ATI01UIFD0KFe]06EU
I@1^KVh0JVYZ079bLP1TI6@0IVIV06][J`1_Kfl0LW9b06=SH`1XJ6P00P1YJFT0301VIVH0IFEU06UY
J@1TI6@0JFUY06m_K`1UIFD0IVIV06m_K`1WIfL0I6AT06=SH`<0JVYZ01`0I6AT06MWI`1VIVH0IVIV
06EUI@1XJ6P0JVYZ06][J`1UIFD0IfMW061PH01VIVH0L71`06QXJ01QHF40J6QX06MWI`1TI6@0IVIV
06=SH`1XJ6P0JFUY06m_K`1]KFd0I6AT06UYJ@1SHf<0JFUY0P1PH6000`1OGel0JFUY06IVIP02069R
HP0:06MWI`1SHf<0Hf=S06=SH`1WIfL0HV9R06EUI@1ZJVX0HV9R06IVIP<0I6AT00D0HF5Q06ATI01P
H600Hf=S06QXJ00205]KF`0D05UIF@1SHf<0IVIV05UIF@1NGUh0Hf=S06MWI`1QHF40FUYJ06=SH`1F
EUH0IfMW061PH01LG5`0IFEU05iNGP1IFET0G5aL05YJFP1LG5`205mOG`0i06IVIP1LG5`0HV9R06IV
IP1OGel0I6AT05UIF@1QHF40GEeM05iNGP1LG5`0FUYJ05aLG01OGel0HF5Q05iNGP1UIFD0HV9R061P
H01YJFT0KFe]06YZJP1[Jf/0K6a/075aL@1gMgL0NGUi07EeM@1gMgL0N7Qh07]kN`1gMgL0KFe]06][
J`1_Kfl0GemO065QH@1ZJVX0HF5Q069RHP1TI6@0GEeM05mOG`1SHf<0GemO061PH01KFe/0Hf=S05]K
F`1JFUX0G5aL05eMG@1LG5`0GEeM05=CD`1KFe/0DE5A00H0fMWI0@0000010=WIf@005P3IfMT20000
00@0fMWI01L0I6AT069RHP1NGUh0Fe]K065QH@1OGel0EeMG05ADE01KFe/0GEeM05]KF`1VIVH0I6AT
05MGE`1OGel0GUiN05aLG01GEeL0F5QH05aLG01OGel0EeMG05]KF`0205mOG`0@05UIF@1KFe/0GEeM
05mOG`1KFe/0GemO05YJFP1LG5`0H61P06EUI@1KFe/0GUiN05eMG@1IFET0GemO069RHP80GEeM00d0
HV9R05MGE`1MGEd0GemO05eMG@1IFET0H61P05aLG01KFe/0H61P06=SH`1LG5`0HF5Q0080H61P0P1O
Gel0501KFe/0IVIV06ATI01SHf<0HF5Q061PH01YJFT0GEeM06ATI01RHV80I6AT069RHP1TI6@0H61P
06MWI`1VIVH0H61P06UYJ@1PH600IVIV0P1]KFd0>`1QHF40IVIV06ATI01[Jf/0I6AT069RHP1YJFT0
HV9R06QXJ01YJFT0Jf][069RHP1QHF40IFEU061PH01YJFT0J6QX06][J`1cLg<0IFEU06YZJP1/K6`0
J6QX06EUI@1RHV80KVi^06EUI@1VIVH0JFUY071`L01dM7@0HV9R06a/K01aLG40K6a/06QXJ01^KVh0
HV9R06m_K`1ZJVX0Jf][06e]K@1VIVH0KFe]06][J`1WIfL0Jf][06YZJP1TI6@0Kfm_06][J`1VIVH0
I6AT06IVIP1cLg<0JVYZ06IVIP1XJ6P0Jf][0080IfMW00`0IVIV06a/K01cLg<0L71`06a/K01eMGD0
IfMW06e]K@1/K6`0J6QX06i^KP1UIFD206UYJ@0O06a/K01ZJVX0H61P06e]K@1UIFD0KVi^06YZJP1X
J6P0I6AT06UYJ@1_Kfl0K6a/06MWI`1]KFd0IFEU061PH01XJ6P0I6AT06UYJ@1TI6@0IFEU06UYJ@1/
K6`0J6QX06a/K01`L700KVi^06MWI`1YJFT0Hf=S06a/K00306MWI`0W06][J`1UIFD0HF5Q06a/K01Z
JVX0KFe]06IVIP1RHV80Hf=S06QXJ01UIFD0IfMW06=SH`1WIfL0J6QX069RHP1UIFD0HV9R06a/K01P
H600J6QX05mOG`1QHF40HV9R05mOG`1VIVH0I6AT05aLG01NGUh0HF5Q06EUI@1KFe/0GEeM06ATI01Q
HF40G5aL06IVIP1^KVh0H61P0080GemO0P1QHF405@1KFe/0GemO06ATI01UIFD0I6AT06MWI`1RHV80
H61P06EUI@1TI6@0GemO05]KF`1MGEd0G5aL06EUI@1QHF40GUiN06ATI01IFET0GUiN06=SH`0205mO
G`0;06IVIP1RHV80FUYJ061PH01NGUh0FUYJ05IFEP1NGUh0GemO065QH@1NGUh00P1PH600801UIFD0
HV9R05eMG@1TI6@0IFEU06IVIP1WIfL0Jf][06a/K01]KFd0MWIf07EeM@1hN7P0PX:207QhN021PH40
OWin08J6QP1oOgl0N7Qh071`L01ZJVX0K6a/06IVIP1OGel0JFUY05mOG`1NGUh0IFEU05UIF@1JFUX0
GemO0P1HF5P02P1LG5`0FEUI05]KF`1NGUh0G5aL04m?C`1RHV80H61P05mOG`1LG5`50=WIf@800000
0@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT07@1LG5`0Fe]K065QH@1VIVH0EEEE05mOG`1K
Fe/0HV9R05aLG01PH600EUIF05MGE`1RHV80FEUI061PH01SHf<0FEUI05iNGP1IFET0Fe]K061PH01O
Gel0Fe]K05iNGP1MGEd0FEUI05YJFP1OGel0F5QH0080FUYJ02D0G5aL06IVIP1QHF40GemO05aLG01Q
HF40EUIF05aLG01NGUh0G5aL05mOG`1NGUh0H61P05aLG01JFUX0HF5Q069RHP1SHf<0GEeM06IVIP1F
EUH0HF5Q05aLG01KFe/0GUiN06EUI@1SHf<0GemO05aLG01RHV80H61P069RHP1`L700I6AT06IVIP1S
Hf<0JFUY0080HF5Q00X0Hf=S06ATI01VIVH0GUiN05eMG@1QHF40IFEU069RHP1XJ6P0Kfm_0P1OGel0
4`1SHf<0J6QX065QH@1SHf<0IfMW06IVIP1YJFT0K6a/06UYJ@1TI6@0HV9R06QXJ01]KFd0IfMW061P
H01XJ6P0JFUY06a/K01WIfL00P1]KFd0101YJFT0IfMW06UYJ@1XJ6P406ATI00606UYJ@1/K6`0Hf=S
06QXJ01TI6@0IVIV0P1^KVh0:01YJFT0I6AT06i^KP1[Jf/0KFe]075aL@1XJ6P0IFEU065QH@1`L700
Jf][06YZJP1[Jf/0JVYZ06IVIP1/K6`0IFEU06YZJP1WIfL0KVi^06EUI@1_Kfl0J6QX06EUI@1[Jf/0
LG5a06EUI@1XJ6P0KFe]06IVIP1/K6`0IFEU06QXJ01ZJVX0Jf][06i^KP1UIFD0LW9b06QXJ01YJFT2
06a/K008079bLP1_Kfl0Ng]k075aL@1WIfL0K6a/06m_K`1`L70206QXJ00E06MWI`1TI6@0JFUY06MW
I`1VIVH0IfMW06EUI@1WIfL0GEeM06i^KP1VIVH0I6AT06e]K@1QHF40IVIV069RHP1]KFd0IFEU06][
J`1VIVH0KFe]0080J6QX00`0Hf=S06e]K@1RHV80GEeM06=SH`1VIVH0Jf][06IVIP1ZJVX0Jf][06EU
I@1WIfL206IVIP80IFEU00<0IfMW05mOG`1QHF400P1QHF42069RHP1C061PH01QHF40HV9R069RHP1V
IVH0Hf=S06][J`1SHf<0IfMW06EUI@1MGEd0JFUY06=SH`1VIVH0HV9R06MWI`1TI6@0IVIV05iNGP1R
HV80IFEU069RHP1NGUh0GemO05iNGP1LG5`0GUiN05aLG01NGUh0GemO065QH@1JFUX0H61P05iNGP1L
G5`0GEeM05YJFP1QHF40GemO06=SH`1PH600IVIV069RHP1WIfL0I6AT05eMG@1KFe/0GUiN05eMG@1N
GUh0HV9R05YJFP1OGel0G5aL06IVIP1JFUX0EUIF05eMG@1SHf<0IfMW06=SH`1XJ6P0KFe]06a/K01`
L700NWYj08R8R02<S8`0TI6A09RHV02LW9`0V9RH08f=S@20P800MGEe07AdM01]KFd0KVi^06ATI01R
HV80J6QX05aLG01QHF400P1RHV800`1TI6@0FEUI05aLG00206=SH`0705]KF`1CDe<0F5QH05YJFP1M
GEd0FEUI05YJFP060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT01P1GEeL0
F5QH05iNGP1MGEd0GemO05YJFP80H61P01D0FUYJ05eMG@1NGUh0FUYJ065QH@1KFe/0GEeM05mOG`1K
Fe/0GemO061PH01OGel0EUIF05YJFP1QHF40GemO069RHP1MGEd0FUYJ05IFEP1HF5P00P1NGUh205mO
G`0505MGE`1JFUX0IFEU05mOG`1MGEd00P1NGUh02`1WIfL0I6AT05eMG@1NGUh0GemO05eMG@1KFe/0
GemO05eMG@1QHF40I6AT0080HF5Q00P0G5aL05eMG@1QHF40HF5Q06=SH`1KFe/0GUiN065QH@80IfMW
01<0IVIV05]KF`1PH600H61P05mOG`1SHf<0IVIV065QH@1SHf<0GemO069RHP1QHF40IFEU061PH01R
HV80J6QX06MWI`1[Jf/0IVIV0080J6QX00l0Hf=S06EUI@1TI6@0I6AT06=SH`1RHV80IVIV06YZJP1T
I6@0IVIV071`L01bLW80I6AT06YZJP1_Kfl00P1[Jf/0101WIfL0IFEU06MWI`1UIFD206YZJP0U071`
L01YJFT0IfMW06UYJ@1XJ6P0Jf][06MWI`1/K6`0KVi^06QXJ01WIfL0J6QX06EUI@1[Jf/0GUiN06QX
J01UIFD0Hf=S06ATI01_Kfl0I6AT06IVIP1SHf<0J6QX07QhN01YJFT0KVi^06=SH`1XJ6P0I6AT06][
J`1_Kfl0I6AT06UYJ@1]KFd0K6a/06e]K@0206EUI@0906QXJ01bLW80Kfm_06e]K@1VIVH0IfMW06][
J`1WIfL0HF5Q0080K6a/00@0IVIV06EUI@1YJFT0L71`0P1_Kfl02@1/K6`0I6AT06][J`1VIVH0Jf][
06ATI01YJFT0IVIV065QH@0206UYJ@0@06EUI@1XJ6P0IVIV069RHP1]KFd0Jf][069RHP1/K6`0IVIV
06UYJ@1RHV80I6AT065QH@1WIfL0K6a/06e]K@80J6QX00<0Hf=S06QXJ01QHF400P1TI6@0201NGUh0
IVIV06EUI@1SHf<0IFEU061PH01SHf<0H61P0P1QHF400`1JFUX0HV9R06YZJP0206ATI00:069RHP1T
I6@0IVIV065QH@1PH600IVIV06=SH`1QHF40IVIV06QXJ080H61P00P0J6QX069RHP1SHf<0GEeM05aL
G01RHV80GemO05eMG@80Hf=S00X0GEeM06EUI@1SHf<0Fe]K061PH01LG5`0HF5Q06=SH`1PH600FEUI
0P1KFe/02@1JFUX0Hf=S05iNGP1MGEd0G5aL069RHP1IFET0HV9R05iNGP0206=SH`0;06QXJ01TI6@0
Hf=S05mOG`1IFET0HV9R05YJFP1QHF40EUIF061PH01OGel00P1JFUX01P1NGUh0IVIV06ATI01TI6@0
GemO06MWI`80IVIV00D0L71`06MWI`1^KVh0M7Ad07QhN00208^;R`0@09NGU`2/[:`0ZZZZ0:NWY`2M
WId0U9BD07emO@1iNGT0JVYZ06IVIP1YJFT0I6AT069RHP1LG5`0GEeM05QHF080I6AT00/0FEUI05iN
GP1PH600GemO061PH01JFUX0FEUI05MGE`1MGEd0EeMG05mOG`060=WIf@4000000@3IfMT001H0fMWI
00<000000=WIf@3IfMT00`3IfMT07@1MGEd0G5aL05QHF01NGUh0FEUI059BDP1PH600HV9R05]KF`1I
FET0FUYJ05mOG`1NGUh0EeMG06=SH`1NGUh0FEUI05eMG@1RHV80GEeM05aLG01SHf<0IfMW05UIF@1M
GEd0G5aL05]KF`1EEED0H61P0080G5aL00d0GEeM05iNGP1LG5`0H61P05YJFP1QHF40Fe]K06=SH`1N
GUh0HV9R05eMG@1NGUh0HV9R0080GUiN00P0HV9R06EUI@1RHV80IfMW05iNGP1XJ6P0Fe]K061PH080
FUYJ00T0HV9R05mOG`1RHV80I6AT06=SH`1UIFD0Fe]K06QXJ01ZJVX00P1YJFT06@1TI6@0FUYJ06a/
K01TI6@0Jf][06ATI01[Jf/0J6QX05mOG`1PH600HV9R06IVIP1RHV80IFEU06MWI`1ZJVX0Fe]K06AT
I01NGUh0H61P069RHP1[Jf/0Hf=S06MWI`1TI6@00P1ZJVX03`1RHV80H61P06ATI01XJ6P0I6AT06=S
H`1TI6@0IfMW069RHP1WIfL0HV9R06ATI01UIFD0HF5Q06i^KP0206EUI@0606ATI01ZJVX0K6a/061P
H01XJ6P0JVYZ0P1/K6`0101YJFT0KVi^06ATI01PH60306a/K00906MWI`1UIFD0Jf][06=SH`1XJ6P0
Hf=S06YZJP1[Jf/0L71`0080Jf][02<0J6QX06YZJP1WIfL0J6QX065QH@1ZJVX0KFe]06a/K01[Jf/0
KVi^06YZJP1^KVh0Kfm_07=cL`1_Kfl0Hf=S06YZJP1WIfL0JVYZ06m_K`1]KFd0Jf][061PH01WIfL0
K6a/06i^KP1aLG40Jf][06MWI`1ZJVX0IVIV06YZJP1]KFd0IfMW06IVIP0206MWI`0906QXJ01TI6@0
J6QX06=SH`1OGel0IFEU06e]K@1SHf<0JVYZ0080Jf][00H0KFe]06IVIP1SHf<0JVYZ06MWI`1LG5`3
06EUI@80Hf=S00d0IFEU065QH@1SHf<0IfMW069RHP1XJ6P0GEeM06IVIP1TI6@0HV9R06IVIP1RHV80
IFEU0080I6AT02P0Fe]K065QH@1VIVH0JFUY05mOG`1SHf<0G5aL065QH@1PH600JVYZ06=SH`1KFe/0
GemO06IVIP1ZJVX0GemO061PH01WIfL0F5QH061PH01OGel0HF5Q05]KF`1QHF40GemO065QH@1KFe/0
G5aL061PH01QHF40GemO065QH@1OGel0FUYJ05QHF01MGEd0FUYJ05iNGP1QHF40Hf=S0P1NGUh02`1M
GEd0Fe]K065QH@1KFe/0GemO065QH@1NGUh0Fe]K05eMG@1PH600EeMG00<0GUiN00/0G5aL05YJFP1N
GUh0Hf=S06IVIP1PH600HV9R06ATI01OGel0HV9R06IVIP0206ATI00D06i^KP1YJFT0NGUi07moO`2=
SHd0Zj^[0<_;b`3UiND0gmoO0<;2`P2c/k<0RXZ:07inOP1eMGD0Jf][06ATI01SHf<0GUiN06IVIP1M
GEd205mOG`80GEeM00X0Fe]K065QH@1PH600GUiN06=SH`1PH600HF5Q05IFEP1LG5`0E5AD1P3IfMT1
00000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0280FEUI05eMG@1NGUh0EeMG05mOG`1I
FET0GEeM061PH01KFe/0FUYJ06=SH`1JFUX0H61P05MGE`1?Cdl0GUiN05eMG@1VIVH0GEeM05]KF`1P
H600F5QH05iNGP1HF5P0GemO05aLG01QHF40FEUI05YJFP1KFe/0G5aL05eMG@1GEeL0Fe]K0P1OGel0
8@1RHV80H61P069RHP1GEeL0F5QH05mOG`1NGUh0HF5Q06ATI01IFET0H61P05aLG01VIVH0HV9R05mO
G`1SHf<0H61P05MGE`1TI6@0Hf=S05iNGP1UIFD0GEeM05aLG01VIVH0I6AT05iNGP1QHF40HV9R06UY
J@1WIfL0H61P065QH@0206IVIP0@05eMG@1VIVH0GemO065QH@1PH600GUiN06=SH`1QHF40IFEU06UY
J@1RHV80GemO06EUI@1WIfL0HV9R05iNGP80I6AT00<0IFEU05mOG`1UIFD00P1PH60206MWI`09065Q
H@1UIFD0IVIV06=SH`1TI6@0HF5Q06YZJP1UIFD0Hf=S0080J6QX00@0K6a/06MWI`1XJ6P0JVYZ0P1/
K6`03`1]KFd0IfMW06ATI01XJ6P0IfMW075aL@1WIfL0L71`06MWI`1VIVH0JVYZ06IVIP1[Jf/0IVIV
06QXJ00206UYJ@0`06a/K01UIFD0M7Ad06][J`1TI6@0K6a/06i^KP1YJFT0JVYZ06IVIP1_Kfl0LW9b
07=cL`1RHV80JVYZ06IVIP1ZJVX0J6QX06IVIP1/K6`0Lg=c06YZJP1XJ6P0KVi^06QXJ01VIVH0IfMW
06a/K01[Jf/0IFEU06i^KP1ZJVX0Kfm_06UYJ@1/K6`0JFUY06EUI@1VIVH0KFe]06ATI01ZJVX0IfMW
06EUI@1ZJVX0IVIV06EUI@1WIfL0JVYZ0P1WIfL00`1TI6@0IVIV06QXJ00206MWI`0B06EUI@1/K6`0
I6AT065QH@1PH600JFUY05mOG`1SHf<0IfMW06IVIP1XJ6P0IFEU06IVIP1ZJVX0Fe]K061PH01NGUh0
I6AT0P1QHF406P1VIVH0I6AT06UYJ@1XJ6P0IFEU06MWI`1SHf<0HV9R05eMG@1KFe/0HF5Q061PH01W
IfL0H61P05mOG`1UIFD0J6QX06IVIP1NGUh0G5aL05YJFP1UIFD0HV9R06EUI@1NGUh0IFEU0P1NGUh0
0`1MGEd0H61P06IVIP0205aLG080GemO0P1LG5`01P1MGEd0Fe]K05mOG`1QHF40IFEU05aLG080HF5Q
00D0FUYJ061PH01QHF40Fe]K05mOG`02061PH00805UIF@1NGUh0GEeM069RHP1PH600HF5Q05ADE01N
GUh205QHF00D05aLG01OGel0G5aL06QXJ01HF5P0EUIF05MGE`1TI6@0IVIV05]KF`1LG5`0I6AT06m_
K`1[Jf/0K6a/07=cL`27QhL0UIFE0;no_`3moOd20?ooo`0=0>o_k`3Bd]80TY:B08F5Q@1kNg/0JFUY
06][J`1WIfL0H61P05YJFP1RHV80Hf=S05aLG00205mOG`0:05aLG01GEeL0I6AT05UIF@1QHF40HV9R
05]KF`1JFUX0E5AD05iNGPH0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0E
05mOG`1HF5P0EUIF05aLG01OGel0FUYJ05UIF@1QHF40F5QH05eMG@1JFUX0HV9R05eMG@1PH600GemO
05]KF`1PH600FUYJ05]KF`1JFUX0FEUI0080G5aL00T0DE5A05iNGP1RHV80EUIF05iNGP1OGel0FUYJ
05MGE`1OGel00P1IFET04`1EEED0GUiN069RHP1JFUX0GEeM05]KF`1PH600Hf=S05MGE`1KFe/0H61P
069RHP1UIFD0GEeM061PH01UIFD0FUYJ05iNGP1GEeL00P1SHf<04`1NGUh0H61P069RHP1QHF40I6AT
05YJFP1NGUh0J6QX06IVIP1ZJVX0H61P05mOG`1RHV80JVYZ065QH@1RHV80HF5Q06=SH`1NGUh00P1U
IFD05`1OGel0Fe]K05YJFP1WIfL0JFUY06MWI`1NGUh0IFEU06UYJ@1WIfL0IFEU06=SH`1WIfL0GEeM
05]KF`1QHF40HV9R06EUI@1SHf<0I6AT06YZJP1WIfL0HV9R0080J6QX0280IVIV06][J`1YJFT0IFEU
06ATI01OGel0GUiN06=SH`1XJ6P0IfMW06EUI@1VIVH0IfMW06UYJ@1VIVH0KFe]06QXJ01PH600J6QX
069RHP1SHf<0JFUY07=cL`1ZJVX0K6a/071`L01YJFT0Jf][06m_K`1/K6`0JVYZ06UYJ@1WIfL0IFEU
0P1ZJVX03@1/K6`0KFe]06a/K01aLG40Jf][06YZJP1YJFT0IfMW079bLP1YJFT0K6a/06YZJP1/K6`0
0P1YJFT02P1WIfL0GUiN06MWI`1VIVH0Hf=S06QXJ01YJFT0K6a/06YZJP1WIfL206EUI@0G069RHP1S
Hf<0JVYZ06UYJ@1XJ6P0Hf=S06ATI01YJFT0KFe]06QXJ01_Kfl0JFUY06e]K@1ZJVX0L71`06a/K01W
IfL0Hf=S065QH@1YJFT0J6QX06MWI`1XJ6P00P1QHF40201OGel0IVIV06QXJ01UIFD0H61P05eMG@1V
IVH0Jf][0P1UIFD0101XJ6P0HV9R05eMG@1WIfL306ATI00d06QXJ01WIfL0IVIV05mOG`1PH600IfMW
069RHP1PH600IFEU06MWI`1NGUh0G5aL05iNGP1LG5`0Hf=S05QHF01SHf<0GUiN061PH01OGel0GUiN
06EUI@1KFe/0JFUY05eMG@1UIFD0I6AT06=SH`1VIVH0GUiN06=SH`1KFe/0GEeM069RHP1MGEd0Hf=S
061PH01JFUX0G5aL05eMG@1NGUh0H61P05eMG@1KFe/0GUiN06ATI01HF5P0FEUI061PH01OGel0F5QH
05YJFP80GemO0100GUiN05YJFP1HF5P0GemO05YJFP1MGEd0HF5Q05aLG01MGEd0EeMG069RHP1NGUh0
HV9R05]KF`1NGUh0H61P0P1UIFD00`1VIVH0J6QX06e]K@0207AdM00308^;R`2HV9P0_;bl00<0oooo
00L0lo?c0>;RhP2OWil0Ti>C07IfMP1[Jf/0LG5a0080Jf][0100FUYJ05mOG`1GEeL0H61P05mOG`1L
G5`0GemO06ATI01OGel0EUIF069RHP1LG5`0EeMG05ADE01NGUh0G5aL1P3IfMT100000040fMWI000F
0=WIf@030000003IfMT0fMWI00<0fMWI0140GemO05iNGP1HF5P0GUiN05YJFP1IFET0Fe]K05UIF@1T
I6@0Fe]K05mOG`1HF5P0Fe]K05aLG01TI6@0GEeM065QH@0205]KF`0?05YJFP1HF5P0GEeM05EEE@1K
Fe/0G5aL061PH01NGUh0G5aL069RHP1GEeL0FUYJ05eMG@1GEeL0GEeM0080FUYJ00P0GUiN061PH01L
G5`0GEeM05aLG01SHf<0F5QH065QH@80G5aL00T0IfMW061PH01MGEd0I6AT05eMG@1PH600Fe]K061P
H01QHF400P1SHf<0101GEeL0Hf=S05aLG01LG5`205iNGP0<06IVIP1OGel0HV9R06EUI@1KFe/0I6AT
06=SH`1NGUh0GemO05]KF`1QHF40Fe]K0P1OGel01`1NGUh0IVIV05]KF`1NGUh0GEeM05mOG`1MGEd0
0P1OGel02`1TI6@0IFEU065QH@1RHV80HF5Q06ATI01SHf<0Fe]K05aLG01QHF40GemO0080IfMW00/0
JVYZ06][J`1PH600Hf=S06QXJ01_Kfl0GEeM06EUI@1XJ6P0Hf=S065QH@0206IVIP0c06MWI`1TI6@0
IfMW06QXJ01/K6`0IfMW06e]K@1VIVH0IfMW06][J`1YJFT0H61P06=SH`1XJ6P0IVIV06QXJ01[Jf/0
IfMW06UYJ@1/K6`0HF5Q06MWI`1ZJVX0J6QX06UYJ@1QHF40JVYZ06UYJ@1[Jf/0K6a/06=SH`1PH600
I6AT06UYJ@1ZJVX0KFe]06][J`1WIfL0Jf][06EUI@1XJ6P0HV9R06QXJ01_Kfl0HF5Q06][J`1XJ6P0
I6AT06QXJ01SHf<0IVIV0080Hf=S01T0J6QX06=SH`1XJ6P0J6QX06IVIP1UIFD0Hf=S06IVIP1QHF40
Jf][06EUI@1]KFd0IfMW06UYJ@1UIFD0IfMW06QXJ01YJFT0J6QX06IVIP1UIFD0K6a/061PH01SHf<0
JFUY0080J6QX00P0I6AT06UYJ@1YJFT0H61P05aLG01XJ6P0GUiN065QH@80IFEU00l0IVIV05eMG@1X
J6P0HV9R05mOG`1UIFD0GemO061PH01KFe/0I6AT06=SH`1MGEd0GemO06MWI`1OGel00P1NGUh02`1L
G5`0HV9R06EUI@1MGEd0Fe]K05QHF01UIFD0H61P06QXJ01VIVH0IfMW0080IVIV03H0GUiN06=SH`1L
G5`0Hf=S06ATI01RHV80GEeM06EUI@1NGUh0Hf=S05mOG`1PH600GemO05QHF01LG5`0Fe]K05eMG@1J
FUX0Fe]K065QH@1JFUX0H61P05mOG`1LG5`0GemO05EEE@1MGEd0Fe]K05YJFP1KFe/0GUiN05EEE@1J
FUX0GemO05iNGP1KFe/0FUYJ051@D01LG5`0GEeM05aLG01QHF40I6AT05iNGP1PH600GEeM06MWI`1T
I6@0K6a/07AdM01bLW80P82008j>SP39bLT30?ooo`0:0>[ZjP37alL0UYJF09BDU01kNg/0MgMg06YZ
JP1VIVH0IFEU061PH080GUiN00@0GemO06=SH`1NGUh0G5aL0P1GEeL01`1HF5P0G5aL05QHF01PH600
Fe]K05QHF01KFe/01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00T0GemO
05aLG01JFUX0Fe]K05aLG01PH600HV9R061PH01NGUh00P1GEeL02P1OGel0Fe]K05YJFP1OGel0Fe]K
05MGE`1MGEd0I6AT05]KF`1PH60205eMG@<0F5QH00H0Fe]K05eMG@1HF5P0H61P05ADE01EEED205eM
G@0305aLG01NGUh0F5QH0080Fe]K00@0H61P05mOG`1MGEd0GEeM0P1NGUh09`1SHf<0G5aL05iNGP1M
GEd0G5aL05UIF@1RHV80GemO05eMG@1PH600GUiN05YJFP1IFET0Fe]K069RHP1KFe/0HV9R05iNGP1S
Hf<0GemO069RHP1OGel0JVYZ06ATI01QHF40HV9R05mOG`1UIFD0GUiN05aLG01JFUX0HV9R06IVIP1Q
HF40J6QX061PH01UIFD0IfMW05mOG`02065QH@0806][J`1PH600J6QX061PH01NGUh0IfMW06IVIP1N
GUh206IVIP0906ATI01PH600HV9R06MWI`1TI6@0IFEU06ATI01PH600I6AT0080IFEU01h0IfMW065Q
H@1TI6@0HF5Q06MWI`1MGEd0JFUY06YZJP1YJFT0Hf=S06][J`1UIFD0JFUY06QXJ01VIVH0I6AT06i^
KP1WIfL0Kfm_071`L01XJ6P0GUiN06YZJP1VIVH0L71`06YZJP1]KFd0IfMW06ATI01XJ6P206EUI@0=
075aL@1PH600J6QX06i^KP1/K6`0Jf][06EUI@1VIVH0KFe]069RHP1XJ6P0JFUY071`L00206EUI@03
06MWI`1XJ6P0J6QX0080IfMW01T0K6a/065QH@1WIfL0IVIV06EUI@1SHf<0KFe]06MWI`1XJ6P0HF5Q
06UYJ@1WIfL0J6QX06EUI@1TI6@0H61P06IVIP1[Jf/0JFUY06IVIP1LG5`0Kfm_06EUI@1OGel0JVYZ
0080IFEU00<0Hf=S06YZJP1ZJVX00P1YJFT206MWI`0:06=SH`1QHF40IFEU069RHP1VIVH0GEeM069R
HP1UIFD0I6AT06IVIP80J6QX0P1QHF401P1UIFD0HF5Q06ATI01RHV80IFEU06IVIP80I6AT00h0GUiN
061PH01OGel0GUiN05MGE`1LG5`0Fe]K05aLG01QHF40I6AT061PH01QHF40H61P06i^KP80JFUY00d0
IFEU06ATI01KFe/0HV9R061PH01NGUh0G5aL05iNGP1SHf<0F5QH05aLG01SHf<0GEeM0080Fe]K0140
F5QH061PH01EEED0HV9R05]KF`1SHf<0EeMG05eMG@1OGel0F5QH05mOG`1JFUX0F5QH05eMG@1VIVH0
GEeM05]KF`0205YJFP0905MGE`1MGEd0GEeM06ATI01VIVH0IFEU05QHF01TI6@0HF5Q0080GemO00/0
HV9R06EUI@1ZJVX0KFe]06MWI`1]KFd0MGEe0861P@2<S8`0^KVi0?7al@020?ooo`0I0=WIf@2m_Kd0
VIVI08^;R`1lO7`0LW9b075aL@1_Kfl0IfMW065QH@1TI6@0GEeM061PH01KFe/0I6AT06QXJ01PH600
GemO061PH01GEeL0F5QH05MGE`1HF5P0FUYJ065QH@060=WIf@4000000@3IfMT001H0fMWI00<00000
0=WIf@3IfMT00`3IfMT03`1KFe/0GUiN05eMG@1RHV80GEeM061PH01LG5`0GemO05QHF01KFe/0G5aL
069RHP1NGUh0Hf=S05mOG`0205aLG00>061PH01SHf<0Fe]K065QH@1MGEd0GemO05QHF01JFUX0H61P
05mOG`1HF5P0FEUI05eMG@1JFUX205]KF`0b05eMG@1OGel0Fe]K05eMG@1HF5P0FUYJ05aLG01PH600
HV9R061PH01QHF40G5aL05]KF`1NGUh0G5aL069RHP1LG5`0GemO069RHP1OGel0FUYJ065QH@1OGel0
Fe]K05UIF@1HF5P0Hf=S05mOG`1SHf<0Fe]K065QH@1[Jf/0GUiN06YZJP1[Jf/0K6a/05mOG`1RHV80
Hf=S06MWI`1PH600FUYJ065QH@1KFe/0G5aL06=SH`1NGUh0EeMG05iNGP1QHF4206=SH`80IFEU01<0
JVYZ061PH01TI6@0GemO05eMG@1OGel0I6AT061PH01NGUh0I6AT05mOG`1KFe/0GemO069RHP1ZJVX0
Jf][06e]K@1ZJVX0HV9R0080IfMW0P1YJFT206MWI`0[06IVIP1^KVh0JVYZ06YZJP1TI6@0IFEU06QX
J01WIfL0Hf=S06MWI`1VIVH0J6QX06e]K@1UIFD0HV9R06QXJ01WIfL0HV9R06MWI`1RHV80IVIV06QX
J01]KFd0Jf][06IVIP1UIFD0JFUY06e]K@1YJFT0JVYZ06UYJ@1QHF40J6QX06m_K`1SHf<0JVYZ06EU
I@1VIVH0JFUY06QXJ01YJFT0JVYZ06a/K002061PH00;06YZJP1YJFT0KVi^069RHP1TI6@0LG5a06IV
IP1ZJVX0J6QX06][J`1TI6@00P1YJFT0201ZJVX0IfMW06YZJP1_Kfl0IVIV06MWI`1UIFD0HF5Q0P1T
I6@01P1SHf<0I6AT06EUI@1PH600IfMW06QXJ080HF5Q01l0Hf=S06QXJ01UIFD0HF5Q06=SH`1QHF40
IFEU06UYJ@1VIVH0GemO06EUI@1TI6@0HF5Q06=SH`1UIFD0HF5Q06MWI`1YJFT0GemO06ATI01QHF40
IVIV06=SH`1RHV80IfMW05mOG`1SHf<0J6QX065QH@1SHf<0G5aL0080HF5Q0P1PH600=P1QHF40IVIV
06ATI01UIFD0IVIV065QH@1TI6@0IFEU069RHP1PH600Fe]K05iNGP1MGEd0FEUI06IVIP1KFe/0HF5Q
05YJFP1SHf<0F5QH05iNGP1TI6@0GEeM05iNGP1LG5`0Fe]K05aLG01HF5P0HF5Q06=SH`1KFe/0GemO
05]KF`1HF5P0IFEU065QH@1DE5@0FEUI06=SH`1NGUh0FEUI05mOG`1JFUX0GemO05aLG01RHV80FUYJ
05aLG01EEED0GUiN05YJFP1IFET0GemO05ADE080Hf=S00`0HV9R05mOG`1VIVH0KVi^07alO01jNWX0
WYjN0;^k^`3@d=00bl_;0;Fe]@2][Jd209>CT`0307alO01hN7P0JFUY0080IFEU0100J6QX05mOG`1R
HV80HF5Q05iNGP1JFUX0Hf=S05mOG`1KFe/0GemO065QH@1JFUX0F5QH065QH@1ADE40EUIF1P3IfMT1
00000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00@0FUYJ05eMG@1KFe/0Fe]K0`1LG5`0
1@1JFUX0I6AT05iNGP1KFe/0F5QH0080GUiN0P1HF5P01@1NGUh0Fe]K05iNGP1KFe/0GEeM0080HF5Q
101IFET01`1RHV80HF5Q05iNGP1JFUX0G5aL06EUI@1GEeL00P1HF5P07P1NGUh0H61P061PH01KFe/0
EeMG05QHF01PH600HF5Q05aLG01MGEd0HV9R06=SH`1OGel0Fe]K061PH01QHF40I6AT05mOG`1PH600
IFEU06=SH`1OGel0Fe]K05mOG`1SHf<0GUiN05YJFP1UIFD0F5QH06QXJ080IVIV00<0JVYZ06][J`1N
GUh00P1PH6007P1RHV80JVYZ05iNGP1RHV80HF5Q06=SH`1UIFD0H61P06ATI01MGEd0GUiN069RHP1P
H600GUiN06=SH`1QHF40Jf][06IVIP1KFe/0I6AT06=SH`1UIFD0JFUY05eMG@1[Jf/0GUiN065QH@1O
Gel0HV9R05iNGP80I6AT00/0JFUY065QH@1UIFD0Hf=S069RHP1YJFT0IVIV06MWI`1NGUh0Jf][065Q
H@0206][J`0606MWI`1ZJVX0K6a/061PH01QHF40K6a/0P1TI6@04P1[Jf/0KFe]069RHP1/K6`0J6QX
069RHP1UIFD0IVIV06QXJ01WIfL0Hf=S06][J`1UIFD0Jf][065QH@1VIVH0HV9R065QH@80JFUY0180
IVIV06EUI@1YJFT0IFEU065QH@1[Jf/0K6a/06MWI`1UIFD0HV9R06QXJ01[Jf/0I6AT069RHP1XJ6P0
GemO06MWI`1RHV8206IVIP0706EUI@1[Jf/0JVYZ06YZJP1UIFD0J6QX06][J`0206QXJ00U05eMG@1P
H600JFUY06IVIP1QHF40Jf][06EUI@1XJ6P0IVIV061PH01ZJVX0I6AT05eMG@1PH600GUiN06MWI`1Q
HF40JFUY05eMG@1OGel0Hf=S06YZJP1UIFD0J6QX06IVIP1[Jf/0H61P06ATI01UIFD0Hf=S06][J`1S
Hf<0HF5Q069RHP1[Jf/0HV9R05iNGP0206=SH`0F06IVIP1PH600Hf=S06=SH`1MGEd0FUYJ069RHP1M
GEd0Fe]K061PH01JFUX0G5aL05iNGP1QHF40H61P06UYJ@1TI6@0HF5Q06=SH`1OGel0GUiN06EUI@80
HF5Q01@0GEeM05iNGP1HF5P0G5aL06IVIP1IFET0H61P06ATI01PH600Fe]K05aLG01GEeL0GemO05YJ
FP1EEED0I6AT05aLG01SHf<0Fe]K05mOG`80FUYJ00<0F5QH05YJFP1IFET00P1MGEd0:P1HF5P0GEeM
05eMG@1NGUh0FUYJ05iNGP1FEUH0G5aL055AD@1LG5`0GemO06ATI01VIVH0I6AT06IVIP1NGUh0IVIV
06a/K01bLW80MWIf08R8R02CTi<0UIFE09ZJVP2HV9P0Ti>C08b<S02:RXX0O7al075aL@1bLW80L71`
06=SH`1UIFD0Hf=S069RHP1TI6@0IFEU05mOG`1EEED0G5aL05EEE@80GUiN00D0FEUI05MGE`1HF5P0
EEEE05QHF0060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT03@1GEeL0Fe]K
061PH01MGEd0G5aL061PH01GEeL0G5aL06=SH`1OGel0Fe]K05mOG`1NGUh00P1PH600301GEeL0GemO
05UIF@1KFe/0EEEE05iNGP1OGel0GEeM05UIF@1FEUH0FEUI065QH@80G5aL00@0GemO05=CD`1HF5P0
FUYJ0P1HF5P0101PH600EeMG055AD@1MGEd205iNGP0?05QHF01QHF40GemO05mOG`1LG5`0HF5Q05mO
G`1LG5`0E5AD061PH01QHF40F5QH05iNGP1OGel0GUiN0080GEeM02<0FUYJ069RHP1PH600FEUI06=S
H`1QHF40JFUY06a/K01`L700Kfm_06UYJ@1SHf<0H61P06=SH`1TI6@0GemO069RHP1QHF40G5aL06EU
I@1KFe/0IfMW06=SH`1QHF40FEUI06QXJ01VIVH0I6AT065QH@1UIFD0I6AT061PH01MGEd0G5aL061P
H00205]KF`0906][J`1UIFD0JVYZ06=SH`1MGEd0GUiN06MWI`1TI6@0H61P0080HV9R00`0IVIV06YZ
JP1WIfL0GemO06IVIP1NGUh0I6AT06YZJP1XJ6P0JVYZ06e]K@1aLG4206ATI00906QXJ01YJFT0Kfm_
06IVIP1SHf<0J6QX06YZJP1YJFT0IVIV0080K6a/0P1XJ6P02P1]KFd0IVIV06UYJ@1ZJVX0LG5a06UY
J@1UIFD0GUiN06MWI`1UIFD206IVIP0606MWI`1]KFd0KVi^06=SH`1UIFD0Hf=S0P1TI6@0101UIFD0
HV9R05iNGP1TI6@306IVIP0Z065QH@1^KVh0Kfm_06IVIP1]KFd0IFEU06IVIP1^KVh0K6a/06IVIP1W
IfL0GemO06EUI@1XJ6P0KFe]06QXJ01VIVH0KFe]06IVIP1PH600J6QX06=SH`1VIVH0IfMW06ATI01V
IVH0HF5Q05iNGP1UIFD0GemO06UYJ@1ZJVX0HV9R06EUI@1WIfL0HV9R05aLG01UIFD0G5aL05mOG`1W
IfL0IVIV0P1QHF40301HF5P0HF5Q06EUI@1LG5`0IFEU065QH@1NGUh0FUYJ061PH01LG5`0Fe]K06AT
I080H61P0140GUiN06IVIP1VIVH0Hf=S06IVIP1ZJVX0FEUI05mOG`1RHV80GUiN06EUI@1TI6@0J6QX
06EUI@1QHF40GEeM05YJFP0205UIF@0H069RHP1IFET0Fe]K04i>CP1LG5`0HV9R05UIF@1HF5P0GUiN
05mOG`1MGEd0HF5Q05YJFP1QHF40F5QH05]KF`1TI6@0IFEU05eMG@1IFET0GEeM05UIF@1JFUX0FEUI
0P1OGel03P1LG5`0EEEE061PH01KFe/0F5QH05iNGP1MGEd0Fe]K05iNGP1JFUX0GEeM05QHF01NGUh0
H61P0P1QHF402@1WIfL0IFEU06EUI@1[Jf/0Lg=c06e]K@1jNWX0R8R808N7Q`0208^;R`0H08f=S@26
QXH0PX:207alO01fMWH0Kfm_06][J`1UIFD0IVIV06ATI01PH600GUiN05]KF`1LG5`0H61P05YJFP1M
GEd0FEUI05aLG01HF5P0Fe]K05MGE`1FEUH0E5AD1P3IfMT100000040fMWI000F0=WIf@030000003I
fMT0fMWI00<0fMWI01D0FEUI05mOG`1OGel0Hf=S05aLG01JFUX0GUiN06EUI@1KFe/0F5QH05aLG01P
H600F5QH05eMG@1HF5P0G5aL05eMG@1HF5P0FUYJ05UIF@1OGel00P1KFe/0501NGUh0FUYJ05IFEP1N
GUh0EEEE05UIF@1LG5`0Fe]K051@D01MGEd0Fe]K05mOG`1UIFD0G5aL05YJFP1PH600F5QH05iNGP1F
EUH0H61P0P1KFe/01P1SHf<0Fe]K069RHP1MGEd0FEUI05QHF0<0GUiN01d0GEeM061PH01LG5`0HV9R
05aLG01IFET0GUiN05aLG01KFe/0I6AT06QXJ01[Jf/0Lg=c075aL@1`L700HV9R06QXJ01JFUX0GemO
065QH@1@D500J6QX061PH01VIVH0IFEU05eMG@1UIFD0GEeM06IVIP02061PH00=05MGE`1PH600GEeM
05YJFP1QHF40Fe]K06IVIP1NGUh0HV9R05eMG@1WIfL0GEeM06ATI002065QH@80GUiN00h0GEeM06][
J`1SHf<0H61P06UYJ@1NGUh0IfMW06=SH`1QHF40J6QX06IVIP1YJFT0Hf=S06QXJ080K6a/0140IfMW
06][J`1OGel0JVYZ05eMG@1WIfL0Jf][06UYJ@1SHf<0HF5Q061PH01XJ6P0IfMW05iNGP1/K6`0IFEU
06i^KP0306YZJP0906m_K`1QHF40IFEU06UYJ@1[Jf/0J6QX06MWI`1SHf<0GEeM0080HF5Q0180JFUY
061PH01UIFD0Hf=S06MWI`1OGel0I6AT061PH01WIfL0HF5Q06EUI@1WIfL0JVYZ06IVIP1]KFd0I6AT
06=SH`1PH60206][J`0@06EUI@1NGUh0IFEU06ATI01VIVH0Hf=S06QXJ01UIFD0GUiN061PH01XJ6P0
K6a/069RHP1UIFD0I6AT06EUI@80HV9R01/0GUiN06=SH`1RHV80H61P08F5Q@1nOWh0GemO06UYJ@1K
Fe/0F5QH06=SH`1WIfL0GemO06=SH`1PH600IFEU061PH01SHf<0HV9R05eMG@1TI6@0IVIV065QH@1F
EUH0J6QX065QH@1JFUX00P1NGUh03`1OGel0GUiN06ATI01KFe/0G5aL069RHP1OGel0EeMG06UYJ@1U
IFD0EeMG061PH01QHF40G5aL05]KF`02065QH@0905mOG`1WIfL0G5aL05]KF`1QHF40G5aL065QH@1N
GUh0IFEU0080FEUI00D0GEeM05YJFP1QHF40GEeM05YJFP0205QHF00806ATI01HF5P0Kfm_05iNGP1O
Gel0GUiN05]KF`1JFUX205]KF`0405aLG01IFET0GUiN05QHF0<0G5aL00H0FEUI05iNGP1LG5`0I6AT
05]KF`1RHV8205iNGP80H61P00X0GUiN05mOG`1QHF40IfMW065QH@1[Jf/0I6AT06e]K@1dM7@0MgMg
0P1mOGd01`22PX80M7Ad07MgM`1bLW80LG5a06UYJ@1^KVh00`1WIfL02`1UIFD0IfMW065QH@1OGel0
G5aL065QH@1RHV80GEeM05MGE`1LG5`0GemO0080Fe]K00<0FUYJ0=WIf@3IfMT0103IfMT100000040
fMWI000F0=WIf@800000103IfMT0301MGEd0GemO05IFEP1FEUH0FEUI05mOG`1JFUX0Fe]K05QHF01L
G5`0IVIV05aLG080FEUI00P0GemO05UIF@1HF5P0EeMG05IFEP1PH600F5QH05YJFP80FEUI00h0GUiN
05aLG01ADE40Fe]K05eMG@1KFe/0E5AD069RHP1FEUH0IfMW05]KF`1MGEd0G5aL05]KF`80GEeM02d0
G5aL069RHP1HF5P0GEeM05]KF`1QHF40H61P06=SH`1OGel0FUYJ061PH01JFUX0G5aL069RHP1IFET0
GUiN05eMG@1NGUh0Fe]K05iNGP1IFET0Fe]K05aLG01PH600HV9R06MWI`1YJFT0KFe]06MWI`1NGUh0
H61P05mOG`1XJ6P0IfMW05iNGP1OGel0GEeM06EUI@1RHV80F5QH05mOG`1KFe/0GUiN065QH@1MGEd0
0P1TI6@0=P1RHV80FEUI06=SH`1RHV80GEeM05mOG`1ZJVX0HF5Q06QXJ01TI6@0HF5Q061PH01RHV80
GUiN05eMG@1UIFD0HF5Q069RHP1UIFD0I6AT05mOG`1RHV80Hf=S06MWI`1TI6@0JFUY06=SH`1UIFD0
JVYZ06=SH`1QHF40HV9R06][J`1XJ6P0I6AT06QXJ01SHf<0GemO06MWI`1[Jf/0J6QX06=SH`1VIVH0
I6AT065QH@1TI6@0HV9R06i^KP1XJ6P0IFEU06=SH`1TI6@0IVIV06EUI@80IVIV00X0I6AT06QXJ01Y
JFT0IfMW06][J`1TI6@0JFUY061PH01WIfL0IVIV0P1WIfL01@1/K6`0HV9R06YZJP1RHV80Hf=S0080
Jf][01<0IfMW06ATI01YJFT0JVYZ05eMG@1UIFD0I6AT06YZJP1QHF40JFUY069RHP1WIfL0JFUY06=S
H`1[Jf/0I6AT06EUI@1SHf<0JFUY0080Hf=S0P1XJ6P02`1UIFD0KFe]05iNGP1VIVH0GemO06IVIP1]
KFd0Hf=S06EUI@1SHf<0GEeM0080GemO02T0K6a/05mOG`1WIfL0JFUY061PH01XJ6P0GUiN069RHP1U
IFD0EeMG06YZJP1TI6@0J6QX05MGE`1PH600GEeM06EUI@1XJ6P0I6AT06EUI@1OGel0HV9R05mOG`1S
Hf<0G5aL069RHP1MGEd0GemO06IVIP1TI6@0H61P06=SH`1LG5`0HF5Q05iNGP1PH600FUYJ05mOG`1V
IVH0H61P05QHF00206=SH`08061PH01KFe/0FUYJ069RHP1MGEd0EEEE05YJFP1LG5`205]KF`0a05eM
G@1HF5P0HV9R05]KF`1MGEd0FEUI05aLG01KFe/0F5QH05MGE`1MGEd0H61P05YJFP1IFET0E5AD06=S
H`1FEUH0G5aL065QH@1PH600FEUI05aLG01HF5P0GEeM05YJFP1HF5P0H61P069RHP1LG5`0IVIV06QX
J01RHV80H61P06EUI@1_Kfl0LW9b07YjNP1dM7@0LG5a079bLP1cLg<0MGEe06e]K@1bLW80KVi^06YZ
JP1XJ6P0JFUY06=SH`02061PH080HV9R0P1MGEd0201OGel0Fe]K05UIF@1OGel0FUYJ05MGE`1KFe/0
GEeM1@3IfMT200000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00L0GEeM05=CD`1HF5P0
GUiN061PH01EEED0G5aL0080F5QH01d0FUYJ05iNGP1TI6@0EUIF05aLG01NGUh0H61P05iNGP1JFUX0
EeMG06=SH`1LG5`0EEEE05=CD`1JFUX0Fe]K05MGE`1OGel0HF5Q05]KF`1DE5@0G5aL05]KF`1IFET0
EeMG05]KF`1RHV80EeMG065QH@0205]KF`<0FEUI0P1KFe/0701GEeL0HV9R05IFEP1JFUX0HF5Q05MG
E`1PH600Fe]K05YJFP1PH600FEUI05MGE`1KFe/0GUiN05eMG@1EEED0Hf=S065QH@1TI6@0Hf=S06EU
I@1WIfL0Hf=S05mOG`1RHV80Fe]K069RHP1KFe/2061PH080Hf=S00<0GUiN05mOG`1OGel00P1JFUX0
1`1LG5`0GEeM065QH@1QHF40HV9R05YJFP1NGUh00P1LG5`04`1UIFD0H61P061PH01WIfL0IVIV065Q
H@1SHf<0EeMG06YZJP1SHf<0H61P069RHP1XJ6P0IVIV06EUI@1LG5`0Hf=S06ATI01VIVH00P1UIFD0
101RHV80IfMW06ATI01SHf<206UYJ@0F06YZJP1WIfL0JFUY06EUI@1PH600J6QX06EUI@1YJFT0J6QX
06UYJ@1UIFD0I6AT061PH01XJ6P0Jf][06YZJP1XJ6P0IfMW06ATI01UIFD0IfMW069RHP80IfMW00d0
IVIV06QXJ01bLW80J6QX06ATI01UIFD0I6AT06=SH`1]KFd0JFUY06MWI`1YJFT0HV9R00<0IVIV01d0
IfMW069RHP1SHf<0JVYZ06EUI@1VIVH0IfMW06YZJP1JFUX0JFUY06QXJ01SHf<0IFEU06MWI`1OGel0
I6AT06QXJ01UIFD0JVYZ06=SH`1RHV80GemO05aLG01PH600J6QX069RHP1SHf<0HV9R06MWI`02065Q
H@80Hf=S02X0HF5Q06IVIP1NGUh0HV9R05YJFP1UIFD0I6AT06=SH`1QHF40Hf=S06ATI01OGel0H61P
05mOG`1LG5`0IFEU061PH01WIfL0GemO05UIF@1TI6@0GUiN05eMG@1XJ6P0HF5Q05UIF@1JFUX0Fe]K
061PH01SHf<0HV9R061PH01QHF40HV9R05YJFP1TI6@0IfMW05QHF01OGel0FUYJ05]KF`1NGUh3065Q
H@09061PH01KFe/0H61P065QH@1LG5`0HF5Q05YJFP1CDe<0GEeM0080Fe]K00D0GemO05YJFP1LG5`0
GemO069RHP02061PH00305aLG01PH600GEeM0080H61P00@0Hf=S05]KF`1NGUh0Fe]K0P1QHF401@1K
Fe/0G5aL05QHF01LG5`0Fe]K0080G5aL0140FUYJ06EUI@1NGUh0GEeM04Y:BP1QHF40GEeM06=SH`1I
FET0GemO06EUI@1NGUh0G5aL06IVIP1^KVh0IFEU06][J`0306e]K@0:06QXJ01aLG40L71`06YZJP1Y
JFT0Kfm_06UYJ@1VIVH0H61P05iNGP80GemO00<0GUiN05aLG01PH6000P1LG5`01@1UIFD0EUIF065Q
H@1HF5P0EEEE00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0405UIF@1D
E5@0G5aL05YJFP80FEUI00@0I6AT05mOG`1NGUh0HV9R0P1LG5`02`1KFe/0F5QH069RHP1KFe/0FEUI
069RHP1PH600F5QH05iNGP1UIFD0GEeM0080Fe]K00`0FUYJ05iNGP1PH600GEeM05]KF`1FEUH0HF5Q
05UIF@1=CDd0FEUI065QH@1JFUX2065QH@0Q05eMG@1GEeL0GemO05QHF01JFUX0Hf=S05QHF01LG5`0
Fe]K05mOG`1LG5`0F5QH05iNGP1FEUH0Fe]K05mOG`1GEeL0GUiN05mOG`1KFe/0H61P05YJFP1SHf<0
HV9R05iNGP1LG5`0GUiN05YJFP1FEUH0GEeM069RHP1LG5`0H61P0080HV9R01D0HF5Q05iNGP1NGUh0
H61P05mOG`1QHF40GUiN05]KF`1SHf<0H61P06=SH`1NGUh0H61P05IFEP1PH600Fe]K06EUI@1PH600
Fe]K05aLG01SHf<00P1NGUh00`1LG5`0HV9R069RHP02061PH005065QH@1OGel0IVIV06MWI`1bLW80
0P1TI6@2069RHP0:06][J`1WIfL0GemO06YZJP1RHV80H61P06EUI@1WIfL0J6QX061PH080IFEU00H0
HV9R06MWI`1YJFT0HV9R06MWI`1XJ6P206=SH`0A06IVIP1UIFD0IfMW06MWI`1PH600JFUY05]KF`1W
IfL0HF5Q05eMG@1[Jf/0KFe]069RHP1[Jf/0K6a/05mOG`1SHf<00P1VIVH03P1/K6`0HV9R06EUI@1Q
HF40IFEU06ATI01[Jf/0H61P06][J`1TI6@0JVYZ06UYJ@1VIVH0I6AT0P1]KFd0401RHV80LG5a06=S
H`1VIVH0IFEU06a/K01PH600IFEU05mOG`1/K6`0J6QX06IVIP1WIfL0J6QX06=SH`1QHF4206=SH`09
06MWI`1QHF40HV9R06MWI`1MGEd0Hf=S069RHP1UIFD0HV9R0080H61P00L0EeMG05mOG`1KFe/0GUiN
05aLG01PH600HV9R0080GemO01<0IfMW05YJFP1MGEd0JVYZ06QXJ01PH600JVYZ05iNGP1RHV80FEUI
05eMG@1NGUh0IFEU065QH@1NGUh0H61P05iNGP1VIVH0HF5Q00<0GEeM0P1NGUh01P1PH600I6AT065Q
H@1RHV80Hf=S05mOG`80HV9R03/0HF5Q05]KF`1MGEd0GUiN05IFEP1KFe/0GUiN06ATI01KFe/0J6QX
05mOG`1MGEd0FEUI059BDP1MGEd0GUiN05aLG01NGUh0FEUI05iNGP1IFET0GUiN05aLG01EEED0GEeM
061PH01IFET0F5QH05iNGP1HF5P0Fe]K05aLG01HF5P0EeMG05]KF`1PH600FUYJ05]KF`1OGel0Fe]K
061PH01RHV80GUiN05mOG`1EEED0G5aL065QH@1PH600IFEU05IFEP1UIFD0IfMW075aL@1VIVH0K6a/
06m_K`1OGel0Kfm_06QXJ00306IVIP0@05eMG@1/K6`0HF5Q05iNGP1KFe/0HV9R05YJFP1LG5`0E5AD
05eMG@1GEeL0FUYJ05MGE`1HF5P0GemO05eMG@H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI
0=WIf@030=WIf@80Fe]K00l0GEeM05]KF`1IFET0Fe]K05UIF@1CDe<0FEUI05QHF01EEED0GEeM05UI
F@1NGUh0E5AD05]KF`1LG5`00P1IFET04@1EEED0FUYJ05mOG`1IFET0G5aL06EUI@1IFET0H61P05UI
F@1JFUX0HV9R05QHF01KFe/0GUiN05UIF@1MGEd0EeMG0080F5QH02P0EUIF05iNGP1RHV80Fe]K05aL
G01MGEd0FUYJ05iNGP1MGEd0G5aL05YJFP1PH600G5aL061PH01IFET0GUiN05aLG01KFe/0GemO05iN
GP1QHF40GEeM05YJFP1QHF40H61P05aLG01PH600IFEU061PH01QHF40Hf=S05UIF@1RHV80G5aL069R
HP1QHF40IVIV05eMG@1KFe/0GEeM0P1NGUh04`1KFe/0Hf=S06UYJ@1OGel0H61P05eMG@1IFET0HF5Q
05eMG@1LG5`0IfMW05mOG`1NGUh0H61P065QH@1YJFT0IFEU06ATI01RHV800P1KFe/00`1QHF40JFUY
05]KF`0305mOG`0806IVIP1UIFD0IVIV06a/K01VIVH0Hf=S06a/K01UIFD206MWI`0506YZJP1RHV80
IFEU06IVIP1UIFD00P1SHf<02P1/K6`0JFUY065QH@1SHf<0IfMW05mOG`1WIfL0GEeM065QH@1WIfL2
06ATI00F06IVIP1QHF40I6AT069RHP1VIVH0IFEU06IVIP1WIfL0GemO06QXJ01TI6@0JFUY06MWI`1M
GEd0JVYZ06MWI`1UIFD0Fe]K06][J`1/K6`0IfMW06=SH`80HV9R00<0IVIV06QXJ01WIfL00P1UIFD0
6P1WIfL0Jf][06ATI01YJFT0HV9R06ATI01aLG40HV9R06MWI`1QHF40Fe]K06EUI@1TI6@0IFEU069R
HP1PH600HF5Q06IVIP1TI6@0IFEU06YZJP1SHf<0IfMW061PH01TI6@0IFEU0P1PH6002P1[Jf/0IVIV
06EUI@1PH600GUiN06=SH`1QHF40GemO065QH@1JFUX205eMG@0I06EUI@1RHV80IFEU05iNGP1PH600
Fe]K05eMG@1PH600Hf=S069RHP1WIfL0F5QH069RHP1LG5`0GemO05iNGP1KFe/0GEeM05mOG`1VIVH0
Hf=S061PH01RHV80IVIV061PH00205eMG@0e061PH01MGEd0GUiN061PH01JFUX0GemO05QHF01FEUH0
FEUI05QHF01RHV80H61P05QHF01OGel0HF5Q061PH01KFe/0GUiN05QHF01JFUX0GemO05aLG01MGEd0
G5aL05mOG`1LG5`0E5AD05QHF01JFUX0EEEE05QHF01MGEd0HF5Q05EEE@1HF5P0FEUI05QHF01FEUH0
G5aL05UIF@1KFe/0G5aL05iNGP1OGel0Fe]K05YJFP1FEUH0FUYJ05eMG@1IFET0I6AT06=SH`1VIVH0
0P1UIFD01P1SHf<0JFUY06IVIP1[Jf/0JVYZ06MWI`80JVYZ01<0Jf][06ATI01VIVH0IFEU06=SH`1W
IfL0FEUI05aLG01TI6@0GemO05iNGP1QHF40Hf=S05mOG`1NGUh0GEeM05MGE`1IFET0Fe]K00H0fMWI
0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0305IFEP1MGEd0E5AD0080FUYJ04`0
HF5Q05]KF`1NGUh0EUIF05iNGP1FEUH0EEEE05YJFP1GEeL0G5aL05YJFP1TI6@0Fe]K05MGE`1FEUH0
GemO05MGE`1HF5P0GUiN05QHF01KFe/0GEeM05]KF`1MGEd0Fe]K05YJFP1KFe/0FUYJ05IFEP1IFET0
EeMG05QHF01JFUX0EeMG05UIF@1PH600E5AD05]KF`1PH600Fe]K05aLG01QHF40FUYJ05MGE`1NGUh0
FEUI05IFEP1IFET0GUiN05QHF01GEeL0G5aL05mOG`1EEED0FUYJ05]KF`1LG5`0GUiN069RHP1MGEd0
GUiN05mOG`1RHV80H61P05QHF01NGUh0GEeM065QH@1LG5`0H61P05iNGP1RHV80GUiN05eMG@1QHF40
H61P0P1QHF40901UIFD0GemO06=SH`1IFET0GUiN05eMG@1SHf<0IfMW061PH01/K6`0G5aL06ATI01M
GEd0GUiN05QHF01MGEd0EeMG06ATI01MGEd0GemO05UIF@1QHF40GUiN06=SH`1/K6`0HF5Q06][J`1V
IVH0IFEU06QXJ01WIfL0IFEU06YZJP1QHF40JFUY06MWI`80IFEU01D0J6QX06MWI`1VIVH0I6AT06QX
J01TI6@0JFUY06MWI`1TI6@0IVIV065QH@1YJFT0IFEU065QH@1XJ6P0I6AT05]KF`1OGel0I6AT06=S
H`1UIFD00P1XJ6P03`1OGel0IFEU06a/K01[Jf/0IfMW06ATI01UIFD0IfMW06YZJP1SHf<0IVIV06EU
I@1PH600GemO06EUI@0205mOG`0<065QH@1ZJVX0IFEU06=SH`1ZJVX0Hf=S06EUI@1VIVH0J6QX061P
H01WIfL0J6QX0P1VIVH04P1QHF40Hf=S05iNGP1PH600HF5Q05iNGP1WIfL0HF5Q06YZJP1SHf<0IVIV
06UYJ@1ZJVX0HF5Q06ATI01NGUh0GemO05eMG@80HV9R00@0Hf=S06ATI01JFUX0Hf=S0P1PH600=@1J
FUX0GEeM06EUI@1VIVH0FUYJ05aLG01QHF40HV9R05MGE`1OGel0HV9R061PH01IFET0GemO05aLG01R
HV80GemO065QH@1PH600FUYJ05mOG`1NGUh0H61P05eMG@1OGel0HV9R05iNGP1YJFT0IVIV06=SH`1J
FUX0FEUI05iNGP1KFe/0GUiN05mOG`1QHF40F5QH05mOG`1KFe/0DE5A05QHF01IFET0Hf=S05IFEP1Q
HF40GemO05aLG01MGEd0HV9R05iNGP1GEeL0GEeM00@0FEUI02D0H61P05YJFP1KFe/0G5aL05iNGP1K
Fe/0G5aL05eMG@1NGUh0Fe]K05mOG`1IFET0F5QH05mOG`1HF5P0HF5Q05UIF@1MGEd0GUiN05IFEP1A
DE40HV9R05YJFP1NGUh0G5aL05iNGP1RHV80Hf=S05aLG01NGUh0I6AT06=SH`1/K6`0I6AT05YJFP1X
J6P0KFe]0080IFEU00P0HF5Q061PH01RHV80JVYZ06ATI01RHV80I6AT06=SH`80G5aL00L0GUiN05aL
G01JFUX0FUYJ05IFEP1EEED0G5aL00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@03
0=WIf@0J05YJFP1KFe/0FUYJ05eMG@1JFUX0HF5Q05mOG`1MGEd0H61P05]KF`1NGUh0GEeM05]KF`1N
GUh0Fe]K06ATI01GEeL0HV9R05eMG@1QHF40F5QH06ATI01GEeL0FEUI05eMG@1OGel205aLG00405]K
F`1PH600GEeM05MGE`<0FUYJ00<0De=C05aLG01EEED00P1IFET0401MGEd0HF5Q05eMG@1NGUh0G5aL
05UIF@1NGUh0EEEE05aLG01JFUX0F5QH05eMG@1HF5P0G5aL05QHF01IFET305mOG`0:05QHF01VIVH0
F5QH05ADE01PH600Fe]K05iNGP1LG5`0GEeM05mOG`<0H61P0P1NGUh02P1JFUX0IFEU05mOG`1HF5P0
HV9R05iNGP1RHV80Hf=S06YZJP1LG5`205eMG@0506EUI@1SHf<0I6AT061PH01DE5@00P1OGel03P1J
FUX0F5QH05iNGP1MGEd0H61P065QH@1NGUh0HV9R05YJFP1SHf<0GUiN061PH01WIfL0Hf=S0P1PH600
4`1LG5`0GUiN06ATI01WIfL0GemO06EUI@1RHV80JVYZ05iNGP1QHF40G5aL06EUI@1TI6@0GemO06UY
J@1MGEd0H61P065QH@1/K6`00P1VIVH05P1MGEd0Hf=S06=SH`1UIFD0GUiN06MWI`1UIFD0Jf][06IV
IP1SHf<0JVYZ06=SH`1XJ6P0K6a/06ATI01[Jf/0GemO06=SH`1QHF40IfMW065QH@1OGel206MWI`80
I6AT0200Hf=S06EUI@1SHf<0IVIV06][J`1YJFT0IFEU06ATI01QHF40Jf][05eMG@1OGel0I6AT05mO
G`1MGEd0I6AT069RHP1KFe/0G5aL06=SH`1]KFd0HF5Q06QXJ01UIFD0J6QX065QH@1]KFd0IFEU06a/
K01UIFD0FEUI061PH080IVIV00P0IFEU05eMG@1PH600Hf=S05mOG`1SHf<0GUiN069RHP80H61P00h0
HV9R06=SH`1NGUh0G5aL06EUI@1HF5P0I6AT065QH@1SHf<0FEUI05]KF`1RHV80Hf=S06a/K080HF5Q
0P1NGUh04`1MGEd0EeMG05UIF@1SHf<0HF5Q06=SH`1JFUX0IfMW069RHP1YJFT0GEeM05iNGP1OGel0
GEeM069RHP1OGel0Fe]K061PH01QHF400P1NGUh0101IFET0E5AD05mOG`1HF5P205aLG00305eMG@1E
EED0GEeM0080EeMG00X0GUiN05eMG@1GEeL0F5QH05iNGP1DE5@0GEeM05YJFP1MGEd0FUYJ0`1LG5`0
101WIfL0Fe]K05iNGP1FEUH205MGE`05065QH@1OGel0FEUI05MGE`1OGel00P1IFET01P1OGel0FEUI
05YJFP1DE5@0De=C05QHF080GEeM0180F5QH065QH@1JFUX0HV9R065QH@1WIfL0GEeM06ATI01NGUh0
HF5Q06e]K@1WIfL0HV9R05aLG01SHf<0IFEU069RHP1IFET205]KF`0:05iNGP1GEeL0HV9R05]KF`1S
Hf<0GUiN05ADE01OGel0EEEE05aLG0H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@03
0=WIf@0Q05YJFP1HF5P0Fe]K05aLG01KFe/0GEeM05MGE`1DE5@0GemO05YJFP1PH600G5aL05QHF01L
G5`0IVIV05aLG01FEUH0GUiN05aLG01PH600GEeM061PH01MGEd0EeMG05]KF`1MGEd0E5AD05YJFP1V
IVH0Fe]K05mOG`1KFe/0EEEE0080G5aL00L0E5AD05YJFP1FEUH0H61P05UIF@1NGUh0EeMG0080FUYJ
00@0G5aL061PH01MGEd0GEeM0P1HF5P04@1JFUX0G5aL05]KF`1HF5P0HV9R065QH@1PH600GemO05]K
F`1UIFD0HF5Q05eMG@1SHf<0Fe]K05eMG@1JFUX0Fe]K0080GUiN01L0G5aL065QH@1JFUX0Fe]K061P
H01GEeL0GemO05UIF@1PH600HF5Q069RHP1JFUX0H61P06EUI@1QHF40H61P06YZJP1YJFT0GemO06IV
IP1TI6@0IVIV06MWI`0205mOG`0606=SH`1LG5`0H61P05mOG`1MGEd0HV9R0P1SHf<2065QH@0W069R
HP1ZJVX0GemO06ATI01OGel0I6AT06QXJ01WIfL0J6QX06YZJP1PH600HF5Q069RHP1PH600IFEU06IV
IP1QHF40H61P06=SH`1VIVH0I6AT06UYJ@1WIfL0IVIV06ATI01PH600IVIV06=SH`1MGEd0IFEU06QX
J01RHV80IFEU06a/K01RHV80H61P06=SH`1WIfL0HV9R0080IFEU00d0GEeM069RHP1RHV80GEeM06YZ
JP1TI6@0IFEU06IVIP1ZJVX0GemO06UYJ@1TI6@0IfMW0080J6QX01L0IVIV05iNGP1PH600Hf=S06EU
I@1VIVH0Hf=S061PH01RHV80IVIV05mOG`1QHF40Hf=S05aLG01RHV80J6QX069RHP1KFe/0IFEU06QX
J01QHF40IfMW06UYJ@0206ATI00306=SH`1_Kfl0HF5Q0080IVIV00D0H61P05iNGP1LG5`0HV9R06EU
I@0206=SH`0505iNGP1ZJVX0GUiN06=SH`1QHF400P1SHf<0=`1FEUH0IFEU05YJFP1RHV80H61P05mO
G`1TI6@0G5aL06IVIP1eMGD0Hf=S06ATI01RHV80EeMG05iNGP1SHf<0G5aL06ATI01IFET0Fe]K05mO
G`1RHV80Hf=S06QXJ01NGUh0HF5Q05UIF@1KFe/0G5aL065QH@1PH600G5aL061PH01MGEd0DE5A05eM
G@1QHF40FEUI05eMG@1LG5`0FEUI05iNGP1JFUX0FEUI05aLG01HF5P0G5aL05eMG@1KFe/0F5QH05IF
EP1MGEd0Fe]K05UIF@1OGel00P1JFUX0901LG5`0H61P05aLG01MGEd0HF5Q05iNGP1KFe/0GEeM05]K
F`1EEED0GEeM05YJFP1CDe<0H61P06ATI01LG5`0H61P05IFEP1IFET0GUiN06ATI01IFET0G5aL05eM
G@1UIFD0HV9R061PH01FEUH0FUYJ06=SH`1TI6@0J6QX06][J`1YJFT0G5aL05eMG@80H61P0P1MGEd0
3@1PH600GemO065QH@1QHF40FEUI06=SH`1KFe/0G5aL05YJFP1GEeL0FUYJ05aLG01IFET01P3IfMT1
00000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0P1MGEd205iNGP0E05]KF`1JFUX0I6AT
05aLG01HF5P0EeMG05]KF`1PH600FEUI05]KF`1QHF40Hf=S05]KF`1NGUh0EeMG05aLG01GEeL0F5QH
05]KF`1QHF40FUYJ0080GemO00<0GEeM05mOG`1JFUX00P1NGUh205eMG@0:05MGE`1NGUh0F5QH05QH
F01PH600FEUI05MGE`1MGEd0HF5Q05MGE`80F5QH0P1IFET01`1RHV80GUiN05]KF`1KFe/0FEUI065Q
H@1LG5`00P1KFe/04P1HF5P0EEEE061PH01MGEd0HF5Q05eMG@1TI6@0FUYJ05aLG01JFUX0G5aL069R
HP1NGUh0FUYJ06=SH`1XJ6P0GUiN05]KF`80GEeM0P1PH6002P1IFET0H61P05iNGP1OGel0FUYJ065Q
H@1SHf<0GEeM06IVIP1WIfL2069RHP04061PH01QHF40HV9R05]KF`80GEeM00@0EeMG06=SH`1MGEd0
IFEU0P1PH6001@1SHf<0HF5Q069RHP1RHV80H61P0080HF5Q0380IfMW065QH@1WIfL0IVIV05mOG`1V
IVH0HV9R065QH@1RHV80GUiN05mOG`1UIFD0HV9R06MWI`1TI6@0J6QX06YZJP1QHF40Hf=S061PH01U
IFD0GEeM05]KF`1TI6@0IFEU05aLG01RHV80HF5Q06EUI@1VIVH0H61P06=SH`1ZJVX0I6AT069RHP1O
Gel0I6AT06EUI@1TI6@0IVIV06UYJ@1UIFD0GemO06EUI@1VIVH0JFUY065QH@1SHf<0H61P069RHP80
IFEU01h0H61P06ATI01WIfL0HF5Q06MWI`1MGEd0HV9R065QH@1LG5`0HV9R06EUI@1TI6@0HF5Q061P
H01UIFD0HF5Q05mOG`1UIFD0JVYZ06UYJ@1NGUh0I6AT05iNGP1UIFD0J6QX069RHP1WIfL0GEeM05]K
F`1[Jf/205iNGP0405YJFP1PH600GUiN05eMG@80GUiN00@0Hf=S06MWI`1QHF40GUiN0P1MGEd0401W
IfL0GEeM069RHP1TI6@0FUYJ06EUI@1LG5`0Fe]K05aLG01UIFD0Fe]K065QH@1JFUX0Hf=S061PH01S
Hf<205iNGP0B05]KF`1QHF40J6QX06QXJ01UIFD0HF5Q05QHF01GEeL0F5QH05]KF`1JFUX0FEUI05iN
GP1HF5P0GUiN065QH@1HF5P0Fe]K0P1JFUX07@1MGEd0GemO05mOG`1PH600G5aL061PH01GEeL0FEUI
05iNGP1HF5P0FEUI05iNGP1MGEd0G5aL05mOG`1MGEd0EeMG065QH@1HF5P0HF5Q069RHP1JFUX0GemO
05=CD`1NGUh0F5QH05]KF`1OGel0H61P0080FUYJ00l0EeMG05YJFP1FEUH0G5aL05EEE@1IFET0GemO
05aLG01MGEd0FUYJ05]KF`1TI6@0GEeM05iNGP1JFUX00P1RHV802P1QHF40Hf=S06QXJ01TI6@0HF5Q
069RHP1SHf<0HF5Q06ATI01NGUh205QHF00:05MGE`1HF5P0F5QH05iNGP1DE5@0F5QH05UIF@1GEeL0
FUYJ05QHF0H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0505aLG01JFUX0
EUIF05]KF`1MGEd00P1QHF401`1IFET0HF5Q069RHP1UIFD0HF5Q05YJFP1IFET00`1NGUh01@1RHV80
GemO05MGE`1KFe/0F5QH0080GemO00@0Fe]K05IFEP1NGUh0G5aL0P1GEeL01P1DE5@0Fe]K05QHF01G
EeL0FEUI05iNGP80G5aL00D0FEUI05eMG@1KFe/0H61P05YJFP02061PH00605UIF@1JFUX0GEeM05QH
F01OGel0G5aL0P1FEUH03P1XJ6P0FEUI05UIF@1JFUX0EeMG05aLG01JFUX0GEeM05YJFP1MGEd0HF5Q
05eMG@1LG5`0F5QH0P1LG5`0301RHV80Fe]K065QH@1VIVH0IFEU05mOG`1PH600I6AT061PH01OGel0
IfMW05YJFP80HV9R0P1LG5`02`1NGUh0GemO069RHP1FEUH0HF5Q05mOG`1QHF40I6AT06QXJ01SHf<0
Fe]K0080G5aL00H0GEeM06MWI`1UIFD0H61P069RHP1PH60205]KF`1O069RHP1MGEd0HV9R06][J`1Q
HF40GUiN065QH@1VIVH0HF5Q06e]K@1RHV80Hf=S05mOG`1PH600JVYZ06IVIP1TI6@0IfMW06=SH`1T
I6@0HF5Q06=SH`1QHF40I6AT06EUI@1QHF40Hf=S06ATI01PH600HF5Q05eMG@1LG5`0J6QX069RHP1Y
JFT0IFEU06=SH`1]KFd0HF5Q06=SH`1UIFD0IfMW05iNGP1SHf<0IfMW05aLG01RHV80I6AT069RHP1X
J6P0HF5Q06IVIP1PH600GUiN065QH@1VIVH0G5aL06=SH`1TI6@0GEeM06QXJ01YJFT0IFEU05aLG01M
GEd0GemO06MWI`1RHV80I6AT069RHP1UIFD0HV9R06QXJ01KFe/0KFe]06=SH`1PH600IfMW06=SH`1L
G5`0IFEU05aLG01SHf<0H61P065QH@1OGel0HV9R05iNGP1JFUX0GUiN061PH01OGel0G5aL061PH01K
Fe/00P1QHF40301VIVH0Hf=S05eMG@1OGel0FEUI06ATI01LG5`0F5QH061PH01RHV80FUYJ061PH080
HV9R00h0Fe]K05eMG@1SHf<0Fe]K05iNGP1JFUX0HF5Q05mOG`1VIVH0GUiN065QH@1LG5`0F5QH05UI
F@80IVIV00`0I6AT05YJFP1LG5`0FUYJ05aLG01QHF40GEeM05]KF`1GEeL0F5QH05YJFP1EEED205YJ
FP80G5aL0100FEUI05YJFP1NGUh0GEeM06QXJ01NGUh0F5QH05iNGP1PH600EeMG061PH01JFUX0F5QH
05eMG@1KFe/0GEeM101KFe/205aLG00>05=CD`1FEUH0GEeM05UIF@1JFUX0G5aL05]KF`1GEeL0EUIF
05]KF`1GEeL0G5aL05YJFP1OGel205aLG00=061PH01QHF40HV9R05aLG01OGel0IFEU061PH01OGel0
HF5Q06ATI01RHV80Fe]K05QHF00205aLG00<05MGE`1PH600Fe]K05eMG@1WIfL0GemO05IFEP1NGUh0
FEUI05YJFP1LG5`0GemO1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00`0
F5QH06ATI01MGEd0Fe]K05iNGP1QHF40GUiN05aLG01KFe/0IVIV05IFEP1NGUh205aLG00]05QHF01G
EeL0EUIF05aLG01JFUX0F5QH05UIF@1JFUX0EeMG05UIF@1NGUh0FUYJ05aLG01QHF40Fe]K05EEE@1L
G5`0FEUI05]KF`1LG5`0GEeM061PH01SHf<0GemO05QHF01QHF40De=C05eMG@1NGUh0FUYJ05aLG01H
F5P0FUYJ05aLG01GEeL0GEeM05]KF`1JFUX0F5QH05eMG@1IFET0GEeM06EUI@1MGEd0GemO0080GUiN
00D0EeMG05]KF`1GEeL0E5AD05aLG002069RHP0C05YJFP1KFe/0HF5Q05]KF`1OGel0IFEU061PH01Q
HF40GUiN05aLG01FEUH0GemO06ATI01OGel0EEEE05mOG`1QHF40GUiN065QH@0205aLG00<05YJFP1S
Hf<0HF5Q061PH01OGel0G5aL06EUI@1MGEd0HV9R05QHF01OGel0I6AT0P1RHV804@1MGEd0IFEU065Q
H@1NGUh0IfMW06=SH`1PH600GUiN06IVIP1QHF40HV9R065QH@1RHV80H61P06EUI@1]KFd0Hf=S0080
IfMW0100I6AT06MWI`1UIFD0HV9R06=SH`1PH600IfMW06ATI01RHV80IFEU05mOG`1PH600HF5Q06EU
I@1IFET0IFEU0P1TI6@05P1OGel0H61P06][J`1KFe/0HF5Q06ATI01UIFD0GemO06ATI01UIFD0I6AT
06UYJ@1UIFD0HF5Q05aLG01RHV80Hf=S069RHP1NGUh0Hf=S065QH@1VIVH206=SH`0A05eMG@1PH600
HF5Q061PH01UIFD0GEeM065QH@1TI6@0GUiN06IVIP1PH600Hf=S05eMG@1SHf<0HV9R05aLG01QHF40
0P1SHf<03P1UIFD0Jf][06ATI01UIFD0I6AT065QH@1RHV80Fe]K05mOG`1NGUh0GEeM06ATI01RHV80
HF5Q0`1OGel04@1JFUX0F5QH05eMG@1QHF40GEeM06=SH`1OGel0HV9R05]KF`1MGEd0H61P05mOG`1H
F5P0EeMG05UIF@1DE5@0IVIV0080FEUI00@0Fe]K061PH01QHF40G5aL0P1KFe/00`1QHF40Fe]K05aL
G00205iNGP0605eMG@1KFe/0F5QH05UIF@1LG5`0FUYJ0P1LG5`04@1NGUh0FUYJ06EUI@1BDU80EUIF
06ATI01IFET0Hf=S05mOG`1KFe/0FEUI05]KF`1HF5P0HV9R061PH01DE5@0G5aL0080EeMG01@0GemO
05]KF`1GEeL0DU9B069RHP1KFe/0EeMG065QH@1NGUh0FUYJ05QHF01@D500EeMG05QHF01IFET0De=C
05QHF01CDe<0GUiN05aLG080H61P0200F5QH05eMG@1OGel0GemO05UIF@1QHF40GUiN069RHP1OGel0
GUiN06ATI01KFe/0H61P069RHP1JFUX0HV9R061PH01WIfL0Hf=S05iNGP1RHV80EUIF069RHP1LG5`0
IFEU069RHP1NGUh0GEeM05aLG01QHF40EUIF05YJFP80FEUI00<0FUYJ0=WIf@3IfMT0103IfMT10000
0040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00<0Fe]K05iNGP1MGEd00P1NGUh2061PH007
05ADE01NGUh0GEeM05eMG@1QHF40Fe]K05QHF002061PH00605iNGP1GEeL0IfMW05MGE`1JFUX0FEUI
0P1KFe/02@1QHF40FUYJ05]KF`1MGEd0G5aL05eMG@1IFET0FUYJ065QH@0205aLG080Fe]K00H0FUYJ
05MGE`1JFUX0GEeM05mOG`1HF5P205aLG00705mOG`1LG5`0GEeM05UIF@1KFe/0G5aL055AD@0205UI
F@0805aLG01DE5@0FUYJ05ADE01OGel0GUiN05mOG`1VIVH2061PH00905eMG@1FEUH0H61P05eMG@1I
FET0Hf=S05MGE`1KFe/0GEeM0080Fe]K00<0IVIV069RHP1NGUh00`1MGEd0AP1RHV80I6AT05mOG`1N
GUh0GemO06IVIP1NGUh0IVIV065QH@1SHf<0GEeM061PH01LG5`0FEUI06ATI01KFe/0GUiN06=SH`1K
Fe/0GEeM061PH01LG5`0J6QX06ATI01RHV80HF5Q069RHP1ZJVX0Hf=S06MWI`1NGUh0HV9R06][J`1W
IfL0IVIV06EUI@1TI6@0IFEU05YJFP1OGel0GUiN065QH@1WIfL0Hf=S06YZJP1QHF40I6AT05mOG`1M
GEd0HF5Q069RHP1SHf<0HV9R05mOG`1MGEd0IfMW06QXJ01UIFD0HV9R06EUI@1OGel0I6AT05eMG@1O
Gel0GUiN061PH01QHF40IfMW05]KF`1VIVH2069RHP0406ATI01PH600H61P06IVIP80Hf=S0P1LG5`0
1`1[Jf/0HF5Q05YJFP1UIFD0HF5Q06a/K01UIFD00P1TI6@03P1OGel0GEeM05iNGP1OGel0GUiN065Q
H@1KFe/0IVIV065QH@1NGUh0Hf=S05mOG`1KFe/0HF5Q0P1PH6000`1SHf<0GEeM06=SH`0206ATI00B
05mOG`1PH600HF5Q061PH01SHf<0HF5Q061PH01LG5`0GemO061PH01QHF40FUYJ05IFEP1LG5`0GUiN
05aLG01OGel0Fe]K0P1PH6005@1SHf<0GEeM05mOG`1PH600FEUI05YJFP1RHV80GEeM06ATI01GEeL0
H61P05]KF`1SHf<0GEeM05mOG`1PH600E5AD05eMG@1ADE40Fe]K069RHP0205aLG00@05MGE`1MGEd0
EEEE05ADE01HF5P0De=C06ATI01RHV80Hf=S05EEE@1FEUH0Fe]K061PH01LG5`0HV9R05=CD`80F5QH
00`0GemO061PH01KFe/0FUYJ05iNGP1OGel0FEUI05iNGP1RHV80EeMG05aLG01GEeL205YJFP0605QH
F01LG5`0DU9B05eMG@1QHF40Fe]K0P1HF5P0101NGUh0EUIF05YJFP1IFET205mOG`0O06ATI01MGEd0
HV9R05YJFP1OGel0E5AD05]KF`1LG5`0GEeM06EUI@1MGEd0HV9R061PH01ADE40HV9R05eMG@1OGel0
GUiN06EUI@1MGEd0GUiN069RHP1HF5P0IFEU05IFEP1TI6@0H61P06=SH`1NGUh0F5QH05]KF`0205UI
F@0305eMG@3IfMT0fMWI00@0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0[
05UIF@1MGEd0EEEE05eMG@1LG5`0HV9R05eMG@1PH600GemO05aLG01QHF40F5QH05MGE`1KFe/0GEeM
05QHF01IFET0FUYJ069RHP1MGEd0F5QH05UIF@1EEED0GEeM05EEE@1IFET0EeMG05mOG`1HF5P0GUiN
05aLG01HF5P0GEeM069RHP1PH600FUYJ05MGE`1LG5`0FUYJ05eMG@1KFe/0FEUI05QHF00205UIF@0>
05IFEP1NGUh0HF5Q069RHP1JFUX0GemO05iNGP1QHF40F5QH05UIF@1KFe/0FEUI05=CD`1OGel205iN
GP0B05QHF01WIfL0GEeM05aLG01HF5P0GUiN05QHF01PH600EeMG05mOG`1NGUh0GEeM05YJFP1UIFD0
Hf=S05iNGP1LG5`0Fe]K0P1JFUX0:01KFe/0GEeM05aLG01OGel0GUiN06=SH`1QHF40GEeM05iNGP1I
FET0GEeM06YZJP1XJ6P0IFEU05MGE`1OGel0HV9R05iNGP1RHV80H61P05iNGP1TI6@0GUiN069RHP1S
Hf<0HV9R06YZJP1WIfL0I6AT06=SH`1XJ6P0IfMW069RHP1SHf<0I6AT06EUI@1TI6@0JFUY06EUI@1W
IfL2061PH00C06EUI@1NGUh0Jf][06MWI`1MGEd0I6AT06a/K01WIfL0GemO06QXJ01QHF40GEeM069R
HP1SHf<0GUiN06EUI@1SHf<0HV9R061PH00205mOG`0906IVIP1RHV80H61P06IVIP1QHF40GemO061P
H01RHV80Hf=S0080H61P0180HV9R06a/K01PH600I6AT06IVIP1MGEd0Fe]K061PH01RHV80I6AT065Q
H@1YJFT0GUiN069RHP1SHf<0H61P069RHP1LG5`206ATI00?069RHP1OGel0HF5Q05iNGP1UIFD0I6AT
05mOG`1RHV80HF5Q06=SH`1LG5`0HV9R06IVIP1LG5`0GEeM0080GemO00<0Jf][06=SH`1SHf<00P1P
H600601NGUh0I6AT06ATI01LG5`0H61P05iNGP1PH600GEeM05iNGP1RHV80GUiN06UYJ@1OGel0G5aL
065QH@1WIfL0G5aL05MGE`1FEUH0G5aL05mOG`1MGEd0G5aL05iNGP80GemO00/0G5aL065QH@1NGUh0
GemO05UIF@1EEED0F5QH05aLG01KFe/0GemO05=CD`0205mOG`0F05MGE`1MGEd0FUYJ061PH01QHF40
Fe]K05UIF@1NGUh0FUYJ05mOG`1KFe/0Hf=S05iNGP1KFe/0GEeM05IFEP1IFET0Fe]K05mOG`1BDU80
F5QH061PH080FUYJ00H0F5QH05iNGP1KFe/0FEUI05aLG01KFe/205=CD`0905YJFP1IFET0FEUI05aL
G01FEUH0GemO05iNGP1HF5P0GUiN0080G5aL02<0FEUI05QHF01JFUX0HF5Q05=CD`1QHF40FUYJ05eM
G@1FEUH0HF5Q06=SH`1PH600FUYJ065QH@1KFe/0EUIF05]KF`1WIfL0HV9R05iNGP1UIFD0EeMG05iN
GP1JFUX0H61P05iNGP1JFUX0DU9B05QHF01PH600GEeM05mOG`1IFET0GEeM05aLG0060=WIf@400000
0@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0201JFUX0Fe]K05UIF@1FEUH0GUiN061PH01F
EUH0IfMW101NGUh02@1KFe/0I6AT05]KF`1GEeL0GUiN05]KF`1JFUX0EeMG05QHF00205eMG@0H05]K
F`1QHF40GEeM06EUI@1HF5P0G5aL05UIF@1EEED0HF5Q05aLG01TI6@0FUYJ05UIF@1VIVH0FEUI05mO
G`1NGUh0HF5Q05MGE`1NGUh0FEUI05eMG@1OGel0DU9B0P1KFe/02@1MGEd0GUiN05MGE`1JFUX0G5aL
069RHP1NGUh0GEeM05aLG00205eMG@0905MGE`1QHF40GUiN061PH01JFUX0G5aL05mOG`1VIVH0IFEU
0080GemO00P0FEUI059BDP1IFET0GemO06=SH`1OGel0HV9R065QH@80GEeM00/0Fe]K05aLG01VIVH0
GemO06IVIP1RHV80GEeM065QH@1RHV80H61P05mOG`02069RHP0F05mOG`1PH600Fe]K06IVIP1SHf<0
GEeM06EUI@1IFET0H61P05eMG@1OGel0IVIV069RHP1HF5P0GUiN06ATI01UIFD0GEeM061PH01OGel0
Hf=S06EUI@<0GemO0400J6QX05]KF`1TI6@0GUiN06EUI@1WIfL0HV9R05mOG`1VIVH0HF5Q069RHP1U
IFD0oooo07AdM01SHf<0I6AT05UIF@1TI6@0IfMW05]KF`1PH600GEeM05aLG01WIfL0H61P069RHP1V
IVH0HV9R065QH@1SHf<0GemO065QH@1SHf<0HV9R06MWI`1NGUh0GemO06e]K@1VIVH0I6AT05iNGP1I
FET0HF5Q061PH01MGEd0IfMW06IVIP1UIFD0H61P069RHP1JFUX0HV9R05iNGP1QHF40GemO06MWI`1T
I6@0G5aL06][J`1PH600FEUI069RHP1XJ6P0GemO0P1PH6002P1NGUh0IFEU05mOG`1JFUX0IFEU05UI
F@1FEUH0GUiN05aLG01OGel205eMG@0N065QH@1IFET0IVIV05mOG`1QHF40FEUI06IVIP1NGUh0Hf=S
069RHP1NGUh0GemO05MGE`1MGEd0Fe]K065QH@1PH600G5aL05YJFP1LG5`0GemO06QXJ01JFUX0F5QH
05iNGP1EEED0F5QH05UIF@1QHF40GemO0P1JFUX01@1LG5`0H61P05aLG01MGEd0EUIF0080G5aL00<0
GUiN05QHF01OGel00P1OGel04P1JFUX0FEUI05]KF`1QHF40F5QH05aLG01IFET0GUiN05mOG`1BDU80
G5aL061PH01KFe/0GEeM05mOG`1JFUX0F5QH05MGE`80F5QH01H0GEeM05MGE`1PH600FUYJ05mOG`1L
G5`0E5AD05MGE`1@D500G5aL05UIF@1TI6@0HV9R065QH@1JFUX0GEeM05iNGP1HF5P0FEUI05MGE`1M
GEd0FEUI0P1PH600301NGUh0HV9R05iNGP1IFET0GemO061PH01UIFD0HF5Q05eMG@1HF5P0GEeM06=S
H`80GEeM0P1NGUh03@1LG5`0IFEU06ATI01MGEd0G5aL05YJFP1SHf<0GemO05EEE@1MGEd0FUYJ05iN
GP1HF5P01P3IfMT100000040fMWI000F0=WIf@800000103IfMT03`1NGUh0EeMG05mOG`1FEUH0GEeM
05QHF01OGel0GUiN06MWI`1OGel0Fe]K05ADE01LG5`0EUIF05YJFP0205]KF`80G5aL00D0E5AD05aL
G01PH600Fe]K065QH@0205MGE`0T05ADE01HF5P0HV9R05aLG01FEUH0H61P05eMG@1QHF40H61P05UI
F@1JFUX0EEEE05mOG`1KFe/0G5aL05MGE`1UIFD0FUYJ065QH@1OGel0GUiN05UIF@1JFUX0EEEE05eM
G@1EEED0HV9R05mOG`1GEeL0HF5Q05eMG@1JFUX0GemO05iNGP1OGel0G5aL0P1HF5P01`1OGel0HF5Q
05]KF`1NGUh0EUIF061PH01LG5`00P1MGEd02`1DE5@0FUYJ06ATI01SHf<0FEUI05aLG01MGEd0GUiN
061PH01KFe/0DU9B0080G5aL00<0IFEU05]KF`1YJFT00P1OGel03`1QHF40I6AT069RHP1PH600IVIV
05eMG@1TI6@0GUiN05YJFP1LG5`0Fe]K05aLG01TI6@0GEeM061PH002069RHP0305mOG`1VIVH0FUYJ
0080GemO00@0HF5Q06EUI@1UIFD0Fe]K0P1PH6003P1SHf<0HF5Q06ATI01NGUh0I6AT05iNGP1UIFD0
Hf=S061PH01UIFD0J6QX06EUI@1QHF40JFUY0P1PH6003P1RHV80HF5Q05mOG`1RHV80GUiN069RHP1O
Gel0HF5Q061PH01RHV80GEeM06ATI01KFe/0H61P0P1QHF405@1LG5`0GemO061PH01SHf<0GUiN06UY
J@1KFe/0Hf=S05iNGP1HF5P0JVYZ069RHP1TI6@0Hf=S06MWI`1NGUh0IVIV05aLG01NGUh0H61P06AT
I002061PH009069RHP1KFe/0HF5Q065QH@1NGUh0GEeM06EUI@1OGel0HV9R0080I6AT00@0G5aL06QX
J01PH600GemO0P1PH600>01JFUX0H61P05eMG@1RHV80Hf=S06QXJ01JFUX0JFUY06EUI@1JFUX0GemO
065QH@1NGUh0IFEU05YJFP1LG5`0Fe]K05eMG@1RHV80GEeM069RHP1MGEd0F5QH05IFEP1JFUX0G5aL
05QHF01RHV80G5aL05iNGP1RHV80FUYJ06EUI@1KFe/0GemO05eMG@1LG5`0FUYJ061PH01IFET0G5aL
05IFEP1KFe/0FEUI061PH01MGEd0EeMG05IFEP1IFET0EUIF05YJFP1HF5P0HV9R065QH@1LG5`0FEUI
0P1KFe/06`1IFET0GUiN05IFEP1PH600F5QH05YJFP1DE5@0Fe]K065QH@1HF5P0HF5Q05aLG01KFe/0
HF5Q05eMG@1JFUX0Fe]K05EEE@1FEUH0EeMG05]KF`1QHF40GEeM069RHP1LG5`0DU9B05aLG00205iN
GP0;05eMG@1LG5`0GemO05IFEP1OGel0GUiN05mOG`1NGUh0GEeM05MGE`1IFET00`1KFe/05P1PH600
EEEE05mOG`1QHF40GEeM061PH01QHF40GUiN05YJFP1OGel0FUYJ069RHP1QHF40Fe]K061PH01OGel0
HV9R05QHF01IFET0G5aL05UIF@1HF5P50=WIf@8000000@3IfMT001H0fMWI00<000000=WIf@3IfMT0
0`3IfMT01@1IFET0HV9R061PH01IFET0G5aL0080Fe]K01@0GemO05ADE01TI6@0GUiN05YJFP1QHF40
H61P05UIF@1NGUh0G5aL05YJFP1IFET0H61P05]KF`1LG5`0EeMG05QHF01IFET0G5aL05EEE@80GUiN
00D0E5AD05MGE`1JFUX0Hf=S05iNGP0205QHF00I05eMG@1KFe/0FUYJ05]KF`1MGEd0EEEE05]KF`1I
FET0F5QH05YJFP1HF5P0E5AD05iNGP1JFUX0Hf=S05eMG@1IFET0F5QH05aLG01MGEd0FUYJ05]KF`1J
FUX0GemO05QHF00205]KF`0705mOG`1MGEd0HF5Q065QH@1MGEd0F5QH05eMG@0205YJFP0305=CD`1J
FUX0GEeM0080FUYJ00<0H61P05eMG@1MGEd00P1NGUh03P1IFET0HF5Q069RHP1PH600GEeM05mOG`1P
H600EeMG05YJFP1RHV80I6AT069RHP1LG5`0EEEE0P1OGel00`1RHV80Hf=S06=SH`0206=SH`0;05eM
G@1RHV80HF5Q05aLG01TI6@0IfMW05]KF`1SHf<0IVIV05eMG@1]KFd00P1QHF40301SHf<0IfMW065Q
H@1TI6@0GUiN06=SH`1NGUh0G5aL065QH@1SHf<0Jf][061PH080HF5Q00/0Hf=S05mOG`1UIFD0JVYZ
06ATI01SHf<0HV9R05mOG`1SHf<0FUYJ065QH@0206ATI00?06EUI@1MGEd0I6AT05eMG@1SHf<0GemO
065QH@1OGel0IFEU06MWI`1PH600HV9R06IVIP1OGel0IFEU0080HV9R01h0GUiN069RHP1GEeL0IVIV
05aLG01YJFT0I6AT06UYJ@1RHV80GUiN069RHP1XJ6P0HV9R06MWI`1VIVH0IFEU05mOG`1NGUh0HV9R
05eMG@1PH600GemO05aLG01OGel0H61P06IVIP1SHf<0Fe]K069RHP1QHF42061PH00=06=SH`1QHF40
I6AT06ATI01PH600G5aL05]KF`1GEeL0Fe]K05UIF@1SHf<0H61P05eMG@0205aLG00]05UIF@1JFUX0
H61P05eMG@1NGUh0IfMW05QHF01GEeL0GUiN06=SH`1QHF40GUiN05UIF@1UIFD0H61P05EEE@1FEUH0
I6AT05MGE`1DE5@0FEUI061PH01UIFD0GEeM05aLG01NGUh0GemO065QH@1IFET0FUYJ05iNGP1TI6@0
EeMG05eMG@1LG5`0Fe]K05YJFP1MGEd0EeMG05eMG@1KFe/0H61P05UIF@1FEUH0Fe]K0080HV9R00/0
GEeM05UIF@1LG5`0F5QH05IFEP1QHF40EEEE05aLG01SHf<0Fe]K05IFEP0205iNGP0=05aLG01HF5P0
Fe]K05iNGP1MGEd0HF5Q05mOG`1HF5P0De=C05]KF`1GEeL0Hf=S05]KF`0205UIF@0>05]KF`1LG5`0
G5aL05]KF`1NGUh0FUYJ06=SH`1LG5`0GEeM05mOG`1LG5`0Fe]K061PH01JFUX2061PH00@05ADE01O
Gel0GEeM05eMG@1HF5P0FUYJ05]KF`1LG5`0EUIF05QHF01MGEd0H61P05]KF`1EEED0G5aL05YJFPH0
fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0905iNGP1FEUH0GEeM05]KF`1G
EeL0GUiN05YJFP1FEUH0H61P0080FEUI00H0Fe]K05YJFP1DE5@0GEeM05YJFP1PH60205mOG`0405YJ
FP1KFe/0EeMG05]KF`80FEUI0140EeMG05EEE@1FEUH0G5aL05ADE01KFe/0EUIF065QH@1FEUH0GemO
06ATI01MGEd0EeMG05eMG@1EEED0GUiN05eMG@0205UIF@0?05]KF`1HF5P0H61P05]KF`1CDe<0EeMG
05IFEP1QHF40F5QH05MGE`1LG5`0EeMG065QH@1SHf<0FUYJ0080GemO0P1JFUX01P1RHV80Fe]K05mO
G`1PH600HF5Q05mOG`80G5aL0180FEUI05YJFP1KFe/0GEeM05]KF`1NGUh0FEUI05iNGP1OGel0G5aL
061PH01DE5@0FUYJ05mOG`1LG5`0F5QH05]KF`1NGUh206ATI00305mOG`1NGUh0FUYJ0080HF5Q00@0
Fe]K061PH01LG5`0I6AT0`1KFe/04`1PH600GemO06=SH`1ZJVX0GemO05UIF@1KFe/0H61P065QH@1R
HV80IfMW06IVIP1UIFD0HF5Q05mOG`1UIFD0I6AT05iNGP1QHF400P1VIVH02@1YJFT0GEeM065QH@1M
GEd0IFEU06=SH`1MGEd0M7Ad06=SH`0206EUI@0506e]K@1TI6@0H61P05MGE`1QHF400P1OGel01`1Y
JFT0J6QX05]KF`1MGEd0GUiN06EUI@1SHf<00P1NGUh01@1YJFT0Hf=S05eMG@1RHV80Hf=S00<0H61P
03/0Hf=S05iNGP1RHV80G5aL05]KF`1NGUh0GemO061PH01LG5`0Hf=S06ATI01QHF40IVIV06ATI01S
Hf<0GemO05YJFP1SHf<0H61P069RHP1VIVH0GemO061PH01SHf<0GUiN061PH01UIFD0HF5Q061PH01L
G5`0IVIV05YJFP1OGel0GUiN061PH01QHF40GemO05aLG01OGel0IFEU05eMG@1LG5`0FUYJ061PH01R
HV80GemO05aLG01MGEd0G5aL05eMG@1OGel0G5aL069RHP1JFUX0GEeM05]KF`1VIVH0FUYJ05mOG`02
05aLG00905eMG@1UIFD0HF5Q05MGE`1NGUh0GemO05MGE`1TI6@0GemO0080Fe]K02/0E5AD05eMG@1G
EeL0GemO05eMG@1HF5P0Fe]K05UIF@1BDU80G5aL05]KF`1PH600F5QH05iNGP1IFET0Fe]K05mOG`1M
GEd0EEEE05MGE`1NGUh0G5aL05eMG@1LG5`0GEeM05ADE01FEUH0Fe]K05iNGP1EEED0GemO05IFEP1I
FET0FUYJ061PH01KFe/0G5aL05UIF@1EEED0DU9B05MGE`1KFe/0GEeM0080HV9R00L0G5aL05IFEP1H
F5P0FEUI05]KF`1QHF40EUIF0080G5aL01d0EEEE05QHF01IFET0EUIF061PH01NGUh0EeMG05aLG01P
H600E5AD05mOG`1MGEd0EeMG05UIF@1KFe/0H61P05aLG01PH600GemO06=SH`1JFUX0I6AT05aLG01K
Fe/0FUYJ04m?C`1KFe/0F5QH05mOG`060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT0
0`3IfMT01P1HF5P0G5aL05mOG`1JFUX0GEeM05UIF@80F5QH0180G5aL05UIF@1KFe/0GEeM05aLG01I
FET0EEEE06=SH`1LG5`0FEUI05aLG01FEUH0F5QH061PH01MGEd0G5aL05iNGP1LG5`305UIF@0605mO
G`1MGEd0H61P05UIF@1NGUh0FUYJ0P1IFET02P1MGEd0FEUI05iNGP1IFET0GEeM05QHF01JFUX0FEUI
05mOG`1JFUX205eMG@80FEUI00<0EUIF05EEE@1LG5`00P1JFUX03@1PH600FUYJ05YJFP1VIVH0FUYJ
05ADE01MGEd0FUYJ05eMG@1LG5`0HF5Q05iNGP1RHV800P1MGEd07`1IFET0GEeM055AD@1HF5P0G5aL
05mOG`1MGEd0HF5Q05mOG`1QHF40GemO05aLG01NGUh0H61P065QH@1IFET0Fe]K05eMG@1KFe/0GemO
06ATI01MGEd0IVIV06=SH`1RHV80EUIF069RHP1MGEd0HV9R065QH@1JFUX00P1SHf<09@1TI6@0IFEU
05QHF01TI6@0H61P069RHP1VIVH0I6AT06EUI@1QHF40G5aL06ATI01OGel0HF5Q06=SH`1HF5P0IVIV
065QH@1UIFD0HV9R06UYJ@1TI6@0HF5Q06=SH`1WIfL0GemO069RHP1SHf<0GUiN05mOG`1YJFT0IVIV
05mOG`1KFe/0H61P069RHP1OGel00P1QHF406P1TI6@0GUiN05aLG01QHF40IVIV06EUI@1QHF40GUiN
061PH01VIVH0HV9R061PH01SHf<0HV9R05mOG`1RHV80I6AT05QHF01QHF40GemO065QH@1SHf<0HV9R
065QH@1SHf<0IVIV0P1JFUX01P1PH600G5aL065QH@1QHF40GemO06ATI080GEeM0P1QHF405`1TI6@0
HF5Q05aLG01SHf<0GEeM069RHP1/K6`0GemO069RHP1KFe/0GUiN06ATI01QHF40FEUI05]KF`1MGEd0
HV9R05aLG01PH600GUiN05]KF`1IFET0Fe]K0080GEeM01@0GUiN06ATI01UIFD0GUiN05mOG`1KFe/0
HF5Q05iNGP1RHV80G5aL05]KF`1FEUH0Fe]K065QH@1UIFD0G5aL05UIF@1JFUX0FEUI05QHF080H61P
00D0GUiN05eMG@1NGUh0H61P065QH@0205eMG@0;05aLG01MGEd0HF5Q06ATI01EEED0CTi>05IFEP1L
G5`0Fe]K05eMG@1LG5`00P1EEED0@P1QHF40EeMG05QHF01EEED0Fe]K05YJFP1KFe/0H61P05YJFP1K
Fe/0EeMG05YJFP1PH600E5AD05UIF@1MGEd0EeMG05YJFP1CDe<0F5QH05eMG@1HF5P0EeMG05aLG01J
FUX0EEEE05]KF`1GEeL0FUYJ05]KF`1SHf<0GemO05eMG@1OGel0FUYJ05EEE@1JFUX0GEeM05aLG01N
GUh0EeMG05iNGP1OGel0H61P05QHF01KFe/0FEUI05QHF01JFUX0F5QH05EEE@1JFUX0F5QH05iNGP1K
Fe/0GemO05MGE`1HF5P0G5aL05YJFP1NGUh0HV9R05UIF@1JFUX0EEEE065QH@H0fMWI0@0000010=WI
f@005P3IfMT00`000000fMWI0=WIf@030=WIf@0B05]KF`1IFET0FEUI05]KF`1OGel0HF5Q05aLG01K
Fe/0FEUI05QHF01NGUh0H61P05]KF`1UIFD0GemO05iNGP1TI6@0IVIV0P1JFUX00`1PH600CTi>05EE
E@0205aLG00=05mOG`1MGEd0H61P05UIF@1FEUH0H61P05aLG01IFET0GemO05EEE@1BDU80GUiN05eM
G@0205iNGP0R05UIF@1QHF40J6QX061PH01GEeL0G5aL061PH01OGel0Fe]K059BDP1SHf<0GemO069R
HP1GEeL0FEUI069RHP1MGEd0Fe]K05YJFP1LG5`0F5QH05aLG01RHV80Hf=S06ATI01KFe/0FEUI05eM
G@1GEeL0GemO05]KF`1JFUX0EEEE05YJFP80F5QH00L0H61P05aLG01LG5`0GUiN05eMG@1JFUX0GEeM
0080GemO0100FEUI05aLG01KFe/0GemO05iNGP1PH600GUiN06QXJ01PH600GUiN06ATI01PH600G5aL
069RHP1PH600GUiN0P1OGel01`1RHV80GUiN05QHF01OGel0GUiN061PH01WIfL00P1PH602065QH@09
06MWI`1MGEd0G5aL05iNGP1MGEd0Hf=S065QH@1WIfL0HF5Q0080H61P00D0Hf=S06IVIP1QHF40EeMG
05mOG`02069RHP0406=SH`1QHF40G5aL06ATI080HV9R00@0GemO06ATI01QHF40GEeM0P1PH6002@1Q
HF40FUYJ069RHP1RHV80Hf=S061PH01YJFT0GUiN065QH@02061PH00d06ATI01YJFT0HF5Q05]KF`1S
Hf<0G5aL06IVIP1QHF40GUiN061PH01LG5`0GemO05eMG@1RHV80HF5Q05mOG`1PH600HV9R06=SH`1R
HV80H61P05]KF`1NGUh0G5aL05]KF`1LG5`0IFEU069RHP1OGel0H61P05eMG@1JFUX0HV9R05]KF`1L
G5`0Hf=S069RHP1UIFD0GEeM061PH01KFe/0FEUI05mOG`1KFe/0GUiN06ATI01FEUH0F5QH05iNGP1S
Hf<0GEeM061PH080GUiN02L0H61P05aLG01SHf<0Hf=S05eMG@1GEeL0GemO05QHF01KFe/0FUYJ05mO
G`1CDe<0HV9R05eMG@1JFUX0GemO05MGE`1OGel0GEeM061PH01RHV80FUYJ05eMG@1GEeL0GUiN059B
DP1JFUX0Fe]K05iNGP1RHV80EEEE05eMG@1KFe/0G5aL05UIF@1NGUh0EUIF06IVIP1NGUh00P1LG5`0
4P1BDU80F5QH05aLG01KFe/0GEeM05aLG01KFe/0DU9B05QHF01NGUh0Fe]K05=CD`1BDU80GEeM05]K
F`1DE5@0F5QH05EEE@80FUYJ00@0EeMG05]KF`1GEeL0H61P0P1HF5P04@1DE5@0De=C05YJFP1FEUH0
F5QH05mOG`1IFET0GemO05]KF`1RHV80FEUI061PH01OGel0F5QH05MGE`1MGEd0GemO00D0FUYJ00/0
Hf=S05QHF01UIFD0Fe]K05aLG01RHV80G5aL061PH01OGel0FUYJ05eMG@02065QH@0305]KF`1EEED0
G5aL00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0405]KF`1MGEd0EUIF
05aLG080Fe]K02P0GUiN05eMG@1HF5P0Fe]K065QH@1HF5P0FUYJ05QHF01PH600I6AT06YZJP1LG5`0
FUYJ05aLG01KFe/0F5QH065QH@1CDe<0F5QH05YJFP1QHF40GUiN05IFEP1LG5`0Hf=S05iNGP1MGEd0
FUYJ05eMG@1OGel0HV9R05]KF`1IFET0GemO05MGE`1EEED0Fe]K05MGE`1LG5`0EUIF0P1JFUX01@1M
GEd0GUiN05QHF01LG5`0FEUI0080GEeM01X0FEUI05MGE`1IFET0GUiN055AD@1EEED0F5QH05aLG01O
Gel0GEeM05mOG`1LG5`0FEUI05YJFP1QHF40GUiN065QH@1NGUh0EEEE05mOG`1NGUh0GEeM05]KF`1J
FUX0GUiN05mOG`80Fe]K00P0IFEU061PH01LG5`0FUYJ05mOG`1JFUX0GUiN06ATI080GUiN00/0FEUI
06=SH`1TI6@0GEeM05UIF@1OGel0FUYJ05MGE`1IFET0GUiN05aLG00206EUI@0L06ATI01JFUX0GEeM
06=SH`1WIfL0GemO06EUI@1XJ6P0H61P06=SH`1UIFD0Hf=S05mOG`1QHF40G5aL05iNGP1UIFD0HV9R
05iNGP1OGel0H61P05eMG@1LG5`0GemO05]KF`1UIFD0GemO06=SH`80IVIV00l0HV9R05]KF`1SHf<0
HV9R06MWI`1LG5`0H61P05mOG`1RHV80IfMW06=SH`1KFe/0GUiN06EUI@1IFET00P1OGel0201PH600
HF5Q065QH@1TI6@0Hf=S061PH01QHF40Hf=S0P1UIFD06`1IFET0HV9R065QH@1UIFD0GUiN06=SH`1P
H600I6AT061PH01QHF40HV9R05aLG01PH600GemO065QH@1RHV80FUYJ05aLG01QHF40GUiN06][J`1T
I6@0FEUI06IVIP1PH600HF5Q05iNGP02061PH00705eMG@1TI6@0GemO05YJFP1IFET0GemO05MGE`02
05]KF`0A065QH@1KFe/0Fe]K05IFEP1EEED0GEeM05aLG01NGUh0EEEE05mOG`1MGEd0I6AT05mOG`1S
Hf<0G5aL06EUI@1QHF400P1OGel0101KFe/0FEUI05aLG01OGel205UIF@0<06=SH`1OGel0FUYJ05eM
G@1GEeL0FUYJ05iNGP1QHF40FUYJ05aLG01KFe/0GemO0P1JFUX205MGE`0305eMG@1FEUH0FEUI0080
FEUI00@0GEeM05aLG01GEeL0FEUI0P1JFUX03`1IFET0GEeM05EEE@1EEED0HF5Q05MGE`1KFe/0EEEE
05iNGP1KFe/0FUYJ05=CD`1LG5`0GEeM05iNGP0205MGE`0D05iNGP1FEUH0EeMG05iNGP1IFET0DE5A
05MGE`1JFUX0G5aL05]KF`1NGUh0EeMG05QHF01JFUX0GEeM05MGE`1KFe/0FEUI05MGE`1HF5P205YJ
FP0705mOG`1LG5`0G5aL05mOG`1SHf<0GEeM05QHF00205IFEP0505]KF`1OGel0GUiN05iNGP1KFe/0
0P1OGel01P1MGEd0F5QH05mOG`1KFe/0GEeM05UIF@H0fMWI0@0000010=WIf@005P3IfMT00`000000
fMWI0=WIf@030=WIf@0705EEE@1IFET0FUYJ05UIF@1PH600GemO05YJFP0205aLG00O069RHP1KFe/0
FEUI05EEE@1LG5`0I6AT061PH01QHF40HV9R065QH@1LG5`0H61P05aLG01JFUX0GUiN05UIF@1QHF40
EUIF05UIF@1QHF40Fe]K05YJFP1PH600GemO05YJFP1HF5P0GEeM05QHF01EEED0EUIF05eMG@0205]K
F`1805aLG01KFe/0FUYJ05]KF`1LG5`0Fe]K05UIF@1NGUh0GemO05UIF@1KFe/0E5AD05aLG01FEUH0
IFEU05eMG@1LG5`0HF5Q05mOG`1IFET0G5aL061PH01LG5`0E5AD05UIF@1LG5`0Fe]K05iNGP1MGEd0
GemO05UIF@1LG5`0H61P05MGE`1HF5P0GemO05YJFP1OGel0GUiN05QHF01NGUh0G5aL05iNGP1UIFD0
GUiN05UIF@1PH600G5aL05]KF`1NGUh0G5aL06=SH`1PH600Hf=S05eMG@1VIVH0H61P069RHP1SHf<0
H61P05mOG`1QHF40HV9R05eMG@1GEeL0HF5Q061PH01NGUh0EEEE05mOG`1WIfL0GUiN0`1TI6@02`1R
HV80Hf=S065QH@1TI6@0Hf=S065QH@1UIFD0I6AT05aLG01SHf<0IVIV0080HV9R00H0Hf=S06UYJ@1]
KFd0I6AT065QH@1EEED2061PH00?065QH@1PH600I6AT06ATI01PH600IVIV06EUI@1TI6@0IVIV05iN
GP1TI6@0IfMW065QH@1RHV80H61P0080J6QX00l0Hf=S06IVIP1OGel0JFUY05]KF`1RHV80H61P05eM
G@1TI6@0IfMW05mOG`1SHf<0G5aL06=SH`1QHF400P1LG5`2065QH@0?06MWI`1TI6@0GEeM05eMG@1Q
HF40IVIV05mOG`1LG5`0H61P05UIF@1QHF40EUIF06EUI@1PH600HV9R0080H61P00<0GEeM05UIF@1X
J6P00P1LG5`02P1KFe/0HV9R05iNGP1QHF40GEeM05MGE`1SHf<0FEUI05iNGP1KFe/2069RHP0905aL
G01JFUX0HV9R05QHF01MGEd0Fe]K05iNGP1OGel0GUiN0080GEeM00L0HF5Q05YJFP1TI6@0FUYJ05iN
GP1JFUX0GemO0080GEeM00<0Fe]K05aLG01JFUX00P1GEeL00`1IFET0FUYJ05]KF`0205mOG`0H05iN
GP1EEED0GemO05aLG01HF5P0FEUI05mOG`1LG5`0GEeM05]KF`1NGUh0HF5Q05iNGP1GEeL0Fe]K05aL
G01IFET0Fe]K05UIF@1JFUX0EUIF05UIF@1OGel0FEUI0P1JFUX02@1CDe<0G5aL05YJFP1JFUX0GEeM
05]KF`1ADE40DU9B05YJFP0205IFEP0305QHF01IFET0EUIF0080FEUI00L0I6AT05IFEP1KFe/0FUYJ
05aLG01NGUh0FEUI0080E5AD00<0H61P05YJFP1GEeL00`1JFUX0101GEeL0E5AD05YJFP1GEeL205UI
F@0=05aLG01NGUh0FUYJ05IFEP1DE5@0F5QH05UIF@1PH600FUYJ05UIF@1LG5`0GEeM05]KF`060=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT09P1OGel0Fe]K05YJFP1KFe/0GUiN
05MGE`1LG5`0GEeM05MGE`1MGEd0Fe]K05MGE`1QHF40Fe]K05eMG@1SHf<0GEeM061PH01NGUh0I6AT
05eMG@1PH600FUYJ05MGE`1HF5P0I6AT05mOG`1MGEd0H61P05]KF`1PH600EEEE05QHF01MGEd0G5aL
05]KF`1JFUX0H61P0P1JFUX01@1MGEd0Fe]K05ADE01LG5`0GEeM00<0FUYJ00T0EeMG05YJFP1IFET0
G5aL05eMG@1LG5`0EeMG059BDP1HF5P00P1JFUX06`1OGel0FUYJ05iNGP1KFe/0HV9R05iNGP1IFET0
FUYJ061PH01LG5`0De=C05YJFP1HF5P0HF5Q05YJFP1RHV80FUYJ05QHF01NGUh0GemO065QH@1PH600
G5aL05QHF01OGel0FEUI05QHF00205mOG`0605YJFP1VIVH0GUiN06=SH`1MGEd0FUYJ0P1OGel01@1J
FUX0I6AT065QH@1SHf<0HF5Q0080GEeM00d0GUiN05]KF`1QHF40GEeM069RHP1SHf<0HF5Q061PH01U
IFD0HV9R06ATI01UIFD0HV9R0080FEUI00P0IFEU06=SH`1OGel0GemO05iNGP1PH600IFEU05mOG`80
Hf=S00D0HF5Q05iNGP1PH600Hf=S06EUI@02065QH@0405mOG`1RHV80G5aL06=SH`80GemO00h0H61P
05iNGP1PH600HV9R05]KF`1SHf<0G5aL06=SH`1UIFD0IVIV06EUI@1PH600IFEU05eMG@80HV9R00P0
GEeM06ATI01QHF40H61P06QXJ01SHf<0FUYJ05eMG@80G5aL00D0GemO065QH@1WIfL0HF5Q05]KF`02
05mOG`0305eMG@1TI6@0IFEU0080GUiN00h0HF5Q05iNGP1LG5`0GEeM06ATI01OGel0GEeM05aLG01P
H600GUiN05MGE`1KFe/0H61P05YJFP80GUiN00T0Fe]K061PH01HF5P0HV9R05]KF`1NGUh0GemO05aL
G01TI6@00P1PH60205]KF`0405IFEP1NGUh0IVIV069RHP80GemO00T0HF5Q05aLG01MGEd0IVIV05UI
F@1GEeL0GUiN05ADE01MGEd00P1LG5`0301HF5P0GUiN05mOG`1QHF40H61P05aLG01MGEd0EeMG05aL
G01HF5P0G5aL05QHF080EeMG03D0GemO05YJFP1HF5P0FEUI06=SH`1GEeL0GEeM05iNGP1JFUX0GEeM
05QHF01ADE40GemO05EEE@1HF5P0G5aL05iNGP1OGel0EeMG05aLG01FEUH0Fe]K05ADE01EEED0DU9B
05IFEP1DE5@0GemO05QHF01QHF40EUIF05aLG01GEeL0F5QH05IFEP1DE5@0FEUI05QHF01FEUH0GEeM
05MGE`1ADE40G5aL05UIF@1HF5P0EEEE05UIF@1GEeL0GemO05iNGP1FEUH0Fe]K061PH00205MGE`0D
065QH@1EEED0GEeM05MGE`1MGEd0Fe]K069RHP1JFUX0G5aL05QHF01DE5@0F5QH05eMG@1PH600FEUI
05iNGP1PH600Fe]K05eMG@1HF5P60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3I
fMT03P1NGUh0G5aL061PH01JFUX0GemO05iNGP1GEeL0De=C05QHF01LG5`0FEUI061PH01MGEd0Fe]K
0P1SHf<00`1TI6@0F5QH05]KF`0205]KF`0405eMG@1LG5`0GEeM05UIF@80Fe]K01@0FUYJ05]KF`1N
GUh0FEUI05EEE@1FEUH0Fe]K069RHP1IFET0G5aL05iNGP1HF5P0GEeM05MGE`1JFUX0F5QH05UIF@1L
G5`0GUiN061PH080FUYJ0P1HF5P02@1LG5`0EUIF05UIF@1LG5`0F5QH05UIF@1OGel0EeMG05UIF@02
05MGE`0C05EEE@1NGUh0E5AD05mOG`1KFe/0G5aL05UIF@1PH600F5QH05YJFP1LG5`0HV9R05eMG@1N
GUh0J6QX05]KF`1MGEd0HF5Q05YJFP0205aLG00705eMG@1TI6@0GUiN06=SH`1UIFD0GEeM05aLG002
05mOG`0A05]KF`1MGEd0GemO06=SH`1PH600HF5Q05eMG@1LG5`0FUYJ05mOG`1PH600GemO05aLG01T
I6@0Fe]K05aLG01PH6000P1LG5`01`1SHf<0I6AT06EUI@1NGUh0J6QX05UIF@1VIVH00`1RHV802P1Q
HF40H61P06ATI01KFe/0FUYJ061PH01VIVH0I6AT05mOG`1NGUh206ATI00<05mOG`1PH600GemO05mO
G`1NGUh0Fe]K05aLG01MGEd0Hf=S069RHP1MGEd0IfMW0P1OGel03P1PH600J6QX05iNGP1TI6@0IFEU
06IVIP1PH600GemO05]KF`1SHf<0Fe]K061PH01LG5`0FEUI0P1LG5`02P1WIfL0HV9R065QH@1MGEd0
GemO06=SH`1MGEd0HV9R06MWI`1MGEd206=SH`0D06MWI`1KFe/0I6AT06EUI@1KFe/0HV9R05mOG`1R
HV80Hf=S061PH01QHF40G5aL069RHP1IFET0GUiN05QHF01PH600GemO05aLG01SHf<205mOG`0305eM
G@1RHV80HF5Q0080GEeM02X0G5aL05mOG`1NGUh0G5aL05MGE`1LG5`0GEeM05UIF@1OGel0GUiN05UI
F@1GEeL0Fe]K061PH01JFUX0GemO061PH01TI6@0Fe]K061PH01RHV80GEeM05YJFP1QHF40GEeM06EU
I@1OGel0IVIV05iNGP1QHF40GemO05eMG@1RHV80De=C05YJFP1MGEd0Fe]K05iNGP1SHf<0GUiN05UI
F@1EEED205mOG`0S05IFEP1CDe<0GUiN05QHF01TI6@0HF5Q05UIF@1MGEd0GemO05MGE`1EEED0GUiN
05YJFP1IFET0Fe]K05eMG@1FEUH0EEEE05=CD`1EEED0EeMG05mOG`1DE5@0Fe]K05eMG@1EEED0EeMG
05YJFP1FEUH0Cdm?05EEE@1IFET0EUIF05aLG01EEED00P1CDe<205YJFP0<05MGE`1FEUH0GUiN05MG
E`1LG5`0EEEE05eMG@1JFUX0EUIF05iNGP1JFUX0Fe]K0P1MGEd03`1BDU80Fe]K059BDP1HF5P0EUIF
061PH01HF5P0FEUI05eMG@1GEeL0Fe]K05MGE`1PH600EUIF05UIF@060=WIf@4000000@3IfMT001H0
fMWI00<000000=WIf@3IfMT00`3IfMT07@1MGEd0HV9R05eMG@1LG5`0GUiN05IFEP1@D500IfMW065Q
H@1MGEd0Fe]K05UIF@1QHF40Hf=S05YJFP1NGUh0EeMG05]KF`1OGel0H61P05YJFP1MGEd0FEUI061P
H01HF5P0GemO05UIF@1HF5P0DU9B0080FUYJ00L0FEUI05mOG`1MGEd0GEeM05MGE`1OGel0G5aL0080
GUiN00<0EEEE05ADE01KFe/00P1NGUh01P1LG5`0FUYJ05iNGP1CDe<0FEUI05IFEP80GEeM00X0GUiN
05]KF`1LG5`0EEEE05ADE01LG5`0FUYJ05]KF`1JFUX0Fe]K0P1RHV807`1NGUh0HF5Q05aLG01PH600
F5QH05YJFP1NGUh0FEUI065QH@1UIFD0FUYJ065QH@1FEUH0GemO069RHP1QHF40GemO05aLG01KFe/0
H61P05]KF`1LG5`0FEUI05mOG`1LG5`0H61P05]KF`1PH600GEeM05IFEP1LG5`00P1PH6001`1OGel0
Fe]K061PH01QHF40H61P06ATI01LG5`00P1OGel02P1XJ6P0GEeM05eMG@1PH600GemO069RHP1SHf<0
IfMW069RHP1GEeL205iNGP0605QHF01RHV80HV9R06ATI01PH600HV9R0P1TI6@02`1OGel0IVIV05mO
G`1JFUX0I6AT06a/K01RHV80GUiN069RHP1MGEd0GemO0080HF5Q00l0H61P069RHP1UIFD0HF5Q05mO
G`1GEeL0GUiN061PH01IFET0IfMW06UYJ@1SHf<0IFEU05mOG`1TI6@00P1NGUh02P1LG5`0IVIV06IV
IP1JFUX0GEeM05mOG`1UIFD0HF5Q069RHP1SHf<205mOG`0H061PH01SHf<0G5aL061PH01OGel0GUiN
05mOG`1YJFT0HF5Q061PH01TI6@0HF5Q06=SH`1TI6@0Hf=S065QH@1OGel0FUYJ05eMG@1PH600GemO
05iNGP1PH600FUYJ0P1LG5`01P1HF5P0H61P05iNGP1IFET0Hf=S05mOG`80FEUI0P1NGUh0:`1XJ6P0
FUYJ05iNGP1FEUH0FEUI065QH@1OGel0Fe]K05aLG01IFET0Fe]K061PH01IFET0GUiN05aLG01NGUh0
F5QH06=SH`1MGEd0GemO05]KF`1LG5`0Fe]K069RHP1OGel0EUIF05mOG`1IFET0H61P05QHF01PH600
EeMG061PH01IFET0FUYJ05aLG01PH600EeMG05QHF01MGEd0GemO065QH@1EEED00P1IFET205iNGP0?
05]KF`1IFET0Fe]K05QHF01GEeL0GemO05iNGP1KFe/0F5QH05ADE01CDe<0FUYJ05iNGP1FEUH0EeMG
0080E5AD00<0G5aL05YJFP1IFET00P1KFe/00`1IFET0Fe]K05QHF00205EEE@0E05aLG01HF5P0Fe]K
05aLG01CDe<0EeMG05]KF`1FEUH0HF5Q05YJFP1PH600GEeM05aLG01IFET0EeMG05]KF`1LG5`0F5QH
05EEE@1KFe/0FUYJ0080GUiN00<0G5aL05MGE`1NGUh00P1HF5P205IFEP0505aLG01MGEd0EEEE05UI
F@1JFUX01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00l0EeMG05eMG@1G
EeL0F5QH05mOG`1GEeL0EUIF05eMG@1OGel0FUYJ05QHF01OGel0EeMG06IVIP1HF5P00P1MGEd05@1N
GUh0Fe]K05IFEP1PH600Fe]K05QHF01KFe/0G5aL05UIF@1OGel0FUYJ06MWI`1PH600FUYJ05IFEP1I
FET0HF5Q05eMG@1OGel0GUiN06=SH`0205aLG00=05]KF`1MGEd0G5aL05iNGP1MGEd0H61P05=CD`1G
EeL0FEUI05=CD`1HF5P0H61P05MGE`0205UIF@0605YJFP1QHF40DU9B05YJFP1MGEd0Fe]K0P1OGel0
3P1GEeL0G5aL05iNGP1LG5`0F5QH05]KF`1OGel0E5AD05aLG01IFET0FUYJ05eMG@1OGel0Hf=S0P1P
H6000`1KFe/0FEUI05mOG`02065QH@0705MGE`1MGEd0F5QH05mOG`1MGEd0HF5Q05eMG@02061PH00A
069RHP1NGUh0I6AT05iNGP1MGEd0De=C05eMG@1QHF40FEUI065QH@1VIVH0F5QH069RHP1JFUX0H61P
05YJFP1RHV800P1LG5`07`1PH600JFUY06UYJ@1HF5P0IfMW06=SH`1QHF40H61P05YJFP1LG5`0HF5Q
06ATI01IFET0HF5Q05eMG@1NGUh0Hf=S065QH@1KFe/0HF5Q05YJFP1KFe/0I6AT06QXJ01UIFD0HF5Q
06IVIP1LG5`0HV9R06=SH`1LG5`00P1UIFD04@1RHV80H61P06=SH`1PH600Fe]K05EEE@1MGEd0HV9R
06ATI01PH600HF5Q06ATI01SHf<0H61P06QXJ01ZJVX0GUiN0080HF5Q00l0JFUY05]KF`1YJFT0GemO
065QH@1OGel0Fe]K05mOG`1MGEd0G5aL061PH01JFUX0GemO06=SH`1JFUX00`1MGEd0201XJ6P0GemO
05aLG01TI6@0HF5Q05iNGP1TI6@0IFEU0P1RHV800`1XJ6P0GEeM05mOG`0205eMG@0@05UIF@1NGUh0
G5aL05iNGP1KFe/0H61P059BDP1EEED0GUiN05]KF`1JFUX0GUiN05QHF01LG5`0E5AD05iNGP80GEeM
00@0EUIF05mOG`1JFUX0HF5Q0P1OGel0101KFe/0G5aL05aLG01KFe/205eMG@0C05aLG01PH600GemO
05aLG01MGEd0FUYJ065QH@1TI6@0HF5Q05aLG01JFUX0G5aL05UIF@1JFUX0EeMG05iNGP1IFET0Fe]K
05iNGP0205mOG`0305]KF`1GEeL0H61P0080FUYJ02<0FEUI05MGE`1FEUH0FEUI061PH01KFe/0FEUI
05IFEP1HF5P0G5aL05ADE01OGel0GUiN05MGE`1IFET0Fe]K061PH01JFUX0EEEE05ADE01JFUX0E5AD
05UIF@1MGEd0F5QH05ADE01QHF40G5aL05YJFP1DE5@0EUIF061PH01OGel0D51@05iNGP0205]KF`04
05IFEP1EEED0FEUI05UIF@80Fe]K00D0F5QH05IFEP1DE5@0G5aL05eMG@02061PH00305UIF@1KFe/0
DU9B0080EEEE0P1IFET205]KF`0305IFEP1KFe/0fMWI00D0fMWI0@0000010=WIf@005P3IfMT00`00
0000fMWI0=WIf@030=WIf@0T05QHF01LG5`0G5aL05UIF@1QHF40FUYJ051@D01QHF40FUYJ05QHF01B
DU80F5QH05YJFP1PH600F5QH05EEE@1IFET0E5AD05eMG@1FEUH0GemO05eMG@1PH600G5aL05QHF01N
GUh0G5aL05iNGP1FEUH0EeMG05aLG01EEED0HF5Q05=CD`1IFET0GemO0P1LG5`0701NGUh0EUIF05QH
F01LG5`0Hf=S05IFEP1NGUh0GemO05eMG@1LG5`0FUYJ05MGE`1QHF40FEUI05QHF01GEeL0GEeM05UI
F@1LG5`0DU9B065QH@1JFUX0F5QH05iNGP1BDU80GemO05IFEP1RHV8205iNGP0505]KF`1HF5P0GEeM
05YJFP1NGUh00P1PH6008`1OGel0H61P05eMG@1PH600G5aL05mOG`1LG5`0GUiN05aLG01QHF40Fe]K
05eMG@1KFe/0GemO06=SH`1RHV80HF5Q05mOG`1NGUh0HF5Q06=SH`1RHV80GEeM069RHP1JFUX0EUIF
05mOG`1QHF40I6AT06QXJ01PH600Hf=S06IVIP1OGel0GUiN0080HV9R00`0IfMW05YJFP1QHF40G5aL
05iNGP1MGEd0GUiN06MWI`1RHV80H61P06MWI`1TI6@2069RHP0J06EUI@1KFe/0HV9R05UIF@1JFUX0
H61P069RHP1JFUX0GUiN06=SH`1XJ6P0I6AT06=SH`1WIfL0H61P05UIF@1TI6@0IfMW069RHP1KFe/0
GemO05IFEP1PH600I6AT061PH01OGel2061PH004065QH@1NGUh0IfMW069RHP80HF5Q03X0Hf=S06EU
I@1QHF40HV9R06ATI01RHV80FEUI05]KF`1RHV80IFEU065QH@1RHV80GEeM06ATI01RHV80GEeM06=S
H`1PH600HV9R05]KF`1PH600G5aL06EUI@1MGEd0HV9R05UIF@1OGel0EEEE05aLG01QHF40GUiN05eM
G@1FEUH0GemO06EUI@1QHF40GemO05eMG@1TI6@0GemO065QH@1GEeL0I6AT05mOG`1MGEd0GemO05IF
EP1OGel0G5aL05UIF@1PH600IVIV05mOG`1IFET0GUiN061PH01DE5@0G5aL0P1KFe/02`1MGEd0F5QH
05MGE`1OGel0EUIF05mOG`1JFUX0GEeM05QHF01OGel0Fe]K0080GUiN00L0F5QH05eMG@1HF5P0GEeM
05YJFP1MGEd0F5QH0080FUYJ01D0EUIF05mOG`1MGEd0FUYJ05mOG`1LG5`0H61P05eMG@1LG5`0EeMG
05UIF@1MGEd0E5AD05QHF01GEeL0EUIF05EEE@1QHF40F5QH05]KF`1HF5P00P1DE5@0;@1IFET0EeMG
05QHF01@D500FUYJ05aLG01ADE40FUYJ055AD@1JFUX0EUIF05eMG@1PH600G5aL05QHF01JFUX0FEUI
06ATI01FEUH0EEEE05eMG@1GEeL0GUiN05]KF`1QHF40Fe]K05YJFP1BDU80FEUI05eMG@1HF5P0De=C
05]KF`1LG5`0EeMG05YJFP1EEED0FEUI05YJFP1IFET0EeMG05EEE@1FEUH0GEeM059BDP0205IFEP03
05ADE01IFET0fMWI00D0fMWI0@0000010=WIf@005P3IfMT2000000@0fMWI01H0GEeM05IFEP1CDe<0
EeMG05iNGP1JFUX0EeMG05]KF`1MGEd0GUiN05YJFP1FEUH0FEUI05iNGP1JFUX0Hf=S05QHF01NGUh0
FUYJ05EEE@1NGUh0EEEE0P1OGel0601RHV80GUiN05MGE`1KFe/0HF5Q05IFEP1OGel0F5QH061PH01M
GEd0Fe]K05eMG@1PH600GEeM05aLG01CDe<0I6AT069RHP1KFe/0H61P05YJFP1IFET0HV9R05IFEP80
FEUI00l0GemO05YJFP1MGEd0GEeM05iNGP1MGEd0HF5Q05QHF01JFUX0FEUI05QHF01OGel0FEUI05MG
E`1KFe/00P1NGUh03@1FEUH0EEEE05iNGP1HF5P0GEeM05EEE@1PH600GUiN05QHF01IFET0GemO05UI
F@1LG5`00P1RHV804@1MGEd0F5QH06ATI01JFUX0Fe]K05mOG`1RHV80H61P05UIF@1RHV80GEeM05]K
F`1PH600G5aL05mOG`1PH600HF5Q0080Fe]K00@0I6AT06][J`1GEeL0GUiN0P1PH6002`1LG5`0Fe]K
069RHP1OGel0IFEU06ATI01IFET0IfMW061PH01WIfL0I6AT0080IfMW00l0I6AT061PH01PH600HF5Q
061PH01TI6@0G5aL06=SH`1QHF40GUiN065QH@1KFe/0GEeM069RHP1TI6@00P1QHF40301TI6@0H61P
06EUI@1YJFT0HF5Q069RHP1KFe/0Hf=S05eMG@1QHF40IFEU05QHF080GemO05/0GEeM061PH01MGEd0
GEeM05iNGP1HF5P0J6QX05iNGP1OGel0H61P06=SH`1NGUh0FUYJ05eMG@1RHV80I6AT05eMG@1RHV80
Fe]K06=SH`1NGUh0IfMW069RHP1UIFD0H61P069RHP1QHF40G5aL06QXJ01LG5`0Hf=S061PH01MGEd0
Hf=S05mOG`1MGEd0HV9R05mOG`1LG5`0H61P05iNGP1RHV80FUYJ05aLG01IFET0GemO06=SH`1KFe/0
I6AT05aLG01KFe/0GUiN05UIF@1JFUX0GemO05UIF@1MGEd0FEUI05QHF01SHf<0H61P065QH@1NGUh0
HV9R061PH01HF5P0Hf=S069RHP1MGEd0FEUI05QHF01QHF40H61P05UIF@1TI6@0FEUI05YJFP1HF5P0
G5aL05EEE@1JFUX0FEUI05]KF`1NGUh0E5AD05iNGP1OGel0EUIF05iNGP1GEeL0FEUI0080Fe]K00X0
IVIV05iNGP1PH600FUYJ05MGE`1OGel0F5QH05YJFP1EEED0GEeM0P1IFET0901JFUX0EUIF05MGE`1Q
HF40FUYJ05EEE@1JFUX0DE5A05YJFP1BDU80H61P05IFEP1KFe/0FUYJ05UIF@1FEUH0GEeM065QH@1E
EED0De=C05EEE@1HF5P0DU9B05IFEP1CDe<0EEEE05UIF@1HF5P0EEEE05UIF@1FEUH0G5aL065QH@1H
F5P0EUIF05UIF@80G5aL00l0E5AD05EEE@1DE5@0EUIF05EEE@1IFET0G5aL065QH@1PH600EEEE05aL
G01OGel0Fe]K05QHF01FEUH00P1IFET00`1KFe/0EEEE05]KF`050=WIf@8000000@3IfMT001H0fMWI
00<000000=WIf@3IfMT00`3IfMT00`1LG5`0GUiN06IVIP0205]KF`0305eMG@1EEED0GEeM0080G5aL
01T0F5QH05IFEP1RHV80G5aL05YJFP1LG5`0HF5Q05YJFP1LG5`0EUIF05QHF01KFe/0GEeM05=CD`1G
EeL0GemO05]KF`1NGUh0Fe]K05mOG`1MGEd0F5QH05aLG01OGel0GUiN0080FUYJ01d0EEEE06=SH`1F
EUH0GUiN05UIF@1RHV80GemO05=CD`1LG5`0D51@05QHF01JFUX0FEUI05MGE`1LG5`0F5QH05MGE`1F
EUH0G5aL05EEE@1HF5P0E5AD05mOG`1EEED0G5aL05UIF@1SHf<0E5AD05eMG@0205aLG00?05iNGP1P
H600H61P05QHF01IFET0H61P05IFEP1OGel0HF5Q05eMG@1JFUX0HV9R05eMG@1RHV80EeMG0080FUYJ
00h0HF5Q06IVIP1NGUh0FUYJ05aLG01SHf<0HV9R05iNGP1PH600F5QH06=SH`1RHV80Hf=S05iNGP80
Hf=S01<0GEeM05mOG`1PH600HV9R06=SH`1WIfL0HF5Q06=SH`1PH600IFEU069RHP1SHf<0HV9R061P
H01VIVH0FUYJ06EUI@1VIVH0GEeM0080IFEU00D0Jf][06EUI@1LG5`0HF5Q06ATI00206=SH`0=061P
H01NGUh0G5aL05mOG`1TI6@0GEeM069RHP1OGel0H61P06=SH`1RHV80Hf=S05YJFP0205iNGP0A06=S
H`1IFET0I6AT05aLG01NGUh0GEeM06EUI@1OGel0HF5Q05]KF`1IFET0HF5Q05mOG`1HF5P0HV9R065Q
H@1LG5`00P1JFUX0:@1RHV80IVIV069RHP1RHV80GEeM05iNGP1JFUX0GemO065QH@1RHV80H61P06AT
I01QHF40G5aL061PH01IFET0Fe]K06=SH`1LG5`0HF5Q05QHF01OGel0GEeM05aLG01MGEd0FUYJ06AT
I01NGUh0Fe]K05YJFP1OGel0FEUI05mOG`1PH600Fe]K05eMG@1HF5P0GemO05UIF@1KFe/0HV9R0080
FUYJ00h0GUiN05QHF01MGEd0G5aL05mOG`1LG5`0GUiN05]KF`1JFUX0GemO05UIF@1DE5@0I6AT05eM
G@80G5aL01d0FEUI05]KF`1IFET0G5aL05mOG`1QHF40GemO05eMG@1CDe<0GUiN04m?C`1GEeL0F5QH
05]KF`1NGUh0EeMG05]KF`1IFET0EeMG05]KF`1GEeL0F5QH05iNGP1LG5`0FEUI05eMG@1QHF40GemO
05EEE@0205]KF`0405QHF01CDe<0FUYJ05iNGP80F5QH01`0EUIF05mOG`1KFe/0H61P05IFEP1HF5P0
GemO069RHP1OGel0GEeM05YJFP1FEUH0DE5A05EEE@1MGEd0G5aL06EUI@1CDe<0GemO05]KF`1IFET0
G5aL04m?C`1@D500FUYJ05UIF@1FEUH0FEUI0`1NGUh00`1IFET0GUiN05QHF00205UIF@0C05ADE01K
Fe/0EEEE05EEE@1JFUX0G5aL05EEE@1JFUX0Fe]K05YJFP1KFe/0E5AD06=SH`1JFUX0Fe]K05eMG@1D
E5@0GUiN05aLG0060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT01@1KFe/0
F5QH05QHF01MGEd0Hf=S0080G5aL00@0FEUI05eMG@1QHF40F5QH0P1MGEd0301DE5@0FEUI05QHF01F
EUH0HV9R05UIF@1NGUh0FUYJ05eMG@1DE5@0FUYJ065QH@80H61P0180FUYJ061PH01FEUH0H61P05aL
G01KFe/0IVIV05ADE01IFET0H61P05UIF@1<C4`0G5aL05iNGP1IFET0F5QH05mOG`1GEeL205YJFP0B
065QH@1KFe/0FUYJ05YJFP1IFET0G5aL05UIF@1DE5@0GEeM05mOG`1ADE40EeMG05aLG01JFUX0G5aL
05]KF`1LG5`0GemO0P1IFET06@1JFUX0FEUI05mOG`1IFET0H61P069RHP1MGEd0EEEE061PH01MGEd0
FEUI05iNGP1MGEd0GUiN05aLG01JFUX0G5aL06QXJ01RHV80G5aL05eMG@1JFUX0GUiN05mOG`1JFUX0
0P1OGel06`1RHV80I6AT061PH01VIVH0Fe]K069RHP1JFUX0GemO069RHP1SHf<0GemO06EUI@1JFUX0
H61P069RHP1NGUh0GEeM069RHP1QHF40H61P05eMG@1PH600IFEU05eMG@1QHF40IFEU065QH@0206=S
H`0d06ATI01KFe/0HV9R065QH@1TI6@0IVIV05iNGP1VIVH0GUiN065QH@1OGel0GUiN069RHP1NGUh0
I6AT05eMG@1OGel0H61P05aLG01VIVH0IFEU05eMG@1VIVH0GemO05iNGP1TI6@0IFEU05aLG01RHV80
Hf=S05mOG`1KFe/0H61P06EUI@1PH600HF5Q05iNGP1PH600GemO069RHP1OGel0Hf=S05eMG@1NGUh0
GEeM05YJFP1SHf<0GemO05YJFP1HF5P0H61P05iNGP80I6AT00P0Fe]K05QHF01KFe/0HV9R05UIF@1P
H600IVIV061PH080GemO0340I6AT05aLG01PH600HV9R06MWI`1LG5`0FUYJ05]KF`1FEUH0GEeM069R
HP1KFe/0GUiN05mOG`1PH600FEUI05mOG`1PH600FEUI05aLG01JFUX0EeMG061PH01FEUH0Fe]K05QH
F01RHV80FEUI05eMG@1JFUX0GEeM05EEE@1KFe/0FUYJ05QHF01PH600G5aL065QH@1LG5`0H61P05QH
F01NGUh0G5aL05eMG@1HF5P0HV9R05mOG`1GEeL0G5aL0080FUYJ01`0F5QH05YJFP1EEED0GUiN05]K
F`1OGel0HF5Q05IFEP1?Cdl0GEeM05UIF@1NGUh0Hf=S05UIF@1JFUX0GemO05YJFP1PH600Cdm?05eM
G@1IFET0EUIF05UIF@1HF5P0G5aL05MGE`1IFET0G5aL0P1HF5P06`1GEeL0CDe=05QHF01DE5@0De=C
05ADE01RHV80FUYJ05iNGP1HF5P0FEUI05QHF01FEUH0FEUI059BDP1KFe/0EeMG05IFEP1LG5`0FEUI
055AD@1MGEd0EUIF05iNGP1LG5`0FUYJ05ADE00205IFEP0405MGE`1FEUH0E5AD05aLG080Fe]K00/0
FEUI05IFEP1HF5P0HV9R05eMG@1NGUh0FUYJ05aLG01OGel0E5AD05]KF`060=WIf@4000000@3IfMT0
01H0fMWI00<000000=WIf@3IfMT00`3IfMT01@1MGEd0FEUI05iNGP1TI6@0E5AD0080GEeM00<0EUIF
05aLG01GEeL00P1LG5`02@1GEeL0Fe]K05UIF@1FEUH0G5aL05IFEP1HF5P0EUIF065QH@0205]KF`0H
05mOG`1PH600H61P05]KF`1NGUh0Hf=S05aLG01NGUh0GemO05UIF@1KFe/0F5QH05MGE`1HF5P0H61P
05=CD`1GEeL0Fe]K06YZJP1RHV80GEeM065QH@1HF5P0Hf=S0P1FEUH01@1LG5`0F5QH05QHF01OGel0
FEUI0080EeMG0140EUIF061PH01NGUh0HF5Q05MGE`1HF5P0I6AT05aLG01IFET0FUYJ05IFEP1HF5P0
EeMG05EEE@1OGel0GUiN05MGE`0205]KF`80FEUI00@0GemO05]KF`1MGEd0GUiN0P1KFe/04P1PH600
G5aL05mOG`1OGel0FUYJ061PH01NGUh0H61P05YJFP1TI6@0Fe]K05eMG@1TI6@0HF5Q061PH01HF5P0
J6QX05aLG080HF5Q0100G5aL065QH@1VIVH0JVYZ05]KF`1QHF40JFUY05aLG01QHF40GUiN05]KF`1P
H600IfMW05aLG01VIVH0IFEU0P1PH6002P1VIVH0H61P06EUI@1PH600IVIV05eMG@1XJ6P0IfMW069R
HP1TI6@205aLG00:06ATI01KFe/0H61P05eMG@1NGUh0HV9R05eMG@1VIVH0GemO06=SH`80HF5Q00P0
IFEU06=SH`1UIFD0IFEU05aLG01OGel0G5aL06IVIP80GemO00<0GEeM05]KF`1RHV800P1LG5`03@1T
I6@0IFEU061PH01QHF40HV9R05mOG`1TI6@0GEeM06EUI@1HF5P0Fe]K069RHP1KFe/00P1TI6@02`1H
F5P0GUiN065QH@1LG5`0HF5Q06ATI01SHf<0G5aL061PH01SHf<0F5QH0080HF5Q00X0HV9R05eMG@1S
Hf<0FUYJ05aLG01HF5P0FEUI05YJFP1NGUh0Fe]K0`1OGel07P1HF5P0GEeM05IFEP1OGel0GEeM069R
HP1QHF40Fe]K05MGE`1LG5`0GUiN05UIF@1OGel0G5aL065QH@1GEeL0Fe]K05IFEP1NGUh0FEUI05YJ
FP1NGUh0GEeM05iNGP1GEeL0HF5Q05]KF`1LG5`0F5QH05YJFP80G5aL01D0FUYJ05mOG`1KFe/0EeMG
05aLG01PH600F5QH05]KF`1NGUh0E5AD05UIF@1UIFD0Cdm?061PH01KFe/0EeMG055AD@1LG5`0GEeM
05UIF@1FEUH00P1GEeL01P1EEED0Fe]K05YJFP1MGEd0F5QH05YJFP80FEUI00@0FUYJ05MGE`1FEUH0
De=C0P1GEeL03@1IFET0FUYJ05IFEP1ADE40FUYJ05eMG@1CDe<0G5aL05EEE@1KFe/0FEUI05MGE`1M
GEd00P1HF5P0101BDU80Hf=S05IFEP1OGel205]KF`0G05eMG@1FEUH0EEEE05ADE01FEUH0Fe]K05aL
G01JFUX0EUIF05ADE01OGel0Fe]K05YJFP1PH600FUYJ05eMG@1EEED0GUiN05eMG@1FEUH0F5QH059B
DP1MGEd01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI02@0FUYJ05MGE`1I
FET0EeMG05YJFP1FEUH0GUiN05YJFP1QHF40EUIF05mOG`1JFUX0H61P05UIF@1QHF40FEUI05iNGP1O
Gel0HV9R05aLG01JFUX0H61P05eMG@1PH600GemO065QH@1HF5P0Fe]K065QH@1KFe/0GUiN05aLG01M
GEd0GemO05eMG@1SHf<205aLG00505YJFP1NGUh0DU9B05UIF@1MGEd00P1PH6003@1IFET0EEEE05MG
E`1NGUh0GemO05aLG01NGUh0Fe]K05MGE`1FEUH0GEeM05aLG01JFUX00P1NGUh06@1HF5P0GUiN05YJ
FP1IFET0EeMG05eMG@1JFUX0F5QH05iNGP1KFe/0EEEE05mOG`1PH600G5aL05]KF`1OGel0H61P05YJ
FP1KFe/0Hf=S05EEE@1JFUX0GUiN05]KF`1OGel00P1TI6@00`1OGel0G5aL05UIF@02069RHP0:065Q
H@1SHf<0GemO05eMG@1UIFD0H61P069RHP1JFUX0GEeM05UIF@80H61P00D0FEUI065QH@1VIVH0G5aL
06=SH`02065QH@80H61P00<0Fe]K05QHF01MGEd00P1MGEd08P1PH600Hf=S06EUI@1QHF40I6AT065Q
H@1OGel0Hf=S061PH01NGUh0Hf=S05YJFP1PH600HF5Q05UIF@1HF5P0Fe]K05eMG@1OGel0IfMW05iN
GP1SHf<0Fe]K06EUI@1SHf<0FUYJ061PH01OGel0Hf=S06QXJ01OGel0G5aL06EUI@1RHV8206ATI00<
05aLG01IFET0H61P05iNGP1RHV80GemO06QXJ01OGel0IFEU06=SH`1PH600HF5Q0P1IFET2065QH@05
05aLG01TI6@0GemO05]KF`1WIfL00P1MGEd01@1KFe/0FEUI069RHP1NGUh0I6AT0080HV9R02d0F5QH
06ATI01PH600HF5Q05]KF`1RHV80H61P05mOG`1NGUh0IFEU061PH01OGel0HF5Q05UIF@1NGUh0GEeM
05iNGP1LG5`0F5QH061PH01KFe/0FUYJ05UIF@1PH600F5QH05eMG@1FEUH0G5aL05QHF01SHf<0H61P
05eMG@1PH600Fe]K05aLG01EEED0E5AD05]KF`1JFUX0HV9R065QH@1JFUX0FEUI05aLG01TI6@00P1K
Fe/05P1LG5`0FUYJ05iNGP1EEED0GUiN05mOG`1MGEd0FEUI05]KF`1GEeL0FUYJ05UIF@1NGUh0E5AD
05]KF`1EEED0EeMG05QHF01KFe/0G5aL05QHF01GEeL2059BDP0605=CD`1LG5`0EeMG05UIF@1KFe/0
F5QH0P1FEUH0101IFET0EUIF05YJFP1DE5@305MGE`80Fe]K0P1HF5P0501IFET0F5QH05QHF01EEED0
FUYJ05=CD`1GEeL0EEEE05aLG01ADE40EEEE065QH@1GEeL0H61P05iNGP1KFe/0FEUI05IFEP1JFUX0
EEEE0P1GEeL01P1IFET0FUYJ05QHF01EEED0FEUI05aLG080FUYJ00X0FEUI061PH01KFe/0EeMG05UI
F@1HF5P0GEeM05aLG01GEeL0Fe]K1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0
fMWI00d0GemO05YJFP1DE5@0GemO05QHF01NGUh0E5AD05]KF`1HF5P0GEeM059BDP1DE5@0FEUI0080
EeMG01d0GEeM05ADE01KFe/0GemO05iNGP1PH600Fe]K069RHP1PH600G5aL06EUI@1XJ6P0F5QH05eM
G@1JFUX0G5aL05QHF01ADE40De=C05QHF01FEUH0FEUI065QH@1PH600HV9R05]KF`1IFET0GemO05YJ
FP02059BDP0=05eMG@1IFET0EeMG05]KF`1SHf<0GEeM05YJFP1NGUh0GEeM05EEE@1NGUh0Fe]K05aL
G00205QHF00A05aLG01KFe/0F5QH05ADE01NGUh0EUIF059BDP1PH600EUIF05ADE01IFET0FUYJ05]K
F`1PH600FEUI05]KF`1PH6000P1LG5`03P1QHF40GEeM06=SH`1RHV80G5aL065QH@1EEED0GUiN05UI
F@1SHf<0G5aL05iNGP1SHf<0Fe]K0P1NGUh0A@1LG5`0FEUI05UIF@1NGUh0G5aL05mOG`1MGEd0GUiN
05]KF`1MGEd0FUYJ05eMG@1OGel0HV9R06=SH`1RHV80GemO06IVIP1IFET0H61P05UIF@1UIFD0Hf=S
061PH01TI6@0GUiN06YZJP1RHV80GEeM065QH@1KFe/0GEeM069RHP1XJ6P0F5QH061PH01LG5`0H61P
06=SH`1QHF40GUiN061PH01TI6@0Hf=S065QH@1RHV80GEeM05MGE`1NGUh0HF5Q06QXJ01MGEd0IVIV
06QXJ01NGUh0G5aL05eMG@1NGUh0Jf][05eMG@1NGUh0HV9R06ATI01NGUh0HV9R061PH01TI6@0GemO
05aLG002061PH00F05UIF@1GEeL0IFEU06IVIP1PH600GUiN06EUI@1IFET0I6AT05mOG`1DE5@0GemO
05YJFP1QHF40GEeM06EUI@1IFET0HF5Q05eMG@1HF5P0HF5Q05MGE`80G5aL00@0FUYJ05MGE`1TI6@0
GEeM0P1RHV802@1JFUX0EeMG05aLG01IFET0EeMG05aLG01OGel0H61P05ADE002065QH@0>06IVIP1F
EUH0FUYJ05QHF01PH600GEeM05iNGP1IFET0FUYJ05mOG`1MGEd0G5aL05]KF`1PH60305]KF`0;05AD
E01KFe/0EeMG05iNGP1KFe/0GEeM05iNGP1GEeL0G5aL05EEE@1BDU800P1LG5`00`1GEeL0Fe]K05UI
F@0205]KF`0306=SH`1QHF40G5aL0080Fe]K02/0GemO05EEE@1IFET0G5aL05MGE`1NGUh0EUIF05]K
F`1OGel0De=C05UIF@1CDe<0D51@05YJFP1EEED0E5AD05IFEP1HF5P0E5AD05EEE@1CDe<0E5AD05aL
G01JFUX0E5AD05UIF@1EEED0HV9R05YJFP1GEeL0FEUI05EEE@1IFET0EEEE05YJFP1NGUh0F5QH05UI
F@1EEED0F5QH05eMG@1HF5P0HF5Q0080FUYJ01D0GEeM05EEE@1JFUX0EeMG05eMG@1IFET0EEEE05iN
GP1IFET0GEeM05UIF@1QHF40EUIF05YJFP1FEUH0EeMG05IFEP1CDe<0FEUI05YJFP1KFe/01P3IfMT1
00000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0400GEeM05UIF@1HF5P0F5QH061PH01L
G5`0FUYJ05MGE`1HF5P0H61P05]KF`1HF5P0FEUI05YJFP1GEeL0H61P05eMG@1NGUh0G5aL05mOG`1N
GUh0FUYJ05QHF01SHf<0H61P065QH@1UIFD0GEeM05UIF@1PH600E5AD05UIF@1NGUh0G5aL069RHP1F
EUH0GUiN05eMG@1GEeL0GEeM061PH01HF5P0I6AT05]KF`1PH600Fe]K05QHF01IFET0EEEE05iNGP1I
FET0FUYJ05IFEP1BDU80HF5Q05MGE`1MGEd0FUYJ05QHF01OGel0GUiN06IVIP1IFET0HF5Q0P1LG5`0
501JFUX0EeMG061PH01NGUh0GEeM05YJFP1HF5P0GemO05]KF`1RHV80G5aL05=CD`1OGel0De=C05mO
G`1NGUh0GEeM05YJFP1HF5P0H61P0P1RHV807`1QHF40GEeM05MGE`1RHV80G5aL06=SH`1MGEd0GUiN
06IVIP1PH600G5aL05mOG`1TI6@0GemO05eMG@1TI6@0GUiN05eMG@1UIFD0EUIF06ATI01SHf<0H61P
05eMG@1OGel0IfMW05mOG`1LG5`0GEeM06MWI`1PH6000P1MGEd04`1UIFD0HV9R06EUI@1WIfL0GEeM
06MWI`1MGEd0EeMG061PH01RHV80IVIV065QH@1JFUX0IFEU069RHP1WIfL0IVIV05iNGP1QHF400P1N
GUh02`1QHF40IVIV05mOG`1NGUh0FEUI05YJFP1RHV80IFEU06=SH`1EEED0G5aL0080Fe]K02X0GemO
065QH@1PH600Fe]K06=SH`1RHV80Fe]K05MGE`1UIFD0G5aL061PH01TI6@0GEeM061PH01TI6@0J6QX
05YJFP1KFe/0FEUI061PH01RHV80Hf=S05YJFP1UIFD0G5aL061PH01KFe/0FUYJ05eMG@1JFUX0Hf=S
05mOG`1FEUH0FUYJ061PH01OGel0H61P05UIF@1HF5P0HF5Q061PH01FEUH205UIF@0<05]KF`1RHV80
De=C05mOG`1TI6@0GemO05aLG01NGUh0IfMW06YZJP1JFUX0GemO0P1JFUX0501MGEd0Fe]K05YJFP1Q
HF40GUiN05YJFP1LG5`0Fe]K05aLG01NGUh0F5QH069RHP1SHf<0F5QH05MGE`1LG5`0GEeM069RHP1I
FET0GEeM0P1IFET0501RHV80Fe]K05UIF@1NGUh0DE5A05UIF@1GEeL0G5aL061PH01MGEd0HF5Q05eM
G@1GEeL0GEeM05QHF01MGEd0Fe]K05YJFP1HF5P0FUYJ0P1IFET205EEE@0I05MGE`1JFUX0F5QH05YJ
FP1PH600Fe]K05=CD`1FEUH0GemO05ADE01FEUH0G5aL05YJFP1FEUH0EEEE05QHF01KFe/0FUYJ05QH
F01FEUH0GUiN05MGE`1EEED0FUYJ055AD@02059BDP0405MGE`1KFe/0EeMG05MGE`80EEEE0P1JFUX0
1`1BDU80GUiN05EEE@1HF5P0EUIF05]KF`1EEED00P1IFET02`1KFe/0G5aL05IFEP1NGUh0GemO05UI
F@1BDU80GEeM05aLG01IFET0Fe]K00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@03
0=WIf@0?05iNGP1GEeL0GUiN05UIF@1KFe/0GUiN05MGE`1LG5`0HF5Q05IFEP1MGEd0FUYJ05aLG01O
Gel0F5QH0080FUYJ0P1NGUh0101KFe/0GemO05mOG`1PH60205mOG`0306=SH`1TI6@0GemO0080FEUI
00D0FUYJ05eMG@1LG5`0F5QH05mOG`0205]KF`0705aLG01KFe/0GEeM05UIF@1NGUh0GEeM05QHF002
05YJFP0P06ATI01PH600H61P05YJFP1PH600GUiN05YJFP1@D500E5AD05QHF01KFe/0GemO05MGE`1F
EUH0GUiN05aLG01FEUH0Fe]K05QHF01SHf<0Fe]K05UIF@1GEeL0GEeM06=SH`1KFe/0Hf=S05aLG01Q
HF40GUiN06EUI@1OGel2065QH@0505aLG01NGUh0EeMG05MGE`1IFET00P1HF5P00`1DE5@0GemO05mO
G`0206EUI@0I05]KF`1IFET0IFEU061PH01XJ6P0EEEE069RHP1GEeL0GUiN05mOG`1LG5`0GUiN06QX
J01SHf<0HV9R05mOG`1NGUh0IFEU069RHP1LG5`0GUiN069RHP1SHf<0H61P05MGE`02069RHP0706AT
I01ZJVX0GUiN065QH@1NGUh0Fe]K05eMG@0205mOG`0D05aLG01NGUh0GemO05QHF01RHV80G5aL065Q
H@1LG5`0FUYJ05]KF`1MGEd0F5QH06=SH`1JFUX0Fe]K05eMG@1NGUh0GEeM061PH01NGUh205aLG00H
06IVIP1NGUh0HV9R05eMG@1TI6@0H61P05eMG@1NGUh0G5aL05mOG`1XJ6P0G5aL05iNGP1PH600GEeM
05iNGP1LG5`0IFEU05mOG`1VIVH0G5aL061PH01QHF40EeMG0`1OGel01P1NGUh0EEEE05IFEP1MGEd0
GemO06=SH`80Fe]K0140Hf=S069RHP1KFe/0F5QH05UIF@1OGel0FUYJ05mOG`1XJ6P0FEUI05YJFP1K
Fe/0H61P05]KF`1NGUh0G5aL06=SH`0205]KF`0606IVIP1KFe/0Fe]K06ATI01RHV80GemO0P1NGUh0
901OGel0F5QH05UIF@1LG5`0EeMG05iNGP1LG5`0GemO05iNGP1WIfL0I6AT05eMG@1OGel0FUYJ05]K
F`1SHf<0GemO065QH@1JFUX0GUiN05EEE@1HF5P0EeMG05YJFP1OGel0H61P05iNGP1GEeL0GUiN05UI
F@1OGel0FUYJ061PH01DE5@0GUiN06=SH`80FUYJ00H0GEeM05iNGP1CDe<0EeMG05UIF@1KFe/205MG
E`0<05]KF`1JFUX0EUIF05]KF`1EEED0H61P05IFEP1NGUh0FEUI05]KF`1GEeL0Fe]K0P1GEeL04`1M
GEd0EEEE05QHF01JFUX0De=C055AD@1JFUX0F5QH05eMG@1NGUh0EUIF05]KF`1CDe<0FEUI05]KF`1M
GEd0De=C05MGE`1NGUh00P1EEED02@1HF5P0DE5A05MGE`1PH600Fe]K05iNGP1HF5P0Fe]K05IFEP02
05QHF00305IFEP1HF5P0GEeM0080GEeM00D0FUYJ05QHF01HF5P0DU9B05iNGP060=WIf@4000000@3I
fMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT06@1LG5`0F5QH05=CD`1QHF40F5QH05iNGP1KFe/0
F5QH05aLG01KFe/0FEUI05eMG@1LG5`0Fe]K05mOG`1LG5`0GemO05aLG01RHV80GUiN06=SH`1LG5`0
Fe]K06EUI@1SHf<00P1QHF401@1KFe/0F5QH05aLG01KFe/0HF5Q0080Fe]K0180EUIF05]KF`1IFET0
HF5Q06ATI01PH600G5aL06=SH`1LG5`0EeMG05aLG01OGel0H61P05MGE`1DE5@0IVIV05eMG@1JFUX2
05mOG`0P05YJFP1HF5P0F5QH05MGE`1MGEd0EUIF065QH@1MGEd0H61P05YJFP1FEUH0EeMG065QH@1L
G5`0GUiN05YJFP1LG5`0Fe]K05aLG01MGEd0FUYJ05iNGP1QHF40H61P06=SH`1MGEd0HF5Q05QHF01O
Gel0FUYJ06=SH`1MGEd205aLG007065QH@1NGUh0G5aL061PH01NGUh0HF5Q05]KF`02061PH080HF5Q
00h0G5aL065QH@1NGUh0I6AT065QH@1PH600GUiN05QHF01MGEd0I6AT06MWI`1NGUh0H61P05mOG`80
H61P01T0G5aL05YJFP1RHV80GUiN05mOG`1UIFD0Fe]K06UYJ@1RHV80H61P06e]K@1RHV80GemO05aL
G01SHf<0Fe]K05aLG01FEUH0Hf=S05aLG01TI6@0Hf=S061PH01NGUh0G5aL0080GEeM00d0Fe]K065Q
H@1OGel0GUiN06EUI@1OGel0FUYJ06=SH`1QHF40HV9R05aLG01VIVH0Fe]K0080GemO00X0GUiN069R
HP1NGUh0GUiN05UIF@1KFe/0I6AT065QH@1JFUX0HF5Q0P1SHf<01`1OGel0Hf=S06ATI01OGel0GEeM
05MGE`1KFe/00P1MGEd0501LG5`0H61P05mOG`1NGUh0GEeM05mOG`1KFe/0FUYJ05]KF`1PH600EeMG
065QH@1VIVH0GEeM06ATI01OGel0G5aL05mOG`1KFe/0HF5Q0P1LG5`206=SH`0I05]KF`1JFUX0G5aL
069RHP1UIFD0GemO05QHF01LG5`0H61P05iNGP1OGel0G5aL05IFEP1SHf<0GEeM05IFEP1QHF40G5aL
06QXJ02?Shl0Kfm_069RHP1MGEd0GUiN05]KF`0305mOG`0605IFEP1IFET0FUYJ05aLG01FEUH0GemO
0P1MGEd06P1FEUH0FEUI05IFEP1KFe/0F5QH05YJFP1IFET0EUIF05eMG@1OGel0EeMG05]KF`1PH600
EUIF05mOG`1PH600HF5Q05]KF`1DE5@0HF5Q05QHF01DE5@0GEeM05UIF@1BDU80De=C0P1GEeL00`1K
Fe/0G5aL05UIF@0205ADE00905EEE@1FEUH0GEeM05IFEP1JFUX0F5QH05YJFP1LG5`0GUiN00<0EUIF
00<0G5aL05mOG`1NGUh00P1GEeL01@1CDe<0FEUI05QHF01LG5`0De=C0080FEUI0P1LG5`01@1GEeL0
EEEE05MGE`1NGUh0FUYJ0080G5aL00X0EeMG05UIF@1QHF40H61P059BDP1KFe/0E5AD05=CD`1GEeL0
EEEE1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00`0FUYJ05QHF01CDe<0
Fe]K05MGE`1LG5`0HV9R05aLG01HF5P0G5aL05]KF`1LG5`205eMG@0805MGE`1NGUh0Fe]K06=SH`1N
GUh0Fe]K061PH01MGEd305iNGP0;05YJFP1PH600EeMG05QHF01TI6@0EeMG05]KF`1PH600I6AT05]K
F`1LG5`00`1NGUh205UIF@0J06IVIP1LG5`0Fe]K05QHF01KFe/0FUYJ05]KF`1DE5@0GUiN05ADE01N
GUh0D51@05YJFP1GEeL0GemO05IFEP1OGel0G5aL061PH01IFET0HF5Q069RHP1NGUh0GEeM05MGE`1O
Gel205iNGP08061PH01NGUh0FUYJ05]KF`1TI6@0G5aL05mOG`1RHV8205iNGP0<05aLG01OGel0Fe]K
061PH01HF5P0FUYJ06ATI01NGUh0HF5Q05iNGP1KFe/0JVYZ0P1LG5`01P1MGEd0F5QH05eMG@1MGEd0
Hf=S05IFEP<0Fe]K01T0Hf=S05mOG`1NGUh0GemO069RHP1OGel0G5aL05mOG`1PH600GUiN065QH@1O
Gel0HV9R05mOG`1TI6@0HV9R05eMG@1SHf<0H61P06QXJ01PH600GemO069RHP1MGEd0GemO0080HV9R
02h0H61P065QH@1YJFT0GUiN061PH01RHV80Hf=S06EUI@1LG5`0GemO06EUI@1MGEd0FEUI05iNGP1H
F5P0GemO05UIF@1NGUh0GemO05iNGP1RHV80HF5Q05iNGP1PH600HF5Q06ATI01OGel0I6AT06QXJ01Q
HF40IfMW06EUI@1MGEd0FEUI05iNGP1PH600G5aL065QH@1GEeL0GEeM069RHP1FEUH0GemO06ATI01L
G5`0GemO0P1KFe/03@1JFUX0F5QH05mOG`1KFe/0E5AD05aLG01GEeL0G5aL05YJFP1HF5P0FUYJ05]K
F`1NGUh00P1PH6007@1FEUH0G5aL05IFEP1QHF40FUYJ05UIF@1OGel0GUiN06ATI01QHF40G5aL069R
HP1KFe/0GEeM05]KF`1QHF40GUiN05aLG01OGel0HF5Q05eMG@1UIFD0FEUI05QHF01MGEd0FUYJ065Q
H@1GEeL0Shn?0080oooo0280:b/[05eMG@1MGEd0Fe]K05UIF@1ADE40GUiN05MGE`1LG5`0EUIF05eM
G@1PH600GEeM05IFEP1JFUX0De=C05MGE`1HF5P0E5AD05EEE@1GEeL0FEUI05MGE`1NGUh0FUYJ05MG
E`1KFe/0EUIF06=SH`1KFe/0G5aL05iNGP1JFUX0EUIF0P1IFET01P1HF5P0EEEE05EEE@1HF5P0FUYJ
05ADE080FUYJ00h0GUiN051@D01IFET0GUiN05EEE@1IFET0DU9B05eMG@1OGel0EeMG05UIF@1BDU80
FUYJ05EEE@80De=C00l0E5AD05aLG01HF5P0EeMG05QHF01JFUX0GEeM05MGE`1KFe/0EeMG05IFEP1M
GEd0FEUI05QHF01IFET00P1JFUX00`1OGel0IfMW05YJFP0205eMG@0905mOG`1MGEd0E5AD05aLG01A
DE40Fe]K05QHF01KFe/0G5aL00H0fMWI0@0000010=WIf@000P3IfMT2000000@0fMWI0P0000040=WI
f@8000001P3IfMT00`000000fMWI0=WIf@030=WIf@0G05eMG@1FEUH0EUIF05]KF`1GEeL0G5aL05iN
GP1QHF40Fe]K05IFEP1TI6@0HF5Q05]KF`1VIVH0G5aL05eMG@1QHF40Fe]K05aLG01TI6@0HV9R05aL
G01TI6@00P1LG5`0401RHV80FUYJ05YJFP1MGEd0I6AT05eMG@1NGUh0F5QH05mOG`1MGEd0FEUI05mO
G`1RHV80EEEE05]KF`1JFUX205eMG@0B05mOG`1IFET0G5aL05mOG`1QHF40G5aL05iNGP1HF5P0I6AT
055AD@1EEED0FEUI055AD@1NGUh0G5aL065QH@1NGUh0GEeM0P1KFe/06@1SHf<0F5QH05YJFP1HF5P0
GEeM05aLG01PH600GEeM05]KF`1QHF40GUiN05IFEP1JFUX0F5QH05eMG@1OGel0QXJ605YJFP1QHF40
EeMG05YJFP1VIVH0GEeM05mOG`1IFET00P1TI6@205iNGP0505YJFP1MGEd0F5QH06=SH`1QHF400P1M
GEd01@1SHf<0Fe]K05iNGP1RHV80GEeM0080HF5Q00T0G5aL061PH01RHV80F5QH05aLG01TI6@0EUIF
069RHP1SHf<00P1WIfL00`1TI6@0Hf=S05mOG`0206=SH`0=05YJFP1SHf<0FUYJ05eMG@1QHF40H61P
05iNGP1RHV80G5aL05YJFP1PH600HV9R05YJFP0205aLG00806YZJP1JFUX0G5aL069RHP1KFe/0FUYJ
05eMG@1IFET205mOG`0Z061PH01MGEd0FEUI061PH01LG5`0HV9R061PH01NGUh0IFEU05aLG01KFe/0
GemO06ATI01EEED0H61P05QHF01LG5`0GEeM065QH@1UIFD0HF5Q06IVIP1NGUh0EeMG05iNGP1QHF40
GEeM05aLG01QHF40GUiN05]KF`1IFET0GEeM069RHP1OGel0HV9R05YJFP1MGEd0I6AT05EEE@1TI6@0
GemO0P1NGUh0501HF5P0GemO05aLG01OGel0FUYJ065QH@1OGel0G5aL06ATI01SHf<0GEeM061PH01J
FUX0H61P06ATI01WIfL0HV9R05QHF01LG5`0GUiN0P1MGEd0201OGel0G5aL05iNGP1HF5P0GemO05iN
GP1JFUX0EeMG0P0000004@0>3Ph0EeMG05IFEP1LG5`0H61P05eMG@1HF5P0GEeM061PH01KFe/0G5aL
05MGE`1IFET0EeMG05IFEP1KFe/0EeMG0080GemO00P0FUYJ05iNGP1HF5P0EeMG05ADE01IFET0GUiN
05UIF@80EeMG00L0E5AD05mOG`1GEeL0E5AD05YJFP1LG5`0EUIF0080GEeM02D0EeMG05QHF01OGel0
D51@05UIF@1GEeL0F5QH05=CD`1JFUX0F5QH05YJFP1LG5`0D51@05=CD`1LG5`0F5QH05EEE@1FEUH0
FUYJ065QH@1HF5P0FUYJ05MGE`1LG5`0GemO051@D01DE5@0Fe]K05aLG01HF5P0E5AD05UIF@1OGel0
EUIF05]KF`1IFET0FUYJ00<0G5aL00<0EUIF05]KF`1MGEd00P1MGEd01P1SHf<0HF5Q05iNGP1IFET0
E5AD05mOG`80F5QH1P3IfMT100000040fMWI00001@3IfMT000000=WIf@3IfMT000000080fMWI00@0
00000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@0000050=WIf@030000003IfMT0fMWI00<0
fMWI0180HF5Q05QHF01JFUX0Fe]K05aLG01JFUX0HV9R05QHF01MGEd0GUiN05UIF@1HF5P0Fe]K05MG
E`1RHV80H61P05mOG`1MGEd205iNGP0305eMG@1SHf<0Hf=S0080GemO00`0EeMG05mOG`1NGUh0EEEE
05UIF@1GEeL0FUYJ069RHP1KFe/0EEEE05aLG01KFe/2069RHP0f061PH01MGEd0GemO065QH@1SHf<0
G5aL06=SH`1KFe/0HF5Q05MGE`1IFET0G5aL05eMG@1KFe/0EeMG05eMG@1GEeL0FUYJ065QH@1GEeL0
Fe]K05YJFP1OGel0FUYJ065QH@1EEED0EUIF05aLG01QHF40Fe]K05YJFP1KFe/0Hf=S05aLG01MGEd0
F5QH061PH01MGEd0E5AD065QH@1HF5P0FUYJ05aLG01NGUh0Hf=S061PH01OGel0H61P05eMG@1LG5`0
FEUI06QXJ01OGel0F5QH0P1OGel04`1QHF40G5aL05iNGP1PH600G5aL05iNGP1PH600FUYJ065QH@1M
GEd0GemO05iNGP1KFe/0HV9R05iNGP1PH600I6AT05aLG01PH6000P1QHF40201JFUX0G5aL05]KF`1Y
JFT0HF5Q05eMG@1IFET0Fe]K0P1UIFD02@1NGUh0HV9R05eMG@1NGUh0FUYJ05UIF@1PH600IfMW065Q
H@0205iNGP0406=SH`1TI6@0GemO06EUI@80FEUI00H0HF5Q061PH01UIFD0HV9R05mOG`1HF5P205iN
GP04061PH01RHV80GUiN05]KF`80G5aL00`0HF5Q05eMG@1RHV80FUYJ05eMG@1UIFD0GUiN05aLG01H
F5P0H61P05mOG`1KFe/2061PH00D05iNGP1IFET0FUYJ05iNGP1IFET0Fe]K065QH@1PH600G5aL05eM
G@1PH600FUYJ05UIF@1KFe/0FUYJ05]KF`1LG5`0I6AT05aLG01PH60205aLG00305iNGP1OGel0EUIF
0080GUiN00H0FEUI05eMG@1MGEd0Fe]K069RHP1NGUh206ATI00Q05UIF@1MGEd0FEUI061PH01YJFT0
GUiN05mOG`1HF5P0HV9R05eMG@1NGUh0FUYJ05eMG@1IFET0H61P0492@P1PH600E5AD05]KF`1PH600
G5aL05eMG@1JFUX0HF5Q05QHF01GEeL0F5QH05aLG01ADE40FEUI05]KF`1PH600F5QH0080Fe]K00T0
GemO05]KF`1FEUH0GEeM06=SH`1HF5P0GUiN061PH01LG5`00P1JFUX01@1QHF40F5QH05YJFP1GEeL0
FUYJ0080F5QH00<0FUYJ05aLG01EEED00P1JFUX05@1EEED0EUIF05QHF01BDU80De=C05aLG01GEeL0
G5aL05MGE`1CDe<0EUIF05aLG01GEeL0F5QH05UIF@1LG5`0De=C05UIF@1EEED0DE5A05ADE00205UI
F@0C05ADE01CDe<0E5AD05QHF01DE5@0EUIF05eMG@1HF5P0G5aL065QH@1DE5@0EeMG05eMG@1JFUX0
H61P05QHF01MGEd0EUIF05YJFP0205MGE`0605iNGP1RHV80Fe]K05EEE@1JFUX0FEUI1P3IfMT10000
0040fMWI00040=WIf@040000003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT000000P3IfMT0
0`000000fMWI0=WIf@030=WIf@<000000`3IfMT0201JFUX0F5QH05aLG01PH600G5aL05YJFP1NGUh0
G5aL0P1MGEd0301RHV80FUYJ055AD@1NGUh0H61P05]KF`1GEeL0G5aL05]KF`1VIVH0G5aL05iNGP80
FUYJ00<0Fe]K065QH@1EEED00`1MGEd03@1QHF40FEUI061PH01MGEd0H61P05EEE@1NGUh0G5aL05eM
G@1OGel0FEUI05aLG01DE5@00P1HF5P09P1QHF40G5aL05QHF01JFUX0GEeM05mOG`1NGUh0G5aL05IF
EP1QHF40EeMG05EEE@1LG5`0F5QH05UIF@1NGUh0EUIF05mOG`1PH600EeMG05mOG`1GEeL0GemO061P
H01HF5P0GemO05iNGP1GEeL0FUYJ05]KF`1NGUh0GEeM06IVIP1MGEd0E5AD05YJFP1NGUh0G5aL0P1R
HV80101JFUX0G5aL065QH@1PH60205eMG@0306EUI@1NGUh0EUIF00<0FUYJ00h0EUIF05YJFP1QHF40
Hf=S05mOG`1PH600HF5Q05aLG01KFe/0HV9R06ATI01NGUh0HV9R06MWI`<0GEeM00@0FUYJ05mOG`1L
G5`0GEeM0P1LG5`05`1UIFD0Hf=S065QH@1QHF40G5aL061PH01RHV80EeMG061PH01KFe/0FEUI069R
HP1MGEd0HF5Q05aLG01YJFT0GemO06EUI@1PH600GUiN05YJFP1HF5P0H61P0080GemO0P1NGUh06P1G
EeL0HF5Q06=SH`1TI6@0IVIV069RHP1SHf<0IVIV05aLG01QHF40IfMW061PH01RHV80HF5Q06ATI01I
FET0GemO05eMG@1OGel0GEeM05UIF@1SHf<0HF5Q05=CD`1TI6@0HF5Q0`1PH6006@1KFe/0GUiN061P
H01MGEd0FUYJ05iNGP1JFUX0E5AD05YJFP1HF5P0GEeM05UIF@1JFUX0FEUI05aLG01JFUX0H61P05]K
F`1OGel0H61P069RHP1QHF40IVIV06QXJ01HF5P00P1NGUh03P1RHV80GEeM05IFEP1OGel0Fe]K05aL
G01NGUh0HF5Q05mOG`1SHf<0J6QX05UIF@1GEeL0Fe]K0P1NGUh0201MGEd0G5aL05YJFP1OGel0EEEE
05iNGP1JFUX0H61P0P1KFe/205iNGP0<05YJFP1UIFD0EeMG05]KF`1FEUH0FUYJ05]KF`1JFUX0F5QH
05UIF@1JFUX0EEEE0P1GEeL02P1MGEd0G5aL05aLG01PH600G5aL05EEE@1GEeL0F5QH05=CD`1LG5`2
05]KF`0605aLG01IFET0E5AD05=CD`1GEeL0FUYJ0P1GEeL0101?Cdl0FEUI05IFEP1GEeL205IFEP03
05UIF@1JFUX0E5AD0080De=C00X0FUYJ05ADE01IFET0EEEE05MGE`1HF5P0D51@05MGE`1KFe/0FUYJ
0P1HF5P0301GEeL0F5QH05aLG01KFe/0FEUI05IFEP1MGEd0HV9R06QXJ01KFe/0FUYJ05eMG@80GemO
00@0GUiN05UIF@1LG5`0EEEE0P1JFUX01P1CDe<0EeMG05YJFP1GEeL0Fe]K05YJFP@0fMWI0`000001
0=WIf@000P3IfMT2000000<0fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@00
00050=WIf@030000003IfMT0fMWI00<0fMWI00<0G5aL05eMG@1PH6000P1LG5`0401JFUX0G5aL05aL
G01RHV80H61P05QHF01LG5`0GUiN05mOG`1RHV80H61P05mOG`1KFe/0GUiN05MGE`1KFe/205mOG`04
05iNGP1PH600EUIF065QH@<0G5aL0180Hf=S065QH@1QHF40GUiN061PH01RHV80FEUI05]KF`1JFUX0
F5QH05mOG`1KFe/0GemO05QHF01RHV80E5AD05aLG01NGUh205eMG@0E05UIF@1LG5`0EeMG05UIF@1M
GEd0F5QH065QH@1SHf<0GemO069RHP1QHF40GemO05aLG01IFET0HV9R065QH@1HF5P0Fe]K05eMG@1O
Gel0FEUI0080GEeM00H0Fe]K06=SH`1JFUX0GEeM05QHF01OGel2065QH@80G5aL01L0HF5Q05EEE@1M
GEd0GUiN06=SH`1JFUX0Hf=S05iNGP1RHV80G5aL05YJFP1IFET0HV9R05mOG`1PH600GemO05aLG01K
Fe/0GEeM05QHF01KFe/0H61P069RHP0205mOG`0605iNGP1FEUH0HF5Q061PH01SHf<0HF5Q0P1OGel0
2`1PH600HF5Q05UIF@1JFUX0HV9R05ADE01LG5`0IFEU06ATI01MGEd0Hf=S0080H61P00D0G5aL05iN
GP1NGUh0H61P065QH@0205aLG00405eMG@1PH600HV9R069RHP<0GUiN00d0HF5Q069RHP1GEeL0H61P
05YJFP1PH600HV9R061PH01RHV80HF5Q05eMG@1KFe/0I6AT00<0HF5Q00D0GemO05eMG@1PH600GUiN
069RHP02061PH00C05QHF01IFET0Hf=S05aLG01NGUh0GEeM061PH01JFUX0GUiN05]KF`1MGEd0FUYJ
05iNGP1MGEd0G5aL05]KF`1NGUh0IVIV05iNGP0205UIF@0805eMG@1KFe/0HV9R05YJFP1IFET0FUYJ
061PH01NGUh205]KF`0405iNGP1TI6@0IVIV065QH@80FUYJ0140EUIF05mOG`1FEUH0H61P05]KF`1N
GUh0HV9R06=SH`1OGel0G5aL05mOG`1RHV80GEeM05mOG`1LG5`0Fe]K05ADE00205QHF080FUYJ0140
GEeM05mOG`1KFe/0Fe]K05MGE`1PH600FUYJ061PH01HF5P0H61P05YJFP1LG5`0E5AD061PH01OGel0
Fe]K05MGE`0305QHF00305aLG01DE5@0EeMG0080FEUI02`0E5AD05aLG01JFUX0FUYJ05eMG@1HF5P0
G5aL059BDP1JFUX0F5QH05YJFP1GEeL0FEUI05EEE@1IFET0G5aL05IFEP1GEeL0FUYJ059BDP1DE5@0
FUYJ05ADE01FEUH0G5aL05mOG`1EEED0EUIF055AD@1JFUX0F5QH059BDP1LG5`0FUYJ059BDP1DE5@0
EUIF05EEE@1MGEd0GemO05EEE@1DE5@0F5QH05]KF`80FEUI01<0GemO06IVIP1LG5`0FEUI05YJFP1L
G5`0FEUI05aLG01IFET0H61P05eMG@1NGUh0FUYJ05eMG@1?Cdl0F5QH05UIF@1@D500GEeM00H0fMWI
0@0000010=WIf@000P3IfMT00`000000fMWI0=WIf@020=WIf@040000003IfMT0fMWI00000080fMWI
00@000000=WIf@3IfMT000001@3IfMT00`000000fMWI0=WIf@030=WIf@80F5QH00H0Fe]K05aLG01N
GUh0GUiN061PH01EEED206=SH`0K06UYJ@1JFUX0Fe]K069RHP1GEeL0G5aL05mOG`1DE5@0GemO05EE
E@1OGel0HF5Q069RHP1NGUh0Fe]K06=SH`1RHV80GEeM05MGE`1MGEd0EeMG06=SH`1UIFD0H61P05mO
G`1NGUh0GEeM0080G5aL00T0GEeM069RHP1MGEd0G5aL06ATI01LG5`0GUiN05mOG`1RHV800P1LG5`0
4`1MGEd0GemO05IFEP1JFUX0GEeM05UIF@1TI6@0H61P065QH@1PH600HV9R05aLG01OGel0I6AT061P
H01TI6@0FUYJ05aLG01NGUh00P1OGel00`1JFUX0GEeM06=SH`0205mOG`0<05YJFP1RHV80GUiN065Q
H@1FEUH0HF5Q05aLG01JFUX0GEeM05UIF@1OGel0HF5Q0P1MGEd09@1LG5`0HV9R069RHP1PH600FUYJ
05QHF01NGUh0JVYZ05mOG`1HF5P0Hf=S065QH@1PH600IVIV05iNGP1OGel0Hf=S05eMG@1QHF40De=C
061PH01OGel0Hf=S06MWI`1RHV80FUYJ06=SH`1[Jf/0HF5Q05eMG@1RHV80J6QX06UYJ@1WIfL0GUiN
05eMG@1OGel00P1QHF402@1KFe/0F5QH05mOG`1IFET0G5aL05]KF`1OGel0F5QH06e]K@0206ATI004
05UIF@1SHf<0FEUI05MGE`80F5QH00d0EUIF05eMG@1MGEd0HV9R05iNGP1LG5`0Hf=S061PH01NGUh0
Fe]K065QH@1SHf<0H61P0080G5aL00D0GemO065QH@1MGEd0GUiN05aLG002069RHP0;05aLG01KFe/0
FUYJ05aLG01SHf<0G5aL069RHP1OGel0G5aL05eMG@1OGel00P1LG5`01`1PH600Fe]K05]KF`1JFUX0
EeMG061PH01RHV800P1LG5`08@1QHF40GEeM05YJFP1IFET0Hf=S05EEE@1JFUX0G5aL05QHF01PH600
FUYJ05mOG`1PH600IFEU05]KF`1UIFD0FUYJ05aLG01OGel0H61P06=SH`1NGUh0Fe]K069RHP1OGel0
EeMG05iNGP1QHF40G5aL05UIF@1HF5P0FEUI05aLG00205iNGP0605eMG@1NGUh0EeMG05aLG01QHF40
GemO0P1HF5P01P1OGel0FEUI069RHP1GEeL0EEEE05iNGP80FUYJ00P0EUIF05QHF01HF5P0DU9B05YJ
FP1HF5P0Fe]K04m?C`80G5aL00`0GEeM05UIF@1LG5`0Fe]K05QHF01PH600Fe]K05QHF01DE5@0EUIF
055AD@1HF5P205MGE`80F5QH02/0HF5Q05EEE@1EEED0De=C05EEE@1PH600F5QH05]KF`1GEeL0De=C
059BDP1LG5`0FUYJ04m?C`1FEUH0De=C05QHF01KFe/0E5AD05MGE`1JFUX0G5aL05YJFP1GEeL0FEUI
06=SH`1KFe/0G5aL05YJFP1VIVH0GUiN05mOG`1IFET0EEEE065QH@1KFe/0HV9R05YJFP1HF5P0H61P
06=SH`1ADE40EEEE0080EeMG00<0D51@055AD@3IfMT01@3IfMT100000040fMWI00020=WIf@<00000
0`3IfMT2000000@0fMWI0P0000060=WIf@030000003IfMT0fMWI00<0fMWI00L0H61P05eMG@1LG5`0
GUiN05eMG@1NGUh0Fe]K0080G5aL00h0EeMG05]KF`1IFET0HF5Q05iNGP1PH600Hf=S05mOG`1HF5P0
G5aL05eMG@1HF5P0GemO05eMG@80Fe]K00X0HF5Q05iNGP1KFe/0FEUI05iNGP1QHF40IFEU065QH@1C
De<0GEeM0P1NGUh05@1RHV80FUYJ05eMG@1OGel0Fe]K05mOG`1UIFD0HV9R05iNGP1PH600Hf=S05iN
GP1PH600Fe]K05eMG@1GEeL0H61P05eMG@1JFUX0Fe]K05YJFP02065QH@0305ADE01SHf<0H61P0080
FUYJ0280GUiN05mOG`1JFUX0Hf=S06IVIP1NGUh0GemO05YJFP1MGEd0GUiN05aLG01QHF40G5aL06=S
H`1KFe/0HV9R061PH01NGUh0Fe]K05aLG01HF5P0FUYJ05QHF01LG5`0IVIV065QH@1OGel0H61P05mO
G`1LG5`0GEeM05YJFP1PH600GUiN0P1PH600101NGUh0FEUI065QH@1FEUH2069RHP0505QHF01IFET0
H61P05MGE`1TI6@00P1QHF403P1KFe/0H61P05aLG01SHf<0GemO05aLG01MGEd0I6AT06=SH`1KFe/0
Hf=S05aLG01NGUh0I6AT0P1SHf<04`1OGel0F5QH065QH@1NGUh0H61P069RHP1FEUH0H61P05eMG@1N
GUh0GEeM05mOG`1KFe/0FUYJ05]KF`1MGEd0H61P05YJFP1SHf<00P1NGUh0101JFUX0Hf=S05mOG`1Q
HF4205mOG`0O06MWI`1MGEd0IVIV05iNGP1LG5`0H61P05UIF@1NGUh0GEeM05mOG`1ZJVX0GEeM065Q
H@1MGEd0H61P06=SH`1JFUX0Hf=S05YJFP1PH600GUiN05aLG01QHF40Fe]K05eMG@1OGel0IVIV05]K
F`1;Bd/0F5QH061PH00205iNGP0605eMG@1PH600GemO05MGE`1SHf<0GEeM0P1KFe/07`1PH600GEeM
05YJFP1QHF40GUiN069RHP1FEUH0HV9R05UIF@1LG5`0FEUI06ATI01ZJVX0HF5Q06IVIP1RHV80GemO
069RHP1PH600EEEE05IFEP1SHf<0Fe]K05YJFP1MGEd0GemO06=SH`1PH600GEeM05UIF@1QHF400P1E
EED02@1GEeL0FEUI05]KF`1IFET0DU9B05aLG01KFe/0G5aL05UIF@0205QHF00R05MGE`1KFe/0G5aL
05MGE`1KFe/0F5QH05YJFP1IFET0E5AD05eMG@1IFET0GEeM05YJFP1IFET0H61P05YJFP1GEeL0DE5A
05UIF@1FEUH0EEEE05QHF01JFUX0F5QH05=CD`1EEED0F5QH05UIF@1GEeL0F5QH05MGE`1KFe/0EeMG
05IFEP80EEEE00H0EUIF051@D01EEED0F5QH05IFEP1KFe/205EEE@06051@D01FEUH0G5aL05UIF@1H
F5P0E5AD0P1IFET0501EEED0EUIF05mOG`1OGel0EeMG05UIF@1RHV80Fe]K05QHF01EEED0G5aL05QH
F01GEeL0EUIF051@D01GEeL0Fe]K05EEE@1DE5@0FEUI1P3IfMT100000040fMWI000F0=WIf@030000
003IfMT0fMWI00<0fMWI00D0HF5Q05]KF`1GEeL0G5aL05iNGP02061PH00305eMG@1NGUh0I6AT0080
GemO01<0FUYJ05mOG`1HF5P0GemO06=SH`1HF5P0Fe]K05iNGP1JFUX0GemO05]KF`1JFUX0HV9R05eM
G@1HF5P0G5aL05]KF`1NGUh0EUIF0080HF5Q02L0FUYJ069RHP1QHF40GUiN06EUI@1PH600Fe]K065Q
H@1OGel0H61P05eMG@1KFe/0FUYJ05eMG@1IFET0H61P05YJFP1LG5`0IVIV05]KF`1QHF40F5QH05aL
G01UIFD0HF5Q05mOG`1JFUX0G5aL069RHP1MGEd0IVIV06ATI01IFET0H61P05YJFP1GEeL0HF5Q05iN
GP1SHf<00P1OGel03P1MGEd0HF5Q05IFEP1FEUH0I6AT05mOG`1KFe/0GEeM05QHF01QHF40G5aL05mO
G`1QHF40Fe]K0P1QHF406@1UIFD0Fe]K05iNGP1KFe/0F5QH05ADE01MGEd0GemO06ATI01OGel0HV9R
05aLG01NGUh0HF5Q069RHP1LG5`0I6AT05iNGP1JFUX0GUiN05aLG01OGel0HF5Q06QXJ01TI6@00P1S
Hf<01P1QHF40JVYZ061PH01QHF40GemO065QH@80GemO00L0G5aL05mOG`1RHV80FUYJ069RHP1HF5P0
GUiN0080HF5Q01L0GEeM05aLG01QHF40GUiN05UIF@1LG5`0Hf=S06QXJ01QHF40J6QX061PH01IFET0
HV9R05]KF`1GEeL0IFEU05eMG@1LG5`0IVIV065QH@1KFe/0H61P05aLG002065QH@0<061PH01XJ6P0
Fe]K069RHP1LG5`0FUYJ05]KF`1LG5`0Fe]K05iNGP1SHf<0HF5Q0P1NGUh02P1IFET0GUiN069RHP1F
EUH0F5QH069RHP1MGEd0GUiN05mOG`1NGUh205aLG00B055AD@1TI6@0HF5Q065QH@1KFe/0G5aL05iN
GP1CDe<0G5aL05YJFP1TI6@0GUiN05YJFP1IFET0F5QH05]KF`1JFUX0GEeM0P1PH600401HF5P0G5aL
05]KF`1JFUX0GemO05YJFP1TI6@0Hf=S05mOG`1JFUX0GUiN05eMG@1FEUH0GUiN05mOG`1FEUH205QH
F00G05eMG@1EEED0EeMG05mOG`1DE5@0H61P05]KF`1IFET0FUYJ05aLG01IFET0H61P05eMG@1NGUh0
GEeM05mOG`1NGUh0Fe]K05eMG@1HF5P0GEeM05iNGP1JFUX00P1EEED00`1JFUX0EeMG05YJFP0205eM
G@0F05QHF01IFET0EUIF05ADE01JFUX0G5aL05UIF@1DE5@0EUIF05QHF01IFET0E5AD05iNGP1KFe/0
GEeM05IFEP1CDe<0F5QH05IFEP1OGel0EeMG05EEE@80EeMG01l0GEeM05ADE01EEED0Fe]K05EEE@1G
EeL0De=C05QHF01DE5@0FUYJ05IFEP1NGUh0E5AD05IFEP1NGUh0Fe]K05aLG01PH600E5AD05iNGP1F
EUH0G5aL05MGE`1MGEd0GUiN05MGE`1JFUX0E5AD05QHF01FEUH0FUYJ0080EEEE00@0GemO05EEE@1K
Fe/0F5QH1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00@0H61P05eMG@1O
Gel0Fe]K0P1JFUX04P1MGEd0H61P05mOG`1UIFD0HF5Q069RHP1OGel0HV9R05iNGP1OGel0FUYJ05UI
F@1LG5`0Fe]K05iNGP1QHF40GUiN065QH@80GUiN00h0EEEE05eMG@1LG5`0GUiN061PH01OGel0FEUI
069RHP1LG5`0De=C05UIF@1NGUh0Fe]K05YJFP80H61P00l0EUIF05]KF`1JFUX0J6QX05EEE@1GEeL0
G5aL05eMG@1EEED0F5QH05aLG01PH600GUiN05]KF`1FEUH00P1KFe/0401NGUh0GEeM05iNGP1YJFT0
GemO05]KF`1NGUh0IFEU065QH@1TI6@0IfMW05aLG01RHV80HF5Q05iNGP1LG5`2069RHP0605EEE@1Q
HF40G5aL061PH01HF5P0G5aL0P1NGUh0101PH600HV9R065QH@1PH60205mOG`1705iNGP1VIVH0I6AT
06=SH`1RHV80G5aL05eMG@1LG5`0H61P05mOG`1QHF40Fe]K05YJFP1UIFD0H61P05iNGP1SHf<0H61P
05aLG01PH600HF5Q06ATI01PH600IfMW065QH@1PH600GemO05]KF`1SHf<0IFEU05MGE`1UIFD0Hf=S
05aLG01JFUX0HV9R05UIF@1XJ6P0HF5Q05]KF`1JFUX0G5aL05mOG`1JFUX0HF5Q05]KF`1NGUh0FUYJ
05QHF01QHF40H61P05aLG01NGUh0IVIV061PH01NGUh0Fe]K06UYJ@1SHf<0Fe]K05mOG`1TI6@0GUiN
05eMG@1LG5`0GEeM06EUI@1NGUh0GemO05YJFP1HF5P00P1NGUh03@1TI6@0GUiN05iNGP1NGUh0I6AT
05YJFP1MGEd0H61P05YJFP1IFET0GUiN05QHF01LG5`00P1JFUX0201KFe/0G5aL05]KF`1JFUX0G5aL
05iNGP1KFe/0G5aL0P1PH6005`1TI6@0EEEE05iNGP1LG5`0HV9R05YJFP1RHV80EeMG061PH01RHV80
E5AD05]KF`1MGEd0FEUI05QHF01KFe/0GemO069RHP1GEeL0GEeM06ATI01SHf<0GEeM0080GemO00<0
G5aL05mOG`1LG5`00P1QHF40301MGEd0HV9R05aLG01KFe/0F5QH05iNGP1IFET0Fe]K05YJFP1TI6@0
De=C05IFEP80EeMG00X0EUIF05UIF@1NGUh0DE5A05IFEP1QHF40HV9R05UIF@1GEeL0Fe]K0P1JFUX0
2@1KFe/0DU9B05eMG@1KFe/0GEeM05MGE`1IFET0EeMG05YJFP0205aLG00W05MGE`1EEED0GUiN05YJ
FP1FEUH0EeMG05aLG01JFUX0Fe]K05EEE@1DE5@0F5QH05EEE@1HF5P0EEEE05IFEP1GEeL0FEUI05MG
E`1?Cdl0EEEE055AD@1HF5P0EeMG059BDP1?Cdl0E5AD059BDP1DE5@0FUYJ05UIF@1KFe/0F5QH05EE
E@1HF5P0FUYJ05IFEP1HF5P0EEEE0080F5QH00h0G5aL05=CD`1GEeL0Fe]K05MGE`1LG5`0Fe]K05iN
GP1FEUH0EeMG05]KF`1LG5`0CTi>05UIF@80G5aL00<0HF5Q0=WIf@3IfMT0103IfMT100000040fMWI
000F0=WIf@030000003IfMT0fMWI00<0fMWI00@0GemO05=CD`1MGEd0GUiN0`1LG5`06P1VIVH0GEeM
065QH@1QHF40Fe]K05aLG01MGEd0Hf=S05YJFP1LG5`0GemO05UIF@1HF5P0I6AT05iNGP1LG5`0Hf=S
065QH@1TI6@0HV9R06EUI@1LG5`0I6AT05IFEP1PH600DE5A0P1KFe/01P1UIFD0H61P05]KF`1SHf<0
G5aL05YJFP80GUiN02/0GEeM06ATI01IFET0HF5Q05]KF`1QHF40GEeM05YJFP1GEeL0G5aL05YJFP1H
F5P0EUIF05]KF`1MGEd0F5QH05aLG01JFUX0HF5Q05UIF@1OGel0Hf=S059BDP1LG5`0H61P05YJFP1O
Gel0Fe]K065QH@1LG5`0GemO05aLG01MGEd0G5aL05]KF`1MGEd0Fe]K06MWI`1SHf<0FUYJ05iNGP1P
H600GemO0080HV9R01T0HF5Q06=SH`1OGel0GUiN065QH@1RHV80FUYJ05iNGP1OGel0HF5Q06ATI01O
Gel0Fe]K05mOG`1MGEd0GUiN069RHP1QHF40GUiN05eMG@1LG5`0GEeM06ATI01SHf<0HF5Q0080H61P
01d0GemO06IVIP1LG5`0FUYJ05mOG`1UIFD0HF5Q05iNGP1MGEd0G5aL05iNGP1QHF40GemO05MGE`1T
I6@0HV9R06=SH`1OGel0HF5Q05mOG`1IFET0Hf=S05YJFP1RHV80IFEU061PH01RHV80GEeM05aLG002
065QH@0805]KF`1JFUX0IfMW065QH@1MGEd0HF5Q069RHP1TI6@205mOG`0=05YJFP1RHV80EeMG05IF
EP1LG5`0F5QH05MGE`1RHV80HF5Q05aLG01SHf<0GemO05iNGP0205aLG00:05mOG`1IFET0FEUI05MG
E`1PH600HV9R05iNGP1OGel0GUiN061PH080GEeM00T0F5QH05YJFP1MGEd0EUIF065QH@1KFe/0Hf=S
05UIF@1LG5`00`1MGEd0801HF5P0FUYJ05mOG`1LG5`0FUYJ05]KF`1OGel0GEeM05iNGP1IFET0GEeM
05]KF`1MGEd0EeMG05]KF`1PH600G5aL05YJFP1MGEd0G5aL05MGE`1MGEd0EUIF05ADE01LG5`0HF5Q
05eMG@1RHV80GEeM05UIF@1LG5`0FUYJ0P1PH6001`1LG5`0Fe]K05aLG01BDU80Fe]K05MGE`1JFUX0
0P1LG5`0101NGUh0FUYJ05UIF@1EEED205YJFP0705MGE`1HF5P0FUYJ05QHF01CDe<0FUYJ05IFEP02
05UIF@80EeMG00L0FUYJ05ADE01BDU80FUYJ05UIF@1FEUH0EEEE0080EUIF01L0Cdm?05]KF`1GEeL0
G5aL05=CD`1MGEd0FEUI05EEE@1FEUH0F5QH04e=C@1FEUH0DU9B05ADE01@D500De=C05]KF`1FEUH0
EEEE05aLG01ADE40F5QH05]KF`0205EEE@0A05mOG`1NGUh0EUIF05]KF`1EEED0GemO05EEE@1DE5@0
D51@05YJFP1IFET0EeMG05ADE01OGel0E5AD05UIF@1NGUh00`1HF5P01@1JFUX0EEEE05=CD`1KFe/0
FUYJ00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0505]KF`1IFET0GUiN
05]KF`1MGEd00`1PH600801TI6@0GemO06EUI@1QHF40GemO05UIF@1OGel0GEeM05iNGP1QHF40GEeM
06ATI01JFUX0G5aL05UIF@1QHF40GEeM05YJFP1OGel0Fe]K05aLG01GEeL0GUiN05mOG`1SHf<0EeMG
069RHP1NGUh0F5QH05iNGP1JFUX0GemO0P1NGUh2069RHP0305UIF@1KFe/0H61P0080FEUI01X0G5aL
05mOG`1DE5@0HF5Q05YJFP1IFET0GUiN05mOG`1EEED0IVIV05mOG`1HF5P0FUYJ05UIF@1JFUX0E5AD
05mOG`1LG5`0GemO069RHP1HF5P0HV9R061PH01OGel0HF5Q061PH080G5aL00`0EeMG05eMG@1MGEd0
JFUY05]KF`1NGUh0GEeM05iNGP1VIVH0GemO05MGE`1SHf<205iNGP0:05mOG`1UIFD0FEUI05IFEP1L
G5`0HV9R065QH@1JFUX0GemO05]KF`80H61P00L0G5aL061PH01MGEd0Fe]K05mOG`1JFUX0IVIV0080
GemO00l0GUiN061PH01PH600GemO05aLG01PH600HV9R06EUI@1OGel0GUiN05mOG`1GEeL0Fe]K05eM
G@1YJFT00P1IFET02`1KFe/0G5aL05iNGP1RHV80GEeM065QH@1PH600Fe]K05UIF@1QHF40IVIV0080
GEeM0P1NGUh02`1MGEd0F5QH05mOG`1OGel0F5QH06ATI01JFUX0HV9R06ATI01KFe/0GemO0080FEUI
00D0Hf=S061PH01JFUX0Fe]K05mOG`02061PH00?05]KF`1NGUh0Fe]K05]KF`1JFUX0Hf=S069RHP1P
H600HV9R05aLG01IFET0HF5Q05]KF`1QHF40HV9R0080GUiN00/0HV9R05UIF@1JFUX0HV9R05EEE@1L
G5`0GemO06QXJ01SHf<0FEUI05aLG00205iNGP0;05]KF`1JFUX0Hf=S05IFEP1OGel0Fe]K05QHF01C
De<0H61P05]KF`1LG5`00P1QHF40701TI6@0F5QH05eMG@1JFUX0J6QX065QH@1IFET0FUYJ05IFEP1I
FET0G5aL05YJFP1PH600GEeM05YJFP1MGEd0G5aL05UIF@1TI6@0HV9R05]KF`1JFUX0J6QX05eMG@1P
H600Fe]K061PH01EEED205YJFP0505]KF`1OGel0GEeM05UIF@1JFUX00P1LG5`0201IFET0DU9B05YJ
FP1JFUX0F5QH05]KF`1JFUX0EUIF0P1LG5`02P1JFUX0EEEE05UIF@1HF5P0EeMG05EEE@1IFET0FUYJ
05MGE`1NGUh205aLG080De=C0P1GEeL05P1NGUh0GEeM05QHF01CDe<0E5AD05aLG01GEeL0FEUI05IF
EP1HF5P0DU9B04m?C`1GEeL0FUYJ065QH@1DE5@0DU9B05YJFP1IFET0EUIF05QHF01FEUH205QHF00D
05YJFP1HF5P0F5QH05QHF01MGEd0Fe]K05aLG01@D500GUiN05eMG@1CDe<0D51@069RHP1IFET0Fe]K
05iNGP1MGEd0F5QH05UIF@1BDU860=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3I
fMT0901FEUH0DU9B069RHP1FEUH0EeMG05ADE01FEUH0HF5Q05aLG01JFUX0DU9B055AD@1EEED0GemO
05aLG01DE5@0EUIF05aLG01EEED0FUYJ05EEE@1GEeL0DU9B05=CD`1MGEd0E5AD05EEE@1>CTh0EUIF
05MGE`1>CTh0D51@05=CD`1FEUH0FEUI05aLG080EeMG01l0FUYJ05EEE@1?Cdl0F5QH055AD@1CDe<0
EUIF051@D01BDU80E5AD05EEE@1@D500EeMG059BDP1ADE40FEUI059BDP1NGUh0Fe]K055AD@1:BTX0
EeMG04e=C@1NGUh0FEUI05YJFP1FEUH0Bd];04m?C`1CDe<0EeMG0080E5AD00<0F5QH05MGE`1JFUX0
0P1JFUX04P1MGEd0DE5A05EEE@1DE5@0De=C05QHF01KFe/0F5QH05EEE@1JFUX0G5aL05YJFP1EEED0
Fe]K05MGE`1KFe/0De=C05IFEP80EeMG00<0GUiN055AD@1EEED00P1FEUH00`1HF5P0EUIF05=CD`02
055AD@0G05=CD`1HF5P0FEUI05EEE@1IFET0EeMG05UIF@1JFUX0GEeM05UIF@1HF5P0G5aL065QH@1O
Gel0H61P05EEE@1FEUH0GUiN05UIF@1GEeL0F5QH05MGE`1EEED00P1JFUX06@1HF5P0Fe]K05YJFP1E
EED0De=C04m?C`1IFET0DE5A05EEE@1IFET0EUIF05=CD`1EEED0EUIF059BDP1DE5@0EUIF05ADE01K
Fe/0EeMG05IFEP1LG5`0FUYJ05iNGP1MGEd00P1EEED07@1GEeL0CDe=05IFEP1HF5P0EEEE059BDP1C
De<0F5QH06UYJ@1EEED0E5AD05=CD`1GEeL0DU9B05EEE@1ADE40EeMG059BDP1FEUH0De=C05ADE01J
FUX0E5AD05IFEP1JFUX0E5AD05aLG01=CDd0EUIF0080EEEE01L0CDe=05UIF@1DE5@0HF5Q05UIF@1<
C4`0EEEE04i>CP1ADE40EEEE05YJFP1DE5@0D51@04m?C`1BDU80De=C04e=C@1EEED0EeMG04];B`1C
De<0FUYJ059BDP0205MGE`80EUIF00@0D51@05IFEP1FEUH0DE5A0P1>CTh05P1IFET0EeMG05ADE01=
CDd0GEeM05IFEP1ADE40FEUI055AD@1JFUX0DE5A05=CD`1>CTh0EeMG05QHF01ADE40D51@05=CD`1;
Bd/0De=C04m?C`18B4P204i>CP0D05IFEP1>CTh0D51@051@D01ADE40CDe=04];B`1?Cdl0CDe=05IF
EP1CDe<0E5AD04i>CP1?Cdl0D51@04a<C01HF5P0Bd];04i>CP1?Cdl205MGE`0A055AD@19BDT0DU9B
051@D015ADD0AdM7059BDP1<C4`0Cdm?04Q8B01CDe<0BDU905EEE@1<C4`0E5AD04Y:BP1;Bd/00P1@
D5000`1?Cdl0CTi>055AD@0204e=C@0D04M7A`16ATH0C4a<051@D01=CDd0DU9B04e=C@1>CTh0DU9B
04e=C@1EEED0CTi>05=CD`1DE5@0EUIF055AD@1=CDd0Bd];059BDP1DE5@205=CD`H0fMWI0@000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WIfD@0fMWI0@0000010=WIf@005P3IfMT00`000000
fMWI0=WIf@3o0=WIfD@0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WIfD@0fMWI
0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI03X0fMWI00<0
00000=WIf@3IfMT0>`3IfMT00`000000fMWI0=WIf@0j0=WIf@030000003IfMT0fMWI03X0fMWI00<0
00000=WIf@3IfMT0>`3IfMT00`000000fMWI0=WIf@0:0=WIf@4000000@3IfMT001H0fMWI0P000004
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0:
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0:
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0:
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT02@3IfMT200000040fMWI000F0=WI
fOl00000B00000010=WIf@00o`3IfMUO0=WIf@00o`3IfMUO0=WIf@00o`3IfMUO0=WIf@00o`3IfMUO
0=WIf@00\
\>"],
  ImageRangeCache->{{{0, 349}, {349, 0}} -> {-46.2288, -38.9981, 1.62945, \
1.62945}}]
}, Open  ]],

Cell[TextData[{
  "  As a final step, we can adjust ",
  StyleBox["PlotRange",
    FontFamily->"Courier New"],
  " to, in essence, adjust the contrast of the image. In this case, we can \
see that the core of M87 has a jet of material arising from a supermassive \
black hole at its core."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListDensityPlot[workingimage[\([1, 2]\)], 
        PlotRange \[Rule] {75, 2500}, Mesh \[Rule] False, 
        ImageSize \[Rule] 350];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 350 350 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.001878 0.0192308 0.001878 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.20703 -0.0125 -9 -9 ]
[.20703 -0.0125 9 0 ]
[.39483 -0.0125 -9 -9 ]
[.39483 -0.0125 9 0 ]
[.58263 -0.0125 -9 -9 ]
[.58263 -0.0125 9 0 ]
[.77043 -0.0125 -9 -9 ]
[.77043 -0.0125 9 0 ]
[.95823 -0.0125 -9 -9 ]
[.95823 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .20703 -18 -4.5 ]
[-0.0125 .20703 0 4.5 ]
[-0.0125 .39483 -18 -4.5 ]
[-0.0125 .39483 0 4.5 ]
[-0.0125 .58263 -18 -4.5 ]
[-0.0125 .58263 0 4.5 ]
[-0.0125 .77043 -18 -4.5 ]
[-0.0125 .77043 0 4.5 ]
[-0.0125 .95823 -18 -4.5 ]
[-0.0125 .95823 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.20703 0 m
.20703 .00625 L
s
[(100)] .20703 -0.0125 0 1 Mshowa
.39483 0 m
.39483 .00625 L
s
[(200)] .39483 -0.0125 0 1 Mshowa
.58263 0 m
.58263 .00625 L
s
[(300)] .58263 -0.0125 0 1 Mshowa
.77043 0 m
.77043 .00625 L
s
[(400)] .77043 -0.0125 0 1 Mshowa
.95823 0 m
.95823 .00625 L
s
[(500)] .95823 -0.0125 0 1 Mshowa
.125 Mabswid
.05679 0 m
.05679 .00375 L
s
.09435 0 m
.09435 .00375 L
s
.13191 0 m
.13191 .00375 L
s
.16947 0 m
.16947 .00375 L
s
.24459 0 m
.24459 .00375 L
s
.28215 0 m
.28215 .00375 L
s
.31971 0 m
.31971 .00375 L
s
.35727 0 m
.35727 .00375 L
s
.43239 0 m
.43239 .00375 L
s
.46995 0 m
.46995 .00375 L
s
.50751 0 m
.50751 .00375 L
s
.54507 0 m
.54507 .00375 L
s
.62019 0 m
.62019 .00375 L
s
.65775 0 m
.65775 .00375 L
s
.69531 0 m
.69531 .00375 L
s
.73287 0 m
.73287 .00375 L
s
.80799 0 m
.80799 .00375 L
s
.84555 0 m
.84555 .00375 L
s
.88311 0 m
.88311 .00375 L
s
.92067 0 m
.92067 .00375 L
s
.99579 0 m
.99579 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .20703 m
.00625 .20703 L
s
[(100)] -0.0125 .20703 1 0 Mshowa
0 .39483 m
.00625 .39483 L
s
[(200)] -0.0125 .39483 1 0 Mshowa
0 .58263 m
.00625 .58263 L
s
[(300)] -0.0125 .58263 1 0 Mshowa
0 .77043 m
.00625 .77043 L
s
[(400)] -0.0125 .77043 1 0 Mshowa
0 .95823 m
.00625 .95823 L
s
[(500)] -0.0125 .95823 1 0 Mshowa
.125 Mabswid
0 .05679 m
.00375 .05679 L
s
0 .09435 m
.00375 .09435 L
s
0 .13191 m
.00375 .13191 L
s
0 .16947 m
.00375 .16947 L
s
0 .24459 m
.00375 .24459 L
s
0 .28215 m
.00375 .28215 L
s
0 .31971 m
.00375 .31971 L
s
0 .35727 m
.00375 .35727 L
s
0 .43239 m
.00375 .43239 L
s
0 .46995 m
.00375 .46995 L
s
0 .50751 m
.00375 .50751 L
s
0 .54507 m
.00375 .54507 L
s
0 .62019 m
.00375 .62019 L
s
0 .65775 m
.00375 .65775 L
s
0 .69531 m
.00375 .69531 L
s
0 .73287 m
.00375 .73287 L
s
0 .80799 m
.00375 .80799 L
s
0 .84555 m
.00375 .84555 L
s
0 .88311 m
.00375 .88311 L
s
0 .92067 m
.00375 .92067 L
s
0 .99579 m
.00375 .99579 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.20703 .99375 m
.20703 1 L
s
.39483 .99375 m
.39483 1 L
s
.58263 .99375 m
.58263 1 L
s
.77043 .99375 m
.77043 1 L
s
.95823 .99375 m
.95823 1 L
s
.125 Mabswid
.05679 .99625 m
.05679 1 L
s
.09435 .99625 m
.09435 1 L
s
.13191 .99625 m
.13191 1 L
s
.16947 .99625 m
.16947 1 L
s
.24459 .99625 m
.24459 1 L
s
.28215 .99625 m
.28215 1 L
s
.31971 .99625 m
.31971 1 L
s
.35727 .99625 m
.35727 1 L
s
.43239 .99625 m
.43239 1 L
s
.46995 .99625 m
.46995 1 L
s
.50751 .99625 m
.50751 1 L
s
.54507 .99625 m
.54507 1 L
s
.62019 .99625 m
.62019 1 L
s
.65775 .99625 m
.65775 1 L
s
.69531 .99625 m
.69531 1 L
s
.73287 .99625 m
.73287 1 L
s
.80799 .99625 m
.80799 1 L
s
.84555 .99625 m
.84555 1 L
s
.88311 .99625 m
.88311 1 L
s
.92067 .99625 m
.92067 1 L
s
.99579 .99625 m
.99579 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .20703 m
1 .20703 L
s
.99375 .39483 m
1 .39483 L
s
.99375 .58263 m
1 .58263 L
s
.99375 .77043 m
1 .77043 L
s
.99375 .95823 m
1 .95823 L
s
.125 Mabswid
.99625 .05679 m
1 .05679 L
s
.99625 .09435 m
1 .09435 L
s
.99625 .13191 m
1 .13191 L
s
.99625 .16947 m
1 .16947 L
s
.99625 .24459 m
1 .24459 L
s
.99625 .28215 m
1 .28215 L
s
.99625 .31971 m
1 .31971 L
s
.99625 .35727 m
1 .35727 L
s
.99625 .43239 m
1 .43239 L
s
.99625 .46995 m
1 .46995 L
s
.99625 .50751 m
1 .50751 L
s
.99625 .54507 m
1 .54507 L
s
.99625 .62019 m
1 .62019 L
s
.99625 .65775 m
1 .65775 L
s
.99625 .69531 m
1 .69531 L
s
.99625 .73287 m
1 .73287 L
s
.99625 .80799 m
1 .80799 L
s
.99625 .84555 m
1 .84555 L
s
.99625 .88311 m
1 .88311 L
s
.99625 .92067 m
1 .92067 L
s
.99625 .99579 m
1 .99579 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
512 string
512 512 8 [512 0 0 512 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
161615161616161715151716171716161716161615161716161716171616171616171617
171717171716171616171618171717171616161817161717161717161717171716171616
161717181717161617171717171717171617161717181718161818171616171817181818
171717171718181717171717171617181717181718181716181717171717171717181817
181718181817171718191818181719181618191818181818171818181817181818181718
181817181718181718181818171A18181918181817181818191919181A18191819191818
191A1918191919191919191A1A1A191A1919191A1A18191A1A19191B1A1A1A1919191B1A
191A1A1A1B1B1A1B1B1B1B1B1B1A1A1B1A1B1B1A1B1B1A1B1C191A1A1B1A1A1B1B19191A
1C1A1A1B1A1B1A1A1A1A1A1B1A1A1B1B1B1A1B1B1B1A1A1A1A1A191A1A1A1B1A19191A1A
1B1A1A181A1B1A1A1919191A1A1A1B1A191A1A19181A1919191A1B1A191A191A1919191A
1B1A1A1A1A1A1A1B1A18191A1A1B1A181818191919191919181918181819181818191918
181718181818181818181918181818181718181818181817191817181618161818181717
181817181817171617171616171718161817171717171717161716161818191718161815
181717161817171817171617161616161718171717161716161616171717161616171617
1717161717161616
171616171816181717171716171817181818181717171818171818181718181717171718
171617171817171817181817181718181819181818171818181918181818181818181818
181718171718181818171818171817181818191818181818191818191818181A19181919
181818181718181919191919181918181918181919191917191918181919191919191818
191A1819191919181819181A191819191A18191819191919191819181A1919181A191919
1A1919191A19191A191A1919191A1919191A191A1919191A1B1A1A1A1A1A1B1B1A1B1A1A
191B191B1A1A1A1A1B1A1A1B1B1A1B1B1B1B1B1A1B1B1B1B1B1B1C1B1D1B1B1B1A1B1B1B
1C1B1B1B1B1C1C1C1D1B1D1C1C1C1B1C1C1B1B1C1B1C1B1D1C1C1C1C1C1B1A1B1C1C1A1C
1C1C1B1B1B1B1A1C1B1A1B1C1C1D1B1C1C1B1C1C1B1C1C1B1C1C1C1A1B1C1B1B1C1B1A1B
1B1B1B1B1A1A1B1A1B1B1A1B1B1A1B1B1A1B1B1A1B1A1B1A1B1B1A1B1A1A1B1B1B191B19
1A1A1B1A1B1B1B1C1A1B1A1B191A1A1A1A191919191A191A191919191A1A191A1A1A181A
19181A19181919191B1A191819191A18191918191818191A191A191A1919191917171719
181919191817181717181718181819181818171918181817181717181919181818171719
181718181718171918181718171818181718171818171718181816171617171816171717
1816181817161717
171818171919181817181717181818181818181818191819181819191819191817181918
181918181718181818191817181918181818181818191818191818191918191718181917
1A1818191A18191919191918191919191A19191917191A191819191A1A19181A19191A19
191918191919191A181A1A19191A1A18191A18191A1918191919191B191A191A19191819
191918191A181A191A1A1A191B1A191A1A1A1A1B191A1A191A181A1A1A1B1A1A1B191A1A
1A1A19191A1A191A1A191A1A1A191B1A1A1B1B1A1A1A1A1A1B1B1A1B1B1C1A1C1B1C1B1A
1B1B1B1B1B1B1A1A1A1C1C1B1B1B1C1B1C1B1C1C1C1B1A1C1C1B1B1C1C1B1D1C1B1C1D1C
1C1C1B1C1D1C1D1C1D1D1C1D1C1D1D1C1D1C1C1C1C1C1C1D1C1C1C1D1D1C1C1C1D1C1D1D
1C1D1C1D1C1C1B1C1C1C1A1D1C1D1C1E1D1D1C1D1D1C1C1D1D1D1B1C1D1C1C1D1B1C1D1C
1B1B1C1B1B1C1B1D1B1C1C1C1B1C1C1B1C1B1B1A1C1B1C1B1B1A1B1C1B1B1B1B1A1C1B1B
1C1B1B1C1D1C1C1C1C1A1C1B1B1B1B1B1A1A1A1B1B1A1B1A1A191B191A191A1A1A1A1A1A
1A1A19191B19191A191A1A1A18191A1919191A191A191A19191A1A1A1918191819191818
181A1A19191919181919191819171818181918191A191A181819191A1A19191919181719
181919181919191819181819181817171919181917171718181617181818171617171718
1818191918181817
191617181819181918181819161719181818191818181819181A1919181A191918191818
181918191818191919181919191A18181818191B1A1A1819191919191A181A191A191918
19181A1818191A19191918191A191B1A1A181A1B1A19181A1B19191A1A19191A191A1A1B
1B1B191A1A1A1A1A1A19191A1A1A1A1A1A1A1A191A191A1A191919191A1918181A1A1A1A
1A1A191A1A1B19191A1B1A191B1C1A191B1B1C1C1B1A1B191A191B1A191A1B1A1A1B1B1A
1B1A1A1B1A1A1A1A1B1A1B1A1A1B1B1B1B1B1B1B1B1B1A1A1C1B1A1A1C1C1C1B1C1B1B1B
1C1B1B1B1C1B1B1B1C1C1C1B1C1B1C1B1C1C1C1C1C1B1D1C1D1D1C1C1B1D1C1B1D1D1C1C
1C1D1C1E1C1F1E1D1D1E1C1D1E1D1C1C1C1C1D1E1C1C1D1C1E1D1C1D1C1D1C1D1D1C1D1C
1C1D1D1B1D1B1D1C1D1D1C1D1C1C1D1D1E1E1C1E1D1D1E1C1B1C1D1E1D1C1C1D1D1C1D1D
1D1C1C1C1D1C1D1C1D1C1B1B1C1C1D1B1B1B1B1B1D1C1B1D1C1D1C1C1B1C1C1C1B1D1C1C
1C1B1A1D1B1C1C1C1A1C1A1B1A1B1B1B1B1A1B1B1B1A1B1B1B191B1A1A1B1A1B1B1C191A
1A1A1A1A1A1A1B1A191A1A1A1B191B1A1A1B1A191A191A181A191A1A181B1A1A1B1A191A
181A19191919191918191A1A1A1A19191919191918181A18191819191819181918191918
191918181919181918191919191919191918181818181919171717171818181919191818
1819181718171818
1A19191919191818181919191A1A1A19181919181919181918181A191A1A1818191A191A
19191A1919191919191919181A1A1A1A191A1A1A191A1A19191A1A1A19181A1918191A18
1A18191919191A191919181B1A1A19191A1B1A1B1A1A1B1A19191A1B191A1A1B1A1B1A19
1A1A1A1A191A1B191A19191A1B1B1A1A1A1B1B1A1B1A1A1A1A1A1A191B1B1A1A1A19191B
1A1A1A1B1A1B1A1A1A1A1A1A1A1A1B1B1C1B1B1C1B1B1A1B1B1B1B1B1A1B1A1B1A1B1C1B
1B1C1B1A1B1A1A1B1B1B1B1B1A1A1B1B1A1A1C1B1B1C1B1B1A1C1D1C1C1C1B1B1B1C1D1D
1C1C1B1C1C1C1C1D1C1C1C1B1D1B1C1C1C1D1D1D1C1C1D1C1B1C1D1D1D1C1C1D1C1D1E1C
1C1C1D1C1D1D1D1D1E1C1D1E1D1D1E1C1E1D1C1D1C1E1C1D1F1E1E1D1D1C1D1D1D1D1D1D
1C1C1D1D1D1D1D1D1C1D1E1D1C1E1C1E1E1D1E1D1D1E1E1D1C1D1D1E1D1C1D1C1E1D1D1D
1C1D1B1D1D1C1C1C1C1D1C1C1D1D1D1C1D1C1C1C1B1C1C1D1C1C1C1C1C1C1C1C1C1C1B1C
1B1C1B1D1C1D1D1C1B1B1C1C1C1C1A1A1B1C1C1C1B1A1B1B1A1B1C1A1B1A1C191B1A1B1A
1A1A1C1A1A1A1A1B1A1A1B1A1B1B1A191A1A191B1A1A1A191A1A1A191A1A1B1A1A19181B
1A1A1A1A19191A181A1A1A1A1A181819181919191A181817191A1B19191A191A1919181A
18181A18191918181A191919181819191919181819181718191718191818181A191A1818
1918181818181718
191919181819191A191919191A191A191918181A19191918191B1A1A1B1A1A191A191A19
1A1B1819191B1819191A1919191919191B19191918191A191A191A191A1B191A191A191A
191A1A1A1A1A1A1A191B1B1A1A191A1A1A1A18191B1B1A191A1A19191B1A1B191A1B1A1B
191A1B1A1A1B1B1B1B191A191A1A1A1C1B1B1A1A1B1A1A191A1B1A1A1A1A1C1B1B191B1A
1A1A1B1A1B1B1A1B1A1A1B1B1B1A1B1B1B1B1B1A1B1A1B1A191A1B1A1B1B1B1B1B1B1C1B
1B1B1B1B1B1B1C1A1B1B1A1A1C1C1B1B1B1B1B1C1C1B1C1C1B1C1D1C1C1B1C1C1B1C1D1D
1B1C1C1D1C1C1B1C1C1D1C1B1D1B1C1C1C1D1D1E1D1C1D1D1D1C1F1C1E1C1C1C1C1D1D1E
1D1D1D1E1D1E1D1E1D1D1E1E1D1D1D1D1C1C1D1D1D1E1E1D1F1E1F1D1D1D1D1E1E1D1D1E
1E1E1E1E1E1D1D1D1D1D1D1D1D1D1D1E1E1E1D1E1D1D1D1D1D1D1D1E1E1E1E1D1D1E1D1D
1D1C1D1D1E1B1D1D1D1E1D1D1B1D1D1C1C1D1C1C1C1D1B1C1B1C1D1C1B1D1B1C1B1C1C1C
1D1C1C1C1B1C1C1B1B1D1D1B1C1B1B1C1A1A1B1C1B1B1C1B1A1B1C1C1B1C1A1C1B1A1B1B
1A1C1B1B1A1A1A1B1A1C1B1B1A1B1A1B191A1B1A1A1B1A1B1A1B1A1B1B191A19191A191B
1B1A1A1A191B191A1B1A191A19191A191A191A18191A1819191A19191B191A19191A1A19
1919191918181B18191A191A191818191A1A191A19191818181818191A19191918181818
1818171818181818
1919191A19181919191819191A191A191A19191A19191918191A1A1B1A1A1A1A1A1A1A19
1A19191A1A191919191919191A1A191A1A191A1A191A1919191A191A1B1B191A191B191A
191A1A1A191A1A191A1919191A1A1A1A19191A191A1A1A1A1B1B1A1B1A1B1B1A1B1B1B1A
1A1B1A1B1A1A1B1B1A1A1B1B1A1B191A1B1B1B1B1B1B1A1A1A1B1B1A191B1B1C1A1C1B1A
1B1B1B1A191B1B191A1A1B1A1B1B1A1C1B1B1B1A1C1B1A1B1B1B1B1B1A1B1C1C1B1B1B1B
1B1B1C1B1C1C1B1B1A1C1C1B1A1C1B1B1C1C1C1B1C1C1C1C1B1C1C1C1B1C1C1C1C1D1C1D
1D1C1C1D1E1B1D1C1C1D1D1C1C1C1D1C1E1D1D1E1D1E1C1D1D1D1D1D1D1D1E1C1E1D1D1D
1C1D1C1D1D1E1D1E1D1E1D1F1D1E1F1E1E1E1D1F1E1D1E1F1F1E1E1E1E1F1D1D1E1D1E1D
1D1C1F1C1E1E1D1D1D1D1D1D1E1C1D1E1E1E1D1C1E1E1D1D1D1E1E1C1C1E1D1E1F1E1E1D
1E1D1C1D1D1D1E1D1C1D1D1D1D1C1D1D1D1D1C1C1C1C1C1B1C1B1D1B1C1C1D1D1C1B1C1D
1C1C1D1C1D1C1C1C1C1C1D1C1C1C1B1B1B1B1B1B1B1B1B1C1B1C1B1B1B1A1B1B1C1B1B1A
1B1B1B1A1B1B1C1B1A1C1A1C1B1B1A1B1A1B1A1B1D1B1A1B1A1A191A1B191A1B1A191A1A
1A191A181A191A191A1B191C1919191819191B191918191918191A19191A1A1919191A19
191A1918181919191A1A181A181919191918191919181819191819181918171818191918
1918181719181819
19191A191819181A19191A1A191A18191A1A19191919191A1A1A1A1A1A1A1A191A19191A
1A1B191B19191A1A1A19191A19191A191A1A19191B191A1A1B1A191A181A19191A191919
1A191A1A1A1A191A1B1A1A1A1A1A1A1B1A1B1A1A1A1A1C1A1B1A1C1C191A1B1B1B1B1B1C
1B191A1B1A1A1B1B1A1B1B1A1A1A191C1A1A1A1B1A1B1B1B1B1C1B1A1A1B1B1A1B1B1B1B
1B1B1B1A1B1B1B1B1A1C1B1B1C1C1B1B1C1B1B1A1B1B1A1C1A1B1C1B1B1A1B1B1C1B1C1C
1B1B1B1B1B1B1B1C1B1C1C1C1C1C1B1D1A1C1C1C1C1C1C1D1D1C1D1C1D1C1C1C1C1C1C1C
1D1D1C1B1D1B1D1D1C1D1B1D1D1D1D1E1D1D1C1E1D1D1D1D1E1E1C1E1E1E1C1D1E1D1D1E
1E1E1F1E1E1E1F1D1C1E1E1E1D1F1E1E1E1E1E1E1F1E1F1F1F1F1E1E1E1F1D1E1E1D1E1C
1E1E1D1F1E1D1C1E1D1E1E1E1D1F1D1D1D1E1E1E1D1E1E1C1E1D1E1D1D1E1D1E201E1E1E
1E1E1D1D1C1E1C1C1C1E1C1D1C1C1C1D1D1D1D1D1D1D1C1D1D1D1D1C1D1C1C1C1C1C1C1B
1B1C1C1B1C1B1B1D1C1C1B1D1B1C1C1D1C1C1D1B1C1D1D1B1B1B1B1B1C1B1D1C1B1B1B1D
1C1A1B1B1C1C1B1B1B1B1C1C1C1B1B1A1A1A1B1A1A1A1B1B1A1A1B1B1A1A1A191A1A1A1A
1A1A1B1B191A1A1A1A191A1A191A19191A1B1A19191A1A191A19191A1A1A181A18191A1A
181919181A1A191A191B191A1A181918191A1918191919191A1919191819191918191918
191819181918171A
1A19191A1B19181A19181A181A1B181A18191A18191A1A191A191A1A1A191B1B1919191A
191A1A1A19191A1A191A1A19191A191A191A1A1B1B1A1A1A191A1A1A1A1A19191A1B1919
1A1A1A1A1A1A1A1A1A1B1A1A1B1A1B1A1A1A1A1B1A1B1A1B191A1A191B1B1B1B1A1A1B1B
1A1C1A1A1A1B1A1C1B1A1B1B1B1B1A1B1B1A1A1C1B1B1B1B1A1A1C1A1A1B1D1B1B1B1B1A
1C1A1A1A1B1B1C1C1A1B1B1B1C1B1B1B1A1C1C1B1B1B1B1B1C1C1B1B1B1B1C1A1B1B1B1B
1B1B1B1B1C1B1C1A1B1B1B1C1B1B1D1B1C1B1C1C1B1C1B1B1C1C1D1D1C1C1B1D1D1C1C1D
1B1C1C1C1C1C1C1D1B1C1E1D1C1D1E1D1C1C1D1E1E1D1D1E1C1D1D1E1D1D1B1D1E1D1D1E
1E1E1D1D1E1D1D1F1C1F1E1E1D1D1E1E1E1F1D1D1E1D1D1D1E1E1E1E1E1E1F1E1F1D1E1E
1E1D1D1E1E1D1E1F1D1E1D1E1E1F1E1D1E1D1E1D1D1C1D1E1E1D1E1D1E1F1F1E1E1F1E1E
1E1E1D1C1C1C1C1D1E1D1E1D1E1D1D1D1D1E1C1D1E1D1D1D1C1D1C1D1C1E1D1D1C1D1B1C
1C1C1C1B1D1C1B1C1B1B1C1C1C1C1B1C1D1C1B1C1C1C1B1D1C1C1C1A1C1C1C1B1A1B1B1B
1B1C1C1B1C1B1C1C1B1B1C1B1A1C1B1B1B1A1A1D1B1A1A1C1C1A1A1A1A1B1C191A1B1B19
1B1A1A1B1A191C1A1A191B1B1A1A1A1B1A191A191A191A1A1A1A191A1B1A1A19191A191A
1A191A1819191A191A191919181A191A1819181819191A19191A18191A191A1818191818
18191818191A1819
1A191919191A1919191A19181A1A1A1A1A1A1A191A181B1A1A1A1B1A1A1A1A1B1A1A1919
1A19191A191A1A1A1A1B1A19191A1A1A191B1B1A1A191A1A1A1A1A191A191A1B1A1A1A1A
19191B1B191A1A1A1A1A191A1A1A1B1B1A1B1A1A191A1A1B1B1B1B1A1B191A1A1A1A1A1B
1A191B1B1B1A1C1A1A1A1B1B1A1B1A1A1A1B191B1A1C1A1C1D1B1A1B1B1C191A1B1A1A1C
1C1C1C1B1B1C1B1C1B1C1B1B1A1A1B1B1B1A1C1B1B1A1B1B1B1C1C1C1B1D1B1A1B1C1C1C
1C1C1C1C1B1A1B1C1C1D1C1C1B1B1B1B1C1D1D1D1B1C1C1D1D1C1D1D1D1C1C1D1B1D1D1D
1C1C1B1E1C1E1D1B1E1D1C1E1C1D1C1D1D1E1D1E1D1E1C1D1D1E1E1E1D1D1C1E1D1D1D1E
1C1E1E1E1E1D1E1F1E1F1E1E1F1E1D1E1D1F1E1E1E1D1E1E1D1F1E1E1E1E1D1F1F1D1E1E
1E1E201D1D1E1D1E1D1E1E1F1E1E1E1E1C1E1E1D1D1D1E1D1D1F1E1E1D1F1F1E1E1E1E1F
1F1D1D1D1D1E1E1D1D1E1E1D1E1D1E1C1C1D1E1E1E1D1B1D1C1D1C1D1C1C1D1D1C1B1C1C
1C1C1C1C1C1C1E1D1D1D1D1C1C1C1C1B1C1D1D1B1C1B1D1C1C1C1B1B1B1C1C1A1D1C1B1B
1B1C1A1B1C1B1C1B1C1C1C1C1C1B1B1C1A1A1B1A1B1A1B1B1B1A1C1B1A1B1B1B1A1B1A1B
1A1A1A1A191A191A191B1A1A1A1B1A191A1A191A1A191A1A1A1A1A19191819191919191A
18191A191A1B191A1A19191A191919191A1A1A1919181918181919191919191718181818
1919191A1819191A
1A191A19191A1A181A1A19191A1919181A18181A191A1A191A1B1B1B191A19191A181919
19181A1A1A191A1A1A1A1A191A1A191A19191A1A1A1A18191A191B1B1B1B1A191A1B1A1A
191A191A191A1A191A1A1A1A1A1A1B1A1B1B1A1B1A1A1B1C1A191B1C1B1A1A1A1A1A1A1B
191B1B1B1A1B1A1B1A1B1B1B1C1B1B1A1B1A1B1A1B1B1A1A1A1B1B1B1B1A1A1B1A1C1B1C
1B1C1B1C1B1B1A1B1B1B1B1B1C1A1B1C1C1C1D1C1B1B1B1B1A1B1C1C1B1C1D1C1D191B1D
1D1B1C1B1C1B1B1B1B1B1C1D1B1C1C1C1C1B1C1C1D1C1C1D1C1D1C1C1D1C1C1D1C1C1C1C
1C1D1D1D1C1D1D1D1C1E1C1C1C1D1E1D1D1E1D1D1D1E1D1C1E1E1D1E1E1D1E1D1D1D1C1E
1E1E1E1E1D1E1E1E1D1F1D1D1D1D1E1E1E1D1E1E1E1E1D1D1D1F1D1E1E1E1E1E1E1E1E1F
1E1E1F1E1F1F1E1E1E1E1F1E1D1D1E1E1E1F1F1D1C1C1D1F1F1E1E1D1D1F1E1E1E1E1F1E
1E1D1D1E1D1C1E1E1E1D1D1B1E1D1E1C1D1D1D1D1D1E1C1D1C1E1D1C1D1D1D1E1B1C1D1D
1C1C1C1C1C1C1C1D1D1C1C1C1C1C1B1B1B1D1D1B1C1A1C1C1A1A1B1B1B1B1C1C1B1B1B1C
1C1C1B1A1B1B1C1C1C1B1C1B1B1A1B1D1B1B1A1B1B1C1B1C1B1A1A1A1A1B1C1B1B19191A
1A1A1B191A1A1A191A1A1A1A1A1A1A191A191A1A191B191919191A1A191A1919191A1A1A
19191A19181A19191918191919181A19181A1919191A1A1A191819191A18191819171818
181A181819181819
1A181A18191A191919191A1A1A191A191A1A1B19191A1A1A1A1A1A1B19191A1A1A1A1A1A
1A191A1A1A1A1A1A1B1A1A1A191A191B1A191A1A19191A1A1A1A1A1A1A1A1A1A1A191A1B
191B191A1A1A191B1B1A1C1A1A1B1B1A1A1A1B19191B1A1A1B1B191B1B1A1A191A1B191B
1A1A1B1A1A1B1B1B1C1B1A1A1B1B1C1A1B1B1A1A1A1A1C1B1C1B1B1C1A1B1B1B1A1B1A1B
1A1A1C1A1C1B1C1A1B1C1A1A1B1B1B1B1C1B1B1B1C1B1A1B1B1C1C1B1A1A1B1B1B1A1C1C
1B1C1B1B1C1C1B1B1B1B1D1B1B1B1B1C1B1A1D1C1C1D1B1C1D1B1C1C1D1C1C1B1C1C1D1C
1C1D1D1E1D1C1D1D1D1D1D1E1D1E1D1E1E1E1C1E1D1D1E1D1D1E1E1F1E1E1E1D1D1E1F1E
1E1E1E1E1F1E1F1F1D1E1E1D1E1E1E1D1E1E1E1E1D1D1F1E1F1E1E1E1F1E1F1E1E1E1E1E
1D1E1D1D1E1E1E1E1F1F1F1E1E1E1E1E1D1D1E1D1E1D1E1F1E1E1E1D1E1E1F1F1E1F1E1F
1E1E1D1D1E1E1C1D1E1E1C1E1D1D1E1D1D1D1D1E1E1D1C1D1D1D1D1D1C1D1C1C1C1C1D1C
1E1C1B1D1C1B1C1D1B1D1B1C1C1B1C1C1B1B1C1B1B1C1B1C1B1B1A1B1C1B1C1D1C1B1C1B
1C1D1C1A1C1C1C1C1B1B1C1C1A1B1B1A1A1B1B1B1C1C1A1B1A1A1A1B1B1B1B1B1B1A1B1A
1A1B191A1A1A191B1B1B191A1B1B1A191A19191A18181A1919191B19191A1A1A19191919
1B19191A19191A1A19191919191A1B1919181A191A19191919191818191A191918191819
1819191918191919
1A191919191A1719191B1A1A1B19191A1A1A1A191B1919191A1A1B191A191A1A19191A1B
1A1A191A1A1A1A191A191A1A1A191A191A1A191A1A191A1A1A1A1A1B1B1A1A1B1B1A1A1A
1B1A1A1B1A1B1A1A191B1B1B1A1B19191B1A1B1A191B1B1919191A1A1A1B1C1B1B1B1A1B
1A1A1A1B1A1B191A1A1B1A1A1B1B1B1B1C1B1C1C1B1B1B1A1A1B1B1C1C1C1B1D1A1B1A1B
1C1C1A1C1C1B1D1B1B1B1B1B1B1B1B1C1C1C1C1B1B1B1C1C1A1B1B1B1C1D1B1B1C1D1D1B
1C1C1B1C1B1C1D1D1C1C1D1C1B1C1D1D1B1B1D1C1C1C1B1D1D1C1D1D1D1D1C1D1D1D1C1E
1C1C1D1D1D1D1E1C1D1E1E1E1E1D1E1D1D1C1E1D1E1D1F1F1C201F1D1E1D1E1F1E1E1E1F
1C1D1D1D1F1E1D1D1E1E1F1F1F1D1D1D1D1D1E1E1F1E1E1E1F1D1F1E1E201F1F1E1E1E1E
1E1F1E1E1F1F201F201E1E1F1E1F1E1D1F1E1E1E1E1E1E1E1D1D1E201E1F1F1D1E201E1E
1D1D1E1E1E1D1D1D1C1F1D1C1D1D1E1E1D1D1D1D1E1C1E1E1D1D1D1E1C1D1D1D1B1C1D1C
1D1D1C1C1C1B1D1D1C1C1B1B1D1B1D1C1B1C1B1C1B1B1B1B1B1C1B1B1C1C1B1D1B1B1B1C
1C1B1A1B1B1B1C1C1D1D1C1B1B1A1B1C1B1A1B1B1B1B1B1B1A1B1A1B1A1A1A1A191A1B1B
191A191A19191919191A191A1A1A1A1A1A191A18191A1A1919191A1B19191A1A1A191A1A
19191A1919191A1A19181A19191A19191919191A191918191919191918191A1919191919
1A1918191A19191B
1B1A1819191A1A191919191919181A1A191A19191A191A1C1A1A1A1A1A191A1A1A191A19
1A1A1A191A1A1A1B1A1A1A1A191A191A1A1A1A1A1A19191A1A1B1A1A1B1B191A1A191B1B
1A1A1A191A1A1B1A1A1A1A191A1A1C1B191A1B1A1B1B1B19191B1B1B191A1A1A1B1B1A1B
1B1C1B1A1A1A1C1B1B1B1A1C1A1B1B1B1C1B1A1A1B1B1B1C1B1B1B1C1B1B1A1C1C1C1B1B
1B1B1B1C1C1B1C1C1B1B1B1B1A1C1C1A1B1C1B1B1C1C1B1C1D1A1A1C1B1D1C1C1B1B1C1C
1B1C1D1B1B1C1C1C1C1E1C1C1D1C1D1C1D1D1C1C1D1E1C1E1E1E1C1E1D1E1E1D1C1D1D1D
1C1D1D1C1D1C1E1D1C1E1C1F1E1D1D1E1E1D1E1D1D1D1E1E1D1E1F1C1D1E1D1E1E1E1E1E
1E1E1E1E1D1D1D1F1F1F1E1F1E1D1E1E1F1F1D1E1E1F1F201E1E1F1E1D1E1F1E1E1E1E1E
1E1F1F1E201F1F1F1F1F1E1F1D1F1E1E1D1D1E1D1F1F1F1E1D1D1D1E1E1E1F1D1E1E1D1E
1E1D1E1D1D1D1E1E1E1D1E1D1E1D1D1D1D1E1C1E1D1E1C1E1E1D1C1D1C1C1D1D1C1D1C1D
1C1D1D1D1B1C1C1C1B1C1C1D1B1C1B1C1C1D1C1D1C1D1C1B1C1B1C1B1B1B1A1B1C1B1B1B
1C1A1B1B1A1B1B1D1B1B1B1A1B1C1B1A1B1B1A1A1C1B1B1A1B1A191B1A1A1B1C1A1B1B1A
191A1A1B1A1A1A191A1A1B191A1A1919191A1A1A191A1919191A191A18191B1B181A1A1A
191919191A1918181A1819191A1B181A1919191919191A18191818191819191919181818
191818191A19191A
1A19181A19171A1919191A1919191B191A1A191919191A1A191A191B1A19191B1A1A191A
19191919191B1B1A1A1A1919191B1A1A191A1A1A191A19191A1A1A1A1A1B1A1B1B1A1919
191A1A1A191A1A1A19191A1B1B1A1A1A1A1A1B1A1A1B1B1A1B1B1B1B1B1B1B191B1A1B1B
1A1A1B1B1B1A1A1B1B191A1B1B1B1B1C1C1B1A1A1A1C1C1A1B1B1C1B1B1B1C1B1C1B1C1C
1B1C1C1C1C1B1C1B1C1B1C1C1C1C1B1B1B1A1C1D1C1D1B191B1B1C1B1E1A1C1C1B1C1C1C
1B1C1C1B1D1B1D1B1C1B1C1B1D1C1D1D1C1C1B1D1C1C1D1B1D1D1D1D1C1C1C1E1C1D1C1D
1D1D1F1D1E1C1C1D1D1D1D1C1C1D1D1D1E1C1C1D1E1D1E1E1E1E1E1E1F1E1D1D1E1D1D1D
1E1E1E1F1D1F1E1F1F1F1F1E1E1E1F201E1E1F1F1F1F201F1F1F1F1F1E1F1D1E1E1E1E1D
1F1F1F1E1F1F1F1E1F1D1F1F1E1E1F1F1E1E1F1E1E1E1E1D1D1E1E1E1E1E1F1D1F1E1E1E
1E1E1E1F1E1E1E1E1D1F1E1E1D1D1E1D1D1D1E1E1E1D1E1D1D1C1E1D1D1F1D1C1B1E1D1D
1D1C1D1D1D1D1C1D1C1D1D1B1C1B1E1D1C1C1C1B1D1C1D1C1D1C1D1B1B1B1C1B1C1C1C1C
1A1C1C1C1C1B1B1C1B1C1B1B1B1A1B1B1B1B1B1A1B1B1B1B1B1A1B1B1B1A1A1B1A1A1A1A
1B191B1B191B1A1A1A1B191A1A19191A1A1A1A1A1A191A191A1A1A19191A1A1B1A191A1A
1A1A19191A1A191A181A191919191A1917191A1A19181A1919191B18191818191918191A
1819191A19181719
1B1A1917191A191918191A19191A1A1A1B1819191A1A19191A1B1A1A1B1A1A1A1B191A1A
1919191A18191A1A19191A1B1A191919191A1A18191A1B1A1A1A1A1B1A191A1B1A1A191A
191A1A1B1B1A191A19191B1A1A1A1A1B1B1A1C1A1A1B19191A1A1B1A1B1B1A1B1A1B1A1A
1B191C1A1B1C1B1B1B1B1B1A1B1A1A1B1B1C1A1A1A1B1A1C1B1B1A1B1C1A1C1B1C1B1C1D
1B1B1B1B1B1B1C1C1C1B1B1C1B1B1C1C1C1B1C1A1C1B1B1B1B1C1C1B1D1C1B1B1C1C1C1D
1B1D1C1B1B1D1B1B1D1D1C1D1D1B1C1C1E1C1E1C1B1C1C1C1C1C1C1C1D1C1D1E1D1D1D1D
1E1C1F1D1D1D1E1D1E1D1D1D1E1D1E1F1E1F1E1E1E1D1F1E1E1E1D1D1D1E1E1D1F1F1C1E
1F1F1D1E1E1E1E1D1F1E1F201E1D1E201D1F1E1F1E1F20201D201F1F1E1E1E1E1E1E1F1E
1E1E1F1F201F1E1F1E1E201D1F1E1E1E1E1F1E1D1D1E1D1F1E1E1E1E1F1F1E1E1D1E1D1E
1D1F1F1E1D1F1F1D1E1F1D1D1D1E1E1E1C1E1C1D1D1D1E1D1D1D1D1C1D1C1D1D1E1D1D1C
1C1D1C1D1D1C1E1C1C1D1C1C1C1C1C1C1C1B1C1E1C1C1C1C1C1C1C1C1D1D1D1B1B1C1C1C
1C1C1B1B1A1A1B1A1C1B1A1B1A1A1B1B1B1A1A1B1A1B1B1B1B1B1B1B1C1C1A1B1B1A1B19
1C1A1A1B1A191A1A1A191A1A1A1A1B1A191A1A191A1B1B1A191A191A191A1A1B1A191918
1B181A19181A1A1A1A1919191A1A1919191A1A191A181A18181919181919181819191819
1919181919191919
181A181A19191A19191A1A1A191A19191A1A1919191B191A1A1A1B1B191A1A1918191B1A
1919191A19191A191A19181A1A1B19191B1A1A1A1A191A1A1B19191A1A1A1B1B1A1A1B1A
191919191A1B1A191A191A1A1A1A1A19191B19191A191A1B19191B1B1A1A1B1B1A1A1B1B
191A1A1B1A1A1A1A1B1B1B1B1A1B1A1B1B1B1A1C1B1B1C1B1C1B1B1B1B1C1C1A1C1B1B1C
1A1C1B1C1B1C1B1C1B1B1B1B1A1D1B1B1B1C1C1D1B1C1B1C1C1D1B1B1B1B1C1C1B1B1D1C
1C1C1C1C1C1C1D1C1D1B1C1C1C1C1C1C1C1D1C1C1C1E1D1D1D1E1C1D1D1C1D1E1C1D1C1D
1D1D1E1D1E1D1D1D1C1C1D1E1D1E1E1D1D1E1E1E1D1D1E1D1F1E1E1E1D1E1E1E1E1E1D1D
1E1F1E1F1E1E1F1E1F1E1F1F1F1E201E1E1F1E1F1E1F1E1F1F1E1E1D1E1E1F1F1D1F1E1F
1E1E1E1F1F1E1F1F1E1E1D1E1E1F1F1E1E1E1E1F1E1D1D1E1F1E1F1E1E1E1E201E1D1E1D
1E1D1E1E1D1E1E1D1D1D1E1E1D1D1F1E1D1E1E1D1C1D1D1D1B1C1D1D1C1C1E1C1C1C1D1C
1D1D1C1B1C1C1C1B1D1C1D1D1C1C1C1C1C1C1C1D1D1B1E1C1C1C1C1A1C1B1C1C1C1D1C1B
1C1C1A1C1C1C1B1B1A1C1A1C1C1A1C1B1B1B1B1C1B1B1B1A1A1A1B191A1A1A1B1B1A1B1A
1B1B1A1A1A1A1A1B1B191A191A1A1A19191919191A1A1A1A1A1B1A1A1A1A191919191919
191818191A1A1A1919191919191A1A1919191A1819191A19191A19191919181A18191918
1A18191919191919
1A18191B1A181A1A191A1A191A19191A1A1B19191A1A19191A1A1B191A1A1A1A191A1A18
1A191A1A19191B1B1A1A1A191A1A191A1A1A1A191A1A1B1A1B1A191B1819191A191A191A
191A1A1A1A1A1A191B1B191A1B1A1B1B1A1B1A1C1C1A1A1B1B1A1A1B1C1B1B1A1B1B1A1C
1B1B1B1B1B1A1A1B1A1B1B1A1A1C1B1B1B1C1A1A1A1B1A1B1B1C1B1B1B1C1B1C1B1C1C1C
1B1C1C1C1C1B1B1B1A1D1B1C1C1B1B1B1C1B1A1C1C1B1C1B1C1C1C1D1C1C1B1D1C1D1B1B
1D1C1C1C1B1C1D1C1C1B1C1C1D1C1B1C1C1B1D1C1E1D1D1D1E1D1C1E1D1C1C1D1E1E1C1D
1D1D1D1E1D1D1E1C1E1E1E1E1E1E1D1D1D1D1E1F1F1E1E1D1E1D1E1D1E1E1F1D1D1E1F1E
1F1D1E1D1F1F1E1E1E1F1E1E1F1F1E1E1F1E1E1F1E1F201F1E1E1E201F1F1F1F1E1F1E1E
1F1F201F1F1D1F1F1E1E1E1F1E1F201F1F1E1F1E1D1E1E1D1E1E1E1E1E1E1E1F1E1F201E
1E1F1F1D1D1E1C1E1F1D1D1E1D1D1D1E1D1D1D1C1D1D1D1D1D1D1E1D1C1C1E1C1D1E1D1E
1C1D1C1D1D1C1D1C1C1C1D1C1C1D1C1D1C1C1C1B1D1D1B1D1B1C1C1C1B1B1C1B1C1B1A1B
1A1C1B1B1C1B1B1B1B1B1C191D1C1A1A1B1B1B1C1C1A1B1A1B1A1A1A191B1B1A1B1A1B1A
1B1B1B1A1A1A1A1B1A1A1B1B1A191C1A1A19191A18191A1A191A1A1A1A1A1A191A191A18
19191A191B191919191A1919181919191A1A191A191819191A19181A191A1919191A181A
181A19181918191A
191919191A191A1A191A19191A1A1A1A191A1A1A1B1A1A1A1A1A1A1A1A191B1A1A1A1A19
191A1A1A191A191A1A19181A1A191A1A1A191A1A1A1A19191B191A1A1A191A191A1A1A1A
1B19191A1B1A1A1A1B1A1C191A191A1B1A1A1B1B1C1B1B191B1B1B1C1A1B1A1A1B1B1A1A
1A1B1A1A1A1A1C1A1B1B1B1B1B1A1B1C1C1C1B1C1B1C1B1A1D1C1B1B191C1B1B1C1B1B1D
1C1B1C1A1B1B1B1C1B1C1B1C1A1B1D1C1B1C1C1B1B1C1C1D1C1B1C1C1B1D1C1B1D1C1D1C
1D1D1C1B1C1C1C1C1C1D1C1C1C1B1C1C1D1D1B1B1C1D1D1E1D1C1D1D1D1D1D1D1C1D1D1D
1D1E1E1E1E1D1E1D1F1E1F1D1D1D1E1F1E1E1E1D1E1F1F1E1F1D1F1E1E1F1D1D1E1E1F1D
1E1E1F1D1E1E1F1D1F201E1F1E1F1E1E1F1E1F1E1F1E1F1E1F1F1E1F201F1E1E1E1F1E1E
1F202020201E1F1E1D1D1E201F1E1F1E1E1F1D1E1F1E1E1E1E1D1F1E201E1E1F1D1E1D1E
1F1F1E1E1F1E1E1F1D1E1E1D1E1E1E1C1D1E1D1D1F1D1D1C1E1D1D1D1C1D1D1D1D1C1C1E
1C1C1D1D1D1C1C1D1C1D1C1C1D1D1D1C1D1D1C1C1C1C1B1B1D1C1D1A1C1D1C1B1B1A1C1B
1A1A1C1C1A1B1B1B1C1C1C1C1C1B1B1B1A1B1B1B1B1B1B1A1B1B1B1B1B1B1C1B1B1B1B1A
1B1A191A191B1A1A1A1A1A1A191B1A1B1A1A1919191A191A1A1B1919191A1919191A1B1A
1A191A1A1A1A1A191A181A1919191A181A191A19191B191A191917191919191919191919
1819191918191919
1B191A191A1A1A19191A1B18191A1A19191A1A1A1A1A1B191919191A1A1A1A1A19191919
1A191A191A1A191B1A191A1B1A191B1B1B1A1A191A191A1A1B1A1A19191B1A1A19191A1A
1B1A1B1B191A19191A1B181A191A1B1A1A191B1C1B1A1A1A1A191B1B1B1B1B1A1B1C1C1A
1B1C1A1A1A1A1B1C1B1B1A1B1B1B1B1C1B1B1B1C1C1B1C1B1B1B1C1B1B1B1B1B1B1B1B1B
1C1C1C1B1C1C1B1B1B1D1C1B1C1A1A1C1B1C1C1B1C1D1C1B1C1B1D1B1D1C1B1D1B1C1C1B
1C1C1C1C1C1D1C1C1C1C1D1C1C1D1D1D1D1D1C1C1D1C1D1D1C1E1D1C1D1D1D1C1D1D1D1E
1D1D1E1E1C1E1D1C1D1C1D1E1E1F1E1E1D1E1F1E1E1E1E1D1E1F1E1E201F1E1E1F1E1E1E
1D1F1D1F1E1F201E1E201E1F1E1F1F1E201E201E1E1E1F1F1E1F1E1E1F1F1F201E1E1F1F
1E1E1F1E1E1E1F1D1F1E1E1F1F1F1F1E1F1E1F1D1E1E1D1E1E1D1F1E1D1E1F1E1D1E1E1F
1F1F1E1E1E1E1D1E1E1E1C1D1E1D1D1E1D1C1D1E1F1E1E1E1E1D1E1E1D1D1D1D1B1C1D1D
1C1D1D1D1D1D1C1D1D1C1C1B1C1E1D1C1C1C1D1D1B1C1C1C1B1C1D1C1C1B1C1B1A1C1C1B
1C1C1B1C1B1B1B1B1C1B1C1B1B1C1B1C1B1A1C1C1B1B1C1B1B1A1B1A1A1A1A1A1B1B1A1A
1B1B1B1A1B1A1A1A19191A1A1A191A1A1A1B18191A191A1A1A1A1B1B191A1A1A191A191A
191A19191A1A1A191A191B1A1A191919191A181A191A1A19191A17191918191918191819
1A1919191A191919
1A191A1919191A1A191A1A1819191A1A1B1A19191A191A1A19191918191A19191A1A191B
1A1A1A1B1A1A1B1A191A1A1A1B1A19191A191A181A1A1B1A1B1A1B1A1A1A1A1A1A1A191A
1B191B1A1B1A191A1A1A1B1B191A1A1A1B1A1B1B1A1A191A1B1A1A1A1B1B1A1A1B1B1A19
1B1B1C1B1A1C1B191B1B1A1A1B1D1B1C1B1B1A1B1B1B1C1B1B1B1B1C1C1B1B1C1A1B1B1C
1A1B1C1C1D1C1B1D1D1B1C1C1C1C1B1C1C1D1C1A1C1C1D1B1C1D1C1C1B1C1B1B1D1C1C1C
1B1C1D1D1D1B1C1C1C1D1C1C1D1D1F1D1D1E1D1C1C1E1E1D1C1E1D1E1D1D1E1D1D1D1E1C
1E1D1D1E1E1E1E1E1E1C1D1E1D1E1D1E1E1F1E1F1E1E1E1E1E1E1E1E1F1F1E1E1E1E1E1E
1D1E1E1F1F1F1F1E1F1F1F1E1F1F1E201F1D1E1F1E1F1F1F1E201F201F1E201F201E201E
1D1F1E1E1E201F1F1F1F1F1E1E1E1F1F1F1E201E1E1F1E1E1E1F201D1E1E1E1F1E1F1F1D
1E1E1E1E1E1E1E1E1D1E1C1D1E1E1E1E1E1D1F1D1D1E1E1D1E1C1D1E1D1D1D1E1D1C1C1D
1C1D1D1C1D1D1C1C1C1D1D1C1C1D1D1D1C1D1C1C1C1C1D1D1D1D1C1B1B1C1D1C1B1C1A1B
1C1C1B1C1B1C1C1A1A1C1C1D1C1C1B1C1A1A1B1B1B1B1C1A1A1B1B1A1B1A1A1A1A1B1A1B
1A1B191A1B1A1C1A191A1A1A1B191A1A1A1A1A1A1918191A1B1A19191A1A191A1A19191A
1A1A19191919191A1A1919191A191A19191A191919191A1A1919191A1919191A1A181919
1A1918191A1A1919
1A191A1A1A19181A191A1919181A19191A191B1B1A191919191A1A1B1A191A1B1B1A191A
191A191A1919191A181A1A1A1A1A1A1C191A1A1A1B191B1A191A1B1C1A1A1B1A1A1A1A1B
1A19191A18191A1B191B1B1A191A1B1A1A1A1A1B1A1A1A1B1B1C1B1A1C1A1B191B1C1B1A
1B1B1B1B1B1B1C1B1A1C1C1B1A1A1B1A1B1B1A1B1B1B1B1B1C1C1C1B1C1A1A1A1B1B1B1C
1B1C1B1B1D1C1C1D1B1C1C1C1C1C1B1C1B1C1B1C1B1C1C1B1C1C1C1C1C1C1D1C1C1C1C1D
1C1C1D1D1C1C1B1D1C1D1E1C1F1E1C1D1E1F1D1D1E1C1C1D1D1D1C1E1E1E1D1D1D1E1C1E
1D1F1D1E1C1E1E1E1D1D1E1E1E1D1D1D1D1E1E1F1D1F1E1F1E1E1D1E1F1E1F1E1E1F1E1E
1E1F1F1E1F1E1E1F1E1F1F1F1F201E1E201D1F1E1F1E201E201F1E1F1E1F1F201F1F201E
1E1E1E1F1E1E201E1E1E1F1E1E1F1E1F1E1E1D1F1E1F1D1F1E1E1E1F1E1F1E1F1E1E1F1E
1F1F1E1E1E1E1E1E1F1F1E1E1D1D1E1D1E1E1D1E1E1E1D1D1E1E1D1D1C1E1D1C1D1D1C1C
1D1C1D1D1C1D1B1C1D1C1C1C1C1C1C1C1B1B1C1B1D1C1C1C1B1B1C1D1C1B1B1B1C1B1C1A
1C1C1C1B1B1B1B1B1B1C1C1C1D1B1C1C1C1B1A1B1A1B1B1A1B1C1A1B1A1B1B191B1A1A19
1A1A1B1A191A1A1A191A1A1A191B191B1A19191A191A1A19191B1A191A19191B1A1A191A
191A1A1A18191919191919181919191A1A1A1A191A1A1A1919191A191A1A191A1918181A
1919191A19191819
1919191A191B1A1A191B191A1A1A1A191B1A1A1A191A191A1A19191A1B1A19191A1A1A1B
181A1B1A191A1A19191A181A1B1A1A1A1A1A191A1A18191A1A1A1A191A191A1C1B1A1A1A
191A1A1A1A1A1A191A1B1B1A1A1B1A1A1A1B1A1B1B1B1A1A1B1A1C1B1C1B1B1B1B1B1A1A
1B1C1A1A1C1A1A1A1C1A1B1A1B1B1C1B1C1B1A1A1B1B1A1C1C1C1B1C1C1C1B1D1C1C1C1B
1B1C1A1B1D1D1B1B1B1C1C1C1C1C1C1C1B1C1A1C1C1D1C1C1C1C1D1D1C1E1C1D1D1C1C1D
1D1C1C1D1D1D1C1D1D1C1C1D1D1D1C1D1C1D1D1D1D1E1C1B1D1E1E1D1C1C1E1D1E1D1D1F
1C1E1D1E1E1F1E1E1D1D1F1D1E1E1D1E1E1E1F1F1E1E1F1E1F1E1E1E1F1E1E1E1E1F1D1E
1F1E1D1F20201F1F201F1F1E1F201E1F1E201E1E1F1F1F1F1F1F1E1F1F1F1D1E201F1E20
201E1E1F1F1F201F1F1F2020201F201F1F1E1F1F1E1F1F1F1E1E1F1E1E1E1F1F1E1F1E1F
1F1E1E1D1D1F1F1E1F1F1D1D1E1D1E1E1E1E1E1E1D1C1D1C1D1D1C1D1E1E1E1D1C1E1D1E
1B1C1D1D1D1D1D1D1E1D1D1D1E1C1D1C1C1B1B1C1B1D1D1B1C1B1D1C1B1B1B1B1C1B1C1B
1C1B1B1C1B1B1C1C1B1B1C1C1C1B1B1A1A1B1B1A1B1B1B1C1A1C1A1B1B1A1B1B1B1B1B1C
1B1A1B19191B1A1A1A1B1B1A1B19191B1A1919191A1A1A1A1A1C1A1A1B191A1A1A1B1B19
19191919191919191A1A1A1A1A1919191A1A1A18191919191A1A19191A1B1A191A1A1919
181A191A19191919
191919191A1A19191A1A1A1A191B1A191A1B1A1919191A19191A1A1A191A191B1B191A19
19191B191A1A1A19191A191A191B1A1B191B191B1A1A1A19191A1A191B1A1A191A1A1A1B
191A1A1A1A191A181B1A1B1A1A1B1B1A1A1A1A1A1A1B191A1B1A1A1A1B1B1A1B1A1C1B1B
1B1C1B1A1C1B1B1A1B1B1C1B1C1C1C1C1B1B1B1C1B1C1B1C1B1C1A1B1D1B1D1C1C1B1B1B
1B1B1C1C1B1C1D1C1D1C1B1B1B1B1B1C1C1D1C1B1C1C1C1B1B1C1D1C1D1D1D1C1D1C1D1D
1C1C1D1D1C1D1D1D1C1B1E1D1E1D1D1E1C1D1D1E1E1C1D1D1D1D1D1E1D1D1D1D1D1E1D1E
1D1E1E1E1E1E1E1F1F1D1D1C1E1E1E201E1F1E1E1E1D1F1F1E1E201E1F1E1E1F1F1F1F1D
1E1F1E1F1F1F1F1E1E1F1E1F1F1E1F201F1F1F1F1F202020201F201E201F1E1F1F1F1F1E
1E1E1F1F1F1F1F1F1F1E1F1F1F1E1F1F1F1F1F1F1E1F1E1E1F1E1F1F1E1F1D1E1E1E1F1E
1E1D1D1F201E1F1D1E1F1E1E1E1D1F1E1D1E1C1C1D1E1E1E1E1D1D1D1E1D1C1C1D1D1C1D
1D1E1C1D1E1C1C1D1D1D1D1D1E1E1E1D1C1D1B1E1C1B1D1D1B1C1D1C1C1B1C1D1B1C1B1C
1A1B1B1C1B1A1C1C1B1C1B1B1C1B1C1A1C1D1B1B1B1B1B1B1B1C1A1B1B1A1A1B1A1C1A1A
1B1A1A1A1B191B1A1B191A1B1A191A1B1B1A1B1A1B191A1A191A19181B1919181A1A1B19
191A1A1A191A191919191718191A1A1A1A1919191A1819181A191A1A19191A1919191919
1A19191A19191719
191A191A1B191A191A1A181A1A1A1A191A191A1A191A1A191A1A1A1A191B1A1A191A1A1A
1919191919191A19191A191A1B1A1A1A181B191A1A1A1A1A191B1A191A1A1A19191A1B19
1A1A1A1A1B181A1A1A1A1A1B1B1A1A1A1B191A1B1A1A1A1B1B1A1A1A1C1B1B191A1B1C1A
1A1A1B1B1B1A1A1B1A1B1A1B1B1A1A1B1C1B1D1B1B1B1B1B1C1C1C1B1C1B1B1A1C1B1B1C
1B1C1B1C1C1D1D1B1C1C1C1C1D1D1D1B1B1C1B1C1C1D1B1C1C1C1D1D1C1C1C1C1C1D1D1C
1D1D1D1E1D1D1D1C1C1D1C1D1D1C1C1D1C1E1C1E1D1C1D1F1E1E1D1D1E1D1E1E1E1E1E1D
1D1E1F1E1E1F1E1F1F1D1D1E1D1E1E1E201E1E1E1F1F1E1E1F1E1F1E1E1F1E1E1E1E1E1F
1E1E1D201E1E1F1D1E1E1F1E1F1F1F1F1F1E1E1F1F1E1F1F1F1F201F201D1F1F1E1E1E20
1E1F1F201F1F1E1E1E1F201F20201E1E201E201F1F1F1D1F1E1F1F1F1E1F1F1F201E1D1E
1F1E1E1F1F1F1D1E1E1E1E1E1E1D1D1E1D1E1E1D1F1E1F1D1E1E1E1D1D1D1D1D1C1C1D1D
1D1E1E1C1D1F1D1E1E1E1D1E1B1C1C1C1C1D1D1D1C1C1D1C1D1D1D1C1B1D1B1B1C1B1A1B
1C1B1B1C1C1B1B1D1C1C1C1C1D1C1B1B1A1B1A1A1B1B1A1B1B1A1A1B1B1B1B1A1B1B1B1A
1A1A1B1C1B1A191A1B1A191A1A1A1A1A1B1A1A1B1B19191A191A191A191A1919191A181A
191918191A1819191B191919191A1A1A191A191819191A1A1A1A1A191A1A191A1A1A1918
1819191A19191A1A
19191919181A1A1B191A1A19191A191B1A1B191A1A1A1919191A1A1A1A19181A1A191919
181A1A1919191B1A1A1A1A1A1B1C1A1919191A1A1A1A1A1A1A1A1A1B1B1A1A19191A1A19
1B1B191A1A1A1A1B1A1B1B1A1B1B1A1B1B1A1A1B1B1B1B1C1C1B1A1B1B191A1B1B1A1B1B
1B1A191B1B191B1C1B1C1B1C1B1C1B1C1C1C1B1B1B1B1C1C1C1B1B1C1B1C1C1C1B1C1A1C
1C1B1C1B1C1B1D1C1C1B1C1B1C1C1C1B1B1B1C1C1B1C1D1C1D1B1E1C1D1D1C1C1D1C1D1D
1C1E1D1D1C1C1C1C1D1C1D1D1C1D1D1D1D1D1C1C1E1D1E1D1D1D1C1D1D1D1D1E1E1E1D1D
1D1E1E1E1E1D1E1E1E1E1E1E1E201E1D1F1F1F1E1F1F1D1F1F1E1F1F1E1F1F1F1F1F1E1F
1E1E201E1E201E1E1E1F1F1F202020201F1F201F1F1F1F201F201E1F1F1F201F1E201F1F
1F201E1F1F1F201F201D1F1F201F1E1F1E1F201F1E201F1F1D1F1E1F1E1E1F1F201E1F1E
1E1E1E1D1E1D1E1E1D1E1F1D1D1F1C1F1E1E1D1E1E1F1E1D1D1D1F1E1D1F1D1D1D1C1D1D
1D1F1C1E1E1F1E1E1D1E1F1C1D1C1C1C1D1C1D1D1C1D1C1B1B1B1D1C1C1B1C1C1C1C1B1B
1B1B1B1B1B1D1C1C1B1C1C1B1C1B1C1B1C1B1B1A1B1B1B191A1B1A1C191B1B1A1B1B1A19
1A1B191C1B1A1B1A1A191A1A1A191A1A1A1919191A1A191A191A1A1A1A1A1B1A1A191A19
191919191A1A1A1A1A1A1A1A1B1A1A18191A19191B19191B191919171919181919191919
1B18181919191919
191919191919191919191A1A1A191A1A1A191A191A1A1919191A191A1818191A191A191A
191A1919191A1A1A1A1A1A1B191A1A1A1A1A1A1B1A19181B19191A1B1A1A1A1B1B1A191A
1A1B1A1A19191A1A1A191A1A19191B1A191A1B1A1B1D1C1C1C1B1B1A1B1B1B1B1B1B1A1B
1B1B1B1B1B1B1B1A1B1A1B1A1B1B1B1D1C1D1B1B1C1A1B1C1B1A1C1B1C1C1C1A1A1C1B1C
1C1C1B1A1C1C1C1D1C1C1C1C1C1C1C1B1C1B1C1B1B1D1C1C1D1B1D1C1D1D1C1D1C1C1E1D
1E1E1C1D1D1C1C1C1C1D1D1D1E1E1D1D1D1C1C1D1B1C1C1E1E1D1D1E1E1F1D1D1F1D1E1E
1E1D1F1D1D1E1F1D1D1E1E1F1E1F1E1E1E1F1F1F1F1F1E1E1F1F1F1E1E1F1F1E211E1E1E
1D1F1F1F201F1E1F1F1E1E201F1E1F1F201F1F1E1F1D201F1E1E1F1F2020201E1F1F1F1F
1E1F1E201F1E1F201F1F1E1E1F1F1F1F1D1E1E1F1F1E1F1F1D1E1E1F1E1D1F1E201E1E1F
1E1E1D1E1E1F1E1E1E1F1E1E1E1C1E1F1F1F1E1E1D1D1E1E1D1F1D1E1D1D1E1D1D1D1E1D
1D1E1E201E201F20201E1E1D1E1E1C1B1D1C1B1D1D1D1C1B1B1B1D1C1C1C1C1D1C1C1A1B
1B1B1B1C1B1C1B1C1C1C1B1C1B1B1C1B1B1B1B1C1A1B1A1A1A1B1A191B1A1A1A1A1B1B1A
1B1A1A1A1A1B191A191A1B1B191A1A1A1B191A191A1A1A1A1A1A1A1A1A1A1A181A1A1A19
1918191A1A1919191A1A1A1A1A191A1A1A19181919191A1A1A191A1919191A1A1919181B
1819191A19181819
1A191A191A19191919191A191A1B1A1A1A1A1A1A1A1A1A1A191A1A191A1A191A1A1A1A19
1A191A1A1A1B1A1A191B191A1B1A1B1A1B1A191A1A191A1B19191A1B1A1A1A1A1B1A1919
191B1A1A191A191A191B1B1B1A1C1A191B1B1A1C1D1C1B1A1B191A1B1B1B1B1A1B1A1A1C
1B1A1B1B1A1B1B1A1B1A1C1B1A1A1C1B1C1C1C1C1C1C1B1D1A1C1C1C1B1B1B1C1C1C1B1B
1D1C1C1C1C1B1C1C1B1C1B1C1D1C1C1D1A1C1C1D1C1C1C1C1B1E1C1D1E1D1D1D1D1C1D1D
1E1F1F1D1D1E1C1E1F1B1C1C1E1D1D1C1D1D1E1E1E1E1E1D1E1D1E1D1E1E1E1D1E1F1D1E
1F1E1F1D1E1F1F1F1E1F1E1E1E1F1E1D1E1F1E1F1F1F1F1E1E1E1E1F201F1E1F1F1E1F1E
1F1F1E1F1F201E1F1F1E1E1E1E201F20211F1F201F1F1F1F1F1F201F211F1E1F201F201E
1E1F20201F1F1F1F1F201F1F1E1F1E201F1E201E1F1E201E1E1F201F1D1F1F1F1E1F201E
1E1E1F1E1D1E1E1D1D1E1F1E1F1E1E1F1E1E1D1E1E1E1E1D1F1E1D1F1E1C1D1E1D1D1E1E
1E1E20202021212021201E1D1E1D1D1B1C1C1C1E1C1C1C1C1B1C1C1D1C1B1B1C1B1C1B1C
1D1B1B1C1B1A1C1B1C1C1B1C1B1C1B1B1B1A1B1B1B1B1B1A1B1B1B1A1C1B1C1B1A1C1C1A
1B1B1B1B1A19191A1A1B1A191B1A1A1B19191A1B191A1A1B1A1A19191919191A1B1B191B
1A1A1A1A1A191A1A19191A1A18191A191A181A1A19191819191A1819191A191A19191A19
1A19191B19191819
1A1A191A1A19191A1A1A1A1A1A19191B1A1A1B19191A191B191A19191A19191B1A191919
191A1A1A1A1B1A1A1A1B1B191B1A1A1A1A1A1A191A1B191A1A19191A1B1B1A1A1A1A191A
191A1A1A1A1A191A1A1A1B1A1A1A1B1A1A1B1B1B1B191B1B1B1A1A1B1B1B1B1C1C1A1A1A
1A1A1A1A1C1B1B1B1B1C1B1B1A1B1C1C1B1B1A1B1B1B1C1C1B1B1B1B1C1C1C1C1B1B1B1B
1B1C1C1D1D1B1C1C1B1C1C1C1B1C1D1C1C1B1B1D1C1C1D1C1C1C1D1B1D1C1D1B1C1E1D1E
1F1E1E1E1C1E1D1D1D1D1D1D1D1D1D1C1E1C1D1F1E1E1E1E1D1D1E1E1E1E1D1D1E1F1E1D
1E1F1F1D1E1F1E1D1F1E1F1E1F1E1E1E1F1E1E1E1F1F1E1F1F1D1F1E1F1E1F1E1F1E1E1F
1F1F1E201F201E1F2020201F1E1E21201F1E201F1F1F1F1F20201F1F1F201F1E201E1E1F
1F20201F201F1F1F201F1F201E1E1F1F1D1E1F1E1F1F1E1F1E1F1F1E1E1E1F1E1E1F1D1F
1E1E1E1F1F1F201F1E1F1E1E1E1D1E1E1E1E1E1D1F1E1D1F1E1D1D1D1D1D1E1D1D1D1D1E
1F1F20222223232322201E1E1E1C1D1D1C1D1B1C1C1D1C1D1C1D1C1C1D1B1A1C1C1B1C1A
1D1B1C1B1C1C1A1B1B1B1C1D1B1B1D1A1C1B1B1C1B1C1C191A1A1A1A1A1A1A1B1A1B1A1B
1B1B1B1A1A1A1A1A1A1A1B1A1B191A1A191B1A1A191B1A191B191919191A19181A191918
1A1A191A191919191B181A1A19191B191A191918191918191A191A1A1918191918191918
191A1A181918191A
1A1919191A1A1A1A1A19191B1A1A191B1A191B181A1B191A1A1A1A1B1A1A1A1A19191A1A
191A19191A1B1A1A1B1A1C1A1B1C1A1A1A191818191A1A1919191A191B191A1A191B1A1B
1A1A191B1A1B191B1B1A1A1B1B1B1B1A1B1A1A1A1A1A1B1B1B1B1A1A1A1A1B1A1B1B1A1B
1B1A1A1B1B1A1B1B1B1B1C1C1B1B1A1B1B1B1C1B1D1B1C1B1B1C1B1C1C1B1C1C1B1B1B1C
1B1C1C1C1C1D1C1D1C1C1B1C1C1C1D1C1D1C1C1E1B1C1D1C1C1D1C1B1B1B1D1E1D1D1C1C
1D1D1C1D1E1D1E1C1D1D1D1D1E1C1D1E1C1D1E1D1D1D1D1E1D1D1E1E1E1D1E1E1D1E1D1E
1D1E1E1F1E1F201D1F1F1F1E1D1F1E1E1F1F1F1E1F1E201F1F1F1F20201F1F201D1F1E20
1F2020211F1E1F20201F1F1F1F1F201E202020211F20201F20201F1F21201E1F1E1F2020
1F211F1E1F201F1F1F1F201F1F1E201F1F1D1F1F1E1F1F1E1E1F1E201E1F1E1F1F1F1E1E
1E1D1E1E1E1F1F1E1F1E1E1E1E1D1F1F1E1E1D1E1F1E1F1E1D1E1F1D1D1D1E1D1E1D1D1D
1E1E202223262424201E1D1D1C1E1D1D1E1C1D1C1C1C1C1C1C1B1C1C1C1B1D1C1C1B1C1B
1B1B1C1C1B1C1D1C1C1C1D1B1A1B1C1B1B1C1B1B1B1B1A1A1A1B1A1B1C1B1B1A1B1C1A1A
1B1B1A1A1A191A1A1B1A1B1B191A1A1B1A1B1A1A1A1A1A191919191B1B1A1A1A191A191A
191A191B1919181A1A1A19191A19191919171A191919191A1A1A1918191A191A19181A19
1A1919191919181A
19191A19191A191A191A191A1A1A1A1A1A19191919191B191A1A191A1A1A191A1A181A19
1A1A1A1A1A1A1A1D1B1A1C1B1C1B1A1A1B1A1A19191A1A1A191919191A1A191A1A191A1A
1A191A1C1B1A1B1A1A1B1B1A1B1C1A1B1B1B1B1B1A1B1B1B1A1B1B1A1A1A1A1B1B1A1C1C
1B1B1A1B1A1B1B1A1D1B1B1A191C1A1C1A1A1A1B1C1C1B1C1B1D1C1C1D1A1B1C1C1C1B1B
1C1C1C1A1D1D1C1C1C1C1B1C1B1B1C1C1B1C1D1B1C1C1B1D1D1C1D1D1D1C1D1C1D1C1D1D
1E1D1D1D1D1C1C1C1C1D1D1E1D1D1D1D1D1D1D1E1E1D1D1E1E1E1D1C1D1E1D1D1D1E1E1D
1E1E1D1D1E1E1E1D1E1F1F1D1E1F1D1F1F1E1F1D201F1E1F1F1E1F20201E1F1F1F1E1F20
1F1E1F20201F1F1F20201E1F201E20211F201F201E201F20202020201F1F201F1F1F1F21
1E20201F201F1F1F211F201F1E1E1F1F1E1F1F1F201F1F201F1F1E1E1F1E1E1E201E1E1E
1E1F1F1E1D1D1E1F1D1E1E1E1E1F20201D1F1F1E1E1E1F1D1D1E1E1D1D1F1E1C1D1D1D1E
1F1F202225252422211E1D1D1D1D1C1C1E1E1D1C1C1D1D1C1D1C1D1D1B1C1C1D1C1C1C1D
1B1B1B1A1B1C1B1C1B1B1C1C1B1A1C1B1C1C1B1B1B1C1C1B1A1B1A1B1B1B1B1B1A1B191A
1B1A1A1A1B191A1B1B1A1B1A1A191A1B1A1B1A1A1A1B1B191A191A191A1A1A1A1B1A1A1A
191918191A191919191A191A18191918191B191A1A1A1A1A1A1918181918191A1A1A191A
1A1A181A1919181A
1A19181A1A191A191A1A191A1B1A1A19191A1B1B19191B1A191A19191A191A1A1B1A1B19
1A1A1B1B1A1A1A1B1B1B1C1C1C1B1B1B1B1B1B191A1A1A191A1A1A1B1B1A19191A191A19
1B19191A1B1A1A191A1A1B1A1C1B1A1B1B1A1A1A1C1B191A1A1B191B1B1B191C1B1B1A1B
1B1B1B1C1C1A1A1A1B1A1C1C1B1B1B1A1A1B1C1B1C1C1A1D1C1C1B1D1C1D1B1B1E1D1B1B
1B1C1C1C1D1C1D1B1B1D1C1C1D1C1C1C1C1D1C1D1C1C1E1C1B1D1D1D1D1D1C1C1E1E1E1D
1C1D1D1C1D1D1E1C1D1D1E1D1E1E1D1D1E1E1F1D1E1E1E1D1E1C1F1F201E1F1E1C1E1D1E
1E1D1D1E1F1E1E1D1D1E1E1E1D1E1E1E1F1F1E1F1F1E1F1F1F1E1E1E1F201F1F1F1F211E
1F1F20201F1F1E1E1F1F1F1F211F201F1F1F1F211F201E1F1F201F1F2020201F1F1F201F
201F1F1F1F1F1F1F1F1F1F1F201E1F1F1F201F1E1F1E201E1F1F20201E1E1F1E1E1F1F1E
1E1E1E1E1F1E1F1E1E1E1E1E1F1F1F1D1F1E1E1E1F1F201E1E1E1D1E1D1D1D1E1E1D1E1E
1E1F202323252321201D1F1E1D1D1D1D1D1D1C1C1B1D1C1D1C1D1B1C1D1B1D1C1C1D1C1C
1A1B1B1D1C1C1C1D1B1C1C1C1B1C1C1B1B1B1A1D1B1D1C1B1A1B1C1C1B1B1C1A1A1B1A1B
1B1A1A1B1A1A1A1B1A1A1A1B1A1A1A1A1A1B18181A1A191B1B1A1B1A191B1A1B1919191A
1A1A181A1A19191A191A1A1A1A1A1A1919191A191A1A19181B19191919191A1A191A1A1B
1A1919191A181A19
1A191919191A1A1A1A19191A191A1A1A1A1A191A1A1A19191A1A1A1B1A1919191A1A191B
191A191A1B1B1A1C1B1C1C1D1D1C1C1A1A1B1A1A1C1A19191B1A1B191B1A1A1A1A1A191A
1A1B1A191A1B1A1A1A1A1A1B191B1A1C1A1C19191B1B191B1A1B1C1B1B1B1B1B1B1B1B1B
1B1A1B1B1C1C1C1B1B1C1B1B1B1B1B1B1A1B1C1A1C1C1C1C1B1B1B1B1B1C1C1B1C1D1B1C
1B1C1C1B1B1B1C1C1C1D1D1B1B1B1C1D1C1C1B1C1D1C1E1E1D1E1C1E1D1D1C1D1D1C1C1D
1D1D1D1E1D1D1D1E1D1D1D1C1D1C1D1E1D1E1D1E1E1E1E1E1E1D1F1E1F1C1D1F1D1E1D1E
1F1E1E1D1E1E1F201E1F1F1E1E1E1D1E1E1F1F1E1F1F1F1F201F1F1F201F201F1F1F1F1F
1F1E1F1F1F1F201E1F1F1F1F1E1F1E20211F1F201F201F201F2020202020201F1F202120
201F2020212120201F211F1F201F1F1F1E1F1F201E1F1F1E1F1E1F2020201F1E1E1E1E20
1F1E1F1D1E1F1E1F1D1F1D201D1E1E1D1E1D201F1F1F1E1F1F1E1F1E1F1E1D1E1E1F1D1E
1E202022222320211F1E1D1E1D1C1D1C1D1C1D1D1C1D1C1C1D1C1C1C1C1C1C1C1D1D1B1B
1B1C1B1B1B1B1C1B1C1C1C1A1B1A1B1D1C1B1B1B1C1B1C1A1B1B1B1B1C1B1C1B1A1B1A1A
1B1B1B1A1A1A1B1B1B1B1A191A1B191A1A1A191A1A1A191A1A1A1A1A191A1B1A1A191A19
1A18191A181B17191A1A19191A1A1B1A1A1A1A1A1919191A1A1A191919191919181A1918
1919191A1A1A1818
1918191B1919191A1A19191A1A19191A1A1A1A1A1A1B1A1A1A1A1A1A1B1A1A1A1A191A19
1919181A1A1B1B1C1C1C1D1C1E1C1C1A1B1A1A1A1B1A1A191A1A1A191A191A1A1A1A1A19
1A1A1A1A1A1C1A1A1A1A1B1A1A1A1B1B1C1A1B1B1C1A1A1B1B1B1C1B1C1C1A1A1B1C1B1B
1B1B1B1B1A1B1A1C1B1C1A1C1B1B1A1C1B1B1B1B1D1C1C1B1B1C1C1A1B1C1D1C1C1C1D1C
1C1C1B1C1C1D1B1B1C1A1D1B1D1D1D1B1D1C1B1B1D1E1C1C1D1D1C1D1B1D1C1D1C1D1E1D
1E1D1D1C1D1E1D1C1D1D1D1C1E1D1E1F1D1E1E1E1D1E1E1E1D1D1E1D1D1E1E1E1E1E1E1D
1E1E1E1E1E1E1E1D1E1F1F1F1F1F1E1E1F1E20201F1E1F1F1F1F1F2020201F201F1F1F20
1F1E201F201F201F201F202020201E1F20201F1E202020211F1F1F1F20202020211E2021
2021202020201F1F2020201F1F20201E201F1E1F1E1E1F201F201F20201F1F1E201F1F20
201E1F1E1F1F1E1E1F1F1F1E201E1E1E1E1F1D1E1F1D1D1F1D1D1E1E1E1E1E1D1D1E1E1F
1F201F202020211E1D1D1E1C1E1D1E1D1D1C1D1D1B1C1C1C1D1C1C1C1D1D1C1D1C1C1C1C
1D1C1D1C1C1D1B1B1C1B1C1B1C191B1B1B1B1B1B1B1B1C1B1A1A1B1A1A1A1B1A1B1B1B1B
1A1B1A1A1B1A1B1D1919191A1B1A1A1A1A1A1A1A1A1A191A1A1A1A1B1A1A19191A1A1919
1A1A1A191A1A1A191A191A1919191A1A1819191A191918191A1A191919191A1918191A1A
19191A191919191A
1A1919191B19191A1A191A191A191A1A191B191A1A1A1A1A1A1A1B1B1B1A1A191A191A1A
1A1A1A1B1B1B1B1A1B1E1D1E1E1D1D1B1C1A1A1A1A1B1A1A191B1A1B1A191A191A1A1A1A
1B1A1A1B1A1B19191A1A1A1A1A191C1B1B1C1A1B1B1B1B191B1B1B1B1B1A1B1B1B1B1A1B
1B1C1B1A1A1B1B1B1B1B1A1B1C1C1A191B1B1C1B1C1B1C1B1C1C1C1D1C1D1B1C1B1C1B1C
1C1C1C1C1C1C1E1B1B1C1C1C1C1B1C1D1B1D1D1C1C1D1D1B1D1D1D1C1C1C1D1C1D1E1C1E
1E1E1D1F1D1D1D1D1E1D1D1E1D1D1E1E1F1E1E1E1E1F1E1E1D1D1E1F1E1D1E1F1D1E1F1D
201D1F1E1E1F1D1E1F1F201F20201F1F1F201F1E1F1F1F1F1E1F20201F201E1F211F1F1F
20201F1F201F201F1F1E202020202020211F201F1F201F211F212120221F201F1F202120
202120201F1F1F211F1F1F1F201F21201E1F1E1F20201E1F1F20201F1F20201F1F1E201E
1F1F201E1D1D1E1F201E1D1D1F1D1D1E1E1E1D1E1E1E1D1D1E1E1E1E1E1E1F1E1E1D1E1F
1D1F1F1F201F1F1E1D1D1E1D1F1D1E1D1D1C1D1B1C1D1D1D1D1D1D1D1B1D1C1D1C1C1C1C
1B1C1C1C1B1B1A1D1B1B1B1B1B1B1C1A1C1B1B1C1B1C1B1C1A1C1B1A1A191B1C1B1B1A1A
1A1C1A1B1B1A1A191B1B1B1A1A1A1B1A1B1A1A1A1B1A1A1A1B19191A191A1919191A1919
19191919181A1A1A19191919191B191A19191A19181A1A191A1A19191B191A191A19191A
191A191A18191919
191A19191A191A191A1A1A19181A1A191919191A191A181A1A1A19191B191A191A1B1A19
1B1A1A191A1A1B1A1B1C1E1C1D1C1C1A1B1A1A191B1A1A1A1B1A1A191B1A1A1A191A1A1A
1B1A1A1A1B1A1A1B1A1B1A1B1B1A1A1A1A1B1B1B1B1B1B1A1B1B1A1B1C1A1A1B1A1A1C1B
191C1C191B1A1C1A1B1B1C1B1B1C1B1B1B1B1C1C1B1C1C1C1D1C1B1C1C1C1C1C1C1C1B1C
1C1D1C1D1D1C1D1D1C1D1C1D1C1D1D1D1C1D1E1C1D1D1C1D1D1D1D1C1D1D1D1C1D1E1D1D
1D1D1D1C1E1C1D1E1D1E1D1D1D1C1C1C1D1D1F1E1D1E1E1D1F1F1D1C1E1D1D1E1D1D1E1E
1E1D1D1F1E1F1F1E1F1E1E1F1F1F1F201F1F1F1E20202021201F20202020201F1F202020
20201F1F20201F1F201F2020201F2021202120201F202020201F20201F201F202020201F
212020201F211F1F1F1F1F20202020201F1F201F1F1F201F1F1E20201E1F1F201F1E1F21
1F201D1E1E1F1E1E1E1F1F1E1F1E1F1E1E1E1E1E1E1E1E1E1F1D1F1E1E1E1E1E1D1E1F1E
1F1E1E1F1F1E1E1D1D1D1C1D1D1D1E1D1E1D1C1C1B1C1D1D1D1B1B1D1E1C1B1C1C1C1C1D
1C1B1C1C1B1B1B1C1C1C1C1B1C1B1B1C1C1C1C1B1C1B1A1B1A1B1B1B1B1B1A1C1A1B1A1B
1A1B1C1A1B1B1B1B1C1B1B1B1A1A1C1C1A1B1B1B1A1A1A1A1A181B191A191B191A191A19
1A191A1A191A1B1A1A1919191A1A191A1A1A1A19191A1A191A191819191A1919181A191A
1919191A181A1819
1919191A1918191A191919191A1A1A1B1919191B1A1A1A1A1A1B1B18191B181A191A1A1A
191A191A1A1B1A1B1B1C1B1C1C1B1B1A1B1A191B191B1A191A1B1A1B191919191A19191A
1A1B1B1A1B1C1A1A1C1B1B1B1B1B1A1A191B1B1B1B1B1C1B1A1B1B1A1B1B1B1B1C1B1B1A
1A1C1B1B1B1C1B1C1A1B1C1B1B1B1B1C1B1B1C1C1B1D1C1D1C1D1B1C1C1B1B1C1D1C1D1C
1C1C1C1D1B1D1C1C1D1D1C1D1D1E1D1D1C1D1C1D1D1D1C1D1D1C1C1C1D1C1D1C1C1D1D1C
1E1D1D1E1F1D1D1D1E1F1E1E1D1F1E1D1D1E1D1F1E1E1E1E1E1E1E1D1E201E1E1E1E1F1D
1D1F1E1E1F1F1E1F1E1F1F1F1F1F1E1F1E1F1F1F201E1F1E1F1F1F1F1F201F201F201F20
201F1F21201F1F20211F2021211F2020202020202020202020212020212020211F202020
2021202021201F20202022211F1F1E20201F1E1F1E201F1F1E1E1F1F1F201F1F1F1E1F1F
211E1F1E1E1D201F1F1E1F1E1F1F1F1F1F1F1F1F1D1F1D1F1E1E1E1D1E1E1F1E1E1F1D1E
1F1F1F1E1F1E1E1D1D1D1D1E1C1E1D1C1C1D1D1D1D1C1C1D1C1C1C1C1D1D1C1C1D1C1C1B
1C1C1C1C1B1B1C1C1C1B1B1B1C1B1C1B1A1B1B1A1B1A1A1B1B1B1B1A1B1A1B1C1B1B1B1C
1B1B1B1A1B1B1B1A1C1A1B1B1B1C1B1A1B1B1C1A1A1A191919191A18191A191A1A191919
1A1A1A191A191A1A191A1A19191A1A1A191919191919191819191A191A191A1A1818191A
1A1A1A1918181919
1919181919191A191A1A1B191A1B1A1A191A191A1B191A1A191A1A1A1A1B1919191A191A
1A191A1A1B191B1B1B1C1B1C1B1A1B1B1A1B1A1B1A1A1B191B1A1A1A191B191B1A191A18
1A1A1A1A191A1A1B1B191B1A1A1A1B1A1B1A1A191B1B1B191A1B1C191A1B1B1A1B1C1B1B
1B1A1B1B1B1B1C1B1B1B1B1C1C1C1C1B1C1D1C1C1C1C1C1B1C1B1C1B1B1C1C1C1D1C1D1B
1C1C1C1C1B1D1C1D1C1C1D1D1C1D1C1E1D1D1D1C1B1C1C1E1C1C1E1D1D1C1D1D1D1D1D1D
1D1D1D1D1D1E1D1D1E1D1C1E1D1E1D1D1E1E1E1F1D1D201E201E1D1E1E1F1E1F1E1D1F1E
1F1F20201F20201F201F1F201F202020211F201F1F1E1F1F201F20211F201F20201F201F
1F201F201F20201F21201F202120201F201F1F201F211F20202120211F20202020202121
212021201F211F201F20212020201F1F20212020201F1F1F1E201E20202020201E1E1D21
1F1E1E2220201E1F1F1F1F1E1D1D1F1E1D1E1E1F1E1E1E1E1E1E1D1E1E1E1D1D1E1D201E
1E1D1E1D1E1F1D1E1C1E1E1D1D1E1D1C1B1C1D1C1C1D1C1C1C1C1C1D1D1C1D1C1C1D1C1D
1C1B1B1B1B1D1C1B1C1C1B1C1C1A1C1D1C1C1B1D1B1B1B1B1B1A1C1B1A1B1B1B1B1B1B1A
1A1B1A1B191A1B191B1A1B191B1B1B1C1C1C1A1A1A1A1A19191919191B1A19191B1A191A
191B19191B19191A1A1A19191A191A1A191A1A1A1A181A1919191A1B19191A1A191A1918
1919181919181B1A
1A1A1A1A191A19181A1A191A191A191A1A191A19181A191A1819191B1A1A1B1A1A1A181A
1A1919191A1B191B1A1B1A1B1A1A1B1A1A1B1B1B1A1A1A1A1A1A1A1B1A1A1A1A19191A19
1A1C1A1A1A1B1A1B1A1B1B1C1B1B1B1B19191A1B1B1B1B1A1A191A1C1B1A1B1B1C1B1B1B
1B1A1C1B1B1B1C1C1A1C1B1B1B1B1A1B1B1B1B1B1C1B1C1C1C1D1D1C1A1B1B1D1B1B1E1C
1B1B1B1D1C1C1D1D1D1D1E1C1D1E1C1D1C1C1C1D1D1C1D1C1C1D1E1C1D1D1D1E1C1D1C1D
1E1D1D1D1D1D1D1D1D1D1E1D1D1D1E1D1F1E1E1E1E1F1E1E1E1D201D1E1E1E1F1F1D1F1F
1E1F1E1E1F1E1F1F201E201F1F1F201F1F1F1F1F1F1F20201E1F1E1F201E20211F21201F
1F201E2021201F20211F1F20201F20201F2020202021202020211E212120202020201F20
1E201F201F20221F202020201F1F1F1F201E1F1F1E202020201F2020201F1E1E1F1E1F1E
1E1E201F201E1F1E1E1F1F1D1E1D1E201D1E1E1E1E1E1F1F1D1E1F1F1D1D1D1F1F1D1E1C
1E1C1D1E1E1D1C1D1D1C1E1D1D1D1E1D1D1D1D1C1C1D1C1C1D1C1B1C1C1C1C1C1B1D1B1D
1D1A1B1C1B1B1C1C1C1C1D1B1C1D1D1C1C1C1B1A1B1B1C1B1A1B1A1B1A1C1C1A1B1B1A1C
1B1B191A1A1A1A1A1B1A1A1A1A1A1B1B1B1B191A191A19181A1A1B1A1A1A1B1A191B1A19
1919181A19191A191A19191A19191A1B191A1A1B191919191A1A1A1A19191A1A1B1B191A
1A19181919191A19
181A191A1A19191A1819181A1A191A1A1A1919191A1B1B1A1A191A1A1A19191A1A19191A
1A1919191A1B1A1A191B1C1B1A1A1B1B1A1A1B1A1A1A1A1A1B1A191B1A191B1B191A1A1A
1A1A191A1A1A1B1B1B1A1A1B1B1B1A191A1A1A1A1B1B1A1A1A1A1C1B1B1F1C1C1B1A1A1A
1C1B1B1B1A1D1A1D191C1B1A1B1B1D1B1B1C1B1C1C1C1C1C1D1C1C1D1B1C1B1D1B1C1B1B
1D1B1B1C1D1D1D1C1C1C1D1D1D1E1D1D1E1D1C1C1D1C1D1D1D1D1D1C1D1E1D1E1C1C1C1D
1D1E1D1D1D1D1E1D1E1D1E1E1E1E1E1F1F1D1E1D1F1E1F1E1E1E1E1F1F1F1E1F1F1F1F20
1F1F1E1E1F201E1F1F201E201F201F201F1F1F1F1F1E1F1F201F20211F201F1F1F1E2020
2020201F1F202020201F202022201F202120202020212020222121202020201F1F222020
2121201F2021202020211F2020211E201F1F2020202021201F1F1E1E1E201F20201F1F1F
201F1F1F201F1E1E1F1F201F1E201F1F1E1E1F1F1F1F1F1D1E1D1E1E1E1E1E1D1D1D1D1E
1E1E1E1F1D1D1E1D1D1C1F1D1D1C1C1C1D1D1D1D1C1B1C1C1C1C1C1C1D1C1D1C1C1C1C1C
1B1C1D1A1C1B1B1C1D1B1C1B1C1B1C1B1B1C1B1B1C1A1B1A1A1C1C1A1B1C1B1C1C1B1B1A
1B191A1B1A1B1C1B1B191B1B1B1B1C1A1A1C191A191A1B19191B1A1A19191A1A1A1B191A
1B191A19191B1B1A1A181A1A181A1A1A1A191A1A1A191A191A191A181A1A19191A1A1819
191A1A1919191819
191A1A191919191A1A191B1A191919191919181B1A1A1A19191A191A1A1A1919181B1919
191B1A1A1A191B1A1B1A1B1B1A1A191A1A191A1A1A1B1A1B1A1A1919191A1A1A1B191A1A
1B1A1A1B1A1B1A1B1B1A1B1B1B1C1C1A1A191B1A1B191C1B1B1B1B1C1B291B1C1A1B1A1B
1B1C1A1C1C1B1D1C1A1C1A1B1B1C1B1D1B1B1B1C1C1C1C1C1B1C1C1C1C1C1C1C1C1C1D1C
1C1D1D1B1C1C1C1D1C1C1C1D1D1D1E1D1E1D1C1C1E1D1C1D1C1D1E1D1C1D1D1D1D1E1B1D
1D1E1D1D1D1E1D1E1E1F1F1D1E1E1D1D1D1D1E1E1D1E1E1D1E1E1E1F1E1E20201D1E1E1F
1D201F1E1F1F201F1F1F1F1F211E1F20201F1F1F1F201F1F1F21201F20201F2021201F20
2020201F2020202121201F20211F20212020202021202120202022212022222220202020
22201F212220202020201F211F1F20201F20201F201F1E201F1F1E1F1E1F1F1F1F1F2021
1F1F1E1F1E1F1F1E1F1F1F1F1E1F1F1F1F1E1F1E1D1E1E1E1E1F1F1F1E1E1D1E1F1E1E1E
1E1E1D1F1E1E1D1D1C1E1D1D1E1D1E1E1E1E1D1C1D1D1C1C1E1C1D1D1D1D1B1C1B1D1C1D
1D1B1C1B1C1C1C1D1C1A1C1C1B1B1B1C1C1C1C1B1B1B1B1C1B1B1A1B1B1C1C1B1B1B1C1A
1C1A1B1B1A1B1B1B1C1B1B1B1B1C1C1B1B1B1A1B1A1A1B1A1B1A1A1A191A1A1A191A1A1A
191A191A19191A1A1A1919191A191919191919181A1A19191A191B191A19191919191919
1919191918191A1A
1A1919191A19181B191A1919191A1919191A1B181A1919191A1A1819191B191919191A1A
1B191B19191B1A1B19191A191A1A1A1A1B1B1A1B1A1A1A1A1A1B1B1A1A1A191A1B1A1919
1A1A191B1A1B1A1B1B1B1B1C1A1C1A1A1B1A1B1B1A1A1A1B1B1B1B1B1B1A1B1B1A1B1B1B
1C1D1B1C1B1B1C1C1B1C1B1B1A1B1B1D1B1C1C1C1C1C1B1C1C1D1A1C1D1D1C1B1D1C1C1B
1B1C1C1C1E1C1C1D1E1C1D1C1D1C1F1B1C1C1D1C1D1E1C1D1E1D1A1B1F1C1D1C1D1E1D1D
1C1C1C1D1C1C1E1E1F1E1D1E1D1F1D1D1E1E1F1E1E1E1E1E201E1E1F1E1F1F1F1F1E1F1F
1F1E201F1F1E1E202120201F1F1F1F201F1F20202020201E1F1F2120201F1E20211F201F
202021212020212121212220202020212120201F202120212120201F2021222121201E20
2020202020202021201E2020211F1F212020202020201E21201F1F2020201F1F201F1E1F
1F1F201F1F201F1E1F201E1F1F1E1E1F1F1F1E1F1F1E1E1E201E1F1D1E1F1D1D1E1E1F1D
1D1D1E1E1F1D1E1E1D1F1D1E1D1D1D1D1E1D1C1D1C1D1C1D1C1B1C1C1C1D1C1C1D1C1B1D
1B1C1B1D1C1B1C1C1B1B1B1C1C1B1B1D1C1B1C1B1C1A1C1C1C1A1B1B1B1B1B1B1B1C1C1B
1C1B1B1A1A1B1B1B1B1C1A1A1B1C1B1B1B1B1A1B1C1A1B1A1A1A1A1A1A19191B191A1A1A
1A1A1A19191B1A191A191A1A1A191A1A191A1A1919191B1A19191A1A191A1A191A1A191A
1A191A191B1A1A1A
19191A191A1819191919191A1A1A1B1A1919191A19191A1B191A191A1A191818181A1B1A
1A1A1A1A191A191A1A1A191A1A1A1B1A191A1B1A1A1B1B1A1A1A191B191A191B1B191A1B
1B1A1C1B1B1A1A1A1C1B1A1C1B1A1A1B1B1B1A1A1B1B1B191A1B1A1B1A1B1B1B1B1A1A1B
1B1A1B1C1B1A1B1A1B1B1C1B1A1B1C1C1C1C1C1B1C1C1C1B1C1B1C1B1C1B1D1D1C1B1D1B
1E1B1D1C1B1D1C1D1D1D1D1D1E1E1C1B1C1D1C1C1C1D1D1C1D1C1D1D1D1C1E1D1D1C1D1E
1F1C1D1E1D1D1E1E1F1E1D1D1E1D1D1E1E1F1E1F1F1E1F1E1E1F1E1E1D201F1E1F1F1F1F
1F1F1F201F1F1F1E20201F201F1F201E1E201F1E201F201F20201F1F1F2020201F1F1F21
21201F1F2021201F20202120202021212222202020232121212020201F21211F21212121
212021202020211F21211F211F202020201F20202020202020211F2020201F1E1F1F1F1E
201F1F1D1F1F1F201F201D1E1E1F1E1F1F1F1E1E1E1E1F1F1F1E1E1F1E1E1F1D1E1E1E1E
1F1E201D1D1E1E1E1E1D1D1E1D1D1D1E1D1D1C1D1E1E1C1E1C1E1B1E1D1D1D1D1C1D1C1C
1B1C1B1D1C1C1C1C1D1B1B1B1C1B1B1C1A1B1C1A1B1C1C1A1D1A1B1B1B1C1B1C1C1A1A1A
1C1A191B1A1B1B1A1C1B1B1A1A1C1B1B1B1A1A19191A191B1A1A1A1A1A1A1A19191B191B
1A1A191819191A1B1B1A1919191A1A191A1A191A1B1A1A1A1A1B1A1A1A191A1B1A191A1A
191919181B1B191B
191919191A191B1A1A1B18191A19191A1A1919191A1A1919191A1A19191A1A1A191B1A1A
191B191A1B1A1A1B1B1B1A1A1B1B1B1A1A1A191A1A1A1A1B1A1A191A1A191B1B1B191C1A
1B1B1B1A1B1A1B1A1B1A1A1C1A1B1B1B1B1B1B1A1C1B1A1B1B1B1B1B1A1B1B1D1B1B1B1B
1C1B1B1B1B1C1B1B1C1C1C1B1A1B1B1C1C1A1C1C1C1C1B1C1C1A1C1C1C1C1C1C1C1D1B1C
1C1D1C1C1D1C1D1C1D1C1C1C1D1D1C1D1D1E1D1D1D1D1D1C1B1E1C1E1D1C1D1D1D1E1D1D
1D1E1D1F1D1D1E1D1E1C1E1D1C1E1D1E1F1E1F1E1E1E1D1F1D1E1E1F1F1F1F1F1F1F1F1F
1E20201E20201F1F1F1F1F1F1F20201F20211F201F1F201F1F20202020212120201F2120
2220212021212021211F212120202121212221212120202020202121221F212022212220
2121201F202021202020211F2121211F1F1F201E201F1F1F211F201F1F1F1E1F1F1F1F1E
1F20201E1F1F1F1F1F1F201E1F1E1F1E1E1F1E1D1E1E201D1D1F1E1D1F1F1F1F1E1E1E1D
1D1D1E1D1E1D1E1D1D1F1D1D1D1D1D1E1D1D1E1D1E1D1C1D1D1D1D1D1D1C1C1D1C1C1D1C
1B1D1B1C1C1D1D1C1B1B1B1C1C1B1C1C1C1C1B1B1C1C1B1A1C1A1A1B1C1B1B1B1B1B1A1B
1B1B1B1B1A1B1B1B1B1A1A1B1A1A1A1B1A1B1A1A1A1A1B1A1B1A1B1A191A1A1A191A191A
1A191A18191A1A1A1A1A1A1A191A1A19191B1A191A1A191B1A1A1B1B1A191A191A1A1919
1A1A1919191A191B
191818191A1919181A18191A191919191919191A1A181A191A1919191919181A191A191A
1A1A1A1A1A1A19191B1A1A1A1A1A1A1A1A1A1B1A1A191A191A191A191A1919191A191A1B
1B191B1B1B1B1B1B1B1B1B1B1B1B1C1A1A1B1B191B1B1B1B1B1B1C1B1B1A1B1A1A1B1B1B
1B1B1B1C1C1C1C1C1D1B1C1C1B1B1C1B1C1C1C1B1C1B1C1C1B1D1B1D1C1C1C1C1C1C1C1C
1B1D1C1C1C1C1C1D1C1C1E1D1E1E1D1E1D1E1E1D1C1C1D1C1D1D1C1D1C1D1D1E1C1C1C1D
1D1E1C1E1F1F1D1E1D1E1E1E1D1D1E1E1D1E1E1E1F201E1F1E1F1E1F1F1F1E1F1E1F1F1E
1F1F1F1E1F1F201F1E1F1F20201F2020201F1F2020201F1F1F1F20202020212221202121
202120202021212121212121202120202020222021212221222022212021202020212021
2121212021222022202021212120201F2020212020201F1F212020201F1F2020201F201F
2020201F1F1F1F1F1E1F201F20201E1D1F1E1E1F1F1E1E1F1D1D1E1D1F1F1E1E1E1E1E1D
1D1E1E1E1E1D1D1E1E1C1C1E1D1D201D1D1D1D1C1C1D1D1C1D1D1E1D1C1E1E1C1C1D1C1C
1C1C1C1B1C1C1B1C1B1B1C1C1C1B1B1C1C1B1B1B1C1B1B1B1A1B1B1C1B1D1B1A1A1B1B1C
1B1A1B1B1B1A1B1B1B1B1A1A1B1C1B1A1A1B1A19191C1B191A1A1A1A1A1A1A191A1A191A
1A1A191A1B1A1A1A1A1B1A1A1A191A191A1A191B1B1A1A1A1A1B1B1B1A1919191A1A1A1A
191A1A191A191A1A
19191A19191A181A19191A1919191A19191A1A1919191B1A19191A19191A191A1B1A1A1A
1A1A191A1A191A191A1A1A1A191A1A1A191A1B1A1B1A1A191A1A1C1C1B1B1A1A1A1B1A1A
1B1B1B191B1A1A1C1B1B1A1A1B1B1A1B1A1B1A1B1A1B1B1B1C1B1A1A1A1B1A1B1B1A1B1C
1B1B1C1A1C1C1B1C1C1C1B1A1C1C1C1C1C1B1E1C1D1C1C1C1C1B1C1C1C1C1C1C1C1B1D1C
1C1C1B1C1C1C1E1D1D1C1E1D1D1E1D1C1D1C1D1C1E1D1D1D1C1D1D1D1C1C1D1C1D1C1D1D
1D1F1D1C1E1F1E1E1D1E1C1F1F1E1E1F1E1E1F1E1E1F1E1F1F201E1E20201E1E1E1F1F20
2020201E201F1F201E202020201F201F1F1F1F20201F1F2020212021211F2120201F2021
2120222120212021202220212221201F2120212121212120222022202020212222202021
21211F2121212121212021202121202121201F20212020212020212021201F2020201F1F
1F1F1F1F201F1F1F1E1F1F1F1F1F1F20201F1F1F1F1E1E1D1E1E1E1E1F1E1D1E1E1E1E1E
1F1E1E1E1F1D1D1E1E1D1E1D1D1D1C1D1D1D1D1D1C1D1B1D1C1D1E1C1D1C1D1C1C1D1D1C
1D1C1C1C1D1C1B1D1C1D1B1B1C1B1B1B1C1C1B1C1B1C1C1C1A1A1B1B1B1B1C1B1B1A1B1B
1B1B1B1B1B1B1A1A1A1B1A1B1B1B1A1B1A1A1B1A1A1B1B1A1B1B1A1A1A1B1B1A1A1A1A19
1A1B1A1A1A191A1A1A1A191A191A1A1A181A1A191819191B1C1B1A1A1A1B19191A1A1B1A
181A1A1A191A191A
19191A191A1A191B18191918181A181A1A1A1A1A1A1A1A1A1A1A191A1A1A1A1A181A1A1A
1A1B1A19191919191A1B1A19191A1B1A19191B1A191A1A191B1B1B1A1A191A1B1A1B1A19
1A1B1B1B1B1B1A1B1B1A1B1B1B1C1B1B1B1B1B1A1B1C1A1A1B1B1B1B1B1B1C1B1B1B1A1C
1D1D1D1A1A1C1D1C1C1A1C1C1C1B191C1B1B1C1C1C1B1C1C1B1C1C1D1C1C1D1D1D1D1D1D
1D1D1C1D1D1C1C1C1D1E1D1D1C1D1D1D1E1E1E1C1E1D1C1D1D1C1D1C1C1E1F1D1E1E1C1E
1D1E1D1E1D1E1D1E1D1E1E1E1E1F1E1E1F1E1E1E1F1F201E1E1F1F1E1E1F20201E1F1F1F
1E1F20201F1F1F201F201F201F221F2020211F2120211F1F2121212020202122221F2122
1F2120212120212020212120212020201F21202121212021211F202021211F20201F2021
20212021212121202220202121201F2020202020211F211F20201F2120201E20211E1F1F
201E1F1F1F20201E1F201F1E1F1F1F1F1E1F1F201F201E1E1F1C1E1E1E1D1F1E1E1E1F1E
1E1E1F1E1E1E1D1E1D1D1D1D1E1E1E1C1D1D1D1D1D1E1D1D1E1D1C1D1D1C1D1E1E1C1D1C
1D1D1C1C1C1C1B1D1C1C1B1B1B1C1C1D1B1C1D1B1C1B1C1A1B1B1C1B1B1B1C1C1C1A1A1B
1C1A1A1A1A1A1B1A1A1A1B1A1B1B191B1A1B1B1A1B1A1A1B1C1A1B1B1A1A191B1A1A1B1A
1A1A1B191A191A191A1A1A1A1A19191A19191A1A191A1A1A1A1B191A1B1A1B19191A1919
1A1B191B191A1819
19191819191A1A1A1919191A19191A19191A1B1A191A19191A19191B1A1A191A1A191A1A
1A191A19191B1A1C191A191B1A191A1B1B19181B181A1B1B1A1A1A1C1A1A191C1A191B1A
1A1A1A1A1B1A1B1B1B1C1C1C1C1B1B1A1B1C1D1B191B1B1A1C1B1B1B1B1B1B1A1A1B1B1B
1C1B1B1C1C1C1C1C1B1C1C1C1C1C1C1C1A1C1A1C1C1C1B1C1B1E1C1B1C1D1C1E1C1C1D1C
1C1D1D1E1D1C1C1D1D1E1E1D1E1E1D1D1D1E1E1D1D1D1E1D1D1D1B1C1C1E1E1D1E1E1D1E
1E1E1E1D1D1E1D1D1E1D1F1E1E1F1E1E1D1E1D1F1E1F1F1E1F1F1F1E201F1F1F1F1F1F1E
1F211F1F1F1F201F20202020211F21211F1F1F1F2021202021212020201F212021202020
212120202021212021202020212021212021222122212220212120202021212122212121
212221202120212220212221202121222021212021202121201F202020211F202020201F
20201F1F1F1F1F1E1F1F201F1F1E1F1F1F1F1F1F1F20201F201E1E201E1F1F1E1F1E1F1D
1E1E1E1D1E1C1E1D1D1F1E1D1D1E1E1F1E1D1D1D1E1D1D1E1D1C1C1E1B1E1C1C1C1D1C1C
1C1C1C1B1D1D1A1C1C1C1B1B1C1C1B1C1C1B1A1C1A1B1C1B1B1C1C1B1B1A1A1B1B1B1C1B
1B1B1B1B1A1B1B191B1B1B1B1B1C1A1A1A191A1A1A1A1A1A1B1A1B1B1B1A1B1A1A1A1A19
1A191A1A1A1A1A1A1A1A1A19191A1B1A191A1A19191A1A1A1A1A1A191A1A19191A1A1919
1B1A1A1918191A19
19181A1A19181A1A1919191B1A19191A1A1B1A191B191B1A1A1A181A191A19191A191A19
1A1A1A1A1B191B1A191A1C1A1B191B1A1B1A1A191B1A1A1B1A1A1A1A1B1A1B1B1B1A1A1B
1B1B1A1A1C1A1B1B1C1C1C1C1B1B1B1A1A1C1A1A1B1C1A1B1B1A1C1A1B1B1B1B1B1B1B1B
1B1B1C1B1D1C1C1B1C1C1B1B1C1B1C1B1C1C1C1C1C1B1D1C1C1C1D1C1C1C1C1D1C1D1A1D
1C1C1D1B1C1B1D1C1D1C1D1D1D1D1D1C1E1D1D1D1E1E1D1E1D1C1E1D1D1E1E1D1E1E1E1E
1D1E1E1E1F1E1E1D1F1E1D1F1E1D1E1F1E1F1F1E1F1E2020202120201E1F201F1F1E1F1F
1F201F211F201F2120201F2020202120202120202020202022212121211F212121212020
222220202221212020222221232222212121212021212221212121212020212120212020
212121212221222122212121202121212020211F201F222022201F1F21201E2020202120
1E201F1F1D1F1F1F201F1E1F1F1E1E201F1F1F1F1F1F211E20201F201E1E1E1E1F1F1F1F
1E1F1E1D1D1F1F1D1E1D1E1F1D1E1C1D1C1E1D1D1C1E1C1C1D1D1D1D1D1C1E1D1C1E1D1D
1C1E1C1D1D1C1B1B1C1C1C1D1C1C1B1C1C1D1B1C1B1C1B1C1C1B1B1B1C1B1B1B1C1B1B1B
1C1B1B1C1B1B1B1A1A1A1C1B1A1B1A1B1A1A1A1B1B1A1B1A1B1B191B1A1A1A1A1C191A19
1A1A191A191B19191A1A1A191A191A1A191A1A1B191A1A1A191A1A191A1A191A191A1B1A
1A1A1A1919191719
191A1819191919191819181919191A1A1A1A1A1A1A1A191A1B1A1B19181A1A1A191A1919
1B191A191A19191A1A1B1B1A1B191A1B1A1B1A191A1B1B1A1A1A19191B1B1A1A1A1A1A1A
1B1B1B1B191B1B1B1B1C1C1B1B1B1A1B1C1C1A1B1B1B1A1B1B1B1B1B1B1B1B1B1B1C1C1B
1B1D1B1B1B1B1D1C1B1C1B1A1E1D1C1C1B1A1D1C1B1C1C1D1D1C1C1C1C1A1D1C1C1C1B1D
1E1C1C1D1D1D1C1D1D1D1D1D1C1D1E1C1E1E1D1B1D1D1C1C1C1F1F1E1E1E1E1F1C1F1E1D
1F1E1F1E1D1D1E201D1F1E1F1E1F1E1D1E1E1F1E1F1F1F1F20201F1F1F1F1F1E20201F1F
2020201F20201F201F1F1F201E201F2021212120202121201F212221211F212220222221
212020212220202020222020212121212122212121212122202221222122232120202220
23212321222121212022212222202121202021202120201F1F1F2121201F1F2120212020
2120201F1F1E201F201F1F1F1E1F1F1F1E20201F1F1F1E1F1E201F1E1F1E1E1F1E1E1E1E
1E1E1F1E1E1D1E1F1D1D1E1D1E1E1D1D1C1E1D1D1D1D1D1D1D1D1D1D1C1E1D1D1D1C1C1E
1C1D1D1C1D1C1C1C1B1B1C1B1B1C1C1B1B1C1C1C1D1C1B1B1A1A1B1C1B1C1C1C1B1A1C1A
191B1B1B1B1B1A1B1C1B1A191B1A1B1A1B1A1A1B1A1A191A191B1A1A1A191B1B1A1B1A1B
1A1A1A1A1A1A191A1A1A1A1A1A1A191A1A1A191B191A1A18191B1B1A1A1A1A1A1A1A1A19
1A191A1A18191819
1919191919181B1A181A1A1A191A1A1B19191A191A1A1A1A1B1A1B191A1A1A191A1A1A19
191A191A191B1B1A1A1B1A1A1A191A1B1B1A1A1A1A1A1A1A1B1A1A1A1A1B1B1A1B1B1B1B
1B1A1B1B1B1B1C1C1D1B1C1A1B1B1B1C1B1C1A1A1A1B1B1A1A1B1B1B1B1B1C1B1C1B1B1B
1B1C1C1C1B1B1C1C1C1C1D1B1C1C1C1C1C1D1B1C1C1B1C1D1C1C1B1D1C1C1C1D1C1C1C1D
1D1C1D1D1B1D1D1D1E1C1F1E1D1D1E1F1E1E1E1D1D1D1F1D1E1D1D1D1F1D1C1D1E1D1D1F
1D1E1F1D1D1E1F1E1F1E1E1F1E1F1F1E1E1F1E1F1D201E1F1F2021201F1F1F20201F1F1F
20201F2020201E1F201F20202020202221201F2120212121212221202121212022202121
2020222122232120222020222221221F2121212120222222212121222122212222222121
22222222222022222120222121212120202121202021212120201F21202021211F202020
2020201F201F211F1E1F1F1F201E201F1F1F201E1E1E1E1F1E1E1F1F1F1F1F1E1F1F1E1E
1D1F1C1D1E1D1E1F1E1E1D1E1E1F1C1D1D1D1E1D1D1C1C1E1E1D1C1D1D1D1C1D1D1D1C1C
1E1E1D1C1E1C1B1D1C1C1B1B1B1B1B1D1C1C1B1C1C1B1A1B1B1B1C1B1B1C191C1A1A1B1B
1A1C1B1A1B1B1C1B1B1A1A1B191B1A1B1B1A191B1A1A1A1B1B1A191A1A1A1A1A1A19191A
1A1A1B1A1919191B1B1A191B19191B191A1A1B1A1A1A191A181B1A191A1A1A1819191A19
1A1B1919191A1919
1A1A1A1918191A1B181A191A1A191B1919191A191A1A1819191B1A1A1A1A1A1A191A1A19
191A191A1B191A1A191A1A1B1A1B1A1A1A1A1B1A191B1A1B1A1B1A1A1A1A1A1B1A1B1B1B
1A1A191B1B1A1B1C1C1C1B1B1C1C1A1B1B191A1B1B1A1A1A191B1B1B1B1B1C1C1C1D1B1B
1B1C1C1B1D1D1B1C1D1B1C1B1C1C1D1C1D1C1B1A1D1B1C1C1D1D1D1D1E1D1D1C1C1D1C1B
1B1C1D1D1D1C1E1D1D1D1D1D1D1C1D1E1D1D1D1D1C1C1D1D1D1F1D1F1E1E1E1F1D1E1E1D
1F1E1E1E1E1E1F1E1E1F1E1F1F1F1F1F1F1F201F1F1F1F1F201E1F1F1F201F20201F2020
1F2020202021202020202020212120202020201F20212122202121212221212020202021
212121202220212121212121212222222121212122222221212221212022212222212221
22212122212121232221212020212021212121212021221F21222021202120202220201F
20201F1F21201F1F1F201E1F1F1E1E201F1F201F20201F1F1D1F1F1E1F1E1E201E1E1F1F
1D1F1E1F1F1E1E1E1E1D1D1D1E201D1C1E1D1D1D1D1C1C1C1D1D1D1D1D1C1D1C1D1C1C1D
1D1C1D1C1C1C1B1C1C1E1C1C1C1B1C1B1B1B1C1C1D1B1B1B1C1C1B1B1A1B1C1B1B1B191B
1C1B1C191B1B1A1A1A1A1B1B1A1B1A1C1B1B1A191A19191B1B181A1A1A1C191A1A1A191A
1A1A191A1A1A191B1A191A1A1A1A191A191A1A1A1A1A1A1A19191A181B1A1A1A1A191A1A
1A1A191A1919191A
1919191919191A1B191A1A19191A181B1A1A1A1A1A1A191A1A191A181A191A1A191A1A1A
191B1A191A1A1A1A1A1B1A1A1A1A1B1A1A1B1A1A1A1A1B1B1A191B1B1B1B1B1A1B1B1A1C
1B1A1B1A1A1C1B1B1B1B1C1A1D1B1A1D1B1A1B1D1B1B1C1B1A1B1B1B1A191A1B1C1B1C1C
1C1B1B1C1B1C1B1C1A1B1C1B1C1B1C1B1C1C1C1C1B1C1A1C1B1C1C1C1B1C1D1D1B1D1B1C
1D1C1C1D1D1C1C1D1D1E1D1C1C1D1D1C1E1D1D1D1D1C1C1D1C1E1E1F1E1E1E1E1E1D1F1D
1D1D1F1E1D1E1F1D1E1F1E1E201F1E1F20201F1F1F201E1D1F2020201F201F1F1F202020
21201F20202120212121212121212021212121201F222120202222222121222021222021
212021222220202121212122212122212221212122232322212221212222222120212222
222023222221212121212020211F201F20222021201F21202220202020201F2020212021
2020201F1F1F201F20201F1F1F1F1F1F1E1F20201F1F1E1F1F1F201E1F1E1F1E1E1D1F1E
1E1E1F1F1E1F1D1F1E1E1D1F1E1E1E1E1D201E1D1E1E1C1E1E1E1C1D1D1D1D1C201E1E1E
1D1C1C1D1D1D1D1B1C1B1C1C1C1B1C1C1C1D1D1C1B1B1C1B1C1C1A1C1B1B1C1B1A1B1B1B
1B1B1C1B1A1A1A1A1B1B1C1C1B1B1B1B1A1B1A1A1A1A1A1A1A1A1A1B1A1A191A191A1A19
1919191A1B181A1B1A1A1B1A1A1A19191A1A191B1A191919191A1A191A1A1B191A191B19
1A19181919191819
1917191918191A19191A181B19191A191A1919191A1A191A1A1A1A191A1A191B1B1A1A1A
1A1A1A1A1A1B1B1B1A1A191B1A1A191B1A1A191A1A1A1A1B1B1B1A1B1B1B1A1A1A191B1B
1B1A1B191B1A1A1B1B1B1C1B1B1B1C1B1A1B1B1B1B1C1B1C1C1C1B1A1C1C1C1B1B1C1B1B
1B1A1C1B1B1C1B1B1B1C1B1C1C1B1C1D1B1C1D1C1B1C1D1B1B1C1D1C1D1C1D1D1D1D1C1C
1E1E1C1D1B1C1D1C1D1D1C1D1E1E1E1E1E1E1D1D1E1D1D1E1D1E1E1F1D1F1E1E1E1D1E1E
1D1E1F1D1E1E1E1D1F1E1E1F1E1E1E201F201E201F202020201F1F201F201F211F1F2021
211F20202021202022222022222020212222212122212221212122202022222221222122
202121212221222023212121212220222022222221232222212222202221212221212221
212021232222222222212021212022212021202122212120202221202021202120201F1F
201F21201F20201E1F201F1F211E1E1E201F20201F1F1F1F1F1F1F1E1E1F1F1E1E1E1E1E
1E1F1E1E1E1E1F1F1E1F1E1E1F1D1D1F1E1D1E1E1D1E1E1C1D1E1D1D1C1E1D1D1E1E1E1E
1D1E1C1D1C1B1C1B1D1C1B1C1B1C1B1D1C1C1D1C1D1D1C1A1B1C1B1C1B1B1C1B1B1C1B1A
1B1B1B1B1C1B1A1A1B1B1C191B1B1B1A1A1A1B1B1A1B1A1A1A1A1A1B1A191A191A1A181A
1A1A1A19191A1A1B1A1A191A1A1B191B1A1A191A1A191A1A1A191A1A1A191B191A1B1A1A
191918191818191A
19191819181A1A191A1A191B1A191B1A1919191919191A1A19191A191A19191A191A181A
191A1A1A1A1A1B1A1A1A1A1A1B191A1A191A191B191A1A1A1A1B1C1A1A1A1A1A1B1A1A1B
1A1B1B1B1B1B1C1B1B1C1C1B1B1B1C1C1B1B1B1B1B1B1C1C1B1B1B1B1A1B1B1B1C1C1C1B
1B1B1C1C1C1C1B1B1C1C1D1C1C1D1C1C1B1C1B1C1C1C1D1D1B1C1C1E1D1B1D1D1C1C1E1D
1C1D1C1D1B1C1C1C1D1D1E1C1E1E1D1D1C1E1D1D1D1C1D1D1F1F1F1F1E1E1F1E1E1F1F1F
1E1E1E1D1E1D1E1E1F1F1E1F1F201F1F1D1E20202020201F1F20201F202020211F212020
212120202121202121212121212122212220222020212121212122222122212122212021
222222232222222121212122202221222221212121222221222322222122222222222121
22222122212222212223222121202021222221202122222222222220212120201F222020
1F202120211F201F211F1F211F211F1F201E1F1F20201F1F1E1F1F20201F1F1F1E1F1F1F
1E1F201E201E1F1F1E1E1F1E1E1E1D1D1E1E1F1E1D1E1C1D1E1C1E1E1C1D1D1E1E1E1E1D
1E1D1C1D1D1C1D1C1D1D1C1D1C1B1D1C1C1B1C1D1C1C1B1C1C1C1B1B1B1C1C1B1B1B1A1C
1A1B1B1B1A1A1B1A1B1A1B1C1A1A1B1A1B1B1A1A1A1A1B1B1B191A1A1A1A191A1B191919
1A1B1A191A1A1A1919191A181B1A1A1A1A191A1A1A1A1A1A1A19191A191A1A1A19191A1A
1A191A1819161819
19191A19191919191A1A1A1A1919191B1B191B1A191A1A1A1A1919191B1A19181A1A1A1A
1B1A1A191A1A19191C191A191A1A1B1A1B1A1B1B1A1A1A1A1B1B1B191A1A1A1A1A1B1B1A
1A1B1A1A1B1B1C1A1C1B1B1B1B1A1B1A1B1C1C1C1B1E1B1A1C1B191C1C1A1B1C1B1B1B1C
1D1C1C191C1B1C1C1B1C1C1C1D1D1B1C1B1D1B1C1C1C1D1E1D1C1B1D1C1D1D1E1D1C1D1D
1D1E1D1D1C1D1D1D1D1D1D1C1E1C1D1E1E1D1D1E1F1D1E1E1D1F1F1E1E1D1E1D1D1E1E1D
1F1E1D1D1D1E1E1E1E1E201F1F1F1F201F201F201F2120202020202021201F2021212120
202021202120212020212321202121212121202222212121212120212021212122212222
212122232222222222212220202120202120232322212221212222232221222122212221
232122212122212220212122212221212121212121212120202122222120202020202121
201F20202021201F201F1F20211F1E211F1F201F1F201F201F20201F1F201F1E1F1D1E1F
201F1F1E1F1F1F201F1E1F1D1E1E1E1D1E1F1D1C1D1D1E1E1E1D1D1E1B1D1E1E1E1D1E1E
1D1D1D1C1D1C1B1C1D1D1B1C1C1C1C1B1D1C1C1C1D1C1B1C1C1C1D1C1B1B1A1C1B1B1C1B
1B1C1A1B1A1B1B1B1B1B1C1B1B1B1B1A1C1B1B1A1A1A1A1B1A1A1A1A1919191A1B1A191A
1A191A1A191A1A1B1B1A191A191B1A191A19191A1A191B1A1A1A1919191A1A1A1A1A1C1A
191A191919181A19
1919191A1B1A1A1919191819191A191A191B1A18191A191B191A1A191A191A1A1A191A1A
1A1A1B1A191A1B1B191A1C1B1A1A1B1A1B1B1B1A1B1A1A1B1A1A1C1C1B1A1B1A1A1A1A1A
1A1A191A1A1B1D1B1B1B1B1B1B1B1A1B1B1C1B1B1A1A1A1B1B1A1A1A1B1A1C1B1C1B1B1B
1C1B1B1C1B1C1B1B1C1C1B1B1E1C1C1E1D1C1C1D1C1C1D1D1C1C1D1C1D1C1C1D1E1C1B1D
1C1C1D1E1D1E1D1D1D1D1D1D1E1D1D1E1D1E1D1E1D1F1F1E1E1D1E1D201E1F201D1E1D1E
1E1E1F1E1E1E1F1F1E1F1F1F1F1E201F1F201E1F1E1F2020201F20211E20201F21202021
202120202021212122212022212022222221212121222122212221212221212221212221
222021232323222121212121222222222222212323222123232123202221212122212223
22212423222221212222202120222222212121212122222120212121212121212121211F
2021202121211F1E1F201F1F20201F1F20211F1E1F1F201E1F1F201F1F20201F1F201E1E
1F1E201F1E1E1F1E1F1D1D1E1D1E1E1E1E1D1F1E1D1D1E1D1E1E1D1E1D1E1D1D1D1E1D1E
1D1B1B1B1C1D1C1D1C1D1D1B1C1C1C1C1B1C1C1C1C1B1B1C1B1B1B1A1A1C1C1C1B1C1A1B
1B1B1A1A1B1B191B1A1B1B1A191A1B1B1B1B1A1A1C1B1B1B191A1A1A191A1A1A1A191A19
1B19191B1B1A191B1A1A1A1919191A19191A19191B1A191B19191A1B1919191B1A1C1A1A
1A19191919191919
1A1A18191818191A1A1A1919181A1B1A191A1A1A191919191A1B191A191B1A1A1A1B1A1A
191A1B191A1A191B191B1A1A1A1A1B1A1B1B191A1A1B1B1B1A1B191B191A1A1B1B1A1B1A
1A1A1A1C1B191B1B1B1B1B1B1A1B1A1B1B1A1C1B1A1C1B1B1B1C1B1C1B1C1A1B1C1A1B1B
1C1C1B1A1D1B1B1C1C1B1B1B1D1C1C1B1C1C1D1C1D1B1D1D1D1D1E1C1D1D1D1C1D1D1D1C
1E1D1D1D1D1D1D1D1F1D1E1E1D1E1F1E1D1C1D1D1D1D1D1E1E1E1E1E1E1F1F1F201D1E1F
1F1E1E1E1E1E1E1E1E1F201F1F1F201F1F1F1F211F1F20201F2120201F201F202020211F
2121201F2020212221212222222220212221212121212222212121202222212222222222
212222222123212123212321232221222122222222222122232222212222232220212221
232122212222212123212122222221212122222222222121212121212122212021212121
202120201F2020212020201F202020201F20201F1F1F1E1F201F1F1F201F211F1E1F1E1F
1F20201F201F1F1F1E1F1E1E1E1E1E1E1D1E1E1E1D1D1D1E1D1E1E1E1E1E1D1D1D1D1D1F
1C1C1D1C1C1C1D1C1C1D1C1C1B1B1C1C1D1C1B1C1C1D1C1B1B1C1B1C1A1B1B1C1B1B1A1A
1A1C1B1B1B1A1B1B1A1B1A1B1B1A1B1A1C1A1A1A1A1B1A1B1A1A1A1B1A1A191B1A191A1A
191A1A1B1B1A1B191B1A191A1A1A191A1A191A1A19191A1A1A1A191B1A1A1A1A191A1919
19191A1A191A1819
1A191918191919191A191A191A1919191A1B191A1A1A1A1A191A1A191A191A19191A191B
1A1A1A1A191A1A1A191A1A1B191B1B1B1A1B1A1B1A1A1A1A1A181A1A1A1C1B1A1B1A1A1B
1B191B1B1B1B1B1B1A1B1B1A1B1B1B1A1B1B1B1C1B1B1C1B1C1B1C1B1B1C1B1B1D1C1B1C
1C1B1C1B1C1B1B1C1B1D1C1C1C1D1C1C1C1C1C1C1C1C1C1C1C1C1C1C1D1D1D1D1D1E1D1C
1D1D1C1D1D1D1C1C1D1D1D1C1E1E1F1E1E1F1F1D1D1D1E1E1E1E1F1E1E1E1E1D1F1E1E1C
1E1F1E1D1F1E1E1D1E1F20201F1E1F201F2020201F201F1F20212020201F201F22211F1F
202220202122222021212222212122212022212123212222222221222221222122222222
222322212223222321222123232221222121202222232223222121232221222223222222
22212322222122222222212222212222232121222222201F222122202221212120202021
2021202121201F20212020201F1F2021201F1F211F201F1E1F1F1F1F1F1F1F201E20201F
1F201F201F1D1F1E1F1D1D1F1E1D1E1E1E1E1D1E1F1D1E1D1D1E1D1D1E1D1E1E1E1E1D1D
1D1D1E1D1E1C1C1D1C1C1C1D1D1D1C1D1C1C1B1C1C1C1D1C1C1B1B1B1A1B1B1B1C1C1B1B
1B1A1C1B1A1B1B1B1C1B1B1D1A1C1A1B1B1B1A1A1A1A1A19191B1B1B19191A1A1A1A1919
1819191A1B1A191A1A1A191A1B191A191B1A1A191B1A1A19191A1A1A1A1A19191A1A1919
191919181A191919
191A1A1A191919181918181A1A191A1A1A1A191A1A19181A191A19191A1A1A1A1A1A1918
1A1A191A1A1A1A191B1A1A1B1A1B1B1C1C1B1B1B1A1A1A1A1A1A1A191A1A1A1A1B1B1A1A
1A1A1A1B1B1A1C1A1B1B1B1C1A1B1C1B1B1B1B1B1B1C1C1C1B1C1C1A1B1D1B1C1B1B1B1B
1C1D1C1D1B1B1C1C1C1C1B1C1C1C1D1D1C1B1E1B1D1C1F1D1D1D1C1D1D1D1D1B1C1D1D1C
1C1E1E1D1E1D1E1D1D1C1C1D1E1F1E1E1E1E1E1E1E1F1D1E1E1F1E1C1E1D1E1F1E1F1D1F
1E1F1E1E1F1E1F1F1E1F1F201F201F201F1F1F2020202020202020202020212021211F21
222021222221202223222022202021212222212221222221212122212222212220212121
222221222121232322222121222122222222212422212322242222202422222122232222
232222222222222122212223212222232122212123222223212320212121222120212120
2020202220212020201F201F1F2121211F20201F21211E1F1F1F201F1F1F211F201F1F1F
1F1F1F201E1F1E201F1E1E1F1E1D1E1D1D1E1E1E1D1E1D1D1E1D1D1E1E1E1E1E1E1D1E1C
1B1E1D1C1D1C1D1B1C1D1B1C1C1C1B1C1C1D1C1C1C1C1C1C1B1C1B1B1C1B1B1B1B1B1C1B
1B1B1A1C1B1C1B1B1B1A1C1A1D1A1B1B1B1A1A1B1A191A1B1B1C1A1A1B1A1A1A1A191A1B
191A181A1A1A1A1A1A1A1A1A1A19191A1A1A1B1A19191A19191B18191919191A1919191B
1919191819191918
191A191919191A1A1819191B191A1A1A191A181A191A1A191A1A1A19191B1A191A1A1A1A
191A1A1919191A1A1A1A1A1A1B1A1B1A1B1B1A1A1B1A1A1C1B1A1B1A1A1A1A1C1A1B1B1B
1A1B1B1B1A1A1B1B1B1B1C1B1B1B1B1B1D1A1A1B1C1C1C1B1C1B1B1C1B1D1B1B1C1B1B1C
1D1C1B1C1C1C1C1C1C1B1D1C1D1C1C1C1D1D1D1D1D1D1D1E1D1D1D1D1D1D1D1C1C1D1C1D
1C1D1D1C1D1D1B1D1D1D1F1F1E1E1D1E1D1E1E1E1E1F1F1F1E1D1D1F1F1F1E1E1E1D201E
1F1E1F1F201E1F1E1F1F201E1F1F1E1F1F201F202020202120202020201F202021212220
211F20222122212222222222222121212121212122212222222322222223212321222221
222222232222212221222222212123222322242322232122212222232323232323222222
22222323232322222222232223222321222322222322232322222222222022201F212120
21212120212220201F2020201F211F1F211F1F201F201F20201E1E1F1F20211E201F1E1F
1F1F1F1F1F1F1F1F1E1F1E1E1E1F1D1E1E1E1D1D1D1E1C1E1D1D1E1E1F1E1E1C1D1D1D1D
1D1D1D1D1D1D1D1D1C1C1B1B1C1C1C1D1D1C1C1C1B1C1B1C1B1B1C1C1B1C1D1B1B1B1B1D
1C1B1B1A1B1A1B1A1B1A191B1B1B1B1B1C1B1B1B1B1B1B1A191B1B1A191A1B191A1A1A1A
191A1A19191A1A1B1A1A1A1A1A1919191A1919191A191A1A191A191A191A1A191A1A1A19
1A1B191818191919
1819191A181A1A19191918191A1919191919191A1A19191919191A1B1A191A19191A1A1C
1A1A1A191B1B1B1B1A1A1A1A1B1B1B1A1A1B1A1A1B1A1A1A1A1A1B1B1A1B1A1B1B1A1A1A
1A1B1B1B1B1B1A1A1B1A1B1B1B1A1B1B1C1B1C1B1B1B1B1B1B1B1B1D1C1C1C1B1C1C1C1D
1B1D1C1E1B1C1B1D1B1C1C1C1D1C1C1C1D1B1D1E1D1C1C1B1C1C1C1C1E1E1D1D1D1D1C1C
1D1D1E1F1C1D1D1C1D1D1E1E1F1E1F1E1E1E1E1E1E1E1F1D1E1E201F1E1E1D1E1E1E1F1E
1E1F1F1F1F1F1F1F201F1F1F20211F201F21211F1F20201F1F201F212120212220212121
202121212221212122222222212123212123222123232023232221222121222221222322
222222222322222122212224222221232222212122212123232323232123232221232322
24212122232224222221232222232322222223222322222223222121212121221F212022
212020202021202020211F20201F1F211F1F1F1F20201E1F1E1F201F1F1E20201F201F1F
201F1F1F1E1E1F1E1E1E1E1E1E1D1F1D1F1D1E1F1D1D1F1E1F1E1D1D1D1E1E1E1D1D1D1D
1D1D1C1D1C1D1D1D1C1D1D1B1C1C1C1B1C1B1C1C1D1A1B1B1B1A1B1C1B1C1C1B1B1C1C1B
1A1C1B1A1C1B1C1C1C1B1A1A1B1B1A1A1B1C19191A1B1B1B1A1C1B1A1B1A1A1B1A1B1A1B
1A1A1A1A1B1B1B191A191A1B191A1A1A1A1A1A1A1B19191A1B1919191A1A191A191A1919
191A19191A191919
19181818191A181A19191919191A1A19191A191919191A1A1A19191B1919191A19191819
1B1A1A1A1A1A1A191B1A1B1A1B1A1A1A1B1C1B1C1B1A1A1A1A191B1B1A1B1A1A1A1A1A1B
1B1B1B191A1B1B1C1A1A1B1A1B1B1B1B1A1D1A1A1C1C1A1B1B1B1C1C1D1B1C1C1B1B1C1B
1B1C1D1B1C1D1C1C1C1C1C1C1D1C1D1D1D1C1D1C1C1D1C1D1D1E1E1D1C1D1D1D1D1C1C1D
1D1D1D1D1E1D1D1E1E1E1D1D1D1E1E1D1D1E1F1F1E1E1F1F1F1E1E1D1E1E1E1E1E1E1E1F
1E1D1F1F201F1F2020202120201F201F1F21201F1F202020212020211F21202121212022
212122212121212222212222232222232122212122212123212221222123232222232222
212324212323232222232222212423232222232121232323232222222222222123222222
232121212222222322222323252323232222242022232322232222222322212221212221
221F2020202120212022201F212021211F1F20201F1E20201F201F211E201F1F1F201E1F
201F1E1F1F1F1F1E1E1E1E1F1E1D1E1F1F1E1E1E1D1E1F1D1E1D1C1E1E1E1D1D1D1E1E1D
1D1D1C1D1D1C1C1C1C1C1C1C1D1B1B1B1B1C1C1C1B1C1A1B1C1B1B1B1B1B1B1D1C1B1B1B
1C1B1C1B1A1B1B1B1C1B1A1C1A1B1B1B1B1B1B1B1A1A1A1A1B1B1A1B1B1A1A191A191A1A
1B1A1A191A1A1A1A191A1A1B191A1A1A1A1A1B1A191A1919191A1A1B19191B191A1A191A
1A1A181918191819
19191918191A191A1A1A1A191A1A19181A191A19191A19191A191A1A1A1A1A1B1B181A1B
191A1B1B1A1A1A191B1B1A1A1A1B1B1B1B1B1B1B1B1A1B1B1A1A1B1B1B1A1A1B1B1B1A1B
1B1C1A1B1B1B1B1B1B191B1C1B1B1B1A1A1A1B1B1B1A1B1A1C1D1C1C1C1C1C1C1D1D1C1B
1B1C1C1B1B1C1B1D1C1D1B1D1D1C1D1D1E1C1C1D1C1C1D1D1C1E1D1D1D1D1D1D1D1D1E1E
1E1E1C1D1D1D1D1D1E1E1E1D1D1F1E1D1E1F1E1F1E1F201E1F1E201E1F1F1E1F1F1F1E1E
1F1F1F211F211F211F20201F1F2020202020202021202021202122212020212221212021
202121212121222222202223212122222322232221222322242323232221222222222322
212322222222212124232324232222232222232323242222232322232323212222232222
222222232322232222232322242124232322232423232324232423232323222222212121
2121212121212021212121202121202021201F20201F1E1F212021201F1F201F1E20211F
1F1F1F1F1F201F1E1E1F201F1E1E1D1E1D1E1E1F1E1E1D1E1F1E1D1D1D1D1D1E1E1D1D1D
1D1D1D1D1C1D1D1D1C1C1D1C1D1D1C1C1B1C1B1C1D1C1C1B1C1C1C1B1C1C1C1B1C1C1C1C
1A1B1C1B1D1C1A1B1B1C1B1C1B1B1B191B1B1A1A1B1A1B1B1A191A1A1A1A1B1A1A1B1B1A
1B1A191A1B191B1A1A1A1B1A1A1A1A1B1A1A1A1A191A181919191A191A1A191A19191A19
1A19191A1A19191A
191919181A1B1A1919181A191A19191A19191A1B19191A1B191A1A1B1A181819191A1A1A
191A19191A1A1A191B191B1A1A1A1B1A1A1A1A1A1B1A1B1B1A1A1B1A1B1A1A1C1B1B1A1B
1A1A1A1A1C1B1B1B1B1A1B1A1A1B1B1B1B1A1C1C1B1C1B1C1C1C1B1C1C1C1B1B1B1C1B1D
1B1B1D1B1B1C1C1C1C1D1B1C1D1C1C1D1B1C1D1C1D1D1C1D1D1D1C1D1C1D1C1E1D1E1D1D
1E1D1C1C1D1E1E1C1D1C1D1E1C1D1F1E1E1E1E1E1D1F1F1D1F1F1E1F1E1E1E1E1F1F1F20
202021211F2022212021201F1F201F1F202020201F21202021202121202021202021201F
212120222020222221222121212122232222232222212323232323232323222322222323
232423222424232321232322232222232223222322232323242423222222222322222223
242223222222232321222222232424232223232322232224232524252221232221212121
22212122202122222120211F1F20202020201F202021201F1F202020201F20201E201F1E
1E201F1E20201E1E201E1F1E1F1E1E1F1E1E1E1E1D1D1F1E1E1D1F1E1E1C1C1C1F1D1E1E
1D1D1D1D1D1D1C1C1D1C1E1D1C1B1C1B1B1C1D1D1C1C1B1C1C1C1A1B1B1C1B1B1C1D1D1B
1B1B1C1B1A1A1C1A1B1A1A1B1C191C1A1B1B1A1A1B1A191C1A1B1A1A1C1B1A1A19191B1A
181A191A191B1A1B1A1A1A191A1A191B1C1A1A1A191B181A1919191B191919191A1A1A1A
191A191918191919
19191918191A1A1A181A1A191A1A191A1919191A19191B1A1A1919191A1A1A1A1A181919
191B19191A191B1A191B1A1B1B1A1A1B1A1B1A1A1B1B1A1C1A1A1C1B1C1B1B1B1A1B1A1A
1A1B1B1A1B1A1A1B1B1C1C1B1B1B1B1B1B1C1B1C1B1B1B1C1C1A1C1C1A1C1C1B1C1C1D1C
1D1C1C1B1C1D1B1C1C1C1C1C1D1D1C1D1D1C1C1C1D1D1C1D1E1E1E1E1D1D1D1D1D1D1D1F
1D1C1E1E1C1E1E1D1D1D1D1F1D1E1E1F1F1F1F1F1F1F1E1E1D1E1F1E1E1E1F1E1F1E1F20
1F21202120202020202021201F2020202020212221202020202020212120212121212221
212021212222222222222220222222232321222222222422222222212323232223222322
232322222221222222222222232222222223242422222323232422232322222223222222
232323232223232223222324222423232223242422242324242423242422242221222221
21212122222220212121201F20211F20201F1F1E2020202020201F1F1F201E201F1F1F1E
1F1F20201E20201F1F1E1F1F1E1F1E1F1E1F1F1F1F1E1E1E1E1E1E1D1F1E1E1E1E1C1D1E
1D1D1C1D1D1C1D1D1B1D1D1C1D1C1C1D1B1B1C1C1C1B1C1B1C1B1A1B1C1D1B1B1C1B1C1B
1B1C1C1C1B1A1B1B1B1C1B1A1A1B1B1A1B1B1B1A1B191B1B1C1B1A1A1A1B1A1D1B1A191A
1B1A1B1B1A1A1A1B1A1A1A191A1A19191A1A1A191A1B1A191B1A19191A1A1B1A1A19191A
191A191A19191919
1919191A19191919191A1A191A19191A191B191A191B19191A191A1A1A191A19191A1A19
1919191A1A1A1A1A191A1B191B1A1A1B1B1A1B1B1B1A1A1B1C1A1B1A1B1B1B1B1A1A191B
1A1B1B1B1B1D1B1B1B1D1B1A1A1A1B1B1A1B1B1B1A1B1B1B1C1C1B1B1B1C1C1C1B1C1D1C
1B1C1B1C1C1D1C1D1B1D1D1D1B1D1C1C1D1D1D1C1C1C1D1D1D1D1D1C1C1B1D1E1C1E1F1D
1E1D1E1E1E1E1F1E1D1F1C1F1E1F1E1D1E1F1F1E1F1E1E1D1E1F1F1E1F1E1E201F1E1F1E
1F201F212120232121221F201F1F20202121202020212021202121202021222221222122
212022202221222123222221232222232022232224242324232222242323232323232224
232424252322222324222323222324222323232323242323222423232223222424242325
242322232222232322212324222523232321232224242424242525242423222222222223
2022202121222120202121212121201F1F20202020201F21211F201E201F1F201F1E2120
1F1F2020201E1E1F1F1E1E1F1E1E1E1E1E1E1E1F1E1E1D1E1F1D1F1C1F1E1D1E1D1B1D1E
1C1D1E1D1E1E1C1D1D1E1D1C1C1C1D1D1D1D1B1B1C1C1C1B1D1B1C1D1C1C1C1B1B1C1C1C
1D1C1B1C1B1C1A1B1A1C1C1A1B1A1C1B1B1B191B1B191B1A1B1B1A1B1A1B1B1A1B1A1A1A
1B1C1A1B1A1A1A1B1B19191A1A1A191A1A1A191B1B1A1A1A1A191A191A191A1A18191A19
19191A191A191819
1A191A191919191A1919191A1A191A1B1A19191A19181A1A1A1A191B1A19191A191A1A1A
19191A1B19191A1A1A1B1B191A1A1A1A1B1A1A191B1B1B1B1C1B1B1C1A1B1A1A1A1A1B1B
1C1A1B1B1B1B1C1B1B1C1B1B1B1C1A1A1B1B1A1B1B1C1A1C1B1B1C1B1A1C1B1B1C1C1C1C
1C1B1B1C1E1C1B1D1C1D1C1C1D1C1C1C1D1C1E1D1C1C1D1C1C1E1D1D1E1E1D1E1C1D1D1E
1E1E1F1E1E1F1E1D1E1E1E1E1E1E1D1E1F1E1F201F1E1F1F1E1D201F1F201E201F201F1F
1F20212121212222222121211F1E1F201F20202021202021212122202221212121222122
212023212121222122222221212222212123232321242424232423242423232423232323
222323232322232324232323232323212422222323242424232423232422232324242423
222322242323232324242223222222242224242223232426252523242422222222232321
21232120212120202121212120202020211F201F2020201E1E202021201F1E1F201E1E1F
1F1F1F1F1F1F1F1E1F1F1F1F1E1F1F1E1E1E1E1E1E1E1D1E201E1E1F1E1D1E1E1C1D1E1D
1D1C1E1E1D1D1D1E1D1B1D1D1C1B1E1D1D1C1B1C1D1D1C1B1C1D1A1B1B1B1C1B1B1C1C1D
1C1B1A1C1D1C1C1A1C1B1B1B1A1B1C1B1C1A1A1A1A1B1C1B1A1A1A1A1A1A1B1A1A1A1A1B
191A1A191B191A19191A1A1A191A191B1A1A1A191A191A1A1A1A1A191A1A1A191919181A
1A1A191A1A19181A
1A19191A1A1A1A1A1A19191A19191A19191A1A18191A19191919191A191A1A1A1A19191B
1A19191A1A1A181B1A1A1A1A1B191A1B1B1A1C1A1A1A1B1B1C1B1B1B1B1C1B1A1B1C1B1A
1B1B1C1A1C1D1C1B1A1B1C1B1C1B1A1B1C1B1B1B1B1B1C1C1B1C1C1B1A1C1C1B1B1D1C1C
1C1B1C1C1C1B1D1D1C1B1C1B1B1D1C1C1C1C1D1D1C1D1D1D1D1D1D1D1C1D1E1D1F1E1E1D
1D1D1E1E1D1E1E1F1F1E1D1E1E1F1E1E1E1E1E201F1E1E1F1E1E1E1F1E1F202020202120
2020212021222122222021201F212020202221212122202121212121211F212021232121
212322212223222221222122212223222222232322232323232324232322232323232324
232322232423232524232423232223252324222322232323232322232324242324232324
232323222324232323232224232324242423222423242425252523232323222222222221
222121222221222123202020202120221F20201F1F20201F1F201F201F1F201F1F1F1D1F
211E1E20201F1E1E1F1F20201E1F1E1E1F1F1D1F1E1E1F1E1C1E1F1E1E1D1B1E1D1E1D1D
1E1C1D1E1E1D1D1D1B1B1D1D1C1D1C1C1C1C1C1D1C1C1C1C1A1D1B1C1B1B1D1C1C1B1B1C
1B1D1E1C1B1B1B1B1B1B1B1B1A1A1B191C1B1B1B1C1A1B1A1A1B1B1B19191B19191B1A1A
1A1A1A1A1A191A1B1A1B1A1B191A191A1A1B1A191A1A19191A1919181B19181A191A1819
191A1A18191A1A1A
19191A191A19191B1A1A19191A191A1A1A1A1B1A1A191A1A1A1B1A1A1A191A1B191A1A1B
191B191B1B1B1A1B191A1B1B1A1B1B1A1B1B1B1A1A1A1B1B1B1B1C1B1B1C1B1A1A1B1B1B
1B1B1B1B1A1B1B1C1B1A1B1B1B1B1B1A1B1C1B1C1B1B1A1C1B1A1C1C1B1D1B1C1C1D1B1C
1D1D1D1D1C1B1C1D1C1C1C1C1D1C1E1D1D1C1C1D1D1E1D1D1C1D1E1D1E1C1E1D1E1D1D1D
1E1D1E1E1D1D1D1D1F1D1E1E1E1E1F1E1E1E1F1F1E1F1E1E1F1F1E201F1F1E201E1F211F
201F211F22222222201F212020201F21201F201F2122222220212021222222221F212122
222222222224222322212323212123232223222322222423232422232323242322232322
222423232424232322232423232423252324242223222324242324242323242425232423
232224232324242322242122252323242323232323232326242424232123212222212221
222021212221212221212121212022222021201F201F2020211F1E20211F1E1E20201F21
201F1F2120201F1F20201F1E1E1F201F1E1E1F1F1E1E1E1E1D201F1E1D1D1E1D1E1D1D1E
1E1D1D1C1D1D1C1D1C1D1C1D1D1B1C1B1D1C1C1C1B1D1C1B1C1B1B1C1C1C1D1D1D1B1B1B
1B1C1B1C1B1C1B1B1B1B1B1B1B1C1B1C1A1A1B1B1A1B191A1A1B18191A1B1B1A1B1A1A1A
1A1A1B1A1A191A19191A1A1A1919191A1A1B1B1919191A1A191918191A1A1A1819181A1A
1819181A1A1A1918
1919191A1A19191A1A1A1A1A18191A191A1A19191A1A1A1A191B1A1A1A1A1B1A1A191A19
19191B191A1B191A191A1A1C1B1A1A1B1B1B1B191C1A1B1A1A1C1A1C1B1C1B191A1B1B1A
1B1B1C1B1B1B1A1C1C1B1C1A1B1C1B1B1C1C1B1C1B1B1A1C1B1C1B1C1C1D1C1C1C1C1B1D
1C1C1D1C1C1D1C1D1C1C1C1D1B1D1D1E1D1B1C1D1E1E1D1D1C1D1E1E1C1D1D1C1D1D1F1E
1E1E1D1E1E1E1E1D1D1E1E1E1F1F1E1E1E1F1E1F1E1F1E1F1F1F1E1F1F201F1F20202020
20201F212122222121211F201F20201F2020212021232121202120222221202120212122
222121222222222221212122232422242323232323242222232225232324232523242323
232323242424242323232525232323242423242424232523232325232323232424242425
242323242324242322242422222323242323222322232324232324232223232322222122
222122222222222223202121202122202220202020202020201F2021201F211F1F1F1F1F
1F2120201E211E1F1F1E1F1F1F1E1F211E1E1E1E1E1E1E1D1E1D1D1F1F1F1E1E1E1E1D1D
1E1D1D1D1D1D1E1D1D1D1D1C1C1C1B1C1C1C1C1B1B1D1D1D1C1C1C1C1C1C1B1C1B1C1C1D
1D1C1C1C1C1B1C1C1A1B1C1B1C1C1B1B1B1B1B1A1B1B1A1A191A1A1A1A1B1A1B1B191A1A
1A1B1A1B19191B1B1919191A191B1B1A1A1A1A1A1A1A191A1B1A1A1A191A191819191A1A
191819191A1A1A1A
191F1B18191A1B1A19191919191A1B19191A1B1A1A1919191A1819191A191A1919181C1A
1A1B1A1A191A191B1A1A1B1A1B1A1A1A1B1B191A1B1B1A1B1B1A1B1B1B1A1B1A191A1A19
1B1C1A1C1B1B1B1C1C1B1C1A1C1B1B1C1C1C1A1B1B1B1B1C1B1B1C1C1B1B1C1C1D1B1B1C
1C1C1C1D1C1B1D1C1C1D1C1C221E1C1D1C1D1B1C1C1E1D1E1C1D1D1D1D1C1E1C1D1D1D1D
1D1D1F1D1E1F1E1D1F1D1D1E1E1E1F1E1D1F1F1E20201F1E1E1E1F1F1F1E1F211F1F211F
212021212121211F22202120212120221F22212221212122222222212122212121232221
212222232322232222232123232321232223232523222323232324232323252423232524
252423242323232423242424242425232325242423232424232424242424242324232424
232324252423232422232322232225232224222323222324222322242222222121212221
2222202122222220202221212021212121212020202120202020212220201E1F201F1F1F
1E1F1E2020201F1E1F1F1E1E1F1E1D1F1E1E1E1F1D1F1E1E1D1E1E1F1E1E1E1E1E1C1E1E
1E1D1D1D1D1C1D1D1B1D1B1C1D1D1D1D1C1C1D1D1C1D1C1B1B1A1C1D1D1B1C1C1D1C1C1B
1C1B1B1C1C1A1A1B1C1C1A1C1B1A1B1D1A1B1A1A1C1B1A1A1A1C1A1A1A1B1B1B1B1B1B1A
1B191A1B1A1A1C1B1A1A191A19191A1A1A1A1B1A1A1A1A1A191A181A1A19191A1A191918
1A19191A19191919
1A1E1A1A191A1A1A19181919181A1A1A1B1919191A191A1A19191A1A191A1A1A1A191A1A
1A1B191A1A1A1A191A1A1A1B1C1B1A1B1A191A1B1C1C1C1A1B1C1A1A1B1B1B1B1A1A1B1A
1B1B1B1B1A1C1C1C1C1B1B1B1B1B1C1C1C1C1C1C1B1C1B1B1B1B1C1C1C1C1C1C1C1D1C1C
1B1D1C1B1D1C1D1D1E1D1C1C1F1D1E1E1C1D1E1D1E1E1C1D1D1C1D1B1D1D1D1E1E1D1E1F
1E1E1E1E1E1E1F1E1E1F1E1F1F1D1E1E1E201F1F1D1E201D201F1F1F201F201E1F212020
1F202021202021211F212021202120222221212121212121222122222121222122202121
222322242222222322232324242325242224232323242324242324252324242523242424
252424242324242424252525242525242424252423242424242423242224242524242324
232424242424242224232323232222212324232422232323222223232322232223232221
2222212222222221212120222122212021211F20242420201F201F2020201F1F1F20201F
201F1F1F1F201F201E1F20201F1E1E1F1F1E1F1F1E1F1F1E1F1E1E1E1D1E1D1F1E1D1E1E
1D1D1D1D1C1D1E1C1E1D1D1D1C1B1D1C1B1D1D1B1C1C1C1C1D1C1D1D1C1C1B1B1C1C1B1D
1C1C1C1C1C1A1B1B1B1B1B1C1C1B1C1C1B1C1A1A1B1C1B1B1A1B1A1B1A1B1B1A191A191A
1B1A1B191B1B1B1A1A191A1B191A1B1A1A1A1A1A1A191A1A191A1A19191A19181A1A1A1A
1A18191A18191919
1B1919191A19191B1A1B1A1A1919191918191A191B19191A1A1A1A1A1A1B1A191B1A1A1A
191A191B1B191B19191A1A1A1A1B1B1A1A1A1A191C1A1A191B1A1B1B1A1B1A191A1B1C1A
1A1A1C1B1B1B1B1B1C1C1B1B1B1C1B1C1B1B1C1C1B1C1B1C1D1B1C1C1A1C1C1C1B1B1C1C
1C1C1C1C1D1E1D1D1D1C1C1C1D1C1C1C1C1E1D1D1D1E1C1C1D1D1E1E1E1D1E1D1F1E1D1E
1E1E1E1D1D1F1F1E1F1F1F1E1D1F1E1F1E201E1E1F1E1F20201E1F1F1F1F20201F1F2120
212120202021202221201F21212122212321222122202121222121222222212222222222
232121232324222222232324222322242224232423232423242323222223252425232324
242425242424242523242423242524242423232425242324232424242423232424242524
232424242324242224242423232424242423242323222423242322232122232222222323
212220232222222121212223212120212120202037513220202020211F20201F1F202021
211F1F1F1F1F201E1F20201F1F1F1F1F1F1D1F1E1E1E1E1E1F1F1F1F1F1E1E1F1D1E1D1D
1D1D1C1D1C1E1E1D1C1D1D1C1D1C1D1B1C1C1C1C1B1B1B1C1C1B1B1C1C1C1B1B1C1C1C1C
1B1B1C1C1B1A1B1B1C1B1B1B1B1B1C1A1A1B191A1B1B1B1B1B1B1A1B1A1A1A1A1B1B1A1A
1A1B1A1B1A1B1A1A191A1A191A1A1A1A1A1A1A1A1A191B19191B1A1A1919191B1919191A
1919181A1A191819
1A18191B1A1A1B1A1A191A1B1A191A191B1A1A1A1A1A191A19191A1A181A1A1A191A1B1A
191A1A1A1A1A19191A1B1A191C191A1B1A1B1B1A1B1B1A1A1B1C1B1C1A1A1A1B1B1A1C19
1B1C1B1B1B1B1B1C1A1B1A1B1B1A1B1B1C1D1C1C1B1B1B1C1C1C1C1C1C1C1C1B1B1D1C1D
1C1C1B1D1C1D1D1E1D1C1C1D1D1D1C1D1C1C1B1E1D1C1D1E1E1E1E1D1D1E1C1D1E1E1D1E
1F1D1E1E201E1F1F1E1E1E201E1E1F1F1E1F1F20201E1F1F1F1F1F211F201F1F1F201F20
202021211F20212022212120212021212221212121212221212123212121222322232222
222322232222232223232323242224232423242424242424242423252623252323252524
232525242522242426252325242423232424242424242424242425242424242423242424
252525252324232424242324222523242423242323242324232423242423232223212123
22222221222222212023202021222121201F212124552620211F1F202021211F20201F21
1F1F201F201E2020201F1E1F1F1F1F201F1F1E1F1D1F20201E1E1F211F201F1E1E1D1D1E
1D1D1D1D1D1D1D1D1D1D1D1D1D1D1C1B1D1D1D1D1C1B1A1D1E1D1C1B1B1B1C1B1C1C1B1D
1B1C1C1C1C1C1B1B1A1B1C1C1A1A1B1A1B1B1B1A1A1A1A1A1A1B1B1B1A1B1A1A1A1B1A1A
1A191B1A1A1B1A1A1B1A191A1A1A191A191A1A1A1C1B191A191B191A191A1918191B1A19
191919181A191919
1A19191A1B1B1A1A191A1A191A1A191A1B1A1A1A191A1A191A1A191A1A1A181B19191A1A
191A191A19191A1A1B1A1A1A1A1B1B1A1A19191A1B1B1A1A1B1B1A1A1B1A1B1A1B1A1A1A
1B1B1B1B1B1A1A1B1A1C1B1B1C1C1C1B1B1B1C1C1D1C1B1B1B1C1C1B1C1B1C1D1C1B1B1C
1B1D1C1D1B1C1D1D1E1C1B1B1E1D1C1E1D1C1C1E1D1D1D1D1F1D1E1D1D1D1D1D1E1E1E1D
1E1E1E1E1F1E1E1E1E1E1F1E1F1F1F1E1F1F1F201F1E1E1F1F201F1F1F201F2020202020
1F211F212021202021222120212120212221212222212222212121212223222122232223
222223222322232324212323232324232323242424232324252324232324242524242423
242423242323252426252325252524232423252525242424262525252424232523252424
262424252425242324242524232423232423232324232423252323232222232323222322
23232122222221212122222221212121212121202020211F211F2120211F1F2021201F20
201F201F1F20201F1F1F1E1F1E1E1F1E1F201F1F1F1E1F1E1E20201E1E1F1F1E1E1D1E1F
1E1C1F1E1D1D1D1D1E1C1D1E1D1C25201C1D1D1C1B1B1D1D1B1D1C1C1D1B1B1B1C1D1B1D
1A1C1C1A1C1B1B1B1A1B1A1B1A1B1B1B1B1C1A1B1C1B1A191A1A1B191B1A1A1B1B1A191A
1B1A1A1B1A1A1B19191A1A1B191A1A1A1B1A191A1A1A1A191B1A1A1B1A1A191A1A1A1B19
1A181A1A1919191A
1A191A1A1A1B1A1A1A1A1A1A1A1A1A1B191A1A1A181A1A1A1A191B1A1A1A19181A191A18
1B1A191A1A1A1B191B1A1A1A1A19191B1B1A1A1A1B1A1A1A1A1B1B1A1C191B1A1A1B1B1C
1A1A1A1B1C1A1A1B1B1C1B1C1B1B1B1A1C1C1B1A1A1B1C1B1D1B1C1B1B1B1C1C1D1B1C1C
1D1C1D1E1E1D1D1E1C1C1D1C1D1C1C1C1C1D1D1D1D1E1E1F1E1E1E1F1E1D1D1D1E1D1D1E
1F1D1E1E1E1E1E1F1F20201E1E1E1F1F201D1F1F201F20201F1F201F1F20201F1F211E20
2020202021212121222121201F2320222121222122222222212222232222212322222322
232323242323232323232323232324242423242324242525242424242525242526242324
252324252423242424252524252524252324242424252424252424242525242324252624
252524252424242523242324252323232323232324242422232423232423222323232322
222321232322222222212221222122222022221E222021212121201F2121221F20202121
21201F1F1F1F1E201F1F201F1F1E1E1F20201F201E1E1F1E1F1F1F1F1F1F1E1E1D1E1D1D
1C1D1C1D1E1E1D1C1F1D1E1C1E1C211E1C1C1D1C1C1B1C1C1C1C1D1C1C1C1D1B1D1C1D1B
1C1D1B1C1B1B1B1C1C1B1A1B1B1C1B1B1B1B1B1B1B1A1A1B1C1B1C1B1B1A1A1B1B1A1A1C
1A1A191B191C191919191A191A1A1A1B1B1A1A1B1A1A191A191B191A191B1B1A1A1A1A19
191A1A19191A1919
191A1A1B191B1B1A1A1A191A1A19191A1A1A1A1A1A191A1A1A1C1B191A1A1B1B1A1A1919
1A1A1A1A1A1B191B1B1A1A1A1A1A1A1B1B191A1B191A1B1B1C1B1B1C1B1B1A1B1B1A1C1B
1B1B1A1B1B1B191A1B1B1A1B1A1B1B1C1C1C1C1B1C1B1C1C1B1B1B1D1C1C1B1C1C1B1D1D
1B1C1C1B1D1D1E1D1C1F1C1D1D1E1D1C1B1E1C1D1D1D1D1E1D1C1E1E1D1D1E1F1D1D1E1E
1E1E1F1E1F201D1E1F1F201E1E1F1F1F1E201E201F1E1E211F1F1F201F201F2120202121
1F2020212121212221212121222221222222212223212222222122222122222322242224
222424242222232324242423252224242424242325242524242525252425232525242525
232324252624232625242524242625232524252425252624242424242425232526242425
252424242524252325232423242423252324242323242322232424242423222322222321
222222222321212323222221222222222122222321212121202020202020202120232020
20211F1F1F1F1F1F1F201E201E1F201F20201E1F1E1E2020201E201F1F1F1F1E1D1E1E1D
1D1D1D1E1D1C1D1E1E1D1C1C1C1C1D1C1D1D1E1D1D1C1B1D1B1D1B1D1B1D1C1C1C1A1B1C
1C1C1C1C1B1C1C1C1B1B1B1B1B1C1B1C1B1A1A1B1B1B1B1A1B1A1B1B1B181B1A1B1A1B1A
1A1A1C1B1B1A1B191B1A191A1A1B1A191A1A1A1A18191B1A1A1A1A1A1B191A1B181A1B1A
19191819191A1A1A
1B1B1B1A1A1B1B191A1A191C191A191A1A1A1A1A191A19191A1A1B1B1A1A1A191A1A1919
181A1A191A1B1A191A19191A1A1B1A1B1B1C1A1A1A1B1B1C1B191B1B1B1B1A1A1B1C1B1B
1B1C1D1B1B1C1B1B1D1A1B1B1C1A1C1A1C1C1B1C1C1D1C1C1C1C1C1C1E1C1C1B1B1B1B1B
1C1C1D1D1C1D1D1C1C1C1E1C1C1B1C1D1C1C1D1E1D1C1D1E1E1B1D1D1E1D1C1D1E1D1E1E
1E1E1D1E1F201E1D1F1E1F201E1E1F1F1F1F201F201F201E201F202020201F2021201F20
212021202120212221212122222120222123232022232122222222232222222223242424
232424222223242222232323232423232523242524242524242525252524252525252525
252525252524252425252424252526252424252525242525262525252424252624252625
242525232324232424242524252324242325232423232323242323232425252024242223
2323222221212123212222222221222122212222222121222121211F2121202120212120
212020201F20201E201F201F1F1E1E1E1E201F201F201F1D1F1F1F201E1E1E1D1E1F1E1E
1D1D1E1E1E1E1E1E1C1E1E1E1D1C1E1D1D1D1D1C1D1C1C1B1C1D1D1B1D1C1C1C1B1C1C1C
1B1B1B1B1B1B1B1B1B1B1C1C1C1B1B1B1A1B1A1B1A1B1B1B1B1B1B1A1B1A1A1B1A1A1A1A
1A1A191A1A1A1A191A1A1A1A1A1A1A1A1B1A1A1B1A191A1B1A1A191B1A1B19191A19191B
191A1A19191A1A19
1A1A1B1B1A191A191B191A1A191A1A1A1A1B1A191A191A1B1A1A1A1B191B1B1A1A1A1B19
19191A191A1A1A1A1A1C1A1B1A1A1B1B1A1B1A1B1A1A1A1A1A1B1A1A1C1A1A1C1A1A1A1B
1C1A1B1A1C1B1C1C1A1B1B1A1A1B1B1B1C1A1C1A1C1C1C1C1D1C1D1B1B1B1C1C1C1B1C1C
1C1D1D1C1C1D1C1D1D1C1D1E1C1E1D1D1D1D1E1E1E1C1F1D1D1D1C1D1D1E1E1D1E1D1E1E
1E1F1E1E1D1F1F1F1D1F1F201E1F1F20201E1F20201E1F201F1F1F1F202120211F202021
202022202120212123222122222122222321222323212222222222232322222224232423
242422232423242322222424232323242525252424242524242526252524252425242524
242624262424252525252426252624252624252526252525262425252625242625252525
252626252324252424252524242424232423232422242324252324242223242424242423
242321232222232321222122212222202221212122212222211F21202020202121212021
2222201F1F201E1F1E20201F1E1F1E1F1E1F1F1F201F1F1E201F1F1E1F1D1F1F1D1E1E1D
1E1C1E1D1E1E1D1D1E1E1C1C1D1D1D1D1D1D1D1D1C1C1D1D1C1C1B1C1D1C1C1B1B1C1C1B
1B1C1B1C1B1C1C1A1B1B1B1C1B1B1B1B1B1B1B1C1B1A1A1A1B1B1A1A1A1A1C1C1C1B1A1B
1A191A1A1A191A1A1A1B1B1A1B191A1A1A19191A191A1A1A1A191A1A1A1B1A1919181919
191A1A1B1A191919
1A191A1A191A1A191B1919191A19191A1A191A1A1B1A1A1A19191B181A1A191A1A191A1B
1C1A1A191A1A1B191B1A1A1B1B1C1B1A1A1B1B1B1A1B1A1A1A1A1A1A1B1A1A1A1C1A1A1B
1A1B1C1D1B1A1C1B1B1B1C1C1A1C1C1C1B1B1C1A1B1B1C1C1C1C1C1D1B1C1C1C1C1C1C1B
1B1B1C1D1D1C1E1E1C1D1E1C1D1E1C1D1D1C1D1E1D1D1E1D1D1E1E1E1E1D1D1E1E1F1F1D
1E1E1E1F1E1F1F202120201D1F1F21202120212121201F1F1F1F20201F20212120211F20
212121212222212322202222232122222222222222212223222222222223242423232323
242323242425242323232424242425262324252424242524252625252525252524242424
242425252624252726262524252526252624252627252524252526252624252525252525
252625242625262624252425242424232424242425242425252424242424232423242223
222223232122222122232023222221222122222321212122222122212120202221222222
212122201F1F1F1F1E201E20201F211E1F1F1F1F1E1F201F1E1E1E201D1E1F1E1E1E1D1F
1D1D1E1D1E1E1D1D1E1D1D1D1E1E1D1D1D1D1E1D1D1D1C1D1D1C1C1D1C1C1D1B1B1D1C1B
1C1B1C1B1B1C1A1B1B1C1C1C1A1C1B1A1B1B1C1B1B1B1A1B1A1B1B1B1B1B1B1A1A1B1A1B
1A1A1B1B1A1A1A1A1C1A1B1A1A1A1A191A191A1A1A1A191B1A191A1A1A191A181A1A1A19
191919191A191919
1B1A191A191A1A191A191A1A1A191A191A191A1A191A1A1A1A1A1B191A1A1A1A191A1B1A
1B1A1A1B1B191B1B1A1B1C1A1B1B1A1B1B1A1A1B1B1B1B1A1B1B1A1B1C1B1A1B1B1A1B1C
1C1B1B1B1D1B1B1D1B1B1B1B1B1A1B1B1B1B1B1B1C1C1B1C1C1E1C1B1D1C1C1D1B1C1C1C
1C1C1D1E1D1D1D1C1D1D1C1E1C1D1A1C1D1D1D1E1C1D1E1E1E1E1F1D1C1F1E1D1E1E1E1E
1F1F1F1F1E1F1E1E1F1F1F1E1F2021211F2121211F1F1F1F2020211F1F21202120201F22
222022221F21222122222122212322232322212123212223222221222221242225242224
222323222323232323242424232525242424242525242525252624252525252625242525
262525252425252526252527262525272625252625272625262624262525252626252525
252627252524252623252525242324242625242425252324232325242524242325222324
232322222223232223222123222222222224222122232321222120202021202021232222
202020201F201F1E1F1F201E1E1F2020201F201F1E1F201F1E1E1F1F201E1E201E201E1E
1E1D1D1D1E1E1D1D1E1E1D1D1D1C1D1C1D1D1C1B1C1D1D1C1D1B1C1C1C1C1B1C1C1C1B1C
1B1B1C1B1B1B1C1C1C1B1C1C1C1B1C1B1B1B1B1A1B1B1B1A1C1B1A191B1B1A191A1C1A1A
1B1B1A1A1B1B1A1B1A1B1A1A1B191A1A1B191A1B1A1A1B1A1A1A19191919191A1A1B1A1A
1B19191A1B1B1819
1A1A191A1A191A1A1B1A1A1A191A1B1A191B1A1B1A1A1B191B1A1B1A1A1A1B1A1A1A191B
1A191B1A1A1A1A1A1C1B1B1A1B1B1A1A1A1B1B1A1C1B1B1B1B1A1B1A1A1B191A1B1C1A1B
1B1C1C1A1B191C1B1B1C1A1B1B1B1C1B1C1B1B1B1B1B1C1A1D1C1C1C1B1C1C1C1C1C1C1C
1B1B1B1B1B1D1D1D1D1D1C1D1C1D1C1C1E1C1E1D1D1D1E1D1D1E1E1E1D1E1D201E1E1F1E
1F1D1F1D1F1F1F1F20201F1F212120212022202121201F201F20211F2120202020202121
201F21212222202222222123232123222222222222222222222323232322222323232324
232322242324232224242525242425262424242626252525252425252526262525272625
252525262626242728262526252526272526252626262526262627272726252525242525
242526242625262525242525252423252625252425252324242626252524242124252423
212324222324232223232223222222222222232323222222222121212121222222242221
2321211F1E201F1F201F1F201F1F1E1F1F1E1F1F1F1F1F1E1F1E1F1F1E1E1D1E1E1D1E1C
1D1D1E1F1E1D1E1D1E1E1D1C1E1D1D1D1C1D1D1D1C1C1B1D1C1C1C1D1C1C1B1C1C1B1B1C
1C1D1B1D1C1C1C1B1C1C1B1B1C1A1A1B1A1B1B1B1A1B1A1B1C1B1C1B191A1B1A1A1B1A1A
1B1A1A1A1A1A191B1A1B1B1B1B1A1A1B1B1A1A1A1B1A1B1B191A1A1A191A1919191B1B1B
191A181A19191A1A
1A191A191A1B191A1A1A181A19191A1A1A191A1A1A1A1A1A1A1A1B1B191A191A1A1A1A1A
1A1B1A1A1A1A1A1A1A1B1A1B1B1C1B1A1B191C1A1B1B1B1B1B1B1A1B1A1B1C1A1A1B1B1A
1C1B1D1C1C1B1B1A1C1C1B1B1B1B1C1B1B1C1B1B1C1C1C1C1C1C1C1C1C1C1C1C1D1B1C1C
1D1C1D1B1D1C1C1C1E1E1D1D1C1D1D1D1D1D1D1E1D1E1D1D1E1E1D1D1D1E1D1E1E1D1D1F
1F1E1E1F1E1F1F201F1F20201F2220212322212021202021202021201F201F2022202120
212221232121212322212121222122222121232322232323242123232425232424242324
242325252323262423252525252525252525252525252525252725262526252526252525
262624252525262525262726282626252725262827272626272725262626272525262425
262526252425252624252525252525242525242425242525252524252524232523242323
232323232322232423222223222222222121232423232222212121222223212220232221
21211F1F202021202020201F2021211E1F201F201F1F1F1F1E1E1E1E1F1F1E1D1E1D1D1E
1E1D1E1D1D1D1E1D1D1E1D1E1D1C1C1C1D1C1D1C1D1C1C1C1D1C1C1C1D1C1C1D1C1B1B1C
1D1B1C1B1C1C1C1B1C1C1C1C1B1B1B1A1B1B1A191B1C1A1B1A1A1B1A1A1C1A1C1A1A1B1C
1A1B1B1A1B1B1B1A1A1A1A19191A1A191B1A1A1B1A191B1B1A191B1A1A1A1A1A1A1A1B1A
1A191A19191B1B19
1A191918191A1B181A191A191A1A1A1A1A191B1B1B1A1B1A191A1A191B1A1A1A1B19191A
1B1A1A1C1B1B1A191A191A1B1A191B1A1B191A1B1B1A1B191C1A1A1B1A1A1A1A1B1D1B1B
1A1A1C1A1A1A1B1B1B1A1A1A1C1B1C1B1B1A1B1D1C1D1C1D1C1A1C1C1C1C1D1C1B1D1B1C
1B1C1C1D1E1E1B1D1D1E1C1D1C1D1E1C1D1C1D1C1E1E1D1D1D1D1E1D1D1E1F1E201E1E1D
1D1F1E1F201F1E1E1F1E1E202221222221222121202020201F2020212021212121212121
202222202021212222222223222421232324232222232223222422222323222324232424
242422252425242425252423242425252425262625252626262725262525272426262525
262525262625262627262626282626262627272726262627262726272626262725252625
262826252425242626272525272425242625252425252425262525272425242425242423
222324232321252223222223222124222222232323222321212220212121222122232220
21201F2020211F201F20201F201F1F201F201E201F1F1E201E1F201F1F1D1E1E1E1F1F1E
1D1E1F1D1E1E1E1D1C1E1D1B1D1D1C1D1C1D1C1E1D1D1C1C1D1D1D1C1D1D1D1D1C1C1B1C
1C1D1D1C1C1A1B1D1D1C1B1C1C1B1A1B1B1B1B1B1A1B1B191A1A1A1B1B1B1B1A1A191C1B
1B1B1A1A1B1A191A1A1B1A1A1B1A191B1A1B1A1A1A191A1A1A191A1A191A1A1A1A1B1A1A
191A191A181A1919
1A19191A191819191A191B1A1A1A1A191B1B1A191A1A1A191B191B1A1A1A1A1B1A1A1B1B
1B1A1A191A1A1B191A1A1A1B1C191A1A1B1B1A1B1B1C1A1B1A1A1A1A1A191B1B1A1C1A1B
1B1B1A1A1C1C1C1A1B1B1C1C1B1C1C1C1B1C1B1C1D1C1C1D1C1C1E1D1C1A1D1C1C1D1C1C
1C1C1D1C1C1D1D1E1C1E1D1C1D1D1C1D1C1C1D1D1E1D1C1D1D1E1D1C1E1D1E1D1F1E1F1E
1F1E1E1F1F1F1F1F20211F2021212121222221211F20202121201E21211F20211F202121
212221222122232223212223212322222222212222222222242222232223232324242423
232425242325252424232425252426252525262525262627252526252525262526252627
272625262527272724262526272726282628282827272627262625262627262725262626
262626262727262727262524262525262626252523242425252425242323242524242323
242322232324232323232322232223212322232322232223212222222222212222222220
212120201F2120202020211F21211E212020201F1F1F201E1E1F1F1E1E1F1D1D1D1E1E1C
1E1E1D1E1E1E1E1E1D1D1E1C1C1D1C1E1D1E1D1C1C1B1D1C1D1D1D1C1C1D1C1B1B1C1C1C
1C1C1B1C1C1D1C1B1B1C1B1C1C1A1B1A1B1B1A1B1A1A1B1C1A191A1B191A1A1B1B1A1A1B
1A1B1A1A1A1C1A1A1A1B191A1C1A1B1A1B1B1A1A1A1A1A1B1A1A1A191A1A1A1A19191A1A
1A191A1819191919
1A1819191919191A1A1A1B1A1A1B1A1A1A1A191B1A1A1A1A1A1A1B1A1A191A1B1A1B1A1B
1A1B1A191A181A1A1B1A1B1B1B1C191A1B1A1B1B1A1B1A1A1A1B1A1B1B1A1B1B1C1B1B1A
1C1A1B1B1A1B1A1B1A1B1C1A1B1A1B1B1C1B1D1C1C1B1C1D1D1D1C1C1C1C1C1C1D1B1D1C
1C1C1C1D1D1B1D1C1D1D1E1D1D1C1D1C1D1E1E1E1E1D1E1E1E1E1E1F1E1D201F1F1E1E1F
1E1F1E1F1F1E1E1F20201F2021222120222121202020201F201F20202120212020201F21
212220212121212120222022212322242323232323232222242223232223222423232525
252325242525242524252525242526252526272426262625262625262525272527252626
262526272625272726282827262728272729272827272727262826272826272525272726
252625252525262626252527272425262426252426252524262525242424242324222423
252423232524232323242323232323222223222122232222222121212223212322222122
2120201F2020201F211F1E1F21221F202020211F1E2020201F1E1F1F1F1F1F1E1D1D1E1F
1E1E1E1E1D1E1C1C1D1E1D1E1C1C1D1D1D1C1E1E1C1D1C1C1D1C1D1C1D1C1C1D1C1D1C1C
1B1C1C1C1C1B1B1B1C1B1C1B1C1B1B1B1A1B1B1B1A1B1A1B1B1C1A1B1C1B1D1A1A1B1B1B
191A1A1B1B1A191A191B1A191A1B1A1B1B1A1B1A1A1B191B1B1A191A19191A19191A1919
1919191819191919
1A171A1A191A1919191A1919191A191A1A191A1A1A1A191A1B1A1A1A191A1A191A191A19
1A1A1A1A1A1A19191A1C1B1A1A1B191A1B191B1B1B1B1A1A1B1C1B1A1B1A1B1B191C1B1B
1B1C1C1B1A1B1A1B1B1C1C1B1A1C1E1B1C1C1C1B1C1C1C1C1C1C1C1C1D1D1C1C1D1C1C1D
1D1B1D1C1D1C1C1C1D1D1D1E1D1C1E1D1D1D1E1D1D1F1D1E1D1D1E1F1E1D1F1D201F1F1F
1D1F201E1F211F1F1F1F1F2020212022212020202222221F20201E1F2120202021212121
212122202222212122212123242322242222212323232423242424232323242423242424
252525242525232525262726252525252725272626262526262728262627262627252626
272626272627282727262527272627282928272827262727262626272726262626252727
262827272626272626272626282626252524252625242624252525252526242423232424
232123242423242523242424212321232221232323222122232121222120212222222120
211F2020211F212020202121202020222121201F2020201F2020201E1E1E1E1D1E1D1E1D
1D1D1E1D1D1E1E1D1D1D1E1E1E1C1D1D1D1E1D1C1C1D1C1D1D1C1C1C1C1C1B1C1C1C1C1C
1D1E1C1C1B1B1B1B1C1B1B1B1C1A1B1A1B1A1C1A1B1C1B1B1C191A1C191B1A1A1A1C1A1B
1A191A191B1B1A19191B1A1A1A1A1A1A1B1B181A1A1A1A1A1A1A19191A191A1B191A191A
191A1A181A191A19
1A191918191A1A19181A1A1A191A191B1A1A1A191B1A191A1A1B191B1B1B191A1A1A1A1A
1B1A1A1B1A1A1A191A1A1A1B1A1A1B1B1B1C1B1B1A1B1A1A1B1C1C1B1A1B1A1A1B1B1C1C
1A1C1C1B1B1C1C1A1B1B1B1C1B1C1B1B1B1C1C1C1B1C1D1E1D1C1D1C1D1D1C1C1C1C1C1B
1C1C1D1D1D1E1D1D1D1D1D1C1C1D1C1D1D1E1E1D1D1D1D1D1D1D1E1E1E1F1F1F1F1E1F1E
201F1F1F1F1F1F1F201F1F202020201F2020201F20202121202020212021222020212120
222022222222212322212122222222232222232324222324242324232424232324242324
252524262526252425242525252625262527252626252526272526262727272826262726
252727272726272626272725282828292626282828272726272728272727272626272726
242527272727272726252725262626252525252625252625262526232626252424242324
242425232523242422242323242322222224222221222220232121212121222223212122
20212121221F2121201F21202120202120212220202020211F1F1F1D1F1F1E1D1E1F1F1E
1D1E1E1E1E1D1E1E1E1E1E1D1D1D1D1D1D1C1D1D1D1D1C1C1D1C1D1C1C1C1E1D1D1C1D1C
1C1B1D1B1B1C1B1B1C1C1C1B1B1B1B1C1B1B1B1B1B1B1B1A1C1C1A1C1B1A1C1A1A1A1A1A
1A1A1B1B1A1B1A1A1A1B1C1B1A1A19191A1B191A1A1A1A1A1A191A1A19191B1A1A191A19
1A191A191A19191A
19191919191A1A191A1B1A1A191B1A19191A1B1A1A1A191B191A1A1A1A1B1A1A191A1A19
1A1B1A191B1A1A1B1A1A1A1A1A1A1C1A1A1C1B1B1B1B1C1B1B1B1A1B1A1B1A1A1C1B1B1A
191C1B1C1C1A1B1B1B1B1B1C1B1B1C1B1D1C1B1B1B1D1D1D1C1D1C1C1B1C1C1C1D1D1C1B
1D1C1C1D1C1E1D1C1C1C1D1B1D1D1C1D1D1E1E1D1D1E1E1E1F1E1F1F1F1E1E1F1E1E201E
1E1F1F1D1E1F211F211E201F201F2020201F1F1F202021211F2021212220212120212121
212122212122222121222323222222232223222425222324242423242324232525242524
252624252424252425252526262627252626262627272727282726272727262728272826
262527272728272726272827272728292729282727272827262928282627262826262825
262728262726272727262525272626252525252625252525252624242524252624252323
252225232424232322232323232322232322222221222323242322202222222122222121
2021202120222020202021211F212022201F21202021211E1E1F1F1F1E1F1E1F1F1D1E1E
1F1E1E1D1E1C1E1E1D1E1E1D1D1C1C1C1C1C1E1E1D1C1E1C1D1C1D1D1D1B1D1D1C1D1C1C
1C1C1B1C1B1D1C1B1C1A1B1B1C1A1C1C1B1B1B1B1A1B1C1B1A1C1B1B1A1B1A1B1B1A1B1A
1A1A1A1A1B191B1A1A1A1A1B1A1A1A1A1B1B1A191A1A1A1A1A1A1A1A1A1A1A1A191A1A1A
1A19191A1A191A1A
1A1A19191A1A1A1B1A1A1A1A1A1A1A1A1A191A1A1B1A1A19191A19191A1A1A1B1A1A1A1A
1A191A1A1A1A1A1C1B1A1B1B1A1A1A1A1C1A1B1B1C1B1A1A1B1B1A1B1C1C1B1A1A1C1C1A
1B1B1B1C1B1C1B1B1A1C1B1A1B1C1B1C1C1C1C1C1E1B1C1D1D1D1C1D1B1D1C1D1D1D1D1D
1C1C1D1B1D1C1C1E1C1D1C1D1D1D1D1D1E1E1E1E1F1D1E1E1D1E1E1E1E1E1E1F201F1F1F
1F1F201F20201F1E2120201F201F202020211F2021212021202121212020212123222021
222122222221222221222323232423232322242423242423242424242424242326232525
242524252424252526262525272725262727262626262727262727282827262727272728
272726272727262827272828292827272929272828272827272827282727272828282627
262627272727262626272526272726262625262526262525252525252524242522252325
232424252424232323232323232322232223232323212222222223212122222122212121
20212221201F1F212120201F212022212221211F201F211F1E1F1E1F1E1F1E1F1F1E1F1E
1F1F1E1E1D1D1E1E1E1C1E1E1E1E1C1B1E1E1D1E1D1C1D1C1C1C1C1D1C1B1C1C1D1D1C1D
1C1D1C1D1B1B1C1B1B1B1C1C1B1B1B1B1B1B1B1C1C1B1B1B1C1D1B1A1B1C191B1A1C1B1B
1B1B1A1A1B1B1A191A1A1A1A1B1A191B191A1B19191A191A1B1B1C1B1A1A1A1A191A1919
1A191A1918191919
191919191A19191A191A1A1A191B19191A1A1A1B1A1B1B191B1A1A1A1B1A1A1A1A1B1A1A
1A1A1A1B1B1A1A1A1A1B1A1A1B1B1A1A1B1B1A1B1B1C1B1B1C1B1A1B1B1C1B1B1B1B1B1A
1B1C1C1C1B1B1B1C1B1C1B1C1D1C1C1B1B1C1D1C1C1C1D1C1B1C1C1D1D1D1C1B1C1D1C1B
1E1C1C1C1D1D1D1D1E1D1D1D1D1D1F1E1E1D1C1D1E1E1F1E1D1F1E1F1E1F1E20201F1F20
1F1F1F2020201E20201F1F211F201F201E202020202020201F2121212221212221222021
222221222221222223232222232323222323242323232423252424222424242325242525
262425242525262525262826262625282727262727272727272628282828272627282728
282728272828282829272728282827282A28282728262826272828282727272928262626
272628262827272727262726252726262526272526242526262527252524252623252424
252524232423222323242224242223212323222224242223222121222121202021222221
2020222020202021201F1F212122212120201F202020211F1E1E1E1F20201F1F1F1F1F1E
1E1E1E1E1F1E1D1E1E1D1D1D1E1C1E1D1E1D1D1D1D1E1D1B1E1D1C1D1C1B1C1C1C1C1C1D
1C1C1C1C1B1C1C1B1D1C1C1C1D1C1B1C1C1C1B1C1C1C1B1C1C1C1B1B1C1A1C1C1C1B1B1B
1B1B1A1A1B1A1B1A1A1B1B1A1B1A19191A19191A1A1A1A1A1B1C1A1A1A191A1A1A1A191A
191918191A18191A
1A1919191A1919191A191A181A1A1A1A19191C191A1A1A1A1A191A1A191A191A1B1A1A19
1B1A1A191A1A1A1A1A1B1B1A1A1B1C1B1B1B1B1C1B1B1A1C1B1C1B1B1B1B1B1A1A1B1B1B
1A1A1B1B1B1A1C1B1A1C1A1B1B1C1C1C1C1B1C1C1C1C1C1B1D1B1B1C1D1C1D1E1B1C1B1B
1C1D1C1C1E1D1D1D1D1D1C1E1E1D1E1D1C1D1E1F1F1E1C201E1D1E201E1E1E201F1F1F1F
1F20201F1F201F2020202021201F20202020201F20212121202120212121202022212120
222321222222232222232222232324232324252425242424232424242426232424242526
242425252626262626262726262727262627262628262726272727292827272828262727
282627272828272827282829272A2828282A282828282628262827292728282828272728
282925272827272627262828262726272726252526272526252425252425242424242524
252524242324232224232423232423232322222323222221212321222223212220212222
21212222212020211F20201F21202122201F21211F20201F1F1F1F1F1E1F1E1F1F1F1F1E
1E1E1E1D1E1E1E1D1D1D1D1E1D1C1D1D1D1C1D1C1D1D1D1C1D1D1D1D1C1C1C1D1B1E1C1B
1C1C1B1B1C1B1C1B1C1D1C1C1C1C1C1D1A1B1B1B1A1B1B1B1B1C1C1C1B1C1C1C1B1C1A1B
1C1B1B191A1A1A1A1A1B1A1A1B1B1A1A1A1A1B1A1A191A1A1B1B1A1A1A1B191A1A181A1B
1A19191A1919191A
1A191818191A191A19191A1A1A1A1A191A191A1A1A191A1A1A1A1A1B1B1A191B1A1A1A1A
1B1A1A191A1B1A19191C191B1A1B1B1A1B1A1A191A1B1B191C1B1A1B1B1A1C1B1B1C1B1B
1B1A1B1B1C1A1B1B1B1C1B1C1C1C1C1B1B1B1C1C1C1C1B1C1C1C1B1B1C1E1D1C1D1B1D1D
1C1C1D1C1C1D1C1C1D1D1C1C1D1E1E1E1D1E1E1D1E1E1F1F1D1F1E1F1F1E1F1F1E1F201F
201F1F1E201F1F2020201F1F1F20201F1F20202020202221212022212121202121212221
222121222323222223232224242323232323262324242524242525242625232424242525
242425262526262626262627252727282727272627272727272727272928282829282927
2828282828272827282828282929292A2828282928282829282829272728292829282727
282828282727272629262927272727262725262727252726252626262625252425262624
242425242424232323242323232423242221242124232323212322212122222222202222
222121202020212020201F2021202020212020201F21211F1F1F1F1F1F1F1E1E1E1E1F1F
1F1E1E1D1E1F1E1E1D1E1E1D1D1E1C1C1C1C1D1D1D1E1C1C1C1B1D1D1C1D1C1C1D1C1D1C
1B1C1C1D1C1C1B1C1C1B1C1C1B1B1C1C191B1B1C1C1C1C1B1B1A1D1C1D1D1C1C1A1C1B1A
1B1B1B1B1A1B1B1C1A191A1A1A1A1B1A1A1B1A1A1A1B1A191A1B1A1A1A19191A19191A1A
191A1B1A1A191919
1A19191919181B1A1A191A19191A1A1A19191A1B1A19191B1B1B1A1A1A1A1A1B1A191B1A
1A1A1A1A1A1B1B1A1A1B1A1B1A1C1B191B1B1A1B1C1B1B1B1B1B1B1C1B1C1C1A1B1B1A1B
1B1B1B1B1B191B1C1C1D1B1B1C1C1B1C1C1C1C1C1C1C1C1B1C1C1B1E1D1C1C1D1C1D1C1C
1C1C1D1C1C1C1C1C1E1E1E1D1D1D1D1E1E1E1E1E1E1D1E1E1E1E1E1E1F1E1F1F1F1E1F1F
1F201F1F1E20202020201F1F21211F2121201F1F20202020212020222121212021212022
222221222222232323232323232223232424252423252624232524252625252523252625
242524252625262626272726272628262629282829282726282827282927282828282929
27272729282928282828282929292A29292927292727272729282B282828272829282629
282927282827272728262727272626282727262726272525262525262427262625252624
252623242523242524242324232223222323232421222323222222232220212121222221
202222212120212020222022212021212120211E1F1F201E1F1E1F1F1E1F1E1F1F1D1F1E
1F1E1E201E1E1D1E1D1E1D1E1E1D1D1E1D1D1D1E1C1C1C1C1B1E1C1D1D1C1C1C1D1B1C1C
1C1B1D1C1B1C1C1C1C1C1B1C1C1C1B1A1B191C1B1C1B1B1B1B1A1C1B1B1B1C1B1C1C1B1A
191A1B1A1B1A1B1A1A191A1B1A1A191B1B1A181B1A191A1A1B191C18191C1A1A1A1B1A1A
1A1A1A191A191919
1A19191919191A171B191A19191A1A191A191B1B1A1B1A1A1A1A1B1A1B1A1A1A1A1A1A19
1B1A1B1B1A1A1B1A1A1A191A1A1B1A1A1A1A1A1B1B1A1B1B1A1B1B1B1C1B1A1C1B1A1B1B
1B1B1B1C1B1B1B1C1C1C1B1B1B1C1C1C1D1C1C1B1C1C1C1B1B1C1B1D1D1C1C1E1D1C1C1E
1C1C1D1B1C1D1C1D1E1D1E1D1D1D1E1E1E1E1D1E1E1F1F1F1E1E1E1D1E1E201E1F1F201F
1F1F1F1F211F20202120201F20221F1F20201F212021202121211F222022212220232222
202322212322222323232423232223242424242425242625252525252424252526242625
252626262627272626272728282726282726282828272929292827272729292929282928
2928282828282829292A28292A2829292928272829292728292828282829282929292828
282827292628282729282728272827272826272826262726282425262625262525262625
232624252525252425232524242324242223222224232323232321222221222221212221
21212020202020202020202121202020201E201F1E1F1F1F20211F201F201E1F1D1F201F
1F1F1D1E1D1F1E1E1D1E1D1D1D1D1E1C1C1D1D1D1D1E1E1D1C1C1D1E1C1D1C1C1C1D1D1C
1B1B1B1C1C1B1C1C1D1A1B1B1C1B1B1B1C1D1C1B1C1D1B1C1B1B1B1C1C1B1C1B1B1C1C1A
1A1B1A1B1A1A1A191A1A1A191A1A1B1A1A191A1A1A1A1A191B191A1B1B1A19191A1A1B19
1A181A191A191A1A
1A1919181A191A191A191A191B1A1A1A1A1A1A1A1A1A1A1A191A1B1A1A1B1B1A1A1A1B1A
1A1B1A1B1B1A1B1A1A1A191A1A1B1A1B1B1A1A1B1B1B1A1B191B1B1B1C1C1B1C1A1B1B1B
1B1B1B1C1C1C1A1C1B1C1C1C1B1C1C1C1C1B1B1C1C1C1B1D1C1C1D1C1D1C1C1D1E1C1D1D
1D1C1D1C1C1D1D1C1E1D1D1D1E1F1E1E1D1F1E1E1F1E1E1E1E1E1E1F1F1F1F1E1F1F1F1F
1F1F1F201F1F202021201F21211F202021211F2121212121222021222122222222202121
212122222222232323242322242423232523242424252525242523262525252426262625
26262525252725272627262729272627272728282A27272728292927282A28292829282A
282828282A2A2A2928282A282C292A29292A272829292928282729282829262929292929
282927292828282929282828272727282827272627262726252526272527252625262624
252424242624242424242523232425232423232424232223222223212122202120202222
222222212121212121212021201F20202021211F1F1E1E201E1F1E1F1F1E1F1F1D1E1F1F
1D1E1E1E1F1E1F1D1E1D1D1D1D1D1D1D1C1D1D1D1D1D1D1D1C1D1D1C1C1D1C1D1D1C1C1C
1B1D1C1B1C1C1C1C1C1A1C1B1C1C1C1C1C1B1C1B1C1A1B1A1C1B1D1B1B1B1B1B1C1C1B1A
1B1A191B1B1B1A1A1A1A1A1A1A1A1A1A1A1A1B1A191A1B1A1B1B1A1B1A1A1A1A1819191A
1B1A1A1A1A1A1A19
1A1919191A191A1A19191A1A1A191A1A191A1A1B1A1B1A1B1B1A1B1A1A1B1B19191B1B1A
1B1B1B1B1A1A1A1A1A1B1A1A1A1A1A1A1A1B191C1B1A1B1A1A1A1A1A1B1A1A1B1B1B1B1B
1B1C1B1B1C1B1C1B1C1B1A1B1C1B1B1C1B1D1C1C1D1C1B1C1D1C1D1C1C1C1C1C1C1C1C1C
1C1D1C1C1D1D1C1C1D1C1C1D1D1E1C1E1E1E1F1F1F1F1F1E1F1E1F1E1F1E1F1E1E1F1F1F
1E1E1E20202020212020202120201F222120212021212121212121222122212223212222
222422232224222423232322252424242324242524252425242626252525262626252527
262627262827272726282628282827272827282A28282727282929282929292929292A2A
29292A28292929282A2A2A2829292A292B2B2929282928292829292A2A2A292929292929
292829282929282828282828262727272726282726262725262727262525262727252625
242625262524252424232425232324232425222322242322232322232122202122222122
2221212121222020202120202120211F201F20211F221F1F1F1F20201E201F1F1F1F1E1F
1F1F1E1F1D1E1E1E1F1D1E1D1E1D1E1D1D1C1D1D1D1D1C1D1E1D1D1C1C1D1C1D1B1C1D1D
1D1B1C1C231B1C1C1D1B1C1B1B1C1D1C1C1C1B1B1C1B1C1A1B1B1C1B1C1D1B1C1B1B1A1B
1A1B1B1A1A1A1C191B1B19191A191A1A1A1B1B1A19191B1B1B1B1C1B1B1B1A191B1A1A1A
1A1A1A1919191919
1B18191A1B1A191A1A19191A1A1A1A1A1B191B1A191A1919191A1C1A1A1B1A1A1B1B1A1B
1B1C1B191A1A1B1A1A1B1A1A191A1A1A19191B1C1A1A1B1A1A1A1B1C1B1B1B1A1A1B1B1C
1B1B1B1C1B1C1C1C1C1B1B1C1B1B1B1C1B1C1B1B1A1C1C1C1B1E1D1D1B1D1C1C1C1C1C1D
1D1C1C1E1C1D1B1C1E1D1C1D1F1D1E1D1E1E1E1E1E1E1F1F1F1F1D1E1F1E1F1E1E1F1F1E
1E1E1E1F202020202120212020211F20201F202021202021212020222022212222232322
232323242323222323232323222524242324252325242425242527252526252624262525
2527252526262727292729282627282828272827292828292A2A292927282A2928292927
292A2A28292A2B2A2A2A2A2A2B2A2A2B2A2929292928292A292A29292A292828292A2A2A
2A2A2A292929292829272928282728282928292827272728272626262526242527262626
252526252524262326242425242423232424232423232322232323232222232323212321
2121212122212120212121212120201F201F20201F1F1F1F20201F201F1E1E1F1E1F1E1F
1E1F1F1E1E1E1E1F1E1E1E1D1E1E1E1D1E1D1C1D1E1D1D1D1D1D1D1D1D1C1C1D1D1D1C1C
1D1C1C1C1F1D1C1C1C1B1E1C1D1D1C1B1B1C1C1B1C1C1A1B1C1B1B1A1B1B191A1B1B1A1B
1B1B1B1B1A1B1B1B1C1C1A1B1A1A19191A191A1A1A1B1B1C1B1B1B1A191B1B191A1A1A19
1A1A191A191A1A1A
19191B19191A191B1A191A1A1B1A1A1B1A19191B1A191B1A1B1B1B1A1A19191B191A1A1B
1B191A1A1A1B1B1A1B1B1A1B1A1B1B1B1A1B1A1A1A1A1B1B1A1A1B1B1B1B1C1B1C1B1B1C
1C1B1C1C1B1C1C1B1C1B1D1C1C1C1D1C1B1C1C1B1B1C1A1B1B1B1B1D1C1C1B1D1C1D1D1C
1D1D1D1C1E1C1C1E1E1E1C1D1D1D1E1E1E1F1C1F1F1F1E1F1F1F1E1F1D1F1F1F1F211E20
1E1F1F1E1F202021202120211F2020201F20212021202120212120222121222223212321
222323222224232224242424232223252423242524252525252625252726252625262627
272828262727262627262727272828282A2827282A2828292929292A28292828292B2928
292A2A292A29292A2A292A2B2A2C2B2B292A29292A2929292829292B2A2B2A2A2A292929
2A29292A28292929282827292A2829272828282728262725272726262525252525272526
262525252526242524242524232525232324252324232323232222222222212123222222
21222221202121212221212020201F202121212020201F1F211F201F20201F1F1E1F1E1E
201E1D1D1F1F1F1D1C1C1D1D1D1E1E1D1E1F1E1D1D1C1D1E1C1D1C1C1C1D1D1D1C1C1D1D
1B1C1D1C1C1C1D1C1C1C1C1C1C1B1C1B1C1B1B1B1B1B1A1B1B1B1B1B1B1A1B1B1C1C1C1A
1A1B1B1B1B1C1A1B1C1B1A1A1A1A1B1B1B1A1B19191A1A1C1C1C1C1B1B1B1B1A1B191A1A
1A191A181A1A1A19
1919181A191B191A19191A19191A191A1A1A1B1A1B1A1A1C1A1A1A1A1B191A191B1A1A1A
1B1A191A191A1A1A1A1B1B1C1A1A1B1B1A191A191A1A1B1B1A191A1B1A1A1C1A1B1B1C1B
1C1C1C1A1B1B1C1C1D1C1D1B1C1C1C1C1D1B1B1B1B1C1C1C1C1C1D1C1C1D1C1D1B1D1D1C
1D1D1D1D1D1D1C1D1E1D1E1D1D1D1D1E1E1F1E1F1F1E1E1F1F1F1F1E1E1F1F1E1D1F1F1F
20201F1F201F1F202020211F20201F202020212120212121202121222122222323232022
222223232424222423242324232325242424252524252525262526252626252525252625
272727272628272726262628282829292928282A282A2A292A2A29282A292B2A2B2A2929
29292A292A292A2A2B2A2B2A2B2A292B2A2A2B2A2A2A292A29292A292A2B2A2B292B2829
2A2A2A29292B2A2A29282728292828272829282827272727262727262726252626252627
242525252525252524252525252424232324232324232222232122232222222121212222
22232222212122212022202120211F2120201F1F201F201F201F1F1F1E201F1F1E1F1F1E
1F1D1F1E1E1E1D1D1D1E1E1F1E1D1E1D1D1C1E1D1C1C1E1D1B1E1D1C1C1C1D1D1C1C1D1D
1D1C1C1C1D1D1C1C1D1B1D1D1C1C1C1B1C1B1D1C1B1C1C1C1A1C1B1C1B1C1A1B191B1B1B
1B1A1B1B1B191A1A1A1B1A1B1A1A1B1A1B1B1A19191B1B1C1D1C1C1B1A1A1A19191A1A1A
191B191A1A1A181A
191919191A191B191A19191B191919191A191A1B1A1A1A1A1A1B1A1B1A1A1A191B1A1B1B
191A1A1A1B1A1A1A1A1A1B1A1B1A1A1A1B1B1A1B1A1A1A1B1A1B1B1B1C1B1A1A1C1B1C1C
1C1B1B1B1C1C1C1D1B1C1E1D1B1D1B1C1C1C1C1C1B1C1B1B1D1D1D1D1D1D1E1C1D1C1C1D
1D1C1D1D1C1D1D1D1C1F1D1D1E1D1D1E1E1D1E1F1E1F1E1E1F1F1E1E201F1F1E1E1F1F20
1E201F1F1F1F202020202020201F21212021202221212120222121222023232122222124
242223242323242323242424242424242525252424242525252524252627272627262626
27282827272728272727292828282829282A2A282929292A2B2A292929292B2A2B2A2B29
2C2B292A2B2A2A2C2B2B2A2B2C2A2B2C2A2A2B2B2A2B2A2B2A2A2A2C2B2A2B2A2B2A2929
2A292A2A2928292A29292A28292929292828272928282628262727272627272626252524
242525252525252524242424242525242324232323232424232423222423222322232322
2122222222212221212322212120212020201F20202020201F1F1F201F201F1E1F1E1F1F
1F1F1E1F1F1F1E1E1D1E1E1E1D1D1E1C1F1D1D1E1D1E1E1D1E1D1D1C1D1C1B1D1D1D1C1C
1C1D1D1C1B1C1B1C1C1D1C1D1B1E1C1B1C1C1C1C1B1B1B191B1C1B1C1C1B1B1B1A1C1A1B
1A1B1B1B1A1C1C1A1B1A1A191B1B1A1B1A1A191A1B1B1B1B1D1B1A1A1B1B1B191A191919
191A1A191A19191A
1919191A1A1A19191A1A191A19191A1A191A19191A1A1A1A1A1B1A1B1B1B1A191A191B1A
1A1B1A1A1A1C1A191B1B1A1A1A1A1A1A1A1A1A1A1B1A1B1B1A1B1A1B1B1C1C1B1C1A1B1C
1C1B1B1B1C1C1B1C1C1B1C1C1C1C1B1C1A1B1B1B1B1C1C1C1D1C1C1D1D1D1D1D1C1D1D1D
1D1C1D1E1D1D1C1D1D1D1E1E1D1E1E1E1D1D1D1D1F1E1F1F1F201F1E201E1E1E1E211F1F
1E201F201F20201E21202021211F201F2021202120212120212122222121212224242322
232324242422242323232524252424242424252425262526262726252625262627272727
2627272929282827292828272829282928292A2A29292B2A2A292A2A2A292A2B2B2A2B2B
2A2B2A2A2A2B2B2C2C2C2C2B2C2A2B2B2B2A2B2B2B2A2A2A2B2A2B2B2B2C2A2A2A2A2B2A
2B2A282A29292929282A292A29292929292828292B282728262728262627282726272626
242525272725252525242625252424242523232223242424232322232223232321212122
222222222122212122212222211F2122202121201F1F201F1E201F20201F1F1E1E1E201F
1E201F1E1E1E1E1F1F1E1E1F1E1D1D1E1D1E1E1D1E1C1E1E1D1D1D1C1E1D1E1D1C1C1C1D
1C1D1D1C1D1D1B1D1C1C1C1B1C1C1B1B1C1B1C1C1C1B1C1B1C1A1B1A1C1A1B1B1B1B1A1A
191A1A1A1A1B1B1A191A1B1B1A1A1A1B1A1A1A1B1B1A1B1C1B1A1B1B1A19191A1A191919
191A1A1A191A1919
1A191A1A191A1A1A1A1A191A1A1A1A1919191A1B1A1B1A1A1A1B1B1A1B1A1A1A1A191B1B
1B1B1A1B1B1A1B1A1A1A1A1A1A1B1A1B1A1A1B1A1B1C1B1A1B1A1A1B1B1A1B1B1A1B1D1B
1B1B1B1D1B1C1C1C1C1C1B1B1C1B1C1C1A1C1B1B1A1C1C1C1C1D1D1D1C1E1C1E1D1D1E1D
1D1C1B1E1D1D1E1E1D1D1D1E1D1D1C1D1D1E1F1E1F1F1D1E201E201F1F1E1E1F1F1F201F
1F1F1F1F2020202021212020202121202021211F21212022212121212121222323222221
222222232423242323242424222524252524242524262626252427272525272626272628
27272728272928292928292A292A292A292A2929292B2A2C2B2B2A2B2B2A2B2B2A292C2C
2B2A2B2B2B2C2A2C2A2B2B2B2C2D2D2D2C2B2C2B2B2B2B2C2B2A2A2B2A2B2A2B2B2A2B2A
2A2A292A2A292929292B29292828282A2829282829282829272728282729272926282526
262625262525252523252424232324242523242423242324242223212322232423232322
22222222232121222121202121202120202020201F1F1E20201F1F1F1F201E201E1F1F20
1E1E1E1E1E1E1E1E1F1C1E1E1D1E1E1D1D1C1D1E1F1C1D1C1E1C1E1D1C1C1E1C1C1C1C1C
1C1D1C1B1C1D1C1C1C1C1C1B1D1C1B1C1B1C1B1C1B1C1B1C1B1C1A1B1B1B191B1A1A1B1C
1A1B1B1B1B1A1B1A1C1A1A1A1A1B1A191A191A1A1A191B1C1B1A191B1B1A1A1B1A191A1A
1A1B191A19191A18
1A1A1A191A1B1A181A19191A19191B1A1A191A1B1A1A1B1B191B1A1A1A1A1B1A1B1A1B1A
1B1C1A1B191A1A1A1B1A1A1C1A1B1A1B1C1A1A1B1A191C1B1A1A1B1B1B1A1B1B1A1B1C1B
1B1A1B1B1B1D1B1D1C1C1B1A1B1C1B1A1D1D1B1C1B1C1C1C1D1D1D1D1E1D1D1D1E1E1D1D
1D1C1C1D1D1D1C1E1D1E1D1D1E1E1D1F1F1E1D1D1E1D1F1E1D1F1F1E1F1E1F201F1E1E1F
1F1F1F201F201F201F202021202121201F21202121222122222222222322222323222324
242423242425232423242524252425252625282626252627262526272626262628272927
28272727292929292829282A2A2A2A292928292A2A2A292A2B2B2B2B2C2B2B2B2A2B2A2D
2B2A2C2A2A2C2C2B2B2C2C2C2C2C2B2B2C2B2C2C2C2C2A2C2B2B2B2B2B2D2B2B2A2B2C2A
2A2B2A2A29282A2A292A2A29282A292929292A2829282827282828272627272827262627
272527262526262526242424252424242524252524232423232223232423232222212322
212123222221232022212122212020212022201F2120201F21201F201F1F1F1F201E1F1F
1D1E1F1E1E1E1F1E1D1F1E1E1D1E1D1D1E1D1D1F1D1D1D1C1D1D1E1D1D1D1D1D1D1C1C1C
1C1C1B1C1C1C1D1C1C1C1D1C1C1D1B1B1B1D1B1B1C1B1B1C1A1B1B1B1B1A1B1A1B1B1B1A
1B1B1B1B1A1C191A1B1A191B1A1A1B1B1B1A1A1A1A191A1A1A1B1B1A1A1A1A1B1A1B1919
1B1A1A1A1A1A1919
1A191A191A1A1A19191A1A1B1A1919191A1A1B191A1A1919191A1A1A19191B1B191B1A1A
1A1B1A1B1A1A1A1A1B1A1B1B1B1B1B1B1B1A1C1B1B1B1B1B1A1B1A1B1B1C1A1A1C1B1B1C
1C1C1B1D1B1A1B1C1C1B1C1C1B1C1C1B1B1B1C1B1C1C1C1C1D1D1E1D1D1D1D1D1E1E1D1E
1C1D1D1C1E1D1F1C1E1E1D1E1E1E1D1E1E1E1D1E1E1F1F1E1F201F1F1F20201E201E1F1F
1F201F1F1F1E201F21201F1F1F2121202121202221202121222121222223222222242425
252424242423242424242424252526242625262624262727262626272527272728272828
2728272827262828292A292A2A29292A2A2A2A2A292A2A2B2B2B2B2B2A2B2C2C2C2D2B2A
2C2C2B2D2B2D2C2D2C2D2D2C2C2C2C2C2D2D2C2C2B2C2C2C2C2C2C2C2B2B2B2C2B2C2A2A
2B2B2B2A2B2B29292A2A2A292A2A2B29292A2A2827292928262828282827272728282627
272627262626252425242524242425242423242523242425232224232123232322212422
2222222222222121232121212121212120202020212021202120211F1F2020201F1E1E1F
1F1F1E1E1F1E1D1C1F1F1E1E1D1D1E1E1D1E1E1D1F1E1D1D1C1D1D1C1F1D1D1C1C1C1C1C
1D1C1C1D1D1C1C1C1C1D1D1C1D1C1C1B1B1B1B1A1B1B1B1C1A1A1B1C1B1C1B1A1B1B1B1A
1A1B1B1A1A1B1B191A1A1B191A1A1B1A1A1A1B1B1A1A1B1A1A1A1A1A1A191A1B1A1A1A19
191A1A191A191819
1A19191A1A19191B1A191A1A181A1B19191A1A1A1919191A1A1A1A1A1A1B1A1A1A1A1C1B
1A1B1B1A1B1A1A1B1B1B1A1A1A1B1A1B191A1B1A1B1B1A1A1B1B1A1A1C1A1C1B1B1B1B1C
1B1A1C1B1C1C1B1A1C1C1C1D1B1C1B1B1B1C1C1B1D1C1C1D1C1D1E1E1D1D1E1D1D1D1B1D
1C1D1D1D1D1D1E1D1D1E1D1D1E1F1E1E1E1F1F1F1F1E1E1E201F1E201F1F1F1F20201E1F
2021201F202020202120202021201F212220222120212121222322232324232323242526
242324232423232325242425242526262525252526262628262626282727272726282929
2828292929292A28282928282A2A2C2A2A2A2A2B2B2A2C2C2B2C2C2B2C2B2C2C2C2B2D2C
2B2A2B2E2C2C2B2D2C2D2C2D2B2C2D2D2A2D2C2C2D2B2D2C2B2D2C2D2C2B2D2B2C2B2A2B
2C2B2C2C2A2B2B2C292A2A2B2B2A2B2A2A29292929292A28282928282828282828282827
272827262527262525252625252425252424252523242524222324242223232222222223
212222232322212121222121212220212022201F20201F1F2021211F202020201F1F201E
1F1E1D1E1F1D1E1E1E1E1E1E1F1E1E1D1D1F1E1D1D1D1D1E1C1D1C1D1C1D1D1D1D1E1C1C
1B1C1C1D1C1C1D1B1C1C1C1C1C1D1C1B1C1A1B1B1C1B1C1C1B1C1B1A1C1B1B1C1B1B1B1B
1B1A1A1A1A1B1A1A1A1A1B1A1B1A1B1C1A1B1B1C1A1B191B1A1B1A191A1B1B1A1A1A1A1A
19191A1B1B19191A
1A1A19191A1A191A1A1A1A1B191A1A1A191A191A191B1A1A1A1A1A1A1C1B191A1A1A1A1A
1A1A1A1B1A1B1A1B1A1A1B1A1A1B1B1C1A1A1B1B1A1A1B1A1A1B1A1A1C1C1A1A1C1D1B1C
1C1A1C1C1B1B1C1B1B1D1B1C1B1B1C1B1B1C1C1C1D1B1D1D1D1D1E1E1E1E1E1D1D1D1D1C
1E1D1D1D1D1D1E1D1E1E1D1E1E1D1D1E1E1E1E1F1E1E1F1F1F1F201F201F1F20201F1F20
1E1F202021201F201F202020202120212120222121212123222222222221232323232525
252525252423232525242525262525262623252627272827272628282728272827272627
29272A28282A282828292A292A2A2A2A2A2B2B2B2C2B2A2B2D2C2D2D2D2D2C2C2B2D2B2C
2D2D2C2D2D2C2D2C2D2D2C2D2D2E2C2C2D2D2B2C2C2D2D2D2D2C2C2C2D2D2C2C2C2C2C2C
2B2C2C2C2B2B2C2B2A2A2B2A2A2A2C2A2A28292929282927292829282828262829272727
272527262627262526262624242525252425242524242523242423252423222323232323
242222222222212022212121212120202120212020201F2220211F1F211F1F1F1F1E1E20
1E1F1E201E1E1F1F1F1F1E1D1D1D1D1E1F1D1D1D1D1D1D1D1C1D1B1C1C1C1E1D1D1D1C1C
1C1C1C1C1C1C1C1C1C1C1C1D1C1B1C1A1C1D1C1B1C1B1C1B1B1B1B1B1B1B1B1A1B1A1C1C
191C1A191A1B1A1B1A1B1A1B1A1B1B1A1C1A1B1B1C1C1A1A1A191A1A1A1A1B1A1A1A1A19
1A1B181A181A1919
191B1A1A19191B1919191A1A1A1A181A1A1A1A1B1A19191A1A1A1A1B1B1B1A181A1A1A1A
191B1A1A1A1B1C1B1B1A1A1A1A1B1A1A1A1B1B1B1C1A1A1B1A1A1B1C1C1B1B1B1B1C1A1B
1C1B1D1B1C1A1B1C1B1C1C1B1B1C1B1B1C1D1C1D1C1C1C1C1C1D1D1E1D1D1E1D1D1E1D1C
1D1D1D1E1D1D1E1E1C1F1E1E1E1E1E1E1D1E1F1F1E201F1E1F201F1F201E1F201F1F201F
202020202020212021212020202021212121202021222221222222212222242324232425
25242425242424242424232424262626262525272928272627262927282726282728292A
2A2829292828272B2A2A2B2A2A2A2A2A2A2B2B2B2C2B2E2C2B2C2C2D2E2E2E2D2E2E2C2E
2E2E2C2E2D2D2D2E2E2D2E2D2D2F2C2D2F2D2D2D2E2C2C2E2D2C2D2D2C2B2C2D2D2C2C2C
2D2D2C2C2C2B2B2B2C2C2C2B2B2A2A2B2A292A2A29282828282929282827282728262827
262827262627272726262626262525252425242424232324242423232223232322222422
22222123232221212223202121202221202021212121212120202120201F2020201F1E1F
1E1E1E1F1D1E1F1F1E1E1E1D1D1D1D1C1E1E1D1E1D1B1D1E1D1D1D1C1C1C1D1D1E1D1D1C
1D1C1D1C1C1E1C1D1C1C1B1C1C1C1B1D1B1B191D1C1C1D1B1B1B1B1B1A1B1C1B1C191A1A
1C1A1B1B1C1A1A1A1A1A1A1B1B1B1B1B1B1B1A1A1A1A1B1B1A191A1A1A1A1A181A1A1A1B
19191B19191A181A
1A191919191A1B191A191A191A1B19191918191A1B1A1B1A1A1A1B1A1A191A1A191C1A1A
1A1B1C191A1A1A1A1A1A1A1A1A1A1B1B1A1B1C1A1B1A1B1B1A1B1C1B1B1C1B1B1B1C1B1C
1C1B1A1B1C1C1B1B1B1C1B1B1D1C1C1D1B1C1B1D1C1D1D1C1D1E1E1C1D1C1C1C1D1D1C1D
1C1B1D1D1E1E1E1D1E1D1D1D1D1E1F1F1E1E1D201F1E1E1F1F1F1F1F201F20201F202121
2020201F2022201F20212020212122212121202122202221212223222224232325242525
25262525242524242524242524272526262627262627262727282728282928292A292928
292A2B2B292A2A2B2B292A2A2C2A2B2A2C2B2B2B2C2C2C2C2D2E2C2E2E2E2D2C2E2D2C2D
2D2E2D2C2B2E2F2E2E2D2D2E2D2D2D2E2D2F2D2E2E2E2E2D2E2E2D2D2D2D2C2D2D2B2D2C
2C2C2B2B2C2B2C2C2B2C2B2A2A2B2A2B2A292928282A2A2929292A28282A282828282729
272626262526262526262727252525252624242524252425242423232323232423232222
242322222121222121212121212221212121212020202021212120201E21201F1F201E1E
1E1E1E1F1F1E1E1E1F1E1D1E1D1E1D1F1E1D1D1E1E1C1D1E1C1B1D1E1C1D1C1A1C1C1C1B
1D1C1C1C1C1C1C1D1C1C1C1B1B1C1B1C1D1C1B1C1D1B1D1B1C1C1B1C1C1A1A1A1A1B1B1A
1B1A1B1B1B1B1A1A1B1B1B191A1A1B191B1B1A191A1C1A1A1A1B191A191B1B1A1A191B1A
191A1A1B19171919
191A1A19191B1B1A191A191A1B191A1919191A1B1B1A1A1A1A1A1B1919191B1A1B191A1B
1B1A1A1B1B1B1A1A1A1B1A1A1B1B1B1A1A1A1A1A1B1A1B1C1B1C1A1A1B1B1B1C1B1B1C1B
1C1B1C1C1A1C1B1B1C1C1B1B1C1D1C1B1C1C1C1C1C1D1D1C1E1C1D1D1D1E1C1E1B1D1C1C
1D1D1E1C1D1E1D1E1E1E1D1C1F1D1E1F1E1D1E1E1F1F1F1F1F1F1E1F201E1F201F1F1F20
1F2120201F212120211F2120202120212021212021212121212223232222222322252325
242626252524232426242426252526252727272727262627282727272728282828282929
28282A292929292A2A292B2A2B2C2A2B2B2B2C2C2B2C2D2D2F2E2F2E2E2D2D2E2D2E2E2D
2F2F2F2E2D2E2F2D2F2F2E2F2E2F2E2F2E2E2D2D2F2D2D2F2C2E2C2E2E2D2D2D2E2D2C2D
2D2C2C2B2C2D2C2B2C2B2B2C2A2B2C2B2C2A2A2A2A2A2928292929292A2A292A27272829
282827282727272626262626242526242524242524242423242424232523242424222424
24242321212222222221212221202121212121212021212222212020201F1F1F2020201F
1F1E1E1F1D1E1F1D1F1E1F201D1E1D1E1E1E1F1D1D1E1E1D1C1D1C1E1D1D1E1D1D1C1D1C
1C1C1B1C1C1B1C1B1C1E1C1C1B1B1C1B1B1B1C1C1D1C1C1C1C1B1A1B1B1C1C1B1B1B1A1B
1A1A1A1B1B191C1A191A1A1A1A191A1A1C191B1B1B1B191A1A1A1A1A1A191B1A1B1A1A1A
1A1A1919181A1819
191A1A1A1A191A1B1A1A1A1A191B1A1A1A1B1A1A1B191A1A191A1B1A1A1B1A1A1A1B1A1A
1B1A1B1A1A1A1B1B1A1B1A1A1B1B1B1A1B1A1A1A1A191C1B1B1A1A1B1C1A1B1A1A1B1C1B
1D1B1C1B1B1B1B1C1B1B1B1C1C1C1C1C1D1C1C1C1D1D1D1C1C1C1C1C1D1C1E1C1D1D1D1E
1D1C1D1D1E1E1D1F1E1E1D1F1F1F1E1E1D1E1D1D1D1F1E1E201F1F2020212020201F2021
2020201F1F20222121202121222021212120212222222323222220222323242224232424
25262424262523242425252527252626252527272827272727272828272728292A2A2A29
292A2929292A2A2A2B2A2A2B2C2B2C2D2D2D2B2C2D2D2E2D2E2E312E302D2E2D2F2D2E30
2E2E2E2E2D2E2D2E2F2F2F2F2E302F2E2E2E2E2E2E2D2F2D2E2D2D2F2D2E2D2D2D2D2E2D
2C2C2B2D2D2D2C2C2C2C2C2B2B2B2C2D2A2A2A292B2929292B2929282828282827282928
282926272726272727262626262526242424242425262524242423232423252223232324
23232422222323222222212222212120212020202022212020211F21201F201F1E1F1F1F
1E1F201F1F1E1E1E1E1E1E1F1E1D1D1E1E1E1E1E1D1D1D1D1E1C1C1C1E1E1C1C1C1D1B1D
1C1C1B1D1C1D1D1C1D1D1D1B1B1C1C1B1B1C1B1C1C1C1B1B1C1C1A1C1C1C1C1A1C1B1B1B
1B1A1B1A1B1A1B1B1A1B1A1A1A1A1B1A1A1A1A1A1B191B1B1B1A1A191A1A1A191A191A19
1A19181919191A19
1A1A1B191A1A191B1B191A1A1A1C191A191A1A1A1A1B1A1A1A1B1C181B1A1C1A1A1A191A
1A1A1A1A191A1A1A1A1A1A1A1B1B1A1A1B1B1B1B1C1B1B1B1A1B1A1B1C1D1C1D1B1C1C1B
1B1D1B1B1C1C1B1C1C1B1C1B1B1C1C1C1C1C1C1D1B1D1B1C1B1C1C1D1D1D1D1D1D1C1D1E
1E1C1E1D1D1E1D1F1E1E1D1D1E1D1E1F1F1F1E1E1F20201F1F1F1F2020201F1F20202121
202020202020202120202122212122222221222122232222222122222324222324242424
24232425242524242526252526262627272726262628282827282728282A28292A272A2A
2B292A2A292B2B2A29292B2B2C2C2B2D2C2B2D2E2C2D2C302F2F2E30302E2F2F2F2E2F30
302E302D2F2D302F2F30302E2E2E2E2F2F2E2D2F2F2E2E2F2E2E2E2D2E2F2E2D2F2D2E2D
2D2E2C2C2C2E2C2C2C2C2C2D2B2C2D2A2C2A292B2B2B2A2A2929282A2A2B292729282928
272728272828272727272626272626252524252424242323252423242424252424232323
23222222222223222122212121212121212021222120201F20201F21201F201F1E1F1F1F
1E1F201F1F1E1F1E1E1E1E1E1E1D1E1E1D1D1D1E1E1E1D1D1D1D1E1D1D1C1E1D1D1D1C1D
1C1D1C1C1D1C1D1C1C1C1C1C1C1C1C1C1C1D1C1D1B1A1B1C1C1B1B1C1B1B1B1C1A1B1B1B
1A1B1A1C191A1B1B1B1B1B1A1B1B1B191A1A1B1B1A1A1B1B1B1B1A1B1A1A1A191A1A1919
1A1B1A1A1A1A1919
191A1919191A1A1B191A191A191A1A1B1B1A1A1A1A1B1A1B1A1B1A1A1B1C1A1A1B1A1A1B
1B1A1B1B191B1B1A1A1B1A191A1A1A1B1B1A1B1A1A1B1A1B1B1B1C1B1A1C1B1B1B1B1C1C
1C1D1B1C1C1A1B1B1B1B1C1B1C1D1B1D1D1C1C1D1D1C1D1C1B1D1B1D1D1D1C1C1C1D1E1D
1D1D1C1D1D1D1D1E1D1E1E1D1E1F1F1F1E201E1F1E1F1F1E1F1F1F202020202120201F20
2020202120201F2021202120212121212322222220212321222222232322242424242227
24242524222524262525252626272727262827262627272727282828282829292A2B2A2A
2A292A2B2B2A2A2C2C2B2B2B2C2B2C2A2C2E2D2C2D2E2F2E30312F302F302F2F2E2F2F2F
2F3030302F302F312F30303030313030302F302F2F302F302F2F2E302D2E2E2E2F2E2E2C
2D2D2E2F2C2D2E2D2D2E2C2D2D2D2B2B2C2C2B2C2A2C2A2A292B2B292A2928282A282928
282727272726272727262626272625262425252524232524232424242424242426242523
222322232122222123222122222121212120212220202020202020201E1F1F1F1F20201F
1E1E201E1E1E1E1E1E1F1D1E1D1E1E1D1D1F1D1D1D1C1E1E1D1D1E1E1C1E1C1D1C1C1D1D
1C1E1B1C1D1C1B1C1E1D1C1C1C1C1B1C1B1B1E1B1C1D1B1D1C1C1B1A1C1B1B1C1B1A1B1B
1A1A1C1C1A1B1A1B1A1A1B191A1A191A1B1B1B1B181C1B1B1A1A1B1B1A1A1A191B181A1B
1A1A19191A191A1A
1A191A1A191A1A191A1A1A1A1A1A1A19191B1B1A1A1A1A1A1A1A1A1A1B1B191A1B1B191A
191B191A1B1B1A1A1B1A1A1A1A1B1A1B1B1B1B1B1B1B1B1C1C1C1B1B1B1B1A1B1C1C1B1B
1C1C1D1B1C1B1C1C1B1B1C1C1C1B1A1C1C1D1C1C1C1C1C1B1C1C1C1B1D1D1C1E1C1D1D1E
1D1D1D1E1D1D1E1E1E1E1D1E1F1D1E1E1F1F1C1E1D1F201E2020201F201F1F1F1F20201E
201F1F2020211F2120212121222020222222212121222321222122232324222424232324
2425232527252525252525242627262728282626252728282729292929292728292A292A
2A2A2A2A2B2B2C2B2C2B2B2C2C2C2E2D2C2D2D2D302E2F2E302F2F2F302E2F302F312F2F
302F31302F30312F302F2E2F3030303130302F2F2F302F30302F3131302E2F2D2E2E2F2E
2E2D2E2D2D2E2C2C2D2D2D2C2D2B2D2B2C2A2C2C2B2B2A2A2B292B2A29292B29292A2728
292728282727272627282626272526262625262525252525252424252425252424232324
2422222424212321222223222122211F21212022202121202121212121211F201F201F1F
1E1F1E1F1E1D1E1D1F1E1E1D1D1F1F1D1D1F1E1E1E1F1E1C1C1D1C1D1D1C1C1D1D1D1C1D
1C1C1C1B1C1C1D1C1C1C1C1B1B1D1B1C1B1B1B1B1B1C1A1C1B1B1A1A1A1B1B1B1C1A1A1A
1B1B181A1B1B1B1A1B1B1A1B1A1A1A191A1A1B1B1A1C1C1A1A1B1A1B1A1A1A1B191B1A1A
1A1A191A1919191A
1B1A1A18191A19191A1A19191B1B1A1B19181B1A1B1A1C1A191A1B1B19191A1A1A191A19
1A1A1A1A1A1B1C1A1A1A1A1B1B1A1A1B1A1B1B1B1A1B1B1B1D1C1B1B1B1B1A1B1B1B1C1C
1C1B1C1B1B1C1B1B1B1B1D1C1B1B1C1C1C1E1D1C1C1C1B1C1C1B1D1E1D1C1C1D1C1E1D1D
1E1D1D1D1D1D1D1D1E1E1E1E1F1E1E1E1E1F1E1E1E20201F1F1F1F1E201F212020212220
202020202120201F20212020212121232122232122222223232424232423242424232325
232525262525262526262626262726272828262827272727282828292829292B292A2C2C
2B2A2B2B2B2B2C2D2B2B2C2C2C2C2C2D2D2C2C2E2E2F2E302E302F302F31302F2F313030
2F31303031303130313031303132313031303131303030312F2E312F302F2E2F302E2F2F
2E2C2E2F2D2D2E2D2D2E2E2D2C2C2D2C2D2B2B2D292B2B2A2A2B2A292A2B292928292828
292927282827262625272627272725262526262426262424252625252324242423232323
23232323232222232222222122222121212121212021202121201F211F201E1F201F201F
1F1F1E1F1D1E1E211E1E1F1E1E1E1E1E1E1F1E1E1D1D1D1B1D1D1D1C1E1F1D1D1D1C1C1C
1C1C1D1D1D1B1C1C1C1D1C1C1C1C1C1B1B1C1B1C1C1A1C1B1B1B1B1B1C1B1B1A1B1B1B1A
1A1B1C1D1B1B191C1B1C1B1B1B191A1B191A1A1A1B1A1A1B1B1A191B1A1A1A1B191B1A1A
1B181A19191A181A
1A191A1A1A1A1A191A1A1B1A191B1A1A1A1A1B1B19191A19191B1A1B191B1C19191A1B19
1B1B1A1A191A19191A1A1B1A1B1B1A1B1B1B1B1B1B1A1B1A1A191B1B1A1B1C1B1C1B1C1C
1C1C1B1D1C1B1C1C1B1C1A1C1B1C1D1D1C1D1D1D1B1C1C1C1D1E1C1C1D1D1D1D1B1D1E1D
1D1D1D1F1F1E1F1D1F1F1E201F1E1F1F1E1E1F1E1F1E1F1F1F1E20201F20202020202020
212021202021212020222221212223212221222221232221222224242425242424222426
252524252424252526272726262726272628272828282829282929292A2A2A2A2A2A2A2B
2A2B2B2C2C2B2B2D2C2D2C2D2E2D2E2E2E2D2F2D2E2F2F2E31302F303130313130303130
31313031323030303031312F3232303230323130303032303031312F303131302E30302F
2F2E2E2D2F2E2D2D2D2E2D2D2C2D2D2D2D2D2D2B2D2D2C2B2B2A2A2A2929282929292929
282928272729282727262726262726262525272525262525242525252424262423242323
23222422232322222221202222222322212122212022202021201F201F1F1F201F201F20
1E201E1E1E201F1F1F1C1E1E1E1E1F1D1D1D1D1D1D1E1E1D1D1D1D1C1D1C1D1D1E1D1E1D
1C1C1C1D1D1C1B1D1D1B1D1D1B1B1D1B1D1C1B1A1B1C1D1B1C1B1B1C1B1C1A1B1A1B1B1A
1D1B1A1B1A1B1A1A1B1B1B1A1B1B1B1C1B1A1B1B1A1B1B1A1A1A1B1A1A1A1B1A1A1A1919
1A19191919191919
1B1A191A1B1A1A1A19191A1B1819191A1A1A191A191A1A1A1B1B1B1B1B1B191B1A1A1B1B
1C1A1B1A1A1A191B1B1A1A1A1B1B1A1C1C1A1B1A1C1A1C1C1A1A1B1B1A1B1B1B1B1A1C1C
1B1C1B1B1C1B1C1D1C1C1B1B1C1C1C1C1B1C1C1D1C1C1D1C1C1C1C1C1C1D1D1D1E1C1E1E
1D1C1D1D1E1D1E1F1D1F1F1F1E1F1D1F1E1E201E1E1E20201F1F201F201F2020201F2120
202020212020212122212021222223222122222423222223232324242424242624242424
252525242626252525252625292528272727282629282828292A292A292B2A29292A2B2B
2A2A2B2B2C2C2C2C2D2D2E2D2E2D2C2E2F2F2E30302F2F302E2F30303131313030333032
3231313132303132303331313230303230323231333131323030313230303130302F2F30
2F2F2E2E2E2F2F2E2E2E2E2D2E2D2D2D2E2D2B2D2B2B2B2C2B2A2A2A2B2A292B2A292828
282828282827282829272627272626262626252524262525242524242425242424232424
2423222323212223242322212223212221212120212021212021202020201F201F20201F
1F1F201F1E1F1E1E1E1E1F1E1E1E1E1E1E1E1E1D1D1E1E1F1C1D1D1C1D1C1D1E1D1C1C1C
1D1D1C1D1D1C1C1C1C1B1B1C1C1C1B1C1B1A1B1B1C1C1C1B1B1B1C1A1B1C1B1C1A1A1B1A
1B1B191A1B1B1A1A191A1B1B1A1A1A1A1A1B1A1A1A1A1A1B191B1B1B1A1A1A1A1A1A1B19
191A191A1A19191A
1A19191A191A1A1A1A1B1A1A1A1A1A1A1B1B1A1A191B1A191A1B1B1C1C1B1A1B1A1B1C1A
1A1A191B1A1B191A1A1B1B1A1B1B1A1B1B1A1A1B1C1A1C1A1B191B1B1B1A1D1C1C1B1D1C
1A1C1C1D1C1C1C1C1C1C1A1B1B1B1C1B1B1B1D1C1B1C1C1C1B1C1C1D1D1B1C1E1E1D1C1F
1D1D1D1D1D1D1D1D1D1F1E1D1E1F1E1F1E20201F1E1E1F1E1F201F2020201F211F1F201E
2120201F20211F2021222222212021232221232223212323232222242324242424232425
2425252526252426252725262728272727272828262826282A2829292A2B2A2B2B2A2B2C
2B2A2C2D2C2C2D2D2D2E2D2D2E2F2E2C2F2E2F2F2F2F3030303130313131313430323131
3131323333323132313231313131313032323132323232313130322F323131312F30302F
30302E2F2F302E2F2E2D2D2D2E2D2E2E2F2B2D2C2B2C2C2B2B2B2B2B2B292929292B2729
292828282A29282827272727262627262626272525262526252524252523252323242324
242224242322222322222223212222222221202122212020211F1F201F20201F1F20201F
201F1E1F1E1E1F1E1D1F1F1F1E1F1E1D1D1E1D1E1F1E1E1D1E1E1E1E1D1C1E1D1D1D1D1C
1D1D1D1C1C1C1D1C1D1C1B1D1C1D1C1B1A1B1B1C1B1C1C1C1C1C1B1B1C1B1B1C1B1C1C1B
1B1B1B1A1B1B1C1B1B1B1B191A1A1C1A1B1A1A1B1A1A181B1B1B1A1B1A1A191A181A1A19
1919181A1B181919
1A191A1A1A1A1A1A1A19191B1A1B1A1A181A1A1A19191A1B1A1A1A1A1B1B1B191A1A1A1B
1A1B1B1A1A1B1B1B1A191A1B1B1A1A1B1B1B1B1A1D1B1C191A1C1B1A1A1C1C1B1B1A1C1C
1C1D1C1C1C1B1C1D1C1C1A1C1C1D1C1C1C1C1D1C1C1C1D1C1C1C1C1D1D1C1F1D1D1E1D1E
1C1E1D1D1E1E1E1F1F201E1D1E1F1F1F1F1F1F1E1F1F1F1F1F2020201F2020201F202020
1F2321212021202021202221212322232123222223212223222223242422252324232524
2425262526262625252728282627252727272727272A292A28292A2A2A2B2A2B2A2B2B2C
2A2C2B2D2C2D2D2D2E302E2E2F312F302F2F2E2F30303032313032313132313230323131
323132333233333232343331313233333333343332323133333232323231323031303031
3031302E2E2F2F2F302E2F2E2E2D2D2E2F2C2D2D2C2D2C2D2B2B2A2C2C2C2B292A292A29
2A2A292A2928282828272826272627252525252824272524252524252424252423242424
24242423232324222222222121222221222120212221212020201F2020201E1F1F201F1F
2020201E201F1D1E201F1E1E1E1E1F1F1E1E1D1D1F1E1E1D1D1C1E1D1E1D1D1D1C1D1D1C
1C1C1C1D1C1D1D1C1D1C1C1B1C1C1B1C1C1B1C1C1D1B1B1C1C1A1B1B1B1B1B1B1D1A1B1A
1C1A1B1A1B1C1B1B1A1A1B1A1B1B1B1B1B1C1B1A1B1B1A1B1C1A1B191A1B1C1A1A1B1A1A
18191A19191B191A
191A1A18191A1B1A191A1919191A191A1A1A1B1A1B1A1A1A1B1B1A1A1A1A1B1A1B1A1B1A
1A1A1B1A1B1C1B1B1A1B1B1A1B1B1A1B1A1B1B1A1C1D1B1A1A1B1B1A1A1B1B1B1B1C1C1C
1C1B1C1D1B1B1C1B1C1C1C1B1B1B1C1C1B1C1C1C1E1C1D1C1D1C1D1D1E1C1D1C1D1C1D1E
1D1D1E1D1D1E1E1E1F1D1D1E1F1F1E1E1E1E1E1E1F1F1E1F201F1F201E2020211F212020
212021212021222221212221222320222424242221222322222324232423242424252425
2426262424262526262827282727282828282828292A2A28292A2A2A2B292A2B2B292C2B
2A2D2D2D2E2E2D2E2D2D2D2F2F302E2F302F3031302F3131313231313131323232323133
323233343132323332333233333234323232333233333332313233313432303231313130
313031302E312F302F2F2D2F2E2E2F2D2D2E2D2E2D2E2C2C2C2A2A2B2B2B292A2A2A2A2B
2A292A292928292828282627262626262725272626242424252525242424252524242423
2423242223242422222222222321222221222221212121222020201F212020201F201F21
201E201E1F1F1F1E1D1F1F1F1F1D1E1F1E1D1E1E1E1E1C1C1E1D1E1E1D1E1C1D1D1D1D1C
1C1C1C1C1D1B1C1D1C1C1C1D1B1C1D1C1C1C1C1C1C1C1D1C1C1C1C1B1C1C1C1B1B1B1C1A
1B1D1B1C1B1C1A1A1B1A1A1A1B1B1B1B1A1A1B1A1B191A1B191A191B191B1B1A1A19191A
191B1A19181A1919
1A191A1A191A191B191A1A1A1B1A191A1A1A1A1A1B1A1A1A1A1A19191A1A1A1A1B1B1A1A
1A1B1B1B1B1B1B1A1A1B1A1B1B1B1B1C1A1B1B1C1B1C1B1B1B1B1B1B1D1B1B1B1C1D1C1C
1D1D1C1B1B1C1D1C1C1C1C1C1B1C1C1D1D1C1C1C1C1D1E1D1C1C1D1E1C1D1D1E1D1D1E1D
1D1E1D1D1F1F1E1E1E1E1D1D1F1F1E1F1F201F202020201E1F201F1F1F1F1F2020202121
212020202220202121212121232121212122232223232323222323242524242326242525
2525262525262727272626272826272828292A2A2829282928292A2B2A2A292B2B2B2B2C
2C2C2D2C2D2D2F2E2E2E2E2E2F2F30302F31313031313030323232323133333433343231
333434343333333333333434343333333434353334323333323233323332333231303231
3031312F312F2F302F2F2F302F2F2F2E2F2D2E2F2D2D2C2C2A2D2D2C2A2B2A2B2A2A2B2B
2B2929292929292829272829282527272726262627262624252525252425252324252324
2423222323232222222124212322222321212221202021212121201F1F202020201F201F
1F201E1F20201F1F1E1F1F1E1F1F1F1F1E1D1D1E1F1D1D1D1D1D1D1E1D1D1D1D1E1E1C1C
1D1D1D1C1D1C1D1C1D1E1C1C1C1C1C1C1B1C1C1C1C1B1C1B1B1B1A1B1A1B1C1B1B1B1B1A
1A1C1C1B1A1A1A1C1B1B1A1B1B1B1B1B1B1B1B1B1A1A1A1B1A1A191A1A191B1A1A1A1A1A
19191A1A1B181A1A
1A1A1B19191A1A1A1A19191A1A1A1A1B1B1A1A1A1B191A191C1A1B1B1B1A1A1A1B1A1A1B
1A1A1B1B1A191A1B1B1A1A1A1A1A1C1B1C1B1B1B1A1B1C1C1B1B1C1C1C1C1A1D1B1B1C1A
1C1C1C1C1B1B1C1D1C1C1C1C1C1B1C1D1D1C1E1D1D1D1D1B1B1D1D1E1D1C1E1D1C1D1E1D
1E1E1D1F1E1E1F1E1E1E1E1F1E1E1F1F201E1F1E1F1F1F211F20221F20212021201F2020
212120212121212022202322232222232223222124232323232224242425252424252525
262624252727272527272726272728282929292929292A2929292A2A2B2C2B2C2C2C2B2C
2C2C2D2E2F2E2E2E2E2F302F2F30302F3031313031313132333234313233323232333135
343334363433343334333433333435343333353334343333323332333332313231323231
31323031303030303130302F2F2E2F2F2F2E2F2D2E2F2F2D2C2C2D2C2C2C2B2B292B2C2B
2A2A2A2B282A2928282A2928272727282826262626272725252424252624232423242423
232223232222222223222223222222212222222121212121212120202020201F1F1F211F
1E1F1F1E1F1F1F1E1F201E1D1E1D1D1F1D1E1C1E1E1E1D1D1D1D1E1F1C1C1D1E1D1C1C1C
1C1D1B1D1C1C1C1C1D1C1D1C1D1C1C1C1B1C1A1C1C1A1C1C1C1D1A1C1B1B1C1C1C1B1B1A
1A1A1B1B1A1B1B1A1A1B1B1B1B1B1C1D1F1E1B1C1A1A1A1B1B1B1B1A1A1A1B1B1A191A1A
1A1A1A191A1A191A
19191A19191A1A18191A1A191A1B1A1A1A1A1C191A191A191B1A191A1A1B191A1C1B1A19
1B1B1B1A1A1A1B1B1B1A1A1B1A1A1B1A1A1A1B1B1C1B1B1B1B191B1C1B1C1B1C1B1B1A1D
1C1D1B1C1C1D1C1D1D1C1C1A1C1C1D1C1D1D1D1C1E1E1D1C1D1D1D1E1D1D1C1E1D1D1C1E
1E1D1E1F1F1E1E1D1E1E1E1E1E1E1E1F201F1F1D1F201F1F211E1F1E2021211F1F212020
222121212121222221232022212223242322222123222323242324242525242426252325
2524252726252726262627282927282828282A282A28292A2A2B2B2C2A2C2B2C2C2C2C2D
2C2D2D2D2D2E2E2F2F2F302F30302F313030313132323333323233323233333334333434
333635343435353434353534353434353334343534353334343332333333333332323231
3132312E313131303130312F31302F2F2F302E2E2D2E302D2C2D2C2B2A2C2C2B2A2A292B
2B2A292A2A292A2A27282828272825272727272625272725262525252524252524232424
242323222222232322232223222122232222212120202121202120211F20201F211F201F
202020201F1F1E1E201E1F1F1F1E1D1F1D1D1F1C1E1E1E1E1D1D1D1D1D1D1E1C1C1C1C1C
1D1C1C1D1D1C1D1C1B1C1D1D1D1C1C1B1B1D1C1B1B1C1C1C1C1C1C1A1C1B1B1B1B1B1B1B
1B1B1B1B1C1A1B1B1A1A1A1C1B1B1D1C22211B1D1B191B191A1B1B1A1B1B191A1A1A1B18
191A1A1A1A181A1A
1A1A191B1A1A191A1B191A191A1A1B1B191B1B1A191A1A191A1A1A1B1A1A1B1A1C1B1A1A
1B1A1A1A1B1B1A1A1A191A1B1A1B1B1B1B1B1B1B1B1C1B1B1B1B1B1C1B1B1B1C1B1C1A1C
1C1B1A1B1C1C1C1D1C1C1C1C1C1D1D1C1C1C1D1C1C1D1D1D1D1C1C1E1C1D1D1D1D1E1D1E
1D1E1D1C1D1D1F1E1E1E1E1E1E1E1F1F1D1F1F1F1F1E1F201F1F20201F1F1F2020202120
212120212021222121212121212223232323232223242223242523242425252524252426
2527272B272626262928272728282729292B29292929292A292A2B2A2C2B2B2C2C2C2D2D
2E2C2D2F2E2F2F2E2E2F3030303131303231323232323332333433343433323434343635
343536363535343537343535343435363535353536333535343432343535333332343433
323232313231303032323131313031302F2E2E2D2E2F2E2D302F2C2C2D2D2B2B2C2C2C2B
2A292A2A2B2A292A29292829292827272826272626262527262725252625262424242524
23232322232322222222232323212222222222212221212120222121211F20201F1E2021
20201F1F1F1F1F1E1F1F1F1E1D1E1F1E1D1E1F1D1C1E1D1D1D1D1D1D1D1E1E1D1E1C1D1C
1C1E1C1D1C1C1D1C1D1C1C1C1B1D1C1B1B1C1C1B1B1C1C1A1B1B1C1A1B1B1D1B1A1B1C1C
1B1B1A1C1B1A1B1B1A1B1B1B1A1B1B1D1E1C1C1B1A1B1A1B191A1B1A1A191A1B1A1B1A1B
1A191B1A1A1A1919
1A19191A1A1A1A1A191A1A1A1A191A1A1A1A191A1B1A1A1A1A191A191A1B1B1B1A1A1B1A
1A1B1A1C191A1B1A1A1B1B1B1B1B1B1A1B1C1B1B1B1A1B1A1A1B1A1B1B1A1B1B1A1D1C1B
1B1C1C1C1B1C1D1D1B1C1C1D1C1C1D1D1C1E1D1C1C1D1D1D1C1E1C1C1D1D1C1E1D1D1D1E
1E1E1E1E1E1E1E1E1F1F1E1D1F201E1E1E1F1E1F2020201F1F1E1F1F1F21202020201F20
202120212020202222212322222121222324222324222423232423242524252525252626
25262526272627262728282827292829292A2929292A2A2A2A2A2B2B2B2C2C2C2A2C2D2E
2E2D2C2F2F2F2F2E30312F30313130313332323333333234343433313436363435373535
343636353535333636363536383737373636353535363535353436343434343534333333
3232323133313331313031323030312F302F302E2D2F2E2E2F2E2D2D2C2C2B2C2B2B2C2B
2B292B2A2A2A282A2A292727292827282827262728272727262625262625252524242324
242424232323222222222223222223222224212220202221212121202120212120201F21
1F20211F1F201F1F1E1E1D1F1F1F1D1D1E1D1E1F1E1E1E1E1E1D1C1D1F1E1D1C1C1D1D1D
1C1D1C1C1C1B1E1C1D1D1C1C1C1B1C1B1C1C1C1D1C1C1C1C1B1B1B1D1C1C1D1B1C1C1B1C
1B1C1B1C1A1A1B1B1B1A1B1A1C1A1B1D1C1C1C1A1B1B1A1A191A1C1B1A191A191A1A1A1A
1A1A1A19191A1A1A
1A1A191A1A1B1B1A1A191A1A1A1A1B1A1A1B1B191A1A1A1A1A1B1B1B1A1B1B1C1A1A1A1B
191A1B1A191B1A1B1B1A1B1B1A1A1B1B1A1B1B1B1B1B1B1B1B1B1C1C1A1C1B1B1B1D1B1A
1D1B1B1B1C1C1D1C1C1C1B1B1C1D1D1D1D1C1D1D1D1D1E1C1D1D1E1D1E1C1C1C1D1D1F1F
1E1E1E1E1E1E1F1F1E1E1F1E1E1D1F1E1F1F1F201E1F1F1F20201F1F1F211F211F202121
20211F202121212222202323222123242323232423232323232324242323242526252625
262626252826282727292929282829272829292A29292B2B2C2A2C2D2A2B2C2C2D2D2C2E
2F2E2D2F302F3030302F2F31323030323431333232333334353335373535343434363535
373735363636363636363635363737373736353635363735353735363434363535353334
343333333332313332323131312F3031302F2F2F302F2E30302D2E2D2D2D2D2D2D2B2C2B
2C2A2B2A2A2A292829292729272828272828282627282626262625272624232425252623
242324242323242123252322212123222124212121222020202122202020202020202020
20211F1F1E1F1F1E1E1E1F1F1E1D1E1D1D1E1E1E1E1D1E1E1F1E1E1C1F1E1D1D1E1C1D1D
1D1C1C1C1C1D1D1C1D1D1C1D1C1B1C1C1C1C1C1B1C1C1B1C1C1B1E1C1B1C1C191B1C1A1C
1B1B1B1A1A1A1B1B1B1B1B1B1A1B1A1A1A1B1B1A1C191B1A1B19191A1A1B1A1B1B1B1A1A
1A1A1A1A1A19191A
1A1A19191A191B1A1A1A1A181A1A1A191A1A1A191A1B1A1A1B1A1B191B1A1C1B1B1B1A19
1A191A1B1A1B1A1A1A1A1C1B1A1A1A1B1B1B1C1A1B1B1B1A1B1A1B1A1B1C1C1B1B1B1B1B
1C1B1A1C1C1C1D1C1D1B1D1B1C1D1B1C1C1D1E1D1D1C1D1E1D1D1D1C1C1D1C1E1F1D1E1D
1E1E1D1F1E201E1F1E1E1E1E1F1E1E1E1F201F201F20201F1F1F2021201F1F2020202020
202021202221222222212122232222222323232424222424242323252624242524252425
2526252626282727282928292A2829292A292A2A2B2A2B2A2B2C2B2B2C2C2C2E2E2D2F2D
2D2E2F2F2F31303030323032313232333432333435353434343535343636353635373636
363638373637383737353836363837373736383638373835353637363536343435353434
34343434333332323333323232313131313030312E2F302F2F2E2D2E2D2D2C2C2C2C2B2C
2B2B2A2B2B2A2A2929282928282929282828282729262628262525252525242424242325
2623242322222323232224222323212221222221212121212020212121221F21201F201E
1F1F1E1F1F1F1F1E1F1F1E1E1E1E1E1E1C1E1E1F1E1E1E1F1D1E1E1E1D1E1C1E1D1C1D1D
1D1C1D1B1C1B1D1D1D1E1D1D1D1D1C1C1B1D1D1B1C1C1C1D1C1C1B1B1B1A1A1B1B1C1B1B
1C1A1B1A1A1A1A1A1B1B1A1A1A1A191B1A1A1B1A1B1A1A1B1A1A19191A1B1A1A1B1C1B19
1A1A1A1A1B191A19
1A1B1A1B191A1A19191A1A1A1A1A191A191A1A191A1B1A1B1A1B1B1B1A1A1B1A1C191B1A
1B1A1A1A1B1A1A1A1B1A1B1B1B1A1A1B1B1A1B1A1A1C1C1B1C1A1B1B1B1A1A1C1C1B1B1C
1C1C1B1C1B1D1D1C1C1D1D1D1D1B1D1D1C1D1C1D1D1D1D1D1D1C1D1D1E1D1D1D1E1D1D1E
1E1E1E1E1E1E1E1F1E1D1D1D1F1F211F20201F201F1F201F1F20201F20211F20201F2021
212020212122222222212322232322232223232223222324232425242424252424252624
2525262726272727282929282828292A292A2A2B2A2A2A2B2A2C2D2D2B2C2D2F2D2E2F2D
302F302E3032313131303232323332343433333535343335363636373635363736363637
373836353739373938383838363838373837373739383736373735353636343536363535
3434353333353433333332313131303130302F31312F2D2F302F2E2F2E2D2C2C2D2D2D2D
2B2B2A2A2C2A2A2A29282729282929282927282727262725252625242624252424252424
2425232422242424222222222122242122222221202221202022202020201F2020201F1F
1E1F1F1F1F1F1F1F1F1E1E1F201F1F1E1E1E1E1F1E1D1E1F1D1E1D1D1C1E1C1D1C1D1D1D
1D1C1C1C1D1D1C1D1C1D1C1C1D1C1D1C1C1B1B1B1C1C1C1B1B1B1B1A1D1C1B1B1B1B1B1C
1B1C1B1A1B1A1B1A1B1B1B1B1A1A191B1B1A1B1A1A1A191B191A191A1C1B1A1A1A1B1B1A
19191B1A19191B19
1B1A1A1A191A1A1A1A1A1A1B1A1B1A1B1A1A1A191A191B1B1A191A1B1B1B1A1B1C1A1B1C
1B1A1A1A1A1A1B1A1A1A1B1A1A1B1B1A1B1B1C1B1C1B1A1B1B1C1D1C1B1A1A1C1B1C1C1C
1C1B1C1C1C1B1C1C1B1C1D1B1D1D1C1C1C1D1D1C1C1D1C1D1C1D1E1D1E1D1E1D1E1D1D1E
1E1F1E1E1D1D1D1E1E1F1F1E201D1E1F1E201F1F1F1F1E201F1F202020211F2020212121
202120212322212223232223242224232323232223232524242426242523242526242526
2526262627282728272829292B2A292929292A2B2B2B2B2B2B2D2D2C2C2D2E2E2E2D2F2E
2D2F2E303130303031333233323334333435363435363537373536363737373937373738
373836393838393837383937383938373837383938383937373837373738373637363636
34353334353534353232333233323231303130313031312F2F2E2E2D2F2E2D2C2C2D2C2B
2C2C2B2C2A2A2A2B29292A28292829272828282726272826272726262425242525262624
232324252424232422232323222223222222222222222121212120202020202020201F20
20201F1F21201E1F1F1F1F1F1F1E1E1F1E1E1E1E1E1D1E1E1D1E1D1E1D1D1D1D1C1C1D1D
1B1B1D1C1D1D1D1D1C1D1D1C1D1B1B1B1B1B1C1B1B1C1B1B1C1B1C1B1C1C1C1B1A1C1C1D
1C1C1B1B1B1A1B1B1B1A1A1A1B1A191A1A1A1A1A1B1A1A191A1B191A1B1A1B1A1A1A191A
1A1A1A1B191A191A
1A191A19191A191A191A1A1A19191B1A1A1A1A1B1B1B1A1B1A1A1B191A1B1B1B1B1B1B1A
1A1A1A1A1A1A1B1B1B1B1A1A1B1B1B1A191A1D1B1B1C1D1C1C1B1B1B1B1B1B1A1B1B1B1B
1B1D1C1C1C1C1D1C1B1B1B1D1D1C1E1D1D1C1D1C1C1D1C1C1D1C1E1D1C1D1E1E1E1D1D1D
1D1E1E1D1E1F1F1E1F1E1F1E1D1F1F1F1F1F1E1F201F20201F20202021211F1F22212020
202220222121202122222123212424232323222224232424252325232624252524252425
2426272627282827292928292A2929292A2B282A2B2A2B2C2C2D2C2B2D2D2C2E302F2F30
2E2F2F31303130323233333233353435343436353635393737383836373938373738383A
39393937383A38393B393A393B3739393839393938393939383937373737383836373636
3636353437343633333434333334333132313032302F2F302E2F2D2E2D2E2D2E2D2C2E2B
2B2B2C2B2A2C292B2A292A29292829292828272826272726272725252525252625242323
23232523232422242323232323212222222221212220202022202121202020212020211F
1F201F1E1F201E1F1F1E20201F1F1F1E1E1E1F1D1E1F1D1E1D1E1E1C1D1C1C1D1D1C1C1D
1D1D1F1D1B1C1E1D1B1D1B1D1C1B1C1C1B1D1B1B1C1C1B1B1D1B1C1B1B1C1B1B1C1A1B1B
1A1A1C1B1A1A1A1A1B1B1B1A1A1B1B1A1A1B1A1A1A1A1B1A1A1B1A1A1B1B1A1B1B1B1B1A
1919191A1A191A1A
1A1A191A1A1A191A191A1B1A1B1B1A191B1A1A1B1B1B1A1B1A1B1A1B1C1B1B1A1A1B1A1A
1A1B1B1A1B1B191A1C1A1A1B1A1B1B1C1B1B1C1B1A1C1C1A1B1C1B1B1B1C1B1C1C1B1C1C
1C1C1B1D1B1D1C1C1C1C1B1B1C1C1C1C1D1D1C1D1E1D1C1C1C1E1F1D1F1D1D1D1D1E1E1D
1D1E1E1F1E1E1F1F1E1E1E1E1F1F1F1F20201F1F1E1E1F1E1F2021212120212121212120
222021202123222122232223232423232222222424242524262325242525262526252725
2727282728272729282A2929292B2A2A2A2A282B2B2B2B2B2C2D2D2D2D2D2C2E2F2E2E30
302F31303331303431333433343434343536363236373736363737383739373939393A3A
3A3C3A3A3A3C3A3A3B393A393B3A3A3A39393A3B3A3939393839393A3638383737363738
3736363636363434343434343233333331313131323130302E30302E2F2E2D2D2E2E2D2C
2D2C2A2B2D2B2A2B2A292B292A2928272729282727262727262625252725252626252523
2424242423232323242223222322222122212121212121202121222121201F211F202020
21201F1E1F201F1F1F1E1E1E1F1E1E1F1E1E201C1D1D1E1D1E1D1E1E1F1C1D1E1C1D1D1D
1C1D1D1C1C1D1C1C1D1C1E1C1D1C1D1C1C1C1B1C1B1C1B1A1B1B1B1B1B1C1C1B1B1B191B
1C1B1B1B1C1B1A1C1B1D1B1B1B1B1B1B1A1A1A1A1A1A1B1A1B1A191A1A191A1A191A1A1B
1A1B1A1A1A19191A
1A191A1A191A191A1A1B1A19191A19191B191B1A1A1B1A1A1A1B1B1A1A1B1A1B1A1B1A1A
1A1A1A1B1B1B1B1A1B1A1A1A1A1A1B191C1C191A1D1A1A1A1B1B1A1B1C1D1B1C1C1B1B1C
1C1B1C1C1C1C1C1C1C1C1D1D1C1C1C1C1C1E1C1C1C1D1D1D1C1D1C1D1D1D1E1E1D1C1E1F
1F1D1F1E1F1E1F1F1E1E1F1F1E1E1E1F20201F1F1E1F1F201E20201F212020211F21201F
212120212121222123222223222223232322232424242524242524252525242625262526
25272726272728292B2A2828282A2A2B2A2B2B2B2B2B2A2E2C2D2D2D2E2E2F2E2F2F302F
303032323132323232343334343635343636373536383738393839383A38393A3B393B3A
3A3C3B3A3C3A3B3B3A3B3B3B3B3B3B3D3B3A3A3B3D393A3D3A3A3A393839393837383737
3635363736343434343535323333343232313031303230303130302F2E2F2E2D2D2D2C2D
2B2C2D2C2B2B2C2B292A2A2829292A282828272727282725262626252725252525252525
242423232522232422242224222323212122222221222021202220211F20201F201F2120
1F20211E1F201F1F1F1F201E1F1F1E1E1F1E1E1E1E1E1E1E1E1E1D1D1D1D1E1C1E1D1C1C
1C1C1C1B1C1D1C1C1C1D1B1B1D1D1B1B1D1D1B1B1C1C1C1C1D1C1A1C1B1B1B1C1B1B1B1A
1C1A1C1C1B1C1B1A1B1B1B1A1A1C1A1B1A191B1A1A1A191A1A1A1B1A1A19191B1A1A1A1B
1A181A191A191919
191A181919191A191A19191A1A1A1A1B1A1A1A1A1B1A1A1A1A1B1B1B1A1B1A1A1B1B191B
1B1B1A1C1A1B1B1B1A1A1B1B1A1B1B1B1B1A1B1A1C1A1A1B1B1C1B1B1C1C1B1B1B1B1B1C
1C1B1B1C1C1D1C1B1C1C1D1C1D1C1C1D1D1C1C1D1C1E1D1D1E1D1E1C1D1E1D1E1E1E1D1E
1E1E1F1E1E1F1E1D1F1D20201F1F201E1F1F1F1F1F1F201F1F2120211F1F212121202220
212221212221232123222221232424232222232324242425262425252625262526262626
2526272829282929292A292A292A2B292B2A2B2A2C2C2B2D2B2D2F2D2F2E2E2F3030302E
31323131313133333433343533343435363437373638383A383839383A393B3A3A3C3C3A
3C3A3B3D3C3C3C3B3A3B3D3A3D3B3C3B3C3C3D3B3B3B3C393A3C3C39383B3A3938383936
393736363535353434343435343233333534313232313231303030302F30302F2F2C2E2D
2D2C2C2C2C2C2B2C2B2A292A292928292828292827272828272625262625252525232525
232524232424232324232323222322212222232222222022222021212020212120212020
1F20201E1E2020201E1F201E1E1E1F1E1F1E1E1F1E1E1E1D1E1D1D1E1E1D1D1D1C1C1C1D
1C1D1C1C1C1D1C1D1C1D1C1D1C1D1C1C1C1A1B1C1B1C1B1B1B1C1C1D1C1D1A1B1C1B1B1A
1A1B1A1B1D1A1C1B1A1B1B1A1B1A1A1A1A1A1A1B1A1A1A1A1B181A191919191A19191B19
1A1A191919191919
1A19191919191919191A1A1A1A1A191A1A1A1A1A1A1C1A1A1A1A1B1B1B191A1A191B1B1B
1B1B1A1B1B1B1B1B1B1B1B1C1D1C1B1B1B1C1A191A1B1B1B1B191C1C1C1B1C1C1B1C1C1A
1C1B1B1B1B1C1B1C1C1C1D1C1C1E1D1C1B1D1D1C1D1D1D1D1D1D1D1D1D1F1D1D1E1F1E1E
1D1E1D1F1D1E1E1F201E1E1E1F1F1F201E1F1F1F201E20202020211F2121202120202121
212221202223212221232222232322232224232323242325232424252525262526272626
2626262828282929292928292A2A2A2B2A2A2C2D2B2C2E2D2C2D2D2C2E2F2F2F30303030
313132323234323434353435353736373635373838373A373A393A3B3B3A3A3A3C3C3B3C
3B3D3D3D3E3B3E3C3B3D3C3C3D3D3C3D3D3C3D3D3C3D3B3D3A3B3B3A3A3A3A3A393A3839
3838373836383636383635353532333333333332323132313131303030302F2E2E2D2D2D
2B2C2C2C2C2C2C2C2B2C2A292A2729292828282828262728262727282627262526242524
2425252525242423232323232322222121222323202120222122222222212121201F211F
20211F1F201F1F1E1F1F1E1E201E1E1F1F201E1E1E1E1E1E1D1E1E1D1E1D1B1D1E1D1D1E
1D1C1C1E1C1D1D1D1E1C1C1C1C1D1C1B1C1C1C1D1B1C1B1C1C1C1C1C1C1B1A1A1A1A1B1B
1A1C1A1B1B1B1B1A1A1B191B1C1B1B1A1A1A1C1B1A1B1B1A1A1A1B1A1B1B1B1B1A191A1A
1A1A19191A191819
1A191819191A1B1A1A1A191A1A1A1A1B1B1A1B1A1A1B1B1A191A1A1A1B1A1A1A1B1B1A1B
1B1A1B1A1B1B1B1A1A1B1B1B1A1B1B1B191B1B1B1C1A1C1C1C1C1B1B1C1C1C1B1A1C1B1C
1C1D1A1C1C1C1C1C1C1C1B1D1D1C1C1B1C1D1D1E1D1C1D1D1D1E1E1C1C1D1E1E1D1E1D1F
1E201E1F1F1E1F1F1E1E1F1F1F1F1F201F1F1E1F2020221F21201F212120202121212023
222221222122232222222322222323232323242324252524252524262626242626272727
2729282827272829282A2828292B2A2C2A2D2D2D2B2D2C2C2E2D2D2F2E2F2F302F303031
3032333334343435333534363636353637383838383A3A393B383C3C3B393B3B3C3D3D3D
3E3D3E3E3E3E3F3D3D3E3D3E3E3C3D3F3D3D3F3E3D3D3C3E3C3D3C3D3B3B3A3B3A3B3A38
38393838383836383636343635343435333332323332343030303030302F2E302D2F2D2D
2D2C2B2C2C2C2D2C2A2A2C292A2A29282828272828282827272628262625272425252424
252424232424232524242221222323222222232120222121212021201F20212220202020
201E201F1F1F1F1E20201D1F1E211D1E1E1F1F1D1E1F1E1F1D1F1E1E1D1F1D1C1D1C1E1C
1E1C1D1C1C1C1E1D1D1D1C1C1C1B1C1C1D1D1C1B1C1D1B1D1C1C1C1B1B1B1B1B1B1C1B1A
1B1B1A1B1A1B1B1B1B1B1B1C1B1A1B1A1A1B191A1B1A1B1B1A191A191A1A1B19191A1A1A
191A191A1A191A1A
1A19191A1A1A1A1A1A1B1A1A1B1A1A1A1A191A1A1A1B1A1A1B1A1A1A1A1B1A1B1A1A1A1B
1A1B1B1A1C1A1B1A1A1B1B1A1B191A1B1B1B1C1A1B1C1C1B1B1B1C1C1C1B1B1B1B1D1B1C
1D1C1C1C1C1D1E1D1D1D1C1D1D1D1B1C1C1D1D1D1E1D1E1D1E1D1D1D1E1E1D1E1D1E1E1D
1E1F1D1E1E1D1E1F1F1E1E1E1F1F1F1E1F1F1F201F1F201F20201F201F21212120222121
222121222222232222222123222423222224242425232424242526242426252525262728
282828272829282A29292A292B2B2B2B2C2B2C2C2C2C2D2D2E2F2D2F2F302F30302E3031
3233333233323437373536353837363637393839393A3A3B3B3A3B3C3C3D3D3D3D3C3D3D
3F3E3E3E3F3E3E403E403F40413F3F40403E403E3F3F3E3E3D3D3B3D3A3B3B3B3C3A3938
393A3938363836383A36353536363534343535333334323130303031302F2F302F2E2D30
2D2E2D2C2D2C2A2B2C2B2B292A292A292929292729272827272626272625262525262625
252424242225242424232223222222222221212221222121212221212021212121212020
1F1F2020201E201D1F1F1F1D1F201F1E1D1D1E1E1D1E1E1E1E1E1E1D1D1D1D1E1D1E1C1C
1D1D1D1D1D1D1C1C1D1C1C1B1C1B1B1B1C1C1B1C1C1D1C1B1C1A1C1C1B1C1B1A1B1B1B1B
1A1A1A1C1A1B1A1A1A1A1A1D1C1D1A1B19191A1A1A191A1A1A1B1B1A1B1C191A191A1A1A
1A1A1A1A19191A1A
1B19191A1A191A191A19191A1A1A1B1A1A191A1A1B1A1A1A1B1B1B191B1A1A1A1A1A1A1A
1A1B1B1A1C1A1B1B1B1A1B1A1A1A1B1B1C1A1B1B1C1B1B1C1C1B1C1A1B1B1B1B1C1A1C1B
1C1C1C1B1B1C1C1D1D1D1D1C1D1E1D1D1D1C1D1E1F1D1D1E1E1E1C1E1C1E1C1E1D1D1E1E
1E1F1E1E1E1E1E1E1E1E1F1E201E1F1F1F202020211F1F2120211F202021202121211F21
212122222222222324232223242323232423232426252625252626252425262826262926
2828272728282A292929292A29292B2C2A2A2D2B2C2D2E2E2D2D2F302F2E2F2F302F3230
31323233353534353536373836383737383938393B3B3B3C3B3C3D3B3D3F3D3D3F3E3F3E
404040404140403F41423F4141413E403F3E3E3F41403E3F3C3E3D3C3D3C3D3B3B3C3C3B
393B3A3939393A3938373738363635353634343435333333333230323130302E302F2F2E
2C2E2D2C2E2C2B2B2A2A2B29292B2A282829292829282726272926262726252526262526
252425242322232324242323232324222222212123222122222120222021212121212021
2020201E1F1E201F1F1F1E1F1F201F1F1E201F1D1F1D1E1E1E1F1E1D1E1E1F1D1D1D1D1D
1C1C1C1C1D1D1D1C1C1D1C1C1D1A1C1C1A1D1C1C1B1B1C1C1C1B1C1D1A1A1C1A1A1C1A1B
1B1B1A191C1B1A1C1C1A1C1C1B1A1A1A1A1B1B19191A1A1A1B1A1B1B1A1A1A1A1A191B1A
191A1A1A18191919
1A1A1A1A1A1919191A1A1A1A1A19191B1B1A1A1B1A1B1A1A1B191A1A1B1A1A1A1C1A1B1B
1C1B1B1A1B1B1B1B1C1A1D1A1B1B1B1A1C1A1B1B1B1B1B1C1C1C1B1B1C1B1C1C1B1B1B1D
1C1D1B1B1D1C1D1C1C1D1C1C1D1D1B1C1D1D1C1E1D1D1E1D1D1E1E1D1E1D1D1D1D1E1C1D
1D1E1E1D1E1F1F1E201E201F1F1F1F201F201F1E1F1F2120202020201E20202120212322
222121212223222320232423222222232322242524242625252624252526262626272626
2827282728292829292B2A2B2B2B2C2B2A2A2C2D2C2E2F2E2E2F2F2F3030303131323131
33333334353636343835373636383A383938393A3A3C3B3D3D3D3C3C3E3F3D3D3E3F403F
41414241424241404241414340414142414142414142403E3E403E3E3D3E3D3D3B3A3B3C
3B3C3A39393A38383837383736363637353634333434323332323133323130302F2F2E2E
2F2D2F2E2B2D2B2C2C2B2B2A2B292B2928292A2828282827272628262626262426252526
2624252526242424232322222323222322232322212122222020212021211F201F212020
201F1F1F201F201F1E1E201F1F1F1F1E1E1F1E1F1F1F1F1F1D1D1C1D1F1C1D1C1D1D1D1D
1D1D1D1E1C1C1D1C1C1C1C1C1C1C1D1C1B1C1C1C1D1B1A1C1B1C1B1B1B1C1C1B1B1B1C1A
1C1A1B1A1B191B1A1B1B1A1A1B1B1A191B1A1A191A1A1A1B1A1A1A18191A1B191B1B1B1A
191B1A1A19191919
1A1A1A1A1A191A1A1B1B1B1B1A191A191A1A1B1A1B1A1B1A1A191B1C1A1A1B1A191A1B1A
1A191A1B1B1A1A1A1A1B1B1B1A1A1B1A1B1B1B1A1A1B1C1A1D1B1C1B1C1C1B1C1B1C1C1B
1C1B1B1C1C1C1C1C1D1D1D1D1D1C1D1E1D1C1D1D1D1D1D1E1E1C1D1D1D1D1D1D1E1D1D1E
1E1E1F1F1F1E1E1F211F1F1F1F1E201E1F1F1F1F1F1F2020202020202120222122232122
212222222322212322222323242323242423232624242525242626262525272528262827
292828292828292A2B2A2A292A2D2C2B2C2C2C2D2E2C2D2F2E2F2F2F3031303130323133
3333333635363536363738383737393A393B3A3B3C3D3C3D3D3E3D3C3F3E3E403F404140
41444243414142424243434342424242434142404140413F403F3F3E3F3E3E3D3C3E3E3C
3E3C3D393B39393A39393837363737373433363435343334353332333130312F31302E2F
2E2D2D2E2C2D2E2C2D2B2A2B2A292B292A2B282728282827272726262626262526252624
252625242426242422232324232324232223222221222222222221212020212021202020
1E20201F1E1F1F1F1F1F1F1F1D201F1E1E1F1E1E1F1E1E1D1D1D1E1E1D1E1E1C1C1E1D1D
1D1D1C1D1C1D1D1D1C1D1B1B1D1B1B1D1C1B1C1C1C1B1B1C1C1B1B1C1B1A1B1C1C1B1B1A
1A1A1B1B1A1B1A1C1B1B1B1A1B1B1A1A1A1A1A191A1A1B1B1A191A1A191A1A1A19191A19
1A1A191B191A1A1A
1A191A1B1A1A1A1A1B1A191A1A1A1B1B1A1A1A1B1A1A1A1A1919191A1B1A1B1B1A1B1A1A
1A1A1B1A1B1A1A1A1B1C1B1A1B1A1B1A1B1B1A1B1A1C1C1B1B1C1B1B1C1C1C1B1C1B1C1D
1C1C1B1C1C1C1D1D1D1C1D1C1D1D1C1C1E1D1D1D1D1D1D1E1E1D1E1D1E1D1C1D1D1D1F1F
1F201F1F1F1F1E1F1F1F201E1F1F1F1F201F1F201F2021211F201F212223202222212321
212221222323222222222323232422242524232524262426272627272625272626262728
272A28272B2928292B2B2A2C2C2C2D2B2C2C2D2D2F2E2D2E2F2E2F312F30313032323332
33333336353635383637383838373A393B393C3B3D3D3C3C3E3E3D3E3F40404141444043
4343444344454541434443454442454243414244424141424141404040403F3D403F3E3E
3D3D3D3A3C3D3B39393939393838373636373735363535353333313332313332312F3030
302E2E2F2D2E2E2D2D2C2B2C2A2A2A29292A292828282828272826272828262526252525
252424242424242424242324232323222222212322222123212221222121212021212121
20202020211F1F1F1F1F1F20201E1F1E1E1F1D211F1D1E1D1F1E1F1E1D1D1D1E1E1D1E1D
1D1D1D1C1D1D1C1D1B1C1C1C1C1B1B1D1C1C1B1C1D1B1D1C1B1C1C1C1B1C1C191B1B1B1D
1B1B1B1C1A1A1B1C1B1B1B1C1A1A1B1B1B1C1A1A1B1B1A1B1B1A1B1B191B1A1A1A191A19
1A1819191A19191A
1A1A1A1A1A1B191A1A181A181A19191A1A1A191B1A1A1B1A1A1B1A1A1A1A1A1B1A181B1B
1B1B1A1C1A1C1B1C1C1B1B1B1A1B1B1C1A1A1B1A1C1B1B1B1B1C1C1C1B1C1B1D1C1C1C1C
1D1C1B1D1B1C1C1C1C1C1D1C1D1E1D1C1C1D1D1D1D1D1D1D1D1D1E1F1D1D1E1E1C1D1D1E
1E1E1E1F1F1F1F1D1F1F1F1E1F1F1F1F1E2020201F20201F202121212121212220212222
212223222123232222232423232324232424242427262428252525252626262628272829
2829292829292B2A2A2A292B2A2B2C2C2D2E2D2D2E2E2F2F2F2F30313031313233333334
3535353536363537373A3839383A3B3B3C3B3C3D3E3C3E3E3F3F3F403F3E424142434444
444545454644444544444445454445444444454443434242424142404240403F40413D3E
3D3E3E3E3C3B3B3A3B3A39393937373837363736363435343433343231323130312F3130
2F2F2E2E2E2D2E2E2D2C2B2B2B292B292B292A2829292928282727282725262625252525
262524252524252424232323242222222322222322232122212122212121202020212021
2020211F20201F1F201F1E1F1F1E1E1F1E1D201F1E1D1E1E1E1E1D1D1E1E1D1E1D1D1D1E
1D1D1C1C1C1D1C1B1D1C1E1B1C1B1C1B1C1B1C1C1C1D1A1D1B1A1A1C1C1B1B1B1C1A1A1A
1A1C1B1B1B1C1B1A1B1A1A1B1B1C1A191A1A1A191A1A1A191A1A1A1A1B1A1A191A1A191A
1A191A19191A1819
1A1A1B1A1B1A19191A1A1A1A1B1B1A1A1B191B1A1B19191A1A1A1A1A1A1B1A1A1A1A1B1A
1A1B1A1C1A1B1C1B1B1C1A1B1B1B1A1B1B1B1C1A1B1B1C1B1D1D1C1C1C1C1C1B1D1C1C1C
1C1C1C1C1D1B1C1C1B1D1D1C1B1C1C1C1C1D1D1D1D1D1E1C1E1E1E1D1D1E1E201D1E1E1E
1F1E1E1F1F1F1F1F1F1F1F1E1F1E20201F1F1F1F2020211F1F2120212021222021222121
212121222322222222232324232422232424252627252625282626262726272726272728
2928282829282A2A2A2B2A2A2B2B2B2E2C2D2D2D2E2E2F2F303030302F31333331323333
343535383636383737393A3B3A3B3B3C3D3D3D3E3E403E40404040414341444342444445
464746474845474444454446454546454547434444444344444241424141404040404040
3E3F3D3E3B3D3D3B3D3B383B3A3A38383736373635353535343333343230323030303130
2F30302E2F2E2D2D2D2B2B2B2D2D2B2B2A29292928292928282727262828272727262425
252524262525252523242322242223232222222222242222212122202021222020212020
2020201F1F201F1E1F1F1E1E1F1F1E1E201E1E1E1E1E1D1E1D1E1D1C1E1D1D1E1C1E1C1D
1E1C1D1C1D1C1D1C1B1D1D1B1B1B1C1B1C1C1D1C1B1B1C1B1B1B1B1B1C1B1C1B1A1A1A1A
1B1A1B1B1B1A1B1C1C1B1B1A1A1B1A1A1B1A1A1A1B1C1A1A1A1A191A1A1A1919191A191A
1A1A1B191A1B191B
1A191A1B1A1A1A1A1A1B1C1B1A1C191A1A1A1A1A1A1A1B1B1A1A1A1B1A1C1B1A1A191A1A
1B1A1A1B1B1B1B1B1B1A1A1B1B1C1B1B1A1B1C1B1A1B1B1C1B1C1C1C1C1C1B1D1D1D1C1C
1C1C1C1C1C1C1C1C1D1C1C1D1C1D1C1E1D1D1E1D1E1D1D1E1D1D1D1E1E1E1E1F1E1F1E1D
1F1F1F1E1F1F1E1E1E1F1E20201E202120211E1F211F1F201F2121212020222222232122
212121212323222222232323232224232625232524262725262525272727272628272928
282728292A292A292A2A2B2B2C2B2D2D2D2E2F2F2E2E2F2F313030303133333333343334
3435353737383737383A383A393B3C3E3E3D3D3E403F3F40414141424042434345464747
474848494848474748474747474546454746464544474645454245444342424242424041
40413E3E3D3D3E3C3C3E3A3A3939383937383636373635343435343433343232322F3031
2F2F2F302E2D2D2F2C2D2C2B2C2B2B2A2C2B292B2B2927282A2828272728262727272826
2625252525242424242424242323232222232424222122232121212121212120211F2020
1F201F1E201F1F1E1F1F1F1F1F1F201F1F1E1E1D1D1F1E1E1E1E1D1E1D1D1C1D1E1E1D1E
1D1C1D1D1D1C1D1C1D1B1C1D1C1D1B1B1C1C1C1B1B1C1B1B1D1C1B1B1C1C1B1A1A1A1B1B
1A1B1A1C1B1C1A1B1B1A1B1C1B1B1B191A1A1B1B1B1A181B1A1A1B181A191B1A1A1C1A1A
1A1A1A1A1A19191A
1B1A1B1A1A1A1A1A191A1A1A1A191B1A1919191B1B1A191A1A1B1B1B1A1A1B1B1B1A1B1A
1B1C1C1B1A1B1A1A1B1B1A1B1B1A1A1B1B1B1A1A1B1A1A1B1B1B1C1C1D1D1C1C1B1C1C1C
1C1D1C1C1C1C1C1D1D1B1C1C1C1C1C1D1C1D1D1E1D1D1E1D1D1D1D1E1F1D1E1E1D1F1D1F
1E1E1F1E1F1F1F201E1F201F201E202020202021201F201F1F2021202220212221222222
232123232222232222232422232322242524242727252625262726252627272628282729
29282928282A2B2C2B2B2A2C2B2D2B2C2E2E2D2F30302F30312F31333132323334343536
353636373839383A3A3A3C3B3C3C3D3E3E3D3E3F42404241414342434444444445464648
49494A49484A48494948494B484849474647494745464746474547454343434343444240
403F3F403E3E3E3D3C3C3B3A3B393A39383837383736353535343434333231323130302F
2F2F302E2F302E2F2D2E2B2C2D2D2C2B2B292A29292B2829292828272827272727262726
252625242524242423242525232323252422232322222221222322222120202021202221
212020211D201F201E1F211E1F1E20201F1F1E1D1E1E1D1C1D1E1D1C1D1D1D1D1E1C1D1C
1C1D1E1C1D1D1D1C1D1C1D1B1B1C1C1E1D1C1C1C1B1C1B1C1A1C1B1B1C1B1B1C1B1C1B1B
1B1B1A1B1B1B1B1C1A1B1A1A1B1B1A191B1A1B1B1B1B1A1A1A1C1A1B1A191A1B1B1A1919
1A1A1919191A1919
1A191A1919191B1A191A1A1B1A1A1A1A1A1A1A1A1A1B1A1A1A191A1B1C1B1A1C1B1A1B1C
1B1B1B1C1B1B1C1B1B1A1A1B1B1B1B1B1B1B1B1C1B1B1C1C1C1B1C1C1D1C1C1C1D1C1C1B
1C1B1C1C1E1C1C1D1C1C1D1C1C1D1C1C1D1D1D1E1E1D1E1D1F1E1E1E1E1E1D1E1D1E1E1F
1E1E201E1E201F1E201F1F20201E1F1E1F201F2020201F20212020201F21212222212122
21222123222322222324232324242324252524242524252626262726262527272726272A
2828282928282A2A2B2A2B2C2C2C2D2C2F2F2E302E2F2F30303131323232333234343535
36363638363839393A3A3C3D3D3C3C3F3E3F3E4141414141434345454546464647494848
4A4B4A4A4A4B49494948494A4B4A4A4A4849494949494747464646474646464443454342
4241403F40403F3E3F3D3C3D3B3D3A393739393838363736363435333332333333313031
303030302E2E2F2E2D2E2C2D2C2C2B2C2B2B292A2A292927292728282727272727272625
262523242525242425252424232324232221222322212321222121222022222120202220
2020201F1F1F1F1F1E1F1E1F1D1E1F1F1F1E1F1F1D1E1D1E1D1E1C1F1E1D1D1C1E1E1D1C
1D1D1F1D1D1C1D1B1C1C1C1C1B1C1C1B1D1B1C1B1B1C1C1C1A1C1B1B1B1C1B1C1C1B1A1C
1B1B1C1C1A1A1B1C1B1B1C191A1A1A191B1A1B191A1A191A1A1A1A1A1A1B18191A1A1919
1A1B181B19181B1A
1919191918181A1919191C191A191A191B1A1A191A1C1B1A1C1A1A1B1A1A1A1A1B1C1B1A
1A1B1B1A1A1B1B1C1B1B1A1B1A1B1C1B1B1A1A1B1C1B1B1C1B1C1C1B1C1C1C1D1D1C1D1C
1B1C1C1C1C1B1C1C1C1C1C1D1D1C1D1D1E1C1C1D1C1D1E1D1E1C1E1D1D1D1D1D1E1E1D1F
1F1D1E1F1F1F1F1E1E20201E1F1F1F201F20201F20212020212120212121222121212222
212221222223232323232224232424242424252524252526262726262626272729272728
282829292B2A2B2B2C2C2A2A2C2B2E2E2E2F2F2D2F2F2F2F313232333334333534353636
36363738393A393939393D3D3E3E3E3D403E414142434344444445454647474947494A49
4A4C4B4C4A4B4C4B4B4A4B4B4C4B4A4A4A4C4B4A4B4A4849484848464745464444434543
424142424041403E3E3F3C3B3D3B3C3A373A383838373638363435353533333233313130
3030302E2E2F2E2F2D2D2C2B2D2C2A2A2A2A2A2A292A2828282928252827272825252625
262626242423242524242225232324242223222322232222222220212121211F1F202021
201F20211E1F1F201F1D1F1F1E1F1F1F1E1E1F1F1E1D1E1E1D1E1D1E1D1D1D1E1C1C1D1C
1D1D1D1D1D1D1D1D1D1D1B1C1C1B1C1C1C1B1C1C1C1B1C1B1C1B1D1B1C1B1C1C1B1B1B1B
1B1A1B1A1A1B1C1A1B1A1A1C1C1B1A1A191A1B1B1A1A1A1B1A191A1A1B1A1A19181A1A19
1B191A1A1A1A191A
1A1919191A191A1A1B1A1B1C1B1A1A191A1A1A1A1C1B1C1B1B1A1B191A1A1A1B1C1A1A1B
1B191B1C1C1B1A1B1B1B1B1D1B1B1C1B1B1C1C1B1C1C1C1C1D1C1C1C1C1D1D1B1C1C1C1C
1B1C1C1C1D1D1C1D1E1C1D1B1C1C1C1D1E1D1D1D1F1D1E1E1D1D1E1D1D1E1F1E1E1E1F1F
1F1E1D201E1E1E1F1F1F1F1F202020201F201F1F1F1F2120222120212120202120222220
24232322222324232323242424242525242524242425262627272626262628282729282A
292A2A2B2A292A2A2C2A2B2C2D2D2E2D2E2E2E2F2F2F312F313032333233333434353535
3638373939393C3D3C3D3D3C3D3F3D414041434143444345474646474648494949494C4B
4C4C4C4B4C4D4C4E4D4C4C4D4C4D4C4B4F4C4D4A4B4A4A4A494948494547484647454345
424244444140403F403F3C3C3F3B3C3B3A39383939373837383736353435343232323232
31302F2F2F302E2D2C2C2C2D2C2C2B2C2B2B2A2A2C282828292827262828262727262726
27262525252524242324242423232123222221212323222022222122212121211F202020
201E1F201F1F1E1F201D1E1F1F201E1F1F1F1F1E1E1E1D1F1E1E1E1E1D1D1D1D1E1E1E1D
1E1D1C1C1B1C1C1D1C1C1B1C1C1D1B1D1D1C1C1C1C1B1B1B1B1A1C1C1B1B1D1B1B1B1C1B
1A1C1B1B1A1B1C1A1A1B1B1B1C1B1A1A1A1B1A1A1B1C1A1C1B191B1A1A1A1B1A1A1A191A
1A1A191A1B1A1919
1A1B191B191A1A1B191A1A1A191A1A1A191A1B1A191B1B1A1B1B1A1A1B1B1A1B1B1A1C1A
1A1C1B191B1B1B1B1B1B1B1B1B1C1C1B1A1C1B1D1B1B1C1C1C1C1D1C1C1D1D1D1B1C1C1C
1B1B1D1B1C1C1C1C1D1D1D1C1D1C1C1B1D1F1D1C1F1D1D1E1E1D1E1E1D1E1E1E1E1F1F1E
1E1E1E1E1E1F1F1F1F1D202021211F202020211F20201F21212022222121212221222022
212322232323232222232424242323262324242525262525262726272726272829282829
28282A292A2A2B2B2C2C2C2C2C2D2E2F2E2E2E302F312F30323232333234353534363536
38383739393B3B3B3B3D3D3E3D40404143424342454445464748494847494A4A4B4B4E4E
4F4F4F504E514E4E4E4D504F504E4E4D4E4E4D4C4B4B4C4B4B494B494947484846464546
45454342414142413F3D3F3F3C3C3D3C3B3B393939373838363735353434333234323231
3031303130302E2D2E2E2E2C2A2B2C2C2B2C2B2A292A2928292A29282827272726272526
27262525262423232424222423232422242223232222232122212121212321201F212220
20201F1E1F1F1F201D1E1E201E1F1F1F1E1E1F1F1E1D1E1E1F1F1D1E1E1E1D1D1E1D1D1E
1D1C1D1D1D1C1C1C1C1C1C1C1C1C1B1B1C1C1B1C1B1D1B1C1D1B1B1B1A1A1B1B1A1B1B1A
1B1B1B1B1C1A1B1B1A1C1B1A1B1A1A1A1B1A1A1A1A1A1B1B1A1B1B19191A1A1A1A1A1A1A
19191A191A191A1A
1A1B1B1A1A191B1B1A1A1B1B1B191A1A1A191B1A1A1B1A1B1A1A1A1B19191A1B1C1B1C1B
1B1B1A1A1C1A1B1A1B1B1B1A1A1C1B1A1A1C1B1C1A1C1C1D1C1D1D1D1C1D1C1D1C1D1C1D
1D1C1C1C1D1D1C1D1D1D1C1C1B1B1D1B1D1D1D1D1D1E1F1E1E1F1E1E1F1F1D1E1E1F1E1F
1F1E1E1F1D1F1E1F1F1F201F20201F1F1F201F201F201F21212022212221222320222223
202222232222232524232324232524242424242525252526262825262526272828282829
2829292B2A2A2B2B2B2C2C2B2D2C2E2D302F2F2E31313131323331333534353736363738
3739393A3A3B3B3E3D3D3E3E3F404141414242444645474747494A49494B494C4C4D4F4E
504F5151505052514F515050504F5050504E4F504F4F4E4A4C4C4B4B4A4A494946464746
4746474544434340423F3D3D3D3D3C3C3B3A3B393A393937373636363536343432333232
32313031302F2E2E2E2D2E2D2E2C2B2C2B2C2B2B2A292A292A2928282726262626262627
27252526252424262523242423232323232223242321232121212222212120211F221F1F
201F201F1F1F1F1E1F1E1E1F1E1D1F1F1E1E1F1F201F1E1E1E1D1E1E1D1F1D1D1E1D1D1D
1E1D1D1D1C1D1C1D1B1C1C1B1C1C1B1E1C1D1C1C1C1B1C1B1D1B1C1C1B1B1C1D1A1B191C
1A1C1A1A1B1B1B1A1C1A1A1B1A1B19191A1B191A1B1C1A1B1A1A1A1A1A1A1A1A1B1B191A
191A1A1A191A1A1A
1A1A1A1918191A1A1A1A1B1A1B191B191A1A1A1A1B1B1A1A191B1B1A1B1B1A1B1B1B1A1A
1C1A1B1A1A1B1C1C1A1B1A1B1A1A1B1B1B1A1C191B1C1C1C1D1D1E1C1C1B1D1C1A1C1D1D
1C1C1C1C1C1B1C1B1C1D1B1D1C1C1E1D1D1D1C1C1D1D1D1E1E1D1E1F1E1E1E1D1F1E1E1F
1E201E1F1E1E1F201E1E1F1F1F1F1F1F2020202120212022202120222122202321222122
212322212324232424232424252525252425252324242526262626262828282728272929
2A29282B2B2B2B2C2B2B2D2E2C2E2F2E2F2F302F30323131313233333436363736363638
3A383B3B3B3C3C3D3D403E404140424443434445454547494B494A4B4B4B4D4E4D4F4F50
515150505050535252504F515251515151515050514E4E51504F4C4D4B4B4B4A4A484747
46474547454343424141413F3E3F3E3D3B3C3A3A3A373838373737363534353433343333
31302F3030302F2E2F2E2E2E2D2D2C2C2B2C2C2A2A292A28282829292827272828292626
252525252624242424242324232323232424222124222122222322212121201F1F202021
21201F2020201F1F1E1F1F1F1F1F1F1D1F1E1F1E1F201D1E1F1F1E1E1E1E1F1D1D1D1D1C
1E1D1C1C1D1C1C1C1D1D1D1D1C1C1C1C1C1C1C1C1C1C1C1C1B1C1B191B1B191A1B1C1C1B
1B1B1A1C1C1B1B1A1A1A1A1B1A1C1A1A1A1A1A1B191A1A1A1A1A1A1B1A1A1A1B1A1A1A1A
1A1A191A191A191A
1B1A19191B1A191A1A18181B1A1A19191A1B191B1A191A1B1B1A1A1A1A1A1B1B1B1B1B1C
1A1A1B1B1B1C1B1C1C1D1C1C1B1C1A1A1B1B1C1B1C1C1D1C1E1B1D1D1C1B1C1C1C1D1C1C
1C1D1C1D1D1D1C1C1E1C1D1D1B1B1D1D1D1D1C1C1D1D1D1D1D1E1C1D1F1D1E201F1F1D1F
1E1E1E1F1E1F1F1E201F1F2021211F201F212021201F2121202121202120212222222222
23232223232323232324252424242524252626252526262626272627262827292827282A
292A2A2A292C2C2C2D2E2D2D2D2D2E2D302F303130303132333334343536363737383739
3A3B3B3B3A3B3D3D3E3F3F40414342444145444547464A484A4C4A4C4D4F4E504F505052
5153505352525453545552555454545452535455515251504F4F504E4E4C4C4A494A4A48
4A47474746454544414242403F3D3D3F3D3C3B3B3A3A3B38363736353537363534323332
2F3031303030302E2F2E2D2E2D2D2D2C2B2A2A2B2A2A2A2B2A2828272827282827262727
242627252524252424232323232224242321222321222322222221232120212120212020
20212020201F1E201E201F1E1F1E1D1E1F1E1F1D1E1D1F1E1F1D1E1D1D1D1D1D1F1D1D1C
1E1D1C1C1D1D1D1E1D1D1C1C1D1D1D1C1C1C1C1B1C1B1C1A1C1C1C1B1A1A1B1A1B1C1B1B
1B1A1A1B1B1B1B1A1C1A1B1C1B1B1A1B1A1C1B1B1A191B1A1B1A1B1C1B1B1A1B19191A1B
1A1A1A191A191919
1A191A191A1A1B1A1B1A1A1A1A1A1A191A1B1A1A19191C1C1A1A191A1A1B1C1A1B1B1B1B
1C1B1B1B1B1C1B1C1A1C1B1C1C1B1C1B1C1C1D1C1C1C1C1D1E1E1E1C1C1D1B1C1C1C1C1C
1D1D1C1D1C1C1C1D1E1D1B1C1D1D1B1B1E1E1E1C1D1E1D1D1E1E1D1D1E1E1E1E1F1E2020
1E1F1F1E1E1F1F1E1E1F1F1F1F1F1F1F2020201F1F20211F202122212022212122222123
232322232224232424242423242525262425242524252527252627272927292828292929
282A292A2B2B2B2B2D2C2C2C2D2F2E2E2F2F2F302F32333432333434363636373737393A
3A3B3C3C3C3E3E3F403F3F40414342444546464B4948494A4D4D4C4C4F504F5051535254
535353555454545756555655555654575654545555535351535150504F4F4E4C4D4C4B4A
4B494849494647454443424241403F3F3D3C3B3B3A393938383637373735343434343433
32313231312F2F30302F2E2F2D2D2D2C2C2A2B2B2A292B29282A27282828282728262726
252626272426252523242423252423232323222223222322222322222220212020202121
202121201E20211F201F1E1F1F1F1E1F1F1D1E1F1E1F1E1E1E1E1E1E1D1F1C1D1E1D1D1E
1D1D1D1E1C1D1C1C1C1D1C1C1C1C1D1C1C1D1C1C1C1C1C1B1B1C1A1C1B1B1C1B1C1B1B1B
1B1B1C1B1B1A1B1B1A1B1A1A1B1C1B1B1A1A1A1B1A1A1A1A1A1B191A1A1B1A1B191A1B1A
1A19191A1A1A1A19
1A1A1A1A1A1B1A1B1A191A1A191B1A1A191A1A1A1A1B1A1B1A1A1A1B1A1A1A1B1B1A1B1B
1B1B1B1A1B191B1A1B1C1B1C1B1C1C1C1A1B1C1A1A1C1D1C1C1E1E1C1C1C1C1D1D1C1B1C
1D1B1D1C1C1C1D1D1E1C1D1C1C1D1D1D1C1E1C1E1D1D1D1D1D1D1F1E1E1E1E1E1F1D1E1F
1F1E201E1E1F201E1E1E1F1F1F1F1F212020201F20212021212322212221222221222122
22212123232224242324232425232325262525262625272728282729292828292829292A
2A2A2A2A2A2C2C2B2D2F2E2E2E2E2E2F303030313031323233313436363637393939393A
3A3C3B3B3D3D3F3E413F3F4244434545454849474C4C4E4C4D4E4F4F5050525052545455
55555855585755575857575A56575858565657565756545452525252524F504E4E4C4B4C
4A4A494A494946444444434140413F3E403E3D3B3C3C3A39393839383636363635333432
33323131313131302F2D2F2E2E2D2D2C2A2C2B2C292A2A292B2829282826282727272626
262626252525252424262325232423232323242123242223222221222021211F22221F21
2021201F2020201F1E1F1F1E1F1F1F1F1D1E1D1E1E1E1E1E1E1E1E1E1D1C1E1F1D1D1D1E
1F1D1D1D1C1D1C1E1E1C1D1D1C1D1E1C1C1D1C1E1C1C1B1B1B1C1B1C1B1B1B1B1C1B1C1B
1B1B1B1B1B1A1B1A1A1A1B1B1A1C1A1A1A1B1A1B1A1A191A1A1A1919191B1B1A1A1A1A19
1A191B1A1A19191A
1A1A1A1A1A1A1A191A1A1A1A1B1A191A1B1B1B191B1C1A1B1A191A1A1B1A1B1B1A1B1B1A
1A1A1A1A191B1C1C1A1C1B1A1C1B1B1C1B1B1C1A1C1B1B1C1B1C1C1B1D1B1C1D1C1B1D1C
1B1C1C1C1D1C1D1D1C1C1D1D1C1E1D1D1C1E1E1E1D1D1E1F1E1D1E1F1D1E1E1E1F1E1F1F
1E201F1E1F1E1F1E1F1F1F1F201F201F1F1F202020202121212121222121212122232222
232223232323242424242523242424252625262525252726252727282828272928272A29
2A2A292B2C2B2C2E2C2D2D2C2F2F2F2F2F3131303332343432333435353537383839393A
3A3C3D3E3D3D3E414141424443464548474A4A4A4B4C4C4D4D5050505252545652555654
58575859585A5A5B5A595B5A59595B5B5B5855565658565655555552525351504F4D4E4D
4C4A4B4948474846474543424141413F403F3E3C3C3C3A3B393937383736373535363333
3331333233312F312F2E2D2D2D2E2D2E2C2C2B2B2A292A2A292B28282828292728272625
262625242524242523262526242422232423232223242323212021212221202221201F21
2020212020201F20201F1E201E1F1F1E1E1E1E1F1E1E1E1E1E1F1D1D1E1D1D1E1F1E1E1C
1D1C1B1D1D1D1D1C1C1D1B1D1D1C1B1D1B1C1C1C1C1C1B1D1B1B1A1C1B1C1A1C1A1B1A1A
1C1A1A1B1B1C1C1B1B1B1C1A1B1B1B1A1A1A1A1C1A191A1B191A1A1A1B1B1B191B191A1B
1A1919191A1A1919
19191A1B1A191A1A1A1B1B1B19191A1A1B1B1B1B1B191A1B1A1A1B1B1A1A1B1A1B1A1B1C
1B191B1B1B1B1B1B1B1B1C1B1B1B1C1B1C1C1B1C1B1C1B1B1D1C1C1C1C1D1C1B1E1D1C1D
1D1C1D1C1D1D1E1C1C1D1B1C1C1E1E1D1E1D1D1D1F1E1D1D1D1F1E1E1D1E1E1D1D1E1E1E
1F201F201F1E1F1F201F1F1E1F2020212121202020202021212121202222222121222323
222223222323232425242425242326252626242526252627252627272728292929292A2A
2A2A292B2D2A2D2D2C2E2D2E2F2E2F3030303131313233343435373536343737383A393C
3C3D3E3F3E3F40404243424445464648494A4A4C4D4E4E51515051505253555657585759
59595A5A5A5C595D5C5D5D5C5C5C5D5A5B5A5A5B5A58585755555856535352524E504F4F
4E4B494B484A4947484545454443413F3F3F3E3D3D3D3B3A3C3A3A383738373736343533
3232323232312F2F2F2E2F2E2D2C2D2D2E2D2A2A2A2B2A2A2B2829272829282727272826
262725252426252525252423242325232323232323222223222322212121202121212021
2020221F202020211F1F1E1E201F1F1E1D1F1F1E1E1D1F1C1F1C1E1D1D1D1D1D1F1D1E1E
1D1C1D1C1D1D1C1E1E1E1E1D1C1C1B1C1C1C1D1C1C1C1B1B1C1B1C1C1B1D1B1C1A1A1C1C
1C1B1B1A1A1B1B1B1B1A1A1A1A1B1A1A1A1A1A1B1B1A1B1A1B1A1A1A1A1A1A191A1A1A1A
1A1A1A191A1A1A19
1A1A191A1A1B1A191A1A1A1B1A19191B1A1A1A1A1A1B1C1B1A1A1A1B1B1B1B1B1B1A1B1A
1B1C1A1C1B1C1B1B1B1C1C1C1B1B1B1C1B1B1C1B1C1B1C1D1B1C1C1D1B1A1C1C1C1D1D1C
1D1C1D1C1E1B1B1D1D1D1D1D1C1D1C1D1E1E1D1F1D1D1E1D1F1D1E1D1E1D1E1F1E1D1E1F
1E1E1D1E1E1E1F1F201E1E1F20201F2020202021211F2121202022222121212323222323
23222322212322242424262526242625252625252626262627272728262929292A292929
2A29292B2C2C2D2F2C2D2F2F2F2E2F3031313132323234333333343636353938393A3B3B
3D3D3D3F3F404041424342434648474948494C4C504E504F525154565555575858595C59
5E5B5C5C5F5C5C605F5F5D5D605F5D5D5E5E5D5B5C5B5C585A5A5758565855545252524F
4F4E4C4B4B4B47474845454543424241423F3F3E3D3F3C3C3B3A39383937363734333434
333333313130312F2F2E2E2F2F2C2D2C2D2D2C2B2B29292B2C2A2A2A2928282727272727
262626262525272525252525242323252323232323222323212322202222201F21212120
202020202120201F201E1F1E1F1E1F1E1E1E1F1E1F1F1E1E1E1E1E1D1D1C1D1E1D1D1D1E
1D1D1D1D1D1E1D1D1E1D1D1D1C1D1C1C1C1C1C1C1C1B1C1C1B1C1C1D1C1B1D1C1B1C1B1B
1B1B1B1C1B1B1A1B1B1A1B1A1A1B1B1A1A1A1A1B1A1B1A1A1A191A1A1A1B181A1A1A1A19
1A191B1A19191819
1A1A19191A1A18191A1B1B1A1A1A1A1B1B1B1B1A1A1A1A1A1A1C1B1A1B1A1A1A1B1C1A1B
1A1A1A1B1C1B1B1B1A1C1B1B1C1B1B1B1B1C1C1B1A1C1B1C1B1A1B1B1C1C1B1B1C1C1C1D
1C1B1C1E1C1D1D1B1C1C1C1C1D1C1F1E1D1C1E1E1D1D1E1E1E1D1F1E1E1E1D1F1E1E1F1E
1E1F1E1D1E1E1E1F1F1F1E1F211F201F2120212120212021212121222022222222232223
232323232225232424252425252625252524252625262727272728282727282729292A29
2A2B2C2A2C2B2D2C2D2D2E2F2E303031313032333132333334353637373738393A3C3C3D
3C3F3E3F3F404242434545464746494A4C4C4D4E51514F5354525456565857595A5B5C5C
5E5F5F616062616263616261626061615F60605F5E5D5D5E5B5B59595855555254525351
50504E4D4C4B4A4B494846474544434141413F3D3F3D3D3C3B3B39383837363734353436
3334323231313130302F2F2E2E2D2E2C2C2C2B2B2C2D2A2B2A2B28292729282728272727
272626252425252426252524242423232424242123232322232322212120212223202121
21202021202120201F1F1F1F1F1F1E1E1E1E1E1F1E1E1E1D1D1C1D1D1E1E1E1E1D1E1E1E
1D1D1C1D1D1D1D1C1E1D1D1C1C1C1C1C1C1C1D1B1B1D1C1B1B1B1C1D1C1B1C1B1D1B1B1B
1B1B1B1A1B1B1C1B1B1B1B1B1B1D1A1C1B1A1A1B1A1A1B191A1B1A1A1B1A1A191A1A1A19
191B1B191A1A1A18
1B1919191B19191B1B1B1A1A19191B1A1A1B1B1A1A1A1A1B1A1A1B1B1A1A1B1A1A1B1B1B
1B1A1A1C1B1C1A1B191C1B1C1C1B1C1B1B1A1C1C1C1C1B1B1C1D1B1C1D1C1C1C1D1D1B1C
1C1D1D1C1D1E1C1D1B1B1D1B1C1D1D1D1E1D1D1E1E1E1E1D1E1D1E1E1D1E1E1E1F1F1F1E
1E1F1E1F1F1F20201F1F1F201F20201F2020212021212022222120222222212221222223
232323232223232426242423242326252425262626252627272728272627292829292929
2B2A2A2B2C2C2C2D2C2E2F2E302F3130313132313333333434353737383939393B3B3D3C
3F3E404041414342444645484948494A4C4D4D505253535455575657595A595A5A5D5E5F
5E606162656464626463636465646663626363636260605F5F5F5C5C5A5B565756545252
535050504D4C4A4A4848474644444540414141403F3E3E3D3D3C3A3A3A38373735373536
343232323032303130302F2F2E2D2E2D2E2D2C2B2B2C2C2B2A2A2B282828272826272726
262627252525252624252422242224242423232423232322212223221F20212220222121
221F20201F201F1F201F20201E1E1E1E1D1E1E1D1E1E1F1E1E1C1D1D1D1C1E1E1D1E1D1E
1D1E1D1D1E1D1D1C1D1D1D1D1D1D1C1D1C1C1D1C1C1B1B1C1C1C1C1C1B1A1B1B1B1B1B1B
1B1C1C1C1B1B1C1B1B1B1B1B1B1A1B1A1A1B1B1B1B1B1A1A191B1A1A1A1A1A1A19191B1A
1A1A1919191A1919
1A1B1A191A1A1A1A1B191A1A1B1A1A1B1A1B1B191A1B1B1A1B1B1A1A1A1A1B1A1A1A1B1B
1C1A1B1B1A1B1A1B1A1B1A1A1C1A1D1D1C1B1B1D1B1C1B1C1B1B1B1A1B1C1C1C1D1C1C1C
1C1C1D1E1D1D1C1D1C1C1C1D1C1D1D1D1E1D1C1D1E1E1F1E1E1E1F1E1F1E1F1F1F1E1F1F
1F1E1F201E1F201E1F201E1E201F20221F20202120212121212121212122212122222324
2423232323232323242325242525252525262426252627272727272927272A28282A2B2B
2B2A2C2B2C2D2C2D2D2E2D2F302F31313232323333343535353437373738393A3B3B3C3E
40463F413F43434446474745474A4B4A4C50515153535556565958575D5C5D5E5F605F60
626463646669666866696467676866656665646565626260605F5D5E5F5D585859555755
53524F504E4F4B4C4A49494744454545424141413E3F3C3E3D3C3B393B37383737363634
33343333323030313131312F2E2D2D2C2D2C2C2C2B2D2A2A2B292A292928292829272625
26262525272525262524252524242423232422242322222122222221222220212221211F
212020211F201F211F1F201D201E1E1E1E1F201F1E1D1E1D1D1D1D1E1E1D1D1D1C1C1D1C
1C1D1C1C1E1D1C1C1D1C1D1E1C1B1D1C1C1C1D1D1C1C1D1B1C1C1C1C1B1C1B1B1C1C1C1C
1C1A1C1A1B1A1B1B1B1C1B1B1B1A1A1B1B1B1A1A1B1A1A1A1A1A1A1A19191A1A1A1A181A
1A1A191A191A1A19
1A191B1B1B1B1A1B1A1A1C191A1A1B1B1A1B1B191B1A1A1A1B1B191A1A1B1A1B1A1B1B1B
1A1B1B1B1B1A1B1B1B1B1B1C1B1C1C1C1C1B1B1C1B1B1C1B1B1A1A1C1D1C1C1D1C1B1C1C
1D1C1B1C1C1D1C1C1C1E1D1D1E1E1E1C1F1E1F1D1E1E1D1E1E1E1E1D1E1E1F1E1E1F1E1F
1F1E1D1F201F1F1E21201F1E202021201F1F1F21201F2221202022212221212223222323
2323242223242424232425242526262525252425252527272927282927282828292A2A29
2B2A2A2C2D2D2C2D2D2D2F2F30313132313133333333353435363737373A3A3A3A3B3D3D
3E4241414243454445494947494A4E4D4E5053525454565857595C5B5D5E606062616364
67666968696B69686A6868676A6B69676867676666646363625F61615F5C5A5B5B585755
54535353504E4E4D4B4B49474646464443434140403F403E3C3A3B3C3A39363837373534
3435323333323031302F30302F2F2E2D2E2D2B2C2C2C2B2B2A2B29292A28282828292628
252727252625262526252524252422232324232223232322212222222021212021212121
20211F202121201E1F1F1F201F1E1F1F1F1E1D1D1D1E1F1E1D1D1E1E1D1D1D1E1D1D1D1C
1D1D1D1C1D1D1D1C1D1D1C1C1E1C1B1C1C1B1C1D1C1C1C1C1C1B1D1C1A1B1C1B1B1B1B1B
1B1B1B1C1D1C1A1B1B1A1B1A1B1B1A1B1A1A1A1A1A1A191B1A1C1B1A191B1A1B1A1A1A1A
1A1A1C1A191A1A1A
1A1A1A191A1A1B1B1A1A1B1B1A1C1B1B1B191A1B1A1B1A1A1B1A1A1B1B1B1B1A1B1B1B1B
1B1B1B1C1B1C1A1C1C1B1B1C1C1B1B1A1D1C1C1C1A1B1B1B1B1C1B1B1C1D1B1C1C1B1D1D
1D1D1B1D1D1C1E1C1E1C1C1D1E1D1D1D1D1E1E1E1E1E1E1E1E1E1E1E1F1E1E1E201E1F1E
1E1E1F1E1F1F201E1E20201F201E1E202020202022212222202221222323232321232323
2323232524232524232424252525252425272527272627272727282929282829292B2C2A
2B2A2D2D2C2C2D2D2D2D2F2F3131313131303334333336363536373839383B3D3C3D3E3E
40404142434446454749484A4B4D4D4F50505255555658595B5C5E5E5F62626163646867
686A696B6D6D6C6F6C6E6D6D706B6B6B6B6B6C696968676566626361605E5F5C5B5A5A58
5857545452504E4D4C4C4B484848454544444341413F3E3E3E3C3B3C3B39383637383535
353434343232323130302E302F2E2F2C2D2C2C2B2C2C2B2A2B2B2A282929282A29272927
272627262526262625242425242523232325232323232222212323222221202022212021
222021201F2121201F1E201F201F1F1F1E201E1E1F1E1E1D1D1D1D1D1C1E1D1C1D1D1C1C
1C1E1C1E1C1B1E1D1D1D1D1C1C1D1C1C1D1D1D1D1C1E1C1C1D1B1C1B1B1C1B1C1B1B1B1B
1B1B1B1B1B1A1B1B1A1C1B1A1B1A1A1B1A1A1A1A1C1B1A1A1A1A1A1A191A19191919191B
1A191B1918191819
1A1A1B1A1A1A1B1A1B1A1A1B1B191A1A191B1A1B1B1A1A1B1A1B1B1B1B1A1A1A1A1B1B1A
1B1A1C1A1C1B191B1C1B1A1B1B1B1B1B1B1C1A1C1A1C1C1B1C1B1C1C1C1B1C1C1D1B1C1D
1C1B1D1D1C1B1D1D1D1D1D1C1D1D1D1E1D1D1E1D1E1D1E1E1E1D1E1E1D1D1E1F1F1F1F1E
1F201F20201F1F20201F1F2020201F1F2021202021212021222120222122212222232122
222324242423242524242424252524262627262626272729282828292928292B2A29292B
292B2B2C2C2D2D2E2D2D302F2F31323232323332343535363536383B393A3C3C3D3E3E3F
3F4042424347464647484A4A4C4D4F505054555457585A5A5B5C5D5F6162646566696A69
6C6D6D6F6F716D6F7070717072716E6F6F6F706C6D6A6A67686664656261605F5C5C5B5C
58565554525252504E4A4C4B4B4946464645424341413F3E3E3D3C3B3C3C3A3A37373636
353533333233303131303130302F302F2C2C2C2D2C2B2B2A2C2B2C2A2A29292928292828
272526262525262625242623252524252423222323222321222020222121212121212021
2122212021201F1F1F201F2020201E1E1F1E1E1F1D1D1F1E1E1E1E1E1C1D1D1D1E1D1D1C
1D1C1D1D1B1B1C1D1C1C1C1D1D1D1D1C1C1C1D1D1C1D1D1D1C1C1C1B1B1B1B1C1A1B1B1C
1B1B1B1B1B1B1C1B1C1B1A1B1B1B1A1A1A1B1B1B1A1B1A1A1A1B1A1B1B1C1A1A1A1A191A
1A1A1A1A1A1A1919
1A1919191A1B1A1A1A1A1A1A1A1B1A1B1B1A1A1A1A1B1A1B1A1B1B1B19191B1C1C1B1B1C
1B1B1B1B1B1B1B1B1B1B1B1C1A1C1B1C1C1D1C1B1B1C1B1C1A1C1B1C1B1D1E1B1D1C1C1C
1C1D1D1C1C1D1C1D1C1D1D1D1D1E1D1D1D1D1E1C1E1E1E1E1D1D201D1E1F1F1F1F1F1F1E
1F1F1E1E1E201E201F201F1F2020211F2122202121202221212222212222222322232323
2223232323242325252524252424252526252626262727282826292928292929292A292A
2B2C2B2B2C2D2D2D2C2E30312F2F3031323232323435353538383A393A3C3D3D3E3D3E41
414042454444454748494A4D4E4E5051535557565959595A5F5F5F5F63666769696C6C6A
6E6F6F70707074747473747474737273737473706D6E6C6B69676668656561615F5D5D59
5A5956545354524F514E4C4C494A4947464646434142413F3F3F3C3D3B3B3A3938383736
3636343332333330302E2F302F2E2D2F2C2F2C2E2A2B2B2B2A29292B2828292828282828
272725262625262727242426252323242324232423232222242221212021212121232121
20212121201F202021201F1F1F201F1F1F1E1E1E1E1D1E1D1E1D1C1D1F1C1D1C1E1E1C1D
1B1D1D1D1D1C1C1E1C1C1D1D1D1C1A1D1C1B1C1D1D1C1C1C1C1C1B1D1B1B1D1C1C1B1B1B
1B1A1B1B1C1B1B1A1B1A1A1C1B1B1B1C1A1B1C1A1A1B1B1B1A1A1B1A1A1A19191A1B1919
1A1A18191A1A1819
191A191B1A19191B1A1B1B1B1B1A1B1A1A1B1A1B1A1A1A1A1B1A1A1A1B1B1B1C1B1C1A1A
1B1B1B1B1B1B1C1B1B1B1B1C1C1A1C1A1C1B1C1B1B1C1B1C1C1C1B1C1D1D1B1C1D1D1D1C
1B1C1C1D1C1D1C1E1C1D1C1D1D1D1C1C1E1E1E1E1D1E201E1E1E1E1E1F1F1E1E1E1F1F1E
1E1F1F20201E2020201F1F1F2020201F2021202021212120222222202221212120222223
2423242425252324252525262525252526262627282727282827282928292929292A2B2A
2C2C2C2C2C2D2D2D2D2F302E30313133303234333636383538383A3A3A3B3C3F3D3D3E3F
4240424144474849494C4C4E4E4F515554555857575B5D5F62626466646A6A6A6D706F70
70727275757577787878787976767678767574717172706F6D6A6B6667686463625F5C5C
5C5A585854545351514D4C4B4A4B4947464645444441403F3E3E3D3C3A3A39393B393836
363534323331313231302F302E2E2F2F2B2D2C2C2B2B2B292B2A2A2A2928292727282727
262626262526262626252524252224232324242422222223222322212221222221212220
21212120201E1F1F1F2020201F20201E1F1E1F1E1E1E1D1E1E1F1E1D1C1E1D1E1E1E1D1C
1D1D1C1E1D1D1C1C1C1C1D1C1B1C1C1D1C1C1B1C1D1E1D1D1C1B1B1C1D1B1C1C1B1B1B1B
1C191A1B1B1B1B191C1B1C1B1A1A1A1B1A191A1A1B1A191B1B1B1B1B1A1A191B1A1A1A1B
19191A19191B1919
1A1A1A1A191A1A1A1A191B1B1B1B191A1A1B1A1B1B1A1A1B1A1A1A1B1A1A1B1B1C1B1B1B
1A1B1B1A1A1B1B1A1C1B1B1C1B1B1C1C1B1B1C1B1B1B1B1B1B1D1C1C1B1D1D1C1D1C1C1D
1D1C1D1C1C1E1E1E1D1D1C1F1C1C1D1D1D1E1D1E1D1E1E1E1F1D1D1E1F1F1F1F1E1F1E1F
1E1F20201F201F1E201E2020212022202021212021202220202220222223222121232223
2223242423232325252525252526262627262527272626282728282928292A2A2A2A2A2B
2B2C2D2C2D2D2E2F2F2F2F30302F313332313435353435373839383C3C3C3C3C3E3E3F40
424342434747484A4A4B4D4D4F5150545458585A5D5E615F62646567686A6D6D6D727275
757576797B7B797C7A7A7C7E7C7C7B7A7A78777575747070716E6E6A6A6667636361605E
5B5A5A575755545150504D4C4C4B4B4847464443414143403F3E3C3D3A3A3A3939383836
3535363334323231303130302F2D2E2D2D2D2C2C2F2B2C2C2B2A2B282728272628282827
262627272625262427262526242424232324242524222223212221222222222221222021
211F20202020201F1F21201F1F1E1E1E1E1F1F1D1E1E1E1D1E1F1D1E1D1E1D1E1D1E1D1D
1C1D1D1F1C1C1D1D1D1C1B1C1D1D1D1B1C1C1C1B1E1D1C1D1C1C1C1C1C1C1C1B1B1B1B1B
1B1A1B1A1A1A1A1A1A1A1A1B1B1B1C1B1B1B1B1A1B1A1A1C1C1B1B1B1A1A1B191A1B1B1B
1A1B1A1A1A19191A
1A1A1A19191B1A1A1B1C19191B1A1B1A1B1B1B1A191A1A1B1C1A1C1A1B1A191B1B1A1C1B
1A1C1B1B1C1B1A1C1B1B1B1B1B1A1C1C1B1D1B1C1B1B1B1A1B1B1C1C1C1B1C1D1C1D1D1D
1D1C1B1D1D1B1D1C1D1E1E1D1E1C1E1E1C1C1C1E1E1E1D1F1C1F1F1F1E1D1E1E1F1E1F1F
1E1F1F20201F1F1F201E201F1F2020202021212020202121202222212222222322232323
23222423242524242625242626262624242526262628282827282829272A2928292A2B2A
2B2B2C2E2C2D2E2F2F2E302F313030323335343533373538373A393C3B3D3D3E3F3F3F42
4143434647484A4A4B4C4E4F50505455585A5A5B5D5E6163646767696C6B6E7071737678
787A7B7B7E7D7D7E7E8180817D7E7F7E7C7C7C797876767474716E6C6A6A696867646561
5C5B5D5B5856545351544F4F4D4B49474846464542424340403F3D3D3C3B3A3839373737
3636363436323230313030302F302F2D2D2D2C2A2C2B2C2B2C2A2A292829292928262827
262627272626262525262426242424232323242324222123232222222322212122212121
2021212121201F201F201F1F1F201F1F1E1E1E1E1E1E1E1D1E1D1E1D1D1E1E1D1E1D1D1E
1D1F1E1F1D1C1C1C1C1D1C1C1C1C1B1B1D1C1C1C1C1D1E1C1D1C1B1B1B1C1B1C1B1A1B1A
1A1B1B1B1B1B1B1B1B1A1B1B1A1A1C1B1A1B1A1B1B1B1C1C1A1C1A1A1A1A1B1C1A1A1B1A
1819191919191A1A
1A1B1B1B1A1B1B1A1A1C19191B1A1A1A191A1A1B1B1B1A1B1A191B1A1B1A1A1A1B1B1C1C
1B1B1A1C1A1A1B1A1B1C1A1C1B1B1C1B1D1B1C1D1B1C1B1B1C1A1D1B1C1C1C1C1C1C1E1C
1C1C1D1C1E1C1B1E1E1E1C1D1D1E1D1D1E1D1D1D1D1D1D1F1E1D1E1F1D1E1D201E1F1F1F
1E1E1F1F1F1F1F211F1F1F20202120202120212121202223212221212221212223222324
222224242524242424242426262526252427262628272828282828292829292A2B2B2C2B
2B2B2D2D2E2F2E2E3030302F303130333232333536383838373B3B3A3C3D3E3E3F413F42
4343454748464A4A4B4F505350535454585B5D606060626668696B6B6C71727375757879
7A7E7E7E80818282838283848385828082807F7F7B7C7B77767374716F6D6B6967656462
605C5D5C5C585753535450504D4C4C494A484744434341413E3F3F3D3C3B3D3939393738
3736353435343333322F312F2F2E2F2D2E2D2D2C2C2C2D2B292B292B2828292929282828
282626262425262625272525252424242324242323242323212322212321222221222120
21202120211F211F201F201F1F1E1F1E1F1F201E1E1E1E1D1F1D1D1D1D1D1E1D1D1C1D1D
1E1D1C1D1C1B1D1C1D1C1D1D1C1D1D1D1B1C1B1D1D47371D1C1D1C1A1A1C1C1C1B1B1B1C
1A1A1C1B1B1B1A1A1B19191B1B1A1C1B1A1A1B1A1B1B1B1A1C1B1B1A1A19191B1A1A1A19
1B1A1A191A1A1B19
1A1A1A1A1B1B1B1A1B1A1B1B1B1B191A1B1A1B191A1A1B1A1A1A1A1B1A1B1A1B1A1B1C1B
1B1C1C1B1A1B1C1C1B1B1C1C1B1C1B1A1C1C1B1C1A1C1C1B1B1C1B1C1C1B1D1C1C1C1C1C
1C1C1C1D1D1D1D1C1C1D1E1C1D1E1E1D1E1E1D1E1F1E1E1F1E1E1E1F1F1F1F1F1E1F201F
201E1E1E1F1F1F1F1F1F211F1F1F21202020202220222022212122202223222323222223
222324232426242525252525252626252626262627272828292928292A2929292B2A2C2C
2C292D2D2E2E2D2E2D2E2F3230313033313534343438363838393B3D3D3D3D3E403F4043
4544454648494B4D4C4E52535354575A5A5A5D5D60626567676B6D6E72717375767B7B7D
7E7E8483858787888787898888898784858383827E7E7C7C7977747371716D6C696A6665
645F5F5F5D595754555453504D4D4B4C4948484645444241413E3E3E3E3B3C3A39383938
39363535343434323130302F30302F2E2F2E2D2B2D2C2C2A2A2A2B292A29292A27292627
272827262725272525252425262325242524232322222322232222212122212222222021
221F2020202021201E201F211F201F1E1E1E1F1F1D1E1F1D1E1E1E1E1E1D1E1E1E1C1C1C
1E1D1D1C1C1D1C1D1D1D1C1B1B1D1C1D1C1D1D1D1E1F1E1C1C1D1B1B1B1A1B1A1C1C1B1A
1B1B1B1B1B1B1B1B1C1B1B1C1B191A1C1A1B1C1C1B1B1A1A1A1B1B1A1B1A1B1A1A1A1B1A
1A1A181A1A1A1919
1A191B1A1A1A1A1A1A1A1B1B1A1A1A1B1A1B1B1A1B1B1B1B1A191C1A1A1A1B1C1A1B1A1B
1B1B1C1A1B1B1B1B1A1B1B1B1C1B1B1B1B1C1D1C1C1C1B1C1B1B1B1C1D1B1C1C1C1C1C1C
1B1D1D1C1C1D1E1D1C1C1B1D1D1D1D1D1D1C1D1E1E1D1E1F1F1E1E1E201F1F1F1F1F201F
1E1E201F1F201F1F1F1F2020212020212020202020202121212222222222222522232324
2322242224242423252526252425252526262626272826282729292829292A292B2A2C2C
2B2A2C2D2D2E2E2F2F2F302F303332323434353536373737393A393A3D3E3E403F414243
454547484A494B4E4D5151525556585A5B5D5F616365686A6B6E6E7474747A7B7C7E8282
8486868A8A8C8A8D8F8D8D8D8B8D8C8B8B878785818180817D7A7A757272706C6B6B6666
6662605F5E5B5957565553524F4F4C4D4C494746454343434241403E3D3B3C393A3A3837
36383635343433333331312F302F2F2E2E2E2E2D2E2C2B2C2A2A292A2A29282828292628
272627262726262524262426242423242424242322232223242324232222222121222220
21212121202020202020201F20211E1F1E1F1E1E1E1E1E1E1D1D1F1D1D1E1E1E1D1D1D1D
1C1C1E1D1D1D1D1C1D1B1C1D1D1C1D1D1D1C1D1C1D1C1C1D1C1C1B1A1B1C1B1C1C1C1B1C
1B1B1B1B1A1B1B1B1A1B1B1A1A1B1B1B1A1A1B1A1B1B1A1B1C1B1B1A1B191A1A1A1A1A1A
1A1A1A191A1A1919
1A1A1A1A1B1A1B1A1A1B191B1A19191A1A1A1C1A1B1A1B1B1A1B1A191A1A1B1B1B1B1A1B
1A1B1B1B1D1C1C1B1B1C1B1C1B1D1D1A1C1A1B1C1D1B1C1B1D1B1C1D1D1B1E1D1D1C1D1C
1E1C1C1E1C1C1D1D1C1D1C1D1E1E1D1C1D1D1D1D1E1F1E1E1E1F1F1E211F1E1F1E1F1F1F
201F1E1F1F1E201F20211F2020201F202020202021212121212121232122232322232223
2222232425242424262424262626262625252526252727282929292B2A29292A2A2B2C2C
2C2C2D2C2D2F2D303031303131323332333535353636383839393B3C3D3E3F4241414343
434646474A4A4C4D4F4F52555557595A605E61646468686D70707374777A7C7E81828286
88898E8E8F9092919291929493958F92918F8D8A88878782817E7C7976737473716C686A
6661635F5E5D595956555355504E4F4C494847474446424341403F3F3E3E3B3C3B393839
3636363635333432323231302F2F2F2F2D2C2F2D2C2C2C2B2C2A2B292A2B2A2A28292828
272727262426262625252625242425242423232422222322222221222222222122222021
2020202020201F201F211F1F1F201E1F1E1D1D1F1F1E1E1F1D1D1F1D1C1E1E1D1D1F1F1D
1E1E1D1D1D1C1D1C1C1E1C1D1C1C1B1D1C1C1D1C1C1D1C1C1B1B1B1B1C1B1C1C1B1B1B1B
1B1A1B1B1A1A1C1A1A1B1B1B1A1A1B1A1B1B1B1A1A1B1C191B1B1B191A1A1B1A191C1A1B
1A1A1A181919191A
1A1A1A191A1B1A1B1B1A1A1A1B1B1A1B19181919191A1A1A1B1A1B1A1A1B1B1A1B1B1C1B
1C1B1C1B1B1A1B1C1C1B1C1A1B1B1C1C1C1C1B1B1B1B1A1A1B1B1C1D1C1D1C1C1C1C1D1C
1C1C1D1D1D1C1D1D1E1C1D1D1D1D1D1E1D1B1D1D1D1F1E1E1E1F1F1F1F1E1F1F201E1F20
1F1F201E201F1E202020211F2121202121201F2221212122222022222323212223232322
23242325252624262425252526252626262627262628272727272929292A2B292A2A2A2C
2C2D2D2E2F2F2D2F313031313132333235343535363837393A3B3B3F3F3F413F41434145
464547494A4C4E4E5252535455585B5C5F60616566686B6E7073767B797D81818788898B
8D8E91939398959B96989A999997969595939091908B8A8885817E7E7D797375716D6D6B
696564635E5D5C5A59575553514F4E4F4A4A4948464644434240403E3D3D3C3D3A3A3837
393834343333333433313130302F2E2E2F2D2E2C2C2B2D2C2B2A2B2A2A2A29292A292827
282727272725262425252525242424242423232222242222232222212122232121222220
21201F2121201F2020201F1F1F201F1F1D1F1E1F1E1E1F1E1E1D1D1D1E1E1D1D1D1D1D1D
1F1E1D1D1D1C1D1D1D1B1D1C1C1C1C1B1C1D1D1C1C1C1C1C1B1B1B1B1B1B1B1A1C1B1C1C
1C1B1A1B1C1C1B1B1B1C1A1C1B1A1A1A1B1B1B1A1B1B1B1B1B1A1A1A1A1A191A19191A1B
1A1A191A191A191A
191B1A1A1A191B1A1B1A1A1B1A1B1A1B1B1B1B1A1A1B1A1A1A1B1A1C1A1A1B1B1C1A1A1B
1C1C1A1B1C1C1B1B1B1B1D1B1C1B1C1B1C1B1B1C1D1B1C1C1C1B1B1C1C1C1C1C1C1B1C1D
1D1D1D1E1E1D1C1C1D1D1E1C1D1B1D1D1E1D1D1D1E1F1E1F1E201E1E1F1E1E1F1E1E1F20
1E1F1F201F2020201F2020211F2021211F20212120201F21202221202221232323232423
22242424252424262425262526272626272628272828282928282A292B2B2B2B2B2B2B2D
2C2C2C2D2E2F302F303131313232333333323537363737393A393A3D3C3F3F4142414346
454749494B4D4F4F52525455575A5D5F61636769686C6D727175777C7C808285878B8C8D
939497979A9D9E9D9DA0A09C9D9C9B9E9999969391928D8D888684827C7A787673716F6E
69686662625F5B5B5A585756534F4F4F4A4C4A49454645434240413F3C3D3E3D3B3A3939
38363635353334323131303130312F2F2D2F2C2D2D2C2B2C2A2B2A2A2A2A292929282929
282727272727262626242525232324242323232423232323232323222121212121212121
21212121202020211F21201F1F201F201E1E1D1E1E1E1E1E1D1D1B1D1F1E1D1E1D1E1E1D
1D1D1D1C1D1E1D1C1C1C1C1D1C1C1B1C1D1D1C1C1C1D1C1D1C1C1C1D1B1C1B1A1C1B1B1C
1B1C1B1B1B1B1A1B1A1B1B1C1B1A1A1A1B1B1B1A1C1A1A1A1B1A1A191B1A1A1B1B1B1A19
1A191A1A1A1A1919
1B1B1B1B1A1A1A1B1A1B1A1A1C1A1A1B19191A1B1A1A1A1A1B1B1B1A1C1C1C1A1A1A1B1B
1C1B1B1C1B1B1B1A1A1B1B1C1C1B1B1C1C1A1B1B1C1B1C1B1C1B1B1C1C1B1B1C1D1D1B1D
1D1D1E1E1C1D1D1D1D1D1D1E1E1D1D1D1E1E1D1E1E1E1F1E1D1F1F1F201F1E1E1E1E1E20
1F20201F20201F211F212020202120212021202120212122212122212223232223212324
252324232424242426262625242527272627272727272828272929292A29292A2B2C2B2E
2D2E2E2E2E2E2F2F302F31303231323334343435373737393A3B3D3C403F404041434545
4647494B4B4F4F4F515456565A5B5D61616467686C7171737378797C7E8187868D8B9094
979B9F9DA1A3A3A2A3A6A4A5A6A4A5A3A19D9C999695938E8E8A86867F7F7A777674726F
6C6A686363615E5C5C5C58565554514F4E4B4A494847454542424040403D3C3C3B3B3A39
3737363636343333322F31322F2F302F2E2F2E2D2D2B2C2B2B292A2929292A2A29282628
282827282627252624252424252524242423232423242223232223232321212122222120
202120212021201F211F201F1F1F1F1E1E201E1E1E1E1D1D1D1E1D1C1E1D1D1E1E1D1D1E
1E1E1D1D1E1C1C1C1D1D1C1D1C1C1C1C1C1D1C1C1C1D1B1B1C1C1C1B1C1B1C1B1C1B1C1C
1A1B1D1B1C1A1A1C1C1A1A1B1A1A191A1B1B1A1A1B1A1B1A1A1B1B1B1C1A1A1A191C1A19
1A1A191A1B191A19
1A19191A1B1A1B1A1B191B1A1A191A1A1A1A1B1B1A1A1A1B1A1B1B1B1B1A1B1B1C1A1A1B
1A1B1B1B1A1A1B1B1B1B1B1B1B1B1B1C1B1B1B1B1C1C1B1C1D1C1C1C1C1C1C1C1B1C1C1D
1C1E1D1C1C1C1D1E1C1E1E1D1D1C1C1C1E1E1D1E1D1E1D1E1E1E1E1E1D1F1E1E1E201E1F
1E1F1F1F201F1F1F201F211E202021221F21212121221F21212222222221222222232323
2323232525252425242625242626252626262727272727292929282829292A2B2B2C2B2C
2D2C2D2D2E312F322F31323232323334353436373A3939383A3A3D3C3F3E414243444446
48494B4A4C4F51525455565A5B5D5F5F62666B6C6D6F7375797A7E808485898E90929798
9F9EA3A3A8A7A9A9ABACABACAFACA7A9A7A6A0A0A09B9893928C8A888483807D79767571
6E6C6C686763625E5D5D5958555553514D4D4B4947474444434141413E3E3C3C3A3B3939
3838363434353533323131302F3131312E2D2C2E2D2C2B2C2C2C292A292B292A29292728
262827272728262526252525232424242324232423242323222223222122222121212121
212020221F2021201F1F1E1F1E201F1E1F1E1D1E1E1E1F1F1F1D1E1E1D1E1E1E1D1E1D1C
1E1E1C1E1C1D1D1E1C1D1D1C1C1C1B1D1B1C1C1C1D1C1B1B1B1C1D1B1C1C1B1C1B1A1B1B
1A1B1B1A1C1B1C1C1B1C1B1A1A1A1B1B1A1A1A1A191C1A1B1A1A1A1B1A1A1A1B191A1B1A
1A1A1A1B1A1B1A19
1B19191B191B1B1B1B191B191A1B1A1B1B1A1A1A1B1A1A191B1A1B1A1C1A1C1A1B1B1A1A
1A1C1B1C1C1A1B1B1C1B1B1C1B1B1D1B1B1C1B1C1A1C1B1B1C1C1C1C1C1B1D1C1C1D1D1C
1D1E1D1C1C1C1D1D1E1D1C1D1D1E1E1D1E1D1E1E1E1D1E1E1F1E1E1F1F1E1F1E1F1F1E1F
1E1F1F1E1F1F211F20202020202020202021222120212121222223222121232223242323
242524242426262525262426252625262527262727252828292928292A292B2B2A292B2C
2C2D2D2F2E2F2E2E31313133323334353635353738383A3A3A3B3E3D3F3F414243454645
47494B4C4D5152525455585A5B5F606263686B6C71767577797F8184888C909194979C9E
A4A4A7A9ACAFB0B0B6B4B4B4B5B1ADAFACA9AAA6A39E98999592908D8983837F79797973
716F6C6A6A646364615D5D5B59575451514F4D4C49484844434141413E3F3C3C3B393939
3837353534363333313232312F302E2F2F2E2E2C2E2C2B2B2B2B2A292A2B292928272829
282827282726262527232525262624242423232423222222222322222222212020212221
2221212020201F201F1F20201F201E1E1E1F1E1E1E201E1E1D1E1E1E1D1D1D1D1D1F1C1D
1E1E1D1E1D1C1D1E1D1D1C1E1C1C1C1C1C1B1B1C1C1D1B1B1E1B1C1B1B1C1C1A1B1B1C1B
1B1A1B1B1B1C1C1B1B1B1A1B1B1C1B1A1A1B1B1B1A1B1A1B1A191A191A1B191A191A1A1A
1A1A1A1A1A1A1919
1A19191B1A1A1A1A1A1A1B191B1B1A1A1B1B191A1A1B1A1B1A191C1B1C1B1A1C1B1B1A1B
1B1B1B1B1C1C1C1B1A1A1A1B1C1B1B1B1B1C1C1A1B1B1C1B1D1C1C1C1D1C1C1C1E1C1D1C
1E1D1D1D1E1D1B1D1C1C1E1E1E1D1E1E1D1E1D1D1D1D1E1E1E1E1F1E1F1F1E1E1F1F201E
1F1E1F1F1F2120212022201F202020202021202221202120202120222223232422222223
232324232525262624262625252727252726272628282828292A2A292A2A2B2B2B2B2D2D
2C2D2C2E2C2E2F313132313033323334343536363839373B3A3B3C3D3F40404345454647
49494A4C4D5051545556585B5E60636668686B717274787B7E7E84868C8F93939A9DA3A6
A8ADB1B0B2B7B6BAB9BCBDBABAB7B7B8B4B0AEAEA7A3A19E9B99978D8B888584817B7A78
73726F6D6B6A68676362605E5B585553514F4D4B4A484547454341423F3E3E3C3B3B393A
393836363435343333313230302F302E2F2E2C2D2E2C2C2B2B2A2A282A2B28292828272A
282728262526262625262525242625252425242424232324232323212122212422212122
1F21212120201F201F1F20201F1F1F1E1E1E1E201E1E1E1E1E1E1E1F1D1D1E1E1D1D1D1D
1D1D1D1C1C1D1E1E1D1D1B1C1C1E1D1C1B1C1C1B1B1B1C1D1D1C1C1C1C1C1C1B1B1B1B1A
1B1B1B1B1A1A1A1B1B1A1B1B1A1B1B1A1B1A1A1B1B1A1B1B1A1A1B1A1B1A19191B191B1A
191A1B1A1A19191A
1A1A1A191A1A1A1B1B1A1A1A1A1A1B1A1B1A1A1B19191A1B1C1A1B1B1B1C1B1A1A1B1B1A
1B1A1A1B1B1B1B1B1C1A1B1B1B1A1C1C1B1D1C1B1C1C1B1C1B1B1C1C1B1C1C1D1C1D1C1D
1E1C1D1D1C1B1D1F1E1D1D1E1D1D1D1E1D1D1E1F1E1E1F1E1D1E1F1E1D1E1E1E1F201D1F
201F20211F20202021202021221F211F2020201F21212122212122222222232222232324
2424232425252526262526252627252528272727272828282829292A2A2A2A2C2B2C2D2C
2D2F2F2D2E2F2F3030303132323233353337353637383B3A3B3D3E3F3F40404343454848
47494A4E515252565458595C5E616465686B6D7174787A7E80838A8A8E94959DA1A1A7AA
ADB1B7BABABBC0C0C2C3C1C5C0C0C0BDBABBB7B3AFACA8A5A19D9494908C898682827F79
767570706B696B69666662605E5A5754514F4E4C4A49474644444343413F3D3D3C3B3A37
383736363735333233323132303030302E2D2D2D2D2D2D2C2A2C2B2B2A292A2728282828
272827272626262725252625242624252425232323232223232223212220222123222021
21212020201F1F2020201E20201F1F1E1F1E1E1D1F1D1D1E1D1D1E1D1E1E1E1D1E1E1E1D
1E1D1E1E1E1F1C1C1D1D1C1B1C1C1D1B1C1D1C1C1B1C1D1C1B1B1B1B1C1A1B1A1B1B1C1B
1B1B1B1C191A1A1B1B191B1B1B1A1B1A1A1A191A1A1B1B1A1A1A191B1A1B1B1A1A1A1919
18191A1A1A191A1A
1A1B1919191A1C1B1B191A1B1B1A1A1B1A1B1C1A1B1A1A1B1B1B1B1A1A1B1C1A1C1C1C1A
1A1B1A1A1A1B1C1D1B1C1C1B1C1C1A1B1C1C1B1C1C1B1B1B1D1C1D1C1D1C1C1C1B1D1D1D
1D1D1D1D1C1D1D1D1C1D1D1D1D1E1E1D1C1E1E1D1E1E1D1E1F1D1F1E1E1F1F1E1F1F201F
1E201F20202120212121212020201F202022201F21212121212122232123232222232322
222323272525252625252525272626252626282727282928292A2A2B2B2B2B2A2B2B2C2C
2C2D2D2E2E2F31303030323134313434353636363839393A3B3C3C3F4140414244464647
4A4A4E4E4E50535557595A5C5F6165696A6D7273777A7C7E84878D8D94989BA0A6A8AAB0
B3B9BAC0C3C6C9CAC9CBC9CBCBC7C8C6C6C2BFB9B6AFAFA8A49F9C9794928D888384807C
7B78757173716D6D6C6B6662615C59565652514E4B494645464443423F403F3B3C3C3B3B
3838373536363534333233323030302F302F2E2D2D2C2B2D2B2B2A2A2B2929292A282928
282528262627252626242625232524232324242424232322222322222221222322202021
20211F1F212120201F2020201F201E1E1F201E1F201F1E1E1F1D1F1D1D1E1D1D1E1D1D1C
1C1C1B1D1E1E1D1C1C1E1C1D1D1D1C1C1D1D1A1B1D1C1C1B1B1B1D1C1B1C1B1C1C1C1B1B
1A1A1A1B1B1B1C1B1A1B1B1B1A1B1A1B1A1A1B1A1A1A1B1B1A1A191A1B1B191A1A1A1A1B
1A1B1A1A1A191A1A
1B191B1B1A1B1A1B1A1A1A1A1B1B1A1A1B1A1A1A1A1A191A1A1A1C1A1B1A1B1B1B1B1B1A
1B1B1A1A1A1A1B1B1B1B1C1A1B1B1B1A1D1B1C1C1B1B1C1B1C1C1B1D1B1C1C1B1C1C1D1C
1D1D1E1D1D1D1D1C1C1D1D1E1E1E1E1E1D1E1F1E1D1F1E1E1E1E1E1E1E1E1E1E201E1E1F
1F1E201F1F21201F2021211F202120202021212121212121222123232322232222242324
23242325242625252625252627262527272627272727292929282A2A2A292C2B2B2B2B2C
2C2C2D2E2F31312F313131343334343336353538393A393B3B3C3F404141424343444747
494D4D4E51505455565C5C60616567696A716F73767A8084878A8F939799A1A6A9ACB2B5
BCC1C3CBCBCECFCFD2D6D3D4D3D1D2D0C9C6C3C0BCB8B4AFA8A5A1999896938C89878381
7F7C7879777274716F6D6A67615D5A5755534F4E4D4B47484646444140403F3E3C3C3B3A
3A3836353736363434323132303030302F2F2D2E2E2D2C2B2C2A2A2A292A292A29292928
262628262626262525262526242424242423222324232222232223212122222222202121
202021201F1F1F2020211F1F201F1F1E1E1F1F1F1E211E1E1E1E1E1F1E1E1E1E1D1D1F1D
1E1D1D1D1D1E1D1C1C1D1B1C1C1C1C1D1C1C1C1D1C1C1C1D1D1C1C1C1B1C1C1C1B1C1C1B
1B1C1A1B1C1C1A1B1B1B1B1B1B1B191B191A1A1B1B1A1A1A1B1B1A1B1B1B1A191A1A1A1B
19191A1A1B191918
1A1A1A191B1B1A1A1A1A1B1B1A1A1A1A1A1A1B1B1A1A1B1A1B1B1C1A1B1B1A1A1B1B1B1B
1A1A1C1A1A1B1B1B1B191A1B1A1B1B1A1C1C1C1B1C1B1B1C1B1B1C1D1B1C1C1C1B1C1C1D
1C1D1D1D1D1B1C1D1E1D1E1D1C1D1E1D1D1E1D1F1E1D1D1E1E1D1D1D1F1F1F1E1D1D1F1E
1F1F201F201F20201F2021201F1F20202020202020222221202322212222222123222423
24242524252525262726252625262826272827272629292A292A292A2C2B2D2B2B2A2B2C
2E2E2E2E2F2F2F30313132323233343434363638383A393A3B3D3C414041434445454749
4B4C4F51515456575A5B5D5F6265666B6E6F7474777D81858A8F94989BA1A4AAACB1B5BF
C3C6CCCDD1D6D8DCDBDFDCDEDEDBD9D9D5CFCEC4C5BCB9B2AEABA4A09D9999928F8C8A87
8783837F7F7A767574716D6964615C585552514D4E4B47474547434240403E3F3E3B3B39
3A38393735353434313231303031312F2E2E2C2C2E2D2B2D2C2C2829292A282927282729
292727252526262625242525252524242324242424232322212123222122202221202221
222221221F2220201F21201F1F1F1F1E1F1F1D1F1E1D1F1D1E1E1E1E1D1C1D1E1E1C1D1F
1C1C1E1D1D1E1D1C1B1C1C1C1C1C1D1C1C1B1C1C1C1D1C1A1B1C1C1C1B1B1C1A1B1C1A1C
1B1C1A1A1A1B1C1C1B1A1A1B1A1B1B1B1A1A1B1A1A1A1B1B1A1A1A1A19191B191A191A1A
1A1A191919191A1B
1B1B1B1B1C1B1A191A1A191B1B1A1B1B1B1A1A1A1B1A1A1A1A1B1B1B1B1A1B1B1B1B1B1A
1B1B1B1C1C1A1B1B1B1C1C1C1A1C1C1A1C1C1C1B1B1C1C1D1C1C1B1C1C1B1B1E1D1C1D1C
1C1C1D1D1D1D1D1D1D1C1D1E1E1F1D1D1D1F1D1E1F1E1E1E1E1E1E1E1E1E1E1F1E1F1E1F
1F1F1F201F20202020201E20202221202021212121212121222122222223222323222323
24232524242526242525252626272625262627262728282929292A2A2A2A2B2C2C2D2D2D
2D2D2F2F2F2F323132323232333337353537383839393B3C3C3C3E424040424446474848
484C505054535457595A5C606265686C6E6F747A7B7F82898E91969BA0A3ACB1B4B9BCC3
C7CED2D8DCE0E5E5E7EBEAE8E5E8E5E2DCD6D4CECAC4BCB7B5B0ACA6A19D9C989797938E
8B8B8A8682837D7C7C777168635E5B57575350514E4B4A494646434240403F3C3C3D3B3A
3938383836353432343433303130302F2F2E2F2E2D2D2D2A2C2B2B2A282A292929292929
282726272627272526232624252324242325242422242322222221222122212122212121
212120202021201F2020201F1F1F1F1E1E1F1D1F1F1F1D1E1E1F1E1E1E1E1D1E1E1D1C1D
1C1D1D1C1E1E1D1D1E1D1B1D1D1D1D1D1D1B1B1E1C1C1B1B1C1D1A1C1B1C1B1C1C1C1B1A
191B1B1A1B1C1B1B1A1A1B1A1B1C1B1A1A1A1B1B1B1C1A1A1A1A1A191B1A1A1A181A1A1A
1A19191B1A1A191A
1A1A181A1A1B1C191A1B1B1A1A1A1B1A1A1A1B1B1B1A1A1A1B1B191B1C1A1B1B1B1A1B1A
1A1A1A1B1B1C1B1A1C1C1B1B1B1B1C1B1C1C1B1C1C1C1D1C1C1C1C1B1C1B1C1B1C1D1C1B
1D1B1C1D1C1D1E1D1E1D1D1D1D1D1E1E1E1F1E1D1E1E1D201F1D1E1E1E1E1F1F1E1F1E21
20201F1F1F20202020202021201F1F212120202022222121222122222222242221232423
232423252426262524242526272627282627282728282A282829292B292B2A2C2C2D2B2C
2D2E2F2E2E303132333232333534353435373837393B3A3B3E3E403F414143444447464A
4C4D4E50535354575B5D5E6265676B6B6F7176797B81858A8D96989EA3A8ACB2BAC0C6CC
D0D6D9E1E6E9EAEEF3F5F4F3F4EEEBEAE8E3DCD5CDCCC4BEBBB4B0ACA4A29F9C999B999A
979694908A86868279777069625F5B595452524E4E4C4A4848474642423E3E3F3D3C3A3A
3A3837363535363334323333313230312D2E2E2E2E2D2C2C2C2D2B292A29292928282828
282828272626272726252524252524242423242424222324222323242121212120202120
20202020212120201F1F2121201E201F1E1E1E1F1F1E1E1E1E1D1D1F1D1F1D1D1E1F1E1D
1D1D1E1D1C1C1E1D1D1D1B1C1B1D1B1B1C1D1D1D1B1C1C1D1C1A1C1A1C1C1B1C1B1B1C1C
191B1B1A1C1A1C1B1A1B1B1A191B1B1B1C1B1A1A1A1A1A1A1B1A191A191A1A1B1A1B1A1A
1A1A1919191A1A19
1A1A1A1A1A1A1A1B1A1A1A1A1C1A1B1A1B19191B1A1A1B1A1A1B1A191B1B1C1A1A1B1B1A
1A1C1A1B1B1B1C1B1C1C1B1B1C1C1C1D1C1C1C1C1C1B1C1C1B1C1C1C1C1C1C1D1C1C1C1D
1D1C1C1D1C1C1B1D1C1C1D1C1E1E1F1D1F1D1E1E1E1F1D1D1E1E1E201E1F1D1E1F1E1F1E
1F1F2020211F1F1F20202021212121202021212121212220212322212122232322252124
222224242324262425262625272626252627282828282929292A292A2A2B2B2C2B2B2C2D
2D2E302F2F3030303131313433353536353739383939393C3D3C3D40414544464646494B
4B50505150575558595D626364676B6D7275777A7E83888D91979BA2A7AEB1B7C3C5CBCF
D8E0E6EAEEF4F5FCFCFFFFFDF8FAF9F5EFEAE7E0DAD2CAC6C1BCB3AEACA8A5A3A3A3A7A5
A4A19B96908A868178776D67615E5A575652514F4D4B4A474646434241403F3F3E3B3C3C
39393837373335343334333133302F2F2F302D2E2E2D2C2C2C2A2A2A292A282A29292827
282727262626262727242525252525242523252423222222232122222322212121212121
2120212121221F1F201F1F211F1F1E201D1E1F1E1E1E1D1F1D1E1E1E1E1E1D1D1E1E1E1D
1D1D1D1D1D1D1E1C1D1D1C1B1D1D1D1C1C1D1C1C1C1C1B1D1C1B1B1A1B1B1C1C1A1B1B1A
1B1B1C1B1C1B1B1A1C1B1A1B1C1A1A1B1B1B1A1A1A1C1B1A1B1B1B191A1B1B1A191A1A1A
191A1A1A1919191A
1A191A191A1A1A19191A1A1A1A1B1A1A1B1A1B1B191A1B1A1C1A1B1B1A1A1C1B1B1B1B1A
1A1B1B1A1B1C1B1A1B1A1B1B1C1B1C1B1B1B1B1B1C1B1B1B1C1C1C1C1C1C1C1D1D1D1D1D
1C1D1B1E1B1D1C1D1D1D1D1E1C1E1E1D1D1E1F1D1F1E1E1E1D1E1E1F1F1F201E1F1F1E1D
1F1E201D1F1F1F201F1F2020222220212121202121222122212222222322222323232324
2423232424242526242526262825262725272729292827292A292A292B2A2B2B2B2C2C2C
2C2D2E3030303130303132343235363435373838373B3B3C3E403F4040434346444A494A
4D4D5154525457595C5B6064656A6A717374777C82848891939A9FA2A9B0B5BFC2C8D5DB
E2E9ECF4F9FDFFFFFFFFFFFFFFFFFFFFF8F2EFE9E1D8D4CAC4C0BBB5B0AFABA9ACAEB1B0
B1ACA39E928B847D79706A67625D58565551504D4D4C484A4744434340403E3D3C3B3B3A
39383836363635353333343133313030302F2F2E2E2D2C2D2B2C2A2A2829292A2A292828
282726262727262526252624262524252423242222222224232323202222212021222022
212021201F22202020201F1F1F1F1F1E201E1F1F1F201F1F1F1F1E1F1D1E1E1E1D1E1D1D
1E1D1D1C1C1D1D1D1E1D1C1C1C1C1D1C1D1D1C1B1B1C1B1B1C1B1C1D1C1B1C1B1C1B1B1A
1B1A1A1B1B1B1A1B1A1B1A1B1A1A1B1C1A1A1B1A1B1A1A191A1A1B1B1B1B1B1A1A1B1A1B
1A191A1B1A1A1919
191A191A1A1A1A1A1A1B1A1A1B1A19191A1A1B1A1A1B1B1B1C1B1C1C1B1A1C1B1B1B1B1B
1A1A1C1B1B1A1A1A1C1C1A1A1B1C1B1A1B1B1B1C1C1C1C1D1C1D1C1C1C1D1D1D1C1E1C1C
1C1D1C1C1D1C1D1D1C1D1C1F1E1E1D1E1E1F1E1E1E1E1E1F1D1F1E2123201E201F1E1E20
1F1E1E1F1E1F1F1F1E2020201F201F212120232022212121212322222121232323222324
2425242625232525252425252725272727272728282828282A2A2B2A29292B2D2B2C2E2D
2F2E2F2F2F303131313333343535353536353837393A3C3C3F3D3F41414144474648494D
4C505253535659595D5E616366686C7075767A7D7F878C90989CA3A8B0B4BDC3CCD1D7E2
E6F0F6FBFFFFFFFFFFFFFFFFFFFFFFFFFFFBF8F1E7E0D8D0CAC5BFBBB6B4B2AFB3B8BFBD
B9B3A99F968C837A746E6A62605E5A565455524F4D4D4A484845424142403F3E3C3C3B3B
3938373836363634343332323132302F2F2F2E2E2C2D2D2C2C2C2A2B2B2B2B2A27292928
282727262726272726272526252525242526252422232322222222222222222221202121
212120212121201F1F1F201E201F1F20201F1E1F1E1F1E1E1E1E1E1F1E1D1D1E1E1E1E1D
1E1E1D1D1C1D1D1D1D1C1C1D1D1C1D1D1C1C1C1C1E1C1B1C1A1C1B1D1B1C1C1C1B1C1B1A
1B1B1B1C1C1B1A1A1C191A1C1B1B1C1B1A1A1A1B1A1A191B1A1A191B1A1C1B1B1A1B1A19
191A191B1A1A1919
1A191A1A1A1A1A191B1A1A1A1B1A1B191A1A1A1A1B1B1A1B1B1B1D1C1B1B1A1B1A1B1A1B
1B1B1A1C1A1B1A1B1C1B1C1B1C1B1D1B1B1C1B1B1C1C1C1D1B1C1C1D1C1D1D1C1B1C1B1C
1B1B1C1C1D1D1C1C1C1C1E1E1D1E1E1E1F1F1E1C1F1E1E1E1D1F1F2020201F1F1F1F1F1F
1F1F1F1E1F2020201F1F1F2120201F212121212120202021212222212022232122252322
24232325232425252525252626262525272727262829292929292A2B2C2B2A2A2C2D2C2D
2E2D2E2F2F3130303132343334363636373739373B3B3C3C3E3E3F424244464547494A4C
4E5151535554595B5D5F6263686A6D7173757B7F83888F92979EA5ADB1BAC0C7D0D7E0EC
F1F8FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5F3E7E2D9D2CCC6C1BAB8BBB9BDC2C4C1
BBB1A79C8F877D73726B64625F5B58585552504D4C4D4849474543434140403D3D3D3B3B
39393736373536353534323131312F31302E2E2F2D2C2C2D2C2A2B2B2B29282A28292928
282727262727272626272526252425242423242423222323232323222222212021211F1F
21222121202021211F2020201F1F20201F1E1F1E1F1E1E1E1E1F1D1D1F1F1E1E1D1D1E1E
1D1D1D1D1D1E1C1C1D1C1C1C1C1C1C1B1B1C1B1C1C1D1B1B1C1C1D1B1A1A1C1B1B1B1C1B
1A1B1B1A1B1C1C1C191B1A1B1C1A1B1A1B1A1A1A19191B1B1A1B1A1A1A1B1B1B1B191A19
1A1A1A1A1919181A
1B191A1B1A1A1A1B1B1B1A1B1B191B1A1C1A1B1B1B1A1A1A1B1A1B1B1B1A1C1B1B1A1B1E
1B1D1A1C1C1C1B1B1C1A1C1B1B1B1D1C1C1C1B1B1B1C1C1B1C1C1C1E1C1D1D1D1C1D1C1D
1C1B1D1C1C1E1C1C1C1C1D1D1E1E1D1E1D1D1E1E1D1E1F1D1E1E1F1F1F1F1F1E1E1F1F1F
201F201F21212020201F1F20202021202021202022222121232122232322232322232323
2424242424252526262527262626272626262828282829282A282B2B2A2B2C2D2C2D2D2E
2E2D302E31313032333234333334353535373938393C3C3B3F3E40404344464746494B4D
4E52525553565B5A5F6064656A6C707275777D81848991969AA1ACB1B3C2C7CDD4DDE8EE
F6FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEF6EFE7E1D9D0C8C4BFBFC0BCC1C2C5C0
B9ADA4948B8278756E696663615C59585452504E4F4B4A484745444341403F3F3C3B3B3B
39393937373735343331333332312F2F302F312E2D2D2B2C2A2C2C2A2B2A2A2929282928
282727272525262524262625252424242423242424222221222223222223212122212120
21202021211F1F2020201F211F1F1E201F1F1E1E1F1F1D1E1E1D1D1D1E1D1E1E1E1E1D1E
1D1F1E1D1E1F1D1D1D1D1D1B1C1D1D1C1C1C1C1D1C1B1C1D1B1C1B1B1B1B1B1C1B1B1C1B
1A1B1B1B1B1A1B1B1A1B1A1B1A1B1A1B1C1B1B1B1B1A1A1A191B181A1B1A18191B191A1A
191A1A191A1A1A19
1A1A1B1A1A1A1A1A191A1A1A1A1A1A1A1A1A1A1B191B1A1A1B191A1A1C1C1A1B1C1C1C1B
1B1B1B1D1C1B1B1B1B1B1B1C1D1C1C1C191C1C1D1D1C1D1C1C1D1D1D1D1B1D1C1E1D1C1C
1C1C1C1C1D1C1C1D1D1C1D1D1D1D1D1D1E1E1D1E1D1E1E1E1E1F1F1F1F201F1E1F1F1E20
1F1F1F20201F211F20212020212120212020222121232021222121212221232223232425
2324242323252425262726262627262727282827282929292929292A2A2B2C2D2E2E2C2D
2D2E2F302F302F323132323334363536353839383C3A3B3C3E3E3F4243454546474A4B4E
4F4F52525456585C5E5F62666A707073777B8081848D8F989CA5ABB5B9C6CBD2DBE8EBF2
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5EBE7DCD6CECAC4C0C0BDC0C0BEB8
ADA499938680766F6C6765605E5D5A585454514F4D4C494A4746454241413F3F3E3B3C3B
3A393737383536333434333431313031302F2F2F2E2C2E2B2A2B2C2B292A29292A2A2A29
272628262625262725262525242424252223222424232323212122222322212121232021
212121201F201F20212021201F201F1E1F1F1E1E1E1E1F1E1D1F1F1D1E1D1D1D1D1E1E1D
1D1C1D1D1D1D1C1C1B1D1D1D1D1D1B1B1E1C1C1C1C1D1D1C1B1C1C1B1A1B1B1B1A1B1A1B
1C1A1B1C1B1A1B1C1A1A1B1A1B1B1A1C1B1C1B1A1B1A1C1A1B1A1B1A1A1A191A1B1B1A1A
191A19191B191919
1B1A1A191A1B191B1A1B1B1A1A1B1B1A1A1B1B191A1B1B1A1B1B1B1B1B1B1B1B1A1C1C1B
1C1C1C1B1B1B1D1B1C1B1B1B1B1B1B1B1B1C1D1D1C1D1D1D1C1D1C1C1C1C1C1C1E1C1E1D
1C1B1C1D1E1D1D1D1D1D1D1D1E1D1E1D1D1F1D1D1E1F1E1E1E1E1F1F1E1E1F201E1F201F
1F201F1F1E201F2020202021202020211F22202121202122232122232322232223242224
242425252423252526262627272627272627262628272929292B2B2B292B2B2B2C2D2D2E
2E2E2F30313130313332323335353537353739393A3B3D3E3C3E3F424244454747484B4C
4F5252555756585C5E6164686B6E7174787C7F85888B91979DA4AEB4BDC6CFD6DDE9F1FA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F3E8E1DBD4CCC9C2BDBAB9BCB7AC
A499908A827976706C6866615F5E5A56565352504E4B4A484744464342413F3F3F3E3C3A
3B3836383735373534333333303130312E2F2F2E2D2C2C2D2C2B2B2B2A292A2929282928
282828282826272624252525252424252424222323252323232222232221212223212222
20212221202020201F212021201F1F1F1E1F1F1E1F1D1D1E1E1F1E1D1E1D1E1C1E1D1D1D
1E1E1E1E1C1D1D1D1D1C1D1C1C1C1B1C1B1C1D1C1C1C1C1C1C1C1C1C1C1B1C1C1A1B1C1B
1C1C1A1B1B1A1A1B1B1B1B1A1A1B1B1A1B1A1B1A1A1A1C1A1A1B1A1B1A1A1A1B1C1C1B1A
1A19191A1B1A1A1A
1A191B1A1A191A1A1A1B1B1B1B1A1C1A1B1A1A1A1A1A191A1A1B1B1B1A1B1A1B1B1B1B1C
1B1B1C1B1B1C1B1D1B1B1B1C1C1A1C1C1C1B1C1C1C1D1D1C1C1D1E1D1D1C1C1C1C1B1D1D
1C1D1B1D1D1D1D1C1D1C1D1D1D1E1E1E1D1E1D1D1E1E1E1D1F1F1E1E1E1F201E1F1F1E20
1F1E1F201F201F20211F20201F2120222020212122232121212222222323232422232424
24242424242424242525272726262725272827272928282A29292B2A2B2A2C2B2C2E2D2C
2E2F302F2F31303132323334343535363737373A3B3D3C3E3F3F424244434446484A4B4E
5151545353575B5A5F64656A6A707477797B8282888E93979FA6AEB8C1C7D0DBE3E9F5FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBF0E6DCD6CDC8C2BBBAB7B2ADA3
9C948B837C7A756F6A6A6362605B5958565350514E4E4B4A474746434441403F3D3C3D3B
3A383839373734343434323333302F30312E2F2D2D2C2D2C2D2B2B292A2A2A2929292928
272727262727252625242526242324242424242424232424222222212122212121212120
21202020201F201F1F2020201F201F1F201F201F1E1F1E1E1E1D1E1E1D1D1E1D1E1E1E1D
1E1C1C1D1D1D1D1D1D1E1D1D1C1D1C1C1C1C1D1C1C1B1C1C1B1B1C1B1B1C1B1C1B1C1B1B
1A1C1B1B1B1B1B1C1A1B1A1A1B1C1B1C1B1B1A1B1B1B1B1B1B1A1B1A1A1A1B1A1B1A1A1A
1A1A1A1A191A1A1A
1A191A1A1A1A1A1A191B1A1A1A1A1A1B1A1A1A1A1A1C1A1A1A1B1B1C1B1B1B1C1C1B1C1B
1C1B1C1C1C1C1D1B1C1B1B1B1D1C1C1C1C1C1B1E1E1D1E1E1D1C1C1C1C1C1B1C1B1C1D1D
1C1D1C1C1E1D1C1D1C1D1D1D1D1D1E1D1D1E1D1D1E1E1D201E1E1E1F1F1E1F1E201F1F1E
1F1E1F20211F1F2020201E20221F1F202221212221212222222323232322222324242423
242423252425252627262525262727272627272828282929292B2A2A2C2B2B2C2D2C2F2D
2D2F2F2F2F2F313132333234343435363738383A3B3C3D3E3E3F414142424447494B4A4E
4F5151525557595B606264686C6F7277797E83858A909399A3A9B3BAC2CCD0D8E6F1F9FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF4E7E4DBCEC5C1B7B6B3AAA29D
978E8A857D7874716C6665635F5C5A585554524F4E4C4E47464945434142403D3D3C3C3B
393B3A3738353735343434313131302F2E2E2F2F2E2D2C2D2B2C2B2C2B2B2A2A29282928
282927272927252526262525252424242424242323232222222120222122202022222122
22212121201F2121201F2020201F20201F211F1F1E1E1D1F1D1F1E1C1D1E1D1E1D1E1D1D
1D1E1D1E1D1C1E1D1D1D1C1E1D1D1D1B1C1D1B1B1C1D1C1B1B1C1B1B1B1B1C1B1C1B1B1C
1C1D1B1B1B1A1B1B1C1B1B1B1B1B1B1B1B1A1B1B1A1A1B1A1A1A1A1A19191A1B1A191B19
1A1B19191B1A1A19
1A1B1A1A19191B1A1B1A1A1B191B1B1B1A1A1B1A1B1B1B1B1B1A1C1A1B1B1B1B1C1C1C1C
1B1B1D1C1B1B1B1B1C1D1B1B1B1C1B1C1D1B1C1C1C1D1D1D1C1D1C1D1D1C1B1C1D1C1C1B
1C1C1C1C1C1C1C1C1C1C1C1E1D1E1E1C1E1E1E1D1E1E1E1E1F1E1E1E1E1F1E1F1E1F1F21
1F1E201F1F1F1F201F1E202020201F212020222121202122232122222323222223242322
232523242425242425252726262627272727272A29292A2A29292A2A2B2A2B2A2C2C2C2D
2E2F2E2F2F3031313232333435353636383839393C3A3D3F3F41404242444648494A4C4F
4F51515556585A5A606364696E6F72767A828087888F979CA0A8B0BAC4CCD5DDEAF3FEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5ECE0D7CFC6BFB9B4ADA79F97
938C87837D78726F6C6766625F5C5A5956545250504C4B49494546444341413D3F3F3C3B
3A39393638373634343332323231312E2D2F2F2E2F2D2B2C2C2C2B2B2C2B2B2A292A2929
282829272727262525262424252524232424232424242224232223222222222221222222
21212020222120202021211F201F1F1E1E1F1F1E1F1E1D1E1E1F1D1D1D1D1D1D1C1E1C1D
1E1E1D1D1C1D1D1D1E1C1D1C1C1B1B1C1C1B1B1C1B1C1B1B1C1C1D1B1B1D1C1B1B1B1C1B
1D1A1C1C1A1B1A1C1B1B1A1C1C1C1C1C1B1B1B1B1B1B1B1B1A1A1B1A191B1B1B1A1A1B1A
191A1A1A1A191A1A
1B1A1B191A1B1A1A1A1A191B1A1C1A1A1B1A1B1B1C1B1B1A1B1A1B1B1B1A1B1C1C1A1B1C
1C1C1B1B1B1C1C1C1B1B1C1B1B1C1C1B1D1C1C1E1E1E1D1E1D1C1B1D1B1C1C1C1D1B1C1D
1D1C1C1D1C1D1D1D1C1E1D1C1C1E1E1D1D1E1E1D1E1D1F1D1E1E1F1E1E1E1E1E1F201E1F
1F1F20201F1F1F1F1F202021202020202020202120222021212122212023232422252424
2425242524252525252726282727262727282829282828282A292A2B2C2C2C2D2D2C2C2D
2E2E2F2F2F31303231323434343536373638393A3B3C3E3C3F3E414342454646484A4B4D
525053565658595B5F63666B6C7074797C7E82888B8F969BA3AAB2BDC3CFD7E4EDF4FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4ECE2D9D0CABEB7B1A7A49D95
8F8D88807776736E6B6665625F5C5A585655524F4F4C4B4847474444404141403E3D3C3D
3B3A3838373636363334333132312F2F2F302F2E2D2E2E2D2B2A2B2C2A2A2A2A29292828
292928262724252626252524242425242424242123222323222221232221222223222020
21212122202021211F20202120201F1F1F1F1F1F1E1E1E1D1F1F1E1D1D1D1E1E1E1D1D1D
1D1D1E1E1D1C1D1B1C1B1D1D1D1C1C1B1C1C1C1C1C1B1D1C1B1C1C1D1B1C1C1B1C1B1B1C
1B1C1C1A1C1B1B1B1B1B1B1B1B1B191A1B1B1B1A1B1B1A1A1A1A1A1A1C1A1B1B1A1B1A1A
191A1A1B19181919
1A191B1A1B1A1A1A1C1A1A1B1A1A1A191A1A1B1A1A1B1B1B1A1A1B1B1C1B1C1B1C1C1B1C
1C1B1C1C1C1B1B1D1B1C1C1B1D1B1C1B1B1C1B1E1D1E1E1E1D1D1C1C1C1C1B1C1C1D1D1B
1D1E1C1D1C1D1C1D1C1C1E1E1D1D1D1E1C1D1D1E1E1D1F1F1E1E201F1F1E1E1E1F1E1E1E
1F1E1F1E1E1F1F20201F2021202220212020202121222121222222212224222224222225
2324242524252326252626262627272827282827282829282A2A2A2A2C2B2C2C2C2D2B2D
2D2D2E303032323233323434343536363538393A3B3B3D3D3E3F41424344454649494B4D
515152545657595E616165686C7173767A7F84898B8F949DA5A8B3BFC4CCD7E1EFF7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6EDE3D9CEC7BCB6ACA7A29C97
9088857C7978736F6C6866635F5C5C5955524F4E4F4E4C4948484545424240403D3C3B3A
3B393837373836353434323331312F2F31302E2E2E2D2E2C2B2C2C2B2A2A292929292B28
292826272727272624242624242424232423242423232321222222212221222221212122
212121211F20212022211F201F2020211E1F1E1E1E1C1E1E1E1E1E1C1C1E1D1D1E1E1E1E
1D1E1D1D1C1C1D1D1D1C1C1B1D1C1B1C1C1C1D1D1D1C1D1C1D1C1B1C1C1D1C1B1B1B1A1B
1B1B1C1B1B1B1A1C1A1B1B1B1B1B1B1B1A1C1A191B1A191A1A1B1A1B1B1A1A191A1A1A1A
1A1A1A191A191A19
1A191A19191A191A1B1A1A1A1A191B1A1B1B1A1C191A1A1B1C1B1C1A1C1B1C1C1A1A1B1A
1B1B1C1B1C1B1C1B1C1B1B1C1C1C1B1C1C1C1B1D1D1E1D1D1E1C1D1C1B1C1C1D1D1D1C1D
1D1C1D1D1C1D1D1C1C1D1D1D1C1D1E1C1D1D1D1E1D1E1E1D1D1F1D1E1D1E1F1D1E1E1F20
1E1F1F20202020201F1F2021202122202021212121212221212322222222242323232224
252423252526252426262625262527282827282828292929282A2A2C2B2B2C2B2D2B2D2D
2F2E2F2E3231303233333233343536383939383A3A3C3D3E3D3F3F42424447464A4C4B4D
4D52545456585B5D616466686D7074797D7E84868D92989EA4ACB5BCC9D0DAE6ECF5FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDEBE1D8CFC4C2B4AFA79F9A93
8B8A82807C76706D6C6965605F5C5B565654514E4E4D4B4A484846434341403F3E3D3B3A
3B3A3A383836353434323332323230302F302F2D2E2D2B2B2C2C2A2B2C2B2A2929282929
292928282627262726252625252424242424242524232323222222212222212122212120
1E20212120201E20202020211F1F1F1E1F1E1E1F1E1E1E1D1F1E1D1D1E1E1E1D1E1F1D1F
1E1C1D1E1D1D1D1D1E1E1D1C1D1B1C1C1C1C1C1C1D1C1D1C1C1D1C1C1C1C1C1D1C1B1C1C
1B1C1B1B1B1D1B1A1A1A1A1B1B1A1C1B1B1A1A1B1B1B1B1B1B1A1A1A191B1A1A191A1B1A
1A191A1A1A191A1A
1A1A1A1B1A1A1A1A1A1B1A1A1B1B1C1A1B1B191B1B1B1B1A1B1B1A1A1A1B1B1B1C1C1C1C
1B1C1C1B1C1C1D1C1C1C1B1C1B1C1C1B1C1D1C1C1D1D1C1C1D1C1C1C1C1C1C1C1C1D1C1D
1D1B1C1D1C1D1E1D1D1D1E1D1E1C1D1D1D1E1E1F1D1F1E1E1F1E1F1E1F201E1F1E1F1F1F
2020211F1F2020211F1F201F20202020202021221F212322212122232324232323252423
232424232324262625262626262626282728272727282729292A2A2B2A2B2D2C2D2E2D2F
2C2E2F30312F3033333432333535363736383A3A393B3D3C3E3E414141454546494B4C4F
4E50535557575A5D606265686B7075787B7F84888B92989EA5ADB5BDC7CCDEE6F0F8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAEDE2D8CEC4BEB5ADA69C9891
8F88837D7B7771706A676563615E5B575655534F4E4C4B494846454344433E403D3D3B3C
3A393835383637353433313132302F2F2F30302E2E2D2D2C2B2C2D2C2B2A2B2A292A2928
272827292726282527262624252425242323252323232324232323212221212022211F21
20222122202221212120211F201F1F1F1E1E1F1F1F1E1D1E1E1E1D1F1E1D1D1D1D1E1E1E
1D1E1E1E1E1E1E1C1B1C1E1D1C1D1B1C1C1D1D1C1B1A1C1B1B1B1C1B1B1B1B1C1C1C1C1C
1C1C1B1A1B1B1C1B1C1A1B1B1B1A1B1B1A1B1A1B191A1A1A1B191B1A1C1B1A19191B191A
1A19191B19191919
191A1B1A1919191A1A1A1A1C1A1B1B1B1B191B1B191B1B1A1A1C1B1B1B1A1C1C1B1B1B1B
1C1C1C1C1B1B1C1C1C1C1B1C1B1C1C1D1B1B1C1C1D1D1C1C1D1C1C1D1C1C1C1C1C1C1E1C
1D1D1B1B1E1D1E1D1D1E1C1D1C1C1E1F1E1D1D1D1E1E1E1E1E1E1E1F1F1F20201E1F1F20
201E1F1F1F1F20201F201E211F2121202022222022202321222021232222222324242423
23232424232425252525252727262727282728282729292A2A2A2A2B2A2B2C2C2C2B2E2E
2E2E302F3031313233333434353535383839393A3A3C3D3E3E4140424446464949494C4E
4F4F535556595A5B5F6265686B6F72777A7F83848C94989EA3AEB3BCC8CEDBE2ECFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7EBE3D8CCC6BAB3ACA39D9793
8E89847C7979736E6B6765625F5E5B5756544F514F4C4B48474445444441403F3D3E3D3A
3A38383837343634343433313130302F2F2E2E2F2D2D2B2B2D2B2C2A2C2A292B2A292829
272827262627262526262425252522242423242323232322232223212122202021202121
2121212120211F2020201F1F201F1F1E1E1E1E1E1E1E1E1F1F1E1D1E1D1D1F1D1D1E1E1E
1D1E1F1E1F1C1E1D1D1C1B1D1B1B1C1D1C1D1C1B1B1C1D1C1B1C1B1B1C1D1D1C1C1B1D1C
1C1D1C1A1C1B1A1A1B1C1B1B1C1C1B1B1B1A1B1A1A1B1A1A1A1A1A1B1B1A1A1A1B1A1A1A
1919191A191A1919
1A191A1B1A1B1A1B1B1A191C1B1A191B1B191A1B1A1B1B1B1B1B1A1C1A1B1C1C1A1D1A1B
1C1B1C1A1A1A1B1C1B1D1B1C1C1C1D1B1C1B1C1C1D1D1B1C1B1C1C1B1D1B1C1D1D1C1D1D
1D1D1E1C1C1D1D1C1D1D1C1D1C1D1E1E1D1D1F1E1D1E1E1E1D1D1E1E1F1F201F1E1F1F1F
1F1F1F1F20201F2020202020202020202021222221222121202122242221232322242424
24242425252625262724262525272828262828272827292A292A2B2B2B2B2C2B2C2D2D2E
2F302E2F303131313232323434363736383939393B3D3D3C3E40414344444748484B4B4D
5052525557585B5D6061656B6A6C7276797F82878C91969BA5ACB6C0C5CEDAE1EEFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4EBE0D8CDC3BBB3ABA5A19895
8B88827E7B77716C6A6864615F5E5C58565652504F4C4A49484745434441403D3E3B3C3A
3A3B3739363735333333333131312F3030302E2E2D2D2D2D2C2B2C2A2A2A292A29282829
272827272628252826252424252324242223242224222322212222222120212022222021
2020211F2120202020201F1F1E1F1F1E1F201F1D1F1E1D1E1E1F1E1E1D1D1F1D1C1D1E1E
1E1E1E1D1E1E1D1C1D1D1C1C1C1D1C1C1E1D1C1C1C1B1C1C1D1C1C1C1C1C1B1D1C1D1D1C
1C1C1C1B1B1B1B1B1A1A1B1C1D1B1B1B1A191A1B1A1A1B191A1B1A1B191B1A19191A1A19
19191A1B19191A19
1B191A191A191B191B1B1B1B1A1B1B1B1A1B1A1B1B1A1A1C1B1B1C1B1B1B1B1D1A1B1C1B
1C1B1B1B1B1B1C1B1B1B1B1B1B1B1C1B1B1D1C1C1C1C1B1D1C1C1C1C1D1C1C1C1D1E1C1C
1C1C1E1D1C1C1C1C1D1C1D1D1D1D1D1D1D1D1E1D1D1E1D1E1D1D1E1F201F1E1F201F1F1E
1E1F1F1F1F1F2220202020221F2021212122212022212321222122222323212322242323
23242425252525262625262626272727272729292928292A2A2A2B292C2C2B2C2C2D2C2E
2E2E302F2F2F323031333134353536353739393A3B3B3C3D4041413F43454547484A4C4F
4E51535558585B5D5F6266696B707577787E81848C8E969EA4ADB2BCC5CCD7E2E9F8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCF5E9DFD5CAC3BCB1AAA49C9890
8B857F7B7B77726F696865635F5C5C57555451504D4D494A474744434343423F3D3B3B3B
3A39383737353535343332333132302E30302F2E2D2C2D2E2D2C2A2D2C2A2A2829282728
262728262727272725252726252526242423232522232322212222222220222120212020
20211F211F2021211F20211E201F1E1F1E1F1E1E1D1F1F1E1D201F1E1D1E1D1D1D1D1D1D
1E1D1E1E1D1D1F1E1C1D1D1C1B1D1C1C1B1D1C1C1B1C1C1D1C1C1C1C1B1D1D1C1C1D1E1E
1D1C1A1C1A1C1B1B1B1A1C1A1B1B1A1B1A1B1B1A1A1B1A1B1B1B1B1A1A1A1A1A1B191B19
1A1A1A1A191A1919
1A191A19191B1A1B1B1B1A1A1B1A1B1A1B191A1A1B1B1B1C1B1B1B1C1B1B1C1D1B1B1C1C
1A1B1C1C1B1B1B1C1B1C1B1B1C1C1D1B1C1B1C1B1C1C1C1C1C1C1C1C1B1C1C1D1D1C1C1C
1D1C1D1C1C1E1D1C1D1D1E1C1D1E1D1E1C1E1C1D1E1E1E1D1E1E1F1E20201F1E1E1F1F1F
201F201F201F2121201F1F1F1F201F212020222222222121212223212223232322232322
242523242525262525262525272827282828272827292A2928292A2B2B2C2C2E2B2D2D2D
2E2D2F30303130323331333334353735373839393B3B3D3E3F40414342444549484A4B4B
4F50555456585B5F606366696C6F7174777C82858991979DA4ABB5BAC0C7D4E0EEF6FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F0E6DAD2CAC1B8B1A6A09D9490
8886817E7975716D6B6A64605E5E59585554524E4D4B4B47474645444242403F3D3D3B3B
3A39383735363434343332313032302F2F2F2F2F2D2D2C2D2D2C2A2C2A29292729282827
282627272826262626262525252525242423242322232322232022222222232122212120
2220202120211F2120201F201F211F1F1F1F1D1E1E1E1E1E1D1E1E1E1E1E1D1D1F1E1E1D
1E1E1E1E1D1E1B1B1B1D1D1D1B1B1B1C1C1C1A1C1B1C1B1C1C1C1C1D1D1C1C1D1E1D1D1E
1D1D1B1A1B1B1A1B1B191B1B1B1A1B1B1A191A1A1A1A1A1A1B1B1A1A1A1A1B1A1A19191A
1A1A1B191A18191A
191A1A1B1B1B191B191A1A1B1A1B1B1B1A191A1B1B1C1B1B1B1C1C1B1A1B1C1C1C1C1B1B
1B1C1A1C1B1B1B1D1C1B1C1C1B1B1C1C1C1C1C1A1C1C1A1C1C1C1C1C1C1B1C1B1C1D1C1C
1D1B1D1C1D1D1D1C1E1D1E1D1D1D1C1C1D1E1E1C1E1E1D1E1E1F1D1E1E1F1F1F1E1F1F1F
1F202020201F211F2021201F1F2020212021222120212222222122222222212222242423
24252524242426252526272626262727282728282928292A292B2A2B292B2A2C2B2B2F2C
2D2F2D3030303232333334343536363837383A3A3B3B3D3D3F4040444446464648494D4D
4E505456565A5B5C5E6267676B6D70727B7C82878A90959CA3AAB0B9C3CBD2DFE9F1F9FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEF7ECE1D7CDC6BFB8AFA7A09D9590
89847F7A7A756F6D6A6763615F5B5B56565251514D4B4B484745454242423F3E3D3D3C3A
3A3938373634353333323332323130312E302E2F2D2E2C2B2A2C2B2A2829292929292828
272627262626272527242525252325242424242322222222222222232222212121212121
20221F1F201F1F20211F1F1F1E1F1F201F1E1F1E1E1E1E1E1E1E1D1D1E1E1D1E1E1E1E1E
1E1D1D1C1D1D1D1D1D1D1C1D1C1C1B1C1D1C1A1A1C1B1D1E1C1B1C1B1B1D1C1C1F1D1E1E
1C1D1C1B1B1C1B1B1C1C1B1C1B1B1A1A1A1B1A1B1A1A1A1A1A191A1B1B1A191A19191A1B
1A191A1A1A1A1919
191A1A1A191B1B1A1A191A1B1A1A191B1C1B1B1A1B1A1B1A1C1B1B1C1B1C1B1B191B1B1B
1A1C1C1B1B1C1C1B1C1B1C1B1C1C1B1D1C1D1A1D1C1C1C1C1B1C1B1D1D1C1B1C1D1B1D1D
1D1C1D1D1D1E1E1D1C1C1D1D1C1D1D1D1E1D1F1D1D1D1F1E1F1E1F1F1E201E1E201E1E1E
201E202020201F1E201F2020212021212020212122212123222121222321232223232423
24242424252525252625252627252826282727282727282929292A2C292B2B2C2D2E2D2D
2C2E2F30303031323233333535353535373839393A3B3C3D3E41414242454647494A4B4E
4F51545456595B60606264686A6B7173757A80828991949BA2A9B0B8BFC7CED7E3EDF4FE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F1E5E0D3CBC2BBB5AEA59D999390
8981807D7571706E696764615F5C58565552514F504D4A48474644434240403F3D3E3B3B
3937373635333533343333313130302E30302E2D2E2D2C2D2B2A2B2B2B282A2A292A2828
282627272625262526242526262324232325232122232422222021212123212121211F20
222021201F201F221F1F1F1F201E1F1E1F1D1D1D1E1F1E1E1D1E1E1F1F1C1F1E1E1D1E1D
1D1C1D1E1D1D1E1D1D1B1D1D1D1D1B1D1C1C1B1C1D1B1D1C1C1C1C1D1D1B1E1E1C1D1D1D
1C1D1C1B1C1D1A1C1B1B1A1A1B1A1B1A1A1A1A1A1A191A1B191A1B1B1A1A1A191A1B1A19
1B1A1919191B1A1A
1B1B19191B191B1A1A1B1A1A1A1A1A1A1A1A1A1B1B1A1B1C1B1B1A1D1B1C1A1B1B1B1B1B
1B1B1C1C1C1B1B1B1C1C1B1B1C1B1B1B1C1B1A1C1B1C1D1B1C1C1C1D1C1C1C1D1C1D1C1C
1C1E1D1C1E1D1D1E1C1D1C1D1C1E1D1C1D1E1F1C1E1E1D1E1E1F1E1E1F21201F1F20201F
1F202020201F20211E202020201F201F2021212221222221212221232222232422232223
2424242424232525262626272726272827262927292728292A2929292B2C2B2B2C2D2E2D
2D2E30312F3031323133333435353537363838393B3B3D3E3E4143414344454949494A4C
4F50535655585C5C5E646468696D6F73777C7E82878D9299A2A4ABB3BBC3CBD5E0E8F3FA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2EDE2D7CFCBBFB7AEA9A59D988F8B
89827F777772716A6C6863625F5C59575452514E4D4B4A4546444443423F413E3E3E3B3B
393838363635353535343332313230302F2E2D2E2D2B2C2C2B2A2A2B2B2B292A292A2928
27282726262626262525252424242324242323242323232322232022221F211F20232120
20202020201F1F21201F201F1E1F1D1F1E1F1E2020201E1E1F1E1E1D1D1D1D1C1E1D1E1D
1E1E1C1D1D1C1C1C1E1C1D1C1D1C1C1C1D1C1B1C1C1C1C1D1C1C1C1C1B1C1D1E1C1E1F1D
1C1B1C1B1B1A1B1B1A1B1A1B1A1B1B1A1B1B1A1B1B1A1B1A1B1B1A191A1A1A19191A191A
1A1A18191B1A191B
1A1B1A1A1A1B1A1A1A1B1A1B1B1A1A1A1B1B1B1B1A1B1A1B1A1B1A1B1C1C1B1B1B1C1C1C
1B1B1B1A1D1B1B1B1C1D1B1C1B1B1B1B1B1A1B1C1C1B1C1B1C1C1C1C1B1C1C1D1D1D1D1D
1D1D1D1C1E1D1C1D1D1D1D1D1D1C1C1D1E1E1F1E1E1E1E1E1E1F1F1E201F1F1E201F1F1E
1F1F1F1F201F201F201F2020211F20202121212123202022232122222322222324232424
2424232424252425252525252627272927282829282829282A2A2B2A292B2A2B2C2C2D2D
2D2E302E3131303231333533343435383736383B3B3C3C3E3E4041424142464648494B4C
4F50545358585B5E5E5F67686B6B7074787A7F82888B91999FA4A9B3BAC1C9D0D9E3ECF1
FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF7EEE5DCD3CAC5BCB8ADA7A19A958F8C
86817D797571706B6764625F5F5B59565453504F4E4B4A4947454442414040403E3C3A3B
39383737383334353232323032302F2E2E2E2E2E2D2D2D2C2B2A2B2A2A2A292929282A27
292726262627252525242425232422232323242322232321222121212222232121212121
20212122211F201E211F1F1F1F1F1F1F1E1F1F1E1F1F1D1E1E1E1D1E1E1E1E1E1E1D1D1E
1C1C1E1D1D1C1C1E1D1C1C1D1C1C1C1B1C1B1C1C1D1C1C1A1C1C1C1C1A1D1D1D1C1C1C1C
1C1B1C1B1A1B1B1C1B1B1B1A1B1A1B1B1C1B1A191B19191A1A1A1B1A1A1A1A191B191A1B
1A1A19191A1A181A
1A1A171A19191A1A1A1A1A1C1B1B191A191B1A1A1A1B1B1B1B1C1B1B1C1B1B1C1B1B1A1A
1B1B1A1C1C1C1C1C1B1B1C1B1B1B1B1B1A1B1B1C1A1D1C1C1C1C1C1D1C1B1C1C1C1D1C1D
1C1D1C1D1C1B1D1D1F1E1D1B1D1D1E1E1D1F1E1D1D1D1D1E1D1D1D1E1F1E1F1F1F1F1F1F
1F1F1F1F20201F1F20201F20201F21212121212122202121212223222221222322222323
252425232325262425262626262627272828272728282928292A2B2A2A2B2C2C2C2C2D2C
2E2D2F2F31303133323334343434353636383A38393B3B3D3F40404243444746484A4A4B
504F535455585A5B5E606467686B707276787F81848D90949BA2A6AEB5BCC3C7D4DBE6EF
F6FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAF3F0E5DFD7D3C8C0B8B2ABA79C9B938F87
85817A79736F6C696763625E5C5B58545452514E4B4B4B49464644414040403F3C3B3A3B
3A3837373434333434333332322F302F302F2D2D2D2B2A2C2B2B2A29292B2A2929282828
282527272727262526262624242424232524242422232322232221212121212121212021
212020212020201E1F1F201F1E1E201E1E1F1E1E1F1E1E1F1F1E1E1E1E1D1D1C1E1E1D1E
1D1E1E1E1D1C1C1C1D1C1C1C1C1C1D1C1C1B1E1D1C1D1C1D1B1B1C1B1C1C1C1B1D1C1C1C
1C1B1B1C1A1C1A1B1A1B1A1B1A1A1B1B1B1B1B191A1A1A1A1A1A1A1A1A1B1A1A1A1A191A
1A1A1A1B1A1A181A
1A1A1A1A191A1B1B1A1B1A1A1A1B1B1C1A1A1A1A1C1B1B1B1A1B1B1B1A1C1B1A1B1B1A1C
1C1C1C1A1A1C1B1C1C1B1C1B1D1C1D1B1C1C1B1B1B1B1D1C1D1C1D1C1C1C1C1D1C1C1C1D
1D1C1C1D1D1D1E1B1C1C1D1C1C1D1C1E1E1D1D1E1E1E1E1E1F1E1F1E201E1F1F1E1E1F1F
1F1E1F2020201F1F202020201E2020222121222221222221222221232223222322222224
2523242523252624252526262726272627272726282929282B2929292A2B2A2B2B2C2D2F
2D2E2F3031303030323134343535353738393A3C3B3A3E3C3F403F404143454748474B4E
4D5052545659585B5D5F6466696C6E7173787C8186888D959B9FA3ABB1B7C1C6CED9E0E5
F0F4FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F1E3E0D7CFCAC0BDB6AEA8A19B978F8E87
847E7C77736E6D69676461605B5958545250504E4C4A494746454341403F3E3F3F3C393A
3938363736353332333432323231302F2E2D2F2C2D2E2C2B2C2B2B2929292A2B2A282827
262726252625262326242624242424242322232424222322232222232121222123212121
2021201F201F201F201F1F1F1E201E1D1E1E1F201E1E1D1E1D1E201E1D1D1D1C1D1E1E1D
1E1D1D1D1D1D1C1E1C1D1D1C1C1C1E1E1D1C1C1C1C1C1B1D1C1C1D1B1C1A1C1B1B1A1B1C
1B1B1C1C1B1A1B1A1A1B1A1A1B1A1B1C1A1B19191B1A191A1A191A1A191A1C1A1A1A1C19
1B191A191A19191A
1A19191A1A1A1B1A1A1B1B1A1C1B19191B1B1A191A1A1B1C1A1B1C1D1B1B1B1C1A1B1B1B
1B1C1C1B1B1C1C1B1B1B1B1C1C1C1B1C1B1C1B1B1B1B1C1B1C1C1C1C1D1D1C1D1C1C1C1D
1D1D1C1D1C1D1C1D1C1E1C1D1E1C1D1D1D1D1D1D1C1F1E1E1E1E1F1F1F1F1F1E1E1F1F1F
2020202021201E21202020201F1F20202020202122222121212223222423232323232223
242524252525252525262726282627262828292929292829282A2B2A2A2A2B2C2D2D2B2D
2D2E2E2F2E30323231313332363435353639383B393B3B3C3F3E414143454747484A4B4B
4E505153575658595D60606465696D7173787D7F83878C92979DA6A9ADB4BDC0CAD1D9E2
E8F0F6F9FFFFFFFFFFFFFFFFFFFFFFFFF9F3F2E6E0D9D3CECAC0B9B1ABA2A097938F8987
817D7978716F6B676561615D5B56575451504E4F4A4B48474644434041403F3D3B3A3B38
39373737383634333331313431312F2F2C2E2E2D2E2C2C2C2A2B2A292A292A2929282826
272728272725252626232524252424222424232422242221222223222322222222202123
2120212021202020201F201E1E211E1E1D1F1E1E1D1D1D1D1D201D1D1D1D1D1D1E1D1D1D
1E1C1E1D1C1D1D1B1C1C1C1D1D1C1B1D1C1C1B1B1B1C1D1C1D1B1B1C1C1B1B1B1B1C1B1C
1C1C1C1B1B1C1B1B1B1B1B1A1A1A191B1B1B1B1B191A191B1A191B1A1A19191A1B1A1A1B
1A191A1A1A19191A
1A181B19191A1B1B19191A1B1A1A1A191A1B1B1B1A1A1B1A1A1A1C1A1B1B1A1B1B1C1B1C
1B1B1B1B1C1C1C1B1A1C1C1B1B1C1C1B1C1C1C1C1C1C1D1B1D1B1C1C1B1C1C1C1D1D1D1B
1C1D1D1D1D1D1D1D1C1D1D1D1E1D1D1C1F1C1E1D1E1E1D1E1E1E1E1E1E201E1D1F1F1F1E
1F1F1F211E20201F201F20201F2020201F20202122212122212121222322232322232523
252324242425272524252427272627282727272729272A2929292B2A2A2C2C2C2C2B2D2E
2D2E2F2E303030323331333435343536373738393D3D3D3D3D3F40424142434546494A4D
4D4E51545357575B5E5F626465686C6E72757A7E83858A8F949A9FA6ADB1BAC0C4CCD0D9
DEE6EBF1F4F8FEFFFFFFFFFFFFFEFAF7F2EDE7E1D9D1CDC9C1BBB4AFA7A09C95928D8983
827B7876706B69666562605D5A57565552524E4E4B4A47464643434341423F3F3C3B3A38
3738373537343431323232323132302F2E2E2C2F2C2C2C2B2C2A2A2A2A2A292828282827
272626272727242524252525252424242422232323232323242123222221222221202121
21202021201F21201F211D1F1E1F1E1F1E1E1F1E1F1D1F1F1E1E1E1E1D1D1E1D1E1C1C1E
1E1C1D1D1C1D1D1E1C1C1C1D1B1C1C1C1C1D1B1C1B1C1C1B1B1B1C1D1B1B1C1C1B1C1C1C
1B1A1A1A1C1A1B1B1C1B1B1A1A1B1B1B1A1A1B1B1A1A1A1B1B1B1B1A1A1B191A191A1B19
1A1A1A1A1A191A1B
1B1A1A1B1A1A1B1A1A1A1A1A1B1B1B1A1B1A1A1B1B1B1B1A1B1C1A191B1B1A1A1C1A1C1B
1B1A1C1C1C1D1B1B1C1D1C1B1C1C1B1B1C1B1C1C1C1C1D1C1D1C1D1D1D1D1D1E1D1C1D1E
1C1C1C1D1C1C1C1D1D1C1C1D1D1C1E1E1D1D1E1E1C1D1E1D1E1E1D1F1E1E1F201F1E1F1E
1F1F1F1F1F1F2020201F21202021211F201F212121222122232221222224232423242324
24252425262426242525252526272627272828272829282B292A2A2B2B2B2C2C2E2C2E2D
2C2E2F2F303230323331333335373536383839393A3B3D3C3E3F3F424243454446494A4B
4C505252555757595A5E5F626569696E72757A7B81848B9094949DA1A5ABB5B8BCC4CBD0
D8DCE2E7EDF3F5F8F6F8FCF9F6F7F0EBE9E4E0DCD2CEC7C2BFB5ADABA0A09993908D877F
7E7A77746F6C686463615E5D58575254514E4C4C4B4A494445444442403F3D3E3D3D3B39
3937353635353435343431313130312E2F2E2D2C2E2D2C2B2B2A2A29292B2A2728272728
262727272526272524262423222524242423232422222323212321212222212021212020
20202020212020202020201F1F1E1F1E1D1E1F1E1F1E1E1E1D1C1E1D1E1F1E1D1E1D1D1D
1E1E1D1D1D1C1E1C1B1D1D1C1C1D1D1B1B1C1C1B1D1E1C1C1D1B1C1C1C1B1C1B1B1A1B1B
1A1A1A1C1B1B1C1C1B1C1A1B1C1A1B1B1A1A1A1A1B1B1A1B1A191B1A1B1A1C1A1B19181A
1B1A18191A1A1A1A
1A19191A1A1A1A1A1B1A1A1A1A1B1A1A1B1B191C1A1A191A191A1B1B1C1C1A1C1B1C1B1B
1B1D1A1C1B1C1B1B1C1B1D1B1C1B1B1A1C1C1C1A1C1C1D1C1B1C1B1C1B1D1D1D1C1C1D1D
1D1C1B1D1D1D1C1C1C1D1D1E1D1E1C1E1D1D1C1F1E1D1E1E1F1E1E1E201F1F1E1F201F1F
20201E1F1F202020201F201F21212021201F202121212122222221222223222323232224
24242424242525252524262526272626272727292728292B292A2A2A2B2B2C2D2C2D2D2D
2E2E2E2F303131323233333435363537373638393A3A3A3D3C3E3E41424344464747494A
4D4E4E525556565A5B5C60606365696F7173787A7E82858A8C94999EA4A9ADB5BAC1C4CC
CED4DBDEE2E5E9EBF2F1EDF0EFEBE5E4DDDDD8D4CCC5C1BCB5AFA8A5A09B94908D8A8280
7E7B76726F6B69666161605A58575752504E4C4C494A4848454344403F3E3E3D3B3A3A3A
3837373734343333323233313331302F2E2E2D2D2B2D2A2B2C2A292929282A2827282828
272727262625252626262525242325252424232224222322212220222020222120212220
20211F1F1F201F20201F1F2021201E1E1E1D1E1F1D1E1D1D1D1E1D1D1E1E1D1D1D1C1C1E
1D1D1C1C1D1D1D1D1D1C1D1C1C1C1C1B1C1B1C1C1B1A1E1C1C1B1C1C1B1A1C1B1B1C1B1B
1B1C1C1A1B1B1B1A1B1A1C1A1B191B191B1A1B1B1B191A1A1A191B1B1A191A1A191A191B
191A1A1A19191919
1B1A1B1A1819191B191A1B1B1B19191A1A1A1C191A1A1C1A1B1B1C1C1A191C1B1C1C1B1A
1A1C1A1D1A1C1B1C1C1C1C1C1C1B1C1B1B1B1C1C1C1B1C1B1C1B1C1C1D1E1C1C1C1D1E1E
1D1D1D1D1D1C1C1E1D1E1C1D1D1C1D1D1E1D1C1E1E1D1E1F1E1E1E1E1E201F1F1E201E1F
1E1E1E201E1F1F201F20202020202021211F212222222221222123232122222324242523
23252425252525272426262526252726282728282729272929292A2A2A2C2A2B2C2B2C2B
2D2E2D2F2F313030313234333435363536373738393A3C3C3E3E3F414044444546474948
4C4E5052525457585A5F5E5F6266696F6E7273797C7D83888A91929B9FA6A9B0B5BBBFC3
C8CCD2D6DCDEE2E4E5E4E4E4E3E1DCD9D6D1CECBC3BFB9B4B0A7A3A29C99918E8985807E
7A76756F6C6A6663625F5D5B59565550504E4E4B4B4847464544413F413D3D3A3C3B3A3A
37373636363435343432322F3232302F2F2E2C2D2C2C2C2C2A2A2A2A2B29292727282727
262627272526252525252324232424242322252322222421222322222222212020202121
2122201F202120202020211F1E201F1F1F1F1E1E1F1E1E1F1E1D1E1E1D1D1E1D1E1E1D1E
1C1E1D1E1E1D1C1C1D1C1D1D1C1D1C1C1D1D1D1C1C1D1C1B1C1C1B1C1C1A1B1C1B1B1B1C
1C1C1B1B1A1B1B1A1B1C1B1C1B1A1B1A1C1A1A1A1A1A1B191B191A191A191A1B19191B1B
191A191919191919
1A1A1A191B1A1A191A1A1A1B1C1B1C1A1A1A1B1B1A1A1A1A1B1A1A1B1D1C1D1B1C1B1C1C
1B1A1B1C1B1B1C1C1B1B1B1B1B1C1C1B1B1C1C1C1B1B1C1C1C1C1D1C1D1C1D1C1D1D1D1C
1C1D1D1D1C1C1B1D1C1D1C1E1D1E1D1D1E1D1E1F1F1E1D201E1D1E1E201E1F1E1F1F1F20
1F1F1F1F1F201F2120212120202020202121212122222222222222222222222322232424
24252425252425242626252626262527272727272729292A292A2B2B2A2A2B2B2B2D2B2D
2D2D2E2E2E3030323433333334363435363938383A393A3C3C3D3D4140434446454A494B
4B4D4E4E515356595A5A5C5F6166686C6F7073767A7E8184888D92969CA2A5ACAEB1B8BD
C2C4C8CDD2D2D5D9D9DADDDED7D6D3D2CCCCC6C2C2B9B4AFAAA6A19C9C918C8B8583807C
78756E6E6A6765625E5D5B5959565452504E4D4B4A48464444424141403E3D3E3B3C3B39
373838353736343433323130302F302E2F2E2D2D2E2C2C2A2B2B2A292829282728272826
262627272624262425252424232223242222232322222223232222222122222222222120
1F20201F212020201F1F1F1F1F1F201F1E1E1E1F1D1E1E1D1E1D1E1D1E1C1D1C1E1D1D1D
1D1C1E1D1C1E1E1C1D1C1C1C1C1C1D1C1D1C1B1C1C1B1B1B1C1C1B1B1D1C1C1D1B1B1B1C
1B1B1B1C1B1B1B1C1B1B1B1A1B1A1A1B1C1B1A1B1A1A19191B191A191A1A191A1A1A191A
1B191A191A191919
1B1A191A1B1A1A1B191A1A1A1A1A1A1B1B1B1A1A1C1B1A1B1A1B1B1C1B1B1B1C1C1C1B1B
1B1B1C1D1D1B1B1B1C1C1C1C1A1A1C1C1B1C1C1C1C1C1B1B1D1D1C1C1C1C1D1C1D1D1E1D
1D1D1E1C1D1C1E1D1E1D1D1D1E1E1C1E1E1D1D1E1E1F1E1E1F1F1E1F1E1F1E1E1D1E1E20
1F20201F1F1F1F21201F2021202020202121212122222222222322242223232324232223
24232525262425252526252624262626262726282727292A292B2A2B2A2B2A2D2C2B2C2D
2E2E2E2F3030303232333335343536363637373A3A3A3B3C3E3C3F3F3F41444445494748
4B4C4E5052525358595A5D5E60636769696C72757A7A7F82858A8E93959C9FA6A8AEB1B7
B8BDC1C4CAD0CDCFCDCDD2CECFCEC9C8C6C2C1BBBAB4AFABA8A19D9A938F8C8482837C7A
76716F6B696860635F5B5B57575550504D4D4C4B48494744434343413F3F3F3D3B3A3A39
3937373636343233343432312F302F2E2E2E2E2B2C2B292A292B2A2A2927282928272628
262627262626262424242626242424242424242323232323212322232221202021212120
201F1F1F2020201E201F201F1F1E1E20201E1E201E1D1E1E1E1E1D1D1D1D1D1E1E1D1D1D
1C1D1D1E1C1D1D1C1C1B1C1C1C1D1D1C1B1C1B1D1D1C1B1C1C1B1C1B1A1B1C1B1C1C1D1B
1B1C1B1A1C1A1C1B1C1A1B1A1C1A1C1A1A1A1A1B1A191A1B1B1A1A191A1B1B1B1A1A1A1A
1A1A191A191A191A
1A1B1A191A191B1A1A1A19191A1B1B1B1B1A1B1A1B1B1B1B1A1B1A1A1C1C1C1B1C1B1B1B
1C1C1D1C1C1B1B1C1C1C1D1D1C1C1C1D1C1C1B1C1D1C1C1D1C1C1E1C1C1C1E1B1E1D1D1C
1C1C1C1C1D1D1D1C1B1D1D1D1D1D1C1F1E1E1E1F201E1E1F1E1F1F1F1E1E1E1D1E1F1F1F
1F201E1F1E201F1F1F202120202020201F1F212121222222222322222224222323232223
2424262424252524262625252626282626262927292928292A292A2B2B2B2C2A2C2C2D2E
2D2F2D2F303030323331343433333636363838393A393B3A3E3D41404042434445464A47
4B4C4D4F50545256575B5E5D61626465666A7074767A7D7F83858D8E93999D9FA4A6AAB1
B3B5B7C0C5C4C6C5C7C7C7C6C8C4C2C1BFBCBAB5B2AEAAA6A09B9A93918C8785817E7A79
766F6C6B696363615F5C5958555352504E4D4C4B484747434242413F3E3E3E3D3B3C3A39
3736373435333433333131312F2F302F2E2D2D2C2C2C2B2B2B2A292A292A272828272726
272626262625262524252424252323232325242422232221222320232222222120202020
202120212021211F1F201E1F1F1F1F1E1F1D201D1F1E1E1E1E1D1C1E1E1E1E1E1D1E1E1E
1D1C1C1D1E1E1D1E1E1C1D1C1C1C1C1B1C1B1C1C1D1C1B1C1C1B1D1B1B1A1C1B1B1C1A1B
1A1B1B1A1B1A1A1B1B1B1A1B1A1A191A191A1B1B1A1A1B1A1A1A1A1A1A1A1B1B1A1A1A1A
1A1A191A1A19191A
1B181919191B191A1A1B1C191A1B1B191A1B1B1A1A1B1B1B1B1B1B1B1B1B1C1B1B1B1B1B
1B1C1C1C1B1C1B1B1C1B1B1D1C1B1B1B1B1C1B1C1B1C1C1B1B1C1D1C1C1D1B1C1C1C1C1B
1E1C1C1B1D1B1B1D1C1E1E1C1E1D1D1E1E1E1E1E1E1E1F1E1F1F1E1E1E1E1E1F1E201C1E
201F1E1F1F1F201E20201F20212120212122202121212223212221232523232223222524
2422242325252525262525252625272627272928272929292929292A2A2A2D2B2B2B2D2C
2E2D2E2F2F322E30313234353435353537373837393A3B3B3C3D3F41404042444347474B
484C4B504F5054565658595C60636365686B6D7071767C7F8183888A8F9597999EA0A3A9
ADAFB2B5B8BBBDBFC0BFC0BEBEBCBDB7B8B3B4ABAAAAA3A19A9695928D8884857F7A7774
726D6C6A6564625F5C5A58555753524E4E4B494B494744454442413E3F3E3E3B3B3B3A39
38393636343334323231302E302E2F2F2E2E2E2C2D2C2B2B2B2B2A2A2929292828282827
262727262626252526232623252524242424252323232221222121202121202122212120
201F20201F201F201F1E1F1F1D1F1E1E1E1E1D1F1E1E1E1D1E1D1F1E1E1E1E1D1D1D1D1D
1D1E1E1D1E1D1E1D1D1C1B1C1B1E1C1C1D1D1C1C1D1C1C1B1B1C1B1C1D1B1B1B1C1B1B1C
1A1C1B1C1A1B1A1A1B1B1B1B1A1B1A1B1B1A1A191A1A1A1A191A191B1A1A19191B191A19
1A1A1A1A191A1919
1A1B1A1A1A191A1A1A1B191A1A1C1A1A1B1B1B1A1B1B1B1A1C1A1B1C1B1C1C1C1C1C1C1B
1C1B1B1C1A1B1C1B1C1D1B1C1B1C1C1C1B1C1C1B1C1C1C1C1C1C1C1C1C1C1C1C1D1D1C1D
1C1C1D1D1C1D1E1C1D1E1C1C1E1E1D1E1E201E1E1F1D1F1D1D1D1D1E1E1E1E1E1E1E1F1F
1E201F1F1F1F2021201F2020202020201F21202222202223222222232223232323232524
252324242325252526262625252626272726262828272829292B292A2A2A2B2C2B2D2E2E
2C2E2E2F2F2E303130313234333436343837373837383C3A3C3D3F3F413F424544434848
484B4D50504F535556575A5C5F60636567686A6F707574797E8283868B9093989A9DA2A1
A5A8ABAEAFB2B6B5B8B6B7B4B6B4B2B2AFADABAAA6A29C9B97958F8E89847F7E7B797573
706C6A676461625D5B585756525151504F4A4C4A48454444424142403E3F3D3B3B3B3B3B
3838363534323133313130302F30302E2E2E2D2D2D2B2C2B2B2A29292A2A292828272627
282626252425242525252525262525242526232423232123222222222021222121212020
21201F20202020202020201E1E1E1D1E1F1F1E1D1E1E1F1E1E1E1E1E1E1E1C1E1D1F1D1E
1F1C1E1D1D1D1C1C1F1C1C1B1D1B1C1C1D1C1C1C1C1C1B1C1B1B1B1C1A1B1C1C1B1B1D1A
1C1B1B1A1B1B1B1A1B1B1A1B1A1B1A191A1A1A1A1B1B1A1A191B191A191B191B1A1A1B1A
191A1A1A1A19181A
1A191A191A1A1A1B1A1A1A1A1A1A1A1B1A1B1B1A1B1A1B191B1B1B1D1B1C1B1B1C1B1A1B
1B1C1B1C1B1A1C1D1C1B1B1C1C1C1C1D1C1C1C1B1C1C1C1C1B1D1C1D1C1C1C1C1C1E1C1D
1C1C1C1C1D1C1C1D1D1D1C1D1D1E1E1D1F1E1E201F1E1F1E1D1D1E1D1E1E1E1F1E1E1F20
1F1F1F2020211F1F201F202120211F212122202020212223222122222323232223232425
252525242425242525262626262526272826282628282A2929292B2A2C292B2C2A2D2D2D
2C2E2E2F31302F30323033333333353536363738393A3A3D3C3D3E3F3E41424342454547
494A4D4F4F5051535759595C5E5F62656569696E717076767B7D8087888E8E9093989A9E
9EA4A3A6AAACABADAFAFADAFAFAEABAAA7A5A3A29E9B9A9692918D8987857D7C79757471
6D6A696661625F5C595758525352514E4E4D4C494645454244413F3F3F3C3C3B3A3B3A3A
3938363435333433323131322F302E2E2D2E2D2D2C2B2B2A2A2A282A2929282828292727
272727262625252525252424252524242525252324232422222222202121212022212021
201F20201F1F1F20201F201F1F1F1F1E1F1E1F1F1E1D1D1E1E1E1D1D1D1E1D1E1E1D1D1C
1D1D1D1C1C1D1D1E1D1C1D1C1C1B1C1C1D1B1C1C1D1C1C1D1B1C1B1B1B1B1B1B1C1B1B1B
1A1B1C1C1B1C1B1A1A1B1B1C1B1B1B1A1B191A1A1B1A1A191A1A19191A1A1A1A1B1B1A1A
1A1A1A1A191A1A1A
1A1A1B191B1B1B1A1A1A1A1A1A1A1A1A1A191A1B1A1A1B1B1B1C1C1C1C1B1B1A1C191B1B
1C1B1B1C1B1B1C1B1B1B1C1C1C1D1C1C1C1D1D1C1C1B1C1B1D1D1C1D1D1A1C1C1C1D1E1C
1C1C1C1C1D1C1C1D1C1D1D1E1D1D1C1E1D201F1F201E1E1E1D1E1E1C1E1F1E1E1F1E1F1F
1E1F1E1F201F1F1F212020201F2021202120212121202022222122212123232323252829
262424242325252525252426262526262727272829282828292A292A2B2B2B2B2B2C2D2C
2E2E2E2E2E2F3030303132313233343535373638383B393D3C3C3E404040414343454547
484C4B4D4D515252535459595C5D6162646667696C6F7576767B7D8184878B8F8D949596
9A9BA1A0A2A6A6A7A6A8A9A8A7A7A3A4A29F9E9A999592928C8B8A84817E7D7975716F6D
6C6965655F605E5C5957585351504E4E4B4B49484545454341413F403D3E3C3C3D3B3A3A
3837353335343631313332312E2F2E2F2E2D2D2B2D2D2B2A292B2A2A2928292A29272726
262826262625252423242425242525242424252423232223222220222220202222222120
1F1F1F1F1F1F201F1F1F1F1F1F201F1E1F1E1E1E1E1D1E1F1D1D1E1E1E1E1D1D1E1E1D1D
1D1D1D1D1E1D1E1D1C1C1E1D1C1B1C1D1B1B1C1C1B1B1B1D1B1C1B1D1D1B1B1C1C1B1B1A
1B1A1B1A1A1B1B1B1B1B1A1A1A1B1A1A1B1A191A1A191B1A1A1A1A1A1A1A1B1A1C1A1919
1A1A191A1A19181A
191A1A1B181B1A1A1B191A1B1A1A1B1A1A1B1B1B1B1C1C1A1B1B1B1C1C1D1D1B1C1C1C1B
1B1C1C1D1B1B1B1C1C1C1C1C1C1C1B1C1E1B1C1E1D1C1B1B1C1D1E1C1C1C1C1C1D1C1C1C
1D1C1C1D1D1C1D1C1D1D1C1E1D1E1D1E1E1F1E1E201D1F1E1D1F1E1E1F1F201E1F1F201F
1F1F1F1F1E1F1F20201E211F1F2020202021222121202122232322222122242323242527
2524242424252525242627262625262726272926272929282828292A2B2C2A2B2B2C2D2D
2D2C2D2E2E2F2F303031313233323334343636383739383B3D3D3C3D3E40424144444546
48484A4B4D504F52535656585B5C5E61656566696B6E7376787A7A7D828382898C8F9193
9598999E9E9FA09FA0A3A1A0A09FA09E9B9C979693918E8B898683807D7D797672726F6A
68666361615E5D5956555552504F4D4D4B4C4A4A4744444442413F3F3D3F3C3A3D3B3938
3736363533333231303231302F2F2E2E2E2C2C2C2B2B2B292B2C2A282929262728272726
282725252425242523252526242524252523232323222323222121212122202122202321
22201F201F20201F201F1F1D1F1E1F1D1F1E1F1F1E1E1E1E1E1E1D1E1E1D1E1D1E1C1D1D
1D1D1D1C1D1D1D1B1C1C1C1C1C1C1D1C1C1C1B1C1C1C1B1C1D1C1C1B1B1A1B1C1B1B1A1B
1B1B1A1B1B1B1A1B1C1B1C1A1A1B1A1B1B1A1B1A1A1A1A1A1A1A1A191A1A1B1B1B1A191A
19191A1A1A19191A
1A1A1A1A1A1B1A1A1B1B1B1B1B1B1A1A1B1B1A1B1A1A1A1B1B1B1B1C1C1B1B1B1C1C1B1D
1C1B1C1B1A1A1C1D1B1B1C1A1B1C1B1C1C1B1C1D1C1B1D1C1C1B1C1C1C1C1C1C1D1C1D1D
1D1D1D1C1C1C1C1D1D1E1D1B1D1D1E1D1E1E1F1E1F1F1E1F1D1D1E1E1E1E1F1F1F1D1E1F
1E201F1F1F20201F201F2021202021212121212021222322232321222223222123232525
242424232325242625252524262526262527262626282A28282828292A2B2A2B2B2B2C2C
2C2D2E2E2E2F2F303131303132333334343637373839393B3A3D3D3D3E3F414043424247
48484A4D4D4D504F535354585A5D5C5D5F6565686C6C6E727476777B7D7F8383878C8A8C
909294949599999B9C9B9B9E99979B95949393928E8E8B888582807E7E797773726E6C68
696464605E5B5A585656525150504F4C4B4A48474643434340403D3F3E3B3C3D3D3D3B38
3A35343535343030302F313030302F2D2D2C2C2D2C2B2C29282B29292929282727272727
272625262527252624232425242425262424242223232222212222222221212221212121
1F20201F201F1D1F1F1E1F1F1F1D1E1E1E1E1F1D1E1E1E1D1E1D1F1D1D1E1D1E1D1D1E1C
1D1C1D1E1D1C1C1C1C1C1D1C1D1C1D1C1D1C1B1A1D1C1B1B1B1B1B191B1C1C1D1B1C1B1B
1B1C1C1B1B1C1B1C1B1B1A1B1B1B1B1A1B191A1A1A1B1A1B1A1A1B191A1A191A19191A1B
1A191A191A191819
1A191A1B19191A1B1A1B1B1A1A1B1B1B1A1A1B1A1A1A1C1B1A1C1C1A1A1A1C1C1B1C1C1C
1B1C1B1C1B1C1C1C1B1B1D1B1C1B1C1C1C1C1C1B1D1D1B1C1C1C1C1C1B1E1C1C1C1C1C1E
1D1E1C1D1D1D1C1D1E1D1E1D1E1D1F1E1E1E1E1E1E1E1E1E1D1F1F1E1E1E1E1E1E1E201F
1E201F1F1E201F201F1F2021202120202020202022212120222221222222232222232423
2425232423232424252625252626262626262827282828292929292829292A2A2C2C2C2C
2D2C2E2F2D2E2F2F303230313433323434363636383838393B3C3D3D3F3F403F41434445
464A4B4D4A4F4F505152545557595B5D5E606263686B6B7073727777797C808083878889
8D8C909194929596969894969695939092908D8B8986858180807C7A787774726F6B6B68
656361635D5C5957545353504F4F4E4E4A48454845444241413F3E3D3B3D3B3C3B3A3A38
37353334333233313131302F2F2E2D2E2D2D2C2C2C2B2B2A2A2A292A292A272827282727
252625262524252424252325232424232324232323232223232221212121202021212120
212020201E1F1E201F1F1F1F1F1E1E1F1E1E1D1E1E1E1D1D1E1F1E1D1E1D1C1D1D1D1D1C
1D1C1D1D1E1B1C1B1C1C1C1C1C1C1C1C1C1B1B1B1B1C1C1B1B1C1C1C1C1C1C1B1B1C1B1B
1C1B1B1B1C1B1B1C1B1B1B1C1B1B1A1B1B191B1A1A1A1A1B1A1B1B1C1A1A1A1A1A1A1A1A
19191A191A191819
1A191A1B19181A1B1B1A1B1A1B1A1A1A1B1B191B1A1A1B1C1B1C1C1B1B1A1B1B1B1A1C1D
1B1C1D1B1B1C1B1D1B1B1C1A1B1B1C1C1C1B1B1D1B1B1D1B1B1D1D1C1C1D1B1D1D1A1D1C
1D1D1D1C1D1D1D1D1D1D1E1E1D1D1D1D1E1F1D1F1D1D1F1F1E1E1F1E1E1F1F1F1E1F1F1E
1F1F2020201F1F201F202021202020212020222222212121212121222121222322232323
242424252625252525242624262726272625272727282728282A2A2A292B2B2C2A2B2C2D
2E2D2D2E2D2F2F3030313130343132353534363837393B393C3B3C3C3D3D3E4141424445
47474949494B4D4F4F51565357575A5B5D5F616364696B6D6D70727276797A7F7E7F8484
87898A898E8E919191909190928D8D8E8D8A898585827F7F7B7E7B7774736E706E6C6864
636160605D5B59555552524F4F4C4C4C4948474544414241403F3F3E3C3B3A3B3B3A3838
363634343232303030302F30302F2E2D2D2C2A2B2B2B2B2A2A292C292829272726272627
262625242425242525252424242423232424232322212122222221212123212020212020
1F201F1F1F1F201F1F1F1F201E201E201E1D1E1E1F1E1D1D1E1D1D1E1D1D1D1C1E1C1D1D
1C1C1D1D1E1D1D1D1E1B1C1C1D1C1C1C1D1B1D1C1C1B1B1B1C1B1B1B1B1C1B1B1A1B1C1B
1B1A1B1A1C1B1A1B1C1B1B1B1A1B1C1B1B1A1B1A1A1A1A1B1A1A1B1A19191A1A191A1A19
19191A1A1A191A1A
1A19191A191A1B1B1A1A1B1A1A1A1B1A1A1B191A1A191A1B1B1A1C1B1A1B1A1C1C1B1A1B
1B1B1B1C1C1A1C1C1B1D1D1B1C1C1B1B1B1C1B1D1D1D1C1C1B1C1B1C1D1C1B1C1D1D1C1C
1C1C1D1C1C1C1C1D1D1C1E1E1E1E1E1E1E1E1E1E1D1E1D1E1F1E1D1D1E1E1E1C1D1F1F1F
1E201F211F1F201F1F202120211E20202121212121212122232121212222222323232324
23232324232424242526252725272526272626272828272827292B292A2B2C2C2D2B2C2C
2D2D2E2F2D2F3130303131313234323332353636373939383B3D3B3D3D3E3E3F41424545
4446474A4B4B4E4F50515355555757595D5D5E6162656A696D6D6E717275777D7C7D8280
84858588898A8A8B8C8D8B8C8B8C8B888786848182817E797A79787573716D6B6A686563
625E5E5B595656545451504F4E4C4B4949474643444442413E3F3F3B3B3A3C3A3A393737
3535333534323332312F2F2D2F2E2D2C2C2C2C2C2B2B2B2A2A2A2A29292A282826282726
2825252524252426252425252424252323232222222322232221222221212120201F1F21
20202021201F1D1F1F1F1F201F201F1E1F1D1D1D1E1D1D1D1E1D1D1D1D1E1D1D1E1D1D1C
1E1C1E1C1D1D1C1D1E1B1C1D1D1C1D1C1C1C1C1A1C1A1C1B1B1C1C1C1A1B1C1B1B1B1B1B
1B1B1B1A1B1B1B1B1A1B1A1A1B1B1A1A1A1A1B1A1A1A1A1A1A1A1A1C1B1A1A1A1B1A1A1B
1A18191A1A1A191A
1A18191B1B1A1B1B1C1B1A1A1B1A1C1C1A1A1B1A1B1A1A1B1C1B1A1A1B1B1B1C1C1C1B1C
1A1C1C1B1C1B1C1C1C1C1C1B1C1B1C1B1B1C1B1D1C1B1C1C1C1C1C1C1C1D1C1B1C1C1C1D
1D1C1C1D1D1D1D1E1D1D1D1E1D1E1E1E1C1E1D1E1E1F1E1E1F1E1E1F1F1C1D1E1F1F1F1F
1D1E1F1E1F201F1F1F202020221F21212021202121212121212220212222232422242322
24242423242324252524272425272626262526272728292827282829292A2A2A2C2B2C2B
2D2B2E2D2E2E2F302F303031323332323435353636383939393C3A3C3E3E3F4141404243
424748474A4B4B4E4F505053545558585A5A5E5F616565696A6A6D6E71727677797A7B7D
808182828587858786888A878886848381817E7F7D7B7A787474746E706F6E6967666361
605D5B5B5757545451524E4E4E4B4A49464746444244403F3E3D3C3D3C3C3B3939383637
3536353432323032322F302F2F2F2D2C2C2C2D2C2D2A2B2A292B2A292729292727272727
272625282426242425242325232423222423232122232022222122202121201F2021211F
20201F2020201E201F20201F1F1F201E1F1E1F1D1E1E1E1C1E1F1E1D1D1D1E1D1D1D1D1D
1E1C1C1D1B1E1E1D1B1D1D1C1C1B1C1C1C1C1B1C1B1C1C1C1B1C1B1B1B1C1B1A1B191B1C
1B1B1B1B1B1B1A1C1C1C1B1A191B191B191A1B1B1A1B1A1A1B1A1A1B1B1B191A1A1A1A1A
191A18181A191A19
1B191A1B1A1B1A1C1A1D1A191A1A1B1A1A1B1A1A1B1B191A1B1B1A1B1B1C1C1A1C1B1B1B
1B1B1B1B1B1A1B1B1C1C1B1D1C1C1B1C1A1C1C1B1D1A1C1C1D1C1C1B1D1D1C1C1C1C1C1D
1C1D1D1C1C1D1E1D1D1D1D1D1E1E1E1D1D1E1E1D1F1E1E1D1E1E1D1E1F1E1D1E1F21201F
201F1E1F1F1F1E1F201F20201F2022202020212020202221222222212223232422232323
24232524262325262526252526242427282527272828282828292A2A292B292A2A2B2D2C
2D2C2E2E2D2E2F2E2F30303132333333353436363637393A3A393B3B3D3E3E4040424242
43444849484C4A4B4E4E5051525556565A5C5C5E6263636667676B6B6C6F72737678787A
7B7D7E7C7E7F8082808182818382808181807E7B7A7878737472706E6D6A6B6964646060
5F5C5B5A57575354504F4C4E4E4C494A454744424342403F3E3D3C3C3C3A3B3A38383736
343533343131313030302E2F302C2D2D2E2C2C2A2B2A2B2B2A2A282A2826282827272627
26262625262424252523242423232424232422222322212121222222222120202220211F
1F1F1F201F201F1F1E1E1F1E1E1E201E1E1D1E1D1D1D1D1E1E1C1D1D1E1D1D1E1E1D1D1D
1C1D1C1C1D1C1E1D1C1D1E1D1C1B1C1C1C1C1C1B1C1C1B1B1B1C1A1B1B1B1B1B1C1C1B1B
1C1A1B1B1B1B1B1C1A1B1A1B1B1B1B1B1B1A1B1A1B1B1B1B191A1A1A1A1A1A1A19191B1A
1A1A1919181A191A
1A1B1B1A1A1A1B1A1B1B1B1B1A1A1B1A1A191B1A1B1B1B1B1A1A1A1A1B1B1C1B1A1A1B1B
1B1C1B1B1B1B1B1C1C1C1C1C1C1C1D1B1C1C1A1D1C1B1B1D1C1C1C1D1C1E1E1C1C1C1D1D
1D1C1D1D1D1E1C1C1C1E1E1E1E1C1E1E1C1D1D1D1D1D1D1D1E1E1E1E1E1E1F1E1E1F1F20
201F1F1E1F1F1F1F20201F20202120202021212020212123212121222123232423232323
232324242424232526252525252626262626272626272628282829292C2A2A2B2B2B2B2C
2B2F2C2D2D2D2F303030323232323232333434363637373A393A393C3D3E3D3F403E4040
4443464848494B4B4B4F4F515152555656585C5F5D6060626566676A6A6E6F7172757575
79797A7A7B7A7D7A7D7D7F7D7F7C7C7C7B787879767373716F6D6B6B6B726C6563625F60
5B5C5A56545352524F4F4F4C4C4C48474546444241423F413D3C3C3C3D39383838373736
35353535313331312F2F302F2E2D2C2E2B2C2B2B2B2A2A292829282A2828282727282726
262625252626252523252324222323252223232223232322232221222021201F2221201F
1F1F1E1F1F201F1F1E201F1E1E1F1F1F1D1D1E1F1E1D1E1D1E1D1D1E1D1D1E1D1D1D1D1C
1D1C1D1C1C1D1D1D1C1D1E1C1D1D1B1C1C1B1C1D1C1B1C1C1B1D1C1C1C1C1C1B1A1B1B19
1A1C1A1B1C1A1B1B1B1B1B1A1A1B1A1A1B1C1B1B1B1B1A1B1A1B1B1A1B1B1B1A1B191A1A
191B191B1A191819
1A19191B19191B1A1B1A1A1A1B1A1B1A1A1B1A1A1B1A1A1A1A1A1A1A1C1B1B1C1C1B1C1C
1C1B1B1C1B1C1C1C1C1C1C1C1B1C1B1C1A1B1B1D1C1B1D1C1C1C1C1C1B1C1C1D1C1D1B1D
1C1E1D1D1D1D1C1F1D1E1D1E1D1E1C1E1D1E1F1E1E1F1D1D1E1D1E1E1E1E1E1E1C1E1F1F
1F1F1E1F1E1F201E1F202020202020212121212121212021222123222122222322222322
242523242423252426252725272626262727272828282828292929292B2A282B2A2A2C2C
2B2E2E2E2E2E2E2F2F3030313231343435353436353736373A39393A3C3C3D3E3E3F3F43
4344454447484A4C4D4D4F4F505153555658595B5E5F5F6161636469696C6C6D6F707172
74757574787977797A7879797A7979787A75747473706E706E6A6A69697E6D62625F5E60
5B5957555451504F4E4F4D4A4A4A46464642444141413E3E3D3B3D3B393A383839373635
343433333331313230302F2F2D2E2D2D2D2D2B2B2B2A292A292928282A27272827272626
262626262525242425242324242223222323232222222122232122222121202021212020
20211F1F2021201F1F1E1E1D1F1F1E1F1F1E1E1E1E1E1D1E1D1E1E1C1D1D1D1D1E1D1D1D
1C1E1D1C1C1C1E1D1B1C1C1C1D1C1C1D1B1C1B1C1C1D1C1B1C1C1C1B1B1C1B1B1B1B1C1B
1B1A1C1B1B1A1A1B1B1B1B1B1B1C1C1B1B1A1B1B1A1B191A1B1B1B1A1B1A1A19191A1A19
1B191A1A1A1A1A19
1B191A1A1B191B1B1A1B1A1A1B1A1A191B1A1A1A1A1B1A1B1B1A1A1A1C1C1B1B1A1B1C1C
1B1B1B1B1B1B1C1C1C1C1B1C1B1C1C1B1B1B1D1C1C1B1C1C1D1D1B1A1C1C1D1C1C1D1D1C
1C1D1D1C1D1C1E1D1D1D1D1D1D1E1E1D1D1D1D1E1E1E1E1D1D1B1E1F1F1E1E1E1E1F1F1F
1F20201F1F1E20202220201F202121201F1F212021202022212222222223232122232223
2224232424242424252525262625252626282727272828282729292829292A2A2D2B2A2B
2C2D2D2D2E2D2F2E2E31303132323232313333343538383937393A3B3B3B3B3E3D403F42
42454445484648494C4A4E4F4F515354545859595C5C5E5E6062636768696B6A6B6C6D70
7172737576727475767776767674757573717171716E6B6A6867696763616160605E5C5C
5B5854545352514D4F4D4B4A494A45464542414041403E3C3D3B3A3B3939393837373535
34343332313131322F2F2F2E2E2E2C2C2A2B2B2A2B2A2B2A282828282727282727272726
262724242524252525242424252323232323222424222321232121212221212122211E1F
1F1F1F201E1F1F1E1E1F1F1F1F1E1E1F1F1E1E1F1F1E1E1E1F1E1E1D1E1D1D1D1B1E1D1D
1C1D1E1C1C1C1D1D1D1C1D1C1C1C1D1C1D1B1C1D1C1B1C1C1B1C1D1C1B1C191C1B1B1C1B
191B1A1B1B1B1A1B1A1B1A1B1A1B1A1B1B1A1C1A1B1A1A1B1B1B1A1A1A191A1B191A1A19
1A1A1A1919191919
1A1A1B1A1A1A1B1A1B1A1A1B1A1B1B1A1A1A1C1B1B1B1A1B1A1C1C1B1B1A1B1B1B1B1B1C
1B1A1B1B1A1C1C1B1B1B1B1B1C1C1C1B1B1B1C1D1A1C1C1B1B1B1D1D1C1C1D1C1C1D1C1C
1E1C1C1C1D1E1C1E1C1E1E1E1D1D1D1C1C1D1D1E1E1E1E1E1E1D1D1E1E1E1F1D1F1E1F1F
201E1F1F201E1F1E20201F1F202121212120212020212221212321222322212123222323
2423252323232424262625262525252628262527282827282829292A28282A2C2B2C2B2C
2C2E2E2D2E2E2E2F302E2F313133313233343334363634373938393A3B3D3C3C3E3F3F40
42434145464548484A4A4D4F4D505152545554565A595B5F5F606164656666686869696D
6D6F6F6E717371727374717172746F6D6C6F6C6D6C6A6967676565646162605F5D5A595B
5855545251504F4E4A4B494849484645454342423F3E3D3B3B39393A3939393737363534
3433323332333031302E2E2F2F2C2D2D2B2C2C2B2B2B292B282828282828262827272627
262625262424242424242423252324232123232322222222222120222123222120212120
20202121211E1F1F1E1F1F1F1E1D1E1D1E1D1D1E1E1D1E1E1E1E1D1D1D1D1E1E1D1D1E1D
1C1D1C1C1D1C1D1C1C1D1C1C1D1B1C1D1C1D1C1A1C1C1C1B1B1D1C1B1C1B1C1B1A1C1B1A
1A1B1B1C1B1B1A1A1A1C1B1B1C1C1B1B1C191A1A1B1B191A1A1A1C1A1A191A1A1A1A1A1A
1A191A1A19191A18
1A191A191A1A1A1A191A1A1A1B1B1A1A1B1C1B191C1B1A1B1A191B1B1C1A1B1A1B1B1B1A
1B1A1B1B1B1C1A1B1B1B1B1C1B1C1C1B1B1C1B1B1C1C1B1B1C1D1C1B1D1C1C1C1C1C1C1C
1D1D1D1C1C1E1E1D1D1E1C1D1D1E1D1D1E1F1D1C1E1E1D1D1E1E1E1D1F1E1E1D1F1F1F1F
1E1F211F1F1F1F1F1F201F1F212120201F21212220212121222222222222232223242324
242324242424262424252525252326262825262727282827282A28282A2A29292B2B2B2C
2D2C2D2D2F2D2D2D2F2F31323230333233323533353537373838383B3A3B3C3D3B3E3F3F
42414345444646494A4B494C4D4F4F50515456565759595A5B5D5F606261656567656869
6A6B6B6F6C6F6F6E6F6D6E6E6E6E6C6C6C6B6A6A6A676766656362605F5E5F5C5B5A5957
57525051514F4D4D4B4C48484745454645413F41403E3C3D3C3A3A383938373736343535
353333303131312F302F2E2F2D2D2C2D2D2D2A292A2A2A29282828292729282826252626
262525252425242323232424232322232221222122202222222022212121202120202121
2021201F1F201F1E1F201F1F1E1F1E1E1E1D1E1E1D1E1E1E1E1E1D1E1E1D1D1C1D1D1D1C
1E1C1E1D1D1D1D1D1C1C1C1D1C1B1B1D1C1C1B1B1C1B1A1C1C1B1C1C1B1B1B1B1B1B1B1B
1B1B1A1B1C1B1C1C1B1B1B1A1B1B1B1C1C1B1B1B1B1A1A1A191A191B1A1A1B1A191B1918
1A19191A1B1A1919
1A1B191A1A1B1A1B1A1A1A1A1B1A1A1B1A1B1B1B1B1A1A1A1B1B1A1B1B1A1B1B1A1C1B1B
1B1B1C1B1B1B1B1B1A1C1B1B1C1C1B1C1A1C1B1B1C1D1C1B1C1C1D1C1B1C1D1C1C1C1D1D
1C1C1D1D1D1D1D1C1D1D1D1C1D1D1E1D1D1E1D1D1D1E1D1E1D1D1D1E1E1E1D1E201F1D1F
1F1F1E201F202021211F1F21202020212120202221212221212122222223222424202324
22232524242323242525252526252527242727262726272729282929282A292B2B2B2C2B
2C2D2C2D2F2D2F2F2E2F3030303230323432333334363537383939383A3B3D3B3D3D3E40
414344434444464749484A4B4A4B4F4F515253545557575A5B5A5F5F6061616363646667
6866686B6B6B6C6C6A6C6B69696A6C6B6966686766686563626161615E5B595A59585655
5353504F504F4B4C4B4A494945454545444140413E3F3C3B3B3A3B3A3937363637343435
323331323130302F2F2F2F2E2E2D2C2D2C2B2A2B2A2B2929292928282927262726262825
262624232425242424242423242222242223242122232322232320212120212121201F1F
1F1F1F201F201F1E1F1E1E1E201E1F1D1E1E1D1E1E1D1E1E1D1D1C1D1E1E1D1E1D1C1D1D
1D1D1C1D1C1C1C1C1C1C1D1D1C1E1B1C1D1D1A1D1B1C1B1B1C1C1B1B1B1B1B1B1C1B1A1D
1B1C1C1A1B1B1B1B1B1C1A1A1B1B1C1B1A1B1A1A1B1B1A1B1B1B1A1B1B191A1A1A191919
1B1B1A1B191A1919
1A1B1A1B1A191B1A1A191B1A1B1A1A1B1B1B1C1C1C1B1A1C1B1C1B1B1B1B1B1C1C1B1C1B
1B1A1B1C1B1C1A1B1C1C1C1B1A1B1B1B1B1C1B1A1B1C1C1C1B1C1D1C1C1D1C1C1C1B1D1C
1D1D1D1D1C1C1C1D1D1C1D1D1E1D1C1D1C1D1E1E1D1C1D1E1E1E1E1E1F1F1E1F1F1E1F1F
1F201E1F20201F1E1F1F1F2120201F21211F212122212221212221232221222322232322
23232423222424262523252525272627262627272727282727282829272A2A2B2A2B2B2B
2B2C2D2C2E2D2E2D2F2E302F303231353433343634353637373838393B3A383C3D3C3F3F
3F4142434445454747484B4B4A4D4E4E50515255545456575A5B5A5C5F5F5F6260636463
65656768686A6768666A67676866686665666666636262625F605D5E5959595858575353
52504E4D4D4A4B4B4A4946494543464242413F3E403E3D3B3A3A38393937363635353434
3231313332312F2F2E2F2E2D2D2C2C2C2C2A2B2B2A2A2829282827272626272626252525
252524252424242524222324232322232323222122222120222121212321211F21202120
20201F1F1E1F1E1E1F1E1E1E1F1E1F1D1D1E1E1E1E1E1D1E1F1E1E1E1D1E1D1D1D1D1D1C
1C1D1D1C1D1C1B1D1D1D1C1B1D1D1D1C1B1D1C1C1C1C1A1B1C1C1B1C1A1B191C1A1B1C1D
1A1B1C1A1B1B1B1A1C1B1B1B1B1C1A1C1B1A1B1B1B1A1A1B1B1B1B1B1B1C1A191A1B191A
1A19191B1919191A
1A1A1A1A1B1A191A1A1A1A1A19191A1B1B1C1C1B1B1A1C1A1B1B1B1C1A191A1C1C1C1C1B
1A1C1B1B1B1B1B1A1C1B1B1B1C1B1C1C1B1D1C1B1C1C1C1C1B1C1D1C1B1C1B1C1D1D1C1D
1D1D1C1B1D1E1D1D1D1D1D1D1D1C1D1D1D1D1C1F1E1D1E1E1F1E1E1E1E1E1F1E1E1F1E20
1F1E1E1E1E1E201F20211E202020211F212120211F212021222121222322242323212323
23232424242325232425242524252625262626262627272928272729292A2A292B2B2B2C
2B2C2D2D2D2E2D2F2E2F3030312F2E31323134323335353637373939393A3C3C3D3C3E3E
40404042444444464647484A4A4B4C4E4F4E5152535354565858585B5D5D5E5D605E5F61
6162656564646363646565666565646363616462615F5F5F5E5E5B5B5959585757545454
4E4F504D4D4D4949494644454344424240403F3E3D3C3B3A3A393A383736363633333335
32323131302F302F2E2E2D2C2D2C2D2B2A2A2B2B292A292A28292A272728272626252626
252525242525242425232424252424222323222322222322222220202121212021211F1F
20211F1F201F1E1F1E1F1F1E1E1E1E1E1D1C1E1F1E1D1D1E1D1F1E1E1E1E1C1D1C1D1C1D
1E1D1C1D1C1C1C1D1C1C1D1D1C1C1C1C1C1A1B1C1D1B1C1C1C1A1C1C1C1B1B1B1A1C1B1C
1C1B1B1C1C1C1C1B1B1B1B1B1B1A1B1A1A1A1A1A1A1A1B1B1B1A1A1A191A1B1B1A1A1A1A
1A1B1A191A1A1A1A
1A191B1A19191A1A1A1B1B1B1A1B1A1B1B1A1A1A1A1B1C1B1A1A1A1B1B1A1B1B1B1C1C1B
1B1B1B1B1B1A1B1C1B1A1A1C1A1A1B1B1C1B1B1B1C1B1D1B1C1C1B1B1C1D1D1C1C1C1C1D
1E1D1C1D1D1D1E1D1C1D1D1D1D1C1D1D1D1D1E1C1E1D1F1D1E1E1F1E1E1F1F1E1F1F1E1F
1F1F1F1F1F1F20202120201F202021202120202021212121212222232321232323212324
24242423242424242324242525252525262628252727272727292627272A2A292B292B2A
2B2B2B2C2C2D2E2E2D2F2F30303132313232333532353535353739383A393A3B3E3B3E3E
3F41404141434444454749494A4B4C4D4E4E50515251535356555756595A5D5C5B605D5F
6061616360646562626062626362616260606161605C5B5C5B59595A5858575454535250
504F4C4E49494A474747444343434343403F3E3F3C3B3B3A393A38383636343535343333
3131323130312E2F2E2D2D2D2D2D2C2A2A2C29292A282A2928272A272827272626272726
25252626242525232324242323232423232322222221222122232021211F212020201F1F
20201F201E1F1F1F1F1F1F1E1E1D1E1E1E1E1F1E1E1E1E1D1E1D1D1D1E1D1E1D1C1D1D1C
1C1C1E1C1C1D1C1E1C1C1C1B1D1B1B1C1B1C1C1C1D1C1B1C1B1C1C1B1C1B1B1C1C1C1B1B
1D1B1B1C1B1B1A1B1B1A1B1A1B1A1B1A1A1A1A1A1A191A1A1B1A1B1B1A1A1A1A191B1A1A
191A191A19191A19
1A19181B1A1A1B1A1A1A1A1A1B1B1B1C1B1A1B1B1B191B1B1B1A1B1C1C1A1A1C1C1C1A1B
1B1C1C1B1B1A1B1B1C1C1A1B1B1C1C1C1C1C1C1C1D1C1C1C1C1C1B1C1C1C1B1C1C1C1B1C
1D1D1C1D1E1D1D1D1C1D1D1D1D1D1D1D1D1E1D1D1E1E1D1E1E1F1E1F1F1E1E1F1F1E1E1E
1F1F1E201F1E1F20201F1F20202020212321212022222222222222222222242223242323
2324232323242425252525242526272526252626262826272927282828292A292A2B2A2C
2C2D2B2D2D2C2D2E2E3031302E31313132323334333436363736363739393C3B3C3D3E3C
3F3F4141424343464447464A49494C4C4C4D4F504F525252555358575959585A5B5B5B5E
5D5D6060605F64605F605F5F5E6160625F5E5E5E5D5C5B5A59555A565755545251504E50
4D4D4B4A4A4A48474745424441424141403E3D3C3C3B3B39383837373737343534333331
323131322F2F2F2F2E2D2D2C2C2B2C2A2B2A2A292B292929282727282726272626252524
262426242426232324242423232324232223232323232223212121202121201F1F20201F
1F1F201F201F201F1F1F1E1F1E1E1D1E1E1D1D1E1F1D1D1E1D1E1F1D1D1E1D1D1C1D1C1D
1E1D1D1D1D1D1C1B1C1C1C1C1D1C1C1C1C1C1C1B1C1B1D1C1B1C1C1B1B1B1B1B1B1B1A1B
1B1B1B191A1B191A1A1A1A1B1B1B1A1A1B1B1B1A1A1A1B1B191A1A1A1A1B191A1B19191A
1A19181A19191818
1A1A1A1A191A1A1B191A1A1A1B1A1C1B1B1B1A1B1C1C1B1B1B1B1B1A1B191B1B1B1B1C19
1C1C1B1A1C1C1C1C1C1B1C1B1B1C1B1C1C1C1C1C1A1C1C1C1D1C1C1D1C1C1D1D1C1C1B1C
1C1C1D1C1C1D1B1D1D1D1C1D1D1D1D1E1D1E1E1D1E1E1E1E1E1D1E201F1D1F1F1F1F1E1F
1F1F1E1E1F20202120211F201E2020202122202021202222222122212322222323222323
2523232323232424242525242324252426252627272727272927282A28292A2A2A2B2B2B
2C2C2B2C2D2C2D2E2E2E2E2E31303131313232323332363736383636383A3A3A3C3C3A3D
3D3F3E3F404242434444464848484A4B4B4C4D4E4E4F505152525356565556595A595A5B
5C5C5B5E5B605D5D5F5E5B5D5D5C5D5B5C5B5B5A5A5A5958585756535553535051504F4E
4E4D4A4A4B47464645454342424140403F3E3D3C3A3A3939373736363536343433343333
3231313030302F2F2D2C2E2C2C2D2B2B2A2C2B292A282829282827272728262527272626
25262525242525232323242423232223222222242223232322202020211F202120211F20
1F2121201F1E1F1E1F1E1F1E1F1E1E1E1D1E1F1E1E1E1D1D1D1D1E1D1D1D1D1F1D1D1C1E
1D1C1D1C1C1D1C1C1C1D1C1C1C1C1C1D1C1C1D1D1C1C1B1B1C1C1B1B1B1B1B1B1A1B1C1C
1B1B1B1B1B1A1B1B1B1C1B1C1B1A1B1A1B1A1A1B1B1A1A1B1A1A1A1A191A1A1B1A1A1A19
1B19191A19191919
1A1A1A1A1A1A1A1A19191A1B1B1B1A1B1B1A1B1B1A1C1B1B1B1C1B1B1A1B1B1A1A1B1C1C
1B1B1B1A1B1C1A1B1D1B1B1C1B1D1B1C1C1D1B1C1B1C1C1B1C1D1B1C1C1C1D1C1C1C1C1D
1C1C1C1D1D1D1E1C1D1B1E1D1D1C1D1C1D1E1D1D1E1D1E1D1F1F1F1E1F1E1D1E1D1E1E20
1F1E1F1F1F201F20201F1F20202020212021222122202222212220232123232224222123
22232324242423242523252626252626262526262728272728282729292A2A282B2B2A2A
2B2B2C2C2D2D2D2D2E2E2E2F2E3030313133333332343435353636373739393B3A3B3C3D
3D3E3E3F4240404243434547474747494B4B4C4D4F504E4F535153525454535658565859
595B5A5C5B5C5B5B5C5C5D5C5B5A5A5959595759585858565553525352525150504F4D4B
4B4A494948434546444342433F3F403D3B3C3B3C3B3A3838383637373634343434323333
31303030302E2D2F2D2E2D2D2B2C2B292B2A2A292A282928282729282827272626262627
2425252523232224232325222223222321222221232323222221212122212022201F2020
1F20201F1F1D1E1E1F1E1E1D1F1E201F1E1E1F1E1E1D1E1E1D1D1F1D1E1D1E1C1E1D1D1E
1D1C1C1C1C1B1D1D1D1C1C1B1C1C1D1B1C1C1C1D1C1C1B1C1C1C1C1C1B1B1C1C1C1D1C1C
1B1A1B1C1B1B1B1A1A1A1A1A1A1B1A1B1B1B1A1B1B1A1A1A1B1A1B191A1A191A19191A1A
191B1A17191B1919
1B1A1A1A1A1A1A1A1A1A1A1B191A1A1B191A1A1C1B1A1C1B1C1B1C1A1B1C1C1A1A1A1D1C
1B1B1B1B1B1B1A1B1B1C1C1C1C1B1B1B1C1B1C1B1B1C1C1C1D1C1B1C1C1C1C1C1C1D1D1B
1C1D1D1C1D1D1C1C1D1D1D1C1E1D1D1D1E1E1E1E1D1D1C1D1E1F1F1F1E1F1E1E1F1F1F1F
1E201F1F1F1F1F201F202020201F201F201F212121212223212122222222222123222323
232323232323232324242526262626252626262726272726262928272A2B2A29292B2B2B
2B2B2D2C2D2D2C2D2D2F2E2F2F3030303231333233353434343636363736393B3A3A3C3C
3D3C3D3F403F41414343444545464749484A494B4B4C4D4D4E5050515355535455565756
57575756575B59595A595A5A58595956575756555655555653545450504F4F504E4C4C4B
494A48464747474543414344413F3F3F3C3C3B3B3A393938383637363535343434333133
313130312D2F2C2E2D2D2D2C2C2B2A2B2B2B2A282A282828282827282626252627262624
242526242525242422232323222321232123212221212121211F22202120202020201F20
1F1F201F1F1E1E201E1F1F201F1E1F1E1D1E1D1F1D1D1D1E1E1D1D1D1D1D1D1D1C1D1C1C
1C1E1C1C1C1C1C1C1C1C1C1C1D1D1D1D1C1C1C1C1C1B1C1B1B1C1C1B1B1C1B1C1D1C1B1A
1C1B1B1B1B1B1B1A1B1C1C1B1A1B1B1A1A1B1A1B191A1A1B1B1B1A1C1A1A191A1A1B1B1A
19191A19191A181A
1A191A1B1A1A1B1A1A1B1B1B1B1B1C1B1B1A1A1B1D1B1B1C1C1B1A1A1B1B1A1B1B1B1A1B
1B1C1D1B1B1B1B1B1A1B1B1C1C1B1C1A1B1B1A1B1A1B1C1D1D1C1C1C1C1C1D1B1D1C1C1D
1C1C1D1C1D1D1D1D1D1C1D1D1E1D1E1D1C1C1F1D1F1E1D1F1D1F1D1F1E1F1D1E1D1F1E1E
1F1E1F1F1F1F1F201F212021201F201F2020212121222121212222232322232423212122
22232324242323242425242524242726272626262627272627282728292929282A2A2A2B
2A2B2B2C2B2C2C2D2D2D2E2F2F312F31303132333234353533353436373839393B383B39
3C3D3E3C3E3E404140434143454547474749494B4C4C4B4E4E4F4F4F5150515454545454
545557555756585457585457555757575757535356545453515250504E4E4D4D4B4B4B4A
4A4747474544434243414240403E3D3E3D3C3A3B3A393937373636353434323233323132
30312F302F2E2D2E2D2D2C2B2D2A2A2C2A2928282A292928272728282525272726252626
252525242425232322232223222221212123212222212121212121202121201F201F2022
211F20201F1F1F1F1F1F1F1F1F1D1E1E1D1D1E1E1E1E1D1D1E1D1C1C1D1D1D1C1C1C1D1C
1E1B1C1C1C1C1D1C1D1B1D1E1C1C1C1D1C1C1C1C1B1D1C1B1B1C1D1D1C1B1B1C1D1C1B1B
1C1C1A1A1B1B1A1A1A1B1B1B1B1A1B1A1B1C1A1B1A1B1B191B1A1B1B1A1A191A1A1A1A1B
191A1A1919191919
1B1A191A1B1A19191A1B1B1A1A1B1B1B1B1B1C1B1B1B1C1B1B1B1C1B1C1A1B1C1B1B1B1B
1A1C1C1C1A1B1B1B1B1B1B1C1C1D1B1C1B1B1B1B1B1C1D1D1B1C1C1C1C1C1E1C1C1D1B1C
1D1D1C1D1D1E1D1D1D1D1D1E1D1C1D1C1E1D1E1D1E1E1F1D1D1D1E1E1E1F1D1E1F1E1F1E
1F1F1E1E20201E2120201F1F2020211F1F20212021212221222123232323232222232323
22232323232223242523232325242525262728272625272727282828282929292A2A292A
282C2D2C2B2C2C2D2E2F2E2F2E2F302F3031313231323333333535363737383739393A3A
3C3B3B3E3D3E403F424141424543454647464648484A4C4D4C4E4C4E4F4F515251515253
535455555554555452555555555655545654535352535150504F4F4F4D4D4C4C4C4A4948
46454745444143404140413E3F3E3B3D3C3B3B3A3B383837353735343334313232323131
302F2F2F2E2F2E2D2C2D2D2C292C2B2A2A2B2929292A2828282928282727252625262625
252524242224242423232324222321232323222222212121212120211E1F201F201E2021
1F2020201F1E1F1E1F1F1F1E1F1F1E1D1E1D1E1E1D1D1E1C1C1E1C1E1D1D1D1C1D1D1C1B
1E1E1C1C1C1C1D1D1D1C1B1C1D1C1B1B1C1C1C1C1C1C1D1B1B1C1B1B1C1D1D1D1C1B1B1D
1C1C1B1B1A1B1B1C1B1A1A1B1B1A1A1A1B1B1A1B1A1A191A191A1A1A1A1A1A1A1A1A1A1A
1A1A1A181A1A1A1A
1919191A191A1B1A1B1B1B1C1B1C1A1A1C1B1B1C1C1C1B1B1B1B1A1A1B1A1A1A1A1B1A1B
1B1B1B1B1B1C1A1B1D1B1C1C1C1C1C1C1C1B1B1C1C1D1C1C1C1A1C1D1C1C1D1D1C1C1D1C
1B1C1D1C1C1D1D1C1D1D1C1D1D1C1D1C1F1F1D1E1B1E1E1D1E1F1F1F1D1D1D201F1E1E1E
1F1F1F1E201F1F1F1E201F20212020202120202020222121212222222123222224232323
23232224232323222324242426252526252525272724272626272728282828292A292929
2A2B2C2C2B2C2D2D2E2E2E2E2D302F30313030323232333334353536373736373838393A
3A3B3B3C3C3D3F3F404043424445434546484848484A4A4C4C4C4C4D4F504E514F4F5151
52515252535354535452525354535254535151515151504E4E4D4F4E4C4A4B4B4A474947
484843444442414042413E3E3F3B3C3C3B3B3B3A38383736343534333333333331313130
302F2E2F2F2E2E2D2C2E2B2B2B2B2B2B2A2B292927272929282827272626282526262525
23242425242424242423222222222223202122212322212221201F21202020201F202120
202020201F1E1D201F1F1E1F1F1F1D1D1E1E1E1E1E1D1E1E1D1E1D1B1D1E1D1C1C1D1C1D
1B1D1D1C1D1C1C1C1C1C1E1B1C1C1C1C1C1C1B1C1C1C1C1B1B1B1D1B1B1C1C1B1B1C1C1C
1C1B1C1C1B1B1B1B1B1B1B1A1B1B1B1B1B1A1A19191A1B1B1B1A191B191A1A1A1B1A1919
1A1A1A1B1A1A1919
191A1B1A1A1A1A1A1A1A1B1A1B1C1A1B1A1C1B1B1B1B1B1C1C1B1B1C1A1A1B1A1A1B1A19
1B1B1B1A1B1C1B1C1B1B1C1C1B1C1B1A1C1C1B1B1A1C1C1C1B1C1D1D1B1D1B1C1E1D1D1C
1C1C1C1D1C1D1F1D1C1C1D1D1C1E1E1C1E1E1D1E1D1E1E1E1E1E1F1E1E1E1F1F1F1F1F1F
1E1F1F1E211F20201F1F2120211F21202021212121202020212121212222222121222322
232322232325252424222325252524252425262826282726272827292A2929292B2A2929
2A2A2C2B2B2C2B2D2D2C2F2F2E2F3030323030313334303434343637363736353838383B
393A3C3D3C3D3E3D40413E424343424444444545474647474A4A494C4C4C4C4E4E4F4F4D
4E4E5050514F515051525051515252525250504F504E4F4E4C4C4B4B4A4A4A4849474643
454744434241423F3F3F3F3F3D3C3B3C3C3B393838383736363534343333313131313132
3030302E2D2E2E2D2D2B2A2B2C2B2A2B2B2A2A2928292929282727262628282624252526
2424242525252423232223222222232221212222212121212122221F201F20201F212020
201F1F1F1F1F1D1E1E1E1E1F1E1D1D1F1D1E1E1E1E1D1E1C1E1C1D1D1C1D1E1D1C1D1D1D
1C1C1D1C1C1C1D1D1D1D1D1C1D1C1C1C1C1C1D1C1B1D1C1B1A1A1B1B1B1C1C1A1B1B1B1B
1C1C1B1A1A1B1A1A1B1A1A1A1A1B1A1B1A1A1A1A1B1A1A1A1C1B1A1B181B1B1B1A191A1B
1A1A1A1819191A19
1A1A19191A1A1B1B1A1A1B1A1B1B191B1B1B1C1C1C1C1C1B1C1A1A1B1C1C1A1B1B1C1B1B
1A1B1A1C1B1B1B1B1B1C1C1C1B1B1B1B1B1D1B1C1C1D1C1D1C1C1C1A1C1C1C1D1C1C1C1D
1D1D1C1E1C1B1D1C1D1D1D1D1D1E1C1D1E1F1D1D1E1E1E1E1F1D1F1E1D1E1F1F1E1D1E20
1F1F1F1F2121201F1F1F1E1E1F20212021202021201F2122202120222121232222222322
23232324232324222424252524262626262627262627272727282928292827282929292A
2B2B2B2B2C2C2D2C2D2D2D2E2F2E30302F31313031323332333433343536353835373738
3A383B383B3C3D3E3F3F43414140434443434446464546484849494A4C4A4C4B4C4D4D4E
4B4E4F504F4F4F514F504F50504F4F4F4E4E4E4D4E4D4D4B4D4B4B4B4949484A48484546
45444142414240403E3E3E3C3B3A3B39393A393938363737363435333233323133313030
2E2F2F2D2E2E2D2D2B2C2B2B2B2A29292A292A2927282927272827282726262625242525
2425242425232424232323232223232222222122212120202222202120212021201F2020
1F1F1F1E1F1E1E1F1F1E1E201F1F1E1E1E1D1E1D1E1E1D1E1D1E1E1D1C1D1C1C1D1E1C1D
1D1C1C1D1B1D1C1C1B1B1C1C1C1B1D1B1C1C1C1B1B1C1C1B1B1C1C1C1B1C1C1A1B1C1C1B
1C1C1C1B1B1B1A1A1C1A1B1B1A1A1A1A1B1B1A1B191A1A1A1A1B1A1C191A1A191B1A1919
1A1A1B1A1A19191A
1A191A1B1B1A1A1A1A191A1B1A1B1B1A1A1B1B1B1B1B1B1B1A1B1C1B1B1A1B1B1A1B1B1A
1A1B1B1B1B1C1C1B1B1C1C1A1B1C1B1C1C1C1B1B1C1C1C1C1C1C1C1B1C1C1C1D1C1D1D1C
1C1C1C1D1C1C1C1C1B1D1C1D1D1D1D1D1D1F1E1D1E1F1C1E1D1D1E1E1D1F1E1F1E1F1E1F
1E1F1F1F1F201E1F1F1F1F1F201F21201F20212121212122212221212223222221222223
24242323232524252424232524242525252525252626292728272628272827282A2A292B
2A2A2B2C2A2B2C2D2C2E2D2F2F302D2E303031323131333333343433363537353637383B
39393A3A3A3B3C3D3F3F3F404040414244444445464445474849494849494B4B4B4A4B4C
4B4F4C4F504E4E4F4E4E4D4E504F4C4E4C4C4E4C4C4D4B494A4A47474949464748434545
43414241403F3E3F3C3E3D3D3C3B383B3A3938383938363634353534323331313130312F
302E2F2F2E2E2D2D2B2C2B2A2A2A2A2A292A292A28272728272727272626252625252525
262423242423232323232223232122232321222221212320222021212020211F20201F1F
1E1F20201F1E1F1F1E1F201E1D1E1D1D1D1D1F1D1D1E1E1E1E1D1D1D1C1D1B1D1C1C1D1E
1D1D1D1B1C1C1C1B1C1C1C1C1B1C1D1C1C1C1B1C1C1C1B1B1C1B1A1B1B1A1C1B1B1C1B1B
1C1B1B1A1A1B1A1A1A1B1B1B1A191A1B1B1B1B1B19191B1A191A1A1A1A1A1B1A1A1A191A
18191A1A19191A1A
1A19191A1A1A1A1A1A1B1A1A1A191A1A1A1A1C1B1B1B1A1C1B1C1B1C1C1B1A1B1A1A1C1B
1B1B1C1B1B1C1B1B1B1C1C1B1B1B1B1B1C1C1C1C1B1B1B1B1C1B1C1B1C1C1D1D1C1C1D1D
1C1D1B1D1D1D1D1D1D1D1C1D1E1D1D1E1E1D1D1E1D1E1D1D1E1E1E1D1E1E1F1E1F1F1F1F
1E1E1F1F20201F1E20202020202021212020202120212122202222212323222322222223
222221222224242424242425232524242524252626282726262727272827292828292A29
2A2A2A2B2C2B2B2C2C2D2D2D2D2F2F2F2F31303031313233323232323334373538373739
38393A393B3B3A3C3E3E3F3D3F404041424142424444454446454A4849494B4948494A4C
4C4C4C4D4E4B4D4D4C4D4B4D494C4C4C4B4B4A4A4C4A4A4A494947474647444445444342
434240413F3E3E3E3C3C3E3B3A393A3838393839363536363534343331333230302F2F2F
2E302E2D2D2F2D2D2B2D2C2A2C292B292729282828272727282726242625272725242424
242324242323242323222422222222232122222221212120222121211F201F1F20201F1F
1F20201F1F211F1E1E201F1E1E1E1E1E1E1D1D1D1E1D1F1D1E1D1D1C1D1D1C1B1E1C1C1E
1D1C1D1B1A1E1C1D1C1A1C1D1C1C1B1C1C1C1B1C1C1B1A1C1B1D1C1B1B1B1C1C1B1B1B1B
1B1B1A1C1B1B1B191B191B1A1A1B1A1A1A1A1C1A1A1A1B1919181A1A1A1A1B1A191A191A
1A19191A1B1A191A
1B1A1A1A1A1A1A1A1B1A191B1A1A1B1A1B1A191A1B1A1C1B1A1B1D1A1B1B1A1A1B1A1B1B
1B1B1A1B1B1B1C1B1C1C191C1B1B1B1C1B1C1D1C1D1A1C1D1D1C1C1B1C1C1C1C1C1C1C1C
1E1C1C1D1C1D1D1D1D1C1D1D1C1D1D1D1D1D1D1E1D1E1E1E1E1C1E1E1E1E1D1E1D201F1F
1F1F1F1F201F1E201E1F1F2021202020201F212020212121222121232123222322222222
232324222323242324232423242524252525262525272626282727272728272829292A2A
2A292A2B2B2C2C2B2D2C2E2C2E2D2F2F2E2F303130313032343232323235363737373637
393839373A3A383C3C3D3E3E3E3F403F4241414143434344454647474948494948494749
4A49494A4A494A4C4C4A4A4B4C4A4B4A4A494A4749484846484546474545454442424242
4241413F3F3F3E3D3D3C3B3C3A39393A38363736363534353334323132323231312F2F31
2D2F2E2E2E2D2C2B2B2B2B292A2A2A2929292A2828282727272727262725252525252623
2524242324242423232122232221222121212122222022212120212121212020201F201F
1F1F1F1F201E1E1F201F1E1E1D1D1E1D1D1D1D1E1E1D1E1C1D1D1C1D1D1D1E1C1C1C1D1E
1C1D1D1D1D1D1C1C1C1C1C1D1B1C1C1B1D1B1C1B1C1C1B1C1C1C1C1B1B1B1B1A1B1C1C1B
1B1B1A1B191B1A1A1A1C181C1B1B1A1B1B191A1B1A1A1A1B1A1A1A1A1A1A1A1A1A1A1919
1A1A1A1A18191919
1B1A191A1B1A1A1A191B1B1A1A1B1B1B1A1B1A191A1B1A1B1B1B1B1C1A1B1B1B1A1B1C1B
1A1B1A1A1B1B1C1B1B1C1B1C1C1C1B1B1C1B1C1B1B1B1B1C1C1D1B1C1B1C1B1D1C1C1C1C
1D1D1D1C1C1D1E1D1D1C1D1E1C1D1D1E1D1D1E1F1D1E1F1D1E1D1E1E1F1F1E1F1F1E1E1F
1E1F1F1E1F201E201F202020202020222120212120212020212222222322232022222122
232224232323242323242424242525252625262526252626252726272728292A2929292A
2B2B2A2A2A2B2B2D2D2C2D2D2E2E2E2E2E2E2E3030313032313232333434343434343638
383838383A3B3A3A3C3B3C3E3D3C3D3E4040414043434243444544454548464646474847
4A494A494A4A4947494A4A4A4A494A494A4946494A474746484748464344424442444040
41403E3F3F3D3B3A3B3B393A39393837363736353635353433333334313031312E302F2F
2E2D2D2D2D2E2C2D2A2D2A2B2A2C2A292A29272829272827272726262426252426252524
2523232423242322232123232222232221222122212120212221212222211F202020201F
1F2120201F1F1E1F211F1E1D1D1E1E1F1F1F1E1D1D1C1D1D1E1D1D1B1D1D1E1D1D1D1D1C
1C1D1C1B1D1D1B1D1B1C1D1C1B1B1C1B1B1B1B1C1C1C1C1A1C1B1C1B1A1C1B1C1C1B1A1A
1C1A1A1B1B1A1B1B1B1B1A1A1B1B1B1B1A1B1B1A191A1B1A1A1A19191B1A1A1A191A191A
1A19191A1A1A1919
1A1A191A1A1A1A1B1A191C1B1A191A1B1A1B1B1A1A1C1C1A1C1B1C1A1B1B1B1B1B1C1C1A
1B1C191A1B1B1C1B1B1C1B1C1C1A1C1D1C1B1C1C1B1C1B1B1B1C1B1C1C1D1C1C1B1C1D1C
1E1C1D1D1D1D1D1D1D1D1D1C1E1E1F1D1D1D1E1D1E1D1E1F1D1D1F1E1F1E1F1F1F201E1F
201F20201F1F1E1E1E1F211F1F1F201F2120202020202121222022222122222222222222
222324232223222323232524252424262525262525252826262727282829272929292929
292A282B2A2B2C2A2B2C2C2C2C2D2E2E2F302E3231313132313033333332343534353737
3537393839393A3B3A3C3C3C3B3D3D3F3E3F414041424142414444444545464645454747
464648454746484947484748494947454846484645454545464544434243444140423F40
3F3E3F3C3D3C3C3B3B393A3939373738353834353433333333323232313031312F2F2F2F
2D2D2D2C2C2E2B2D2C2C2C2A2A2A292A2828282727272627272725272524252526252524
242423222423232223222323222220212321212121222122222222201F20202020201F1F
20201D1F1E20201E1E1E1E1E1D1E1F1E1E1D1E1E1E1E1D1C1E1D1E1D1C1D1D1C1E1D1D1D
1C1D1D1D1C1C1C1D1B1B1B1C1C1C1D1C1B1B1B1C1A1C1B1C1B1C1B1A1C1C1B1A1A1A1B1B
1B1C1A1A1C1B1A1A1A1C1A1A1B1A1C1A1A181B1A191B1A19191B1B1C19191A1B1A1A191B
1A1A1819191A1A1A
1A191B1A1B1A1A1A1A1A1B1B1C1B1B1B1A1A1B1C1B1A1B1B1C1B1B1A1B1B1B1B1C1A1B1A
1B1B1B1A1A1C1B1B1B1B1A1C1B1C1C1C1A1A1B1B1B1C1B1C1B1C1C1C1B1B1D1C1B1C1C1D
1D1D1D1C1D1D1C1E1F1D1D1D1D1C1E1D1E1E1D1D1E1C1D1E1E1E1D1E1D1E1E1E1E1F1F1E
1F1F1E1F1F1F20201F1F1F1F201F211F1F20212020222122212121212221232322212322
232123222323242223232424242425252524252527272626272727272728292928282929
292A292A2B2A2B2B2C2B2B2D2D2E2F2E302E303031303032313032323332343535343537
363636373939393A3B3A3B3C3B3B3D3D3D3D404040414040434442434244444446454345
46474645484546454748484646464648464545444545444444444443414140413F3F3E40
3F3F3E3B3C3C3B3B3B3B393839383737363536353532343332333130313031302F2E2E2E
2E2E2E2B2D2C2C2C2B2A2B282A2929282928272827272627262727252627262524252525
242424242422242323222223222223212222222120212222222121212020201F1F201F1F
1F201F20201F1E1F1E1E201E1E1E1E1E1F1E1E1F1F1E1D1E1C1D1E1E1D1D1E1C1E1D1E1C
1E1D1D1D1C1C1D1C1E1D1C1B1C1C1C1B1B1C1C1C1C1B1C1C1B1B1B1C1C1B1B1B1B1B1A1B
1C1A1B1B1B1B1A1A1A1C1B1B1A1A1B1A1A1A191B1A1A1919191A1A1A1B191C1A1A1B1B1A
1A191A1B19191A1A
1A1A1A1A1A1A1B1A1B1A1B1A1A1A1A1A1A1A1B1B1A1B1B1B1A1C1C1B1C1B191C1B1A1B1B
1C1D1B1B1B1B1B1B1C1B1B1C1A1A1C1B1D1B1C1C1D1C1C1B1C1D1C1C1D1C1C1D1D1C1C1C
1C1C1C1C1C1D1D1C1D1D1D1D1D1C1E1C1E1D1D1D1D1C1D1E1F1F1E1F1F1E1E201F1E1F1E
1F201E1F20201F1F201F1F20202020212021212222222221202021222121212222222221
222123232323212323242424242424242624242526242526252626262727282827282828
2A2A2A2A2A2B2A2A292C2C2C2C2C2D2C302D2F2E2F2F3132313132333232333236353637
3638363838373938393A3A3A3C3C3C3C3D3E403E3E3E4042414143424243414444454543
4342464544464544454448444446464546444442444543424243424341413E3F423F3E3F
403D3E3C3D3B3B3B3A3A3838373837353534343434333332323232333230302E2F2F2E2E
2D2D2E2B2C2B2B2B2B2A2A292928282A2827282827272726272625272727262524242524
25242422222323222323222222222221212121222122222121212121202020201E1D1F1F
201F1E1E1E1F1F201E1E1F1E1D1D1E1D1D1D1D1D1D1E1D1E1D1D1D1D1D1D1D1D1E1C1C1D
1D1D1C1C1C1D1C1C1C1C1C1C1C1A1C1B1B1C1B1C1B1B1C1C1C1B1B1C1A1B1C1B1B1C1C1B
1B1B1A1C1A1B1B1B1B1B1C1A1A1A1A1B1B1A1A1B1A1A1A1A191A191A1B1A1A1A1919191A
19191A181A1A1A1B
1A191A1A191A1A1B1B1A1B1A1A191A1A1B191A1B1A1A1C1B1B1B1B1A1C1B1A1B191A1B1B
1C1B1A1C1B1A1C1B1B1B1B1C1D1C1B1C1D1C1D1B1B1C1C1B1C1C1C1C1D1B1B1D1D1C1D1C
1C1C1C1C1D1C1D1D1D1C1D1D1D1D1E1D1D1C1C1E1D1E1D1D1E1D1D1E1E1D1E1E1E1E1E1F
1E1F1F201F1F201E20201F201F1F20202021212021212021222121212322202221222223
222223222323232323232325242624262425252525262527262627282727272828292729
2929292A292B2A2B2B2A2A2B2C2C2D2D2D2F2D2F302F3030313031313332333535343435
353535363738373839383B3B3B3B3A3A3D3C3D3D3D3E3F404142413F4142424243424145
44444345464442444545434444434545444544444244424142404040413F3E3F3E3E3B3E
3E3D3C3B3C3B3A3A3839393736373636353533343532323331313132322E302E2E2E2E2E
2D2E2C2C2D2C2B2B2B2A29292A2A29282828272727272727272626272528282526252524
25242323232224232223222122222223212121222121222121222020202021201F202021
1F1E1E1F1F1E1F1F1E1E1F1E1F1F1F1E1D1D1D1D1D1E1C1C1C1D1D1D1E1D1E1C1D1D1D1C
1E1C1D1C1D1B1C1B1B1C1C1C1B1C1C1C1B1B1B1B1B1C1C1B1B1C1C1B1B1B1A1A1A1B1C1B
1B1B1A1A1B1A1B1B1A1B1B1C1B1B1A1B1B1B1B191B1A1A1A19191B1B1B19191B1A1A191A
191A1B191B19191A
1A191A1B1B191A1A191A1B1C1A1A1B1B1A1A1A1A1A1B1A1A1B1A1B1B1A1B1B1A1B1A1C1B
1B1B1B1A1B1A1C1C1B1C1B1B1B1B1B1C1B1C1C1C1B1B1C1B1B1C1D1D1D1C1C1C1D1B1C1C
1D1C1C1C1C1D1D1D1C1D1C1D1D1F1B1D1D1C1D1E1C1E1D1E1D1E1E1E1E1E1E1F1F1F1F1F
1F201F1E1D1E201F1F20201F1F1F202021202121212121212C2D22212220222223202222
222222232223232323242322242323242524252525252426262726272828272728272928
282A2A292A2A2A2A2A2B2B2C2B2E2D2C2F2F2F2E2F302F2F312F31323132323333333435
35343636373635383938393A3A3B3A3B3A3C3B3B3D3D3E3F3E4040414041404041414042
42424341434142434244434441444444414342443F4341414140403F3F3D403F3E3C3C3B
3B3D3B3A3B3A383737383835353536343633333333323331313230302F2E2F2D2E2E2E2D
2C2C2D2C2B2B2A2B28292B29292928272727272725252627272625282626262626252525
242325232222232222232323222221212122212121202020212121201F2120211F201F1E
1F1E1F1F201E1E1F1E1D1D1E1E1E1E1F1E1E1D1D1D1D1C1D1C1D1D1C1D1E1E1C1C1D1D1E
1E1C1C1C1C1C1C1C1C1C1C1B1B1B1B1C1A1B1B1C1C1C1C1D1C1B1B1B1B1B1B1C1B1B1C1B
1C1B1B1C1B1C1C1B1B1B191C1B1A1A1B1B1B1A1B1B1B1A1A1B191A1A1A1A1A1A1A1A1B1A
1918191A191B1919
1A1A1A1A191A1A1B1A1A1A1A1B1A1A1A1A1A1A1B191A1A1B1B1B1A1B1A1A1A1A1B1C1C1B
1B1B1B1C1C1C1B1B1A1A1B1B1B1C1B1C1C1A1B1B1B1B1B1C1C1C1C1C1C1C1C1C1D1C1D1D
1C1C1C1C1C1D1C1D1D1E1D1C1E1D1E1E1D1D1D1D1D1D1E1E1C1E1E1E1F1F1E1F1F1F2020
1F1F201F201F1F1F1E1F1F1F201F21201F2123202121201F352323202023232222222221
232222222421232223242324232425232325252325272627262626262726272728292827
2929282A292A2A292B2C2A2B2D2C2C2C2E2C2E2E2E2F30302E2F30313033333332333335
363535363536353739393939393D393A3B3B3A3C3B3C3C3D3F3D3F3F404140403F404140
413F424241424440424143424343424243404042413F3F3E403F3F3E3F3C3E3C3D3D3B3B
3B3B3B3B3A3838383836363635363634353432333231323131302F30302F2F2E2E2C2E2E
2E2D2D2C2B2A2B2B2A292A29282927272727282726262525262626262626252626242423
252324242322242321222121202221232122212022212120211F201F20201F1F201F1F20
1E1E1E201E1F1F1E1E1F1F201E1E1E1F1E1F1C1D1E1D1C1E1D1D1C1E1E1C1C1E1C1C1D1D
1D1D1C1C1C1D1C1C1D1D1C1D1B1C1D1B1A1C1A1B1C1A1D1B1A1C1C1B1C1C1C1C1B1B1C1B
1B1B1B1A1A1A1C191C1B1B1A1A1A1B1B1B1A1A1B1B1A1A1A1B1A1B19191A191A1A1A1B1A
1A1A1A1B191A191B
1A1A181A191A1A1C1A1A1B1A1A1B1A1B1B1B1B1B1A1A1B1A1A1B1A1B1C1A1C1A1C1B1B1B
1C1C1B1B1B1C1B1B1C1B1B1B1C1C1C1B1B1C1A1D1C1D1C1D1B1B1C1C1B1B1C1D1C1C1E1C
1C1B1C1C1C1E1C1C1C1D1C1D1D1D1D1D1D1D1E1D1E1D1D1D1D1E1D1D1D201E1D1E1E1E1F
1F1F1E1F1E1E1F1F211F21201F201F2020201F201F202021222221222021232222222221
222224222223252322232325242423252425242426252626242527272828282727272829
27272A2A292A292B29292B2B2C2C2D2E2C2F2E2E2F2E2F3030312F313230313332323235
33353435353636363638383838393939383C3B3B3D3D3D3B3D3C3D3E3E3F403E403F403F
404140403F40403F414041404140414240424140403E3F3E3E3D3D3C3D3C3C3C3B3C3B3A
3B3A3B3A39383837373636363536343433343232323133302F312F2F2F2F2E2D2D2D2C2C
2C2B2C2D2B2A2A2B2A282928292828282727282828272628262627252626252424242524
2423242223222324222222202122202122212121212121201F201F20201F1F201F1F1E1F
20201E201F201E1E1E1F1F1E1E1F1D1D1F1F1E1D1D1D1D1E1D1D1C1C1D1C1E1C1C1D1B1C
1E1D1E1C1D1B1C1B1D1C1D1C1B1B1C1B1D1C1B1B1C1C1B1B1C1C1C1B1D1A1B1D1B1B1B1B
1B1A1B1B1B1B1A1A1A1B1B1B1A1B1B1A1B1A1B1B1A1A191A1B191A1A1A1A191A1A1A1B1A
1B1A1A1A1A191919
1A1A1A191B1A1A1B1A1A1B1B1B1B1B1B1B1A1A1B1A1B191A1A1B1B1B1C1B1C1B1B1B1A1B
1B1D1B1B1B1C1B1C1B1C1B1B1B1D1C1C1C1C1C1B1C1B1C1B1B1B1B1C1C1B1C1D1C1C1D1C
1C1C1C1E1C1C1C1D1D1D1D1E1D1D1D1D1D1D1D1E1D1C1D1D1D1D1E1E1E1D1D1F1E1F1F1F
1E1E201F1E1F2020201F1F201F1F21201F221F2021212021202121222222212121222122
222122212322222123242324242323242426262526262626252727262626272627272829
27272828292B2C282A2B2B2C2D2C2D2C2D2E2D2E2D2E2F2E2F2F2F2F2F30313130323432
34333535333635353637383837373839383A3B3A3B3A3C3E3D3D3C3B3F3D3E3E3E3E3D3C
3E3F403E403F3F3F4040403E40403F3F3F3F3E3F3D3E3E3D3C3D3D3D3C3C3C3B3C3A3A39
3C38393837363736353635343535333233333131313031332F2F2F2D2E2F2F2D2D2E2D2E
2C2D2A2A2B2A2A2A29292929292728282727282726262627252725252526252523252424
24222322212222222321222222232122222120212120211F2021202021202120211E2020
201F1E201F1E1E1F1E1E1D1E1E1E1F1D1D1F1E1C1C1E1D1D1E1D1D1D1D1D1D1D1C1D1C1C
1C1B1B1B1C1C1C1D1C1C1D1D1C1C1C1C1C1C1B1B1C1C1B1B1C1B1B1B1C1B191B1A1B1B1A
1C1B1B1A1B1C1B1B1B1B1A1A1A1B1A191B1A1B1A1A1A1A1B1B1A1A191A1A1A1B1A1B1A19
1A1A19191A191A1A
1B191A1A1A19191A19191A1A1A1A1B1B1A1B1A1B1C191A1A191A1B1A1C1A1B1C1B1A1B1A
1B1B1A1C1B1B1B1B1C1C1B1B1B1C1C1C1C1B1C1D1C1B1C1B1B1D1C1D1D1B1C1C1D1D1D1D
1B1C1B1C1C1C1C1C1D1D1D1D1D1D1D1D1E1D1E1D1C1D1E1E1D1E1D1F1E1E1E1F1E1F1E1F
1F1E1F1E1F201E201F1F202020202120211F202120202020212020212222212222222122
212122222223232323232324242525242424242424252426252528262727262727282727
27292928292A2A2A2A2A2B2B2B2C2C2D2D2D2E2D2F2D2E2E2F302F303130313030323333
323234333434353537373639363937383938383A3A3B3A3C3D3C3C3D3C3D3E3D3D3D3F3E
3F3D3E3F3F3F3E403E3F3F3E403E3E3E3E3E3E3E3C3D3D3C3D3D3C3B3C3B3B3B3839393A
383937373737373634383435343333343132323232302F31312E2D2E2E2F2F2D2D2C2C2C
2A2C2B2B2C2A29292A292A29282628272928272726272726262525252524232325242324
2322222222222322222222222021212222222121202120201F211F1F1F1F1F1F1D20201F
1F1F1E1E1F1E1F1F1D1F1E1F1D1D1D1E1E1E1D1D1D1D1E1D1E1D1E1E1D1D1C1D1D1C1D1C
1C1C1C1D1D1C1C1C1D1C1C1C1C1D1B1B1A1B1C1C1C1B1B1C1A1C1A1C1B1B1A1A1B1B1C19
1A1B1A1B1A1B1B1A1A1A1A1B1B1B1B1B1C1A1A1A1A1A1A1A1B1A1A1918191B1A181B1A1A
19191A1919191A19
1A1A1B191B1A1A1B191A1A1A1A191A1B1C1A1B191A1A191B1B1A1B1B1A1B1A1A1B1B1B1B
1B1C1B1B1B1C1B1B1C1B1B1C1C1B1B1C1C1C1D1B1C1C1C1C1B1B1B1B1C1B1D1C1C1C1B1C
1C1D1C1C1C1C1C1C1D1C1D1C1C1C1D1C1D1D1D1E1E1E1D1E1E1E1E1D1D1E1E1E1E1D1F1E
201E1E1F1F1F1F1F1F1F201F1F201F20201F202021212021212021222122222223222223
232223242223232223232422242322232424252425252525252626262625252626272829
29272728292A292B2B2A2B2B2A2D2D2C2D2C2C2D2D2E2E2D2E3030303031313030313031
3234343334333536353436373737363738373938383A3B393A3C3C3C3B3C3C3C3B3B3D3C
3C3C3C3D3F3E3B3D3F3C3F3D3D3C3F3E3E3E3C3D3C3C3B3B3B3A3B3A393A393939393938
393837383636353734343434323333333331313231302F302F2E2F2E2D2F2D2D2B2C2D2D
2B2B2B2A2A2A2B2929292828282928282828282728272726262424252325242324252323
232324232323222422232322212321202220212221201F202021201F202021201F1F1F1F
1E1F1F1F1E1E1E1F1F1E1E1D1E1E1E1F1D1E1C1C1D1E1E1D1E1C1E1E1D1D1D1D1C1C1C1C
1D1B1D1C1E1C1D1C1C1C1C1B1D1C1C1A1B1C1B1C1C1B1B1C1D1B1B1A1B1A1C1B1A1B1A1B
1B1B1A1A1B1B1B1A1C1A1B1B1A1A1B1A1A1A191A1A1A1A1A1A19191A1A1B1A1A191A191B
191B191819181A18
19191B1A1A191A1B1A1B191A1A1A1C1A191B1B191B1B191B1B1A1B1B1B1B1B1A1B1B1B1A
1A1B1C1B1C1B1B1D1C1C1C1B1A1B1C1C1B1B1C1B1C1B1B1C1D1C1D1D1C1B1C1C1C1B1D1C
1C1C1D1E1C1C1D1C1C1D1E1D1D1E1D1D1D1D1C1E1E1E1E1F1D1E1E1D1F1F1E1D1E1E1F1F
1E1E1E20201F1F201E20201F1F20202021201F2022202220212120212122222122222123
222324222223212223232324222425242425252626252426262526272627252527272728
272827282829282B2A2A2A2A2B2C2C2C2C2B2C2D2D2D2C302F2F30302F2F323330323131
3233323334343433353635363637363837373739393939393A393B3A3A3B3C3B3B3A3B3B
3D3B3E3D3C3C3B3C3D3E3D3D3C3D3D3B3C3D3C3C3B3A3B3B3B3A393A393839393A383939
37363637353535353634333431333231323130323030302F2E2F2D2E2E2D2D2E2D2D2C2C
2C2B2B2B2A29292A29292828282829272526272627282725262625252424232623242324
222423232322222222212122202121222021212021211F21202021211F1F1F1F1F20201E
1E1F1F1E201E1F1E1E1E1E1E1D1E1E1D1E1D1E1E1D1E1D1E1E1E1D1D1C1C1D1C1C1B1B1D
1D1C1C1B1C1D1D1D1E1C1B1D1B1B1C1B191C1B1B1D1B1B1B1A1C1A1B1B1A1C1B1C1B1A1A
1B1B1B1A1A1A1B1B1B1B1B1B1B1A1B1B1A1A1A1A1A1A1A1B1A1A1A191A1A1A191A1A1A1A
1919191A19191A19
1A1B1A191A1B1B1A1B1A1A1A1A191A1B1A1A1A1B1B1A1A1A1B1A1B1B1B1C1B1B1B1A1A1C
1C1C1C1A1C1C1A1B1A1C1C1B1C1C1B1B1C1D1A1B1C1B1B1B1D1C1C1C1C1C1C1B1E1D1D1D
1C1C1D1C1C1C1D1C1D1C1C1C1D1C1D1C1D1C1E1E1D1C1D1E1E1C1E1E1E1E1D201E1F1E1E
1D1F1F1F1F1F211E1F201F202120201F2020211F20202121222021222222212020222322
222122232122232323242122222423252323252224242626272626252625262627282826
282829292929292A28292B2A2A2B2B2C2C2C2B2C2D2E2B2F2F2F2F2F3031302F31323131
31323332333433343533353635363736363737373538373838393A3A3B3A3B393A3A3A3A
3C3A3A3B3C3B3C393B3C3C3C3C3C3C3C3C3B393C3A3B39393A3939393B38383839373838
3736383635353433333433333332313231313030302F2E30302E2E2F2F2D2B2C2C2B2D2B
2B292B2A2A2929292A282927272828282627282526262625262425252423252324242323
2522232123222221212222212221212220222122211E1F202021201F202020201F1E1F20
1E1F1F1E1E1E1E1F1F1F1D1E1D1F1E1E1E1C1E1D1D1E1D1C1D1C1D1E1D1D1D1C1B1C1D1D
1C1C1C1C1C1B1B1B1C1C1C1B1B1B1A1C1A1B1C1A1C1B1B1B1B1B1B1B1B1B1A1A1A1B1C1B
1C1B1B1A1C1A1B1A1B1B1B1A1A191A1A1B191A191B1A1A1A1B1A1A1A1A1B191B1A1A191A
1A1A1A1A1919191A
1A1A1919191A1A1B1B19191A1A191B1A1C1A1B1A191A1B1B1A1B1A1A1B1A1B1B1B1C1A1B
1A1B1B1B1A1B1B1B1C1C1A1B1C1B1A1B1B1D1B1B1B1B1C1C1B1C1C1B1C1C1C1C1D1C1C1C
1C1C1C1D1C1D1B1C1D1C1B1C1E1D1C1C1D1D1E1E1E1D1E1D1E1E1D1D1E1E1F1F1E1E1F1E
1F1F1E201F1E1F201F1F1E1F1F2020201E1F2120201E2122212220222121222221222122
222123222222222322222322232424252424242424262426252626262525262626262728
2829282A2929282A2A2A2A2A292A2B2D2A2C2B2C2B2D2D2C2E2D2E2E302F302F31313031
312F313233343334353534373535353736363635383837393A38383A393939393A3B3A39
3B3A3A3B3B3B3A3B3B3B3B3A3A3B3B393A3B3A393A393938393A38383838393838373738
35363536353734333331323432323332303130302E302E2E2E2D2F2C2D2D2D2A2B2B2C2C
2B2B29292928292929292728282729282828272626262727242624242425242323242422
2323232323212223212122212021212021211F20201F2021202020201F201F1F201F1E1E
1E1E1E1F201E1D1E1F1D1F1E1F1D1E1D1E1E1E1D1D1D1D1D1D1E1D1C1C1D1D1B1C1B1C1B
1C1D1A1B1B1B1C1D1D1B1C1B1B1B1B1B1C1C1A1C1B1B1C1B1B1B1A1A1B1B1B1B1C1C1A1B
1B191B1B1B1A1B1A1A1A1A1A1A1B1A1B1B1A1A1A191A1A191A1A1A191B1B1A191B1B1A19
1A19191A19191918
1A1A1A1A1B191B1B1A1A1A191B1B1A1A191B1A1A1B1B1A1A1C1A1B1B1B1B1B1B1C1C1C1C
1D1C1C1B1A1A1B1C1B1C1B1B1C1B1A1C1B1C1C1B1B1B1B1C1B1C1B1C1B1C1C1C1C1B1C1B
1C1C1D1D1D1B1C1D1C1C1D1C1C1E1E1C1B1E1E1D1D1E1D1C1E1C1E1D1E1E1E1E1E1E201F
1F1F1E201F1E1E1F1F201E1F1F1F202120201F2020202120222020212122222121222222
232322242122222322222323222324252524242425252524252524262525252727282727
2728282827282927282A2A2B2A2A2C2A2B2C2B2C2C2E2D2D2C2E2E2F2F302E302F2F3131
2F3232323332313334423436343334353635363537373839383838393A393939393A3A3A
3B383939393B3B3A3A383A3A393A3A393A393B38383839383737383A3837373836353437
363435343433333331343130313131312F303130302F2F2D2E2D2D2B2D2D2C2D2A2A2C2A
2B2A2A2A29282A292A292827282728272726262525252624252424252424242323232423
222324232222222221222222202120202020212020201F1F1F1F1F2020201F1F1F1F1E1F
1D1E201F201F1E1E1E1D1E1F1F1E1E1D1E1E1D1D1E1E1C1D1D1C1C1C1C1B1E1C1C1C1C1C
1B1C1C1D1C1B1C1B1C1A1A1B1B1B1B1A1D1B1C1C1C1C1B1A1B1A1C1B1B1B1B1A1A1C1C19
1B1B1A1B1A1A1A1B191A1B1B1B1A1A1A1A1A1A1A1B19191A1A1B1A1B191A1A191A1A191A
1A19191A1B18181A
1A191A1A1A1A1A1A1A1A1A1A1A191A1A1B1B1A1A1B1A1A1A1A1A1A1A1B1B1C1C1B1B1C1B
1B1B1C1B1A1B1B1C1C1C1B1C1B1B1C1B1B1C1B1C1C1B1B1B1D1C1C1D1C1C1C1C1C1C1C1C
1C1C1C1B1B1C1C1C1C1D1C1B1E1C1D1D1D1D1C1E1E1D1D1E1E1E1E1E1E1E1E1E1F1E1E1E
1F1F201F1F20201E1F201F1F20201F1F211F20211F1F2020202020212021222121222122
212321232323232223222322232223232325232525252525262525252626262526262728
2928292828292829282B2B292A2B2B2B2C2C2C2C2C2C2E2E2E2D2E2E2F2F2E2E2E313032
323130313231333232333535333436353534363637373737393937383938383839383738
3A39393A38393A3A38383A3A3A3A3A393838383838393737373836383636343437353536
3533333334313134313231313030313030302E2E2D2F2E2D2D2E2E2C2C2D2C2C2B2C2B2B
2B2C2B292A282A2929282927272827282626252425252425262525232224242423242422
2522222323222122222021222321222020212121212020211F1F201F1F1F201F1E1F201F
1F1E1E1E1F1E1F1E201E1E1D1E1F1E1E1D1D1E1E1C1C1E1D1E1C1C1D1C1C1B1C1D1D1B1C
1C1D1B1C1C1D1B1C1B1B1B1B1D1C1C1C1C1B1C1B1B1B1C1A1B1B1B1A1C1A1B1A1A1B191C
1A1A1A1B1B1B1B1B1B1A1A1A1A1A1A181B1A1A1A1A191B191A1A191A1B1A1A1A1A191A1A
1A191A1A1A19191A
19181A1A1A1A1A1A1A1B1A1A1A1A1B1A1A1B1A1A191A1A1C1A1A1C1C1B1B1B1C1B1C1B1A
1A1A1B1A1B1C1A1B1C1C1B1A1C1C1C1B1B1C1A1B1B1C1D1C1C1B1C1C1D1D1C1C1C1D1D1C
1C1C1C1D1D1B1D1C1C1C1D1C1F1D1C1D1D1D1C1E1D1D1D1D1D1D1E1E1D1E1E1E1E1E1F1E
1F1F1E1E1F201E1F1E1F1F201F2220202120201F2020201F212121202221222322222321
202223222322232421232322242323232323242426242625252526242626252627252727
272728272728292A2829292B2B29292B2A2C2C2B2B2C2D2D2C2D2D2D2E2D2F2E2F2F2F2F
303031313132323232323332333434363435363637363535363737363838393738363938
383836383837393938383937393838383838363737363636373736373634353634363536
35343434323132323331313131302F31302F2F302E2D2E2D2D2D2D2C2E2A2A2B2B2C2B2A
2A2B292A28292829282A2727272728272724252525252524242225252523242425222222
23222223232321222122202021202121202121202020202220201E1F201E1F201F1F1E1E
1E1F1E1F1E1D1E1E1E1D1E1E1F1E1E1D1D1D1D1D1D1D1E1C1D1C1D1C1C1D1B1D1C1C1D1C
1C1C1A1B1B1C1C1B1B1B1C1C1B1A1B1B1B1C1D1B1B1B1B1A1C1A1C1A1A1A1B1A1A1A1A1C
1B1B1A191B1B1B1C1B191A1B1A1A191A1B1A1A1A1B1A1A1A1B1B1A1A19191B191A1A1A1A
1A19191A18191919
1A191B19181A1A1A1B1A1A1A1C1B1B1A1B1B1B1A1B1A1A1B1B1B1A1B1A1A1B1C1B1B1B1B
1B1B1B1A1B1A1B1B1B1B1C1B1C1C1B1B1C1B1C1A1B1D1D1C1B1C1B1D1C1C1C1C1C1C1C1D
1B1B1C1C1C1D1D1C1D1D1C1C1D1E1D1D1C1E1D1D1D1D1E1D1C1D1E1F1E1E1D1E1E1E1E1E
1F1E1D1F1F1E1F1E1E1F1E1F2120202120201F202120202020201F212021202120212122
222021212121232322222323232424232324232525242424242525252525252525262626
282727272827292829282A2A2A2B2B2B2A2A2D2B2B2D2D2B2E2D2D2E2E2C302F2E30302F
303030303132323231343232333432333335353436353636363638373737373637363639
383636353837383839363839383938373636363637363536363535353535363534323434
3333333333333331313130313230302F2E2E2F2F2F2E2E2F2C2D2C2C2B2D2B2C2C2B2A29
292B29292929282A28272727272627272725252625252325242524242423242424232322
232223222121212122212221232120202120201F201F201F201F2021201F20201F1F1F1F
1F1F1E1E1D1F1D1E1F1E1D1F1F1D1F1E1E1D1D1C1D1B1D1E1C1D1D1D1C1C1C1B1B1C1C1C
1C1B1C1C1B1D1C1B1C1C1B1C1B1A1B1B1A1B1D1D1D1B1B1C1B1B1B1B1B1B1B1B1B1A1B1B
1A1B1B1A1C1A1B1C1B1B1A1A1B1A1C1A1B1A1B191B19191B1A1B1A1A191A1A191A1B191A
191A1A1A1A191A19
1A1A191B1B1A1B1B191A1A1A1A1A1A1A1B1A1B1B1A1B1A1A1A1B1B1B1B1B1C1A1B1B1C1A
1A1B1B1C1A1B1B1C1B1B1B1C1C1B1B1B1B1C1B1C1B1B1C1C1C1B1C1C1C1B1C1C1C1C1B1C
1C1C1C1B1D1C1C1D1C1C1D1D1C1B1C1E1C1C1D1C1E1E1E1C1D1E1E1D1F1E1F1F1D1F1E1F
1F1E1F1E1E1F1E201F201F202020201F21201F2120202020202020222022212221222120
222122222222232423222222232524242323242423242525242526252526272726262526
272726262828282829282A29292A2A2A2A2B2A2C2D2D2C2D2E2D2E2C2D2E2E2D302D2E30
2D2F2F3031302F3132313232323334333533353434343434363736353738353737343536
383736373736363836383736383735363636373536353535353435343536353534343335
323232333332303230313231302F2F2F2E2C2E2C2E2D2E2C2D2C2C2D2B2C2A2B2B2C2B29
2A2929292A29282727282827262828272626252525242425252624252424242423232323
2323222323222221222221212221202020202120202021212020211F1F1E1F1E1E1E1F21
1F1F1E1F1F1F1D1F1E1E1D1E1F1F1D1E1E1D1D1D1D1E1F1D1C1D1D1D1C1D1C1C1C1B1D1D
1C1B1C1C1A1C1C1C1B1A1C1C1B1C1B1B1B1C1C1B1B1C1A1B1B1B1B1B1A1A1A1B1A1A1B1B
1A1B1B1B1A1A1B1A1B1B1A1A1B1A1B1A1B1A1A1A1A1A1B191A1A1A1B1A191A1A1A1A1919
1B19191A19191819
1919191A1A1B1B1A1A1A1A1A1A1B1B1A1B1A1B1B1B1B1B1B1A1A1A1B1A1C1B1A1B1B1B1A
1B1A1C1C1B1A1C1B1B1C1C1C1B1B1B1B1B1A1D1C1B1B1D1D1B1C1C1E1A1A1B1B1D1B1C1D
1D1C1C1B1C1C1C1C1D1C1C1D1C1E1D1E1D1F1D1E1D1D1E1E1B1D1E1D1E1D1D1F1D1E1E1F
1E1E1F1E1F1F201F1F2020202120202020211F201F1F2120202120212121222122212222
212122232022212223222423242423232424242525252425252425262625262625252626
2727262726282828282829292A2A2A2B2A2B2B2C2C2C2C2D2D2C2C2C2C2E2E302F2E2F30
2E2F2F302F31303232313232313232333333333234363535353635373435363537363735
353635363436373637363637363836353635343533343634343235353234323534353333
31323232323132303130312F2F2F2E2E2F2E2C2E2E2D2D2B2D2C2B2B2C2D2B2B2A292A2A
2A2A29292829282727292626262727262525252526252425232424242423232323232222
222221232322222222222120212021202020202020201F20201F201F201F1F201F1F1E1E
1E1E1F1E1E1F1E1F1D1F1E1E1E1E1D1D1D1E1D1D1E1C1E1C1C1C1D1C1D1D1D1B1C1B1C1C
1B1C1B1C1C1D1C1B1B1A1C1B1A1B1B1B1C1C1B1C1C1B1B1B1B1B1B1A1C1B1A1A1A1A1A1B
1C1A1A1A191A1B1B1A1B1B1A191B1B1B191B1A1A1A1A1B1A191A1B1A19191A191A181C1A
191A1A1A1A1A1819
1A1A191A191A1B1B191A1A1B1A1B191B1A1A191A1B1A1A1A1B1A1A1B1B1B1A1C1C1B1C1C
1B1B1B1B1B1B1A1B1C1B1B1B1B1B1B1C1C1B1B1A1C1B1C1B1D1D1A1C1C1A1C1D1D1C1C1C
1C1D1C1C1C1C1D1D1C1D1B1C1E1D1D1D1C1D1C1D1C1E1E1D1D1E1C1D1F1D1E1E1E1E1F1E
1F1E1E1E1E1E1E1F1F201F1F2020202020202020202020211F1F212120201F2121212221
202121212022222124232323232323242424242423242324242424252624252626262527
27262726282826282A28292A29292A2A2B2B292B2A2A2A2C2C2B2D2D2C2E2D2E2E2E2E2F
2F312F2F2F312E3131313030303233343433343336353333343535353635363436353535
363635363535353537353637363634363535363533363334343334343434333231323232
313330313130303030303030302F2F2E2D2D2E2C2D2D2C2E2C2C2C2B2A2C2B2B2A2A2B2B
2A2929282828282727272728272827262526252526242625262424232424232322232223
222321222223222221222221222120212120222020201F211E1E1E1F1F1F1E1D1F1E201E
1E201F1F1E1F1D1E1E1E1E1F1E1E1E1F1E1F1D1D1C1E1D1D1D1D1C1C1C1B1C1C1D1C1D1C
1B1B1D1C1C1C1C1C1B1B1A1C1B1C1B1C1C1C1A1A1B1C1B1A1B1C1B1A1B1C1B1B1A191A1B
1A1A1A1C1B1A19191A19191A1A1A1A1A1A1A19191B1B1A1A1A191A1B1919191A191A1A19
1A191B191A191A1A
1B191A1B1A1A1A1A1B1B1A1B1A1A1B191A191A1A1B1B1A1A1C1A1B1B1B1A1B1B1B1B1B1B
1B1A1A1A1B1B1A1B1A1B1C1B1C1C1D1B1C1A1C1B1B1B1B1B1C1C1C1D1C1B1B1C1B1B1B1C
1C1C1B1C1C1D1D1C1D1B1D1D1D1D1E1D1D1D1C1E1D1E1E1D1D1E1D1D1E1D1E1E1E1F1D1E
1F1E1E201F1F201F1E1F1F201F1F1F2020202020201F2020222020222021202120212121
222122222222222323232223232423242324242324242423242425252625252425262727
262627272828282829292828292A28292A2A2A2A2A2B2B2B2C2A2D2C2B2D2D2B2F2E2F2E
2F2E2F2F2F30303030303030313131323231333435353534333435363335353334343435
343435343536323634343633353436353535353433333334333333323334313132323232
3231303032303030302F302F2F2E2E2C2C2D2C2C2B2D2C2B2B2B2C2A2C2B2A282A29292B
2A2927282928282927272727262626262425252625252425252524222324232422242222
232123222122232021212120212120201F20202020201F20201F1F1F1D1E1F1E1F1E1F1F
1F1F1F1E1E1E1D1D1E1D1D1E1D1E1E1D1E1E1D1E1E1E1E1C1D1C1E1D1C1D1D1D1C1D1C1D
1D1C1C1C1C1C1A1B1B1B1C1B1A1A1B1C1C1C1A1A1B1B1C1A1B1B1A1A1B1B191B1B1B1B1B
1B1B1B1A191B1A1A1A1A1A1A1B1A1A1B1B1A1A1B1B19191B191A191A1A1A1A191A191A1A
1A191A1A1A1A1A1A
1B1A1A1A1A1A191B1B1A1A1C1B1A191A1B1B1A1A1B1A1D1A1B1B1B1C1B1B1B1A1B1B1A1C
1B1C1A1B1A1A1C1B1A1B1A1B1B1B1C1C1B1B1B1A1B1C1A1A1C1B1B1B1B1B1C1C1C1C1C1C
1C1B1D1C1B1C1D1D1C1D1D1E1C1C1D1E1D1D1D1D1D1D1E1D1D1D1E1E1D1D1D1D1F1D1E1E
1E1F1E1E1F1F1E1F1F201E1E1F20201F201F201F211E1F201F20201F2121222121212120
212222212122232223232323222322242323252524252427242525252526262525262628
2427272627292827292829292928292A282A2B282A2A292B2A2C2B2B2D2B2C2E2E2D2E2E
2E2F2F2F2F3030303031302F303130323233333333333333333433353333353433363434
363336343433353434353534333334353333333534333331333432333332333331323132
2F31312F2F30312F302F2F2F2F302E2F2E2C2D2C2C2C2A2C2C2B2A2A2A2A292A2B2A2929
292929282927282727272525282626252526262425242524242423232324232422232323
22232121232221212321212121202020222221201F201F21201F20201F1F1F201F1F1F1F
1F201D1D1E1E1E1D1F1F1D1F1E1F1D1E1D1D1D1D1C1D1C1C1E1D1D1B1C1D1C1C1B1C1C1C
1C1B1C1C1C1C1B1B1C1B1C1B1B1B1C1B1C1A1C1C1C1B1B1B1B1B1A1B1A1A1A1B1B1B1B1A
1A1A1A1A1A1A1A1B1C1B1A1A1B1A191A1A191A1A1A1A1A191A191A1B1B191A1A191A1A1A
1A191A1919191A19
1A18191A19191B1A1B1B1A1A191A1B1A191A1B1B1A1C1A1A1B1C1C1A1B1B1C1B1C1C1B1A
1B1A1A1B1A1B1D1B1B1B1B1A1B1B1B1A1C1C1C1D1B1B1B1C1D1C1D1C1B1C1C1B1C1C1C1C
1C1D1B1A1C1D1C1D1C1D1C1C1F1C1D1D1C1D1E1E1D1D1D1E1D1D1D1D1D1D1E1D1F1E1E1D
1E1E1E1D1D1E1E1D1F1E1F1F1F201E2020201F201F1F202021201F212122202220212223
222123212122222123222423232323232325252323232423242624252525252425252726
26262727272826282828272729282828292A292A2A2A2A292D2B2B2B2C2C2C2D2D2D2F2D
30302F2E2F302F2F2F2F2E30303030303132313233323334343434343333343333343334
333332333334333334343334343434343334323333333232333032333132323232313131
3131302E302E2F302F2F2E2E2D2E2D2D2D2D2D2D2C2A2A2B2A2A2B2C2B292A2A28292929
2829282A2828272627262827262627252526252526252524242323232324232322232123
22232122222221212120222121202121201F211F20201E1D1F201F1E1F201F1F1F1F1E1F
1E1F1F1E1E1E1E1F1E1E1E1E1E1D1D1E1D1D1C1D1C1C1D1C1D1C1D1C1D1C1E1B1C1C1C1B
1C1B1C1B1C1D1A1B1B1C1B1B1A1C1B1C1B1C1B1A1C1B1B1A1B1C1C1C1B1A1B1A1A191C1A
1C1C1A1A1B1A1B1B1A1A1B191A1B1B1A1A1A1B1B1A1B1A191A191B1A19191B1A1A1A191B
191B19191A1A1919
1B1A1A1A1A1B191A1A1B1A1A1C1B1B1A1A1A1A1A1A1C1B1B1C1B1B1A1B1B1B1B1B1A1A1B
1A1D1A1A1C1C1C1A1C1B1C1B1B1C1B1B1B1C1C1C1C1B1B1C1C1B1C1C1B1C1B1B1C1C1C1D
1C1A1B1C1D1C1D1C1C1D1D1D1C1E1D1D1C1D1D1D1C1D1D1D1D1D1D1C1D1E1C1F1E1D1D1E
1D1E1D1E1E1F1F1E1F1E201F21201E1F1F1F1F2021201F20212020212021212121212220
222121212222212222232124222322232323222324242524252524262526252625252627
27272726272727282728272729282829292929292B2B2A2B2B2C2B2B2B2C2C2B2D2C2C2F
2F2F2F2E2E2D2E2F2F2E2F2F2F3032313031313031313233353334323232333232323233
32333433333235333333333432333434333333333132323132312F3132302F302F303031
2F2F30312F302F2E2E2F2D2E2E2F2D2D2D2A2C2C2B2B2B2B2B2A2B292A2928292929292A
282829292827262727262626272524252524252424252524232324232422222223232122
222322212222212121212221211F1F202120201F201F1F1F21201F1F1F1F1F1F1F1F1F1E
1E1E1E1E1D1F1E1E1E1E1E1D1E1D1D1D1E1C1E1D1D1D1D1E1C1C1C1D1C1D1D1C1C1C1D1B
1D1D1B1B1C1B1C1C1C1C1B1C1B1B1B1B1B1B1B1B1B1B1B1B1B1A1B1B1A1A1C1A1B1B1B1A
1C1A1A1A1A1B1A1A1A191A191B1A191A1A1A1A1B1A1A1A19191A1A1A1A1A1A1A1B1A1A1A
1A1A1A1A191A1A19
1A1A1A1A191A1A1A1A191A1B191A1A1B1B1B1A1A1B1A1A1B1A1B1B1C1B1B1A1B1A1B1B1B
1A1B1B1A1C1B1A1B1A1C1B1A1A1B1B1B1B1B1A1B1C1C1B1B1A1C1C1C1D1C1D1C1B1B1B1B
1C1B1C1D1C1C1C1E1D1D1F1D1D1C1C1D1D1C1E1E1D1C1D1E1E1D1E1E1E1E1F1E1E1D1E1E
1E1E1E1F1F1F1F1E1E1F1E1E1F1E1F1F1E1F1F20211F1E1F202020202122202120202021
222122212121222222232222222224222123232324252623252425232424242525262526
26272426262727282928292729272929292A292828292B2A2929292B2B2C2B2B2E2D2F2E
2E2F2F2E2D2D2F2E2E2F2E2F2F3130303031323131313233323433323433343231333233
31313332313233313332333433313332323332323231323131333030312F30303131312F
2F2F2F312E2D302E2F2D2D2E2E2C2C2E2D2C2C2B2C2A292B2B2B2B2A28292B2A28292829
282827282927262627272627262525262525252624252625252524232322232222222322
212121222120232221212021212121201F201F201F2020201E1E201F1F1F1F1F1F201F1F
1E1F1E1D1E1E1D1D1E1D1D1D1D1E1D1D1D1D1C1D1D1D1D1D1C1E1D1D1C1D1B1C1D1D1E1C
1C1C1B1C1C1A1B1D1A1B1C1B1C1C1A1A1A1B1A1B1B1B1B1B1B1B1A1B1C1A1A1B1B1A1A1A
1A1A1B1A1A1B1B181A1A1B1A191A191A191B1B191B1A1A1A1A191A191A191A19181A1919
1B1A19191A1A191A
1B191B191A1B1A1B1A1B1A1B1B1B1C1A1C1A1A1A1C1B1C1A1A1A1B1A1A1B1B1C1B1A1B1B
1A1B1B1B1B1B1C1C1B1C1A1A1B1D1B1C1A1B1B1C1C1A1B1B1C1D1A1B1C1C1C1D1C1B1C1B
1B1C1C1D1C1D1D1D1D1D1C1C1C1D1D1D1D1C1D1E1D1D1D1D1D1D1D1D1D1E1D1D1F1E1D1D
1D1E1E1F1F1F1D1F1C1F201F1F1F1F1F1F201E1F201E1F1F1F2020202020202020202122
212123212221222222212323222223222224242324242424242425252425252325242727
252626272627272827282A2A28272628292A28292A29292A2A292B2B2A2B2B2B2C2B2D2E
2F2D2E2E2D2D2E2D2F2F2D2E2F30302F3031303031313133313432323332313132313132
33323132323030333331313232333330313232313031313131302F312F312F31302E302E
2E2E302E2F2F2F2E2C2E2C2D2B2C2C2D2C2B2A2C2B2B292A2B2A2A282A29292928292829
292929272727272726262625262524252523242525242523242424232323222422232221
2124212221202121202121202120201F2020201E1F1F211F1F211E1E1F201F1E1E1E1F1F
1E1E1E1E1E1E1D1D1D1D1D1D1E1E1D1D1D1C1D1E1B1D1D1E1A1B1D1C1D1E1D1C1C1E1B1C
1D1C1C1B1A1B1B1A1C1C1B1B1C1D1B1B1C1B1B1A1C1B1C1C1B1A1B1B1B1A1A1A1B1B1B1A
1A1A1B1B1A1B1A1B1A1B1A1A1A1A1B1A191A1A191A1A1A1A1A191A1A191A1B19191B1A19
19191A1919191919
1B1A1B1A1A1A1B1A191B1A1B191C1A1B1B1B1B1B1B1C1B1A1B1B1B1A1B1C1B1B1A1B1C1B
1B1B1D1C1C1C1B1B1C1C1C1B1D1C1B1A1B1C1B1B1B1B1C1B1B1A1C1C1C1B1B1C1C1B1B1B
1C1B1C1C1C1D1C1D1C1E1C1C1D1D1D1D1D1E1D1E1D1D1D1F1D1C1D1E1C1E1D1E1D1D1D1E
1D1E1D1E1E1D1E1E1E201E1F1E1E1F1E1F1E1D1F1F1F2021201E21202021202121212021
212221212122212121212323222222232324242523232423232424242524252626242725
262526262528262827272827282827272829282A292B2A2A2B2B2C2B2B2A2C2D2C2A2D2F
2C2C2D2D2D2D2E2E2F2D2F2E2F2F2F2E302E303131303131323231313031313331303031
313132323131313230313232323230333130313232313131312F302F2F2F322E302E302F
2F2E2F2E2E2E2E2C2C2D2C2C2D2D2A2C2C2C2C2A2A2A2A2B2A2A2A2A2929292A29282928
272928272727282826262527252624262524222424252424242423232224222222222122
21222223222221212221201F212120212221201F20211E1F20201F1E1F1F1F1E201F1F1F
1F1E1D1E1D1F1D1E1E1E1E1F1E1E1E1C1C1D1C1D1D1C1C1C1C1B1C1B1C1E1D1D1C1C1B1C
1D1B1B1C1D1C1C1C1C1B1B1C1A1B1B1A1B1B1C1B1A1A1B1B1C1A1B1B1C1A1A1B1C1B1B19
1A1B1B1B1B1B1A191B1B1B1A1A1A1B1A1A1A1B1A1B1A191A19191B1B191A1A1A1A19191A
1B1A1A1A191A191A
1B1A1A1A1A1A1B1A1B1A1A1B1A1B1B1A1A1B1A1A1B1C1C1B1A1A191B1A1A1A1B1C1A1B1A
1A1B1B1B1B1C1A1C1B1B1C1B1C1B1C1C1B1A1B1C1C1C1C1C1A1C1C1B1C1C1B1B1A1C1B1B
1C1B1D1C1B1C1C1D1D1D1D1E1D1D1D1C1C1D1D1D1D1D1E1D1E1D1C1D1D1D1C1D1D1F1D1E
1E1D1D1F1F1E1E1F1E1E1E1E1F1F201F201F20201F1E20201F1E20212020202020202122
23211F202221212121222222222123232322242424242424242324242524232625242626
25262628262727282827282826282628272929282A29292B282A2A2A2A2A2A2B2C2B2C2D
2D2E2D2C2C2D2D2D2E2E2F2E302F2E2E2F2F2F2F303030313131312F3031303032333031
3031303131303131303131323131313231303232303030313030312F2E302F302F302D2F
2F2F2E2F2D2F2F2C2D2E2D2C2C2A2C2C2B292A2B2B2A2C2A2B29292A2929272928282827
272727282827252626252526242425252425222524252523222323232222222321232223
22222122222123211F212121212121212121201F20211F1F1F1F1F1F1F1E1E1E201E1F1F
1F1F1E1D1D1D1F1D1D1E1E1D1E1D1D1D1C1D1C1C1C1D1D1C1C1C1D1B1D1C1B1C1C1C1B1B
1C1D1C1B1C1B1B1C1C1C1C1B1A1B1D1B1A191C1A1C1C1B1B1B1C1A1C1A1B1B1A1A191A1B
1A1B1A1B191A1B1A1A1A191A1A1A1B1A1A1A1A19191A1B1A1A1A191A1A1A1A1A1A1A1819
191A1A1A191A1819
1A1A1A1A1A1A1A1A191A191B1A1B1A1C1B1A1A1B1A1A1B1A1B1B1A1A1B1A1C1B1A1B1B1B
1A1A1B1C1B1B1A1C1B1A1B1B1B1B1A1B1B1B1C1B1C1C1A1C1C1B1A1D1D1C1B1C1C1B1B1C
1C1C1C1B1D1D1D1D1D1C1D1D1D1C1C1C1D1C1D1C1D1E1D1D1E1D1E1D1E1E1E1D1D1E1E1F
1D1E1F1E1E1E1F1E1D1D1F1E1E1F1F1F1F20201E1F201F20201F20201F20202121202022
222121202222222122232222222322232323232223242424242424232625242423252526
252626272626262827292827292728282828292728282929292A2A2A2A2B2B2A2B2C2B2C
2C2C2C2D2C2C2D2D2D2E2D2D2F302E2E2E2F2F2F2F2F2F2F30302F323030302F31302F30
3030303131312F31313030312F3030303130312F3031303030302E2E2E2D2E2E2E2E2E2E
2E302E2D2E2C2B2F2D2E2C2C2D2B2C2B2C2B2A2A29282A29292A2A282A28282828282927
272626282827262725262626252526262524242323242323252324222223232323232120
2221222121222122211F2121202121201F21211F1F20211F201F201D1E201F1F1F1F1E1E
1E1F1E1D1F1D1E1E1E1E1D1E1C1F1C1D1C1C1C1C1D1E1D1C1B1C1E1C1B1B1B1D1C1D1C1B
1C1B1B1C1A1B1B1A1A1C1B1A1C1C1B1B1C1C1B1A1B1A1B1B1B1B1B1B1A1B1B1A1B1B1B1A
1C191B1A1B1A1A191A1B1A1A1A191A191B191B1A1B181B1A191A1B1A1A1A191A191A1A19
191A1919181A191A
1A1A1A1B1B1B191A1B1A1A1A1B1A1B1B1A1B1B1B1C1A1B1A1A1A1B1A1B1A1A1B1B1A1A1B
191C1C191B1C1A1B1C1C1A1C1B1A1B1C1B1A1C1B1B1A1C1C1B1C1B1C1C1D1C1A1B1B1B1D
1D1C1B1C1C1D1B1C1B1D1E1D1D1C1C1C1D1C1E1D1D1C1D1D1D1C1D1D1E1D1D1D1E1E1E1E
1D1F1D201E1E1E1F1E1E1E1E1E1F1E1F1F1E2020201F1F1F202120211F20202121212021
232221212120222122212322232223222223242424232424252424242325252324242526
2625252527252627262726272828282729282729292A29282A292A2A2A292A2B2A2C2B2B
2B2C2B2C2C2D2D2C2C2D2F2C2E2E2F2F2F2F2F2E2E2F30302E303030302F2F2F2F303130
2E302E31302F2F302F2F2E2F312F3030312F3031302F2F302E2D302F2D302F2E2F2E2F2F
2F2E2D2D2E2E2D2C2C2C2C2B2C2A2B2A2B2A2B2A2A2A2929292A28282927272928292627
272627272726272725262625252425232323232424222422232322222121212123202222
2122212120212220202121212121222021201F20211F1F201F201F1E1F1E201F1F1F1F1D
1D1D201F1E1F1E1D1E1D1D1C1E1D1D1D1C1D1C1D1D1C1C1C1C1D1C1B1D1C1C1D1C1B1D1C
1D1C1B1C1B1B1C1C1B1C1A1B1C1A1B1A1B1B1B1C1A1B1A1C1A1C1A1B1B1C191B1C1A1A1B
1B1B1A1B1A1A1A1C1A1B1B191A1A1A1A1A1A1A1A1A1A1A191A1A1A1A1A1B1A1A191B191C
191A1A1819191A19
1A19191A1A1A1A1B1B1B1A1A1B1B1C1B1A1B1B1B1B1B1B1B1B1A1C1C1C1A1B1B1C1A1B1B
1B1C1A1B1B1B1C1A1C1B1A1A1C1A1B1B1B1B1B1C1C1C1B1C1B1C1D1B1E1C1C1B1D1D1C1C
1D1C1D1D1C1D1D1C1E1D1D1B1D1D1C1D1C1D1C1D1D1D1D1D1D1E1D1D1C1E1E1D1E1D1D1E
1D1E1D1F1D1D1E1E1E1F1E1E1F1D1F1F1F1F1F1F2021201F1F202021201F202020222121
202122222021222221212323202122222222212423232323232423242425242425242426
272626272626262727272828272828282928282A2A2928282829292829282A2A2A292B2B
2C2C2B2A2B2B2B2B2B2E2C2D2E2D2E2E2E2D2D2F2D2F302F2F2F2F2F2F2F2F2F2F2F3031
2E2F2F2E302F2F3030312F2F2F2F302F2F302F2F302F2F30302F2E302D2E2F2C2E2E2D2E
2E2C2D2C2C2D2C2C2B292C2B2B2B2A2A2B2A2B2B2A2A2928292829282828272828272627
262727262626262626252426252624242425242524232423242222232222222321212121
201F222020212021211F21202122212021201F202020201F1E201F1F201F1E1E1F1F1E1F
1D1F1E1C1E1E1E1E1D1E1D1C1D1D1D1C1D1C1C1D1D1B1C1C1D1C1D1D1C1D1C1C1C1C1C1B
1B1B1B1B1B1C1C1B1B1B1B1B1B1B1A1C1C1B1A1B1B1A1C1B1B1C1B1A1B1B1A1B1B1B1B1A
1B1B1A1A1B1B1B1A1A1A1A191A1A1B1A191A1A191B1A191A1A1A191A1B1A1A1A18191A1A
1A1A191A1919191A
1A1B1A1A1B1A1A1B1B1A1A1B1B1A1A1A1B1B1A1B1C1B1C1A1B1A1B1C1A1A1B1B1B1B1B1A
1C1B1B1B1A1A1C1C1B1C1B1C1A1C1B1A1C1B1B1B1B1C1D1B1C1B1B1B1B1C1B1B1C1B1B1C
1C1D1C1D1D1E1D1D1D1D1D1D1D1D1C1D1B1B1C1E1D1D1D1D1D1D1D1E1F1D1E1E1E1D1D1D
1C1D1E1E1E1D1D1E201E1E1E1F1E1F1F1E1F20201E201F20201F1F202121212020212120
21201F212222212222212321222321222222232223232325242524232324232425242625
2525252624262727292627272727292727282827282A292828292929292A2B2A29292A2B
2B2A2B2A2C2B2C2C2B2C2D2D2C2D2D2D2D2E2E2D2E2E2E2F2E2F2F2D2F2D2F2E2E2F2E2F
302F2E302E2E2E302F2E2E302F312E2D2F2F302F302E2F302F2E2F2F2E2D2E2D2D2D2D2D
2C2C2D2C2B2C2C2D2B2A2B2B2A2B2A29292A2A2A29292828282929282829282828272726
272726252626272623242526252524232424242523232223232323232223232223212222
2122222220212121212121211F1F202020201F20201E1F201F1F20201E1F1F1F1F1E1F1E
1F1F1E1E1E1D1D1E1D1C1D1E1D1D1D1C1D1B1C1D1D1C1D1C1B1C1D1C1C1B1D1B1C1B1C1B
1C1C1B1A1C1C1B1C1B1B1B1A1C1B1C1C1A1D1B1B1B1A1B1B1C1B1A1A1B1B1B1C1B1B191B
1A181B1A1B1B1A1A1919191A1A1B1B1A1A1B1A1B191A191B1A1B19191B1919191B191A1A
181A18181A191919
1A1B191A191B1A1A1A1A1B19191B1B1A1B1B1C1B1B1B1B1A1B1B1B1B1A1B1A1A1A1C1A1A
1B1B1C1B1B1A1B1C1C1C1C1A1B1B1C1B1C1B1B1B1B1B1B1B1C1C1D1B1C1C1D1C1C1B1C1D
1C1C1D1D1D1D1C1D1C1C1C1D1C1B1D1C1C1C1C1D1D1C1D1D1C1C1D1C1D1D1D1D1E1E1E1E
1E1D1E1E1D1D1D1D1D1D1E1F1E1F201E1F1F1F1E1F201F20201F21202121212120202220
212020222221212022222221202222222223232222222325242324242422232324252425
2525262426252727282826272727282728282728272927282829292929282929292A2A2A
2A2A2A2C2B2B2B2A2D2D2D2D2C2C2D2C2E2D2D2B2E2D2D2D2E2F2F2D2E2E2E2E2F2D2F2F
2F2E302E2F2D2F302F2F2F2E2E2F2F2E2E2F2E2F2E2F2F2C2D2E2F2D2E2D2E2D2D2B2C2D
2B2B2C2C2C2C2C2B2B2B2B2A2B2B2A2A28292829292A292A282A28292829272926262627
252626252727262525252525252424232425242424222223232323222223242221212322
21202021212123212020201F202020211F1F1F1E20201F1F1F1F1F1F1F1E1F1E1F1E201F
1F1E1E1E1C1C1D1E1D1D1F1D1E1D1B1D1E1B1B1D1E1D1D1C1C1C1C1C1B1C1B1C1C1B1C1B
1C1B1B1A1C1C1C1C1B1B1C1C1A1B1B1C1B1C1B1A1B1A1A1B1A1B1A1B1C1B1B1A1A1A1A1A
1A1C1A1B1A1B1B1A1A1B1B1B1B19191A191B1A1A19191A1B1A191A191A191A1A1A1A1A1A
1A1A1919191A1819
1A191B1A1A1A1A191A1A1A1A1A1A1A1A1A1A1B1B1A1A1A1A1B1B1C1A1B1B1C1B1C1B1B1B
1A1B1B1B1B1B1B1B1B1B1B1D1B1B191A1C1C1B1A1B1C1B1B1C1A1B1C1B1C1C1C1C1C1C1C
1B1C1C1C1D1D1D1C1D1D1D1B1D1C1C1C1C1C1C1C1D1B1E1C1D1C1D1D1C1D1E1E1C1D1E1E
1C1F1E1E1D1E1F1E1F1F1E1F1F1F1E1F1E1E1F1F1F20201F1F1F21212020201F21202021
21211F212222222221222221222121232222222222212322232424232525232424252525
262525242526252725262727272627262828272828282828292929282828292928292A29
28292C2B2A2B2C282C2D2B2D2C2C2D2D2C2E2C2D2E2D2D2D2D2D2F2D2E2E2D2E2D2D2F2E
2F2F2F2F2D2F2F2E2F2E2E2C2D2E2F2F2F2E2E2C2E2F2E2E2E2C2D2E2D2C2D2E2D2D2B2C
2C2D2B2C2A2B2C2D2A2A2C2C2A292A282929292929292929282927272827272526272725
252525262525262526242524242324252325232223232423232323232223232121222022
212021212120202120221F211E201F1F1F1E1F20201F20201E1F1F1F201F1E1E1E1F1E1E
1F1F1E1E1E1E1D1E1C1D1D1E1E1B1C1C1E1D1C1C1D1D1D1D1D1B1C1B1C1C1B1B1A1A1C1B
1C1C1C1C1B1B1B1B1A1C1C1B1B1B1B1B1A1B1A1B1A1A1A1B1A1C1B1B1A1B1A1B1B1A1A1A
1B1B1B1A19191A1A191A1B19191A1B1A19181A1A1A1A1B1B1A191A1A1A1A191A191A1A19
1A191A1A18181919
1A1A19191B1A1A191A1C1A1A1A1B1C1A1A1A1A1B1B1A1A1A1B1B1B1A1A1B1A1B1A1B1B1B
1B1B1B1A1B1C1C1B1C1C1A191C1B1A1C1B1C1C1B1C1B1C1C1C1C1C1B1B1D1C1C1C1A1C1C
1C1D1B1C1C1B1D1D1D1C1D1C1D1B1C1D1C1C1D1D1C1D1D1D1D1C1D1D1D1D1F1D1D1E1D1E
1E1E1D1E1E1E1E1F1E1F1E1E1F201E1F1F1F1F1F1E1F1F1F202020202021201F20212020
222121212221212122212222212221212222232223232323242324242424232425232525
242625252625262826262527282726262828272927272828272728282A28282928282929
29282A292A2A2A2A2A2C2A2C2D2B2C2C2D2D2B2C2D2D2C2D2C2D2C2C2D2D2D2C2D2F2D2F
2D2D2E2F2F2E2D2E2F2E2C2D2D2E2E2E2C2D2F2C2D2E2E2E2D2D2D2D2D2C2C2C2D2B2B2B
2C2C2D2B2B2C292A2B2A2B2A292A2A29282A29282928282927292A272827272727282726
252627272626252525262425242525252424232322232423232222222121222222212220
21212121211F20211F1F20201E201F1F21201F1F1F1F201E1E1F1F1E1E1E1F1F1F1F1F1E
1E1D1D1D1E1D1D1E1D1D1D1E1C1D1C1D1D1D1E1D1D1E1C1B1C1C1D1D1C1B1B1C1A1B1A1C
1D1C1C1B1B1B1B1B1C1B1A1B1A191A1B1A1B1A1B1A1A1B1A1B1B1B1B1A1A1B191B1A1A1D
1A1B1C1A1B1B1B1A1A1A1A1A1A1B1A1B1A1A19191A1A1B1A1A1A191A1B1A1819191A1919
1A19191918191A1A
1B1B1B1A1B1A1A1B1B1B1A1A1A1B1A19191A1A1A1B1A1A1A1A1B1B1A1A1A1B1A1A1B1B1A
1B1B1A1A1B1C1C1B1B1B1B1B1B1C1B1C1B1A1B1B1B1C1C1B1B1C1B1C1B1C1C1C1C1B1C1D
1B1D1D1D1C1B1D1C1C1D1C1D1C1C1D1C1D1D1C1D1D1D1D1D1D1D1D1E1F1D1E1D1D1D1E1E
1E1E1E1E1E1D1F1E1E1E1E1F1F1F1E201E1E1F1F1F201E1F1F20202020201F2120202120
222121222121222121212022222222222322212222232224232425242523242425242523
252424242627262627272627262627272627282728292728282A28292927282929282829
292A2B292A2A2A2A2A2B2B2B2B2C2B2B2C2C2D2B2B2C2E2C2D2C2D2C2C2D2C2E2C2D2E2D
2D2E2E2D2E2E2D2D2E2E2E2C2E2D2C2D2D2E2D2D2C2C2B2D2D2C2C2B2C2D2D2C2B2C2C2B
2B2B2A2A2B2A2B292A2A2C29292928292929292A292A2828292827282626272828262525
262524242526252525262625242524242423252422232222222323232122222120222220
2122202120212121211F1F1F2020212020201F201F1F1F1E1E1E1E1E1E1E1D1E1F1E1F1E
1F1D1F1D1D1D1D1E1D1F1E1D1C1D1D1E1C1B1D1E1D1B1C1C1D1D1D1D1C1C1C1C1C1C1A1B
1A1B1C1A1C1C1C1A1B1B1B1B1D1B1B1B1B1B1B1A1B1B1B1B1C1B1A1B1B1A1B1A1B1A1A1B
1B1B1B1B1B1C1A1B1C1A1A1B1A1A1A1B1A1C1B1A1B1A1A191A1A1A1A191A1A1B191A1A1A
1A1A181A19181818
1A1A1A1C1B191B191B1A191A1B1A1A1A1A1A1B191B1B1B1B1B1C1B1A1A1B1B1B1A1B1A1A
1B1A1B1B1B1A1B1C1B1C1A1A1B1B1B1B1B1B1C1C1B1B1B1C1B1B1B1C1B1C1C1C1B1C1C1B
1B1B1C1D1C1C1C1D1C1C1C1B1C1D1C1D1D1D1D1D1C1D1C1D1D1E1E1D1C1D1F1E1E1D1E1D
1E1E1E1E1E1E1E1D1E1D1E1F1F1E1F1E1F201E20201F1F1F1F20201F201E20201F20211F
1F22201F2021212122222120212221222223222124232424232324242424242425252424
252424252526242627282525272627262526282928282828282928282928292929282828
2729292A2A292A292A292A2A2B2C2C2B2C2C2B2C2C2C2C2C2D2D2C2D2C2E2C2C2B2C2D2D
2C2D2C2D2C2D2C2D2D2C2C2E2D2D2D2E2D2D2C2B2B2C2C2C2D2D2B2B2B2A2A2C2C2A2C2C
292B2B2B2A2A2A2B2A2A2B2A2928292927292827282A2929292727262726262726272525
242527262526252524242425252523222323242222242322202322222123212223212222
2121221F20202020201F21211F1E20201F1E1F2120201F1F1F201E1E1E1E1F1F1E1F1E1E
1E1E1E1E1E1C1D1E1D1E1E1E1D1D1C1D1D1C1C1C1D1C1C1D1B1B1D1B1B1B1B1C1B1B1B1B
1B1C1B1B191B1B1B1B1B1B1B1A1A1B1B1B1B1B1B1C191B1B1B1B1C1C1B1A1C1A1A1B1919
191A1A1A1B1A1A1A1B191919191A1A191A1A1A1B191A1A19191B1A1A1B191B1A191B1A19
191A1A1918181919
1A1A1B1A1A1A1B1A1B191A1A1B1A1A1A1A1B1B1B1B1B1A1B1B1B1B1B1B1B1A1B1A1B1B1B
1A1B1A1B1B1A1D1C1A1B1B1B1B1A1C1C1B1B1B1B1B1C1C1B1B1B1C1B1C1C1C1C1D1C1B1D
1C1D1C1B1D1B1C1B1B1C1D1D1C1C1D1D1D1D1B1C1D1C1C1D1D1E1E1D1D1E1D1D1E1E1C1D
1D1E1D1D1F1E1D1E1F1E1E1E1E201E1E1E1F1F1F201F1E1F201F1F20202021202020211F
202120212023212221212221222122212122212222232223242324232425252424232626
25242426242325262526252625262625282726272828272728272828282628282A282828
2928292A2A2B2A2A28292A2B2B2C2B2C2B2B2C2C2C2C2C2C2B2D2B2C2B2B2C2D2C2C2C2C
2D2D2E2C2D2D2D2C2C2C2D2C2D2E2C2C2C2D2D2C2A2B2C2D2C2D2C2B2B2A2B2B2C2A2D2C
2B2B2A2A292B292A28292A28292828292927272828282828272727282525252628252625
252625252424242425252425252424252423232321242321212122212221212222222221
20211F1F2020202120211F20211F1F20201F201F1F20201F1F1E1F1F1F1F1E1D1F1E1E1C
1E1D1E1C1C1E1C1E1D1E1D1D1C1C1E1D1D1E1D1C1C1D1D1C1B1C1C1C1B1B1C1B1C1B1B1D
1C1C1B1A1B1D1A1B1C1B1A1A1A1B1B1B1B1C1B1B1B1B1B1B1B1A1B1A1B1A1A1A1B1A1A1A
1B191B1B1A1B1A1A1A1A1A1A1B1A1A1B191A1B1A1A1A191A1C1A1A1919181A191A1A1919
19191A1A1A181819
1A1A1A1A1B1B1A1A1A1B1B1A1A1B1B1A1A1B1B1B1A1A1B1A1A1A1A1B1B1B1B1B1D1B1B19
1B1B1B1A1B1B1B1C1B191B1B1B1B1C1B1B1B1B1C1B1C1C1B1B1B1D1B1C1B1B1D1B1C1D1C
1C1C1C1C1C1C1B1C1E1D1B1C1C1C1C1D1D1D1D1D1D1C1E1D1D1F1D1D1D1E1D1D1D1D1D1D
1E1D1E1E1E1D1D1E1F1F1E1E1F1E1F1F1F1E1F201F1F1F201E201F211F1F202021201F20
212020212020212120222120212222212122202322212122222323232422232324242325
262325242425252525252826252525282725262626282627272628282826282727282829
2928292929292A2A2A2B2A2A292B2C2B2B2C2B2B2C2B2A2B2B2C2C2B2C2B2D2C2C2C2C2C
2C2C2D2C2D2C2C2C2D2C2B2E2B2C2C2C2C2C2C2C2D2B2B2A2B2B2C2C2C2A2B2C2B2B2A2B
292A2B2A2A2B292B292A2A292929282A292727292B282827272827252527262626262525
252525252524252425242425252424252324242222222321222321202123202020212121
22221F21212020212121202020201F1F202020201E1F1F1E2021201F1E1E1E1E1E1E1E1E
1F1E1D1D1E1C1D1E1E1D1E1F1D1D1D1D1D1C1C1D1C1C1B1C1C1D1C1D1B1C1C1C1C1A1B1C
1C1A1C1C1C1B1C1B1B1A1B1C1A1C1B1B1A1A1B1B1B1B1B19191A1A1A1B1A1A1A1A1A1B1A
1A1A1A1A1A1A1A19191919191A1A1B1A1A1A1A1B191A1A191A1A1A191B1B1B1A1A1A191A
1A191A19191A1A1A
1A1B1C1B1B1A1B1A1A1A1B1A1A1A1B1B191A1B1B1A1A1B1B1B1B1B191A1A1B1B1B1B1B1C
1B1B1B1B1A1B1A1A1B1B1B1B1B1C1B1B1B1B1B1C1C1B1B1A1C1C1C1B1B1B1C1B1D1C1C1C
1D1B1C1D1C1D1C1C1B1C1D1C1B1C1D1D1C1C1D1C1D1D1D1C1D1C1D1D1E1C1C1E1D1D1D1F
1E1D1E1E1D1F1D1E1F1F1E1E1D1F1F1E1E1F1F1E1F1F201E1F201F21201F1F1E20202021
201F21202021202020212122222122222022222223222224222322232323242323232424
242424242424242526242625262626252725262627282626282729282629272928292828
2728292A292A2A282A29292B292A2B2A2A292C2A2A2B2C2B2A2B2B2C2A2B2C2D2B2D2B2B
2B2D2C2C2C2D2C2C2B2C2B2C2C2B2B2C2C2B2B2A2C2C2B2B2B2B2C2C2B2B2B2B2C292A2A
2A2B2A2A292A29292A29282829292A2A2928292729282828282825262527262627242527
252424232424242423232423242324242423232223232223212221212121222121222021
2121202020202121202020201F1F20201E201E20201E1F201F1F1F1F1E1E201E1E1E1E1E
1D1D1D1E1E1D1D1E1E1E1E1E1F1E1D1E1C1D1D1C1D1C1D1D1D1D1C1C1B1C1D1D1B1C1A1B
1A1A1C1B1B1A1C1B1A1B1B1C1A1A1B1A191B1B1B1B1A1B1A1B1B1A1B1C1B1B1A1B1B191A
1A1A1B1A1A1A1A1A1A19191A1A1A1B1A1B191B191A1A1A191B1A191A181A191A1A191B1A
1A18191B1A19181A
1B1C1B1B1C191B1B1C191B191B1B1A1A1B1A1B1A1A1A1A1C1B1B1B1B1C1A1B1B1B191B1B
1B1B1C1B1B1A1B1A1B1B1B1B1B1C1A1C1B1B1B1B1C1C1B1B1B1C1B1B1C1C1C1C1B1C1C1B
1D1B1B1D1D1C1D1C1C1C1C1C1E1C1C1D1D1C1D1D1C1D1D1D1E1E1E1F1D1E1E1C1D1E1D1F
1F1E1F1E1E1E1D1D1F1D1E1E1F1E1F1D1E1F201F1F1E1F2120201F201F20201F211F2020
202021212120202021212121212022202221232322212323232323212424232223232426
252425252424252423252525262626262625262626262826262627262828292728282729
2829282929282A292929292A2B2A292A2B2A2B2B2B2B2B2B2B2B2A2B2B2C2C2A2A2A2C2A
2C2B2B2A2D2B2B2D2C2B2B2B2C2C2B2B2C2B2B2B2B2C2B2C2A2B2A2A2A2A2B2A2A292A29
2A292A2A2A2A2A292A2A28282A2828282828272827282725272727262627262525262526
252324252524242524232424232224232423232222212022222322212221222120212121
20212120202020201F1F21202020201F1F1E1F201F1E1F1F1E201F1E1F1F1E1D1E1D1D1D
1E1D1E1D1E1E1E1D1D1D1E1D1C1D1D1D1C1D1C1D1D1C1D1C1C1C1D1B1C1B1C1B1B1A1B1A
1D1B1C1A1A1C1A1B1B1B1A1C1A1B1A1B1B1A1B1B1B1B1A1B1C1A1A1A1A191A1C191A191A
191B191A1B1B1A1A1B1A1A1A191A191A1B1A1B1A1A1A1A1A1A1A1B191919191A1A181A1A
1A1918191A191819
1C1B1A1C1A1A191A1A1B1A1A1A1A1A1B1B191B1B191A1A1B1A1A1A1B1A1B1B1B1A1C191B
1B1B1B1A1A1B1B1B1A1B1B1B1B1B1A1B1B1B1A1D1B1C1C1B1C1C1B1D1B1B1C1B1C1C1C1D
1B1B1B1C1C1C1D1C1B1B1D1C1B1B1D1C1D1C1D1D1C1C1D1D1C1D1E1D1D1E1D1D1E1D1C1D
1F1E1D1C1E1F1E1E1E1E1E1F1D1F1F20201E1E1F1F201E1F1F1F1F20201F2020201E2020
202121212020212122202020212121212122212122222222232223232325222423232522
232424242525242524252525252627252626262625252528272626282727292727272828
292829292A28282A2A292A28292A2A2929292A2A2A2A2B2B2B292B2B2C2A2B2C292B2C2B
2D2A2B2C2B2B2C2C2C2C2B2C2B2C2A2C2B2C2A2B2B2A292C2A2A2A2B2A2A2B2A29292B2B
2A29292A292B292928272927272829282728282727282927272726262627252526262525
252423252424242524232423232324242324242122222223212121212221212222211F20
212120202021201F20202120201F201F201E1E201F1E1F1F1F1E1E1E1E1E1D1E1E1E1D1C
1E1E1E1E1D1D1D1D1E1D1E1D1D1D1D1C1C1D1C1D1D1D1C1D1C1D1C1C1B1C1C1B1C1D1C1C
1C1C1D1B1C1B1B1B1A1B1A1B1C1B1A1A1A1A1B1B1B1B1A1A1A1B1B1A1A1A191B1A1A1C1B
1B1A19191B191A1A1A1A1B1A19191A1A1A1A191A1A1A1A19191A191A191A191A18191919
1A1A181A1A18191A
1C1C1B1B1B1A1B1A1B1A1B1A1A1A1A1A1A1A1B1B1B1A1B1B1A1B1A1B1A1B1B1A1A1A1B1B
1C1B1A1A1A1B1C1C1B1A1B1A1B1A1C1B1A1A1B1C1B1D1B1C1C1D1C1D1B1B1B1C1B1C1C1D
1B1B1C1C1D1C1D1D1C1C1B1C1B1D1D1D1C1D1D1D1C1C1D1C1C1D1E1D1D1D1E1E1E1D1D1D
1E1E1E1E1E1E1E1E1F1F1F1F1E1F1F1F1E1F1F1F1E201F201F1F2020201F2020211F2020
211F2021202022221F22212120212220221F222221232222232223222224242422222424
242424242324242424262425242626262524262725262626272627262627262828282829
2828272A2728282B29292A292929292928292A29292B2B2A2A2A2B2B2A2A2C2B2B2B2B2C
2B2B2A2B2B2A2A2A2B2C2B2B2A2A2A2C2C2A2C2C292A2A2B2A2A2A292B2B2A2B2B29292A
29292A292A282829272728292A2928272828282827272627282527272625252524252623
252523242524252524232425232424232323232222232221212121232122222121202120
2021202020202021201F201D201F1F201F201F1E201E1F1E1D1E1D201F1E1E1D1E1D1D1E
1D1D1E1D1D1D1C1D1C1D1D1D1D1D1E1D1C1D1D1C1D1C1C1C1D1B1D1C1D1C1B1C1C1B1D1A
1B1B1B1B1C1A1B1C1B1B1C1C1A1B1B191B191B1A1A1C1A1B1A1A191A191A1A1A1B1A1A1A
1A1A1A1A1B181A1A1A191C1A1A1B1A1A1A1B1A191A1A1918191A1A1A1A1A1C1A191A1A1A
1919181717191919
1D1B1C1B1B1A1A1A1A1A191B1B1A1A191A191A1B1B1A191B191A1A1A1B1B1B191B1B1B1C
1B1B191A1B1A1B1B1B1B1A1A1A1B1B1C1C1A1B1B1C1C1B1A1C1C1D1C1C1C1C1C1A1C1B1C
1C1C1C1D1C1D1C1C1D1C1C1C1C1C1D1D1C1B1D1C1D1C1D1C1E1C1D1D1D1E1E1D1E1E1D1E
1D1D1D1E1D1F1E1D1F1D1E1F1E1F1E1F1E1E1F1F1E1F201F1E201F202020201F20202021
20221F202020202020212221202221212021202121212123242322232323242323242425
252323232424252424252625252526262525242526252626262526242727272728272727
272827282727272828272929282929292A2928292A2A292A2A2A2B2A2A292B2A2A2A2B2A
2B2B2A2A2C2C2C2A2C2B2B2C2B2A2B2A2B2B2B2A2A29282B2A292A282A28292829292929
272A28282827282729272A27282829292628282726262727272627272425252525232525
242424232423242525242424232423232323232222222022212222212222212121212121
202022201F20211E1F1E1F201F1F1F1F1F1F201E1F1E1F1D1E1E1D1D1E1F1D1E1D1E1E1E
1D1D1E1D1C1E1D1E1C1D1C1E1D1D1D1C1C1C1E1C1E1C1C1B1B1C1C1C1C1C1B1B1B1B1D1C
1B1B1C1D1C1B1C1A1B1A1B1B1B1B1C1B1A1A1B1A1B1A1A1A1A1A1B1B1A1A1B1A1B191A1A
1B1A1A1A181A1A1B1A1A19191A191A1A1A1A191A1A191A1A1A191A191A1A191919191A19
1A191A19191A1919
1D1D1B1A1A1A1B1A1A1A1919191A1B1B1A1A1A1A1A1B1B1A191A1A191A191A1B1A1B1B19
1A1B1B1B1B1A1A1B1C1A1B1A1B1B1C1B1A1B1C1C1A1C1C1B1B1C1B1B1A1C1B1B1C1B1C1C
1B1B1D1C1B1D1B1C1D1C1A1B1C1C1D1C1B1C1C1D1C1C1D1C1C1D1D1D1D1C1E1D1D1D1D1E
1E1E1E1E1E1E1D1F1E1F1E1F1E1E1E1D1E1F1E1E1E1F1F1F1F1F1F1F1F1F20201E1F2020
2120202020221F2121202120202120222121222322232122232224232423222322232324
242323242524242424252525232624262525232525252525252726262726262726282827
292729262829282829292828292A292A2B292829292A2A29292929292A2A2A292A2B2A2A
2A2A2B2B2A2A2C2B282D2A292B2A2A2C2A2A2B2A292A2A2A2A2A2A292829282A29282826
292929282928272726282827282828272626272728272626252727262725262524242525
242524232524232426242424242224222323232322212221212221202221212021202120
202020202021202020201F20201E20201F1F1E1F1F1F1F1E1E1E1D1E1F1E1F1D1E1C1D1E
1E1E1D1D1D1D1C1E1D1E1C1D1D1D1C1C1D1C1C1C1D1D1C1C1C1B1C1D1B1B1C1D1B1C1C1C
1C1C1B1B1B1B1C1C1B1A1C1C1B1B1C1B1C1A1B1A1B1B1A1A1A1B1A1B19191B191A1A191A
1A1A1A1A1A1A1B1A191A1B191A1A171A1819191A1A1A1919191A1B19191A1A191A191919
1919191819191919
1F1D1B1A1B191A1A1A1B1A1A1A1A1B191A1A191A1A1A1A191A1A1A1B1A1A1A1A1B1B1C1A
1B1A1B1A1A1A1B1B1A1B1A1B1B1B1B1A1A1A1B1C1A1B1C1B1C1B1B1B1C1C1B1C1C1B1B1C
1C1C1C1C1B1B1C1B1B1D1B1C1C1C1D1C1C1E1C1D1C1D1D1D1D1E1E1D1D1E1E1D1E1E1D1D
1E1C1D1E1D1F1F1E1E1F1F1F201E1E1E1F1E1E1E201F1F1F201F1F1F1E2020201F201F20
20212022201F212120201F21212022212121212220212323222222222423222123252424
252524242423232523242725252425252525252526242527262625262726262726282827
272728272726282829292A292A2A292A29282829292A282A292A29282A292829292A2A2C
2A2A282A2A2B2A2A2B2A2B2C292A2B2929292929292B2929292A282829292A2A28282928
292827272826272728272827272827272626272727262626272425262426242525242525
242524242524242424242524242323242221222322232222202221222121202120202221
212021212020201F201E1F1F1F1F1F1E1F1F1F1E1F1E1E1E1F1F1F1E1E1F1E1D1C1D1E1F
1C1D1D1E1D1D1D1C1C1D1E1E1D1D1C1E1C1C1D1C1B1C1C1C1C1D1B1E1C1B1B1C191B1C1B
1B1C1B1B1C1B1C1B1B1A1A1A1C1B1B1B1A1A1B1A1C1A1B1B1A1A1A1B1B1A1B1A1A1B1A19
191B1B1A1A1A1919191A1A1A1A1A191A191A1A1B181B1A1A1A1919191B1A19191A19191A
1A19191919191819
1E1D1A1B1C1B1A1B1A1B191B1A19191B191C1A1B1A1A1A1A1A1A1A1B1A191B191B1A191B
1B1B1A1B1B1A1B1B1A1A1B1B1B1B1C1B1B1A1A1B1B1C1B1B1B1B1B1C1C1B191C1B1B1C1B
1C1C1C1C1C1C1C1C1C1C1B1B1C1B1D1C1C1C1C1D1D1D1C1C1D1D1E1D1E1E1C1E1D1D1C1E
1D1C1E1F1E1E1F1D1E1E1E1F1E1D1E1D1E1F1E1E1F1F1F201E201E1F21201F1D21211F1F
1F1F211F2221201F20212020202120212122232021222221222222222223232322242423
252423232223232525252423242526252525252526242525272526262625272626282727
282726262828282729292A27292A292A28282928282A29282929282A29292A29292A2B2A
2829292A2A2A2A2A2A29292A2A2A28292829292A28292B28272A29292829282829292927
272728272728272728272826272727262627272626262626262526262425242425252524
242425242425252424252325242323222222212221212121212121212121212120212021
2021211F212020202020201F1F1F1E1F1E1E1F1E1F1F1E1D1D1E1E1F1F1F1E1C1D1D1E1D
1D1C1E1D1D1D1C1C1C1D1D1E1D1C1C1E1D1D1C1C1D1B1C1C1C1C1D1B1C1C1B1C1C1C1B1C
1B1B1B1B1B1A1C1A1C1A1A1B1B1A1A1A1C1B1B1A1B1B1B1A1B1A19191B1B1B1A1A191A1A
1A1A1A1B1A191A1A1A1A1B1A1B1A1A191A1A1A1A1A1B1A1A191A1A1A191B191A1A1A1719
1A1A1A19191A1919
1F1D1C1C191B1B1A1A1A191A1A1B1A1A1A1A1A1A1B1B1A1A1A191A1A1A1B1A1A1B1B1B1A
1B1A1A19191A1C1B1A1C1A1A1A1B1B1A1B1B1B1A1B1A1C1C1B1C1C1B1B1B1C1C1C1B1B1B
1B1D1B1C1C1B1C1C1B1C1C1C1C1B1D1C1D1D1D1D1C1C1D1E1C1F1E1D1D1D1D1C1C1C1C1E
1E1C1C1C1F1E1E1E201E1E1F1E1E1F1E1F1F1F1F1F1F1F1E1F1F1F1E1F1E1F1F201F1F20
201F21202020202121201F22212220212122202122202122222222222322222224242323
232223242423242326252325252525242426252425252427252627252726252526272627
28272726272726282929292928282829282828282928282A292928282729282929292927
292A29292A292829292A292B2B2B29282929292A2A292A2828282A282828282928272828
292629282828272827262726272727262627272627252627252525262424242424252524
262522232424242425242323242323222322202223222220222121202122212122201F21
20212020201F2020201F201E1F201E1E1F1F1F1E1F1F1F1F1E1E1E1E1E1F1E1E1D1E1E1D
1E1E1D1C1D1C1E1C1D1C1C1D1D1E1C1B1C1C1C1D1C1C1C1B1C1D1B1B1C1C1B1C1B1A1B1C
1B1B1A1B1B1B1B1A1A1B1A1B1A1B1B1A1B1B1A1A1B1B1A1A1A1A1A1A1A1B1A1A1A1A1A1A
19191A1B1A1A1A1A1A1A1B1A1919191B1A1B19191A19191A1A1A1A1A1A1A1919191B1A19
191A191919191919
1E1B1B1A1A191B1B1B1A1A1A1A1B1B1A1A1A1A1B1B1B1B191A1A1A1A1B1A1A1A1A1B191A
1B1A1B1B1B1B1A1B1A1B1A1B1B1C1A1C1B1B1A1B1A1B1B1B1C1B1B1C1B1B1A1C1B1C1B1C
1B1B1E1D1C1D1C1C1B1C1C1C1C1D1C1C1C1C1B1D1D1D1E1E1C1D1C1C1C1E1C1D1C1E1D1D
1E1E1E1D1E1E1E1E1E1E1E1E1E1D1E1F1F1E1E1E1E1F1F1F1E20201F1F1E201F1F21201E
202021202120202121202020212120212121222120212222212122222322242223232422
232423242425222325242424242525262526252425242626242425252625262727272626
2626262727262627282826292927272729282A2827282927282829282828292829292928
292929292A29292A2A2A2B2929282A292828292928282828282828282827282628282628
272927272828262726262827272726272727272527262625252525262425252424252525
262223242423252324232324232321222323222121222222212021222121222120202021
212020201E20211F1F201F201F1F1E1E1E1F1F1F1E1F1E1E1F1F1E1F1D1D1F1E1F1C1D1E
1D1D1E1E1D1D1D1C1C1C1E1D1D1D1C1D1C1C1D1B1D1B1C1B1A1B1A1C1C1C1C1C1C1C1B1B
1A1B1B1B1A1B1A1A1A1B1B1C1B1B1A1C1A1B191B1A1B1B1A1A1B1B1A1A1A1A1B1A1A1A1A
1A1A1A191A1A1A1A1A1A1A1A1919191A19181A191A1A1A1A191A191A19191A19191A1A19
1A1A1A1919191919
1E1B1B1B1B1B1B1B1A1A1B1B191B1B1B1A1A1A1A1B1A1A1A1A1A1A1B1A1B1A1B1A1A1B1A
1A1A1B1A1B1B1B1B1B1B1A1B1B1A1C1A1B1C1B1B1C1C1A1B1B1C1B1A1D1B1C1B1C1C1C1B
1B1C1B1C1B1B1B1B1B1C1C1C1C1C1D1C1C1C1C1D1E1D1C1C1D1E1E1C1D1D1D1C1C1C1D1D
1E1E1E1E1F1E1D1E1F1F1E1E1E1E1E1E1E1F1D1E1F1F1D1E1F1E201E1F1F1F201F1F201F
1F2020201F1F202021202021202021212120202221212222222322222223212224232323
232423222324232323242425242524232325242524262524252525252626272625252627
26272626262627272827282A272827282529282728282929282827292826282A28282828
2828282928292A2928292929282929292929292829282828282728282827282727282628
272826272826282626262827262527262525252625262526252524262524242524242324
242323232423242323232323232222212221222221222221222221212121202021212020
21202020201F20201F1F201F20201E1F1E1D1D1F1E1E1F1E1D1D1D1D1E1D1E1E1E1F1E1E
1E1C1D1D1D1C1E1E1D1D1C1D1D1C1C1D1B1C1C1D1D1C1B1C1D1D1B1C1B1B1B1B1B1C1B1C
1C1C1C1B1B1A1A1B1B1C1A1A1B1A1A1A1B1B1B1A1A1A1A1B1A1B1A191A1B1C1B1A1A1A1B
191B1A1B1A1A19191A1A191A19191A191A1A191A1A1A1A191A19191A19191B1A191A191A
1919181A19191819
1C1B1B1C1A1B1A1A1A1B1B1A1B1A191A1A1A1A1A1A191B1B1B1B1A1A1A191B1B191A1B1A
191B1A1B1A191B1B1A1A1B1B1B1B1B1A1C1B1C1B1B1B1B1B1B1C1B1A1C1B1B1C1B1B1B1B
1C1C1B1B1B1C1C1B1C1C1C1C1B1D1D1D1D1C1C1D1C1D1D1D1E1D1C1D1D1D1C1D1C1E1E1D
1D1E1E1D1E1D1E1F1E1E1F1D1E1F1F1D1F1F1F1F1F1E1E1E1F1F1F1F1F1E1F1F201F1F21
1F1D1F1F2020201F202020201F2121212221212122232122222023222222222222222322
222223242323242223242324242324242524262525262325242525262525252625262627
262627262527272627272727262827282727282828292827282829282927272928282828
282827292928292829292729282829292927282829272827272827272727272826282727
272627262626262727272627262726252426252626252524252524232424252425252324
222423232324232423242223232321212122222122212123212121212121212022201F1F
20201F20211F1F1E1F1F1F1E1F1D1F1F1F1F1E1F1F1F1E1E1F1C1F1E1D1E1E1F1E1D1E1E
1E1D1E1C1D1D1C1D1D1D1D1E1C1B1C1D1D1C1B1B1D1D1A1C1B1C1C1C1B1B1B1A1C1C1B1B
1C1C1A1B1B1C1B1B1A1B1B1B1B1B191B1A1A1B1A1B181B1B1A1A191B1B1A19191A191A19
1A1A1A1A191A1A191A181B181B1B19191A1A1A1A1A1B1A1A1B191A1B18191A19191A191A
1A1A191919191819
1C1A1A1A1A1B1B1A1B1B1B1B1B1A1A1C1A1B1A191A1A1B1B1B1A1A1B1B1A1A1A191A1A1A
1B1A1A1B1C1C1B1A1C1A1C1B1A1A1A1C1B1A1C1B1A1C1B1A1B1C1C1C1C1B1C1B1B1D1D1B
1C1B1B1C1C1B1C1C1C1B1B1C1C1C1C1D1D1D1C1C1D1D1D1B1C1C1D1C1E1D1D1C1C1E1D1C
1C1D1F1D1D1E1E1E1E1E1D1E1E1E1E1F1E1F1D1F1E1E1E1E1F1F1D1E1E1E1F1F1F1E1E1F
2020201E1F21202021211F20202121202122212120212121222121222121212222232223
242223232323222324232426242624242425242526242424252525242425242526262625
2726272627272726282827262827292726292827282928272927272828282A2928282829
29282828282928272A292A28272828292728292927282527282727282827272826272528
282727272626262626262626252625242626242525262524252425262625232422252324
242423232225252322222322222223222221202122212121222222212221222120202122
1F1F1E201F1E1F1F201F1F1F1F1F1E1F1E201E1E1E1E1E1E1E1F1E1D1D1D1D1E1D1D1C1D
1C1D1D1D1E1E1D1D1C1D1B1D1C1C1C1C1C1B1C1E1C1C1C1D1B1B1B1C1C1C1B1B1C1C1B1B
1C1C1A1A1C1B1B1A1B1A1B1B1B1A1A1C1A1B1C191C1A1C1A1B1B1B1B1A191A1A1A1A1A1A
1A1A1B1A1A1A191A1A1A1A1919191A1A1B1B1B1A1B1A1A191A191A19191919191919191A
191A19181A191919
1C1A1A1A1A191A1A1B1C1B1A191B1A1A1A191A1B1A1A1B1A1B1A191A1A1A1B1C1A1A1B1B
1A1A191C1A1A1A1B1B1A1A19191B1A1A1B1B1B1A1C1B191B1B1A1A1C1C1B1B1B1B1B1B1C
1B1B1C1B1C1D1B1C1D1C1C1C1E1C1E1E1C1C1C1D1C1D1C1E1D1C1E1E1E1C1D1E1C1D1D1C
1D1C1D1F1D1E1C1D1D1C1D1F1F1E1D1D1E1F1E1E1F1E1E1F1F201E1F1D201F1E1E1F201E
1F201F1F201F211F1F1F1F20201F20212222202122212020212321222121232222212123
232321222323232325242324242423252424242525252425232425252525272426252626
242626262526262627282728262827262828272729272628292728282827282729292727
292827272728292928292828282A28292828272727272827272827272726262726262726
272627262626282626262725252625262826252525232425232324242523222423242323
222423222223232322222223222222212222212120222021201F2122212220202021201F
201F20201F1F201F201F1F201F1F1F1E20201F1E1E1D1E1E1D1F1E1D1E1D1D1E1D1E1D1C
1F1D1D1D1D1D1D1D1D1D1C1D1B1D1B1C1D1D1C1C1D1C1C1C1C1B1B1C1C1A1B1B1B1B1C1A
1B1B1B1A1B1B1B1B1B1A1C1A1A1B1B1A1A1B1B1B1A1A1A1A1A1A1A1B1B1B1B1A1B1A191A
191A1A19191A1B1A1A1A1B1A1B1A1A1A1B191A1A1A1A191A191B191A1A19181B1A1A1B1A
1919191818191919
1B1B1B1A191A1A1A1B1B1B1C1B19191A191B1A1A1B1B1919191B1B1A1A1A1B1B1A1A1A1A
1B1B1A1A191B1B1B1A1B1A1B1C1A1B1A1C1B1B1B1C1B1A1B1B1C1B1B1C1A1B1C1A1C1C1C
1C1C1C1B1B1B1B1C1C1C1C1C1C1D1C1C1D1C1C1C1C1C1D1C1E1E1D1D1C1D1E1D1D1F1E1D
1D1C1D1E1D1D1E1E1D1F1F1E1E201D1E1F1E1E1E1E1E1E1F1E1E1E1E1E1F201F1F201F20
1F201F20202020201F20202120202022211F212121202021212121202221232222222322
232123232222232422232424232424232323242525242325242525242426262624252525
252526262526262628262626282726272828252726262828272628272829262827272727
282829272828282A28272829292829272728292827272828262627272627252727252626
272726272625262627252526252625262525242525242425252325232525242424232422
22232322232322232222232323232222232021212022202020212221212121202021201F
201F1F211F20211F1F1F201F201E1F1E1F1F1F201E1E1D1E1E1E1D1E1E1E1E1E1D1D1C1E
1C1D1E1E1D1C1C1C1D1D1C1C1D1D1D1D1C1C1C1D1D1B1C1D1B1B1C1B1D1C1A1C1A1C1B1B
1C1B1B1C1B1A1B1B1A1B1B191A1A1A191A1A1C1A1B1B191A1B1B1B1A1A1B1A1A191B191B
1A191A1919191B1A191B1B1A191A1B1A19191A1A1A1A191A1A1B1A19191A1A1B1919191A
1919191A191A171A
1B181A1A1A191A1B1A19191A1A1A1A191B191B1A1A1A1B1A191A191A1A1A1B1A1B1A1919
1A1A1A1B1B1B1B1C1C1B1B1B1B1B1C1B1B1B1B1B1B1C1B1B1A1B1B1B1B1B1C1C1B1B1B1C
1B1C1D1C1C1B1C1D1C1C1D1D1C1D1C1C1D1D1E1B1D1C1E1C1D1D1E1C1D1D1D1E1D1E1D1D
1D1D1E1D1E1C1E1D1D1D1F1E1D1F1E1E1E1F1F1F1F1E1D1F1E1F1E1E1F20201F1F1F211F
1F201F20201F1F211E2021202021202021201F2020202121202021212122222222222221
222222232322212222232225242523242325232525252424232524242524242524262525
252526262626262726272426262726272826272628272627272827262727282626272827
282727282727272928272729282727262827262726282727262626252628272626262627
262627252527252626252625242626242527242425252524252424232523242424232324
2323232222222222232223222222222222212120212121212220212120202121201F1F20
1F1F20201F21201F1F1E1F1F1F1F1E1F1F1E1D1E1E1F1D1F1E1D1D1E1E1D1E1E1E1C1D1D
1D1D1D1D1D1D1C1D1B1C1D1C1C1C1B1C1C1C1C1C1A1B1C1D1C1C1C1C1C1B1C1C1C1B1B1B
1C1C1C1C191B1B1A1A1A1A1A1B1B1B1A1A1B1B1B191A191A1A1A1A1A1A1A1A1A1A1B1919
1A1B1A191A1A1A1A1A191A1A1A181A191A191A1A191A1A191B1A191A1A1A19191A1A1B1A
1A1A191819191919
1A191A19191A1A1A1B1A1A1A1A1B1A191B1A1A1A1B1B19191A191A1B1B1A191A1A1B1B1A
1C1B1C191A1B1A1B1B1A1A1B1A1A1C1C1B1B1B1A1B1B1C1B1B1C1B1C1B1B1C1C191B1B1C
1B1C1C1C1B1C1C1B1C1C1C1D1D1D1D1D1D1E1F1D1D1D1C1C1C1C1C1B1D1D1E1C1D1E1E1D
1E1E1E1E1D1E1D1E1D1E1D1D1D1E1E1C1E1F1E1E1F1E1E1E1D1E1F1F1F1E1E1F1F1F1F1F
1E1E201F1F1F2020201F201F1F2120212020222022212021212321212122222222222222
202222222222232323232424242424242325242424242424272425242426252524262525
252625262525252627262627262627272727282725272727262726272727282726272828
262827282828272827272728282729272825272726272626272826262827282525252626
272526252626262625252526252525252425242424242425232424252323242223242223
232423232323212221212221222122212121212120222020202020202121201F211F1F20
2020201E1E201F1E1E1F1F201F1E1E1D1E1F1E1E1D1E1F1E1D1E1D1D1C1C1E1D1E1D1D1D
1C1D1E1D1C1C1D1D1D1C1B1B1C1D1B1C1C1C1C1C1C1C1C1C1D1D1B1B1A191C1B1C1C1B1B
1A1B1B1B1B1B1B1C1C1A1A1A1A1A1B1A1A1B1A1B1A1A1A1A1A1A1A1A1A1A19191A191B1A
191A1A191B181C191B191A1B1A1A19191A1A1919191A1A191A19191A181A1A191A18191B
1919191A18191819
1A1A19191A1A1A1A1A1B1B1A1B191A1A1A1A1B191A181B1A191A1B1B1B1A1A191B1A1919
1A1A1A1B1B1A1B191A1B1A1A1A1A1A1A1A1A1B1A1B1B1B1B1B1C1C1B1D1B1A1A1B1B1C1B
1C1C1C1C1B1C1B1C1C1B1C1C1E1D1E1E1F1E1D1C1D1D1C1C1C1D1C1C1E1D1D1E1C1D1D1D
1D1C1E1D1D1E1D1E1E1D1E1D1D1F1F1D1E1F1F1E1F201E1E1E1F1E1E201E1F1F1F1E1F1F
1F1F1F1F2020202120201F20202121212121202020212020212121202221212222222122
232122222222232323222223242423232423242325242525242526232425242526252425
252524252626262526262725262626262626262627262726272726262727282726262727
282727282827252628282628282727262726272526262626252626272826272626262625
262626272624252524252624252524242524232424252524242525232424242324222223
212323222321232122212122222221212122212221202121212122211F21202020202121
20201F201F1F20201E201E1E1F1F1F1F1D1E1E1E1D1D1E1F1F1D1D1E1D1D1E1D1C1E1D1D
1C1D1E1C1C1C1C1B1D1D1C1D1C1B1B1C1B1B1C1B1B1C1C1C1C1E1B1A1C1B1A1C1C1B1B1B
1C1B1A1B1B1A1A1A1A1A1A1A191B1B1B1B1A1B1A1A1A1A191B1A1A1B191A1A1A1A19191B
1A1A1919191A1B1A191A1A191A181A19191B1A1A19191A1A1A191A191A1A1A1B1A1A1B19
1A19191919191918
1B191A1A1A1A191A1A1B1A1A1B1B1A191A1B1A1A1B191A1A1A1A1A1B191A1A1A191B1A1A
1A1A1A1A1A1B1B1A1C1A1C1B1B1A1A1B1C1A1B1D1B1C1B1C1B1A1A1B1C1B1A1C1B1C1B1C
1C1C1B1B1B1C1C1B1C1C1B1C1C1D1D1D1E1F1E1D1D1E1D1C1E1C1D1D1D1C1C1D1C1D1D1D
1D1D1D1C1E1D1D1D1D1F1D1E1E1D1E1D1F1F1D1F1E1E201E1E1F1E1E1F1E1E1E1F1F1E1F
201F1F201F1F20201F2020201F2121201F21202120222021212020222120212122212221
202223222222232322242323232322232324232323232423232524252525242625252526
252425262525252626252627262625262525262625272626262627252726272727262726
282626262726262826272826272727272726262626262627252626272626252525262526
262526252625262425262426242425242423242424252524252424242423242323232222
2122232222222222222321222122222221202120212120212020212021201F1F20201F1E
1F1F1F1F1F1F1F201F1E1E1F1E1F1E1E1F1D1E1E1D1E1E1E1E1D1D1E1D1F1E1E1D1E1D1C
1C1D1C1D1D1C1C1D1C1C1C1C1C1C1D1D1D1B1D1D1C1B1D1D1C1B1C1C1B1B1C1B1B1B1C1D
1A1C1B1A1B1B1A1B1A1A1B1A1A1A1B1B191A1A1B1B19191A1A1A1A1A191B191A1B191B1B
1B1A191A171A1A181A191B19191A1B191A1A1A191B1A191A1A191A191A1A1A19191B1B1A
191A1A191A181919
1B1A19191A1B1A1B191A1A1A1B191A1B191B1A181C1C1A1A1B1B1A1A1B1A1B1B191A1A19
1A1A1B1B1B1B1B1B1A1B1B1A1B1C1A1C1B1B1C1B1B1B1B1B1B1C1A1A1B1C1C1C1B1B1B1B
1C1C1C1C1C1D1C1C1C1C1D1C1D1E1C1F1E1E1C1D1C1D1C1C1D1D1D1C1C1D1D1C1D1D1D1D
1D1C1D1D1E1E1E1E1E1D1E1E1C1F1D1E1E1F1F1D1F1F1E1F1D1F1E1E1F1F1E1F1E20201E
1F1F201F1F1F1F201F1E2020202121212021202220211F211F211F222122222121222122
222220232122222223222324232323232323252424252524232425222524232524252425
252525262524262626252426262626252725272626272727262626272727282625272626
252625262527252626252627282726252627262726262527252525262527262625242525
252626262524252424252325242425232424252424242423232325242223222323232224
22212123232222212321212122212221212021212121212220212020201F1F20201F1F20
202020201F201F201F1F1F1F1F1E1E1E1E1E1E1E1F1F1F1E1D1D1E1D1D1E1D1D1C1D1D1D
1E1C1E1E1D1D1B1C1D1C1C1D1C1C1D1C1C1C1D1C1C1C1C1B1C1A1B1C1C1C1B1B1C1C1B1A
1B1C1B1A1B1A1B191B1A1B1B1B1B1B1A1A1C1B1A1A1A191A1B1A191A1B19191B191A1B18
1A191B1A1A1A1A1A19191A19191B1A1A1A191A191A1A1A1B191A19191A1A1A1919191A1A
19191A181919191A
1A19191A1A1A191B1A1A1A1A191A1A1A1A1B1B1B1A1B1A1A1C1A1B1B1A1A1B1A1A1A1B1A
1A1B1A1B1B1B1A1B1B1B1C1B1B1B1B1B1C1B1B1B1C1C1B1C1C1B1B1C1C1B1C1B1B1C1B1C
1B1B1B1B1B1C1A1C1C1C1B1C1D1B1C1E1E1E1D1C1D1C1D1D1D1D1E1C1C1C1C1D1D1C1C1D
1D1D1D1D1E1C1D1E1D1D1E1E1E1E1E1D1D1E1E1E1E1E1E1D1E1F1E1F1F1F1F1D1F1F1E1E
1F211F1F21211E2020201F2120201F20211F2020201F2021212021222122212021212121
202221222222212122232323232423222322222325242322232423252325252325252524
252425232425252525252625272525262425262525252626262625252624262726262626
272625272627262626262627282625272627272626262724252526272626262525252525
262526252525252424242425242324232325242223242324232422222323232123232223
22212223232223232223212222222221212121212120202022202022211F201F2020201F
1E201E1E1E201E1E1F1E1E1F1E1E1D1D1E1F1D1F1E1E1E1D1D1E1D1D1E1E1C1E1E1D1C1D
1D1D1D1D1C1D1C1C1D1C1B1C1C1C1C1B1C1C1C1D1B1C1C1C1C1B1D1B1C1C1B1C1A1B1C1B
1C1B1B1A1C1B1B1A1A1B1B1A1A191A1A1B1A1A1A1B1C1B1B1A19191A1B1A191A1A1A1A19
191B1A191A19191A1A1A1A1A1B1919191A191B1A1A1A19191A1A19191A191A1919191919
18191A1819181819
1A1A19191B1A1A1B1A1A1A1A1B1A1A1A191B1A191A1B1A1A1A1A1C1A1B1A1B1A1A1A1A1B
1B1B1A1A1A1B1B1A1A1A1B1C1A1A1B1B1B1A1C1B1C1C1B1C1D1B1B1B1C1C1C1B1C1B1C1C
1D1B1C1C1C1C1C1B1C1C1B1C1C1C1F1D1F1D1D1C1D1C1B1E1D1E1D1C1C1B1D1D1E1C1E1D
1D1D1D1D1D1D1C1D1D1D1D1D1D1F1D1E1E1D1D1E1D1F1E201E1E201F1F1E1E1F1F1E1F20
201F1F1E20201E1F1F211F2020202020212020201F212121202120211F21222121212122
222222212223212223222122232323212424222524242324252322232425262324242624
252525252424242525242525262526252726252627272527262525252725272627252626
262626262626252526262625262528272426262625242525262626272626252725232525
262426262525242424242324242424242423222321242323232322242423222222232223
222222202223222121232222202121222121212020211F2020201F1E1F211F20201E1F1F
1F201F1F1F20201F1E211F1E1F1E1E1D1D1D1F1D1D1D1F1E1E1E1E1F1E1F1D1E1D1D1D1D
1E1D1D1D1C1D1D1D1D1D1B1E1D1C1B1D1C1B1C1D1C1D1C1C1B1D1B1C1B1B1A1C1B1B1B1C
1B1A1B1A1B1A1B1A1B1A1B1B1A1A1A1A1C191A1A1B1B1A1A1B1B191A191A1A191B1A191A
191A19191A1B1A1A1A1A1A191B19171B1A191A191A191A191818191918191A1B19191918
1A18191919181719
1A19191A1A1A191B1A191A1A1A1A1A1A1B1A191A1A1A1B1A1A1B1A1A1A19191A1B1A1A1A
1A191A1C1B1B1B1A1B1B191A1A1B1B1B1C1C1D1C1C1C1C1C1C1B1B1B1B1A1B1C1C1C1B1B
1B1B1B1B1A1B1C1C1C1D1C1C1D1E1C1D1E1D1C1D1C1C1B1C1D1D1E1C1D1D1C1C1D1B1D1D
1E1D1D1D1D1D1D1E1E1D1D1D1D1E1D1E1E1D1E1D1E1E1E1E1F1E1E1E1E1F1F1F1F1E201E
1F1E1F1D1F1F1F1F1E1E202120202121201F1F1F20202021202122212021212120222121
232221232322212223232223222222222423232224242324222423232424242424232425
252525242424252525252525272626242625252525262526242524272626252628272626
252527252624262726272626252727262726262525252425252625252624262524242526
242425242525242524252424232422232524232423232224232224232223212323222223
222022222221222121212121202021212120202021212020201F2020202121201F201E1F
1F1F1F201F1D1E1E1F1E1F1F1E1E1E1E1E1E1E1E1F1E1E1E1D1D1E1D1C1C1D1D1D1C1C1D
1D1C1D1D1D1D1D1D1C1C1B1B1C1C1B1B1C1B1B1C1C1C1C1D1C1C1B1B1B1B1A1C1B1A1A1B
1B1C1B1B1B1A1B1A1B1A1B1B1B1B1A1B1B1A1B1A191A1A1B1A181A191A19191A181A1B1A
191A1A1A1A1A1B1C191B1A191A1A1A1B1B1A1B1A1A1A191A1A1A1B1B1A191A1A1A1B191A
191A18191A191819
1A1B1B1A1A191A181B1A1A1B1A1B1B1A191B191A1A191A191A1A1A1B1B1B1A1A1B1A191C
1B1A1B1A1A1A1B1B1B1B1B1A1B1B1C1C1B1B1B1C1C1C1C1C1C1C1B1B1C1B1B1B1B1A1A1C
1C1B1C1B1C1B1D1C1B1C1A1D1B1D1C1C1D1D1D1D1C1D1C1C1D1C1D1B1D1E1C1D1C1D1D1D
1E1D1D1D1E1E1D1E1D1E1D1E1E1D1F1E1E1E1F1D1E1F1E1E1F1F1F1D1E201E1E1F1E1F1E
201F1F1E1E201F201F211F1F1F1F202120201F21201F202120211F202120212020202222
212220212122232222232222232223232223222124242424242324232324232425232424
242524242426252523252625242525252625252625252626262626242625262626252725
262626272626252526252626262526262625262625242425242524252425252525262526
242325252623242425252426252424232224232422242322232322232322232224232323
21222221222122212120212221212121202120222021202120201F2020201F1F1F1F201F
1D201E1E1F1E20201E1F1E1E1E1D1D1E1E1F1F1E1D1E1E1D1D1D1C1D1D1D1D1C1E1D1C1C
1D1D1D1C1E1C1D1E1D1B1C1D1C1C1B1B1B1B1C1C1C1C1C1C1B1C1C1C1B1B1C1C1C1B1B1B
1A1B1A1C1A1B1B1A1A191C1B1B1A1A1A1B1A1A1B1A1B181B191A19191A1B1A1A1A1A191A
1A1A19191919191B1A1A1A1A1A1A191919191A1A1A191A1819191B191A1A191919191A19
191919191A1A1918
1A1B1B191A1B1A191B1A1A191A191A1A19191B1A1A1A1A1B1B1A1A1A191A1A1A1A1A1B1A
1B1A1B1A1A1A1C191C1B1B1C1B1A1B191C1C1B1C1C1C1C1C1B1C1B1B1B1C1B1B1B1B1B1C
1B1A1B1C1B1C1C1C1C1B1C1C1C1C1D1D1D1D1C1D1D1D1D1C1C1C1C1D1C1C1E1C1C1C1E1D
1E1C1D1C1C1D1C1D1E1E1E1D1D1E1C1E1E1E1E1E1D1F1E1F1F1E201F1E1F1F1F1E1F201D
1F1F1F1E1F1F1F1F1F201E1F1F1F201E202020212021201F201F21212121212021222122
212120212221212222222322212222222224232322232324232223242322242324232425
252423252425262423242524252524252625242625242426252625252726272625262626
262426262526252526262624252626262726262524242525242625252525242424242525
232424232523232423232223242324222423222424232324242323232422222321242224
2222222221232121222222202020212121211F201F2021202021201F201E20201F1F1F1F
20201E20201F1E1F1F1D1E1E1E1C1E1E1D1E1E1E1D1F1D1D1E1E1D1F1E1E1D251F1D1E1C
1C1D1D1B1C1D1D1D1C1C1C1C1B1B1C1C1C1C1B1D1B1B1C1C1C1C1C1C1B1B1A1B1B1C1B1B
1B1B1B1B1B1B1B1A1A1A1A1B1B1B1A1B1A1B1B1919181A1A1A1A1A1A1A1B1B1A1A1A1A1C
1A191A1B1B1A1A1A1A181A191B191A1A181B191A19191A1A1A1A19191A1B191919191A18
1A18191919191819
1A19191919191B1B1A1A19191B1B1A1A1A1A1B1A191A1B1B191A1A1A1B1B1A191B1A1A1B
1A1A1A1A1B1B1B191B1C1A1A1C1D1A1B1B1D1B1D1C1B1D1C1D1B1B1A1B1B1A1B1B1C1C1B
1B1B1B1B1B1C1B1C1C1C1C1C1A1C1D1D1E1C1C1D1D1D1C1C1C1D1E1C1C1D1E1E1C1C1D1C
1C1D1D1D1D1D1D1D1D1D1E1D1E1E1E1D1E1E1F1D1D1F1E1F1E1F1F1F1F201F1F1F1F201E
1F1F1F1F1E1E1F1E1E1F201F1F1F1F1F1E2120201F20202122211F202120202021212121
222323222122222223222222222223232221232323232324232424232323232423232424
252423232524242324252526232325232625252525242525252525252524252526272526
242525252425242524262424262627262425242424252425252624242526242324242424
242323242324242423232323232324242323242322242322222223232121242222222222
212221232221212122202121201F2223212121212021201F1F2020211E201F1F20201E20
1F1F1E1E1E1E1F1F1D1E1F1E1E1E1E1E1E1E1E1E1E1E1E1E1E1D1C1D1E1D1C1C1C1D1C1D
1D1A1D1E1C1C1C1D1C1C1D1B1C1C1B1C1C1D1B1B1B1D1B1C1B1A1B1B1C1B1A1B1A1C1B1A
1B1A1A1C1C1B1A1A1C1B1A1A1B1A191A191B1C191A1B191A1A1A19191B1A1A1A1A191B1A
191B191A191B1A191A1A191A1B1A1A1A1A19191A19181A1A1A191A1A191919191A1A1A1A
1819191919191919
19191A19191B1A191B1B1A1A191B1A1A1B1A1B1919191A191A1B1B1A191B1B1A1A1B1B1A
1A1A1A1B1A1B1B191A1A1B191B1B1A1B1C1C1C1C1D1C1C1C1B1B1C1C1B1B1A1C1B1B1C1A
1A1A1B1A1C1C1B1C1D1A1D1B1D1C1B1C1D1D1C1C1C1C1C1D1D1C1C1C1C1D1D1C1C1B1C1E
1D1C1D1B1D1D1D1D1D1D1D1E1E1E1D1D1C1D1E1E1E1F1E1E201F1E1E1E1E1F1E201F1E1E
1F1E1F1E1E1E1E201F1F20201F1E20201F20211F1F202021202120202121202221212020
2122212321212123221F2221232222222224222223222221232323222323242324232323
242425242424262524242424242724242525242525242525232525252524252626262526
252525242424252525262525262423242725262625252425242423252424252524232324
242323252422232325242323242322232422222423222422232223232122232322222220
2021212020212121211F202220222020202121212021201E1F1F20201F201F1E201F201F
1F201F1F1F1F1D1E1E1E1E1E1D1D1D1F1E1E1D1E1E1E1D1D1D1E1D1E1E1D1C1D1D1E1D1C
1E1D1D1D1C1D1B1C1C1C1C1C1C1B1B1D1E1D1B1C1C1C1A1C1A1B1C1B1B1B1B1C1B1D1B1B
1B1B191A1C1B1B1C19191B1B1A1A1A1A1A1B1A1B1A1A1B191A1A191A191B1B1A1B1B1A1A
1A1A19191A1A191A191A1A1A1A1A1A1919191A1919191B1A1A1918191A1B1918191A1819
19191A1A1B191A19
1A1A19191A181B1A191B19191A1A1B1A1A1A1B1B1A1A1A1A191A1A1B1A1B1B1B1B1A1B1A
1B1A1C1A1B1A191A1B1B1C1A1B1A1B1B1C1B1C1B1C1C1B1C1B1A1C1B1B1C1B1B1B1C1C1B
1A1C1B1B1D1C1B1B1B1B1B1C1B1D1C1C1C1C1B1C1D1B1D1D1C1C1D1C1B1B1C1B1D1C1D1C
1D1C1E1D1D1D1D1C1D1D1D1D1E1D1D1D1D1D1D1D1E1E1E1E1D1F1E1D1F1F1F1E1D1E1F1E
1E1E1E1E1F201F1E1F2021202020202021212020201F1F20202021212021212121202221
212021212221212122202221212423232222222324222322242223232324222423252423
232323232424242324242524242423252624242525242324252523252525252525252525
252624242526242526242424242524232424242424252325242424242425252424242423
242524232423242323232323232322222324222324222321222222232322222222212322
212121202221212121212121222121202021202121211F21201F1F1F201E1F1F1F201F1F
201E201E1F1F1F1F1E1E1E201F1E1E1E1E1F1E1D1D1F1D1D1F1D1D1D1D1D1C1D1C1E1D1D
1C1C1C1D1C1D1C1D1B1C1C1C1C1E1B1B1D1D1B1A1C1B1B1C1B1C1B1B1B1C1B1B1A1B1A1C
1A1B1A1B1C1919191A1A1B1B1A191A1A1B1A1A1A1B191A1B1B1A1A1A1A191A191A1A1A1A
1B1A1B191A1A1A19191A19191A1A1A1B1A1A1A1B1A1A1919191A18181919191A1A1A1919
191919191919191A
1A1A19191A1A181A1C1A1A1A1A1A1B1A1B1A1B1B1B1A1B1B1A1A1B1B1A1A1A1A1B1C1B1B
1B1B1A1A1A1A1B1B1B1B1A1C1B1B1B1B1D1B1B1B1D1B1B1B1B1C1A1B1C1B1C1B1A1C1C1C
1D1B1B1B1B1B1B1B1B1C1C1C1C1C1C1C1C1E1D1B1B1C1D1C1C1D1B1C1D1C1C1E1D1C1D1C
1D1D1D1D1C1D1D1C1F1D1D1D1D1E1D1E1E1D1E1D1E1D1E1F1E1E1F1E1F1E1E1D1D1E1E1E
1F1F1F1F1E1F201F1F1F1E1F2021202021201F201F202020202120212120201F21212221
202121212121202022222220212223222122212223232221242323232424242223242423
242424232324252624232324242524242426252424242525252424252523242425252425
232525272623242426242424242524252524232324252323232425242324252323242324
252324252425242222232323232323232223222223212322232222222322212222202121
21222121222220212121212020212220211F2021201F202020201F20201F1F1F1F1F1E1F
1E1F1E1F1F1E1E1E1E1F1E1E1F1E1F1D1C1E1D1D1D1D1D1D1C1D1D1C1E1C1B1C1D1C1C1C
1C1B1D1D1C1C1B1D1C1B1C1B1C1B1C1C1C1B1C1C1D1C1C1D1B1B1B1C1B1C1B1B1A1D1B1C
1C1B1B1B1B1B1B191A1A1B1A1A1A1A1A1A1B1B1A1A191A1A1A1A1B1A1B1A1A1A1A1A1A1A
19191A191A191A19191A1B191A191A1A191B1A191A181B181A1A1A191A19191A19191919
1919181A1B1A191A
1A1A1A19191A191A191A1A1A1B1B1B1A1A1C1A1B1A1B1A1B1A1B1B1A1B1B1A1C1A1A1B1A
1A1B1B1B1A1C1C1A1B1A1B1B1B1A1B1A1B1B1B1B1C1C1B1B1B1B1B1A1B1B1C1B1B1A1B1B
1A1B1B1B1C1C1C1B1D1B1C1B1B1B1B1C1C1A1D1B1C1D1C1C1D1D1D1C1C1C1D1D1E1C1C1D
1C1D1D1D1E1D1D1D1D1F1D1D1C1C1B1D1E1D1E1E1E1E1F1E1F1E1F1F1F1E1D1F1E1E1F1E
1E1F1E1E1E1F1F1F1F1E1F20212020201F1F1F2020201F20202021202020222220212021
1F2021212020202021212221222122212223222222222223232323262321222223222223
222322232324232424252424252424252425232624242523242324242425252624242425
252424252525242324252425252423252524262524232323252524232424252424242425
242422222223242323232323222324232223232221222321222222222222212221222121
212122212022212221211F202121211F2120201F20212120201F1F20201E201E1F1E1F1F
1F1E1F1F1F1F1E1D1D1E1E1D1D1E1D1D1E1E1E1D1D1D1D1C1D1D1C1D1D1D1D1C1C1D1C1D
1C1C1D1B1C1D1D1C1B1C1C1B1B1B1C1D1B1C1C1D1D1B1C1B1B1B1B1C1B1B1B1C1B1B1C1A
1A1B1A1B1C1A191C1B1C1B1B1C1A1A1B1A1A1B1A1B1B1A1A191A19191B1A19191A181A1A
1A1A1A1A1B1A1A1A1B1A19191A1919181A191A1A1A191919191A1A191A19191A19191819
18191A1919191819
1A191919191A1A1A1A1A18191A1A1A1A1B1A1B1A1B1B1C1B1B1C1C1C1C1B1B1C1B1C1A1B
1B1C1B1C1B1C1A1B1A1B1A1B1B1B1B1B1B1C1B1C1B1B1B1A1B1B1C1B1C1C1B1B1A1B1C1B
1A1A1A1B1A1A1B1C1B1B1C1C1C1C1C1C1C1C1B1B1C1C1C1C1C1C1C1D1C1D1C1C1C1E1C1D
1C1C1D1C1D1C1D1D1E1D1E1C1F1D1E1D1D1D1E1D1E1E1F1E1E1E1D1F1E1D1D1F1E1F201F
1F1F1E1F1E1E1F1F201F1E211F1F1F211F1F1F20211F1F21202020202020212020202021
212222212122212121232121222121212122232323212222232323222423232324232222
242323242323242324242324242423232324242424242422242325242623242425262522
242524252424252424242524232424232325232524252424242324232323232424242424
232424232423232322252323242323232222222223232223222222232022222122202220
22212121202020212122212021212021211F1F2021212020201F1F201F1F201F1F1F1E1F
1E1F1E1F1F1E1F1E1F201E1F1E1E1E1F1D1E1D1E1D1D1C1C1D1D1D1D1C1C1D1C1D1C1B1C
1D1C1D1D1B1C1C1D1C1D191D1C1C1C1B1C1C1B1C1B1D1D1B1A1C1B1A1A1B1B1A1A1B1C1B
1A1C1B1B1A1A1A1B191A1C1A1B1A1A1A1B191A1A1B1A1A1A191A1B1B191B1A1A1A191A1B
191A1A1919191A1A1A181A191A1B1A1B1A1A1A19181A1819191A1918181A191918191A19
1A1A1A1919191919
1A181A1A1A191A1A1A1A1A1A1B1A1A1A1B1C1B1B1C1B1B1C1C1C1D1A1C1C1C1C1C1A1A1B
1A1A1B1A1A1A1A1C1B1B1C1D1B1B1B1B1B1B1B1B1B1B1B1B1A1B1B1B1A1B1B1B1C1C1B1B
1A1B1C1B1B1B1C1D1A1B1C1D1B1C1B1B1D1B1C1C1C1B1B1D1D1C1D1C1C1C1D1D1D1C1C1C
1D1D1C1C1C1D1D1C1D1D1D1C1D1D1D1D1D1C1E1D1F1E1D1E1E1E1E1E1F1E1F1E1E1F1F1D
1E1F1E1F1F1E1E1F1F201F1E1E201F201F1F1F21202020202020212020201F20211F2021
202020202122222121212121222123222123222222212222232421232222242323222323
232423242324222424222323232424252325252223252325232424242324232425232524
242524242322232324242325242425242423242323252323252324252322252425252324
222224232324232323232324232323242323222323232221222221222122212221202121
2121222221212221201F202020211F21202020211F201E1F1F201F201E1F1F1F1E1F1F1E
1F1F1E1E1F1E1F1E1F1C1E1C1D1D1D1E1E1D1E1F1E1D1E1D1C1E1D1D1C1D1D1D1E1D1C1C
1C1D1B1D1D1C1C1D1C1C1A1B1B1B1B1B1B1B1C1C1C1B1B1B1A1B1B1B1C1B1B1B1B1C1B1C
1C1A1A1B1B1C1B1A1A1A1A1B1A1A1A191B1B1B191B1B1B1A191A1B1A1A1A1B181B1A191A
191A1B1B1B19191A19191A191B1A1A1918191A19191A1A1A1A19191919191A1919191819
1918181819181819
1A1A191A1A1A1A1B191A191C1A1A1B1B1C1A1B1C1C1C1B1E1D1D1D1F1D1D1B1C1B1C1B1B
1A1A1B1A191A1C1B1A1B1A1B1A1B1B1C1B1A1B1A1B1B1B1A1B1C1B1B1B1B1B1B1B1B1B1B
1D1B1B1B1B1B1D1D1B1C1B1C1B1D1B1C1D1B1C1C1B1B1C1C1C1C1C1B1C1D1D1D1C1C1E1C
1C1D1C1D1C1D1C1D1C1D1E1D1C1D1E1C1D1C1D1D1F1E1D1E1D1E1E1E1E1D1D1D1E1F1E1F
1F1F1E1F1E1F1F1F1F1F1F1E201F1F201F201F201F20201F1F211F20211F202121212121
1F212021222120222121221F212221222121212121232123232323222323232323232222
232323242423242423232423242425242423242324232424252424242424242324242325
242425232324242424252323232324242422242223222324232223242323252322252422
232423232223222321222222232223232222232221222221232222212221212122212021
22232220212120212021202020201E211F201F1F1F20201F201E1F20201F1F1F1E201E1E
1E1E1E1E1E1D1E1D1F1E1E1F1E1C1D1E1D1E1D1E1D1D1D1C1C1D1D1C1C1C1D1C1C1C1D1E
1C1B1D1C1B1C1C1C1B1C1B1B1B1C1B1B1C1C1B1C1C1A1C1B1B1C1D1B1B1B1B1B1B1A1A1B
1B1A1A1C1A1B1B1B1A1B1A1B1B1C1A1B1A1B191B1A1A1B1A1B191A191B1A1A1919191A18
1A191819191A1A1A191A1919191A1B1A1A19191A18191919191919191A1A19191A191B18
19191A1919191819
1A191A1A1A1A1A19191A1A191A1A1B1B1B1C1C1C1D1D1E1F1F20201F1D1D1C1D1B1C1B1B
1B1A1B1B1B1B1B1B1B1B1B1B1B1B1A1A1B1A1B1C1B1B1A1B1B1A1B1B1A1C1B1B1D1B1A1B
1B1A1C1B1B1D1C1B1B1C1B1C1C1B1B1C1C1B1C1C1C1C1B1C1C1C1B1C1D1B1D1E1C1C1C1C
1D1C1D1C1D1E1C1D1D1D1D1D1D1D1C1D1E1C1D1E1E1E1E1E1D1E1E1E1E1E1E1E1F1D1F1D
1F1E1E1F201F1F2020201E1E201F211F1F1F2020201E20201F201F20201E1F2020202020
212220222021212221202122212122212123222121232123222223222223222222232222
232323222423232422232424242323222324232224242323242424252324232523222523
242424232524242424232224232323242323252423232424242322242323242324242422
232222252122232423222222222123232223232221222121212123212221212122212021
20212122202021201F20212020202020201F202020211F201F201F1F201F1E1F1F1E1E1F
201E1D1F1D1E1E1F1D1D1D1D1E1D1E1D1D1E1E1D1C1D1D1D1C1C1E1D1D1D1C1C1D1B1C1B
1E1C1C1C1B1D1B1C1C1C1B1C1B1C1B1B1A1B1B1B1B1B1A1C1C1B1A1B1B1B1A1B1B1C1B1A
1C1A1B1A1B1C1A1C1A191A1B1B1B1B1A1A1B1B1A1A19191A1A1A191A1A1A1A1A1A191A1A
191A1B1A191A191919191A191A1A1B1A1A1A191918191A1A1919191A1818191A1A191919
181818191A181918
1A1A1919191B1B1B1A1A1A1A1A1A1B1A1C1C1C1D1F1F212224242523231F1E1D1C1C1B1B
191A1A1A1B1C1B1B1A1B1B1B1B1A1B1B1B1A1B1B1B1B1A1B1C1C1B191B1B1C1B1B1B1C1D
1C1B1B1B1D1B1B1B1B1B1B1C1B1B1C1D1C1C1B1C1D1B1B1C1C1D1C1C1C1C1D1D1B1E1C1C
1D1C1D1C1E1C1D1D1C1D1C1B1C1D1D1E1D1B1D1E1D1D1E1D1E1D1D1D1D1E1E1E1D1F1D1E
1E1F1E1F1F1F1E1F1F1F1F1F1F2021201F20201F20201F201F201F20201F202020202120
211F20202020202120202022212121202021212121222123222122212223242222232224
222422222223222223242323232323232323242423232324242323242323232423222324
222425222322232423242322232323232424222324242423232325252224222323232423
232323232223222323232222222324222222222322212121222222212120202021202121
2122202121222021201F20201F1F2020201F201F201F201F1E1F1F201E201F1E1E1E1F1F
1E1E1F1C1E1E1E201F1E1E1E1E1D1C1D1E1C1D1E1D1C1C1D1E1D1D1C1D1B1D1D1C1D1C1C
1C1B1C1B1C1C1C1B1B1C1B1C1C1B1C1C1C1B1B1B1A1B1A1B1B1B1A1C1B1C1C1A1B1A1A1C
1B1C1C1B1A1A1B1A1A191A1B1B1B1A1B191A1A1A191B1A1A1A1A191A1A1A1919191B1919
1A191A1A19191B191B191A1B191A191B1A191919191B191A191A191A191B191A19191919
1B1A191919191819
191A19191A19191A1B1A1A1C1A1A1A1B1C1C1E1E1E2325282A2D2C2A2722201E1B1C1B1B
1B1B1B1A191B1A1B1A1B1B1B1B1C1A1B1A1B191A1A1B1B1B1A1B1B1B1B1B1A1B1B1B1B1B
1A1A1B1B1B1B1C1C1B1A1C1B1B1B1C1B1B1C1C1C1B1B1C1C1B1C1C1D1D1C1C1B1C1D1D1C
1D1C1D1D1D1D1E1B1D1B1D1C1E1E1D1C1D1D1D1E1D1E1D1D1E1D1E1E1E1E1D1C1E1E1E1E
1D1E1E1F1F1E1E1F1F1F201F1F1E1F212020202120201E1F1F1F202021201F1E21202021
201E202020211F2120212022202222212022222223222322222123232222222222222321
232322222222242223232122222324232323242224242122232423232423232323222524
242324252423232323232322232423222423222323242323232223222323242323232223
232321242323222222222222232223222222222222212321212221202121222121212020
2120202021212120211F201F20201F201E1F1F20201F1F1F1E1E1E1E1F1E1D1F201F1D1F
201F1F1F1E1F1E1D1E1E1E1E1C1E1D1E1D1E1C1C1D1D1C1D1C1C1C1D1C1B1D1C1C1D1D1C
1B1C1C1C1C1B1C1B1B1C1A1B1B1B1D1C1A1B1A1B1C1B1B1B1B1A1A1C1A1A1A1A1B1B1A1B
1B1C1A191B191B1A19181B1A191A1A1B1A1B191B1A191B1A1A191B1A1A1A191A1A191A1B
1A1B1A1A1A1A1B1B191A1A1A1B181A1A1A1A1A181A1A191A19191A191919191A1A1A1919
1A1A1B19191A181A
1B1A1A1A1A191A1A1B1A1A1A1B1B1A1B1D1D1E2022272A31363939362E2823201E1B1B1B
1B1B1B191A191A1A1A1A1A1A1B191B1A1A1C1B1B1B1B1A1A1B1B1A1B1C1B1B1A1B1C1C1A
1B1B1B1B1B1B1C1C1B1B1B1C1C1B1C1C1D1B1D1C1C1C1C1D1D1D1C1C1C1C1D1C1C1D1D1C
1C1C1D1C1D1C1B1D1D1C1C1C1C1C1D1C1B1D1C1D1D1E1E1D1E1E1E1D1D1D1E1D1E1D1E1E
1E1F1F1F1E1E1E1F1E1E1F1E201F2020201F1F2020201F1F1F201F1F1F1F1F1F1F1F1F1F
201F20202121202120212020222222212220212221212121222222212221232023212222
222224232324242223222322222324222222232422232325232324242423232323222423
232324222223222323242423222323232324242324242322232423232122222323242222
212223232122212322222222232422222121232223222221212221212121202022212120
211F212220201F2020201F20201F1F2021201F20201F1F1D1F1E1E1E1E201F1E1F1E1E1F
1E1E1F1C1E1E1E1D1E1E1E1D1E1E1D1D1E1D1D1D1D1D1E1C1D1D1D1C1C1D1C1C1C1C1C1C
1D1C1B1C1C1C1B1B1B1B1D1C1B1C1C1B1B1B1A1B1A1C1D1B1C1B1A1A1B1B1B1B1B1C1A1A
1B1B1A1B1B1B191B1B1A1B1B1A1A1A191A191B1A1B1A1B191A1B1B1B1B1B1A1A1B1A191A
1A19191A191B1B1A1C1A1B1A1A1A191A1A1A1A191A1A1A1919191A181A19191A19191918
1A19191919181818
19191A19181A191A1A1A1A1B1B1A1C1C1C1D1F22252D343D474C4D473B2F26231E1C1C1B
1C1C1A1A1C1B1A1A1A1B1A1A191A1A1B1B1B1B1B1B1A1A1B1B1B1B1B1C1A1C1B1B1A1B1B
1A1A1B1C1B1C1D1B1B1C1B1B1C1C1D1B1B1C1C1C1C1C1B1B1C1C1B1C1C1D1D1C1D1B1B1D
1C1D1D1C1D1D1D1C1C1D1B1D1D1D1D1C1D1D1C1D1C1C1D1E1E1E1E1D1E1D1D1C1D1E1E1E
1D1F1E1E1F1E1F1F1E1E1D1D1E1F1E201F1F1F20211E2121201F1F1F1F20201E1E20201F
2020201F20221F2120212021202021202123222221212222222221222222222222232222
222323222122212123232322222423232322222322222223232323242324232423232423
232323232222222423242123232221232322232223222322242322222323232322242222
23232323232222212222222222212322212220222121212021222121221F2020201F1F20
212020211F2021202020201F201F1E1F1F201F1E1F1E1F1E1F1E1F1F1F1F1E1F1E1E1F1F
1D1E1E1F1D1E1D1E1D1D1E1D1E1C1E1D1D1D1E1D1B1D1C1D1D1E1C1D1C1C1B1C1D1B1D1B
1A1B1B1C1C1C1C1C1C1C1D1C1B1B1C191C1B1B1B1C1B1B1B1B1B1C1B1A1A1B1B1A1A191C
1A1A1B1A1B1B1B1A1A1A191A1A1A1B1B181B1A19191A1A1A1A1A191A1A1A1A1A1A19191B
19191918191A1A1A1B1B191B1A1A1A1919191919191A191A1A1A1918191919191A181818
19191A19181A1919
1A191A1919191A1B1A1A1B1A1B1C1B1B1C1F22252C3240515F67665B473829231F1E1D1C
1B1A1B1B191B1B1B1A191B1A1A191A1A1C1A1B1B1A1A1B1B1A1B1C1B1B1A1A1B1B1B1B1B
1B1B1C1C1B1B1A1C1B1B1C1C1B1B1D1C1C1C1C1A1C1D1C1C1C1D1C1C1D1C1C1C1B1C1B1B
1C1C1C1D1D1C1E1D1D1D1D1C1D1D1D1E1D1D1D1E1D1C1F1E1C1D1E1D1F1F1E1D1D1D1D1D
1D1D1D1E1E1F1F1E1F1F1F1F211F1F1F1F2021201F201F201F1F201F201F201F1F212020
202121202020212021211F1F202021202120212222202222212122212122232222212123
232223222421222122212222222321242322232424232223232323232223242322232323
232323222423222222212322242321222323232123232222232223222222232123232121
222222222222222123232123222121222222222121222122212022202120202122202121
222120201F2221212120201F201F1F1F1E1F201F1F1E1F1E1F1F1E1F1F1E1E1F1E1E1E1E
1D1E1E1E1E1F1E1F1F1E1D1D1C1E1E1E1D1D1D1C1D1C1C1D1C1D1C1B1C1C1E1C1C1C1C1B
1C1D1D1B1C1B1C1C1B1C1C1C1B1C1B1B1B1C1B1A1C1A1B1B191C1B1B1A1B1B1A1B191B1A
191A1A1B1B1B1A1C1B1B1A1A191B1A1A1A1A1B1A1C1A1A1A1B191A1A191A1A1A19181A1A
191A1A191B191B1C1A1B1A1A19181A1A1A191A191B1A1B191B18191A1A19191919181818
191A1818191A1919
1A19191A1B1B1A1A1A1A1A1A1B1C1B1D1D202328324154657A817E6D543E2D23201C1C1B
1B1B1C1B1B1A1C1A1A1A1B1B1B1A1A1B1B191C1B1B1A1B1B1B1B1B1B1B1B1C1B1C1B1B1B
1B1B1B1B1B1B1B1C1C1B1C1B1B1C1A1B1B1C1C1A1A1B1E1C1D1D1D1D1D1D1D1D1C1D1D1C
1C1E1D1D1D1E1D1D1C1C1D1D1C1C1D1D1C1D1C1D1D1D1D1E1D1E1D1D1D1E1D1E1D1E1E1D
1D1E1D1F1E1E1F201E1D1F1E1E1F1F1F1F1E201E1F1F1E211E1F1F201F20202022201F20
1F2121212220222021212020212020212021212120222022212221222222212122222122
232223222322232222232221222221212223232322232323232223222323232223222222
222222232322222323222122222223232221222223232224232321222222232322212321
2221212222212222212221222221212221222222202120212221212020202121201F2020
1F1F2021202120201E1F201F1F1F20201F1F1F1E1F1F1F1F1E1E1E1E1E201F1F1F1E1E1E
1E1E1E1E1D1E1D1F1D1D1E1D1C1D1C1C1C1C1C1D1E1C1C1C1C1C1C1D1D1C1D1C1C1B1D1D
1D1C1C1C1C1B1A1C1B1A1B1C1B1B1D1C1B1B1C1A1B1B1B1B1A1B1A1A1B1B1A1B1B1A1C1A
1A1B1B1B1B1B1C1A1A1C191A1B1A1A191A1A1A19191A1B191B1A18191A1A191A19191A19
1A1B19191A1A1B1A191919191A19191A19191A1A1A1A1B1C191A1A1A1919191919181918
191A1A1A1919191A
1A19191A191A1A1A1A1A191A1A1A1C1C1D20252C394A647E969B9174573C2C24201D1B1B
1B1B1A1B1C1B1A1B1B1C1B1B1B1A1A1A1B1C1B1A1B1A1C1A1A1A1B1B1B1B1B1B1C1B1B1A
1B1B1C1B1C1B1B1B1C1C1C1B1B1C1C1D1B1D1D1B1C1D1D1B1B1C1D1C1C1B1B1B1C1C1E1C
1B1C1D1D1C1C1C1B1C1C1C1C1C1D1D1D1E1D1D1C1D1E1E1D1E1E1D1F1E1E1E1E1D1F1D1E
1E1E1D1F1E1F1D1E1E1E1F1E1E1F1F1F1F1E1F1E1F1F2020201F20201F20201F1F201F1F
2121212121212122201F2120202121212122222021212120212122212221212121222321
222322212322222323222323222222222322232222222322242222222323232222212023
232222212423222322232222222221242222232222222321232222232222232323222223
2221212021202222212221222221212123212121202221202020221F1F20212121202120
2021201F21201F20201F201F1F1F1F1F1F1F1F1F1E1F201E1F1E1F1F1F1E1F1E1F1D1D1E
1E1E1E1E1D1E1E1E1E1E1D1D1D1D1D1D1D1D1E1C1F1D1E1E1D1C1D1C1C1C1C1C1D1C1C1C
1B1C1C1C1C1C1B1C1B1C1B1C1B1C1A1C1B1B1B1B1B1B1C1C1A1C1B1B1A1A1A1B1A1B1B1B
1B1B1B1A1A1A191A191A1C1A1B1A1B1A1A1A1A1A1A1B1A1B1A1A1B1A1A1A191A1A191A19
181A191B1A1A1A1A1B1B191A1A18191A1919191A1A191B1A191A191A1A1A1A191A191918
19191A191818181A
1A1A1A1A1A1A1A1A1A1B1A1A1B1C1C1D1E21262E3D526E91AAAE93714F372A221E1D1C1B
1B1A1A1A1B1B1A1B1A1A1A1A1A1B1A1A1C1A1B1B1B1B1A1B1A1B1B1A1A1B1C1B1B1B1B1B
1B1B1B1B1B1B1B1C1B1B1C1A1B1D1C1D1B1C1C1C1B1B1C1D1C1B1C1C1C1C1D1C1D1C1C1D
1D1C1E1E1D1C1C1D1D1B1C1C1C1E1D1D1D1E1D1D1F1D1E1D1E1D1E1D1E1D1E1E1E1E1D1F
1E1D1F1E1F1E1E1F1E1F1F1E1F1F1F1E1F1F1F1E1E1F1F1E1F1F1F201E1F1F201F212021
212022252322202020211F202120212021211F2121202221212021222223222221232122
212122232322222221222322222122222222222322242222232321222221222322222223
232122232022232223232221222320232122232122202123222222222121202123212321
21222322212223212321222122222220212121202120212120202120202121201F202021
201F1F22201E1F20201F201F201E1F201F1E1F1F1F1E1E1E1E1E1E1F1E1F1E1E1E1D1D1D
1D1D1E1D1E1F1E1D1D1E1D1B1D1E1C1E1C1C1E1D1F1D1D1C1D1D1B1D1D1B1C1C1D1B1C1C
1C1C1C1C1B1C1C1D1B1C1C1B1C1B1A1C1B1C1B1C1C1A1A1A1B1B1B1A1C1C1A1C1B1A1B1B
1A1A1C1B1B1A1B1B1B1B1B1A191A191A1A1A19191A1B191B1A1B1B19181918191B1B191B
19191A1A1A1A1A1A19191B1A1919191A1A1A191A19191B1A1A1A1A1A1A191B191A1A181A
1A19181918181919
1A1A191A19191A191A1A1A1B1B1D1D1C1E22262F40557595ABA38961443126221E1C1B1C
1B1B1A1B1A1B1A1B1B191A1A1A1A1A1B1B1B1B1A1B1B1A1A1A1B1B1B1A1D1B1A1A1B1B1B
1A1B1B1B1B1B1A1B1A1B1C1B1B1B1A1C1B1C1B1B1B1B1B1B1C1D1B1C1C1C1D1C1A1C1D1D
1C1D1B1C1C1D1C1C1B1C1D1D1C1E1C1D1D1C1D1C1D1E1D1E1E1E1E1E1D1B1D1E1E1E1E1D
1E1F1E1F1E1F1E1E1D1E1E1E1F1F1F1F1F1E201F1F1F201E1F1E1F1F201F201F1E1F1F20
21212227232020202020212020212020201F2121201F2122212222212020222222212322
232421222321222322212022222122222322222222232123222221212222222322212222
212122232321232222222221222222202123222222222122212122222221222223222222
2122212121222122221F212121212121212123212120202122212021211F20201F212020
1F1F20212020201F1F201F1F1F21201F1F1F1E1D1E1F1E1E201E1F1F1F1E1D1F1D1E1E1E
1E1D1C1E1E1E1D1D1D1E1E1D1E1D1D1D1D1D1E1E1D1D1D1D1C1C1B1B1D1C1D1C1C1C1D1C
1D1D1B1C1C1B1C1C1C1C1B1C1A1C1B1C1B1B1A1B1B1A1B1B1B1A1B1A191B1B1B1B1A1B19
1A1B1A1B1A1A1B1B1B1B1B1A1A1A1B1A1A1A191A191A191A1A1A1A1A1A191A191B1A1A19
1A1B1A1A1A1A1A1A1B19191A191A1919191A1A1B1A1A191B1A19181A191919191918181A
1A181A19181A1918
1A191A19191A1A1B1B1A1A1C1B1C1D1E1F23272F3F546D8B948A6F50392A241E1F1E1B1B
1A1A1C1B1B1A1B1B1B1B1A1A1A1A1A1B1B1A1A1B1B1A1B1B1A1A191B1B1A1C1A1B1B1C1A
1A1B1B1B1B1B1B1C1C1A1B1B1C1C1B1B1C1C1B1B1C1C1C1B1B1C1C1C1D1D1D1C1C1D1C1C
1C1C1C1B1E1C1C1C1D1D1C1D1B1D1D1B1D1E1D1C1D1D1C1E1D1E1D1E1E1D1D1E1D1E1E1E
1E1F1E1F1D1F1E1E1F1F1F1F1E1E211F1F1F1E1F1E1E1F1F1F1F1F1F201F1F1F1D1F2020
20212122222120211F201F22202021202121202121221F22202121202021212221222023
212221212221212121202222212222242123222122212122212121232323232322222021
212221222121212222212222222223222222212322222123222222212221212222212222
212121212121212122212121202120202221202020212121222020212020202221211E20
212121201F1F201F1F1F1F1F1E1F1E201F1E1F1E201E1F1F1E1E1E1F1F1D1F1E1E1D1F1D
1E1E1D1D1E1F1E1D1D1E1D1E1D1D1D1C1D1E1E1D1D1C1C1C1C1C1D1C1C1C1C1D1C1D1E1E
1C1C1C1B1C1C1B1C1B1B1B1C1A1C1B1C1B1A1B1B1A1B1B1C1B1B1B1B1C1A1A1C1B1A1B1A
1A1B1B1B191A1A1B1A1C1B1A1B1B181A191B1A1A1A1A1A1A1A1B1A1B1B1A1B1A1A1A1B19
191918191A1A1A1A191A1A181A1A1819191A1A1A191A191A191A1A181919181A191A1919
1A181A1819191819
1A191B1A1919191B1B1B1B1C1B1B1C1D1F21272E3E4C60707568543F2F2723201D1C1C1C
1B1A1B1B1C1B1B1B1B1A1B1B1C1A1B1A1A1A1B1A1B1B1B1C1A1A1B1A1C1C1A1B1B1B1B1B
1A1B1B1A1B1B1B1C1B1A1B1C1B1C1B1C1B1C1D1C1B1D1B1C1D1D1C1D1B1D1C1D1C1D1D1C
1D1D1C1D1C1C1D1D1D1C1E1B1C1C1B1C1C1D1C1D1D1C1C1D1D1E1D1D1D1D1C1E1E1D1E1E
1E1D1E1D1E1E1E1E1E1E1E1F1F1D1F1F1F1E1E1F201E1E1F1F1F1F1F201F201F1F1F1E20
202120202120201F201F2021202020212122202121212120202121222123212221212321
232221212221212122212122222321222223212223212122222122212222232222222122
202223212222212321222223212322222323222122232321212120222121222122222221
222220212220212020202122212121202221202120212121202120212021201F1F1F1E1F
1E222020201F1F1F201F1F201E1F1F201D1F1E1E1E1F1D1E1E1E1F1D1E1F1E1E1D1C1E1E
1E1E1D1E1E1D1F1D1D1D1C1E1E1E1D1D1C1E1C1D1E1F1D1D1D1D1C1C1C1C1C1C1D1C1C1B
1C1C1E1C1C1A1B1B1B1B1A1C1B1C1A1C1B1B1A1A1B1A1B1B1B1B1A1A1A1A1A1A1B1A1A1B
1C1A191C1A1A1A191A1B1B1A191B191A191A1A1A1A1B191A1A1C1A1A1B1A1A1A1A1A1A19
1B191A1B1A191A1A1A191A1A191A18191A19181B191B1B191A1A191919191A19191B1819
19181A191A191919
1918191919191B1A1B1A1B1B1A1B1B1C1D20242C36434C55574C3E322822201E1D1C1C1A
1A1B1B1B1A1A1B1B1B1B1A1B1A1A1B1A1B1A1A1A1C1A1A1A1A1B1A1B1C1B191B1B1B1C1B
1B1B1B1B1B1A1B1B1A1B1B1B1B1B1C1B1C1C1B1B1D1B1B1B1C1B1C1B1C1D1D1C1E1E1C1C
1C1C1C1C1C1B1C1C1D1C1C1B1D1D1D1C1D1D1E1D1E1E1D1F1D1C1D1D1E1D1D1D1D1D1D1D
1D1E1D1D1E1E1E1E1E1E1D1F1D1F1D1E1E1E1F1E1F1F1D1F1E1E201F1E1E1F1E201F1F1F
2020201E201F1F1F1F1F201F211F20202021212121212220222122212122212022222222
232121222222212221202121232122212222212221222221212122222222222221202223
222022212222222222232122222022232222212221222121222222212122212122212222
202121202121212221212221202021221F2120212120201F20201F2120202121201F201F
201E201F1F201F1E1F20202020201D1F1F201F1E1D1F1E1E1E1F1E1D201D1E1E1F1F1F1F
1D1D1E1E1D1E1E1D1D1C1E1D1E1E1D1D1C1C1D1D1D1D1C1D1D1C1D1D1D1B1D1B1D1D1D1B
1B1C1C1C1C1D1C1C1B1B1B1B1C1B1B1A1C1B1C1B1B1A1B1B1B1B1B1A1B1B1A1B1B1B1B19
1B191A1A1B1A1B1A1B191A1A191A1A1B1A1A1A1A1A1B1A191B1A1A1A1A1A19191B191A18
1919191A191A19191A1A19191A181A1A1A1A1A191A1B1919191A19191819191A191A1919
19191B1A19191918
1A1A1A191919191B1A191A1A1A1B1B1D1E1F23292E363C3E3E39322923201F1D1C1B1D1A
1B1A1B1B1B1A1B1A191A1A1A191B1A1B1B191B1B1A1A1A1C1A1B1A191A191B1B1A1B1B1A
1A1A1B1A1C1B1C1D1A1A1A1B1B1B1C1C1C1B1C1B1B1C1C1B1C1C1B1B1D1E1C1D1F2A1D1D
1B1C1C1C1C1D1D1C1C1D1C1D1C1C1D1C1C1C1E1C1D1C1D1E1D1E1D1E1E1D1D1D1D1C1E1D
1C1E1D1E1E1F1E1E1E1D1F1F1E1E1E1F1F1E1E1F1E1F1E1F1E1E1F1F1F201F1E1F201F20
20201F20201F1F1F1F1F20202020202021202121212120221F2220212222212221202122
202120222220212221212221222122222222222121202122222220212122212122222122
212121222122222221222322222122232321222121222121202221212222211F21222122
21212122212021212021202221211F2121201F20202120201F1E2021212020201F20201E
20211F201F1E20201F1E1F1E1F1E1E201E1E1F1E1F1E1E1E1F1D1E1E1E1D1F1E1E1E1E1E
1E1E1E1E1D1D1D1C1D1E1E1B1C1D1D1D1C1C1C1D1D1D1B1C1D1C1C1C1C1C1C1C1C1C1C1D
1D1B1B1A1C1C1C1B1C1C1B1B1C1B1C1B1C1A1C1A1B1A1B1B1B1B1B1A1B1A1A1B1A1B1A1B
1B1B1A1B1B1A1A1B1A1A1A1B1A191B1B1B1B1A1A1B1B191B1A1A1A19191A1B191B1A191A
19191A1A191A1A1A1A1A1A1A1B1A1A1B1A191919191A1A1A1A1A191B1A19191919191A19
1A19181918191819
1A191A1A1A1B1A191A1A1A1B1B1B1B1C1D1E2123292D2F302E2B2823211F1D1C1C1C1A1B
1A191A1A1A1B1B1A1A1A1A1C1A1A1A1A1A1B1B1B1A1A1A1B191A1B1B1A1B1B1B1B1B1B1B
1C1B1B1B1C1B1B1A1C1B1B1C1C1B1B1A1D1A1C1C1C1B1C1C1C1B1C1C1C1D1D1C1E1C1C1C
1D1D1C1D1C1C1B1C1C1C1C1C1C1B1C1D1D1D1D1D1D1E1D1D1C1E1D1C1D1D1D1E1F1E1E1E
1D1E1E1E1E1F1E1D1F1D1F1F1E1D1E1F1F201F1E1E1E1F1E1F1E1E1E1F1E1F1F1F1F2120
201F1F201F1F201F20201F1F1F2020202120202120202020202021202122212221222222
2020212121212123212221221F2021222221212122222122232221212021212221212120
222122222222212223212221232220212320212321212121212120212221212022212222
21232121202020232122212120202020212020202021221F1F20201F20201F201F1F1F20
201F201F2120201F1E201F1E1F1E1E1F1F1F1F1E1D1E1D1F1D1E1F1D1E1F1F1E1F1D1F1E
1D1D1D1E1D1D1E1E1D1C1D1E1D1D1D1E1D1C1D1D1C1C1C1D1D1C1C1C1D1C1C1D1B1C1D1C
1B1B1C1C1C1B1C1B1B1C1B1C1B1C1B1B1A1B1A1A1A1B1A1B1B1B1A1A1B1B1A1A1A1A1A1A
1B191A1A1A1A191B1B1A1B191B191A1A1A1A1919191A1A1A1A191B191B1A1A19191A1A1B
1A1A1A1A191A1B1A191A191A181A1919191A191A19191A1A1B191A191A19191A1919191A
191A1918191A1919
1A1A19191A1B1A1A1A191A191B1A1A1B1D1E1F212325262725232220201D1C1D1C1B1A1B
1A1B1B1A1B1B191A1A1A191B1A1A1B1A1A1A1A1A1B1B1A1B1B1B1A1B1C181A1B1B1A1B1A
1B1A1B1A1B1B1C1A1B1B1B1B1B1C1B1D1C1B1B1C1D1C1A1B1A1C1C1C1C1D1D1E1D1C1D1D
1D1C1C1D1C1B1B1D1E1D1C1C1D1C1B1D1D1C1E1D1D1D1D1D1D1D1D1D1E1E1E1E1C1D1D1F
1E1F1F1E1D1F1E1E1E1E1E1E1D1F1E201F1E1F1E1E1E1F1E1F201F1E1E1F1E1F1F201E1F
20201F1E201F201F1E1F1F211E1F1F1F21201E202121211F21201F212021212121212021
212321222121212222212222212120232221222021212121212221212221212221202121
212122212120212221222220212221212122202321212122232221212221212121212021
22212020212121211F2120212120202120202120212021201E21201F20201F1F1F201F20
202120201E1F1F1F1F1F1F1E1F1E1E1E1F1F1F1E1D1E1E1D1E1E1E1E1D1E1D1D1E1D1E1E
1D1D1E1D1B1C1D1C1E1D1D1F1D1D1D1D1B1D1C1C1E1C1C1D1C1C1C1C1C1C1A1B1B1C1B1C
1C1C1B1B1B1B1C1C1B1B1C1C1D1C1D1B1B1B1B1A191D1A1B1B1B1A1B1B1B1A1B1B1C1B19
1A1B1C1B1A1B1B1A1A1B191B1A1B191A1B1A1A191B1A191B19191A191A1A191A191A1B1A
191A191A191A19191A1A1A1A191A19191A191B1A1A1A191A1A19191A1A19191818181919
19191A191A19171A
181A1A1A1A191A1B191A1A1A1B1A1B1B1B1C1C1F1F202021211F201E1E1C1C1B1C1A1A1B
1B1A1A1B1B1A1B1A1B1A1A1A1B191A1A1B1A1C1A1A191A1A191B1B1A191B1B1A1B1C1A1A
1A1C1B1B1A1C1B1B1A1C1C1A1A1C1B1C1C1B1C1B1B1B1B1C1C1C1C1C1C1C1D1C1D1C1D1D
1D1D1D1B1C1C1C1D1C1D1C1D1C1C1D1E1E1D1D1E1D1C1D1D1E1E1D1D1D1E1E1E1D1E1E1D
1D1E1E1D1D1E1D1D1D1E1F1E1D1E1E1F1F1E1E1F1F1F1F1F1F1F1F1F1E201F1F1F1E1F1F
1F1F201F1F1F1F1E1F20201F201F20212020201E1F1F2020202020212220202120212120
20212122212221222120222122222120212121222021212321222021222122211F222121
222022222021212322222122212121212121212121222122222320212122222122202021
2121221E2120202120201F2021202020202120211F202020201F20201F201F1F1F21211F
1E1F201F1F1E1D1F1F1F1F1E1F1D1F1E1E1E1E1F1F1F1E1D1E1E1E1E1F1E1E1E1E1D1E1E
1E1C1D1C1D1E1D1D1C1D1E1C1D1D1D1C1D1C1B1C1C1C1D1C1C1C1C1D1C1D1C1C1C1B1B1C
1C1B1B1B1C1B1C1D1B1B1B1B1B1D1B1C1D1B1B1B1A1B1B1C1B1C1B1A1B1B1B1A1A1B1B1B
1B1B1A1B1B1B1B1B1B1B1B1A1A191B1A1B191A1A1A19191A1B191B1A191918181A1A1919
19191A1A191A1A191A191A1A191A1A19181A191B1A1B1B191A1A1A18191A1A1A19191A1A
191A1A1A1A191A19
181A191A1B191A1B1A1A1A1B1A1A1B1B1A1A1D1C1D1E1D1D1F1C1E1C1C1B1C1A1B1A1B1C
1B1A1A1B1B1A1B1B1A1A1A1B1C1A1B1A1A1A1A1B1A1B1A1A1A1B1B1A1A1B1A191A1B1B1A
1B1B1A1B1B1C1B1A1D1B1B1A1B1C1A1B1C1C1C1C1B1B1A1C1C1D1C1C1B1A1C1C1C1B1C1C
1C1D1C1B1C1D1C1C1B1C1C1D1D1B1D1D1D1D1D1D1C1D1D1D1D1D1D1D1D1D1D1D1D1D1D1C
1E1E1D1D1D1C1E1D1D1E1F1D1F1D1E1D1F1E1F1F1F1D1E1E201F1F1E1F1E201F1F1F1F1F
1E1F212020201F201E201E211F1F201F2020211F201F2121202120212120202021202221
202120212122212120202220202120222222222121202122202221202021222121222021
22202122212121212120212120222122212121232022212122212021212023201F222221
222121202020202120202021201F2021202020202020201F1F201F201F2020211F20201F
1F201F1E1F201F1E1E1F1F1F1F1E1F1E1F1D1F1F1E1E1E1E1E1E1E1E1F1D1E1C1E1D1E1E
1E1D1E1D1E1D1D1D1D1E1D1D1C1D1D1C1D1D1C1D1B1C1C1D1E1B1B1C1C1C1C1D1C1C1C1B
1C1C1B1B1C1B1B1B1B1A1C1C1B1C1C1B1B1D1B1B1B1A1B1B1B1B1B191B1B1C1B1B1B1C1A
1A1B1B1B1B1C1B191B1C1A1A1A1A1A19191A1A1A1A19191A191A19191B1A19191A1B1919
191A1A1A191A191A191A1B191A1A1A1A1A1B191A1B1A19191A191A19181A181819181A19
191A191A19191819
19191A19191A1A1A1A1A191A1A1A1A1A1C1A1B1C1B1C1D1D1B1C1D1C1B1B1A1B191A1A1A
1B1B1A1A191B1B1B1B1A1A1B1A191A1A1A1A1A1B1A1B1A1A1A1A1B1C1B1A1B1B1B1A1B1B
1B1A1A1B1B1B1B1B1B1C1A1B1B1C1C1C1B1D1C1C1B1C1B1C1C1C1C1B1C1D1D1B1B1C1C1C
1C1C1D1E1C1C1D1C1C1C1C1C1D1D1C1E1D1D1C1C1D1E1E1D1D1D1D1D1D1C1D1C1E1D1D1D
1F1E1F1E1E1F1D1D1F1D1F1D1F1E1D1F1F1E1D1F1F1E1F1E1E1E1F1F1F1F1F1F1F1F1E1F
1F1F201E1E1F201F201E1F1F2020201E212120201F2120202020222120202022211F201F
20202020202021212122212121232120221F212120202121212020212020202120212122
212221202022202020222221212121212120212222222121212220212122212121212220
21212120211F1F21202121211F2022201F1F202021211E201F201E1F201F1F1F1E1E1F1F
1F201F1F1F201F1E1F1F1F1E1E201E1E1E1F1D1E1D1E1E1E1E1E1E1E1D1D1D1D1E1E1D1E
1D1D1D1D1D1E1D1D1C1D1E1C1D1D1D1C1C1D1C1B1D1D1D1D1C1C1D1C1C1C1B1D1D1B1A1B
1C1C1B1B1C1B1B1B1A1B1B1C1B1B1C1D1C1A1B1B1C1A1A1A1B1B1B1B1A1B1A1A1A1A1A1A
1B1B1A1A1B1B1A1A1A1A1B1A1A1A191A1B1A1B1A1B1A1A1B1A1A1A1B191A19191B1A191A
1A191A1A1A1A19191A1A1A191A1919191A1A1A1A19191A19191A19191A191A181A1A1819
1918181919191919
191A191A1A1A1A1A1A1A1B1B1B1B1A1C1B1B1B1B1B1B1C1C1B1A1B1C1C1D191B1A1A1B1A
1A1B1B1B1B1A1B1B1B1B1A1B1A1B1A1B1B1A1A191A1A1A1A191A1B1A1A1B191B1B1A1B1B
1C1A1A1A1C1B1B1C1C1B1A1B1D1C1C1B1A1B1C1C1B1A1C1C1C1B1C1A1C1D1B1B1C1C1B1C
1C1A1C1C1C1C1C1C1C1B1C1C1D1C1C1D1C1D1D1D1D1D1D1D1E1D1D1D1C1D1C1C1D1C1D1D
1D1D1C1E1D1D1E1D1D1E1D1D1E1F1F1D1F1D1F1E1E201F1D1F201F1E1F1F1F1F1E1F1E1F
1F20201E20201F1F1E1E1F1F20201F20202020202020201F20211F212020202021212120
2021212121212122202020212121201F2120201F21212121202122222220202020202120
201F222021212022212120202121222020222021202022211F202121222120212121211F
20202020202020201F20212020212020201E20201E201E21201F1F201F1F1F1F201F1F1F
1F1F1E1E1F1F1E1F1F1E1D1E1E1E1F1E1F1E1E1E1E1D1E1E1E1D1F1C1D201F1E1C1E1E1E
1E1D1E1E1C1C1D1D1D1C1D1E1D1C1C1C1D1D1B1C1D1B1C1C1D1B1C1D1D1B1B1C1C1C1C1C
1B1B1C1A1B1C1B1B1D1A1C1B1A1B1C1B1B1A1B1B1A1B1B1B1B1B1B1A1B191B1A1B1B1B1A
1B1A1B1A1A1A1A1A1A1A1B191A1A1B191A1A1A1A1B191A1919191A1A1A1A191A1A191A1A
1B19191919191A191919191A191A1A1A191B1A1A19191919191A191A1A1A18191A1A1919
1919191919191919
1A1A191A1A19191B19191A1A1B1B1A1A1B1B1B1B1B1A1C1B1A1A1B1B1A1A1B1A1B1A1919
1B19191B191A1A191B1B1A1A1A191B19191B1A1B1B191A1A1A1C1B1B191B1B1A191B1B1A
1A1A1A1A1A1A1B1B1B1B1C1A1B1B1B1C1C1B1B1B1A1B1C1C1B1D1B1C1C1B1B1B1B1D1C1B
1B1B1D1B1D1B1C1C1C1C1D1C1C1D1C1D1D1D1C1C1D1C1D1D1C1E1D1D1E1D1D1C1D1D1C1E
1E1D1D1C1D1D1D1D1D1E1D1D1D1E1E1D1E1E1E1F1E1E1E1E1F201F1F1F1F1F1F201F1F20
1E211F1F1F1E1F20201F1F1E1F201E2020211F1F20202120211F202020201F2020202020
20212121212020212222202021202121212121212020211F212020202021212022212120
202121222120212121212121222121212121212121212123222120202121202020212122
2120201F1F20202021212020201F1F2021212020211F1F1F201F1F1F1F1F1E1D1F1F1D1F
1F1F20201F1F1F1E1E1E1D1F1E1F1F1F1E1E1E1E1D1D1E1E1D1E1E1E1D1D1D1D1D1D1E1E
1D1C1E1D1D1C1C1C1D1D1C1C1D1D1D1D1C1C1B1C1B1C1C1D1C1C1D1D1C1C1C1C1C1B1C1B
1B1B1B1B1C1A1B1B1B1C1C1B1C1B191A1B1B1B1B1A1B1A1A1C1A1A1B1B1B1A1B1B1A1B1B
1B1A1B1B1B1B191B1B1B1A1B1A1A1B1B1919191A1B1A19191A1A191A1A1A1A1A1B19191B
191B1A191A19191919191A1A191A1A19191A1A1A1A1B1A181B1A1A1A191A191A19191A1A
191A181919191919
1A191919191A191B191B1A1B1B1A1A1C1C1A1B1B1B1B1A1A1A1B1A1B1A1A1C1A1A1B1A1A
1B191B1A1A1A1C1A1B191A191B1B1A1A1A1A1A1A191A1B1A1B1A1B1B1B1A1B1A191A1B1B
1B1A1A1A1B1A1B1A1A1B1C191A1C1B1C1B1B1C1B1B1C1B1C1B1A1C1B1B1B1B1D1C1C1C1C
1B1B1C1C1C1C1C1C1E1C1C1C1C1D1C1C1D1C1D1D1C1D1C1B1D1E1C1F1D1D1D1C1D1D1C1C
1C1D1D1D1D1D1E1D1D1F1D1F1E1E1E1E1E1E1E1E1E1E1E1F201F201F201F1F201D1E1F20
1F1F1E1F201F1E201E1F201F1F1F20201F20201F2021202020201F1F2020202020201F22
211F21202120212121222120202221232021212122201F201F20212020201F2120211F21
212021202121202120212121202020212121222122212121202020212020202021202021
2022202020202020202120202120201F211F1F20201F201F1F20201E1E1F1E202020201F
1F1F201F1F1E1F1E1F1F1E1E1F1E1E1F1D1E1C1E1D1D1D1D1D1E1D1D1E1D1E1E1E1D1D1E
1E1E1C1D1D1C1D1D1D1C1D1E1C1D1E1C1C1D1C1C1C1C1C1D1C1C1E1C1C1B1C1C1C1C1C1C
1C1A1C1C1B1C1B1B1B1A1B1C1C1B191A1C1B1B1C1C1A1B1B1B1B1B1B191A1A1A1D1A1A1A
1B1A1A1B1B1A1A1B1A1B1B1A1A1A1A1A1A1B191B1A1A191B1B19191A1A19191A191A1A1A
1A1A1A1B1B1A1A19191A1A1A191A19191A1A191B19191A1919191A1A1A181918191A1918
1A1A1A191819191A
191819191A1B1A1B1A1A1B1A1A1B1A1A1A1A191A1A1B1C1A1B1B1B1A1A1B1B1A1A1B1A1A
1A1A1B1A191B1A1A1A1A1A1B1B1B1A191A1B1A1A1A1B1A1A1B1A1B1A1A1C1B1A1B1A1A1B
1B1B1B1B1B1B1A1C1A191B1B1B1C1C1C1A1A1C1C1C1B1B1B1B1C1B1B1C1B1B1B1B1C1B1C
1C1C1C1B1B1D1B1C1C1D1B1D1D1C1C1D1D1D1D1B1C1D1C1C1C1D1C1C1D1D1E1E1D1D1E1D
1D1C1E1D1D1C1E1E1E1E1D1E1D1D1E1F1E1E1E1E1E1E1E1F1F201F1E1F1E1E1F1F1E1F1E
1E1F1F1D1F1E1E1F20201F1F1F201F2021201F211F21201F1F1F202020201F2120202021
202021212021211F20212121222121212120202021202221212020212120212121212021
21222221212020202221212122212120201F21212023212120222020201F212020201F20
201F20201F1F1F2020201E21201F1F202020201F1F201E211F1F1F1F1F1E201F1F1F1F1E
1F201E201D1F1F1F1F1E1F1E1E1F1E1F1F1E1F1F1E1E1D1E1D1E1E1D1E1D1C1D1C1D1D1E
1C1D1D1D1C1D1C1E1D1E1D1E1B1C1C1D1C1B1C1C1C1D1C1C1C1D1B1B1C1B1C1B1B1A1C1C
1B1C1B1B1C1C1C1B1C1A1B1A1B1B1C1C1A1B1B1B1A1B1B1A1C1B1B1C1B191B1A1A1A191B
1A1A1B1A1A1B1B1A1A1C19191A1A1A19191B1A191A191A1A1A19191A1B1A1A1C1B1A191A
1A1A19191A1A181A1A191A1A1A191A1A1A1A181A1C1A1A191919181A1A1A191919191919
1A1919191A181819
191A1919191A1A191B1B1A19191A1B1A1A1A1B1B1A1B1A1A1A1B1A1A1A1A191B1A191A19
1A1B1A1A1B1A1A1B1A1A1A1A1B1B1B191B181A1A1B1A1B1B1B1A1A1B191B1C1B1B1B1A1A
1B1A1A1D1B1B1B1C1A1B1C1B1D1B1A1B1B1C1B1B1C1C1B1B1D1D1B1B1C1A1B1C1C1B1D1C
1C1C1C1B1B1C1C1C1C1B1C1C1B1C1C1E1C1D1C1D1C1C1D1C1D1B1E1D1E1D1C1D1C1D1E1D
1C1E1E1D1D1E1D1D1D1E1D1D1E1D1E1E1E1D1E1F1F1E1E1F1F1F1F1F1E1E201E1E201E1D
1E1F1E1F1F1F1E201F1E1E1F201E1E201F201F1E2020201F201F20201F20202121201F21
20212020202020212120211F1F1F202021202021201F20201F2120202120202122201F1E
201F211F2021202020202121202121202020212121212121202021211F21202020202021
1F1F201F1F21212120211F1F201F2020202120201F1F1E1F1F1E1F1F1E1E21201E1E1E1E
1E1D1E1F201E1E1E1D1E1F1E1E1F1E1D1D1D1E1F1E1D1E1E1E1E1D1D1E1E1E1D1E1D1E1E
1D1D1E1D1D1D1D1E1C1D1C1D1D1D1C1C1D1C1C1C1C1C1B1B1C1B1D1C1B1D1C1B1B1B1B1C
1C191B1A1B1C1A1B1C1C1B1B1B1C1B1A1A1B1D1C1B1B1B1A1A1B1A1A1B1B1B1B1C1A1A1B
1A191A1A1B1B1A1A1A1B1B1A1A1B1A1A1A191A1A1A1A1A191B191A1A1A191A1A1A191B19
19191B191A1A1A1A1A1A1A1A1A1A1A1B1A19191A1A191A1919191A1A1A181919191A1A1A
19191A1918191818
1A1918191A1A1A1A1A1918191A1A1A1A1B191A1A1A1A1A1B191A1B1A1B1A1A191A1A1A19
1A191B1A191A1A1A1B1B1B1B1B1A1A1B1A191B1A1B1A1A1B1B1A1A1B1B1B1B1B1A1A1B1C
1A1C1A1B1B1C1B1C1A1B1B1A1C1B1B1B1B1B1B1C1B1C1B1C1B1C1B1B1C1C1C1C1B1B1B1C
1C1C1C1A1B1B1C1D1C1C1C1D1B1B1C1D1C1D1C1B1C1C1C1D1C1D1C1C1C1D1D1C1D1D1D1D
1D1B1D1D1E1D1D1D1D1E1D1D1D1E1D1D1F1E1E1D1E1E1D1C1E1F1F1E1E1E1F1F1E1E1F1F
1E1E1E1E1E1F1F1F1F1E1E1F1E1F1F1D201F1F201F201F1F1E202020201F202020201F20
202120202020212020201E1F211F20201F21211F202021201F2020201F201F1F20202123
20202021212120202021202120212021202020212121212120211F2021211F1F20202021
1F1F20201F212020201F201F201F201F20201F1F201F201E1F201D1F1F1F1E1E1F1F1E1E
1F1F1F1E1E1E1E1F1F1E1F1E1F1E1E1E1E1E1C1E1D1C1E1D1E1C1C1C1C1C1D1E1D1D1D1D
1C1D1D1E1D1C1C1C1D1D1D1D1C1C1D1D1C1D1C1D1C1C1C1C1C1B1C1D1C1C1C1B1C1C1B1D
1B1C1B1B1C1C1B1D1B1A1A1B1C1C1A1B1C1B1C1B1A1C1B1B1B1B1B1B1B1A1A1B1B1C1B1B
1A191A1A1B191B1B1A1A191A1A1A181A1A1A1A1B1A1919191A1A1A1A1A1A1A191A1A1A1B
19191A1A1A1919191A1B1A1A1A1A191A191A191A191A191919191A1919181A1B1A1A1919
1A19181919191A19
1919191A191A1A1A191B1A1919191A191A1B1A1A1A1A1A1A1A1A1B191B1B1B1B1B1A1A1A
191A1B1A1B1A1A1A1A1B1B1A1A1A1A181A1A1A1B1B1B1A1A1B1C1A1A1A1A1A1A1C1B1C1B
1A1B1C1A1A1C1A1B1A1B1A1A1C1B1B1B1B1B1B1C1C1B1B1B1B1C1B1C1C1B1D1C1C1C1B1C
1B1C1B1C1C1C1C1D1B1C1C1B1C1C1D1E1D1C1A1D1C1D1D1D1D1C1D1D1D1C1D1C1D1E1E1C
1E1D1D1D1C1D1D1D1E1E1D1D1E1F1E1D1E1E1D1F1D1E1E1D1E1F1F1F1F1F1F1E1E1F1E1F
1D1E1F1E1E201E1F1E1F201F1F1E201F1F1F1E201E1F1E20202120211F20201F1F212021
211F2020201F1F20201F202120201F1F2120211F2121202120201F202020201F211F201F
20202020212021211F21202021202220201F1F20201E202021212120201F1F201F201F1F
1F201F1F201E201F202120201F1F202020201F201F201F201E1F1E1F1E1F1E1F1F1E1F1E
1F1E1F201E1C1F1F1E1E1C1D1E1F1F1F1E1E1F1E1D1D1C1E1D1D1E1E1E1D1D1E1C1D1E1D
1D1E1E1E1D1D1D1D1D1D1D1E1D1C1C1D1C1C1C1C1D1D1C1C1C1C1C1C1B1C1C1C1B1C1C1C
1C1C1C1B1C1B1B1C1B1C1B1A1C1A1C1C1B1B1A191B1A1C1C1B1B1A1B1A1B1A1A1B1A191A
1B1A1B1B1A1A1A191B1B1A1A1A1A1B1A1A1B1B1A1A1A1B1A1A1A1A191A1B1A1B1A191B1B
1A1919191A1A1A1A1A191A1A1A1A1A1A1A1B1A1A191B191A1919191A191A1A191A191A19
191A191A19191919
1A191A191A191A1919191A1A191A1A1A1B1A191B1A1A191B1A1B1A1A1A1A191A1A1A1A1B
1A191A1A1A1A1A1B1B1A1A1A1A1A1B1B1A1A191A1A1B191A1B1B1A1B1B1B1B1B1B1B1B1A
1B1A1B1B1B1C1A1B1A1B1B1B1B1A1A1B1B1A1C1B1B1B191B1B1B1B1C1C1B1C1C1C1C1B1C
1C1C1C1C1C1C1B1D1B1B1D1C1D1C1C1C1D1C1B1C1C1D1D1D1C1D1C1C1D1D1D1D1D1C1D1E
1D1D1C1E1D1D1D1D1D1C1D1E1F1D1E1D1D1C1D1E1E1E1F1E1E1F1E1F1D1D1E201F1E1E1E
1E1E1E1E1E1E1F1E1E201E1F1E1F201F1F1F1F1F2020201F1E201F1F1F1F202020202021
20201F211F1F1F2120211F2120202121201F2120211F1F211F201F201F1F201F20202020
20201F1F211F201F2120221F212020211E221F20202121201F1F201F2121211F1F1F1F1F
201F1F1F1F201F1F1F1F1F1E201F1F2020201E1F1F1E1F1E1E201F1F1F1F1F1F1D1F1F1D
1F1E1E1F1F1E1E1E1E1D1E1D1C1F1E1E1E1E1E1D1E1E1E1F1E1D1D1E1E1E1D1D1E1E1D1F
1E1E1D1C1D1B1E1D1E1C1C1D1D1D1E1C1C1C1D1C1C1D1D1B1C1D1C1D1C1B1B1A1C1B1D1B
1C1C1C1B1A1C1B1B1C1C1B1C1B1B1A1B1B1B191C1B1B1A1B1B1A1B1A1B1B1B1B1A1B1A1B
1B1A191B1A1A1A1B1C1A1A1A1A191B191A1C1A1A1C1B1B1A1A1A1A181A1A1B1B1B191819
1A191A18191B1919191A1B19191B1A1A1A1A1A1B1A1A1A1A19191A19191A1A1A1A1A191A
1A181A191818191A
191A191A191B1A1A1A19181A1A1A1A191B1A1B1A1A1A1A1B19191A1C1A1A1A1B1B1A1A1A
1A1B1B1A1A1A191A1B1A1B1B1A1A19191A1A1B1B1B1B1A1A1B1B1B1A1B1B1B1B1A1A1B1A
1A1A1C1B1B1B1C1A1B1A1B1A1B1B1B1B1C1B1C1B1B1C1B1A1B1B1B1B1B1C1B1C1B1D1C1C
1C1B1C1B1B1B1B1C1B1C1C1D1C1C1C1E1C1D1D1D1C1C1D1C1D1B1D1C1D1D1D1E1D1D1D1D
1F1D1D1D1E1D1D1C1D1D1D1D1D1E1E1D1E1E1E1D1E1E1D1D1F1E1E1E1E1E1E1E1E1E1E1F
1E1E1E1F201E1E1F211F1E1E1F1F1F201F201E1F1F1F201F1F1F201E1F201F2120211E1F
1F1F2020202020221E1E201F201F202220201F1F202020201F1F1F1F212020201E1F1F1F
1F1F201D20201F212020202021201F1F1F1F201F1F1F1F1F201F20201F1F1F1F1F1F1F1E
201F20212020201F20201F1F201F1F1F20201F1E202020201F1E201E1D1F1F1E1E1E1F1E
1E1E1E1E1E1E1F1F1D1E1D1F1E1E1D1E1D1E1D1D1D1D1C1F1D1F1E1E1E1D1D1E1E1C1E1E
1D1D1D1D1E1D1D1B1C1C1D1D1D1E1D1E1C1D1D1D1D1D1C1C1C1D1C1B1C1C1B1D1B1B1C1B
1C1B1B1B1A1A1B1B1B1D1C1A1B1A1B1A1B1C1A1C1C1C1C1B1B1B1B1A1B1A1B1B1A191B1B
1A191B1A1B1A1B1B1B1A1A1A191A1A1A1A1A1A1B1B1A1B1B1A1B1A191A191B191A1A1919
191A1A1C1A1A1B1A191A1A191B1A1A1A1B1A191C191919191B19191919191A1A1A191A1A
18191A1A1B191A19
1A191818191A1A191A1B1A1A191A1A191A1B1A191A1A191A1A1A1A1A1B191A1A1A1B1A1A
1A1A1A1A1A1A1B1A1A1B1A1A1A1B1B1A1A1B1A1B1B1A1C1A1A1A1A1A1A1B1B1A1B1B1B1A
1A1A1B1A1B1A1B1B1A1B1B191B1B1A1B1C1B1B1A1B1B1B1C1D1D1C1C1B1B1C1C1B1C1B1B
1C1D1C1B1C1B1B1C1C1B1C1D1B1D1C1C1D1C1B1C1C1B1C1D1B1D1D1D1D1C1D1C1D1D1C1D
1E1D1D1D1E1D1D1E1D1B1D1E1D1E1D1E1E1D1E1E1E1D1D1D1E1E1D1E1E1D1D1F1F1D1E1F
1F1F1E1F1F1E1F1E1F1F1E1E1F1E201F20201E1F1E1F201F1D201F201F1F201E201F2020
1E1F21201F201F201F1F21201F202120201F1F1F1F2121201F211F1E201F1E201E1F2020
202021201F20201F20212021201F1F212020202020201F211F1F1F1E21201F20201F1F1E
1F211F201F211D211F201F1F1F1E1F20201E1F1F1F1E1F201F1F1F1E1F1F1D1F1F1E1E1F
1E1E1E1E1E1E1F1F1D1F1D1D1C1E1E1E1E1E1E1E1D1D1F1E1E1C1D1D1D1F1D1D1C1D1D1C
1D1C1D1D1D1C1C1D1D1C1C1B1D1D1C1C1C1C1D1E1D1B1C1D1D1D1B1D1C1D1B1B1A1B1B1C
1A1C1C1B1C1C1B1C1A1C1C1C1C1B1C1B1B1A1B1A1B1A1B1A1B1C1A1B1B1B1A1B1A19181B
1A1B1B1A1B1B1A1B1B1B1A19191A1A1A1A1A19191A1C1A1B191B1A1A191A1A1A1A1A1A19
1919191A191A1A1B1A1A1A1A191B19191B1A1B1B1A1A191A191A1A1A191A1918191A1918
191919191A191A19
191A191A1A1A191A1B191919191A1B191A1A1A1B1C1A1A1A1A1C1A191A1A1B191A1A1A1A
1A1A191A1A1A1B1B1A1B1A191A1B1B1A1B1B1B191B1C1A1A1B1A1B1A1A1A1B1B1A1A1B1C
1B1A1B1A1B1B1B1A1B1C1B1B1B1C1C1B1A1B1A1A1B191B1B1C1B1C1B1B1C1B1B1C1B1C1C
1B1B1D1C1C1B1B1B1C1C1D1B1C1C1C1B1B1B1C1B1B1C1C1B1C1C1D1C1C1C1C1C1D1D1C1D
1D1D1D1D1D1D1D1C1D1C1E1E1E1E1D1C1E1C1F1E1D1E1E1D1E1D1E1F1E1E1D1D1D1E1E1E
1E201F1D1E1F1F1F1D1E1E1E1F1F1E1F1F1E1F1F1F1E201F201F1E1F20201F1E1F1F1F20
20201F20212021201F1F211F211E1F201F21201F1F1E201E1F1F1E1F1F1E201F2020201F
1F2020212021202020201F20201E21201F20201F202020211F1F21201F20201E1E202020
1F1F1E1F211F2021201F1F1F1F201E201F1F1E1E1E1F1E1F201C1F1E1E1D1F1F1E1F1E1D
1D1D1E1E1E1D1D1F1E1D1E1E1F1E1D1E1D1E1D1E1D1D1E1D1D1C1E1D1C1C1C1D1C1D1D1C
1C1E1E1C1D1D1D1B1C1D1D1C1D1B1B1C1D1D1D1D1D1E1D1C1D1D1B1C1C1D1B1B1C1C1B1C
1C1B1B1B1B1B1B1B1B1B1C1B1B1B1C1B1B1B1A1B1A1A1B1B1B1A1B1A1A1A1B19191B1A19
1B1A1A1B191A1A191B1B1A191A1B191A1B191B1B1A1B1B1A191A1A1B191A191A1A1A1919
19191A1B191A1A191A1A1B1A1A1A1A191A1A1B1A1A19191919191B1A1A1819191A191A19
1919191918181A19
1A181A191A191A1A1A1A1A19191A19191A1A1A19191A1A1A1A1A1A1A1A1A1A1B191B1A1A
1A19191A1A1A1B1B1A1A1B1B1A1B1A1A1B1A1A1A1A1A1B1A1A1B1A1A1B1B1B1A1A1B1A1A
1B1A1B191B1C1C1B1B1B1C1B1B1C1B1A1A1A1C1B1C1B1B1C1B1C1C1B1B1B1C1B1B1C1B1C
1C1D1C1C1B1D1C1B1D1C1C1C1D1C1C1C1C1C1C1C1D1C1D1C1D1D1C1D1C1B1E1B1C1D1C1D
1D1D1E1D1D1D1C1D1D1C1E1E1D1D1D1D1D1D1E1D1D1E1E1E1D1D1C1E1E1E1D1F1E1E1E1E
1E1F1E1F1F1D1F1F1E1F1D1F201E1E1F1F1F201F1F1E1E1F1F1F1F2020201F1F1F1F1E1F
201F1F2020201E20201F21201F1F1F212020211F1F201E211F1D1F1E1E1E1F1F201E201E
1E2020201F20211F20202020212121201F21201E201F1F201F20211F1F2020211E21201F
1F1E1E201F201F1F201F1E1E1F1F201F1E201F1F1F1F1F1E1E1F1F1E1F1E1E1F1E1F1E1E
1D1F1E1F1D1E1E1E1D1E1E1E1F1D1E1E1D1E1D1F1D1E1E1D1D1D1E1D1C1D1D1E1D1E1D1C
1D1D1D1E1D1C1C1E1D1D1D1C1D1C1C1C1C1E1D1E1C1E1D1D1C1D1D1B1C1C1C1B1A1C1B1B
1C1B1B1C1B1B1B1A1C1B1B1B1B1C1B1C1B1A1B1C1A1B1A1A1A1A1A1A191B1A1A1A1B1A1B
1A1C1A1A1A1A1A1A1A1A1A1A1A191A19191B1A1B1B191B1B1B191A1919181A1A1A1A1A19
19191B1A1A1A1A1A1919191A1B191A1A1A1A191A1A191A1919191A19191B1919181A191A
1A191A1919191919
1A1A191B1C1A191A19191B191A1A1A191A1B1A1A19191A191B1A1A1B191A1A1A191A191A
1A1B1A191A1A191B1A1B1B1B1A1A1A1A191A1B1A1A1B1B1A1B1A1B1B1A1B1A1B1A1A1B1B
1B1B1A1B1B1A1A1B1A1B1A1B1C1C1B1B1B1B1B1B1B1B1B1B1B1B1A1B1B1B1C1D1B1A1B1B
1C1C1B1B1C1C1C1C1C1B1B1C1C1C1C1C1C1C1D1B1B1C1B1D1C1D1E1B1C1C1D1C1D1E1C1C
1C1E1D1C1D1E1D1C1C1E1D1D1D1E1D1D1D1E1E1E1F1F1D1F1C1D1E1D1D1E1D1E1E1E1E1E
1E1E1F1D201E1E1F1F1E1F1F1F1F201E201F1F1E1F201F1F1E1F1E1E201F1F1E201F1F1F
2020201F1F1F1F201F211F201F21201E20211E1F1E1F1F201E201E1F1F1F20201F201E1E
1F1F201F202020211F1F201F2020202120211F20211F201F20201F1E201E1F1F1E1E1F1E
1F1E1E1F1F201E1F201F201F1F1F1F201F1F1E1F201F1F1E1D1E1E1D1E1F1E1F1F1E1F1F
1D1D1E1E1E1D1E1E1E1E1E1E1D1F1F1D1D1C1E1E1D1E1E1D1D1D1C1D1E1D1C1E1D1D1E1D
1D1D1C1C1C1D1D1E1D1E1C1D1C1C1C1C1D1E1D1E1D1D1D1C1D1B1C1A1B1C1B1B1B1C1C1C
1C1C1B1C1C1B1A1B1C1B1B1C1C1A1B1C1A1C1B1A1C1A1B191A1A1B1B1A1A1A1B1C1B1A1A
1A1A191A1A1B1A1A1B1A1B19191A1A191A1B1B1A1A1B191A191A191B1A1919191A19191A
1A1A1A1A1A1A1A191B1B1B19191A1A1A191A191A1919191A1A1919191B1A181919181A19
191A19191A181919
191A1A191A1A1A19191A1B1A1A191A1B1A1A1A1A19191A1B19191A191C1A1B1B1B1A1A19
1A1B19191A1A1A1A1A1B1B1A1A1B1B1A1B1B1A1A1B1B1A1A1A1A1A1B1B1B1A1B1A1B1A1A
1B1A1B1B1C1B1B1B1A1A1A1A1B1C1A1A1B1B1B1C1B1C1B1A1B1C1C1B1D1D1C1C1A1C1D1C
1B1B1E1A1B1B1B1C1C1C1C1A1C1B1B1B1B1C1B1C1D1D1C1B1B1D1C1C1C1C1D1C1C1C1C1C
1E1E1D1E1C1D1E1C1D1D1C1D1E1D1C1E1E1D1C1D1C1D1D1E1D1E1E1F1D1D1D1D1D1D1D1E
1E1F1E1F1E1E1E1F1E1E1E1E1F1E201E1D1E201E1E1D1F1F1F1E1F1F1F1F1F1F201E201F
1F1F20201F201F1F1F1F202120201F20201F1F1F1F1F201F1F1E201F1E1F1E201F1F1F1F
201F2120201F201F211F1F1F2020202120211F1E212020201F201F1D1F1F201F1F1F1F1F
1E1F1F1F1F1F201F1E201F1E1F1F1E1F1F1F1F1E1F1F1F1F1F201D1D1F1F1F1D1D1E1E1E
1E1F1E1D1E1F1E1D1E1D1E1E1E1E1D1E1D1D1F1D1D1E1D1D1D1D1C1D1D1C1E1D1C1C1C1C
1D1C1C1D1D1D1D1D1C1B1C1C1D1C1C1F1C1C1D1D1C1D1C1B1C1D1C1C1D1B1D1C1C1C1B1B
1B1B1B1C1B1B1B1C1C1B1B1A1B1A1C1B1C1B1B1B1B1B1A1B1A1B1B1B1B1B1A1B1A1A1A1B
1A1B1A1A1A1B1B1A1B1A1A1919191B191B1A1A1A1B19181B1A1A1A1A1919191B1B191A1A
18191A191A1A191A1A191B19191A191A19191A1A1A191A1A1A1A1B1919191A1918191919
191A191A18181919
19191A191A1A1A191B1A191A191A191A1A1A1A1A1A1A1A1A191B191B1A1A1A191A1A1A1A
1A191A1A191A1A1B1A1B1B1B1A1B1A1A1A1B1B1B1B1B1A1A1A1B1B191A1A1C1A1A1A1B1A
1B1A1B1A1B1B1A1B1B1A1B1A1B1A1C1B1B1B1B1B1B1D1B1A1C1B1B1B1C1C1B1C1D1B1B1C
1B1C1C1B1B1C1C1B1C1B1B1C1C1B1C1C1B1B1B1D1B1C1D1C1B1C1C1C1C1C1D1D1C1C1D1C
1D1C1B1C1D1D1D1C1B1C1D1D1C1C1D1E1E1D1E1D1D1E1D1D1D1D1D1D1D1D1C1E1E1D1E1D
1D1E1E1F1F1F1D1F1F1F1E1F1F201E1F1E1E1F201E1E1E1E1F1D1F1F1F1E1F1E1F211E1E
1F1F1F1E1E1F201F1F201F20201F20201F1F20201F211F1E1F1F1F201D1F201F201F1F1F
1E201F1E1F1F20201F1F2020201E201E21201F2021201E201F1F201D20201F211F1F2120
201F1F201E201E1E20201F1E1E1F1F1F1F1E1F201E1E1E201E1F1D1D1F1F1E1D1E1E1D1E
1E1F1F201E1D1F1D1E1D1D1D1E1E1D1E1E1D1D1D1D1C1D1C1C1E1E1C1C1D1E1C1C1C1D1D
1D1D1C1D1D1D1E1C1C1D1C1C1D1C1D1C1D1D1E1D1F1D1D1C1C1D1C1B1B1D1C1B1C1B1C1C
1A1A1B1B1C1A1A1B1C1B1C1B1B1B1C1B1C1B1B1C1B1A1A1A1B1A1B1B1B1A1B1C1C1B1B1A
19191B1B1A1A1A1B1B1A1B191A1A1A1A1A1A1B1A1B1A1A1A1A1919191A1A1A191B1A1919
1A19181A1A1B191A1B191B1A191A1A1A191A1A1A1918181A19191A1A1A191919191A1918
1919191818181919
1A18191A1A191A18191B1A1A1A1A1A1A191A191B1A1B1B1A1B1A1A1A1A1A1A1A1A1A1A1B
1A1B1A1A1B1B1A1A1A1B1A1B191A1A1B1B1A1A1B1B1A1A1A1A1B1A1A1B1A1B1A1A19191B
191A1A1C1B1B1B1B1A1B1C1A1C1B1B1B1B1B191B1B1B1C1C1C1B1B1B1B1B1A1B1C1D1B1C
1B1B1C1B1B1B1B1B1B1C1B1A1C1B1B1C1B1C1C1C1C1B1B1B1C1C1B1B1C1B1B1C1E1D1B1C
1C1B1D1B1C1D1D1D1C1D1C1D1E1D1D1D1D1D1D1D1C1E1D1E1D1E1E1E1F1F1D1E1E1D1E1D
1E1E1E1E1E1E1E1E1F1E1E1D1E1F1F1F1F1E1E1F1E1F1E1E1E1E1F1E1F1F1F1F1F1E201F
1F1F1E1F1E201E1F1E1F201F1E20211F202020201F1F1F1E1E1F1F1F1F1F1F1E1F20201E
1F1F1F1F1F201E201F2020201F202020201F1F1E1F201F201E201F201D1E1E1E20201F20
1F1E1F1F1F1F1F201F1F1E1F201E201E1F1F1E1E1D1E201F1E1E1E1E1F1E1E1E1F1D1E1D
1F1D1D1E1D1E1D1E1D1F1F1E1F1C1D1D1D1C1D1D1C1C1D1D1E1C1D1E1D1B1D1D1C1D1C1C
1C1D1D1C1D1D1C1D1D1D1D1C1D1C1D1C1D1D1D1E1D1D1C1D1C1D1C1D1C1D1C1C1C1C1B1D
1C1B1E1C1B1B1C1A1B1C1B1C1B1C1C191B1C1B1A1A1B1B1C1C1B1A1B1B1B1B1B1A1C1A1A
1A1A1A1A1B1A1A191B1A1A1A1A1A1919191A1B1A1A1A1A191A191919191A1919191A1A1A
1A1A1A1A191B1A1A1A1A1B1A1A1B1A181A1A1919191A18191A181919191B19181A19191A
1919191A1A181A19
1919191A1A1A191A1A1B1A1A1B1A1B1A1A1B1A1B1A18191A1A191B1A19191A1A1A1A1B1B
1A1A1A1A1A1A1A1B1A1A191A1A1A1B1B1A191C1B1B1A1B1B1A1A191B1B1A1B1B1B1A1B1B
1B1B1A1A1B1B1B1A1A1B1A1A1B1A191B1B1A1B1A1B1B1B1C1B1B1C1C1B1B1B1B1C1D1B1B
1B1B1B1A1C1B1B1A1B1A1A1C1B1D1C1B1B1C1B1B1C1C1B1C1C1C1C1C1D1B1B1B1C1C1C1C
1C1D1E1D1C1D1E1C1D1C1D1C1C1D1E1D1D1D1E1D1D1D1D1D1D1C1E1E1E1D1E1D1E1C1E1D
1D1D1E1E1E1F1F1F1E1F1D1E1F1F1F1E1E1F1F1E1E1E1F1F201E1F1F1F1F1F1E201F2020
1F1E1E1F211F1F1F1E1F1F2020201F1F1F1F1F1F1E1F1E1F1F201F1F1E211E1F1F1D1E1F
1E1F1F1E1E2120201E201E1F1E1E201F1F1F1F20201F1E1F1E1F201F1E1E1E1F1F1F1E1E
1F1F201F1F1F1E1E201D201D1E201F1E1E1E1D1D1E1E1F1F1D1E1F1E1E1D1F1E1D1D1E1E
1C1D1F1E1E1E1E1E1E1E1D1D1D1C1D1F1E1E1E1D1E1D1D1E1D1D1D1D1D1E1C1E1D1B1C1C
1C1D1C1D1C1D1D1C1D1C1C1C1C1D1C1D1D1C1D1D1D1D1C1C1D1D1C1B1D1B1C1B1C1C1C1B
1C1C1C1B1B1B1B1C1B1B1C1C1B1B1C1B1A1C1C1B1B1D1B1A1A1A1A1B1C1B1A1B1A1A1A1A
1A1A1A1B1A1B191A1B1A1B191B1A191A191B1A191A191A1A1A1A1B1A191A191A191A1A19
1A19191B18191A19181A1C191A1A1919181A1A1A181A19191B191A1A191A191818191919
191A1A1A1A19191A
1A181A191919191A191A1A1A1A1A1A1A191A1A1B1B1A19191B191B191A1B1A1A1A1A1919
191A1A1A1A1A1A1A191B191A1A1A1A1A1B1B1A1B191B1A1A1B1A1A1B1A1A1B1C1A191B1B
1A1A1B1B1B1B1B1B1A1A1A1B1B1B1C1B1B1B1B1B1B1B1B1A1A1D1B1D1D1A1B1C1C1C1C1B
1B1B1C1C1B1B1C1B1C1A1C1B1C1C1C1C1C1B1D1C1B1B1B1D1C1D1C1C1C1C1D1B1C1C1B1C
1C1C1C1D1C1D1C1D1D1D1E1C1C1D1D1D1D1C1E1E1D1C1E1D1D1D1E1E1E1E1E1E1E1D1D1E
1D1E1F1E1E1F1F1E1F1E1F1F1F1F1F1E1E201F201F1E1E1F1F1E1E1F201E1F1F1D201E20
1F201F1F1F1F1F201F1F201F1F1F1F20201E1E1F20201E201F201F1E1E1E1E1F1E1E1E1E
1E1F1F1F201E1E201F2020201F1F1F1F1F1F201F2020201F1E1E1F1F1F1D1E1F1E1F1F20
1F1F1E1F1F1F1F1F1F201E1F1E1E1E1E1F1E1E1E1E1E1D1E1F1E1E1E1E1E1E1F1E1E1F1E
1E1E1E1D1E1F1D1D1D1E1E1E1E1D1D1D1D1D1D1D1E1E1D1C1D1D1D1D1C1C1C1D1D1D1D1D
1B1C1D1C1D1C1C1D1C1C1C1C1C1D1C1D1C1D1D1C1C1E1C1C1C1E1D1D1C1C1C1C1B1C1C1C
1B1D1C1D1C1C1A1C1B1B1B1A1D1B1C1B1B1B1B1B1A1A1B1C1B1A1A191B191A1B1B1A1A19
1B191B1B1B1A191B1A1A1A1A1A1A191A1A1A1A1A1A1B1B19191A19191A191A19181A1A1A
1A1A191A1B19191B1A1A1A191A19191919191A191B1A1A1919191A1A1A18191819191A19
1A19191919191A1A
19191919191A191A1A191A191A1A1A1A1A191A191A19181A191B191A1A1A1B1A1A1A1B19
191B1A1A1B1A1B191919191B19191A1A191B191A1B1A1B191B1A1A1B1A1B1A1B1A1A1A1B
1A1B1A1B1A1B1B1B1A1A1A1A1A1A1B1B1B1C1B1B1A1B1B1B1B1C1B1C1B1A1B1B1C1C1B1C
1C1B1B1C1C1A1B1B1B1C1C1C1C1C1B1B1D1C1C1D1D1C1C1D1C1C1C1C1D1C1C1D1D1B1D1D
1C1C1C1D1D1D1B1C1C1C1C1D1E1D1D1D1E1E1D1C1D1E1E1D1E1C1D1C1D1E1D1D1E1D1F1E
1E1E1E1E1F1F1E1D1F1E1E1E1F1F1E1F1E201F1E1E1E1D1E1E1F1D1E1E1E1E1F1F201E1F
1F1F1F1F1F211E1F1F1E1F1F1F1E1E20201F1F201F1F1F1F1F1D1F1E1E1F20201E1F1E1E
1E1F1F20201E1F201E20201E1E201F1F1F1F201F1F1F1F1F1E1E1F1F1F1F1F1F201E1F1E
1E201F1D1E1E201F1E1E1F1E1E1E1D1F1E1E1E1E1F1E1E1F1E1E1E1E1D1E1E1D1E1F1E1E
1D1E1C1D1E1E1E1D1D1D1D1E1D1E1D1E1D1D1D1D1D1D1D1C1E1D1D1C1D1C1D1B1C1D1C1E
1C1D1C1C1C1C1C1E1D1C1C1C1B1C1C1D1C1D1C1E1D1C1C1C1B1D1D1C1B1C1B1B1C1C1C1C
1D1C1B1C1B1C1C1D1B1B1B1B1B1C1B1C1C1A1C1A1A1B1B1B1B1A1A1A1A1B1B191B1A1A1B
1A191A1B1A191A1A1A1919191B1A191A1B1819191A1A1A191A191A1A1A191A1A19191A18
1A19181A1B1B1B1A1A1918191A1B1A171A19191A1A191919191A1B19191A1A181B1A1918
1B191A181A191A18
1919191A19191A191A19191A1A1A181B1B19191B1A191A1A1A191A1919191A1A1B1A1A18
19191A19191B1A191A1B1B1A1A1A1A1A1A1A1A1B1B1A1A1A1B191A1A1B1A1A1B1B1A1B1B
1A1A1A1A1A1B1B1A1A191B1A1B1C1B1B1B1C1B1B1B1B1C1A1B1B1C1B1C1B1C1C1C1B1B1A
1B1C1C1C1B1C1B1B1B1B1C1B1C1C1C1B1C1D1C1C1C1D1B1B1B1B1D1C1B1C1D1B1D1C1C1C
1C1C1B1C1D1C1C1C1C1D1C1C1D1D1C1D1C1D1D1D1E1D1E1D1D1D1D1C1D1E1D1D1E1D1E1F
1E1E1E1D1D1D1D201D1E1E1C1E1F1E1E1E1F1F1F1D1D1F1E1E1E1E1E1E1E1E1F201F1F1F
201E1F201E201E1E1F1F1F1F1F1E1F201E1F1F1F1F1F1E1E1F201F20201F1F1F1F1E201F
1F201F1F201F1F201F201F1F1E1F1F1F1F201F211F1F20201F1E1F1E1F1E1E201E1E1E1F
1E1E1E1F1F1E1E1E1E1F1F1F1E1E1E1E1E1D1D1E1E1D1E1D1E1E1E1E1E1E1D1E1E1E1E1D
1E1E1D1E1D1E1D1E1E1D1E1D1D1C1C1D1D1E1B1E1D1D1E1D1D1D1C1D1B1D1E1D1D1D1D1C
1D1C1D1D1B1C1C1B1C1B1D1C1C1D1C1D1C1D1B1D1D1C1C1C1E1C1D1C1B1C1C1B1C1C1C1C
1C1C1C1B1C1C1B1C1C1C1C1C1B1B1C1C1B1B1A1A1C1A1A1A1A1A1A1A1A1A1A1A1B1A1B1B
191B1A1A1C1A1A1B191A1A19191B1A1A1A1A1A1A19191919191A191919181919191A1A1A
191A19191A1A19191A191A1A19191919181A191A1A1A1A1A191919191A1A191A1A19191A
1919181919191919
1919181A19191919191A1B191A19191A191A1B1A1A181A1B1A1A1B191A1A1A191A1A1B1A
191A1A19191A19191A1A191B1A1A1A1B1A1A1A1B1A1A1A191B1B1A1A1D1A1A1A1A1A1A1B
1A1B191A191A1C1A1B1A191A1C1A1A1B1A1A1B1B1B1C1B1A1B1C1B1C1B1B1B1B1A1A1B1B
1B1B1A1B1C1B1C1C1B1A1A1C1A1B1B1D1C1D1D1C1B1D1B1C1C1C1B1B1C1C1C1C1C1D1C1B
1C1D1D1C1B1C1C1C1D1C1B1D1D1C1D1C1D1D1D1C1C1C1D1D1D1E1E1E1E1E1D1F1B1E1E1F
1E1D1D201E1E1D1E1D1F1D1E1D1F1F1E1E1F1E1E1F1D1F1D1F1E1E1E1F1E1F1D1D1E1F1F
201F20211E1F1F1F1D1F1E1F1E1F1F1E201E1D1D1D1F1E1F1F1F1F1E1F1F1F1F1F1F1E1F
1E1F1E1F1F201F1F1F1F211F1E1F1E1E1F1F1F1F1F1E1F1E1E1F1E1F1F1E1F1F1E1E1F1E
1E1F1F1E1F1F1E1E1E1D1F1D1E1E1D1F1D1E1F1F1D1E1D1F1E1D1E1E1F1D1E1E1D1E1C1D
1C1D1D1C1E1D1D1D1D1D1E1D1D1D1D1C1D1D1D1D1D1C1E1D1D1D1C1D1D1C1D1C1C1C1D1C
1E1C1D1C1D1C1C1C1C1D1B1C1D1C1D1C1D1C1C1C1D1D1C1C1C1B1C1C1A1C1C1C1C1B1C1D
1C1C1C1C1C1C1D1B1C1B1C1C1C1C1C1C1B1C1B1A1C1C1C1A1A1C1B1A1B1B1A1A1C1A1A1A
1A1B1A1A1A1A191B191A1A1919191B191A191A191A19191A1A1A1A1A1A191A181A18191A
1B191A191A191919191A191819191A191A1A1A1A1819191A1A181A19181A191A1919191A
1919181918191918
1A1A19191A1B191A1A191A1A191B191A1A1B191B1A1A19191B1A1B1A1A1A1B191A1A1A19
1A1A19191A1A191B1A1B1B1B1A191A191A1A1B1B1A1A191B1B1B1A1A1B1C1B1A1A1A1A1B
1B1A1A1B1A1A1A1B1A1A1B1C191B1A1C1A1B1B1A1B1C1A1A1A1A1B1B1B1A1C1A1A1C1B1B
1B1B1A1C1C1C1B1C1B1C1B1B1B1B1C1B1B1B1C1C1B1C1C1A1C1D1C1C1C1B1B1C1B1B1D1C
1B1C1C1D1D1C1D1C1B1C1E1C1E1E1C1D1E1D1D1D1C1D1B1D1E1D1E1D1C1D1D1E1D1C1C1D
1E1E1E1E1D1E1E1E1D1D1E1E1F1E1E1D1E1E1E1F1D1E1F1E1F1E1D1D1F201E1F1F1E1D1F
1F1F1F1F1F201E1F1F201F1F1F1E1F1F1F1E1E1E1F1F1E201F20201E201F1E1E1F1E1F1F
1F1F201F1E1D1F1F1D1E1E1F1E1D1F201E20201E1F1F1F1E1F1F1F1F1E1E201F1F1F1F1E
1E1E1D201F1D1E1F1F1E1E1C1E1E1E1E1E1E1E1E1F1F1E1D1F1E1E1F1E1D1E1D1C1C1D1E
1F1E1E1E1D1D1E1D1D1D1D1C1D1D1C1D1E1D1D1C1D1C1D1C1D1D1E1B1D1C1B1C1D1B1D1C
1D1D1D1C1D1C1C1C1B1C191C1C1B1C1B1D1B1C1C1D1C1C1C1D1C1C1C1C1C1D1C1C1B1C1C
1C1C1D1E1D1C1C1B1C1B1C1C1B1B1C1B1B1A1B1C1C1C1B1A1A1C1B1B1B191A1B1B1A1919
1B1B1A1A1A1B1A1A1A1B1A19181B1B191B1A1B191B1A181A181919191A181B19191A1A1A
19181B1A1919191A191A18191A19191919191919191A1B19181A1919191C1D1919191A19
1A19181A191A191A
19191A191A1919191A191A191A1919191B1919191A191819191A1A1A18191A191B191A1A
191A1A1A1919191A1B1A19191A1B191B1A1A1B1B1B1A1B1A1A1A1A1A1A1B191B1B1B1A1B
19191B1B1A1A1B1A1A191B1A191A1A1A1A1B1A1A1A1A1A1A191B1C1A1B1B1C1B1C1A1C1A
1B1B1C1B1A1C1C1C1B1C1B1A1A1A1C1C1C1B1C1C1C1B1C1A1C1B1B1D1C1D1C1C1C1C1B1C
1D1D1D1D1C1B1D1C1D1C1C1D1D1D1D1C1C1D1D1C1D1D1E1D1C1C1D1D1D1D1B1D1E1D1D1D
1D1F1E1E1E1F1D1D1E1E1E1F1D1E201F1D1E1E1E1E1F1E1D1F1E1E1E201E1D1E1E1F1E1F
1F1F1E1F1E1E1E1F1E1F1F1E1F1F1F201F1E1D1F201F1F201F1E1F201E1E1F1E1E1D1F1E
1F1E1F1F1D1F1D1E1F1E1F1E1E1F1E1E1F1F201F1F1F201F1F1E1E1E1E1F1F1F1E1C1E1F
1E1F1E201F1E1F1E1F1E1E1E1E1E1F1D1E1E1F1F1D1D1D1D1E1D1D1C1D1D1E1E1D1E1D1E
1D1E1D1E1E1C1D1C1C1D1D1C1C1D1D1D1D1E1C1C1D1D1D1D1C1B1C1E1D1D1B1D1C1E1D1B
1C1D1D1C1B1C1C1C1B1C1C1C1C1C1D1B1C1D1C1B1C1C1D1C1D1C1C1C1C1B1C1C1D1E1D1C
1B1D1C1C1C1D1C1C1C1B1C1D1C1B1D1C1B1C1B1B1B1B1A1B1B1C1B1C1A1B1B1B1A1B1A1C
1B1B1C191A1A1A1A1A1A19191A1A1A191A191A191A191A1A19191A19191A191A1A1A1A1A
1A1A1A1A1918191A191A1A181A1A191A191A1819191A18191A1A1A1B19191A1A191A1A1A
19191A1918191919
1A191819191A19191A1A1A1A1A1A1B1A1A191A181A191A1A1A1A19191A191A1A1A191A1A
1A19191A1A1B1A1B1A1B1A191B1A1A1B1A181A1A1B1A1A1A1B1A19191B1C1C1A1B1B1B1A
191A1A1B1B1A1B1A1A1A1B1C1B1B1A1B1B1A1B1B1A1A1D1A1B1B1B1A1B191B1B1B1B1B1B
1B1B1B1C1C1B1B1C1C1B1D1C1C1A1B1C1C1C1C1B1B1B1B1B1C1C1C1C1B1C1B1B1D1C1C1B
1C1E1C1C1C1C1D1C1C1C1C1D1D1C1E1C1D1D1C1C1C1D1D1D1D1D1E1C1D1D1D1D1D1D1E1E
1D1E1D1C1E1D1E1E1E1E1E1E1D1E1E1D1F1F1E1F1E1F1D1F1D1E1E1E1F1D1C1E201F1E1F
1E1E1F1F1F1E1E1E1E1F1F1F1E1D1E1E1F1F1D1F1E201E1F1D201E1E1F1E1F1F1F1E1E1D
1F1E1F1D1F1F1F1F1E1E1F1E1F1F1E1E1E1E1E1E201F1F1F1E1F1D1E1E1E1E1F1E1F1F1F
1E1F1D1E1F1D1E1E1D1E1D1E1D1F1D1E1E1E1D1D1E1E1D1E1D1D1E1E1D1D1E1C1F1C1D1C
1E1D1C1E1E1C1C1D1D1D1C1E1D1E1D1C1C1B1D1C1D1D1C1D1C1B1C1B1C1D1C1C1C1C1C1D
1C1D1C1D1D1C1C1B1C1B1C1B1C1B1B1D1B1C1C1B1D1C1C1C1C1D1D1C1D1C1D1C1C1C1C1D
1C1E1C1D1D1C1E1D1D1B1C1E1B1C1B1C1C1B1B1B1A1A1A1C1B1B1A19191B1B1A1A1A1B1A
1A1A1A1B191A1A1B1A191A191A1A1A191A1B1A1A1A1B1A1A1A181A191A1A191A1A1A1A1A
191919191A1A1A1919191A1A1A1A1A1919181A1A1A1A191A1A1A1919181A1A181A191A19
1A19191A181A1919
19181A191919191A191A191A1A1B1A19191A19191919191A191A191A1B1B1A1A1A191A19
1A1A1A191A1A1B1A181B1A1B191A1A1A1A191B1A1B1A191A181A1B191A1A1B1B1C191B1A
1B1A1A1A1A1B1B1C1B1B1A1B1B1A1A1B1B1B1A1B191A1A1B1A1C1A1B1B1C1C1B1B1A1B1B
1A1B1A1B1A1C1B1B191B1B1D1B1B1B1C1D1C1B1C1C1C1B1C1D1C1B1C1C1C1C1D1C1C1C1B
1C1D1C1C1D1C1D1C1C1C1C1C1D1D1D1C1D1D1C1C1D1D1D1E1D1D1D1D1D1C1E1D1D1C1D1D
1D1D1D1E1D1D1F1D1D1E1E1D1F1D1F1E1F1E1F1F1D1E1E1E1E1F1D1F1D1F1E1E1E1E1E1D
1F1F1F1E1E1F1E1F1F1D1E1E211F1E1F201E1F1E1E1E1F1E1F1E1E1F1D1F1E1F1F1E1D1E
201F1E1F1D1E1F1E1E1E1E1F201E1F1F1F1F1F1D1F1F1F1E1E1E1F1F1E1E1F1E1E1E1F20
1E1F1E1F1E1F1F1E1D1E1D1E1D1D1E201F1D1D1E1E1F1E1D1E1D1D1D1D1C1F1E1D1C1D1B
1D1E1E1D1D1D1E1E1D1C1D1B1D1C1E1D1D1D1C1D1D1D1D1C1D1C1D1D1E1C1D1D1C1D1B1C
1E1C1C1C1B1C1C1C1C1C1D1D1B1B1C1C1C1B1B1D1C1C1C1D1C1C1D1D1C1D1C1E1E1C1E1D
1C1C1C1D1D1D1D1C1C1C1C1D1C1C1C1C1B1C1C1C1B1C1C1A1C1C191A1A1B1A1A1A1A1B1A
191A1A191A1B1A1B1A1A1A19191919191A1A1A1A191B191919191919181A1A1A1A1B191A
19191A1A1A1819191A19191918191A1B181B19191A1A191918191A191A19191919191819
1A1A1A191918181A
19181918191A1B191A191A191A191B1A191A1A1A19191B191B1919191A1A1A19191A1919
1A1919191A1B1B191A1A1A1A191B1A1A19191B1A1A1A1C1B1A1B1A1A1B1B1A1B1A1A1A1A
1A1A1A1A1B1A1B1B1B1B1A1B1B1A1B1A1A191A1B1A1A1A1B1C1B1A1B1D1C1A1A1A1B1B1B
1B1B1A1B1B1B1B1A1B1C1A1B1B1B1C1C1C1B1B1B1C1C1B1D1C1C1C1C1B1C1C1C1C1C1C1C
1C1C1D1C1C1D1B1C1C1B1C1D1C1C1D1C1D1C1D1C1D1E1E1C1E1D1E1E1D1D1E1D1D1E1D1E
1D1E1E1D1E1E1E1E1D1F1E1E1E1E1F1F1E1E1E1D1E1E1E1C1F1E1F201F1F1E1D1F1E1D1F
201F201E1F1F1E1E1D1E1E1E1E201E1F1E1F1F1E1F1D1D1D201E1F1E201F1F1F1F1E1E1D
1D1F1F1F1F1E1E1F1E1E201E1D1F1E1F1E1F1F1E1E1E1E1E1E1E1D1E1E1F1E1E1F1E1E1E
1D1E1E1D1E1C1E1D1E1E1E1D1D1D1C1F1E1D1D1E1E1D1E1D1D1E1E1F1D1E1D1E1D1D1D1D
1C1D1C1D1E1C1E1B1E1C1D1D1C1C1C1D1C1D1C1C1C1E1C1C1C1D1D1D1D1C1B1D1D1D1C1C
1C1B1C1C1D1C1D1D1C1B1B1C1C1B1B1C1C1B1C1C1D1D1C1C1C1C1C1D1D1E1D1D1E1C1E1C
1E1D1D1D1D1D1C1C1E1B1D1D1C1C1D1C1C1B1B1B1A1B1C1A1B1B1B1A1B1C1B1A1B1B1B1A
1B191A191A1A1A1919191A1B191A1A1A1B191A1A19191A1A1A1A1A191A19191A1A1C1A1A
1919191919191B191A191A191A19191719191A19191819181A191919191A18191919191A
18191A19191A1A19
191A1A191B1A191A191A19191A1A18191B1B1A191A191A1A1A191A1A191919191B191919
1A1A1A1919191A191A1A1B18191A1B1A1A1B1A1A1A1B1C1A191A191B1B1B1A1B1D1C1A1B
1A1B1A1A1A1A1A1B1A1B1B1B1A1A1A1A1B1A1A1A1A181B1A1B1B1A1B1C1C1B1B1B1C1C1B
1B1C1B1B1A1C1B1B1A1B1C1C1A1B1B1B1B1C1B1B1B1A1C1B1C1B1B1C1C1D1C1C1C1C1B1C
1C1D1C1C1C1E1D1C1D1B1C1D1D1C1D1C1D1D1D1D1D1D1C1C1E1D1E1D1C1C1E1D1D1C1D1E
1C1E1D1E1E1E1E1D1E1D1D1E1E1D1D1E1E1E1F1E1D1D1E1C1D1D1D1E1F1D1E1D1E1E1F1F
1F1F1F1E1F1E1F201F201E1F201F1F1F1D1F1D1F1D1E1E1E1E1E1F1F1D1F1E1F1F1F1E1D
1F1E1D1E1F1F1E1D1E1F1E1D1E1D1E1F1D1F1E1D1E1F1E1D1F1F1E1F1D1E1E1E1D1E1F20
1E1E1D1E1E1E1E1E1D1D1D1E1D1F1E1D1D1D1D1E1D1D1D1E1E1D1E1D1D1F1D1E1D1E1E1E
1C1D1C1D1C1D1D1C1D1E1D1C1E1C1C1D1D1D1D1C1D1C1C1D1D1D1C1D1C1C1D1D1D1D1B1C
1C1C1C1D1C1C1B1C1B1C1C1D1C1C1C1D1C1C1B1D1C1C1C1D1D1D1D1C1D1D1E1D1D1E1D1E
1F1E1E1F1E1E1E1D1D1E1D1D1D1E1C1D1C1D1C1C1C1B1C1C1B1B1A1C1B1B1B1A1A1A1A1B
1A1A1B1A1A1A1919181A1A1A1A1A1A1A1B1B181A1A1A1A1A1A1A18191A1919181B191B19
1A191919181A1A19191819191A1A1917191B1A191A191A181919191A1A191A181A1A1819
181A19181819181A
1A191A191A19181A191A1919191A18181A1A1A1A1A191A191B191B191A1A1A1A19191A19
191B1A191B1A191A1A1A1A1A191A181A191A1A1B191A1A1B1B191A1B1B1B1A1A1A1B1A1B
1B1B1A1A1A1A1A1A1B191A1B1B19191B1A1A1A1B1A191C1A1B1C1B1B1C1B1B1C1C1B1B1B
1A1C1B1A1C1A1A1B1C1C1B1B1B1C1C1C1B1B1B1B1A1B1C1B1B1C1C1B1C1A1B1C1B1D1B1C
1B1C1B1C1D1C1C1C1B1C1C1C1C1C1C1B1C1C1E1C1C1D1D1D1D1C1C1C1E1E1D1D1D1D1E1D
1E1E1D1E1D1D1D1D1D1E1E1D1F1E1E1E1F1E1E1E1E1C1D1E1E1E1E1F1E1E1D1F1D1F1F1D
1F1F1F1F201E1E1E1F1E1F1F1F1F1E1D1D1D1E1E1D1E1E1E1F1E1D1E1D1F1D1F1E1D1D1F
1D1F1D1D1F1E1C1F1F1F1D1E1E1E1E1D1E1E1C1E1F1D1D1E1F1E1D1E1E1E1D1F1D1E1E1E
1F1F1D1F1F1E1E1F1E1E1E1E1D1D1D1E1D1D1E1D1E1D1D1D1D1D1D1C1E1D1D1E1E1E1E1D
1E1C1C1C1E1D1C1D1C1C1C1E1D1E1C1D1B1C1D1C1D1D1C1C1C1C1C1C1D1D1B1C1B1D1C1D
1C1D1C1C1C1B1C1C1D1D1C1C1D1C1C1C1C1C1D1C1A1D1D1C1C1D1D1D1D1E1E1D1E1F1C1E
1E1E1E1E1D1E1F1F1F1E1E1D1D1D1C1C1D1C1B1C1B1B1C1C1C1B1B1C1A1B1A1B1B1B1A1A
1A1A1B1A1B191A1A1B1A1A191A1A1A191A1A1A191A181B1919181A191A1B1B191A191A18
1B1819191819191919181B1A19191A1919181A1919191A1A191A19191818191A1A181818
181919191A191918
1919191A19191A1A1A19181A1A1A191A1A1A1A1A1A1A1A191A1A1A18191A1A1A1A191B19
1A1A191A1A1B191B191B191A1A1A1A1A191A191B1A1B1A1A1B191A1A1A1A1A191B191A1B
1B1A1B1A1B1A191A1A1A1B1A1A1B1B1B1A1B1B1B1A1B1B1B1A1B1B1B1C1B1B1B1B1B1C1B
1B1A1B1B1B1B1A1C1C1C1D1A1B1C1B1A1A1B1B1C1B1C1C1C1B1C1C1B1C1C1B1C1D1C1B1C
1D1B1C1C1C1C1C1D1C1C1D1C1C1C1C1B1C1C1D1D1D1C1D1F1D1E1D1D1E1C1C1D1D1C1D1D
1D1E1E1D1D1D1C1E1D1E1C1F1C1F1E1D1F1D1E1E1E1D1D1D1D1E1E1E1E1E1E1E1E1E1E20
1F1F1F1F1E1F1E1E1F201F1F1D1F1F201F1F1E1E1E1D1E1F1E1D1E1F1C1E1E1E1D1E1E21
1E1E1E1E1E1E1E1F1E1E1E1E1E1D201E1F1D1F1C1D1E1D1E1E1E1F1F1E1E1D1F1E1F1E1D
1E1D1F1E1D1D1F1D1D1E1D1E1D1E1E1E1C1E1D1E1C1D1E1D1E1E1F1D1D1D1C1E1D1D1C1D
1D1D1D1D1C1C1D1D1B1B1D1C1C1D1C1C1E1C1D1C1C1B1B1C1B1B1C1D1C1D1B1C1C1B1B1C
1D1C1C1C1B1B1B1C1C1C1B1B1C1D1D1B1C1B1C1D1D1D1D1D1D1D1E1E1C1D1D1E1E1D1F1F
1E1F201F1E201F1F1F1F1D1E1D1D1E1C1C1C1C1C1C1D1B1B1C1B1B1C1B1C1B1C1B191A1C
1A1A1A1919191B1B1A1A1A1919191A1A1A191A191919191A1B191A1A1A191A1B18191919
191919191A19171A1A1A1A191B191A181A1A191A1A191819191A1919191A19181B191919
181A19191A1A1919
1A1919191A191B1A1A1B1A1A19191A19191A1A1A1A1A1A1A1A191A191A191B1B1A1A1A1A
1A19191A1A19191A191B1A1A1A1A1A1A1B1A1A1B191A191B1B1B1B1B1B1A1B1A1A191B1A
1A1A1919191A1A1A19191B1A1A1A1B1A1B191A1C1B1B1A1B1B1C1B1A1B1B1B1A1C1B1A1A
1B1C1C1C1A1B1A1B1B1B1C1A1A1B1B1B1C1B1C1B1B1B1C1D1B1B1B1C1D1B1B1B1B1D1B1C
1D1D1C1B1C1C1B1B1B1C1D1D1C1C1C1C1C1E1D1C1C1D1D1C1C1D1C1C1E1C1D1D1D1E1D1E
1D1D1E1D1C1D1D1D1D1D1E1D1E1E1E1E1E1E1F1E1D1D1D1D1E1E1D1D1F1E1D1E1E1F1E1C
1F1F1F1E1E1F1F1F1F1E1E1D1E1E1E1E1F1E1D1D1D1D1D1F1E1D1E1E1D1D1D1D1C1F1D1D
1E1D201E1E1D1E1E1E1F1D1E1D1E1E201D1D1D1D1F1D1D1D1F1D1E1D1D1D1E1E1E1F1F1E
1C1D1E1F1D1E1C1D1D1D1E1D1E1D1E1E1D1E1E1D1D1D1F1F1D1D1E1C1D1D1E1D1D1D1C1D
1D1E1D1C1C1C1D1D1D1C1D1C1D1B1C1D1C1D1C1D1C1C1C1D1D1D1D1C1D1C1D1C1C1D1C1C
1C1D1C1C1C1B1B1C1C1C1B1E1E1C1C1C1C1C1C1D1B1C1C1E1C1D1E1D1F1F1E1E1E1F2021
201F212020202120201E1F1E1F1E1D1D1C1E1D1E1E1C1B1B1B1B1C1A1B1A1B1B1B1C1A1A
1B1A1A1A1A1A1A1A181B191A1A191B191A1A181819191A19191A191A1A1A1A1919191A1A
19191A1A19191A1A1B1A191919191919191A1A191A1A1A1A19191B181A1A191A1A191919
191919191A191719
1A1918191819191A1A19191A1A191A191A1A1A191A191B1A191A191A19191A191A191A19
1A1A191A1B19191A1919191A1A1A1A1B1A1A1A1C1A1A181A1A1B1A1A1B191A1A1A1A1B19
1A1B1A1A1A1C1B1A1A1B1B1B1A1A1C1C1A1B1B1A1A1B1B1A1B1D1B191B1B1C1B1C1A1A1A
1B1B1A191B1B1B1A1B1B1B1B1B1B1B1B1B1B1B1A1B1C1C1C1B1C1D1B1B1B1C1B1B1C1C1C
1B1C1D1B1B1C1C1E1D1C1C1D1E1B1C1B1C1B1D1C1C1C1D1C1C1D1C1D1D1E1C1C1D1D1D1D
1C1D1D1D1D1D1E1C1E1D1D1D1D1C1E1D1E1D1E1E1E1D1D1E1D1D1D1D1D1D1F1E1F1F1D1F
1D1E1E1E1D1F1E1E1E1E1E1F1F1E1D1E1F1E1D1D1E1D1E1F1E1F1D1D1E1D1C1E1E1E1D1D
1E1E1E1E1D1E1D1D1E1D1E1E1E1E1F1F1D1D1E1D1E1E1D1F1E1E1F1C1D1D1E1D1C1E1E1D
1E1C1D1E1E1C1D1E1D1E1D1D1E1D1D1D1E1D1C1D1C1D1C1C1E1D1E1E1E1E1C1D1C1D1E1C
1E1C1D1C1D1C1D1C1C1D1B1B1C1C1D1C1B1B1D1C1B1C1B1B1C1C1C1A1C1B1C1C1C1B1D1B
1B1C1C1C1C1D1C1C1D1C1C1C1C1B1C1C1C1C1C1C1D1D1C1C1E1D1D1F1E1E1F1F1E1E2021
2021222120222221202120201E1F1E1D1D1D1B1D1D1C1C1B1C1C1B1B1C1B1A1B1A1B1A1A
1B1A1A1A1B1C1B1A1A1A1919191A1A1A19181B1A191919191A1A1A1A1A1A191A1919191A
191A1A1A191A1A191A18181A19191A191A1A181A1919191919181A1A1919181919191918
1918181919171819
1A191A191B1919191A191A1A19191B191A19191A1A1A1A191A191A191A191B1A1A1A1A1B
1B191A1A1A191A191919191A1A1A191A1A191A1B1A1A1A1A1A191B1A1A1A1A1B1A1B1A1B
1A1B1B1A1B1A1B191A1A1B1B1A1A1A1A1B1A1B1B1A1A1B1A1A191B1A1B1C1B1B1A1B1B1B
1C1A191A1B1A1B1B1B1C191A1C1B1C1B1A1B1C1C1B1A1B1B1B1B1B1B1C1C1B1C1B1B1B1C
1B1C1C1B1D1D1C1C1C1A1C1C1B1C1C1C1D1D1C1B1C1C1B1C1D1D1E1D1D1D1D1D1C1D1D1C
1C1D1C1D1E1D1D1D1D1E1D1E1E1D1D1D1D1E1C1E1F1C1F1E1F1E1D1D1D1D1D1E1E1E1E1E
1D1E1E1E1E1E1E1F1E1E1D1D1D1E201E1E1F1E1E1E1E1E1F1E1E1E1D1E1D1E1E1E1E1E1E
1D1E1F1E1F1E1E1D1E1E1E1E1D1E1D1E1D1E1E1F1E1E1F1F1E1D1D1D1E1E1F1C1E1F1E1D
1D1D1E1E1D1E1D1C1D1D1D1E1D1E1C1D1E1C1D1D1C1C1E1E1C1E1E1D1D1E1C1D1D1D1D1D
1D1B1D1D1D1C1C1C1C1D1C1C1C1B1C1C1D1D1B1C1C1C1B1C1C1C1B1B1B1D1C1C1A1B1C1B
1D1C1B1C1D1A1C1D1D1B1D1C1D1C1D1C1B1C1B1D1C1D1C1D1E1E1D1E1E1E1F201F202121
21222322232425232323212221211E1F1E1D1D1C1C1D1D1D1D1A1B1C1C1B1A1B1A1B1B1A
191A1A1A1A1A1A1A1B1A1A19191A1A1819191A1A191A191919191A191A181919191A1919
1A1A1A1A1A19191919191919181919191A191B191A181A18191B1919191819181A1A1819
181918191818191A
19191A1A19191B1A19191A1A191B1A191A1A191A1B181A191A191A1919191A1A1A1A191A
1A1A19191A1A19191919191A19191A1A1A1A1B1B191B191A191A1B1B1A191B1A1B1A1A1A
1A1A1A1B1A1A1A1A1A1A1B1A191B1A1C1A1B1A1B1B1B1A1A1B1A1B1C1B1B1A1A1B1A1B1B
191C1C1C1B1B1B1B1B1A1B1D1B1B1B1B1B1A1B1B1B1C1B1B1B1B1B1B1B1C1B1B1C1C1D1C
1B1B1C1C1C1C1C1E1D1C1C1C1D1C1D1C1C1C1C1D1B1D1D1D1E1D1C1C1C1E1C1D1D1D1D1E
1D1D1C1C1D1E1D1C1D1F1C1E1D1C1D1E1D1E1F1D1E1E1E1C1D1C1E1E1D1E1D1E1C1D1D1E
1E1D1E1D1F1E1E1E1F1D1E1D201E1C1D1E1F1D1E1F1F1E1E1E1E1E1E1E1E1E1D1E1E1D1D
1E1F1E1F1E1E1F1D1C1F1E1D1E1E1E1E1D1E1D1E1D1D1E1D1E1D1E1F1E1D1D1E1D1E1E1C
1E1D1D1D1D1D1C1D1E1E1E1D1E1E1C1E1D1C1E1D1C1C1E1C1D1D1D1E1E1D1D1E1D1D1C1D
1C1C1D1C1C1D1B1C1C1C1C1C1C1C1C1C1C1D1D1D1D1C1A1C1A1D1D1C1D1C1B1B1C1D1C1C
1D1C1B1C1B1C1D1B1C1C1B1A1C1B1D1C1D1D1B1D1D1E1C1D1E1E1D1F1F1F1F2120202221
232525252627272626262324232120201D1E1D1B1C1C1C1B1B1D1C1C1A1B1B1C1B1B1B1B
1A1A1A1A1A1A1A181B1A191A191A1A1A181A1A1A191919191A1A18191A18191A1A1A1918
181A1A191919191A1A1A1A1A1A1A1A191A1A191819181A1B1919191819191A1A19191919
1819191A19191B19
1919191A1919191A191A19191919191A191B1A1A1A1A1A1A1A191A19191A19191A1A191A
1A1A1A1A1A1B1A191919191A1A1A19191A1A1A1A1919191A19191B1A1C1A1A1A191A1B1B
1A1B1A1B1A1A1B1B1A1A1B1A1A191A1A1B1C1B1B1B1B191A1B1A1B191B1B1B1B1B1A1A1A
1B1C1A1C1B1A1C1B1B1B1C1A1A1B1B1B1B1C1B1B1B1B1B1B1B1A1B1B1B1B1B1C1B1C1C1B
1B1C1C1C1C1C1D1C1C1C1C1B1B1C1B1D1C1C1B1D1D1C1B1C1C1C1C1D1C1D1B1C1C1B1E1D
1C1D1E1C1B1D1D1D1D1E1E1D1E1E1E1D1E1D1F1E1E1D1D1D1D1D1E1E1D1E1F1F1C1C1F1D
1D1D1E1D1E1E1E1F1D1D1E1E1E1E1D1E201E1E1E1E1E1D1D1E1C1E1E1D1F1D1D1D1E1D1F
1E1D1F1E1D1D1E1F1E1E1D1E1D1E1E1C1E1C1D1C1D1E1E1E1D1E1E1D1C1C1D1E1D1E1E1E
1C1E1D1E1E1C1C1D1C1E1E1E1E1E1C1C1D1E1B1E1E1D1C1D1C1E1D1C1D1D1D1D1C1C1C1C
1D1C1D1C1D1B1D1C1D1C1D1D1B1C1C1C1C1B1D1C1C1D1D1C1C1C1C1C1C1D1C1C1C1D1C1B
1E1D1B1C1C1C1D1C1D1B1C1D1B1C1D1D1C1C1C1C1E1D1D1D1E1F1E1E2021201F1F222223
242527282A2C2C2C292828242321211F1E1F1D1D1E1D1C1C1D1C1D1B1B1B1B1B1B1A1B1B
1A191A1A1A1A1B191A1A1A19191919191A1B1A1A1A191A1A1919191919191A1A1A1A191A
1A18181A191A1A1A19191918191A1A1A1B1A1A1A1A191A191918181919191A181A1A1A1A
1A19191919181919
191919191A191A1A191A191A1A1A19191A191A19191918191A19191A1919191A1B191B1A
1A1A1A191A191A1B1A191819191A191A191B1A1A1A1A1A1A1A1A1A191B191A191A191A19
1A1A1A1A1B1B1A1B1A1A1B1A1A1A191A1A1B1A1A1A1B1B1A1B1B1A1A1B1A1A1B1A1A1B1B
1A1A1A1A1B1B1B1B1A1A1B1B1B1C1C1B1C1B1A1B1B1C1B1C1C1B1B1C1C1C1C1C1B1C1A1B
1C1B1C1C1E1D1D1C1C1B1C1C1C1C1B1D1D1D1D1C1C1C1C1D1B1C1C1D1D1D1C1C1C1C1D1C
1D1C1E1C1C1E1C1D1D1E1D1D1D1F1B1D1E1D1F1D1D1D1E1D1D1D1E1C1D1E1C201E1F1F1D
1D1E1D1C1E1E1E1F1D1D1E1E1D1D1D1E1E1E1D1F1E1E1E1E1E1F1E1E1E1D1E1C1D1D1D1D
1E1D1F1C1E1E1D1E1D1D1C1E1D1D1D1D1D1E1D1D1E1D1E1D1E1C1E1D1E1F1D1D1E1D1E1D
1E1C1C1D1F1D1D1E1E1E1E1D1D1C1D1C1D1E1E1C1D1C1D1D1C1E1D1E1D1C1D1D1B1D1C1E
1D1D1D1D1B1C1C1B1C1C1C1D1C1C1D1C1D1C1B1B1D1D1C1C1C1B1B1C1D1C1B1B1D1C1C1B
1D1D1C1C1C1B1C1B1C1B1C1C1C1C1B1B1C1C1C1B1E1D1D1C1D1F1F1D1E20202020232425
26262A2C2F302F2F2F2E2A27252123211F201F1E1E1D1C1B1C1B1C1B1B1B1B1A1B1A1A1A
1A1B1A1A1A1A19191B1B19191A1A1A1A1A1B19191B191A1A1A191A191B191A1A1A19191B
1A1A191A1A1C1919191A1A1B1A191A191819191A191A18191A1A181A1919191919191919
1819181919181919
1A191A1A1819181A18191919191A1A1B1B191A1A191A1A19191B191A1A1A18191A1B191A
191A19191A191A1A191A1A1A1A1B1A1A1A1A1B1B1A1A1B191A191A1A1A1A1A1A191B1A19
1A191A1A1A1B1A1A1A1A1A191B1B1A1A1A1A1A1A1A1919191B1B1B1A1A1B1B1A1A1B1B1A
1B1A1A1A1B1A1B1A1A1B1B1C1B1B1A1B1B1B1B1C1D1B1B1C1B1B1C1B1B1C1C1B1B1B1B1C
1C1A1C1C1D1D1C1C1C1B1B1C1B1C1C1C1B1B1E1D1B1D1D1D1C1C1B1D1C1D1C1D1C1C1C1D
1C1D1C1E1D1E1E1D1D1C1D1D1D1C1E1C1C1D1E1E1E1E1D1E1E1D1D1D1E1C1C1E1D1D1D1D
1D1F1E1F1D1D1E1D1D1E1D1E1D1D1E1D1D1E1D1D1F1E1D1E1D1F1E1E1D1E1E1E1F1E1E1E
1C1D1E1E1E1D1D1D1E1F1D1D1E1E1E1E1D1E1D1E1C1D1D1D1C1D1E1E1E1D1E1E1E1E1D1E
1D1D1D1D1E1E1E1D1E1D1C1D1B1E1D1D1C1C1D1D1C1D1D1C1E1D1D1D1D1D1E1C1D1D1D1C
1D1D1C1D1D1C1D1B1D1C1D1C1D1C1C1C1C1C1B1C1C1C1C1C1C1B1B1C1C1C1C1C1C1C1C1C
1D1D1C1B1C1A1B1C1C1C1C1C1D1B1B1C1C1C1C1C1C1C1D1D1F1E1F1E1E20202122232324
282C2C2E3434343433302E29282322201F1E1E1D1D1D1C1C1C1C1B1B1C1C191C1B1B1B1A
1A1B1B1B1A1A191A1A191A18191A1A1A1A1919191A1A19181919191A1A1A1A191A181A19
1A1B191A1A1A1A191A1A1A191A191A19191A191A191919191A191A1919191A1A1A19191A
191819181919191A
18191A19191A191919191A1919191A191A19191A191A19191A191A191A191A191B191A1A
19191A19181A191A18181A19191A1A1A1A1A191A1B1A1A191A1A1A191A1A1A191B19191A
1A191A1A1A1B1B1B1A1A1B1B1A1A1B1A1A1A1B191A1A1B1B1A1A1B1B1A1A1B1B1A1B1B1A
1B1B1A1B1B1B1A1A1B1B1C1B1A1A1B1B1A1C1C1D1B1B1B1C1B1C1A1B1C1A1B1B1D1B1B1D
1C1B1B1C1B1C1C1A1B1C1C1C1C1C1E1C1C1D1C1E1B1B1B1E1C1D1D1C1C1D1C1D1C1D1D1C
1D1C1C1C1D1C1E1C1D1D1D1E1E1C1D1D1C1D1E1D1F1D1D1D1C1E1E1E1E1C1D1D1D1E1D1D
1E1E1D1C1D1F1D1E1D1E1E1D1D1F1C1D1C1E1E1D1C1E1D1C1D1D1E1F1D1D1D1C1D1D1C1D
1E1D1E1D1D1E1D1E1E1E1D1E1E1E1E1D1E1C1D1E1D1D1D1D1D1D1D1D1D1E1C1C1D1E1E1E
1D1E1D1D1F1C1E1D1D1E1D1D1D1E1E1C1C1D1D1E1C1C1E1C1C1C1C1C1C1D1D1D1C1C1C1C
1D1C1C1D1C1B1C1C1C1C1C1C1C1D1B1C1C1E1C1C1C1B1C1C1C1B1C1B1D1C1C1C1C1C1B1C
1B1B1C1C1C1B1C1B1C1C1C1C1C1C1C1C1C1B1C1D1C1C1E1E1D1E1F1E1F1F202122222626
2B2C303237393A3938332E2B27252322201F1F1E1E1D1E1D1D1C1C1B1C191B1A1B1B191C
1A1A1B1A1A1A1B1919191A1A1A1A1A1A1B1A1A191A1A191A1B191A1919191919191A191B
1A1A1A191A191A191A191A1B1B1A191A19191918191A191B1A191A1A191919191A18191A
181919191A19191A
191919191A1A1A19191A1A19191B191A1A1919181A191A191A191919191A1919181A191A
1B1A191A1A1A191B1A1A191A1A1A191A1A191A19191A191A1A1A1A1B1A1B181A181C1B19
1B1B1A1A1A1A1A1A1A1A1A1A191A1B1A1B1A1A1A191A1A1B1B1A19191A1B1A1A1A1B1C1A
1A1B1A1B1C1B1B1A1B1B1B1A191B1B1B1B1C1B1C1B1B1A1B1B1B1C1C1A1B1C1C1B1B1B1C
1C1B1B1B1C1C1D1C1C1C1C1C1B1C1C1C1C1C1C1C1B1C1C1C1C1C1C1C1C1E1C1C1C1D1D1C
1B1C1D1C1D1D1D1D1E1B1D1D1D1C1D1D1C1C1D1D1E1C1D1D1D1F1E1D1D1D1C1D1D1D1D1E
1D1E1F1C1D1D1D1D1D1D1E1E1E1D1E1E1F1D1D1E1E1D1C1E1D1D1D1D1E1E1E1E1E1D1F1F
1F1E1E1E1E1F1D1C1D1E1E1D1D1C1E1D1C1D1D1E1E1D1E1E1D1D1D1C1D1E1E1C1E1D1D1C
1E1D1D1E1C1D1E1D1D1C1E1D1E1D1B1D1D1D1D1C1D1C1D1D1E1D1E1D1D1C1C1C1E1D1C1D
1C1C1C1B1C1C1C1D1C1C1C1C1C1C1D1C1C1C1C1C1C1C1C1D1C1C1C1C1C1C1B1B1B1B1B1B
1C1C1C1B1B1C1B1B1C1B1C1C1A1C1B1D1C1C1C1D1C1C1E1D1D1E1E1E1F1E212122232427
2A2D3036393C3C3C3B342E2B2725222220201F1F1E1D1D1C1D1C1B1A1B1B1B1A1B1B1B1B
1A1A1A1A191A191A1A191A1A1A191A191A191A1A191B19191A1919191A1A1A1A1B1B191A
1A1919191A191A191B191A1A19191A1A1A19191A1A1A191A1B1A1919191A1A191A191919
1A19181818191919
191A1A191919191A191A191919191919191A1919191A1A191A1A1A191A1A1A1A1A191A19
19191A1A1A1A191A1A1A1A19191A191A191B191A1A191A191A1A1A1A1A1B181A1A1A1A1A
1A19191A191A1A1A1A1B1A1A1A1A1A1A1B1B1B1A1A1A1B1A1C1A1B1B1A1B1A1B1B1A1B1B
1A191A1B1C1A1B1B1C1B1B1B1B1C1B1B1C1B1C1B1B1B1B1A1B1C1C1B1C1B1C1B1C1B1B1A
1B1B1B1B1B1B1C1B1C1B1B1C1C1B1C1C1C1C1C1B1B1C1D1C1B1D1D1D1C1C1D1B1C1C1E1C
1D1C1D1D1C1E1D1D1C1D1C1E1D1C1E1D1D1C1C1C1D1E1D1D1D1D1E1D1E1D1D1D1E1E1D1C
1D1E1D1E1D1D1D1D1D1E1D1D1E1E1F1E1D1D1D1D1D1D1E1F1D1D1D1D1D1E1E1D1E1C1F1C
1E1E1E1E1E1E1D1E1D1E1D1D1D1D1D1C1D1E1E1E1F1D1D1E1D1D1E1D1D1C1D1E1C1C1D1E
1E1C1D1C1E1F1D1C1E1D1E1C1D1C1E1C1D1D1C1C1C1D1E1D1C1D1C1D1D1C1C1D1D1D1C1C
1C1D1C1C1D1E1C1D1C1C1D1B1B1D1B1B1D1B1C1D1C1C1B1C1B1B1B1B1B1C1D1B1C1C1C1D
1C1B1B1D1B1C1B1D1C1A1C1B1C1D1B1B1C1D1C1C1D1D1C1C1E1E1E1E1E1F212123232527
2B2D3236393F3E3C39342F2C28252322211F201E1E1E1C1C1C1C1D1C1C1C1C1B1B1A1B19
1A1A1A1A1A1A1A1A1A1A191A1A19191A1A1A191A18191A1A1A1A1A19191A1A1A19191A19
191A1A1A19191A1A1A1919191A19191919191A19181A1919191A1A1A1A1B1A1919191A19
1A19181918181919
1919191A1A191A191A1919191819191A19191A1A19191919191A191A191A191A19191A1A
191A1A191A1B19191C1A1A1B191A1A1A1A1A191B1A1A1A1A1A1A1A191A191A1A1A191B19
1A1A1A1C1A191A1A191A1A1B1A1B1A1A1B1B1B1A1A1B1B191A1A1A1B1B1B1B1B1B1B1A1A
1A1B1A1B1B1A1A191C1A1B1C1B1B1C1A1C1C1A1C1B1B1A1C1C1A1B1B1B1B1B1A1B1A1B1C
1B1C1A1B1A1C1C1B1C1D1B1A1B1B1C1C1C1C1D1C1C1C1C1B1D1C1C1D1C1D1C1C1C1C1D1C
1C1C1C1D1D1C1C1D1D1D1C1D1D1C1E1D1B1D1D1D1D1D1E1E1C1E1E1E1D1D1D1E1D1E1D1D
1D1D1E1D1E1E1D1D1D1D1D1D1E1E1E1E1E1E1F1C1E1D1D1C1E1B1D1D1D1E1D1D1D1F1D1E
1D1E1E1E1E1E1F1E1D1E1D1C1D1E1D1D1D1C1E1D1E1E1C1D1E1E1E1D1D1D1D1C1D1C1D1D
1D1D1D1C1E1D1D1D1E1C1D1D1E1E1E1D1F1D1C1D1C1C1C1D1E1B1E1C1D1D1C1C1D1D1D1C
1C1D1D1C1C1C1D1C1C1A1C1C1B1B1C1B1D1D1C1B1C1C1B1C1D1C1B1A191D1C1B1C1B1E1E
1B1B1C1C1C1C1B1B1C1C1C1C1C1D1C1C1C1C1C1B1C1B1C1D1D1F1E1E1F1F202021242627
2A2C3135383B3D3937322D2A2625242220211F1E1E1D1C1D1B1D1A1B1C1D1B1B1B1B1A1B
1A1A191A1B1B191A191A19191B1A19191A1A1A191A1A191A19191A191B1A19191A1A191A
191A1A19191A18191B191818191A1A191A181919191A1A191818191A19181A191A18191A
1A191A191918181A
191818191919181919191A1A191A19191A191919191A1A191A1A1A1A1A181819191B191A
1A1A1A1A1A1A1A181A1A1A191A1A1B191A1A1A19191A1A1A1A1A19191A1A1A1A1A1A1A1B
1A1A19191A1B1B1A1A191A1A1B1B191B1A1A1A1B191B1B1A1B1A1B1B1B1B1B1A191A1C1B
1B1C1B1B1B1A1C1A1B191B1C1A1C1A1A1A1A1A1B191B1C1A1B1D1C1B1B1B1B1B1C1C1B1D
1B1C1C1B1D1D1B1C1C1B1C1C1C1B1C1C1C1C1C1C1C1B1D1C1C1D1D1D1B1C1C1D1C1D1C1C
1C1C1C1C1C1D1D1E1D1D1E1D1D1C1E1D1D1D1D1C1E1C1D1D1D1E1D1D1D1D1E1E1D1D1E1E
1C1C1E1D1D1D1D1D1F1C1D1E1E1E1E1D1D1D1D1E1D1D1E1E1E1E1E1D1E1D1D1D1E1D1E1E
1E1D1E1D1D1E1E1E1E1D1D1D1B1D1D1D1D1D1E1D1D1E1E1D1D1D1D1C1D1E1C1E1C1D1C1D
1C1D1E1D1D1D1D1D1D1C1D1D1E1C1C1D1C1D1D1E1D1D1D1C1D1B1D1D1D1C1C1D1D1D1C1D
1B1C1D1B1C1B1C1C1D1D1D1C1D1D1E1C1D1D1B1C1C1C1C1C1B1C1C1B1B1C1B1B1C1B1C1C
1D1C1A1B1B1B1C1C1C1B1B1B1C1B1C1C1C1D1C1C1D1D1D1E1E1D1E1E1E1F201F20232425
292B2F3236383936322F2B2926242321211F201E1E1D1D1C1C1C1C1C1B1C1B1A1B1A1B1A
1B1B1A191A1A1A1B1A1A19191B1A1A19191A1A191A191A19181819191A191A1A18191A19
1A1A1C1B191A1819191A191A1A191A19191819181919191919181A191A17191A191A1819
19191919191A1919
191819191919191A191A191A1A191A1A1A1B1A1A1A191A1A19191A19191B1A19191A1A1B
1A191A1A191A191A1A1A1A1A1A191A1B1A1A1A1A18191A191A1A1A191A1A1B1A1A1C1A19
1A1A1A1A1A191A1B1B1A1A1B191B1B1A1B1A1B1A1A1B191B1A1A1B1B1A1A1C1A1A1C1C1B
1A1A1B1A1A1A1B1B1A1A1A1B1A1B1C1B1B1A1B1C1B1C1B1B1B1C1B1B1B1B1B1C1C1B1C1C
1C1C1B1B1C1B1C1C1C1B1C1B1B1B1C1C1C1C1B1C1C1C1D1C1B1C1B1D1C1D1D1D1D1C1C1B
1C1C1C1D1D1D1D1D1C1C1D1D1D1C1D1D1E1D1D1D1E1E1D1C1E1D1D1E1C1E1E1C1D1D1D1D
1D1D1C1D1E1D1D1D1C1E1D1D1D1D1D1E1E1E1D1D1E1F1E1E1D1E1D1D1D1E1D1E1C1D1D1D
1F1D1E1D1D1D1F1D1D1C1E1D1D1D1D1F1E1E1E1D1D1D1C1C1E1E1D1D1E1D1D1C1E1C1C1C
1E1D1C1C1D1C1C1D1D1D1E1D1D1D1D1C1E1D1D1D1C1D1D1C1C1D1C1D1C1B1D1B1C1C1C1D
1C1D1D1B1D1B1D1C1C1C1B1C1C1C1B1E1C1D1C1B1C1C1B1B1C1B1B1C1B1C1B1C1B1B1B1C
1C1C1C1C1D1C1A1D1B1B1B1D1B1C1C1B1C1C1D1D1C1D1C1C1D1D1D1E1E1E1F2021222325
27292C2F323332312E2C292724232221201F1E1E1E1D1D1D1D1C1D1C1B1B1A1B1B1B1A1B
1A1A1A1A1A1A1A1A1A1A1A1A1819191A1A191A1A1A1A19191A1A191A19191A1B1A191A1A
1A191A181919181A1A1A191A1A1A1B1A1919191919191A181919191A181A191919191A1A
1918191919191919
1919181A1919191A1A181A181A191919191A191919191A1A19191A19191A191A1A1B1B1A
1A1A1B191B1A1919191A191A1A1A1A1A191B1A1A1A1919191B1B1A191A1A19181A1A1B1B
1A1A1A1A1A1A1A191A1A1A1B19191A1B1B1C191B1A1B191C1B1B1B1A1B1A1A1B1A1B1A1B
1B1B1A1A1C1C1A1A1B1B1B1A1B191A1C1B1B1B1B1B1A1C1C1C1B1B1C1B1C1B1C1C1B1C1B
1C1B1C1C1B1C1B1B1C1B1C1C1C1B1D1C1C1C1D1C1C1C1C1D1B1B1C1C1C1B1C1C1C1C1C1D
1D1D1C1C1D1D1D1C1C1C1C1E1D1D1D1C1E1C1C1D1D1D1D1D1D1D1D1C1D1D1E1D1C1D1E1D
1D1D1E1E1C1D1D1E1E1D1D1D1D1D1E1F1E1C1E1E1E1D1E1E1D1D1D1D1E1D1E1D1E1E1D1E
1C1E1D1E1C1C1D1D1E1E1D1C1D1C1D1C1E1C1C1D1D1D1C1C1D1D1D1C1D1D1D1D1E1D1C1C
1D1D1D1C1C1C1C1B1C1C1C1C1D1D1C1C1D1C1C1E1D1C1C1E1C1E1B1C1D1C1B1C1D1D1D1C
1C1D1C1C1C1C1C1B1B1D1B1B1B1C1D1D1C1C1B1C1D1C1B1B1C1B1C1A1B1C1C1B1C1C1B1D
1D1A1D1C1C1B1A1C1B1C1C1C1B1B1C1B1D1C1C1C1D1D1D1C1C1C1D1E1E1D1E1F21222223
25282A2C2C2D2D2C2B29272624222020201F1F1D1E1D1D1C1C1C1C1B1C1B191B1B1B1A19
191B1B1A1A191A191A1A1A191A1918181A1A1919181A19191A1A1A1A191A191A19181B1B
1B1919191A1A191919191A181A191A1A191A191A191A1A1A181A19191A19191A1A181919
1919181819181919
1A1819191819181A1A19191A1A18191919191A19181A1A191A1B19191A19191B191A191B
191A1A1A191A1A1919191B19191A191A191A1A191A1A19191A1919191A1A1A1A1A191A1A
191A191A1B1A1B1A181A1A171A1A1A1A1B1B1A1A191A1A1A1B1A1A1A1A1A1B1A1B1B1B1B
1A1A1B1C191A1A1B1C1B1B1B1A1B1A1C1A1B1B1A1B1C1B1B1C1B1C1B1C1B1B1C1A1B1C1C
1C1B1B1B1C1B1B1B1C1B1C1C1B1B1A1D1D1C1E1A1B1B1B1C1C1C1C1B1D1C1C1C1D1C1C1D
1C1D1C1B1B1E1C1D1D1C1E1D1D1D1D1C1E1C1E1D1D1D1C1C1C1D1E1D1E1C1C1D1D1E1C1D
1D1C1E1D1D1F201D1C1E1D1E1E1E1D1D1D1D1E1D1D1F1E1D1D1D1D1D1D1C1D1D1C1E1C1C
1C1D1E1D1E1E1C1D1D1D1D1D1D1E1D1C1E1C1C1E1D1D1D1D1D1E1C1D1D1E1F1D1C1D1D1D
1C1E1E1C1C1D1D1C1D1E1C1C1D1D1D1E1C1E1D1E1C1C1C1C1D1B1D1E1C1B1C1C1D1C1C1C
1C1E1D1B1D1D1C1D1B1B1B1B1C1C1D1C1D1B1C1C1B1C1D1B1D1C1D1D1B1B1B1A1C1C1B1C
1B1C1C1B1B1B1B1B1B1B1B1C1C1C1C1C1E1C1C1C1D1C1C1C1B1D1C1D1E1D1E1F20212122
232229272829282827252624232220201F1E1C1D1E1D1C1D1C1B1C1C1B1B1A1A1B1B1A1A
1A1A1A1A191A1A191B1A1A1A191A1A191A1B1B191A191A1A1A191A1919191A1A19191A1B
1A191919191A191819191A1B1A1A1A1918191A19191A1918191919191A1919191A191919
1819181A1918191A
19191819191819191A181919191B1A1A1B1A191A1A1919191A1A1A191919191A191A1B19
191A19191A1A1B1B1A191B191A191A1A1B191819191A1B1A1A1A18191B1A191A191A1A1A
1A191A1A1A1B191A191A1A1B1A1A1A1B1A1B1A1A1A19191A1A1A1A1B1A191A1A1A1A1B1A
1A1B1A1A1B1C1A1B191A1A1A1A1A1A1A1A1B1C1C1B1B1C1B1C1B1A1B1C1C1B1B1B1C1B1C
1B1B1C1C1B1B1C1B1C1B1D1D1B1C1B1C1B1C1C1D1B1A1C1C1B1C1C1B1C1C1B1C1C1D1C1D
1B1B1D1D1C1C1C1C1C1C1C1D1C1D1C1D1D1B1D1C1D1C1D1D1C1D1C1D1D1E1C1C1E1B1D1C
1D1C1D1D1E1D1C1C1D1D1C1D1C1D1D1D1D1E1D1D1C1C1D1C1D1C1D1C1D1E1C1D1D1C1D1D
1D1D1D1D1D1D1C1D1D1D1C1D1E1C1E1D1D1D1D1D1E1D1D1E1D1D1D1D1E1E1D1D1C1E1E1D
1C1C1D1C1D1D1D1D1D1D1D1C1D1D1D1D1D1C1D1C1D1E1D1C1C1C1C1C1B1D1B1C1C1C1C1B
1C1C1C1C1D1D1C1C1C1D1C1C1D1C1C1E1C1D1C1B1B1A1B1C1C1C1B1C1C1D1A1B1D1C1D1B
1C1B1B1B1A1C1B1C1C1B1A1B1B1B1C1C1D1C1D1B1C1C1C1C1C1D1E1C1D1E1D1E1F1F2021
2123242425262524242223212220211E1F1E1E1E1D1D1D1B1B1B1C1B1C1B1A1A1B1B1B1A
1B1C1A191B1A191A191B191A191A1A1A1A19191919191A1A191A1A1A1A1A191A1A1A191A
1A1919191A1A1A1919191A1B191A1A191A1B1A191A1919191A191B1A1A1A19191918191A
191A1819191A1919
19191A1A191919191A191A19191919191A1919191A1A1A1A1A1A1A191B1A191A1A191A1A
18191A1B19181A1A191A1A1A191A191A1A1B1A181B1919191A181A191A1919191B19191A
1B1A191A191B1A1B1B19191A1B1A1A1A1B1A1A1A1B1A1A1A1A1A1B1B1B1A1B1A1A1A1B19
1B1B1A191A1B1B1A1B1B1B1A1A1C1B1B1B1C1B1C1B1A1B1B1B1B1A1B1C191A1B1B1C1A1B
1B1C1B1C1C1C1C1C1C1B1B1C1B1C1C1D1B1C1C1A1C1B1D1C1D1B1B1C1C1B1C1C1C1D1D1C
1C1D1C1E1C1B1C1D1D1C1C1C1C1D1D1D1D1D1B1E1C1C1C1D1D1C1D1E1D1E1B1D1D1C1D1E
1E1E1D1D1C1D1D1D1D1E1E1C1D1D1C1D1E1E1D1E1D1D1E1D1E1D1C1D1E1D1D1E1D1D1C1C
1E1D1D1D1C1D1E1D1C1D1D1D1C1D1D1C1E1D1D1C1D1D1D1E1D1D1E1F1E1D1D1C1D1C1D1D
1C1D1C1D1D1D1D1D1C1D1D1D1D1D1D1C1C1E1C1D1D1B1D1C1D1C1C1D1D1D1D1C1B1C1C1A
1D1C1B1B1C1C1D1C1B1B1D1C1B1E1C1D1C1C1C1B1B1B1B1D1C1B1C1B1C1C1B1C1D1B1C1A
1B1B1B1A1C1B1B1B1C1C1A1C1B1B1B1B1C1C1C1B1B1C1C1C1D1B1D1D1C1C1C1D1F1E201F
2020212222222322221F2221221F1E1E1E1E1E1E1C1C1D1B1C1B1A1C1A1A1B1B1B1B1A1A
1A1B1B1B1A1A1A1A191A1A1A1A1A191A1A1A1A1A1A19191A1A1B1A1A19181B191A18191B
19191919191A1A1A1B1919191A19191919191A1818191A1A19191A19191819181A18191B
1A19181819191819
19181A191819191A1B191A191A1A1A191A191A191A1A191A191A19191A191A191B1B1919
1A19191A1A1A191A191A18181A1A1B181A1A1A191A19191A1A1A1A191A191A1A1A19191A
19191A19181A1A191B1A1A19191B1B191A1B191A1B1B1A1B1A1C1C1A1A1A1A1A1A1A1B1A
1B1B1C1A1B1B1A1C1C1A1A1A1B1A1B1A1B1B1B1C1B1C1B1B1C1B1B1B1A1B1C1B1B1C1B1B
1B1B1B1C191B1C1A1B1C1B1B1D1B1C1D1C1B1C1A1C1C1C1B1B1C1C1C1D1B1B1B1C1B1C1E
1C1D1D1C1C1C1C1B1C1C1D1C1D1D1C1D1D1C1C1D1D1D1C1C1D1D1D1D1C1C1D1D1D1D1D1D
1D1D1B1D1F1B1D1D1F1D1C1D1E1C1D1E1E1D1C1D1E1D1C1C1E1C1D1D1D1D1D1C1C1D1C1D
1C1D1C1D1E1D1C1D1D1D1D1D1C1D1D1C1C1E1C1C1C1E1E1B1D1D1D1C1E1E1C1C1D1B1C1C
1B1D1C1C1D1C1C1C1E1C1C1C1D1D1D1E1D1D1C1D1C1B1D1C1E1D1D1D1C1B1C1D1C1B1C1C
1D1C1B1C1B1C1C1C1C1B1C1C1D1C1E1C1C1B1C1C1B1B1C1B1B1C1C1B1C1C1C1C1B1C1B1A
1B1C1B1B1B1C1B1C1A1C1D1A1A1A1B1B1B1C1B1C1A1B1A1D1C1D1B1C1C1B1D1D1E1D1E1F
1F201F1F1F22201F201F1F201F1D1E1D1E1C1C1D1C1C1C1C1E1B1B1A1C1B1B1C1B1B1B1A
1B1A1A1A1A1B1A1B1A1B1A1A1A1A191A1B1A191A19191A1919191A1A1A1B1B1A1919191A
191918191A191A19191A1A1A191A1A1A1A1A19191A19181819191819191A181919191A19
181A191919181819
1918191919191919191A1A191A191A1A19191A19191A191A191A1A191A1A19191B1A1C1A
1A191A191919191A1B1B191A1919181A1A19191A1A191A181A1919191A1A19191A1A1A19
18191A1B1B1A1B19191A191A1A1A191A1B191A1B1B1A1A1B1A1B1A1A1C191B1B1B1B1A19
1A1B1B1B1A1A1A1A1A1B1A1A1B1B1C1B1B1A1B1A1A1B1B1A1B1B1D1B1A1A1D1B1C1B1A1C
1C1B1C1B1B1C1B1D1C1B1B1B1C1B1B1B1C1B1C1C1B1C1C1E1B1C1C1C1C1C1C1C1C1C1C1D
1C1D1C1C1D1C1C1D1C1C1D1C1B1C1B1C1D1D1C1C1C1D1D1E1D1D1C1D1D1D1E1D1C1D1D1D
1D1C1D1C1D1C1C1C1D1E1D1D1D1E1D1B1E1C1C1C1D1D1D1E1D1B1D1C1C1D1E1E1D1E1D1D
1D1D1C1C1D1D1D1C1D1C1C1C1C1D1D1D1C1D1D1D1D1C1D1D1D1C1E1D1E1C1D1D1D1E1D1C
1D1D1C1B1D1C1C1B1C1D1C1B1D1C1C1C1C1D1D1C1D1C1D1C1C1C1D1D1D1C1C1D1C1C1C1C
1C1D1B1C1C1C1C1C1C1B1C1A1B1C1C1C1B1A1B1A1B1B1B1C1C1B1B1B1B1B1B1C1B1B1C1A
1B1C1A1D1C1B1C1C1B1B1B1B1B1B1C1D1B1A1C1D1B1B1D1C1C1B1B1C1C1D1C1D1D1C1E1F
1F1F1F1E1F1E1F1D1F1F1F201F1E1D1E1E1C1D1E1C1D1B1D1D1C1C1B1B1B1A1A1B1B1A1B
1A181B1B1A1A1A1B1B191B1B1A1A1A1A1A1A1A1A1A1919191A19191B1819191A1A191A19
191A1A18191919191B1A191A191A191A1A191819181A1B19181A1918181A1A1819191818
1819181919181818
1919191A19191B1A191A18191B1A1A1A1A1A191A1919191A1A191A1B1A1A1B1A1A191A1A
191A1A1A1A1A191A191B19191A1919191A1A1A1A191A191A19191A1A1A1919191A1A1A1A
191A1A1A18191A1A1A191A1A1B1A1A1B191B191A191A1A1A1B1A1B1B1A1B1B1B1A1B1A1A
1B1C1B1B1A1A1A1B1B1B1A1B1A1A1B1B1B1A1B1A1B1B1A1B1C1B1A1C1B1B1C1B1B1B1B1B
1B1C1C1C1B1A1C1A1B1B1B1D1C1B1B1D1B1D1C1C1D1C1C1C1C1B1C1C1C1B1D1B1B1D1C1D
1D1C1E1B1C1B1C1C1C1D1C1B1C1D1B1D1C1C1D1D1D1C1D1D1D1D1D1C1D1E1D1C1C1B1C1C
1B1D1C1E1D1E1B1D1C1E1D1D1D1D1D1D1C1D1D1D1C1D1D1D1D1B1D1C1D1D1E1E1D1D1B1B
1E1D1D1C1D1B1D1D1D1C1C1C1C1E1C1D1C1B1D1D1D1D1E1C1C1D1E1D1D1D1D1D1D1C1C1B
1C1C1D1B1C1C1C1D1C1C1C1C1D1B1C1D1B1C1C1C1C1B1D1C1D1C1C1D1D1C1C1D1D1C1C1D
1C1C1D1C1B1C1C1D1B1B1C1B1C1C1B1C1B1C1B1D1B1C1C1D1B1C1D1C1B1C1A1A1B1B1C1B
1B1B1B1C1B1C1B1B1A1B1B1B1C1C1B1B1A1B1C1C1C1C1C1B1C1C1C1C1C1C1D1B1D1D1E1C
1D1F1E1F1E1E1F1E1F1D1E1E1D1E1C1E1D1E1C1B1C1A1C1B1B191C1C1B1B1C1A1A1A1A1C
1A1A1A1B1B1A1A1A1A1A1A1A191A1A1A19191A1A1A19191A19191A1A1A19191A1A19191A
1A1919191919191A191A1A1A1A191A1819191818191A191918181919191A19191A191A1A
19191918181A1918
19191919191919191A1A1B1B1919191A1A191B191A1A1A191A191A191B1A1A1A1A1B1A1A
191A1A191A1A191A1A1A1A19191A1918191A191A19191A1A19181A1A1A1A1A1A1A1A1A1A
1A191A1A1B1A1A1A1A191A1A1A191A1A1A1A1A1B1B1A191A1A1A1A1A1A1A1A1A1B1B1B1B
1A1B1B1B1A1B1A1A1A1B1B1A1A1B1B1C1B1A1B1A1B1B1A1B1A1A1B1B1B1C1B1B1B1A1B1A
1A1C1B1C1B1B1A1B1B1C1C1C1B1B1C1B1D1C1B1B1D1C1C1B1C1C1D1C1C1D1C1C1D1D1C1C
1C1D1E1B1B1C1C1B1C1C1C1C1B1E1C1C1D1D1C1D1D1D1C1C1D1E1D1C1C1C1C1C1C1C1D1C
1E1D1D1C1D1D1C1D1D1B1C1C1D1D1D1C1E1D1D1E1C1C1D1D1D1C1B1D1D1C1D1D1C1C1C1C
1B1C1D1D1D1C1D1C1E1D1C1E1B1D1C1D1D1D1C1C1A1B1C1D1D1D1E1D1F1C1C1D1C1C1C1D
1B1C1C1C1E1C1D1C1B1C1B1C1B1D1C1C1C1B1C1B1B1C1D1D1C1C1C1C1D1D1C1C1D1C1C1C
1D1B1B1C1A1C1B1C1B1C1B1C1C1B1B1B1B1C1A1C1B1B1C1C1B1C1A1B1A1B1C1A1B1C1B1B
1B1A1B1B1B1C1B1B1A1B1B1B1B1C1C1B1C1A1B1D1B1B1C1C1B1B1C1B1B1C1C1C1D1D1D1C
1D1E1D1D1F1D1D1D1C1B1D1D1D1D1B1C1B1C1D1B1A1C1C1C1B1B1A1B1B1C1C1B1B1B1A1B
1B1B1A19191A1B1B19191A19191A1A1B1A1A1A1A191A191A1A1A1A191A19191A191A1919
191B1A1918191A19181B191A1A1719191A1819191A18181919181A19191A1819191A1918
191A1A1919191819
19191818191A1A191A1A1A1A191B1919191A191A191A19191A1A1A1A1A1A1A1A1A1B1A1B
1A18191A1A181A1A1B191A191919191A191A1A1A19191A1A191A1A191A1A1919191A1A1A
1A1A1A1A1A1A1B191A1B1B191A1A1A1A1B1A1B1B1A1A1B1A1A1A1B1A1B191B1B1A191C1B
1C1A1A1B1B1B1A1B1A1B1B1A1B1B1B1B1B1B1A1A1A1C1A1A1B1C1B1C1B1A1B1C1B1B1C1B
1A1B1B1B1D1B1B1C1B1B1C1B1C1B1B1B1C1C1B1C1B1B1C1C1C1C1C1C1B1B1B1C1D1C1C1C
1D1C1C1C1C1D1E1C1C1C1C1C1C1D1C1C1C1C1C1B1C1D1C1D1D1C1D1D1D1D1C1D1D1C1E1C
1D1D1D1C1C1C1C1D1D1C1C1C1E1C1E1C1D1C1D1D1C1C1D1D1D1D1C1C1D1C1C1E1C1E1E1D
1C1C1D1C1D1C1C1C1C1C1D1D1D1D1D1D1C1D1C1D1D1D1C1C1C1E1E1C1D1D1E1C1D1C1C1C
1C1D1D1C1C1D1E1D1D1D1C1D1B1C1C1B1B1C1D1E1C1D1B1D1C1C1C1C1D1E1C1C1C1C1B1D
1C1B1D1D1C1B1C1C1C1C1C1B1B1B1B1C1B1C1B1B1C1C1A1A1B1B1B1D1B1B1B1B191C1B1B
1A1B1C1B1A1A1A1C1D1B1B1C1B1C1B1B1B1B1B1A1C1B1B1D1B1B1B1C1C1C1B1C1C1B1C1C
1C1C1D1C1E1D1D1C1C1D1D1E1C1C1B1C1C1C1B1C1C1A1C1A1A1B1A1A1C1A1B191B1A1C1A
1B1B1B1B1B1B1A1A1A1A1A1A191A1A1A1A1A191A1A1A1A191A1B1A191A1B191918191A1A
1A1A191819191A1919191A1918181A18191818191819181819191919181A1919191A1918
1919191A19181A1A
1A18191A19191B1A1A19191B19191A1A1A1A191819191A19191B1A191A1A1A1A1B1A1A19
1B1A1A191A181A19191919191919181A181A1A19181A191918191A1B1A181A1A19191A1B
191919191B19191A191B1B1A1A1A1A191919191B1A1A1A1A1A1B1B1A1C191A191A1B1B1B
1A1A1B191A1B1919191B1A1A1B1B1C1B1C1C1A1A1A1B1B1B1A1A1B1B1A1C1A1B1C1B1B1C
1C1C1C1B1A1B1A1C1C1B1B1B1C1C1D1C1C1C1B1B1B1B1B1C1D1B1D1B1D1C1B1B1B1D1D1C
1C1C1C1C1C1D1B1C1C1C1D1C1C1D1D1B1C1D1C1D1B1D1D1D1E1C1D1C1D1C1D1E1D1C1B1D
1D1C1C1B1D1B1D1D1C1C1C1D1C1B1D1C1C1C1C1D1C1C1D1C1C1B1C1D1D1C1C1D1C1C1C1C
1C1C1D1D1C1B1C1E1C1D1D1C1B1B1E1C1D1C1E1D1C1D1C1C1C1C1D1C1C1D1D1C1C1D1C1C
1C1C1D1C1D1D1C1B1B1D1C1D1D1C1C1C1C1D1B1C1C1D1C1D1C1C1C1C1E1C1C1D1C1D1C1D
1C1D1D1D1C1C1C1C1B1C1C1C1B1B1D1B1B1B1B1A1B1B1A1A1A1C1B1A1B1C1B1B1B1B1B1B
1B1B1B1B1A1A1C1B1B1A1B1B1C1A1A1A1B1B1C1B1B1A1D1B1A1C1A1B1C1C1B1B1C1B1D1D
1C1B1C1D1D1D1E1C1B1D1C1C1C1C1D1C1B1B1B1C1B1B1C1A1C1B1C1A1B1B1B1B1B1C1A1B
1B1A1A1B1B1B1A1B1A1B1A1A1A1A191A1A1A191A191B1A1B191A19191A1A1A1A181A191A
1919191A1A1A1A1A191A1919191A1819191919191918191819181919181A181A1A181919
1819191A19181818
1A181A191A1A1A191A191A191A1A1919191919191A19191A1A1919181919191A1A19191A
191A1A1A191919191A191A1A1819191919191A191A1A191A181A191A191A19191B1A1918
191A1A1A19191A1A191B1B1A1A1A1A1A1B191B1B19191A1A1B191A1B1B1A1B1A191B1A1A
191B1A1A1B1B1A1A1A1A1B1A1A1A1B1B1A1B1B1A1B1A1B1A1B1B1C1B1A1A1C1A1B1B1A1B
1B1B1B1B1B1C1B1B1C1B1C1C1B1C1B1B1B1C1B1C1B1B1D1B1C1A1C1B1A1C1C1B1C1C1C1C
1C1D1C1B1D1D1C1D1D1D1C1B1C1B1D1D1D1C1C1C1B1C1E1E1C1C1C1C1B1D1C1D1C1C1C1B
1E1C1C1D1D1D1C1D1D1D1C1D1C1D1B1B1C1C1E1C1D1C1C1D1D1C1D1B1C1D1B1E1E1C1D1C
1B1C1C1C1D1C1C1D1C1C1D1C1B1C1D1E1C1D1C1D1C1C1D1C1D1C1D1E1D1E1B1E1B1A1C1C
1D1C1C1E1C1C1C1D1C1C1B1D1C1C1C1D1C1C1C1C1D1C1C1C1C1E1C1E1C1D1C1D1D1C1D1D
1B1B1C1D1C1C1C1B1A1B1C1B1B1B1A1C1A1C1B1C1B1B1B1C1C1B1A1A1A1B1B1B1B1C1B1A
1B1B1B1B1B1A1B1B1A1C1C1B1B1A1B1C1C1A1C1A1C1A1B1A1B1B1C1C1B1B1A1D1D1B1C1C
1C1D1C1C1D1C1C1C1C1D1C1B1A1D1B1B1B1B1B191B1B1B1A1A1B1B1C1B1B1B1B1B1C1B1C
1A1B1A191B1A1A1A1A1A1A1B1A191A1A181A1A1A1A1A19181A181A1A19191A19191A1819
19191A1A1A19191A191A1A191B18191719191918191918191A1A1918181918181919191A
19181B181A19191A
191919191A181A1B191919181A1919181A1A1A191A191918181A19181A19191919191A1A
191B18181A1A1919191A19191A1A191917191A1A191B191918191A1A1A1B1A1A1A1A1A1A
1A19191A1A1A1A1A1A1A1B1B1A191A1A1B1A1B1B1A1A1A1A1B1A1A191A191B191A1A1B1A
1A1B1A1A1B1A1A1B1C1A1B191A1A1B1A1A1B1B1B1A1B1B1A1A1A1A1B191A1A1C1B1B1C1C
1A1B1B1B1B1B1B1B1A1C1B1B1C1D1B1B1B1C1C1A1B1B1B1B1C1C1C1C1C1C1B1C1B1C1C1C
1C1C1C1D1C1C1C1C1D1B1C1C1A1C1C1B1C1C1C1C1E1B1C1C1B1D1D1D1C1C1B1D1D1D1C1C
1C1C1E1C1D1C1C1C1D1D1C1D1D1C1E1D1E1C1C1D1D1D1D1C1D1C1C1C1C1B1D1C1C1C1D1C
1C1D1C1C1D1C1E1C1C1D1C1C1C1D1C1C1C1C1D1C1C1B1C1C1C1A1D1D1C1C1D1C1C1B1D1C
1C1B1B1C1C1D1C1D1D1D1C1D1E1C1C1D1B1D1C1C1B1C1C1C1A1D1C1D1B1C1D1C1D1D1D1C
1B1C1C1B1C1C1B1E1C1A1B1B1B1C1B1C1C1B1C1B1C1B1C1B1B1B1B1C1B1C1A1C1B1B1A1B
1B1B1B1B1C1B1C1B1B1B1B1A1B1B1A1C1A1C1A1A1B1B1A1B1C1B1B1B1A1B1B1B1C1C1B1C
1D1B1B1C1B1C1B1C1C1C1C1C1D1C1C1B1B1B1B1B1B1C1B1A1A1A1A1B1A1A1A1A1B1B1A1A
1B1B1B1A1B1B1A1A191A1A1B191A1A19191A1A1B1B191B1A18191A1A1B1A1A1919191919
191A1A1A191918191C191A1A1A19191A1A191918191819191A1919181919181818191919
19191A1A18191919
18191919191B1818191A1A1A1A191A19191A19191A1A191A1918191A1A191A19191A1A1A
19191A19191A1B191A191A191A1A191A1919181A1919191A19191A1B191A191A1A1A1919
1A1A1A191B1A19191B19191A19191A191A191B191A1A191A1B1A181A1A1B191A1A1A1B1A
1B191A1A1A1B1A1A1B1C1B1B1B1A1B1A1A1B1A1B1A1B1B1A1B1C1C1B1B1B1A1B1B1A1A1B
191C1B1B191B1B1A1B1A1C1C1B1C1B1B1B1C1B1B1A1A1B1D1C1C1C1B1C1C1B1B1C1C1C1C
1D1C1C1C1B1C1C1B1B1C1C1C1D1B1C1B1C1C1D1C1D1D1D1C1D1C1E1D1D1E1B1B1D1C1C1D
1D1B1C1D1D1D1C1E1C1C1C1C1C1C1C1D1C1C1C1C1D1C1C1C1C1C1C1D1C1B1D1C1C1D1C1E
1B1E1C1C1C1C1C1C1C1C1C1B1C1C1D1C1B1C1D1C1C1C1C1C1B1C1D1C1D1C1C1B1C1D1D1B
1C1D1D1C1B1D1B1C1D1C1C1C1E1D1C1D1B1C1C1B1C1B1B1C1C1B1B1C1B1D1D1C1C1D1D1E
1C1C1B1B1D1C1B1C1C1C1B1C1B1C1B1C1B1A1C1B1C1B1A1B1B1A1C1B1B1C1B1A1B1A1B1B
1A1C1A1C1A1B1B1B1B1C191C191C1C1B1B1C1A1A1B1B1B1B1B1B1A1B1B1B191B1B1B1C1A
1C1C1C1D1B1A1C1B1C1B1B1B1B1B1B1A1A1B1A1A1B1A1B1B1A1A1B1A1B1B1B1A1B1B1A1A
1A1B1A1A1A1B1A1B191A1A1A1A1A1A1B1A1B191B19191A191A1A191918191A191A191A19
1B191919181A1A1A191A1A1919191B19191A18181919181818181919191919191A18181A
191A19191919181A
1A191919191A191A19181A19191919191B1A19191A1A1A19191A191A19191A191A19191A
191A1919191A1919191A1A1A1A191A1A191A191A191A1A19191A1919191A1A1A1A191919
1A1A19191A1B1A1A191B1A1A1B191A1A1A191A1A19191A1A1A181A191A1A191A1A1A1B1B
1B1A1A191A1A1B1A1B1B1A191A1A1C1A191B191A1B1B1B1A1B1C1A1B1A1B1B1A1B1B1A1A
1C1B1B1A1B1A1B1B1B1B1B1C1B1B1C1C1B1B1B1B1A1A1A1C1C1B1C1C1C1C1C191D1B1B1C
1D1C1C1D1C1D1C1B1C1B1B1B1B1C1C1C1D1C1B1D1C1B1C1C1C1D1D1C1C1D1C1C1C1D1C1D
1B1D1C1C1E1C1D1C1C1C1C1C1C1C1C1D1C1B1D1C1C1D1C1C1D1C1C1E1C1C1D1C1D1D1C1C
1C1C1D1C1C1B1D1D1C1C1C1C1C1B1C1B1C1C1B1D1D1D1B1D1D1B1C1C1C1C1C1C1D1D1B1B
1C1D1D1C1C1C1B1B1C1B1C1B1C1B1C1C1D1C1C1C1C1C1B1C1C1C1C1C1D1B1C1D1C1C1E1D
1C1D1D1D1C1D1C1D1B1C1B1B1B1D1D1C1C1B1A1C1D1C1A1B1B1C1B1A1B1C1A1B1B1A1A1B
1B1A1B1C1B1B1B1A1C1A1B1A1B1B1B1B1B1B1B1A1B1B1B1B1B1C1A1B1C1B1D1C1B1A1A1B
1B1B1B1C1C1C1C1A1B1C1B1B1B1C1B1A1B1C1B1B1B1B1B1B1B1B1C1A1A1B1B1B1A1B1B1B
191B1A1A1B1A191A1A1B1A1A1A191A1B1B1A1A19191A191A1A191A191A1B191918191A1A
1A1A1A191919191A1A191919191819191919191819181A19181819181A1919181819181A
1919191919181819
191819191B18191A191A191919191919191A1A1A1A181A19191A19191A191B1A191A181A
1A191B191A1A1A1A1B191819191919191A1A19191A1A1B191B1A191919191B1A191A1A1A
1A1A1A1919191A1A1A191A1A1A1B1A1A1A1B1A1A1A1B1B191A19191A1A1A191A1A1B1B1A
1A1A1A1A1B191B1A1B1B1B1B1B1A1B1A1A1B1A1A1A1A1B1B1B1B1B1B1B1B1A1B1B1B1B1A
1A1B1B1B1A1A1A1C1A1B1B1B1A1B1B1B1C1C1B1B1B1C1C1B1C1A1A1C1C1B1C1C1D1D1B1C
1D1B1B1C1D1C1C1C1C1C1B1C1C1C1B1C1E1D1C1D1C1C1C1D1C1D1D1B1C1D1D1C1D1B1B1C
1D1D1C1B1C1B1C1D1D1C1D1B1C1C1C1C1C1D1B1C1C1B1D1D1C1B1E1D1C1D1B1C1D1B1C1C
1C1C1B1B1C1C1C1B1C1C1B1C1C1C1C1C1C1C1C1B1C1C1C1D1C1B1B1D1C1C1D1E1C1B1C1C
1C1B1C1C1C1C1C1C1C1B1B1C1B1C1B1C1C1C1C1C1C1D1C1C1D1B1B1D1B1D1C1C1C1E1D1E
1E1D1E1E1E1D1E1D1C1C1C1C1C1B1B1A1B1A1D1B1B1D1C1B1C1A1B1B1A1C1A1B1C1A1A1B
1B1A1A1B1B1A1A1A1B1B1B1A1B1C1A1B1B1B1C1B1B1C1B1B1A191A1B1A1A1A1A1A1C1B1B
1B1B1C1C1B1A1A1C1A1A191C1B1B1A1B1A1A1A1B1B1A1A1A1A1C1A1B1A1B1A1A181B1B19
1A1A1A1B1B1A1A1A1B1A1B1A1A19191A1A1A191B191A19191A1A1B1A1B1A191A1A191919
1A191B181A1B1A1918191B191A19181A1A191818191918181A19191A181919191A1B1919
191A191818191718
191819191A1A19191A191B191819181A1B191A191A19191A19191919181918191918191A
191A191918191A1A19191A1919191A1919191918191917191A1A1A19191A1A1A181A1A1A
1A1B191A191A1A1A191A19191A1A1A191B191B191B1A1A1A1A1A191B191B1A1A1A1B1A1A
191A1B1B1B1A1B1C1A1B1B1A1B1B191A1A1B1B1A1B191A1B1A1A1B1A1B181B1D1B1C1B1C
1A1A1A1A1B1B1B1A1B1B1B1B1B1C1C1C1C1D1B1B1C1B1A1B1C1C1C1C1C1C1C1C1C1D1D1D
1B1B1B1C1B1C1D1B1B1D1D1C1C1B1C1C1C1C1E1D1B1C1C1D1D1E1D1C1C1B1B1D1D1B1D1C
1C1C1C1C1D1C1C1D1C1C1B1C1C1C1D1D1B1C1B1B1C1C1B1C1D1D1C1B1C1D1D1D1C1D1C1B
1D1B1C1C1B1C1C1D1C1D1C1C1B1B1B1D1C1C1D1C1C1B1C1B1C1C1C1C1D1C1D1B1C1B1D1A
1B1C1B1C1C1C1B1C1B1B1B1A1C1C1C1C1C1B1C1C1C1C1B1C1C1D1B1C1C1D1C1D1C1D1E1E
1E1E1E21211F1E1E1C1C1C1D1B1A1B1B1A1B1B1C1B1B1B1C1C1C1A1B1C1A1B1B1B1B1C1A
1C1B1B1B1B1B1B1A1B1A1B1A1B1A1B191B1A1B1B1B1A1C1A1A1A1B1A1C1B1A1A1B1B1A1A
1C1C1B1B1B1C1B1B1B1A1B1B1A1B191C1B1C1B1A1A1A191A1B191B1B1A1A1A1B1B1A1B1A
1B1A1B1B1B1A1A19191B1A191A1A1A1A191A1A1A1A1A1B1B1A1B1A1A1B1A191A18191A1A
1919191A181A191919191819191A191819191918191A19191819191A1919191919181A19
191A191917181818
1819181918191919191A191919181A1A191A191A1A191A191819191A191A1B191A191A19
1A1A1A191A191A191818191A191A1919191918191919191A1A1A1A19191919191B191A1B
1A19191A1A1A1A1A1A1A1B191A191A1A191B1A191A1A1A1A1A1A1A1A1A1A1B1B1A1B1A1A
191B1A1A1A1A1A1B1A1A1B1B1A1C1A1B1A1B1C1B1C1A1B1A1B1A1B1B1B1A1B1A1B1B1B1B
1B1A1B1B1C1B1A1B1B1C1B1B1B1A1B1A1C1B1B1B1B1B1C1B1C1C1C1B1B1C1C1B1C1C1C1B
1B1B1C1C1D1C1D1C1C1B1D1C1C1C1B1C1C1B1B1B1C1B1C1C1D1D1C1D1C1C1D1C1D1D1C1C
1C1C1C1D1D1D1C1C1D1C1C1B1D1C1E1C1C1B1D1B1B1C1D1C1D1C1B1C1E1C1C1C1D1B1D1D
1C1C1C1C1D1C1C1D1B1B1C1C1C1B1D1C1C1D1C1D1E1C1C1B1D1C1C1B1C1B1C1C1D1B1C1B
1A1C1D1A1B1C1D1B1C1C1B1B1A1C1D1B1C1C1C1C1C1A1C1B1C1B1C1C1C1B1B1D1D1D1C1F
202122242322211E1E1C1C1B1B1C1B1B1D1C1B1B1B1B1B1B1B1B1A1A1A1A1B191B1A1B1B
1B1B1C1A1A1A1B1A1C1C1A1B1B1A1B1B1A1B1A1A1C1B1A1B1C1B1B1B1B1B1B1A1B1A1C1C
1B1A1B1A1B1C1B191A1B191C191B1B191B1B1A1A1A1B1A1A1A1A1B1B1B1A1A1A1A1A1919
1B1B1A1B1C1A1A1A1A1A18191A1B1A1A191A1B1A191B1A19191A1A1A1A1A1A1A1A191A1A
18191A1A19191A1A19191B191A1A1A18191A181A191818191918181919191A1919191819
191918191918191A
19191A191819191A19191A1A1A1818191A191A1919181A19191A1A1919191A1918191A19
181A191919181A19191919191A1919191819191919181B19191A1919191A1A1A1A1A1919
1A1A19191919191A191B1A1A1A191B19191A1A191A191B191A1A1A1A1A1A191A191A1C19
1B1B1A1B1A1A1B1B1B1B1A1A1B1A1A1A1A1B1B1C1B1A1C1A1A1B1B1A1B1B1C1C1B1A191B
1B1B1A1B191B1C1B1B1B1C1B1B1A1C1B191B1B1B1B1B1B1A1A1B1C1B1B1B1C1C1C1B1B1C
1D1C1C1B1C1C1C1C1D1D1B1B1C1D1B1C1C1B1D1D1C1B1C1D1C1B1C1D1D1B1D1C1C1D1C1D
1B1D1D1D1D1C1C1C1C1D1D1C1C1C1C1C1C1C1C1C1B1C1B1D1C1C1D1D1B1D1B1D1B1C1C1C
1C1C1C1C1C1C1C1C1C1C1C1C1C1D1D1D1C1C1D1C1C1B1B1B1D1B1D1C1D1B1C1C1D1B1C1C
1A1C1B1C1C1D1C1B1B1C1C1C1D1C1C1C1B1C1D1C1C1B1B1B1B1C1C1B1C1C1C1D1D1E1F20
21242528282725201E1E1B1C1B1B1B1C1C1B1C1C1C1A1C1C1A1A1A1B1C1A1B1A1C1B1C1A
1B1B1B1B1C1C1B1A1A1A1B1B1B1B1B1A1A1B1B1B1A1A1B1B1B1B1A1A1B1A1B1B1A1A1B1B
1B1A1B1B1A1A1A1A1B1A1A1A1A191A1A1A1B1A1A1B1A1B1A191A1A1A1A1A1B191B1B191A
191B1B1A1A1A1A1A191B1B1B1A1A1A1A1A1B1B1A1A1A1A1A1A191A191A1A1A191B191919
19191A1A181A191A19191A1919191A1918191A1A19191919171919191918181919191A18
1818181819181719
1919181919191A1A18191A19181919181A19191A1A1919191A191A181A1A19191A1A191A
1919191919191A18191919191A19181A19191A1B1A1A191A19191A1A1A1A1A191A181918
1B1B191A191A191B1A191A1A1A1A1B1B181919191B1B191A191B1A1A191A1A191B1A1A1B
1A1A191B1B1A1B1A1B1A1A1B1B1A1B1B1A1B1B1B1A1A1B1A191B191B1B1B1B1B1B1B1A1B
1B1A1B1B1B1B1A1B1B1B1B1B1A1C1B1B1A1A1B1B1C1B1C1B1C1B1B1C1B1C1B1B1C1C1C1B
1B1D1C1B1C1C1B1C1A1D1C1C1C1C1D1B1C1B1C1C1B1C1D1D1B1D1D1D1A1C1C1D1C1C1D1D
1C1C1C1C1C1B1B1C1C1C1D1D1C1C1D1E1B1C1D1D1B1C1C1D1D1C1E1D1C1C1C1C1B1B1C1B
1C1B1C1C1B1C1C1D1B1C1C1C1B1C1C1C1C1C1C1C1C1C1C1B1C1D1C1B1C1C1C1C1A1B1C1C
1C1C1D1C1B1D1C1B1C1C1B1C1C1C1C1B1B1C1C1B1C1B1B1C1C1B1C1D1C1C1C1E1D1E2021
24272B2D2F2B27221E1C1C1A1C1B1B1A1B1B1A1C1A1B1C1B1B1C1B1C1B1A1A1B1A1C1A1A
1B1A1A1B1B1B1C1B1A1B1B1B1A1A1B1B1A1A1A1B1A1A191B1B1B1A191B1C1A1A1A1B1B1B
1B1A1B1B1B1A1A191A1B1A19181A1A1A1A1A1A1A191B1B1A1B1B1A1B1B1B1A1A1B1A1A19
1A1A1B1B1A1A1B1A1B19191C1A1A1A1B1A191A1A1B1A1A1B1A191B1A1B191B1B1919191A
191A1B1A191918191A1A181A1A191B1919191A19191819191919191818191919181A1719
19191A1918191818
191919181919191A1A19191A18191A1819191A191919191A1818191A1A191A1918191819
1A1A191A181A19191919181919181918191A1B1A1A1819191A19191B191819191A1A1B19
191A1A1B19191A1A191A19181A1A19191A1A19191A1A1B191B1A1A191B1A1A191A1B1919
1B1A1A1B1A191A1A1A1A1A1B1B1B1A1C1C1B1C1A191B1B1B1A1C1A1A1B1B1C1B1C1B1B1C
1B1C1B1A1A1B1B1B1A1B1B1B1C1C1A1B1C1B1B1B1B1B1B1B1B1B1B1B1B1C1C1B1B1C1B1B
1C1C1C1C1C1C1C1D1C1C1C1B1B1C1B1C1B1C1C1C1C1B1C1D1C1C1B1C1D1C1C1D1C1D1D1D
1C1C1C1C1C1C1C1C1D1D1C1D1C1C1D1C1B1C1C1C1D1C1B1B1D1D1D1C1D1C1C1D1C1B1C1C
1C1B1C1C1C1C1B1A1C1B1B1D1C1C1C1B1B1C1C1C1C1C1C1C1B1B1D1E1C1C1E1C1B1C1B1C
1B1B1B1D1C1D1C1C1C1D1C1C1D1D1C1C1B1D1B1D1C1E1B1B1C1C1C1D1C1D1C1D1D1E1F23
2A2E3235312E29231F1D1C1C1C1B1B1C1B1C1B1B1C1B1B1A1B1B1C1A1B1A1B191A1B1A1B
1B1A1A1A1A1A1B1B1B1B1B1B1B1A1B1B1B1A1A1A1B1B1B1B1A1A1A1B1A1A1B1C1B1B1A19
1B1A1B1B1A1B19191A1A1B1A1A1A1B1A1A1A1A1A1A1B19191A1A191A1A1A1A1A1A1A1A1B
1A1A1B191A1A1A1A1A191A1A1A1A191B1A191A191A1A1B191A1B1B1B1B1A1A1A1A1A1919
1919191919191A1A1A191A191A1919191719191818191919181919191919191A191A1818
1A191A1917191919
19181919191919191A1A191A1919191A1A1A1919191A191A1A19191A19191A1819191B1A
1B191A1A19191A191918181919191819191B1A191A191919181A1A1919191A191919191A
19191A1B1A1A19191A1A1A1A191A191B181A1A1A19191B191B1B19191B1B1A191B1A1B1C
1B1A1B1A1A1B1A1A1A1A1B1A1A1A1A1A1A191B1A1B1B1B1A1C1B1B1B1A1A1B1A1B1C1B1B
1B1A1A1B1A1B1A1B1A1A1B1A1A1B1B1B1B1B1D1B1C1B1B1A1B1C1B1D1C1C1C1C1B1B1B1B
1C1B1B1B1C1C1B1C1C1C1C1C1D1D1C1B1D1C1A1B1C1C1C1C1C1C1C1B1C1C1C1C1B1D1D1D
1C1C1C1B1D1C1B1C1B1D1C1E1B1D1C1D1C1C1C1B1B1C1D1C1D1C1C1D1B1C1C1B1C1C1B1C
1C1A1B1C1C1D1C1B1C1B1C1C1B1A1B1B1B1D1C1C1C1C1B1C1C1D1D1C1B1C1B1C1B1B1C1C
1B1C1C1C1C1C1D1B1C1C1C1D1C1C1C1C1C1B1C1C1C1D1A1C1D1B1B1C1C1C1D1D1F202225
2D323639332D27231F1D1B1C1B1B1D1C1C1B1B1C1C1A1C1B1B1A1B1A1A1A1B1B1B1B191B
1B1B1B1B191A1B1C1B1B1B1B1B1B1B1A1A1C1B1A1C1B1B1B1B1A1A1A1B1A1A1A1A1C1A1B
1B1B1B1A1A1A19191B1B1A1A1A1A191B1A1A191A19191A1A1B1A1A1A1919191A1B1B1A1A
1A19191A1B181A1A1B1A191B1A1B1A1A1A1A1A1A191A1A1B1B1C191A1A1A1A191A191A19
1B1A19191A1919191919191A191A1918191A18191918191919191A181817191919181918
19191A1918191917
191918191A19191A191A1A191A1A19191A1A1A19191A1B191A18191A19181918181A1918
181918191A1A191918191A1A19191A191A1918191919191A19191A1A1919191A191A191A
191919181A1A1A1A1919191A1A191A1A19191A191A1A1A1A19191A1A1A1A1A1A1C1B1C1B
1A1B1A1B1A1A1A1A1B1B191B1A1B1B1A1B1A1B1A1B1B1C1B1A1B1A1C1A1C1C1C1B1A1B1B
1B1B1A1A1B1B1B1B1B1B1A1A1B1A1B1A1B1B1B1B1B1B1B1B1B1B1C1C1C1B1B1C1C1B1B1B
1D1C1D1C1C1C1A1B1C1D1D1E1C1D1C1C1C1C1B1C1C1B1D1C1B1B1B1C1C1B1B1C1B1C1C1C
1C1A1C1D1C1C1E1D1D1D1C1D1C1D1B1D1D1E1A1B1C1C1B1C1B1D1D1B1B1D1C1D1C1C1D1A
1C1B1B1D1D1D1D1D1C1C1C1C1C1B1C1C1D1C1C1B1B1D1A1C1B1B1C1B1C1C1C1C1D1C1B1B
1B1C1C1D1B1B1C1C1C1C1C1C1B1B1C1B1B1C1B1B1A1C1B1A1D1B1B1C1C1D1C1D1F1F2327
2E363939352C25201D1D1B1B1B1B1B1C1B1B1A1C1C1C1B1C1B1B1A1B1B1B191A1B1A1C1B
1A1A1A1A1B1A1B1A191B1A1A1A1B1B1B1C1A1A1B1B1B1A1B1C1A1B1A19191B1A1A1A1B1B
191B1B1A1A191B1A1919191B191A1B1A1A1A1B1B1A1A1A19191A181A1A1A191A1A1A1C1A
19191B1A191A1A1A1A1A1A1B1A1B191B1919191A1A1B191C1A1B1A1A1A1B1A1B1A191A1A
191A191A1B18191A19191B1A1819191A1A19191819181919191818181919181819191919
1819191918171718
1919191A1919191A1A1A181919191A191A191A191A1A1919191919191A191A1A19191918
1A19191919181919191A191A191A19191B191A191A1B1A1919191A1A191A1918181A191A
1A19191B1A1A19191A19191A1A1A191B1A191A1B191A1A191A19191B1A1A1A1A1B1A1A19
1B1A1B1B1B1A1A1B1B1B1A1A1B1A191A1A1A1B1C1B1B1A1A1A191B1B1B1A1B1B1B1B1B1B
191B1B1B1B1C1B1B1B1B1B1B1A1C1C1C1A1B1C1A1A1C1B1B1C1B1B1C1C1C1C1B1B1C1C1C
1C1C1B1C1C1B1C1C1D1B1D1C1C1B1C1B1C1B1A1D1D1C1B1B1B1D1C1D1C1D1C1C1B1C1D1C
1C1B1B1C1D1C1C1C1B1C1C1B1D1C1C1B1C1C1C1C1B1C1C1A1D1D1C1C1C1C1E1C1D1C1B1C
1B1B1C1C1D1B1B1C1B1B1C1B1B1C1C1C1C1B1C1C1B1D1B1D1C1C1C1C1D1C1B1C1C1C1B1C
1B1B1B1B1C1B1C1C1B1D1B1D1C1D1B1C1B1B1B1C1C1C1C1D1C1C1C1C1C1C1D1E1E202227
2E363938302822201D1C1D1C1B1C1B1B1B1B1A1B1A1C1A1A1A1B1A1B1B1A1C1A1B1B1A1B
1A1A1A1A1A1B1A1C1A1B1B1B1A1A1A1B1A1B1B1B1B1B1B1A1B1A1B1B1C1C1C1B191A1A19
1B1A1B1A1A1A1A1A1B1A1A1A1B1A1A191B191B1B191A191A1A1A1A19191A1A1A1A1B1A1A
1A1B1A1C191A191A1B1A1B1B191A1A1A1A1A1A1B1B1A1B1C1C1B1A1B191A1A1A1A191B1A
191A19191B1A191A1A191A1A1A19191A181A1919191A1A191918181918181A1918191919
19181A1919191817
1A1919181919191A1A171A19191919181818191919191B1B1A1A191A19191A1819191919
191A1A1A1918191A1A191A18181819191A1919191919181A1A191A191A191A1919191A19
191A1B19191A1A191A191A1A1A19191A191B19191A1A1A1A1A191A1B1A1B191A19191A1A
1A1A1A1A191B191A1A191A1C1A1A1B1A1B1B1A1B1A191B1B1A1A1A1C191A1A1B1B1B1B1C
1C1A1C1B1A1A1A1B1C1B1B1B1C1C1B1A1B1C1B1B1A1B1C1B1C1B1C1B1D1C1B1C1B1B1B1C
1C1C1C1E1C1B1C1B1C1D1B1C1D1C1C1A1C1C1B1C1C1B1B1D1C1B1B1D1B1C1C1D1C1C1B1B
1C1C1C1D1B1C1C1C1D1D1D1C1C1E1C1C1C1C1D1C1B1C1C1C1C1B1C1B1B1C1C1B1D1C1C1D
1C1B1B1B1B1C1B1C1C1D1C1C1C1C1C1B1C1C1C1B1B1C1C1D1B1B1C1C1B1B1D1C1D1C1C1B
1C1B1B1B1C1B1B1C1C1B1C1D1B1C1B1A1B1A1B1B1C1B1B1C1C1D1C1C1D1C1D1D1C202327
2C3032302A24211E1D1C1C1C1B1C1A1B1A191B1B1A1A1A1B1A1B1A1A1A1A1B1A1A1B191B
1B1B1A191A1A1B1B1C1A1A1C1B1A1A1A1A1B1A1B1A1B1B1B191B1B1A1A1A1A1A1A1A1B19
191A1A191A1A1A1A1A1A1A1B1A19191B1A1B1A1A191A1A1A1A1B1A19191A191A1A1A1B1A
1A1A1B1B1A1A1A1A181A1B191A191A1A1A1A191B191C1B1B1A1B1C1B1C1B191A1A1B1B1A
1919191A191B1A19191A1A191A1A18191A191A1A191A191A181A1A1A1919191918191A1A
1818191819171818
1918181818191A19191A191A19191919191B1A19191A1A1A1A1A1919191A191A181A1919
191819191918181A1A191919191A191A191A1A1A191919191A1A191819181A1A1A1A1919
191A1A191918191A191A1A191A1A191A1A1B1A1919191B1A1B1A191A1B1A1B1A191A1A1A
1B1A1A1A1B1B1A1A1B1A191B1B1B1B1B1C1B1B1A1B1B1C1A1C1A1B1A1B1B1A1A1A1A1B1A
1A1B1A1A1B1B1B1C1B1B1A1B1B1C181C1B1A1B1B1B1C1A1A1B1B1B1B1C1B1B1B1B1A1C1B
1B1B1B1A1B1C1C1B1B1C1C1B1C1B1B1C1B1B1C1C1C1C1D1C1D1C1C1B1C1C1C1C1B1D1C1D
1C1B1A1D1D1B1D1C1C1B1D1D1B1C1C1C1C1E1C1D1C1C1A1C1C1C1C1C1D1B1B1B1C1D1B1B
1B1C1B1B1B1C1C1B1B1C1B1D1C1B1B1B1C1B1C1C1B1B1C1B1B1C1B1C1B1B1B1C1B1A1C1C
1D1B1C1B1C1B1C1A1B1C1C1B1B1A1B1B1C1C1C1C1A1B1B1C1C1C1C1D1B1B1C1C1E1F2025
292A2B2A23211E1C1D1D1C1A1A1B1A1A1A1C1C1B1B191B1B1B1A1B1B1C1B1A1A1A1A1A1B
1B1A191A1B1A1B1A1B1A1A1B1B1C191A1A1B1A191A1A1C1B191A1A1A1B1A1B1B1A1A1A1A
1B191B1A1919181A1A191A1A191B1A191A1A1A1A1B1A191A1A1919191B1A191A1A191A19
191B1A1A1A1B191A19191A1A1A1A1B1A1B191A1A1B19191B1C191A1A1B1C1A1A1B1B1B1A
1A1A1C1B1A1A1819191A1A1919191B19191A18191A191919181919191817171819181919
1918191918191918
191919191A19181A1A19181A191919191918191A1A1A1919191A1A1A19191817191A1918
1A1918191A191A1819191919191918191A191A191918191A1B1B191A18181919181A1A1A
191A1A1B181A191A18191B191A19191A1A191A1A1A191A191A1A1A1A191A1A1B191B1A1B
1A191A1A1A1A1A1B1A1A1B1A1B1B1B1B1A1A1A1B1A1C1B1B1A191A1B1B1A1B1B1B191B19
1A1A1A1B1A1A1B1A1B1B1C1C1B1B1B1D1B1B1B1B1B1B1B1C1B1B1C1B1C1B1B1C1B1C1C1C
1B1B1C1B1B1A1B1C1C1B1D1C1B1C1D1C1C1B1A1B1C1C1B1B1C1C1C1C1C1D1C1B1C1B1C1B
1B1C1C1C1B1C1C1C1C1C1C1B1C1B1C1C1D1C1C1B1B1C1C1C1C1B1B1B1C1C1C1C1B1C1D1C
1D1C1C1B1B1B1C1B1B1B1C1C1C1B1C1C1B1B1A1C1C1C1C1C1C1C1C1B1B1B1C1B1B1C1C1B
1C1B1C1C1C1C1C1C1A1B1C1C1A1A1C1B1B1C1A1C1B1C1C1C1D1D1A1C1B1C1C1C1E1F2024
25252522211F1E1C1D1B1B1C1C1B1B1B1B1B1B1B1A1B1B1C1B1B1A1C1B1B1A1B1A1A1A1B
1B1A1A1A1A1B1B1B1A1A1A1A1B1C1C1A1B1A1A1B1A1A1A1A191A1A1A1A1A1A191A1B1A1B
1C1A1B1A1A1A1A1A1B191A1919191A1A1918191A1A1A191A1A19191A19191B191A19191A
1A1A1A1A1A1A1B191A1A1A1C1A19191A1B1A1B1A1B1B1B1A1C1B1B1A1C1A1B1C1A191B1A
1A1A191A1A1A1A1A191B191A1A1A191A1A1A19191819181919191818181919181A191818
1819181817181719
191A191A1A191918181A191A19191A19191A181A191B1919191919191A191A181A1A191A
191B191A1A1A19181A191B1A191A1A18191A1A191A1A1919191A181919191919191B181A
1A181A19191A19191A1A1919191919191A19191B1B1A1A1B1A1A19191B191A1A1A1A1A1A
1B1B1A1A1B1B1B191A1A1A1A1A1A1B1B1B1B1A1B1A1B1A191B1C1B1A191C1B1A1B1B1A1B
1A1A1A1A1B1A1C1B1A1C1B1A1B1C1A1A1C1B1B1A1B1A1B1B1A1B1B1A1B1D1B1B1B1C1C1C
1B1B1B1C1B1C1B1D1D1A1C1B1A1B1C1A1B1D1C1B1C1B1C1C1C1D1D1C1C1C1D1D1C1B1B1D
1C1B1D1B1E1C1D1D1C1C1C1B1B1C1B1B1C1C1A1D1A1D1D1C1D1B1C1C1C1D1C1C1C1C1C1C
1C1B1C1B1B1B1D1D1C1C1B1B1C1B1C1D1B1B1B1C1B1C1C1C1D1B1C1C1C1D1C1B1C1B1B1C
1B1C1B1B1D1B1B1B1B1B1B1B1C1B1B1B1B1B1B1B1C1B1B1A1C1D1B1C1D1B1C1D1D1C201F
212221201F1E1C1B1B1B1B1A1B1B1A1B1B1A1B1B1B1B1A1B1A1A1A191B1B1A1B1A1B1B1A
1B1A191B1A1B191A1C1B1A1A1B1B1A1A181A1A1A1A1919181A1A1A1A1A1B1A1A191B1B1A
1A191A1A191B191A1A1A1A1A191A191A1A1B1B1A1A181C1A1A1A191A1A19191B1B1A1A19
1A1B1A1A1A191A191A1A191B191B1B1A1B1B1A1A1A191B1A1A1C1C1C1B1C1C1A1C1A1A1A
1B1B1A1A1A1A1A1A1A191A1A1918181918191918181819191A191918191A191919191918
1819191918171918
1919191A191A19191919191A19191B191A1919191A191A1A19181A191A191A191A1A1919
1919181A1A1919191A1A191A1A191A1A191918181819191A19181918191919191B19181A
19181A1A191B181A191A191B19191A1A1A1A1A1A1A1A191A1A191A1B1A1A1A1B1A1A1A1A
1B1A1A1A191B1B1A1A1A1B1A1A1B1B1A1B1B1A1A1B1B1B1A1A191A1A1B1C1C1B1A1B1A1B
1A1B1A1A1B1B1B1B1A1B1A1C1B1A1A1A1B1B1B1B1B1C1B1B1B1C1A1B1B1B1B1B1C1B1B1C
1B1B1B1C1A1C1D1D1C1C1D1B1B1B1C1B1C1D1B1B1B1C1D1C1B1C1D1C1D1C1D1D1B1B1B1C
1B1A1C1B1D1C1C1D1C1C1D1B1C1B1C1B1D1B1B1B1C1C1C1C1C1C1C1C1C1B1C1C1C1B1D1D
1B1B1B1C1B1B1B1B1C1B1D1C1C1D1C1C1B1A1B1B1C1C1B1C1B1B1B1C1B1C1B1C1B1B1B1D
1B1A1C1B1B1B1A1B1B1A1B1C1B1A1C1B1B1A1D1B1B1B1C1C1C1B1C1B1C1C1B1C1B1D1D1D
1E1E1E1F1E1D1C1D1B1B1B1B1B1A1A1C1B1B191A1B1B1A1A1B1B1C1B1B1A1C1A1A1A191A
1B1A1B1A1A1A1A1A1C1A1A1B1B1B1A1B1A1B1B191A1A1A1A1B19191A1A1A1B1A1B1B1C1A
1A1A1A1A191A1A19191A1A1A1A181A1B19191B1A1A1B1A1A191A1B191A191A1A1A191A1A
1B1A1A1A1A191A191A1A1A1B1A1A1A1B19191A1A1A1A1B1A1A1B1A1B1B1B1C1B1C1B1B1A
191B191A1A191A1A1B1A1A1819191A1919191A191A191819181919191819191A19181918
1919181918181818
19181A191819191A1919191A1918191A1A1B1B1B181A191919191B1A191A181919181919
1A1919181A1B181A191818191A181A191918191A1919191919191A1A191A1A1A191A1918
1A1A19191B1A1A191A1B191A1A1A19191A1A1A191A1A191A1A1A1B1A19191A1B1A1A1A1A
1A1B191A1B1A1B1B1B1A1A1B1A1A1C1B191B1B1A1B1A1A1B1B1B1B1B1B1A191A1B1B1A1A
1B1B1B1B1A1B1C1B1B1B1B1B1A1A1B1B1C1B1A1A1B1B1B1B1C1B1C1B1D1B1A1C1C1B1C1B
1C1A1A1B1C1A1C1C1B1C1C1C1B1B1A1B1A1D1B1C1C1B1B1B1C1A1C1D1B1C1C1B1B1B1B1C
1C1C1E1D1D1B1C1D1D1C1C1C1B1B1B1B1C1B1C1B1C1C1C1C1D1C1D1C1C1C1D1B1C1B1B1B
1C1B1C1C1C1C1B1C1D1C1C1D1C1B1D1C1B1B1C1C1B1C1B1B1C1B1B1B1B1B1B1C1D1A1B1C
1C1C1B1B1B1B1C1B1C1B1B1A1C1B1A1B1B1B1B1B1C1B1B1B1B1C1B1C1B1C1C1C1B1C1D1D
1D1C1D1C1C1B1B1B1B1C1A1B1B1A1B1A1B1B1A1B1C1A1A1A1C1B191B191A1A1A1B1A1A1A
1A1B1B1A1A1B1B1A1B1B1B1B1A1B1C191A1B1A191A1A1B1A1C1A19191B191A1A1A1B1B19
1A1B1A1B1A1A19191A191A191A1A19191B1B18191A1A1A191A1A1A1A191A1A191A18191B
1A191A1A1B1A1A1B1A191A1A191A1B1A1A1A1B1A1A1B1A1C1A1C1B1A1D1D1C1D1C1B1A1C
1A1B1A1B19191A1A1B1919191A19191A18191819191818191A19191918191A181918181A
1919171818181818
1918191919191819191A19191918191A1A1918191A181B1819191A19191A191A1A1A1919
1818191819191819191B1A191A1919191919181A19191A1A191919191A19191A1A19191A
1A1A1A1A18191A19191919191A1A19191A1A1A1A1A1B1A191A191A1A1A19191A191A181A
1A1B191A1A191B1B1A191A19191A1B191B1A1A191B191A1B1A1B1B1A1B1C1B1B1B191A1B
1A1C1B1C1B1A1B1A191A191B1A1A1A1B1A1B1B1B1A1B1B1D1B1C1B1B1C1C1A1C1B1B1B1B
1A1C1B1B1A1C1B1C1B1C1C1B1B1D1B1C1D1B1A1B1B1C1C1C1B1C1B1D1B1B1D1C1C1B1C1A
1B1C1B1C1B1D1B1C1B1D1B1C1C1A1C1C1B1C1C1C1D1B1A1C1D1C1B1C1D1D1B1B1B1C1C1C
1B1A1A1C1C1C1C1C1B1D1C1C1B1C1C1B1C1B1A1B1B1B1B1C1B1C1B1C1C1C1C1B1C1B1A1C
1A1C1B1A1C1C1A1A1A1A1C1C1C1A1C1B1B1C1B1B1B1B1B1B1B1C1B1C1C1C1C1C1C1A1D1B
1C1C1C1C1B1C1B1B1C1C1A1A1B1B1B1B1B1B1A1A1B1C191B1A1B1B1A1B1B1A1A1A1A1B1A
1A1C1A1A1B191A1A1B1A1A1A191A1A1A1A1A1A1A1A1A1B191B1A1A1A1A181A1A1A1B1B19
191A1A191A1A1A1A19191A1A19191A1A1A191919191A1A1B19191A1A1A1A1B191919191A
1B1B19191B1A1A1A1A1A1B18191B1B1B1B1A1A1A1A1A1B1A1B1D1C1B1C1D1C1D1B1C1B1B
1B1A1A1A1A1A1A1C1A191A1A19181A19191A19191919191919191A181919191918181A18
181819191919191A
1919191818181919191A1A1819191A1B1A191A1A1A1919191B1A18181919191A1819181A
1A1A191A191A18191A191A1918181919191A19191A191A191919191A1A191A1A181A1B1A
1A191A19191A191A191B19191A18191A191A191A1A1A19191A1A1A1B1A1A1A191A191919
1A1A1A1A1A1A1A1A1A1A1B1B191B1A1B1A1B1A1A191A1A1B1B1A1A1B1B1B1B1A1C1B1B1A
1B1B1A1A1B1A1A1B1A1A191B1B1A1B1B1C1A19191B1B1B1C1C1B1C1B1B1B1A1B1B1A1B1B
1B1C1B1B1C1B1A1C1B1A1C1B1C1B1C1A1B1B1C1A1B1B1C1C1C1C1C1C1B1B1C1A1B1B1C1B
1C1E1B1D1B1B1C1C1C1C1C1D1B1C1C1B1C1B1C1D1D1C1C1C1C1D1C1C1C1B1C1B1B1C1C1B
1A1C1B1B1B1C1C1B1D1C1D1C1C1B1B1C1D1B1C1A1D1B1C1C1B1C1B1B1C1B1B1C1B1B1C1D
1B1B1B1B1C1B1C1C1C1C1C1B1A1C1B1B1C1A1C1B1B1C1C1B1B1B1B1B1B1B1A1A1B1D1B1C
1C1C1C1C1A1C1C1B1B1B1B1C1A1B1B1B1B1B1A1B1A1B1B181A1B1A1A1B1A1B1A1A1B191A
1B1B1B1B1A191B1A1A1A191A1A1A1A1B1A1A1A1A1A1B191A1A1A1A1A1A1A1B1B1A1A1A19
1A1A1B191A19191919191919191B1A191A1A1A1B1A1A1A1B1A1A1A1A1A1A1A191A191A19
1A1C1A191A1A1A1A1919191A191A1B1A1A1A1A1B1A1B1C1C1D1B1C1B1C1B1A1D1B1A1C1A
1C1B1B1A1B1A1A18191A191A1A1A1A1918191A181A1819191A191A1A1B18181A19181919
18191819171A1819
1A191918191819191819191918191919191918181919191A191919191A1A1A1819181A1A
181A1919191A19181919191819191A1919191A1A19191A1A18181A19191A181819191A1A
191A1A1A191B181A191A1A1A1A191A191A1A1A191A1A1B1A191A19191A1A191B1A1B1A1A
1B1A1A1A1B1A1B191A1A1A191B1A191A19191B1C1A1A191A1A1A1A1B1B1B1B1B1B1B1C1B
1A1A191B1A1B1B1B1B1B1A1A1C1B1B1B1B1B1A1A1B1C1B1A1C1C1B1B1B1C1A1C1C1C1A1B
1B1B1B1B1B1B1C1A1B1C1A1B1C1B1C1B1B1B1C1B1B1B1B1B1C1B1A1C1C1D1B1B1B1B1C1C
1B1C1B1C1C1E1C1C1D1C1B1B1B1C1C1B1C1C1D1C1C1D1D1D1C1C1C1C1C1C1A1D1B1B1B1B
1B1C1B1C1B1B1D1B1B1C1C1C1C1C1B1C1B1D1B1B1B1C1B1B1C1B1B1B1A1B1C1B1C1C1B1C
1B1B1B1A1B1D1B1A1B191B1C1C1C1C1B1B1B1B1A1B1C1C1C1A1A1B1B1B191A1B1A1A1B1B
1B1A191B1A1A1C1B191B1A1B1B1A1B1A1A1C1A1A1A1B1A19191B1A1A1A1A1A1A1A1C1A1B
1B1A1A1A1A1A191A1A1A191A1A1B1A1A191A1A1A191A19191B1A1B1B1B1A1B1A191A1B1A
1A1A1A191A191A1919191A1B1A191B1A1A1A1A1B1B18191A1B1B1B19191A1A191A19191A
1B191A1A1A191A1A1A1A1A1A191A191A1A1A1A191A1B1A1A1B1C1C1B1C1D1C1D1C1C1E1C
1B1C1B1B1A1A1A191A1A1B191919191A191A19191A191A19191A191A191A191819191919
1919191819181819
1918191818181919181A19191A1A1A1A1A1919191A19191A18191918191A191919191919
19191A19191919191919191A1A191918181A191918191918181A1819191A191A1919191A
191919191919191A1A19191A191A1A1A1A1B19181A191A1A181A1A1A1A1A1A191A1A1A1A
1A1A1A1A1A191A1A1A1B1A1A1B1A1A1A1B1B1B1B1B1B1A1A1A1C1B1A1B1B1A1B1C1C1A1A
1B1A1A1C1A1B1B1B1B1C1C1B1C1A1C1C1C1A1A1C1B1B1B1A1A1B1C1B1B1B1B1C1B1B1A1C
1B1B1C1B1A1C1B1B1B1B1B1C1C1B1B1B1B1C1B1B1C1C1B1B1B1C1C1C1C1C1B1C1B1B1B1A
1A1C1B1D1B1A1C1B1C1B1C1C1C1C1D1C1C1C1D1C1C1D1D1C1C1C1B1C1B1B1B1C1C1A1A1C
1C1C1A1C1B1B1B1B1C1B1C1B1C1B1C1B1A1B1C1D1B1B1B1C1B1C1C1A1A1B1C1B1A1C1B1B
1A1B1C1C1C1B1C191B1A1B1C1B1C1B1A1B1C1A1B1C1C1B1C1B1B1C1C1B1D1A1B1B1A1A1B
1B1B1A1A1A1C1C1B1A1A1B1C1B1B1A1A1A1A1B1B1B1A1B1B1A1A1A1B1A1A1B191A1A191B
1B1B1B191A1A1A191A1A1A1A1A1A1A1A191A1A181A1B1B1A1A1B1A1A1A1B19191A1A1B1B
1A191A19181A19191A18191817191A1A1A1919191A1919191B1A1A191A1A1B19191A191B
19181919191A1B1A191A1A1A1A1A1A1A1B1A1A1A1B1B1B1B1B1D1B1B1C1C1D1C1C1D1C1C
1C1C1B1B1A1B1A1B1A1A1A1A1A18181B19191919191919181A19181A1A191A1919181919
1918191918191719
191919191818181918191A191919191A181919191A19191B191A191919191B1819191818
191A1A1919191A191918191919191A1919191919191818191919191A19191A191A1A1A1A
1919191A1A19181A191A18191A1A1A1A191A1A1B1B191A191A1A1A1A191B1A1A1B1B1A1B
1B1A1B191A1A1B1A1A1A1A1A1A1A191A1B1A1A1A1A1A1A1A1A191C1A1A1A1B1B1B1A191A
1B1A1B1A191B191B1C1A1B1B1B1C1B1B1A1C1B1B1C1B1A1C1B1A1B1B1B1B1B1B1A1B1C1B
1C1C1B1C1B1B1B1B1B1B1A1B1B1C1B1C1A1C1C1C1C1C1B1B1B1C1D1B1E1C1B1B1C1B1A1C
1B1C1C1B1B1C1B1C1C1B1C1B1A1B1D1C1C1D1C1C1B1D1B1C1C1B1B1B1B1B1C1B1C1A1C1A
1B1B1C1B1B1D1B1B1B1C1B1C1C1B1B1C1B1C1C1C1C1B1C1B1C1C1D1B1B1B1A1A1C1B1A1C
1A1B1B1B1B1C1A1B1B1B1A191B1A1B1B1C1B1C1C1A1B1B1B1C1B191B1B1A1B1B1B1A1B1A
191A1A1A1B1B1B1A1A1B1A1C1A1C1B1A1A1A1A1B1A1A1A1A191A1B1A1B1B1B1A1B191B1B
1A1B1A1B1A1A1B1A1B1A1A1919191A1B1A1A191A1C19191B1B191B1A1A191B191A1A1919
1A19191A1A1A191A1A1A19191A1A191A181A191919191B1A1B1A191B1B1A1918191A1A1A
1A1A191A1A1A1A191919191919191B1B1B1B1B1B1B1A1C1C1C1C1D1B1B1C1D1E1C1D1D1D
1B1C1A1B1B1C1A1A1A1A1B1A1A1A18191A1A1A18191919181919191919181A191A181A19
18191A1819171819
1A1A181A1819191919181919191719191A1819191A1A1A19191A18191A1919191A191918
181819191A1919191919191918191919191A19191A1A19191A1918191919191919181919
181A191A1A1A1A1A1919191919191B1A1B191A1A1A1A1A191A1A191A1C191A1A1B1A1A1A
1A1C1A1A1A1A1A1A191B1A1A1A1A1A1B1B191B1B1A1B1B1B1A1C1A1A1B1C1B1A1A1B1B1B
191B1A1A1A1A1B191B1C1A1A1C1A1C1A1C1D1C1B1A1C1C1B1C1A1B1B1B1B1B1A1B1B1B1B
1A1A191C1B1B1A1B1B191B1B1B1A1C1C1B1B1C1B1C1C1A1B1B1B1C1B1B1A1B1B1C1A1B1D
1A1A1B1B1A1B1D1A1C1C1C1A1B1C1B1D1C1C1C1C1C1C1B1C1B1D1B1B1B1C1C1C1B1B1C1C
1C1B1C1A1B1C1C1B1B1B1C1B1B1B1C1B1B1C1B1C1B1B1B1C1C1C1C1B1C1B1B1C1B1A1B1B
1A1B1B1B1A1C1C1B1B1A1A1B1B1C1C1B1C1B1A1C1B1B1C1C1C1C1C1C191B1B1A191B1B1A
1B1A1B1B1A1B1B1A191A1B1B1B1B1B1A1A1A1A1B1A1B1A1A1A1A1A1B1A1A191B1A1A1B19
1A1A1B1B1B1A1A1B1A1B1A1A1A1A1A1A191919191A1A191B1B191B19191A1A191A1A1B1A
1A19191A191A1B19191A1A1A19191A1A1A1A191A1A19191A1B1A19191B1A1A1A1A181919
191A1A181A1919191919191A1B1A1B1A1A1B1B1B1A1B1D1D1B1B1D1C1D1E1E1D1C1C1C1D
1D1C1C1C1B1B1B1B1A1B181A19191A19191A1A17191919181919181A1A191A1819191819
1818191919191718
191819181A1919191919191819181919181A1919191919191A191A1A1A19191918191918
191A191919191A18181A191818191819191A181A18191A19191718191919191A191A191A
1A19181A1A1A1A1919191B1A191A191A1B191A1A1A1918191A1A1A1A1919191A1B1A1B1B
1A1A191A1B19191A1B1B1A1A1A1B1A1C1B1A1B1B1A1B1A1A1A1B1A1A1A1A1B1B1B1B1B1B
1B1B1A1A1B1B1C191B1B1B1B1B1B1B1A1A1A1B1C1B1A1B1B1A1A1C1B1B1C1B1B1A1A1C1C
1C1B1B1B1B1B1A1B1C1B1B1A1C1B1B1A1B1B1B1A1A1A1B1C1C1B1A1C1C1B1C1B1B1B1B1B
1B1C1B1B1C1B1B1B1B1B1B1B1A1B1B1B1A1B1B1C1B1C1B1B1B1C1C1A1C1A1C1C1A1B1C1B
1B1C1B1A1B1A1B1B1C1C1B1A1B1A1B1C1B1B1C1A1B1B1A1B1B1C1C1A1C1B1C1A1B1A1A1A
1B1B1A1B1B1B1A1B1A1B1A1B1A1C1B1C1B1B1B1A1B1C1A1B1A1C1A1B1C1A1B1C1B1B1A1A
1A1A1B1A1B1A1C1C1B1A1A1B1A1A1B1A1A1A1B191B191A1A1A1A1A1B1B1A1A1A1A1B191A
1A1A1B1A1A1B1A1A191A1A1A1A1A1A1A1A1A1A1B191A1919181A191B191A19191A1B191A
1B191A1A181B191A19191A191919191918191919191B191B1B191A1A1B1B19191A181A1A
191A191A19191A1919191A1B191A1B1A1A1A1B1A1C1B1B1B1B1B1C1C1D1E1E1D1D1D1E1E
1E1E1D1D1C1B1B1C191A1A181B1A1A1A181A1919191A1A19181A191A1A1A191919191A19
1919191819191817
19181818191819191A1A19191A19191919191A1A1A1A1919171A19191919191A18191A19
18191819181A1919181A1A191A1A19191A1A1A19181A191A18181919191A191A191A191A
191A191A191A1A1A19191A1A1A191A191A1A1B191A1A191B191A1A1A1A1A1A1A1A1B1B1A
1B1A191A1B1B1B1B1A191A1A1B1B1A1A1A1B1B1B1C1B1A191B1A1B1B191B1A1A1B1A1B1B
1C1B1A1A1A1A191B1B1B1B1A1B1C1C1B1B1A1B1A1C1B1B1B1A1A1B1B1B191C1C1B1B1B1B
1C191B1B1B1A1B1B1C1B1B1B1B1C1A1C1C1A1B1C1A1C1B1C1A1A1B1A1C1C1B1C1A1B1C1B
1A1C1C1B1B1A1B1A1C1C1C1B1C1B1C1B1C1C1C1B1B1A1C1A1C1A1B1B1B1C1B1C1A1B1C1C
1B1B1B1B1B1C1B1B1C1B1A1C1B1B1B1B1C1C1A1B191B1B1B1C1B1C1B1B1B1B1A1A1A1C1B
1B1A1B1A1B1B1C1A1A1B1C1B1B1A1C1B1B1C1A1B1B1C1B1B1C1C1B1A1B1A1C1B1C1C1A1B
191A1A1A1C1A1A191B1A1A1A1B1B1B1A1B1A1B1A1B1A1A1A19191A1A1A1B1A1B1919191A
1A1A1A1B1B191A1A1B1B1B181B1A191A191A19191A181A19191A1A1A19191A1A1918191A
19191A1A1A1919191A1A1A191A18191A191A1A1A1B1A1C1A1B1A1A1A1A19191A1A1A191A
1A1B1819191A1A1A1A19191A191A191A1A1B1A1A1A1B1B1B1D1C1D1C1E1E1C1E1D1E1E1C
1E1F1D1E1E1C1D1B1C1A1A1A1A1A1A1919181A191A181A1918191A1B1A1A1A1819181919
1917181918181918
1A1A1A1919191A1A191A181918191A191A191A191A19181919191918181818191A191918
191819191A181B19191819191919191919191A191A1919191819191919181A1919191A1A
181819191A1918181A191919191A191A19191A191A1A1A19191919191B1A1A1A1A1A1A19
1B1A191A1A1A1A1A1A1B1A1A1A1B1B1B1A1A1B1B1A1B1B1C1C191A1A1B1A1A1B1B1A1A1A
1B1A1B1B1A1B1B1A1A1A1A1A1C1A1B1B1B1B1B1D1C1A1A1B1C1C1B1A1A1A1B1C1A1A1B1A
1B1C1A1D1B1A1B1C1C1C1B1B1B1C1A1A1C1B1B1B1C1C1C1B1C1C1B1B1B1B1C1B1A1A1C1B
1B1B1B1A1B1C1D1B1B1B1C1B1C1B1B1B1B1B1A1B1A1D1C1B1C1C1D1B1B1C1C1C1B1A1C1A
1D1B1B1B1B1B1B1B1A1C1B1A1C1B1B1B1B1A1A1B1B1C1B1B1B1B1C1A1A1A1B1C1A1B1B1A
1B1A1C1B1C1C1B1C1A1C1C1C1B1C1B1C1A1C1C1B1B1B1B1B1B1A1B1A1B1C1B1B1C1B1A1A
1A1A1B1B1A1A1B1A1A1B1A1B1A1A1A1A1A1B1A1A1B1A191A1A1A1B191B1B1A1B19191A1A
1B1A191A191B1A1A1A191A1B1C191A1919191A1A1A1A191A191A191A1A1A1B1A1A1A1A1A
1A1A191719191919191A1A19191A1A1918191A1A191A191B1A1A1A191A1A191919181A19
19191A19191A191A181A1A19191A1A1A191A1B1B1B1C1C1C1B1D1B1D1D1D1F1D1F1F211E
201F1F1F1D1C1C1B1C1B1B1A191B1B191A191A1918191919181818181919181919191919
17191A1A19191819
1A1918191919181A1918191919191919191918181A18191919181A181919191A1A1A1819
18191A181819191919191919191919191A1919191919181A1A181A191A1B19191919191A
191A1A19191A191A191819191A19181A1A1B1B191A1A191A1A1A1A1A1A1A1A1C201B1C1B
1A19191A19191A1A1A1C1A1A1A191B1A1A1A1B1A1A1B1A191A1B1A1B1A1A1B1B1A1B1B1A
1A1B1A1A1A1A1A1B1B1A1A1A1B1A1A1C1A1B1B1B1C1C1A1A1A1C1C1B191B1A1B1B1A1A1B
1B1B1B191A1B1B1A1B1A1B1B1A1B1B1B1B1A1C1B1B1B1B1B1B1C1B1B1A1A1C1C1C1C1C1A
1B1B1A1B1B1C1A1B1B1C1C1A1B1B1C1B1C1A1B1C1C1B1B1B1B1B1C1C1C1D1B1C1A1B1B1B
1C1B1A1B1D1B1B1B1B1B1B1C1B1D1D1C1B1B1A1C1B1A1B1A1B1C1A1B1A1B1A1B1B1C1B1C
1C1B1A1B1B1A1A1B1B1C1C1B1B1C1B1B1B1B1A1C1B1C1B1B1A1B1B1A1B1B1B1A1A1B1A1B
1A1A1A1C1A1B1B1A1B1B1B1A1A1A1A191A1C1B1B1B1A1A191A1B191A191A1A191A1B1A1B
1A1A1A1A1A1A191A1A1B1A1A1A1A1A191A191A191A191A1A1A1A1A1B191B1A1A1A1A1A1A
1A1A19181919191B19191919191A18181A19191A1A1B1B1A1A181B1A191A191A19181818
1819191818191919191A181A181A1A1A1B1B1B1B1C1B1B1C1C1D1C1D1D1D1E2020202021
2220211F1F1F1E1D1C1B1B1B1C1B1B1919191A17181919191A1919191A1918181A181818
1919191918191819
191919191A1A1918191919191A19191A191818181A18181A191A191919191919181A1919
191819191918191919181819191919191B191A1A1919191A19181918191919191A191A19
191B191A191A1A1A19191B18191A1A19191919191A1A1A1919191A1A1A1A1A1C1F1A1B1A
1A1B1B1A1B1A1A1A1A1A1B191A191A1A1A1A1A1B1B1C1B19191A1A191B1A191A1C1B1A1A
1B1B191B1B1A1A1A1B1B1C1B1B1A1B1A1B1B1C1B1B1C1B1C1B1C1B1A1B1B1A1A1A1B1A1B
1A1B1B1B1A1A1B1A1A1A1C1C1B1C1B1B1A1C1C1B1C1C1B1C1B1B1A1A1B1C1B1B1B1B1B1C
1B1B1B1B1A1C1B1B1B1C1B1A1B1C1B1C1A1B1B1C1B1A1B1A1C1B1B1C1C1A1B1B1B1B1B1C
1B1A1A1C1B1B1B1C1B1C1C1D1C1C1E1C1C1B1C1B1C1C1C1B1B1B1B1B1B1A1B1C1B1B1B1B
191A1B1B191A1C1B1B1A1B1C1A191B1C1A1C1B1A1B1A1B1C1C1B1B1B1A1A1C1B1A1A191A
1A1B1B191B1A1B1B1A1A1A1B1A1A1B1A191A1A1B191C1A1B1A1A1A1A1A1A1A1A1A1A1B1A
1A1B1A191B191A1B1A1A19191B1A1A1B1A1A1A1B1A191A19191A191A1A1A191A19191919
1919191A1919191A1A191A1A1919191918191A18191A1A1A1A1B191A1B191A1A19191919
1918191A1A191A1919191A1A191819191B1A1B1A1A1B1B1C1C1C1E1C1E1F202120212123
23242321211F1E1D1D1A1C1A1C1A1B1A1A1B19191A1A181A191A1819191A1A1A1A191818
1818191918181819
1819181919191A1919191A191A191919191919191A1919191919191919191A1918181919
1A19191A19191A191819181819191A1919191818191A1A1917191919191A1B1A1919191A
191A1919191919191A1B1A1A1A1A191919191A1A1A1A19191A191A1A1B1B1A1B1B191A1B
1A1A191A191B1A1B1A1B191A1A1A1B1A1A1B1A1A1B1B1A1B1B1B1B191B1A1A1A1B1A1A1A
1A1A1B1A1B1B1A1B1B1B1C1D1B1A1B1A1C1B1B1B1B1B1C1A1B1B1A1A1B1B191C1B1A1B1B
1B1B1B1B1B1B1C1B1C1B1B1B1C1B1A1A1B1C191B1C1A1B1A1A1C1C1A1B1B1B1A1B1A1D1B
1B1C1B1A1B1B1A1A1B1C1B1A1C1B1C1C1B1C1B1A1C1A1B1B1D1A1C1C1B1B1C1B1B1A1B1A
1B1B1D1B1B1B1A1C1B1C1C1C1C1B1C1B1A1B1A1B1B1B1A1C1B1B1B1A1A1B1B1B1A1A1B1B
1A1A191C1B1B1A1C1B1B1A1B1A191A1B1A1B1B1C1C1A1B191B1A191B1A1A1A1A1A1B191B
1A1A1A1A1A1A1A1A1B1A1B1A1A1A191A1A1B1B1A1A1A1A1B1A1A1B1A1A1A1B1A1A1A1A1A
1A1B1A191A1A1B1A1A1A191A19191A191919191A1A1919191A1A19191A1A19191A1A191A
191819191919191A1A19191919181A181A1A191B1A1A1A1B1A1A1A1A191A181A1A19191A
181A1A1819191A191A191B1B1A1A1B191A1B1B1B1A1A1C1B1C1C1D1D1D1F202021222526
262625242322211E1E1C1B1A1B1B1B1A191A191A1918191A1A1A181919191A19191A1A19
1819181919181919
1919191A191A191918191919181A1B191919191A191A191918191819191A181A19181A19
191919191A1919191A191918191819191919191A1A19191A1919191919181918191A1919
1A1918191B181A191A19191A1919191A1A1A1A1A1A1A191B19191A191A1B1A1B1B1B1B1A
1B1A1A1A1A1A1A1A191A191B1A191B191A1A1B1A1A1A1A1A1A1B1A191A1B1B1A1B1A1A1B
1B1A191A1A1A1A1A1B1B1A1A1B1A1B1B1A1C1A1A1B1A1B1A1A1B1B1C1B1B1B1A1A1B1B1B
1B1B191C1B1B191C1B1B1B1A1B1B1A1B1B1A1C1C1B1B1A1B1C1C1B1B1B1B1C1B1B1D1A1B
1A1B1B1B1C1B1C1A1B1A1B1B1B1B1B1B1B1C1B1B1B1C1B1B1B1B1A1B1A1D1C1B191A1B1B
1C1B1B1B1C1B1C1B1A1C1C1B1C1B1B1C1B1C1B1C1C1B1B1B1A1A1C1B1B1A1B1C1C1B1C1B
1B1A1C1C1A1A1B1B1B1A1A1A191B1C1B1B1A1B1A1A1A1A1A1A1B1A1A1A1B1B1A191A191B
1A1B1B1A1A1A1A1A1A1A1A1A1A1A1A191A191A1A1A1B1A191A1B1B1A1A1A1A191A1A191A
1A1A1A1B1B1A1A19191A1A191B1919191B19191A1A1A19191A1919191A1A191A191A1919
191819191B1A191A1A1A191819191A1919191B181A1A1919191A1A1A1819191919191A19
191A19191919181A191A181A181A19191A1B1C1A1B1A1C1B1B1B1D1B1D1E202023242628
2B2A29292624221F1E1D1B1C1B1A1A1A1A1B1A191919191A1A19181919191919181A1A19
191A1A1918181A19
191919191819181817191A191A1919181A1919181918181A1919181919191A191819181A
1B19181919191A1918181A1819191A19191919191A19191A19191A1A19191A1918191A1A
191B191A1A1A1A1A1B1B191B1919191A191B19191A19191A191A1A1B1A191A1B1B1B1B1B
1B1A1A191A1B1A181B1A1A1B1A1B1B191A1A1A1B1A1A1A1A1B1A1B1A191A1A191C1A1A1A
1B1A1B1B1B1A1B1A1B1A1A1A1A1A1B1A1A1B1A1A1A1B191A1B1B1A1B1A1A1A1A1C1B1A1C
1A1A1A1B1A1C1A1B1B1B1B1C1C1C1B1B1C1A1A1A1B1C1A1C1C1B1B1A1A1B1A1A1B1A1A1B
1B1B1B1C1B1B1B1B1B1B1B1B1C1B1A1B1B1C1B1C1B1B1C1A1B1C1C1C1C1D1A1C1A1C1B1B
1A1B1B1C1C1B1B1C1A1B1B1B1C1C1C1B1B1B1C1B1C1A1B1B1C1B1B1B1A1B1B1A1B1C1A1B
1A1A1A191A1B1C1A1A1B1B1B1B1B1C1B1B1A1B1B1B1B191B1A1A1B1A1A1A1A1A1A1A1A1A
1B1B1A1B1B1A191B1B1A1B1A1B1A1A1A191A1A1A191A1A1A1B1B1B19191A191B1A1A1A1B
191A1918191A1A1B19191A1A1B19181A19191A1A191A1A1A191A191919191A191A191B1A
1A191919181919191A191A191A1A19191919191A1A1A1919191A1819191919181A181A19
1918191819191A19191A1B1A1A1A191A19191A1A1A1B1A1A1C1C1C1B1E1E1F212326282B
2F2F2E2D292722201E1D1D1C1B1A1A1A1A191B1A191919191A19191A191A1A1A1919191A
1A191A181A191918
18191A191A18191A1A191919191A19181A1B191919191A181919191A1919191A19191819
1918181A1819191A19181A1919181A181919181819191A1A18191819191919181919191A
181A191919191B191A1B1919191A1A1B1919191A1A1A1918191A1A1A1A1B191C1B1A1B1A
1B1B1B1A1A191A1A1A191B1A1A19191A1A1A1A1A191A1A1A1C1B1A191A1B1A1A1B1B1C1B
1B1B1A191A1A1A1B1A1B1C1B1A1B1B1A1B1B1B1A1B1A1A1B1A1A1A1B1A1A1A1B1B1A1A1B
191A1B1B1C1A1A1C1B1C1B1B1B1B1A1A1C1B1B1B1B1B1A1B1B1B1B1B1A191B1B1C1B1B1C
1B1B1D1B1B1B1C1A1B1B1A191B1A1B1C1A1B1B1B1C1C1B1B1B1B1B1B1B1B1A1A1C1B1A1C
1B1B1A1C1A1C1B1D1B1C1B1B1B1B1B1B1B1B1C1A1A1A1A1B1C1B1B1B1A1A1A1C1A1B1B1B
1B1A1B1B1B1A1A1C1A1B1B1B1B191B1B1A1B1B1C1B1A1A1B1B1B1B1A1A1B1B1B1A1A191A
1B1B1A1B1B1A191919191C1A1A1B1A1A1A1B1A1C1B1A1A1A191A1A191A1B191A1A1A1A1A
1A1A1A1A191A1A1A1A191A191A1B191A191A191B19191A1A181A191A1A1A191B1A1A1A19
191B1918181A18191A1819191919191817191919191919191A1919191919181A19191919
1919181A1A19191A18191A19191919191A1A1A1B1A1A1B1B1C1C1D1D1D1E202225272B2E
323334322C2927221F1E1E1C1B1A1B1A1A1819191A19191919191A1919191A1919191919
1918191918171718
1918191919181819181819191A191819181A191A1A1818171A1919181B1A19191A1A1918
191918191819181A1819191919191919181A19171919191A191A1A19181918191A191A1A
1A19181A19191A1B1A1B191A191A18181A191A1A191A191919191B1A1A191B1A1B1A1B1A
1B1C1A1A1A1B1B19191B1B19191A1A1A191A1A1A1A1A1A1B1A1A191B1A1B191A1A191A1A
1A1A1A191A1A1A1A1A1B1B1B1A1A1A1B1B1A1A1A1B1A1B1B1A191A1B1B1B1A1B1B1B1B1B
1B1C1B1C1A1C1B1A1A1B191B1B1C1B1B1C1A1B1B1B1B1B1A1B1B1A1B1B1B1C1B1C1B1A1B
1D1B1A1A1B1A1C1C1B1B1B1B1B1C1C1B1D1A1B1B1B1B1B1B1B1B1B1B1C1D1A1B1B1A1C1B
1A1B1B1B1C1B1B1B1A1C1B1B1C1C1B1B1B1B1C1A1B1B1C1C1A1B1B1B1B1A1B1B1B1B1A1B
1C1B1C1B1B1A1A1B1A1B191B1B1A1A1C1C1A1B1A1A1A1B1A191A1A1B1A1B1B1B1A1B1A1B
1B191A1B191A1A1A1A1A191B1A1A1B1B1A1A191B1A1A1A1A1919191A1A1A1B1A1A191A1A
1A1B1B1A191819191A1A1A191A1A191A19191A1919181A1A1B191A19191A191A19191A19
1919191B1A1A19191A1A1A18191A1A1A1A19191A1A1A1A18191918191A191A1A1A181919
1819181A191918191A1B18191818191A1A1B191B191A1A1C1C1B1B1B1D1F202224292E33
373A3936312C2622201E1E1C1B1B1A1B1A1A19191A1A1919171919181919181A1918191A
1A18191919181819
1919181A18191919191918191A1819191A191A1A19191A1918191A191919191919191919
19191719181A19181919191919181A19181818181819191A1A19191919191A1A19181919
1A191A1A1A19191A1A19191919181A1A1A19191A1A1A181A1A1A191A191B1B1B1A1B1A1A
19191A1B1A1A1A191A191A191B1A1A1A191A1919191B1A1B1B19191A1A1B1A1B1A1A1A1A
1B1919191A1A1A1B1A1A1A1A1B1B1B1A1A1B1B1B1A1A1B1B1B1A1A1A1A191A191A1B1B1B
1B1A1A1A1B1B1B1B1A1C1C1B1C1A1B1B1A1A1A1B1B1D1A1B1B1A1C1B1B1B1C1C1B1C1B1C
1B1B1A1A1B1B1B1B1C1C1A1C1C1C1B1B1B1B1B1B1A1D1B1B1C1A1B1C1B1B1B1B1B1A191B
1A1B1A1A1B1A1B1B1B1B1B1B1A1C1A1A1A1A1B1B1C1B1B191A191A1B1B1C1B1B1C1C1B1C
1B1B1B1C1B1B1B1A1B1A1B1B1B1B1B1B1B1A1C1A191A1A1B1B1A1A1A1A191B1A1B1A1A1A
1A1B1A1B191B1B1A1A1A1B1A1B1A1B1B1A191B1A1B1A1A1A1A1A181B1B19191A19191A1A
19181A19191A1A1919191A19191A1B191A1A191A1A191A18191A1A1919181A19191A1A1A
191919191919191A1919191819191A1819181A181918181919191919191A191818191A19
19191A1919191A18191A191A1A191A19191A1A1B1A1A1B1B1A1C1B1D1D1E212326283034
3C3C3B38312F292422201D1D1B1C1B1B1B1B191A1918191A1919191919191A1919181A1A
1919181819191819
1918191919191918191A1A191A1818191A191818181A181A19191A191919191918191819
1818191919191919191819191918181918191A1A19181919191A181919191918191A1919
1919181A1919181A191A191A1B191A191919191A1A1919191A1A1A1A1A1B1B1B1B1B191A
1B1B1A191A1919191A191A1A191B19191A1B1A1A191A1A19181A1A19191A191A1A1A1B1A
1A1A1A1B1A1B1B1A1B1A191A1B1B1A1A1B1A1B1A1B1A1A1A1B1A191A1A1B1A1B191B1C1B
1B1B1C1C1A1B1C1A1B1B191B1B1A1B1B1B1B1B1C1B1A1B1A1B1C1A1B1C1A1C1B1B1B1A1C
1A1B1C1A1A1C1B1A1B1A1D1C1B1B1B1A1A1A1B1B1C1A1B1B1B1A1B1C1B1B1B1A1C1C1B1A
1B1C1A1B1B1B1B1B1C1B1B1A1B1A1B1A1B1B1B1A1B1B1B1A1A1A1A1B1A1B1A1B1B1A191A
1B1B1A1B1B1A1B1B1A1B1A1B1B1B1B1A1C1B1B1B1B191B1A191A191A1A1B191A1C191A1A
1B1B1A1A1B1A191A1A1B1A1B191A1A1A1A191B1A1B1A1A1A1A1A19191B191A1A191A1A19
191A1A1A191B1A19191A1819191A191A1B1B1B1A1919191A1919191919191A1A1919191A
191919191A1A181819191819191A191919191A18191A1919191A1A181A18191A1918191A
1A1A191A181819191919191A181919191A191A191A191C1B1A1B1C1D1B1E1F22252A3037
3D3E3C39312D2724211F1F1C1C1C1B1A1B1A1A191A1A1A1A1A1B19191919181A191A1917
1919191A18181819
1919191918191919181A1919181A1A191A1918181919191A19191A191918191919181A19
18191919191A1919191A1A19181919191819191919191919191A191A1918191A19181A18
1919191B1A1A18191A1A191A1919191A1A1A1A191A181A1A1A19191A19191A1A1A191A19
1A19191A1A1A1919191B191A19191919191A191B1B191919191A191A191919191B1A1A1A
1A1A191A1B1A1A18191C191A1A191B191B1B1B1B1A1A1A1A1B1A1C1C191A1A1B1A1A1A1A
1B1A1C1B1B1A1B1C1B1B1B1B1B1C1A1B1B1B1B1B1B1A1C1A1B1A1A1B1C1B1B1B1B1C1C1D
1A1B1C1B1B1B1B1C1A1B1A1B1C1B1C1A1A1A1B1A1B1B1B1B1C1B1B1B1C1B1B1A1B1B1A1B
1B1C1B1A1B1B1B1B1A1B1B1A1B1C1A1A1A1B1A1A1B1B1B1C1A1B1A1A1B1B1A1A1B1B1A1C
1B1B1B1B1A1B1B1B1A1B1A1B1B1A1A1B1B1A1A1A1B1B1B1B1B1A1A1B1B1B1A1B191A1B19
1B1A1A1A1A1A1B191B1B1B1A19191A191B1A19191A1B1A1A19191A1B1B1919191919191A
191A1919191A181A1A1A1B1A1B1A1B1B1A1B1A191A1A19191A1A181A19191A19191A1A19
1A1A1918181919191919191819191A19191A191919191918191919191919191919181919
19191918191918171A191919191A191A1B191A1B19191B1A1C1C1B1D1C1E1F21252A2F34
3A3C3B35302A252222201E1E1D1B1B1B1C1A1A1919191919181A191A191818181A181919
18191A1919181A19
19191919191919191A191A181A19191819181918191819191919181919191A19191A1A19
19181818191818191918181A1A1818181918191919191918191919191A1A19191A191919
19181A191A191A19191A191A19191A191A1B191819181A191A1A19191A19191A1A191A1B
19191B1A1A1A1A1A191A1A191A191A191A191B1B1A1B1A1A1A1A1B1B191A1A1A191B1A19
1B1A19191A1B1B1A191A1B1B1B1A1A1B1A1A1B1A1B1A1B1A1A1A1A1B1A1A1A1B1A1B1A1B
1A1B1B191B1B1B1A1B1A1B1B1B1A1B1B1B1B1B1A1B1C1B1B1C1B1C1B1B191B1B1B1B1C1C
1B1C1A1B1A1B1B1B1A1A1B1C1B1A1B1A1C1C1A1B1C1A1B1B1C1A1A1B1A1B1B1C1A1B1A1B
1A1B1A1B1B1A1B1B1B1A1B1B1B1C1A191A1C1B1B1A1B1A1A1B1B1B1B1B1A1A1B1A1B1A1B
1A1B1B1B191B1C1A1B191B1B1A1A1A1B1A1B191B1B1A1B1B1B1B191A1B1A1A1B1A191B19
1A1A1A1B1A1C1B1B1B1B1A1A1A1A1A1A1A1A1B1A1A191B1A1A1A1B191B1A191919181919
1A1919191A1A1A1A1A1A1A1B1C1A1B1B1A1A1A1A191A1A191A191A1919191A191819191A
1A1919191918191A1A181A1919191A181819191918191919191819191B18191919191919
181A191A191A191B191A18191A1A1A1919191A1A1A1A1B1C1B1B1B1C1D1D1F2125282E31
363835302D29252321201E1C1D1C1A1C1A1B1A191A19191A18191A181B191A19191A1918
181918181819181A
191918181819181919191919181919191919181918181B191A191A1A191A181A19181919
191A1919181918191918191A1919191A191919191819191A19191919191819191A18191A
1819191A1A1919191A1A19191A1A191A191B191A1A1919191A1919191A1B1A191A1B1A1A
1B1A1A1B1A1819191A191A191919191A1A191A191A1A1A1B191A1A1A191A191B1B1A191B
1C191B1B18191A1A19191A1B1B191A1A1B1A1B1B1B1A191A1B191B1A1B1B1A191A1B191A
1B1A1A1A1B1B1A1A1B1B1A1A1B1B1B1A1B1B1B1B1B1A1B1A1B1B1C1B1A1B1A1A1B1B1C1A
1B1A1A1A1B1C1B1B1A1B1A1A1B1A1B1A1B1B1A1B1A1B1C1A1C1A1B1B1B1B1B1B1B1B1C1B
1A1A1B1A1B1B1B1C1B1A1A1A1A1B1B1B1C1B1A1B1B1A1A1A1B1B191B1B1B1A1B1B1B1B1A
1B1A1B1A1A1A1A1A1A1A1B1C1B1A1A1A1A1A1A1B1C1B1A1A1B1A1A1B191B1A191A1B1A1A
1A1B1919191B1B1A1A1B1A191B1A1A1B1B1B19191A1B19191A1A1A1B1B19191A19191A19
19191B191A181A1919181B1A1B1A1B1B1B1A1A1A191A191A1A1A1A1A1919181A1A1A1819
181918191919181A191A191A19181918191A191A191A1A191919191A1A19181A1819181A
1A1919191A191918191919191918181A1A1A1A19191A1A1B1A1B1C1D1C1F1E1F23262A2E
32322F2B2B27252221201F1C1D1B1C1B1A1B1A1B191A1A1A19191A19191A191918191818
181A191819181919
19191919191A1A191A18191819181A1919191A1919191A191A19191A1A1A1A19191A1A19
191918191A1A19191819181919191A19191819191919181918181919191A1A1A191A1A19
191919191919191A1919191A1A1919191A19191919191A18181A191A1A19191A1A1B191A
1B1A1B1B1A191A1B1A1A1B1A18191A1A191A191A1A191818191B1A1B1A1A1A1A191A1B1A
1A1A19191919191B1A191A191B1A191A191A191A191B1A1B1C1A1B1A1A1B1A1B1B1B1B19
1B1B1A1B1B1C1B1B1B1A1B1A1B1B1B1A1A1B1B1B1A1B1C1C1A191A1B1B1B1B1A1B1A1A1B
1A1B1B1C1B1B1B1A1A1B1B1C1B1B1B1A1B1A1A1B1A1C1A1C1B1A1A1B1B1B1A1B1B1B1B1C
1B1A1A1A1B1B1B1B1C1A1B1A1C1A1B1B1B1B1B1B1B1A1B1A1B1B1B1B1B1B1C1B1B1C1B1A
1A1A1A1A1A1A1A1A1A1A1A1A1B1A1B1A1A1A1B1A1B1A1A1A1A1A1B1A1A1A1B1A1B1B191A
181A1A1C1A1B1A1A191B1A1B19191A1A1B1B1A1A1A1A1B1A191A1B1B181A1A18191A1A1A
1A1A1A1A1A191B1A191A1A1A1A1B1A1A1A1A1A1A1918191A1918191A191A1A19191A1918
1A191A1919191A191819191818181A1A1B19191A1918181A191A181818191A1919181919
19181919191A19191919181A191919181919181A1A1A1A1A1B191B1B1C1D1E1E21242728
2C2B2B2A27262322221E1E1D1D1B1C1A1B1A1B1A191A1B1A1A1919191A1919191919191A
1919181A17171818
1A181A1919191819191819191919191919181818191919181919191919191A181A191919
1918191918191919191A191A19191919191A1A1A1A19191819191919181918181B191919
1919191A191918191A1A191A191A191A191919191A18191A1A1A19191B1A1A1A191A1C1A
1A1C1B1C19191A1A1819191A1919191A1A1A1919191A1A191C1A1A1A1A1A191A1A1B1A1B
191A1A191A1A1A1A1A1A1A1A1A1A1A19191B181A19191A1A1B191B1B1A1B1A1A1B1A1A1A
1B1A1C1A1A1A1B1B1B1B1A1B1C1B1B1A1A1B1B1B1C1B1C1B1C1C1C1A1A1B1A1C1B1B1B1B
1A1B1C1B1C191B1B1B1A1A1C1B1C1C1B1A1C1B1B1B1B1B1A1A1A1A1B1B1B1B1A1C1B1A1C
1A1A1A1A1B1C1B1A1B1B1A1A1B1A1B1A1B1A1B1E1C1A1C1B1A1B1B1B1A1A1A1A1A1C1B1A
1B1B1A191B191A1A1A1B1A1A1A1A1B1A1B1B1B1A1B1B1B1A1A1A1A191A1A1A191A1A191A
1A1B1A1A1A1A191A1B191A1A191A1A1A1B181B1B19191A1B1A1A19191A1A191B1B191A1A
1A1A1A191A1A1A1A1A1A1A191A1A1C191A1A19191A1A19191A191A191A19181919191919
1A191818191A1819191A1918191B1A191919191A1A1A19191819181A191A181A1819191A
19191918191A1A1917191A1B19191A1A19191A1A1A1B1A1A1A1A1C1A1C1B1D1F21222324
272526262423212120201F1E1D1B1C1C1A1A1A1B1A1B191A1A1A1A191A1919191919181B
181A181919191819
1917191A19191A1919191919191A191919191819191A19181818191A191819191A19191A
1A1A1918181819181A181A19191919191A18181918181919191A1A1A19181818191A1A1A
1918191A191A1A19191A1A1A1A1A18191A181A1A1A19191919191A1919191A1A19181B1C
1B1C1B1B1A1B191B1A191A1A191B19191A1A1A181A1A191A1A19191B191A1B1A1A191A1A
1A1B191A1B191A1B1A1A1A1B1B191B1A191A1A191A1A1B191A191A1A1B1A1A1A1A191A1B
1B1B1C1B1A191B1B1A1B1B1B1A1B1B1C1C191A1A1B1B1A1A1A1C1B1C1A1A1B1B1B1D1A1B
1A1B1B1B1B1C1A1B1B1A1A1B1B1A1A1B1A1A1B1B1B1B1B1A1A1B1B1A1B1A1C1B1C1A1B1A
1C1A1A1B1B1B1A1B1A1B1B191B1B1A1B1B1B1B1A1B1B1B1A1B1B1A1B1B1B1B1A1B1B191A
1B1B1A1A1A1A1B1A1A1B1A1B1A1B1B1A1A191B1A191A1B1B1A1B1A191B191A191B1A1A1B
1A1A1B1A1A191A1A1A1A1B1B1A1B1A1A1A1B1B1A19191A191A1B1A1A1A1A1A1919191A1A
1A1919191A1A19191A191A1A1A191B1A1A1A181A191919191A1A191A1918191A18191A1B
19181A191A1A191919191819191E1918191A19191A1919191A191819181A191818191819
1819191A19191719191918191917181919191A1A1A1A1A1A1A191B1B1C1D1D1D1E202122
2223232123222121201F1E1E1C1C1B1C1A1A1A1B1A1A1A1A1A1A19191818191819191819
1918181818181818
1818191A1A191A191A1A181A191A1A1919191919191B1A1A191819181918191819191919
191A18181818191A191819191918191819181818181A18181917191919191918181A1919
1919191A19191A1918191A1A1A181919191A191919191819191A1A1A191A191A191B1C1D
1C1C1C1B1A1A1A191A191A191A1A191A191A1A1A191B1A1A1A1A181B1B1B191A191A1A1A
1A1A1B191A191A1B191B191B191A1B191A191919191B1A1A1A1A1A1A1A1B1B1B1B1B191A
1B191A1A1B1B1B1B1B1C1B1C1B1A1A1B1B1A1B1C1B1B1B1A1B1B1B1B1A1B1B1C1B191B1B
1B1C1B1B1B1B1B1B1C1B1C1A1B191B1A1A1B1B1A1B1B1C1B1C1B1A1A1B1A1B1A1A1B1A1A
1B191A1A1B1B1B1B1B1A1A1C1C1C1B1B1C1A1B1A1B1C1B1B1B1B1B191B1A1B1A1C1A1B1B
1A1C1B1B1A1B1B1A1A1B1A1B1A1B1B1A1A191B1A191B1B1A1B1A1B1A1A1B1A19191A1A19
1A191B1B1B1A1A1A1A181A1A1A19191A1A1A1919191A1A191919191A1B1A1A1A191B191B
1A1A1B191B1A18191A1A191B1A1A1A1B191A191A191A191A19181B1A1819191A1719191A
1918181919191919191A191A1A1918191A1A1A1819181819191818191818191919191918
1A191919181919191919191A191918181B191A1A1A1A1A1B1A1A1B1A1B1A1D1C1C1E1F20
201F212120211F201F1F1E1C1D1C1B1B1B1A1B1A1A1A1A191A1919191A1919191A181919
1818191818181818
1918191919181A19191A19191819191918191919191A19191A191A191919191A19181819
1919181919191918191A191A1919191919191919191A1919181819191A19181919191A19
1818181919191919181A19191818191A191A181A1A1B19191B191B19191A191A1B1A1B1C
1D1C1B1B1B1818191A191A191A1A191B191A1A19191A1A1A1B1B1A1A1C19191B191A1A19
1A1A1A1A191B1B1A1A1A1A1B1A1A1A1A19191A1A1A1A1B1B1B1A1A1A1A1B1B1A1A1B1B1A
1A1B1B1B1B1B191A1B1B1A1B1B1B1B1B1A1B1B1A1B1B1B1B1A1B1B1B1B1A1B1A1A1B1B1A
1A1B1A1B1A1B1B1C1B191B1A1B1A1B1B1C1A1B1B1A1A1A1A1B1A1A191C1B1B1B1B1B1B1A
1A1C1A1B1B1B1A1B1A1A1A1A1B1A1C1B1A1A1B1B1A1B1B1A1A1A1B1B1B1B1A1B1B191B1A
1A1A1B1B1A1A1B191B1B1B1A1B1A1A1A1A1B1A1B1B1A1A1B1C1B19181A1A1B191B191B1A
191A1A1B1A1A1A1B1A1A19191A191A1B1A1A1A1A1A1A1B19191A1A1A191B191819191B1B
1A1B1A191A191A1B1A1B1A191B1A1A191919191A191A19191A1919191A1A19191919191A
19191919191919191919191919181919191A1A1A1918181A1A181919191A191818191A18
1719181817191919191819181A1919181A181A1A1A19191A1A1A1A1A1B1B1A1B1B1D1C1E
1E1E201F201E1F1E1D1E1D1C1C1B1C1D1D1B1A1A1A1B18191A19191A1A19181A191A1819
1819171819181919
19191918191A1A19191919191A191A1819191A19181A19181A191917181A191818191919
1919191918181919181A181A191919171919191A191A1A1918191A1A181A1918191A1919
19191A191A1A19191819181919191719191A1A1A191A1919191919181919191A1A1B1B1D
1D1C1C1C1B1A1B1A1919191A19171A1B1A1A1B191A191A1A19191B191A1A1A18191A1919
191A1819191A191A1A1B191B1B191A1A1A191A191A191A191B191A1A1A1B1C191B1A1A1A
1A1B1B1B1B1B1A1A1B1B1B1C1B1B1B1B191B1B191B1B1B1B1B1A1A1A1B1A1A1B1B1A191B
1C1A1B1C1B1B1B1A1B1C1A1A1A1A1B1A1B1B1B1B1B1A191A1A1B1A1B1A1A1A1A1A1A1B19
1A1A1A1A1B1A1A191A1B1B1B1B1A1C1B1A1A1A1A1A1B1B1B1A1A191A1A1A1B1A1A1A1B1A
1A191B1A1B1B1C1A1B1A1B1A1A1A1A1A1A191A1A1A1B1A1A201E1A191A1B191A181A1A1B
19191A1A1A191A1A1A1A191A191A1A1B191A19181B1A1A1919191A191819191A1A191A19
191A191918191B1A1A181A191A1919191A1A1A1A19191B191919191A19191A18191A1818
18191919191A191919191819181A1A181A1C191919191919191918191918191918191918
191819191918191919191A19191A1A1919191A1A1A191919191A1A1B1A1C1B1A1C1C1C1D
1D1D1E1E1E1F1D1D1D1F1C1D1C1B1C1C1B1B1B1B1B1A191B1A1A191919191A1A1A191918
1919191918191919
1918181917181819191A191A191818181A1A19191A191919191918191A19191919191A19
1918181918191918191818191B191818191918191919181A191918181919191819191918
1A1A191819181A1919191919191918191A181A191A191A1A181A1A1A1919191A1B1A1D1B
1C1B1B1B1B1A1B19191A1A1B1A19181919191A18191A1A1A1A1A1A1A1A1A1B1A1A1A1A1A
181919191A1A1A1A1A1C191A1919191A1A191A1A191C191A1A191A1A1B1A1B1A1A1B1B1A
1A1A1B1A1B1A1A1C1A1A1B1B1B1C1C1A1A191B1B1B1B191B1A1B1A1A1A1B1B1B1A1A1B1C
1A1B191B1A1A1A1A1A1B1B1B1B1B1A1A1B1C1D1B1B1B1A1C1B1B1B1C1B191B191B1B1A1B
1A1C1A191A1B1A1A191A191B1B1A1C1B1A1A1A1C1A1A1B1A1A1B1A1B1B1C1A1A1B1B1B1B
1B1B1B1A1B1C1A1B1B1B181A1A191B1A1B1B1A1A1A1A1C1A1B1B1A191A191B1A1A1A1919
1A191A19191A191A19191A191918191A1B1A191A1A191A191B1A19191A1A191918181A1B
19191B1A19191A1A191B1919191A18191919181819191A1A181919191919191919191919
191918181918181919191A1A19191A181B1A1A1919191A171819191A1819191A181A1919
1819191918191A1A19181919181919181819191A191A19191A1B1A1A1A1A1B1A1A1B1B1C
1C1D1C1E1D1E1E1D1D1D1D1E1C1C1C1A1B1B1B191B1A1A1A1B1919181A181A18181A1819
19191A1819191819
1919191A18181A181919191919181A19191B1919191A191919191819181A181A1A181919
181918191B191917191919191918191A18191B191919191918191919191A191A19181918
191A1A1A191A1A1919191A191919191A18191919191919191819191A1919191A1B1A1B1A
1B1B1C1B1A191A1919191B1B1A191919191A1A191A181919191B191A1A191A1A191A1A19
191A191A1A1919181B1B1A1B1A1A1A191A191A1919191A1A1A1A1A1A1A1A1B191A1A1A1B
1B1A1A1B1B1A1A191B1A1A1A1B1A1B1B1B1B1A1B1A1A1B191B1B1B1B1A1A1A1B1A1A1A1B
1A1A1B1C1B1B1A191A1A1B1B1C1A1B1B1B1A1B1B1B1B1B1B1B1B1A1B1B1A1B1B1B1A1B1B
1B1C1A1A1B1A1A1A1A1B1B1B1B1A1A1A1B1B1B191A1A1A1A1B1A1A1B191A1B1A1B1A1A1B
1A1A1B1A1A1A1B1A1B1A1A1B1B1A1A191C191A1B19191B1A1C1A191A1A1A191A191A191B
1B191B1A1B1A1A1B1A191A1A1A19181B1A1A1A1B18191A1A191A191B191A1A19191A1A19
191A191A1A1919191A1A1A1A1A1A1A19191A18191A191918191A1A1A18181A1A1A1A1919
18191A19191819191919191A191A1918191A19191919191919191818181819191A191818
18191A181819191A181A1919191819191A1918191A1A1A19191A191B1A1A1A1A1B1C1B1D
1E1D1D1D1C1C1D1D1D1C1C1D1D1C1B1B1B1B1B1B1A1A1B1A1A1A1A191919191919191918
1919191818191919
191A17191819191A1819191818181A1919191A18181A1919191A1918191A181A18191918
17181919191819191A191918181919191918181A191A1918181A1918191818181A18191B
1919181A191818191A19181A1A191A191A18181818191919191918181A1A191A1A1A1A1A
1B1A1A191A1A191A1A1A191A1A1A1A1A1A1A191919191919191B191B191A191A1A1A1919
19191A19191A1A191A1A1B1A191A1A19181A1B1A191A191A1B1B1B1A1A191A1A1A191B1A
1A1A1A1A1C1B1A1A1A1B1B1B1A1B1B1A1B1B1A1A1A1B1B1A1B1A1B1B1A1A1B1A1A1A1B1B
1B1B1B1B1B1A1A1A1A1B1A1A1A1B1B191A1B1B1D1B1B1A1B1A1B1A1A1A1C191B1B1B1B1A
1B1A1B1B1B1A1B1A1A1A1A1B1A1B1B1A1B1B1A191B1B1B1A1A1B1A1B1B191A1A1B1B1A1B
1B1A1B1A191A191A1C1B1B1A1A1A1A1A1B1A1A1A1A1B1A1A1A1B1A19191A19191A1B1A1A
1A1A1A1A1A19191A191918191A1A1A1B19191A181A1B191B191B191A1A181919191A1A1A
191A1A191A191A191A1A1B191819191919191A191A191A191A1A19191A191A19191A1919
1917191919191A191819191919191A1A191A191A1A1A191A181A191A19191918191A191A
1919191A1819191919191918191A1819191916191A19191A19191A191A1A19191A1B1A1C
1A1B1B1B1C1C1C1C1B1C1C1C1C1B1B1B1B1C1B1B1B1A19191A19191B1919191A1A191819
1A19181A19181818
19181A191819191819191A18191A191819191A191A191A1919191918191A1919181A1919
1A19191919191A1918191919191919181819191919191B1818191818191B191A191A1919
181A1A1919191A19191A19191919181919181A181919191A1A191B1A1B1A1A19191A191A
1A1B1A1A19191A191A1A1A1A1A1A1A1A1A191A1A191A1A1A1A1A1A1B1A191A1918181A1A
191A19191A1A191A1A1A1919191A181A191A1A1B1A19191A1A19191A19191B1B1A1A1B1B
1B1A1B1B1B1A1A1B1A1A1A1C1B1C1B1B1A1A1A191B1A1A1B1B191C1A1B1B1A1A1C1A1A1B
1B1A1A1B1A1A1A1B1B1B1B1B1B1A1B1B1B1B1C1B1A1B1A1B1B1B1B1A1A1B1A1B1B1B1C1B
1B1A1B1A1A1A1B1B1A1B1A1B1A1B1B1A191B1B1B1A1A1A1A1B1A1A1B1A1B1A1B1A1A1B19
1919191B1B1B1B1A1B1A191B191A1B1A1A1B191B1A1A1A191A1A1B191A1A1A1A1A1A1B19
191A1A1A191A1A1B1A191A191B191A1A191A1A1A1819191A1B191A1A191A1B1A1919191A
191A1A191A1A1A1A19191A1B1A191919181919191A19191A191919191919191A191A1819
191A191A19191A1919181A1818191A1A191A191A1919181919181919181819191A18191A
1A181B191819191918181918191919181A191818191A1918191919191B191B1A1A1B1A1B
1B1B1C1C1B1B1B1B1B1C1C1B1B1A1A1C1C1A1A1B1B1A1A1A191919191A1A1A1919181918
1818191917181919
1918181A1919181818181A181919191A191919191918181A1819181A1A191A1819191A1A
19191919191918191A1819191918191A18171718181A19191A1A1A191918181919181919
1A1918191B191819191918191A181A191919181A19191A191A1A19181A1A1A1919191919
191A1819191A19191A1A1A1A1B1A1A1919191A19191A1919191A1A191A1A1A19181A181A
1A191A1A1A1A191B191B1A191919191A1A191A1A1A1A1B1A19191A1A1B1D1B1A1A1B1A1B
1A1B1A1B1A191B1A1A1A1A1A1A1B1B1B1A1B1A1A1B1A1A1B1B1A1A1B1B1B1B1A1A1B1B1B
1A1B1B1B1A191B1A191B1A1A19191B1A1C1A1B1B1A1C191A1A1A1A1A1A1B1B1A1A1A1A1A
1A1A191B1A1B1B1B1A1B1B1B1B1B1A1B1C1C1A1A1B1C1A191A1A1A1C191A1A1A191B1B1B
1A1B1A1B1B1A1A1A1B1A1B1A1B1B1A1A1A1B1A191A1A1A191A1A1B1A1A1A181A19191919
1A191A1A1A1A19191A1B1A19191A1B1B1A1A1A1B191A1A1A18191819191A1A1A191A1919
191A1A19191A19191A1919191A191A1A191A1A1A19191A1A1A1A1A191918191A18191919
181A191A1B191A1919181719191919191919181A191A18191919191819181A1819181919
181A19181918191818191A191919191919191A1A1A19191919181A191A191A1A1A181B1A
1B1A1C1A1B1C1D1C191B1C1C1B1B1C1B1A1B191B1C1A1B1918191A1A1919191818191918
1919181819191819
1918191819191918191919191719191818181919181919181819191A1819181818191919
1819191A1918191A181A191A1A18191919191818191819181918181819181A191A191918
1919191919191A191A18191A19181819191819181919191A191919191A1A1819191A1A19
1A181A1A19181A1A19191A1A1A1B1A19191A1919191919191A191B19191A1A1919181A19
19191A1B1A19191A1A1A1A1B1A1A1A191A1919191A1A191B191B191A19191A1B1A191B1A
1C1B191A1B1B1A1B1B1B1A1B1B1A1A1B1B1B1A1A1B1A1B1C1B1B1A1A191B1B191B1B191B
1A1B1B1A1A1A1A1A1A1A1A1A1A1B1A1B1B1B1B191B1B1A1A1B1A1B191B1B1B1B1A1B191B
1C1B1A1B1A1A1A1B1A1A1A1B1B1A1A1A1A1B1A1B1A1A1B1A1A191A1C1A1A1B1A1A1A191A
1A1A1B1A1A1B1A1A1A1A191A1A1A1B191A1B1A1A1A1B1A1A1A1A1A1B1B1B1A191A1B191A
191A191A1A19191919191A1A1A1A1A191A1A1919191A1A1A1A1A191B1B181A1919191819
1A19191A191A1B1A1A1A1A191B1A1A1919191A1A191919181A191919181A18181818191A
191A1819191A1A1A1A1919191819191918191918191A19191A181918191818181819191A
1817181919181818191918181919191919191919191A181919191A181A1A1A1B1A1A191A
1A1A1B1C1A1B1B1B1B1B1B1A1B1B1B1A1B1A1A1A1A1B1B1919191A1B191A191A191A1819
1919191819181819
18181A19191919191818181919191818191819181818191918191918191A1A1819181919
1918191819191A191919191A181A1918191919191919191919191A181819181918191819
1819191919181719191A181818181919191A1919191A191A1A1919181919181919181919
1919191A1A1919191A191A181B1A1A1A1A191A1A19191A1A19191A191A19191A191A1919
1A191A1A1A1919191A1A1A1919191A1B181A19191A1A1A1A1A1A1A1B1B1B1A1C1A1A1A1A
1A1A1A1A1B1A1B1A1A191B1B181A1B1A1B1B1B1B1B1B1A19191B1B1A1B1A1A1A1B1B1A1A
1A1A1A1A1A1B191A1B1A1B1B1B191B1C1B1A1C1B1B1A1A1A1B1A1B1A1A1B1A1A1A1A1A1A
1B1A1A191A1A1B1B1A1A1B1B1A1A1A1A1A1A1A1A191B1A1A1A1A1B1A1B1B1B1A1A191919
1B1A191B1B1A1A1A1A1C1B1B1A1B1A1A1A1B1A1A1A1B1A1C1A1A1A191A19191A1A1A181A
1A1B19191A19191A1B1A1A1A19191A1A1A191B191A191A19191A1A191A1A181A1919181A
1B19191A1919181A1B191A191A191A1A1919191A1A1A1A191919191A1A1918181918181A
1A1A1918191819191A191819191918191919191A19181718191818171819181919181918
1818181818191A1818191A181A1919191A1A191A191A18191919181A19191A1918191C1A
1A1A1A1B1A1A1B1A1A1A1B1B1C1A1B1A1A1A191A19191A1919181A1A18181A1919191818
1A19191818181918
1818191A181918191A191919191819191A1818191919181919191A1A1919181819191818
1818191819191819191919181919191919181819181818181A19181918191A181A191A19
1919191A18191918191818181818191918191819191919181919191A1919191A1A191919
191A1A1A1A18191A191A1A19191A1B191A1A191A191A1A1A1A1A1A181A191A1A1A191919
191A191B191A1B19191A1A191A19181A191A181A1A191B19191A1A1A191A1A1C1A1A1B1A
1B1A1A1B1B1B1A1B1B1A1A1B1B1B1A1A1A1B1B1B1A1B1A1A1B1B1A1B1B1B191A1B1C1A1A
1B1A1B1A1B1A1A1A19191B1A1B1A1A1A1B1B1A191B1A1C1B1B191B1A191A1A1B1B1A1A1A
191A1A1A191B1A1A19191A1A1B1A1A1B1A1B1A1A1C1A1B1B1B1B1A1B1A1B1B191A1A1A1A
1A191A1A1A19191B1A1A1B1B1A1A1A1A1B1B1B1A1A1B191A1919191A1A1A1A1A1A1B191A
1A1A1A18191A191A1B1A181919191A1A19181A191A1A1A1A19191919191A191A1A1A1819
1A19191A1A1A19191B1A191A1B1A1B1A19191918191919191919191A1818191919171818
19181A19181A1919191919181A19191819191819181A1818181A19191918191A19191919
19191918191919191A181919181A18191A191919181B171A1A191A191919191A1A1A1A19
191A1A1B1A1B1B1A191A1B1B1C1A1A1A1A1A1A1B1A1B1B1A1A1A1A191A19191919191A19
1919191819181719
19191819191718191A18191919171919181A191A1919191919191719181B19191A19181A
191A181919181A19191A191818181A191A1919191818181818191A181818191918181A19
1A1A1A191A1A1A191A1A19191A191919191919191919191A191919191A19191A1A191917
181918191A191A19191A191A1A1A191A1A1918191A1A1A191A1A1A1A1C19191A1A191819
1A1B1A1A1A1A1A19191B1B1B1919181A1819191A1919191A191A1B191A1B1A1A1A1A1A1B
1B191A1B1A1B1B1A1A1C1B1B1A1A1B1A1B1B1A1A1B1C1A1B1A1B1B1A1A1B1A1A1A1A1A1B
1B1B1A1A1A1A1A1A1B1A191A1A1A1A1A191A1A1B1B1A1A1A1B1C1A1B1A1A19191B1B1A1A
1B1B19191C1A1C1B1B191A1A1A1A1A1B1A191A1A1B1A1B1B1A1C1A1B1A1A1A1A1A1A1A1A
19191B1A191A1A1B1A1B1A1A1A1B1A1B1A1B1B1A1A1B1A1A1A1A1A1918191A1A1A1A1A19
19191A1B19191A191A1A191B191B1A1919191B1A1A1A181A1A1A1919191A19191A191919
1919191A191A1A181A1A1A1A191A1B1A19191A19191C191919191A19191919181A191919
191A1919181819191919191919191A191A191919181A19191919191A19181A19181A191B
1A1A1919191A191919191A18191A1919191919191818191819191919191A191919191A1A
1A1A1A19191A1A1B1A191B1C1B1A1B1A19191B1A191A1A191A1A191B181A19191919191A
1A181A1919191819
1919191819191A191A1A1918191A18191A191919191A1919181A18191A19191A1818191A
1819191919191819191819191A1918181918191819181919191819181819191A1919191A
1918181918181919191818191918191918191819191919191A181B1918181A1A18191919
19181919191A1A191A1A19191A19191A191818191A19191A1A1A1B1919191919191A1A18
1A1A1A181A19191B191918191A191A1A1A1B191A1919191A191A1A191B1A1A1A1A1A191A
191A1A1B1A191A1A1A1B1A191A1A191B1A1A1A191A1B1B191A1C1A1B1A1B1B1B191B1A1A
1A1A1B191B1B1A1B1B1B191A1B1B1A1A1B1C1A1A191B191B1A1A1A1B1B1A1A191B1A1B1A
1A1A1B1A1A1A1A191A1B1A1B1A1A1A1A1A1B19191B191A1B191A191A1B1A191A191A1A1C
1A1A1A1B1A1A1B1A1A1C1A1A1B1B1A1B181A191B1B1A1A1A191A1A1A1B191A1919181A1A
1A1A1A1A1A1A19191A1A18181A191A1A1A1819191A1A1A1A1B1A191A1919191A19181919
191A1A1A1A19191B1A1A1B1A191B191919191A1A191A19191A1A1819191A191918191918
1A19191A1918171919181819191A1918181819191818191918191A1919191919191B1919
1919181A1818191A1819181918191918191819191819191819171918191A1918191A1A19
1A1A1A191B191B1A19191A1B1C1B1A1A19191A1A1A1A1B181A1919191919181A1819191A
1919181918181819
1919181A191919191919181918191819191A19191818191B191918181919191A1919181A
191918191919191819181B1919191919181819181918181919181A18191A19181A191919
19191A191919191818181919191919181A1A1A191A191919191A1A1A191A191918191918
191919191A191A1A1919191A1A181A1918191A181A1A19191A1A1A1A1A1A1A1B1A1B1919
1A1A1B1B1A1B1919191A1A19191A1919191A1A1A191A1A1A1A1A1A1B1B19191A191A1A1A
1B1B1C1B191B1A1B1A1A191A191A1B1B1A1A1A1A1A1B1A1A1B191B1B1B1A1A1A1B1B1A1A
191A1A1B1A1A1A191B1A1A1A1A1A1B1A1A1A191A19191A1A1A1A191B1A1A1A1A1B1B1B19
1A1B1B1A1B1B1B1A1B1B1B191A191A191A1A1B1A191A1A1A1B18191A1A1A191B1A1A1B1A
1A191A1A1B1A1A1B1A1B1B1A1A1A1A191C1A1A1B1B1A1A1919191B1A1A1A1A191A1B191B
1A191A191A181A1A1A18191A191A1A1A1A191A1A19191A1A1D1A191A181A181A191A1919
191A1818191A191A1B1A1B1A191A1A18191919191A191A19191A1919171919191A191919
181918181919191819191819191819191818181919191919191919191918191A1A191A19
1A18191819191919191819191918181A191A19191A1918181819191A181A1919191A191A
1A1A1819191A1A1A1B1A1B1B1B191A191B1A1A1A1919181A19191A191A19181A19191919
1918181918191818
191919181A19191918191919191819191918191919181818191A19181919191A19191819
19181919191A191919191819191919171A1819191818191918191918191918191B1A1819
19181919181A19191A1A191A191818181919181A191A191A1819181A191918191A191919
181A1A191A1919191A19191A181A191A1A1A1A1A191A181919191A1A1B1A1B191A1A1B19
191A1A1A191A1A1B1919191B1A191A191A1B1B1A1919181A1A1A1B1A1A1A1A1A1B191A1A
1A1B191A1B1A1B1B1A1B1B191A1B1B1B1B1B1A1A1B1A1A1B1A1B1A1B1A191A1A1B1A1A1B
1A1B19191B19191A1A1A191A1B1B1A1C1A1A1A1A191A1A1A1A1A1A1A1A1A191A1B1A1A19
1A1A1A1A1A1A1A1B1A191A1A1A191A1A1B191A1A1A1B1A1B1B191B1B1B1A1B1A1A191A19
1A1A1A19191A1A1A1B1B1918191B191A1A1A1A191A1B1A1A1A1A19181A19191A1A181A1A
191A1A1A1A1A1A191A1A191A1919191B1A191A1A1A19191919191A191A191A1A1918191A
1A191919191A1A1919191A1B1B1A1919191919191A1A191819191919191819191A1A1919
19191A1818191A19181918191819181A181A191819191919191A1A181919191818181919
18181919171A1918191818181918181918191A18191919181919181918191819191A191B
1919191A1A1A1A1B191A1A1A191A1B1A1A1A1A1A1919191B1A1A1A19191819191A181919
1A1B191918191818
1918191719191919191A1A1A1918181818191A1A1819191A191A19191919181918181818
19181A1919191A191919191A19191819191819181819161819181A18191818191A1A1818
181918191918191A191A19191818191A1919191919181918191A19191A19181A19191919
1919191A1A1919191A191B1917191A1919191A181A18191A191A191A191A191A19191B19
1B1A1A1A1A1A1A191A1A19191A19181A1A19191A1A1A191A1A191A1B1A1A191A1A1B1A1A
1B1A191B1B1B191B1A1A1A1A191A191A191A1A1A1B1B1A1A1B1A1B1A1B1A1B1A1A19191A
191A1A1A191B1A1A1A1A1A1B1A1A1A1A1B1A1A1A19191A1A1A1A1A1B1A1B1A1A191A1A1A
1A1B191A1A1A1A1A1A1A1A1A1A1A1A1B1B1A1A1B1A191A1A1A1B191A1A1A1A1A1A191A1A
1A1A1B191A1A1B1B1A191B1A191A1A1A1B1A1A1B191A19191B191A191B191A19191A1919
19191A191B191A1919191A191B1A191A1A1A19191A1A191819191A1A19191A18191A181A
181A19191919191A1A1B1B1C1A1A1A1819181A18191719181919181819181A1918191919
191919181919191A19191A191819191919181819191919191919191918181A17181A181A
1919191817191818181919181A191819191819191818191819181919191A191919191A1A
191A1918191A1A1A1A1A1A1A1B1A1B1A1B1A1A191A1A19191A181819181A181818191918
181918181A191918
191819191919191A18191A18191A1819191919191A191A19181919191A181A1919191818
19181719191919191818191918191918181919181918181718191919181918181818191A
1819191A1A19191A18191919191919191919181A1918191819191919191A191919191919
1918191918181A18191918191A1B19191A1A191A191A191919191919191A1A1A1A1A1A1B
1A191B19191B18191A191919191919191A1A1A1A1A191B1A1A1B1A191B1A1B1A1A1A1B1A
191A1A1B1B1A1B1A1A191A1B1B181B1A1A1A1B19191A1A1A1A1A1A1A1B19191B1A191A1B
1A1C1A1B191A1A1A1A1A19191B1A1A1B1A1A1B1A1A1A191C1A1B191919191A1B1A1B1A1A
1A1A1A1A191A1B1A181B1B1A1A1A1B1A1A1B1A1A1A1C1B181B1A1A1B1B1B1C1A19191A19
191A19191B191B1A1A1A1A1C1A1A191A1B1A1A1A1A191B1A19191B1A1A1A1A1A1A1A1A1A
1919191A1B19191A1C19191A1A191A191B1919191A1A1A1A1A1A1A181A191A1A191A1919
1A1A1A19191A18191A191A1B1B191A1A191919191919191919181818191A191A191A1918
1A18181A19171A1A191918191A1819191918191819191A1A19191919181919181A191919
1A1A1A19191819191919181818191818181A19191B191919181818181918191919181919
191A19191A1A19191A19191A1B191A1A1A1A191A19191919191A1A1A19191A1819181919
1918171919191819
191A1919181919191A1A1A19181A191A1A1A1A1919181819191919181A18191818191818
19191919181819191918181918181A191819181819191919181918181918191A19191A1A
1A1A18191A191918191A191818181A1B1819181919181919191919191919181A19191919
18191919191A19191A191B1A1919191A1A1A1A1A191B1A191A191A1B191919191A191A1A
181A19191A1A1A1A1B1A1A191A19191A191A1B1A191A191A1A1A1919191A1A191A1C1B1C
1A19191A191B1A1B1C1A1A1A1A191A1A1B1B1B1A1A1B1B1A1A1B1A1A1A1A1A1A1A1A1A1A
1A1A191A1A1A191A191B1A1A1A1B1A1A1A1C1B1A191A1A1A1B1A191A1A1B1A191A1A1A1A
1B1B1B1A1B191A1A191A1B1B191A1A191A191A1B181B1A1A191919191A1B1A1A1A1A1A1A
1A1A191B191A1C1A1A1A1A1B1A19191A1A191B1A1A1B1A1A191A1919191919191A1A1919
191A191A1A191A1A191A1B19191A181A191919181A191A19191A191A191A1919191A1A19
191919181A19191A19191A1919191818191B181B1A191918191919191A19191A19181918
1919181A1919191919191819191A1919191B19191819191A1A18191A1918181A19191919
191919191919181919191819181918181919191919191818181919181918191919191A19
1A191A181A191A191A1A1A1B191A1A1A191A191918191A1919181A19191A191B19191818
1918181918191819
18191A1A191918191A19191919191A1B1918191819191918181818191918191818191819
18191919181918191A1919191819181819181918191A191A181918191A18181919191919
191A18191B191A181919191919181819191919191A19191918191919181919181918191A
1A191A1919191A191918191A181A191A1919191818191A1A1919181A191A1B19191A191A
19191A1A1A1A1A18191A191A1A191A19181B191A191A1A1A191A1A1A1A19191B1A1A1A18
191B1B1A191A1A1A1A1A1B1A191C1A1A1B1A1B1A1A1B1B1A1A191A1A1A1B1A1A1A1B1A1A
191A1A1A1A19191A1A1A1A1A1A191A1A1B191A1A1B1A1A1A19191A1A1A1A1B1B1A1B1A19
1A1A191A1A19191A1A1A1A1B1A1A1A1A191A1B1A1B1A1A1A191A1A1A1A191B1A1A191A19
191A1A1A191A1A1A1A1A1A1A1B1A1A1A1A1A191A1A1A191B19191919191A1A191A181919
1919191B1819191A1919191A19191A191A191A1A191A1819181818181A1B181918191A1A
191A1919191A191A1A1919191919191919191A181919191919191919191819191A171918
1A1A18181A1918191818191818181A1A191819181819181919191818171A1A1A1918171A
19191918181718181918181917181A171919191A1A191A181A1919191919191A19191A1A
191919191A19191A1A1919191A1A191B1A1A19191A181A1A1A191A1A1A19191919191B1A
1819191819191919
1A1718191A181A19191A191919181819181A1919191A1919181918191819191918171919
191819191819191919191919181A1918191819191918191A191818181A17191A1A1A1A19
1A191819191A1918181918191919191819191918191819181A19181A1919191919191A1A
191A18191A1B18191A1A19191918191A1918191A1A191A1A1A191919191819191A191919
191A1A191A191A1A1A181A19181A1A1919191B19191A191A1A1A1A1A191A191919191B19
19191A1A1A1A1A1B191A1A19191A1B191A191A191A1A1B1A1A191A1A191A1B1A1A1A1A19
19191B1A1A1A1A191B1B1A1A1A1A1A1A1A1A191B1B191B1B1B1A1A1B191A1A1B1A1A1B1B
1A1B1B1A1A1A191A1A1A1A1A191B191A191B191B1A191A1B1B1B1A191B1B1A1919191A1B
19191A1A1A19181A1A1A1C1B191B1A191B1A191B191B1A1919191A19191A1B1A1A19191B
1919191A18191A1919191A1A1A1A1B191A1B1A1A191A191A1A191A191A181A1919191A19
191919181A1A1919191919191A191819181918191919191A19191919191A181918191917
181918181819181B18181A171B181919191819181919191818191A191A18191819191918
19191919191819191A191919191919191918191818191A19191818181919191619181919
1A191B19191A1A1A1A1A18181B1A181919181A1B1A191A1A191A1A191A1A191919191919
1A18191819181818
191A1919191919191A191A1B1819191919191A191919181A1A1A191918181B1818191919
1917191A1919191919191918191817191A18191A19191919191918191919191919181919
1919191918191A19191819171A1818181918181819181919191919191A1A181A18191819
1A1A19181A1A1819191919191919191B1A1A191919191A191A181A1819191919191A191A
1B1A191A1A191A1A191A181A191919191A1B19191A1A1A191B191A1A1A1A1B1A1B1A1A1A
1B19191A1A1B1B1B1B1A1A1A1B1A191A191A191A1B1B1A1A1B1A1A1A1A1919191A1A1A19
1A1A1919191B1B1A1B1A1A1A191A19191A191B191A191A1A1A1A1B191B1B191A1A1B1A1A
1A1A191B1A191A1919191B1B1A1B191A1A1A1A1B1A1A1A1B1A1919191A19191919191A19
1B1B1A1A191A1A191919191A1A1B1A1A1A191A1A1A191A1A191A191A1A1A1A1A1A1A1A19
1A191A191A1B19181919191919181919191A1A1A1A1A1919191A191919191A1A191A1A18
191A19191A1919191A1A181A191A1719191A19191919181919181918181918191A1A191A
1918181A191A1A19181A171918191819191A1918191A1919181818191A19181919181719
1919181919171919181A1919181819191918191818191919181A19191A18191918181819
191919181A19181A1A19171A1A19191919191A1A1919191A19181A1918191A1A191A1819
1818191818181919
181A191918191A191A1919191A191919191A1819181919191918181919191A1918181918
1819191819191818191918191919181819181A1A1A1919181819191A191819181818181A
18181819181A1A1A19191919191A1A181818191A181719191919191A181B191919191819
191A181A1A18191919191919191A1A1A191A191919191A191918191819191919191A1A1A
1919191919191B1A1B191A1819191A1919181A1A19191A1A191A1A1A1A1A1A1B1B191A18
1A1B191B1A1A1A1A1A1A191A1B1B1A1B1B1B1A1A1B1A19191B1A1B191A1A1A1C1B1A191A
1B1A1A191A191A1A191A191A1B1A1A1A19191B1B1A1A1A1A1A1A1A191A1A1B1A1A1A1A1A
1B1A1B1B1A191A1A1B191A191A1B1A1B1A1A1B1B1A191A1A1A1A1A1A1A191A1B1A1A1A19
191A1B191A1B1A19191A1A1A1A1B19181A1B1A191919191A191B1A1A191A1A191A19191A
1A1A191A1A19191A1A191A191A1A191B1B1919191A1A1B1A191819181919191919191A19
1919191919181A191A19181A181918191B191819181719191918171919181A181A191919
191919191919191A1919191819191818191919181719181A1A1919191819191919181919
191A17191719191818181918181919191A18191819191918191818191A19171A19191B19
18181A191A1A19191A1A19181819191B1A1A191A1A18191918191A181919191719181A1A
191B191818191819
1A191919191919191A1919191A191A191A191818181A1818181819191B1A191819191919
191819191A1818191819191918191A181819191919191919181919181A1819191A191817
1819191819191819181A191919181819171A1919191919191918181A19181A1A1A19181A
19191A19181A191A1A1919181A1919191A19191A191A1A1A1A181A19191A1A19191A1819
19191919191A19181A1A1A1A1A1A19191A1A191A191A19191A191A1918191A1A191B1919
18191919191A1A1A1A1A191B1A191A1A1A1B191A1A191A1A1B1A1B1A1B191A1A1A1A1A22
1B1A1B191A1A19191B1A1A1A1A1A1A1A1A1B1A1A1A191A1B191A1A1A1A19191B1B1A1A1B
191A1A1A1A1A1B19191A1A1A1919191A1A1A1A1B1A1A1B191A191A1919191B1A1A1A1A1A
1A1A1A1C1A1B1A191A1A1B1A1B1A1A1A1B1A1A1A1919191A1A191B19191919191A19191A
1A19181A1A1A19191919191A1919191A1919191A1A1A1A19181A191A19191A19191A191A
1A1A19191A1919191A18181918181919191A1919171919191A19191A1917191819181919
19181918191918191918181B19181A1919181A191A1918181819191819191918181A1919
181918181919191919191917181818191A1719181919191A1818191719171918191A1A19
191819191A18181A1A18181A19191A1919191A1A1A181A191A19191919191A1A18191A19
1A18181A1818191A
1918191918181A191A1818191B191A191A19191819191A19181819191918191818181819
1919191A1819191A181819191818191A19191A181918191B19181919191A1A1819191918
191A19171919191919191918191918191A191919191919191A1918191A19191A19191918
19181B1A19191918181A171818191A1A191A1A1A1A191A19191919191B19191A191A1918
1A1A191A18191A1A1A1A191A19191B191A19191A19181A1A1919191A1B1A1918191A1A19
1A19191A1A191A191A191A191A191B19191A1A19191A1A1B1A1A191A1B1A1A1A1A19352C
1D1A1A1A181A1A1B1B191A1A1919191A1B1A1A1A191B1A1A1A1B1A19191A1A1A1A1B1B19
1B191A1C1B191A1A19191A1A1A1A191A1B1B1A1A191A1A19191B1A19191A19191B1A1A19
1A1B191A181B1A1B1A191A1A1A1A19191A191A191A19191B18191A191819191A191A1A19
191B191A1A18181B1A19191A1A1A19191A18181919191A191A191A19181919181B191A18
181918181819181A1A191919191A191A18191A19181A191A19191918191A191919191919
18191A19181918181919191A171A191A18191918191919181818191818181918181A1819
1919191918181817191919191A1A191A1819191B191818191818181918191A1A18191A1A
19181819191A181A1A1A191A18191A1A1A19191919191919191A1A1A191A1919191A1919
1818191918191918
1A1A18191A191A191A1A18181918191A18191919191718181A1A1A1A1919191919181918
1818191919191919181A1A1819191A1819181819191918191919191A1919181919181917
191917191819181919171919191A1A191A181A1918191A19191919191819171919181918
191919191A191919181A191B1919191A1918191A181A1919181A1919191919191A191919
1919191A1A19191A1A1A1A181A191A1A1918181819191A191B191A191A191B1A1B1A1A19
1A191A1A19191B1A1A19191D1B1A1A1A1A191A191B191A191A191A1A1B1A191A191A1A1A
1A19191A1A1A1B1A1A1A191A1A19191B1B1A1B1B191A19191A1A1A1B191A1A191B1A1A1A
1A1A1A1A1A191A1A1B191A19191A1A1A1B1A191A1A1A1A191B191919191A191B1A1A1A19
1B1A1A19191A1A191A1A1A19191A1A1A1A1A1B1B1919191A19191A191919191A19191B18
191A191A191A1919191919191A1919181A1A1918191A191819181919181A1A1819191819
1A181919191918191A1818181A1818181919191819191A18181819191919181918181918
1819191919191919181919191819191A1A19191919181819191918191919191918181919
181818191717181818191818171919191918181A19191817191918191918181718191819
191919191A181A191918181A1A191B1A1A191A1A1A1A191A1919191A1919191A19181919
1919181818191918
191A18191918191918181918191B1A1919191819191A18191919191A191919181919191A
19181A181918191818181A1A1918181A19181A191A1919191918191A19191918181A1919
1A1919191918191918181918191A181918181A1A191919191919191A1918191818191A19
19181918191A19191919191819191A1A1A1A181A191919191A191918171919191A1A1919
1B1919191A1A1A1A1A1A1A1B1A191A191919191919191A191A1A19191A1A1A1A19181B19
19191C191A1A1A1A1A19181A1B1A1A1A1A191A191A1A1A191A191A1A1A1A1A1B1A1B1A1B
1B1A1A1A1A191A1B191A1A191A1A19191A1A1B1A19191A1A19191A1A191A1A19191A1A1A
1A191A1B19191A1919181A1B1A191A1A1A1B19191A1B191A19191A1A1A1A1A1A1A19191A
1A1A1919191A1A19191A1A1A1A19191A1B1A19191A191A19191A1919191A1A191B1A191B
191A191A19191A19191A1919191A1919191A19191A1A1919181819191A19181A1A191919
191A191A1A1919191819191919191A1918191818191A18181A1918181819181918191918
191A1A1919181A191A1919191919181A181819181819191A1918191A191819191A191919
1918181818181919191A19181A191817191919191917191918191918191819191A191919
18191819191918191A181819191A1919191A1A1A1919181918191A1A1A19191A1819171A
1819181918181918
18181A181A1819191918191719181B1A191919191A191A18181919191919191A19191A19
181818181919191819191919181819191A191918181818191A1919191919191819191819
181819181818181919191A191819181819181919191918191A1918191919191918191A1A
1A1919181A19191A1918181919191A19191A1A1919191819191918191A1A191A1B191919
1A181B191A1A1A191A1919181B1919191A191A1A191A1B1A19191A1A1A191A1A1B19191A
1A1B19191A1C1A1A1A1A191B1A1A1A1A191A1A191A191A1A1A191B1A1B1A191A1A1B191B
1A1B1B1A1A1A1A1A191A19191A1A1A1A1A1A1B19191A19191A19191A1A191B1A1B1A1A1A
1A1B1A191A1A1A191A191A1A18191B19191B1A1A1A1B1A19191A1A1B1A1A1B1A1B1A1A19
19191A1A191B1A1919191A191A191B191A191C1A1A191A1A1A1A191A191A1A191A191919
1818191A18191A1A1A191919191A1919191A1919191A1B1918181A19191A1A1A19181A1A
191A181918181A18191818191A171A191919191919191A18181919191A18181919191919
1919191918191919181A18191819191A181A191A181919181818191A181819191A191818
1919191819181A19191919191A19191818181918181A1A1919181A181918191919191819
19191A1919191819191A19191A19191A191A181919191919191819181919191818181819
1A1A191818191819
1A18181918191A1A191719191819191919191918191919181A19191B191B181819191918
1918191A19191918191919181818191918191A191819191919191A1818181A191919191A
1919191819181919191919191919181819191818181A1A1719191A191A191A1819191A18
1A1A191818181919191A1A181A191A191A191819191A1919181A191919191919191A1919
1A1919191A191A1A1A1919191A1A1A19191A191A1A1918191A181A191A1B1B1A191A1A1A
1A181B1B1A1A19191A1B1B1A1B1A1A1B1A191A1A1A1B19191A1A1A1A191B1A1B191B1B1B
1A1A191A1A191A191A191A1A1A1A1A1A191A19181B19191A191A1A191A1A1A1B191A1A19
19181919191A191A19191A191A191A191A1A19191A1A1A1A1A1A1A19191919191919191A
1A1B191A191B191A1A1A1A191B191A1A191A1A191919191A1A191A1919191A191A1A1919
1A1A1A1919191A1A1818191A19191A1919181919191919191A18191A181819191718181A
19191B19181919181A19191A181A191918191919181919181919191918181A1819191A19
19191919191A1918191919191819191819191819191919191819181819191A1919181818
19181819181A1919191A1819181819191A19191918191A18191A181919191818171A1818
19191818191819181919191B1919191919191A1919191A18191A1A191A1A181919181A18
1919191917181819
191918181919181819191919181A1818191819191919181918191A191919191918191918
19191819191819181819191918191A181A191818191A1A1918181919181A191919191818
1919181A191919171819181A19181818191918181A1A1919181919191919191A18191917
1A191A1919191918191919191819181919191919191918191A19181919191A191B18191A
191A191A1A19191A19191A1A1A191A1A19191A191A191A191A1B19191A1B1A19191A191A
1A1A191A1A1B1B191A1A1A191A1A1A1A191A1A1B1B1B191B191A1A191B1A1A1A191A1D1B
1A1A1C1A1C1A1A1A1A18191A191919191B1B19191A19191A1A191A191B19181B1A1A191A
1A1A1A1A1A1B1A1B1A191A1A191A191B19191A1A1A191A1A1A1A1A1B1A1A1A19191A191A
1A1A1B1A1B19191A1B1A19191A1A1A1A1A1A19191B1919191919191A1A1A191A1919191A
1B19191919191A1A1819191919191919191919191A19191819191A1A1A19191819191819
191A1A191819191919181A1819191919181819191818191919181B19191817181919181A
191819181819191918191819181919191A191919191A181819191A19181A191A18181919
1A19191919191918191718191919181A181A1919181818181819191A1817191918181818
191918181A19181819181A191819191919181819191A19191A1A19191A19191A19191919
1919171919181919
1A19181919191919191919191819181917191919191B191919191919191A191819191818
1819191919191A19181819191919191A181919191A19191919191A191919191819191918
19191A191918191B1A181819191A18191A1A18191919191918181918181818181819191A
19191A19191918181A1A1819191919181918191A181919191A191819191919191A19191A
191819191A1A191A1A1919191918191A1A1A1A1A181A1B191A18191A18191A1A1A191A19
1A1919191A1A1A1A19181A1A1A191A191B19191A1B1A1B1A1B1A1B1A19191A1A1A1B1B1A
1A1B191A1A1A1A1A1A19191B1A1919191A1A1A191A191A191A181A1A1A191A1B1A191B19
1A1A191919191B191A1A1A1919191A191A1A1A191A191B191A191A1A1A1A18191A191A1A
19191A19191A19191A1A191B1A191A1A1B19201918191819191A1A1A191919191A1B1819
191A19191919191A191A1A191A181A1A1919191A191A1B19191A1A1918191A1919181918
19191918181919191A1819181A181A181819181919181919181819191819191918191918
18191A191919191A1818191918191A181919181917181918181917181919191918181718
181819181819181918181919191818181819181A181918181719191819191A19181A1918
1918191818181919191919191819181719191A1A1919191919181919191A191819191918
1A1919191A181919
1819191A1919191918171819181919191919191819191818191A1919191A19181918191A
19191919191919191919181819191A1A18191918191918181919181A1919191919181919
181819191819181918191918191819191918191A1A1919191A1B19171819181917191918
1A18191A191919171818191719181919191A19191A19191A1919191A191A1A1A1918191A
191918191A1A191A1B1B1A1A19181A1A191A1A1A1A191A1A1A1A1A191A18191A1A1B1A1B
1B1A1A1A1A1A19191A191B1A191A181B1A1B1A1A1B1A1A1B1A191A1A191B1A191A1B1A1A
19191B1B1B19191A191A191A19191A1A1A1A19191A191A1B1B191A1A19191A1A1A1A1A1A
1A1A1A1A19191A1A1A181A1A191B1A1B1A1A191A191A1B1A191B191A1A191A1A1A19191A
1A1919191A181A1A1A1A1A191A18191A1A1B1D191A191919191A1A1A1918191A191A1A19
191A1919191B181919191A1919191A1A1919181919191A19191A19191A191818191A191A
19191819191A1818191A1A1919191919181A191A191819191919181A1A19181817181919
1919191A19181918181A181A18181819191919191A191919191818191A18181818191918
191717171819181818181918191819191818191819191A1919191819191A181919191919
191A181819191A1A181A191A191818191A181819191818191919191A181A181919191A19
1A1918191918181A
19181819181918191A1A191A191818181A191A19191A1A191A191A191B191919191A1817
18191919181919191A191819181A19191918191A181718191A1919181918181A191B1A19
1819191A1919191917191A19181A191818181A191919191918191818191A181A191A191B
181819181A19191819191819181818181A19191919191A191919191A19191A181A191919
19191A1A19191B191A1A191A1A1A19191A1A1A1919191A191A1A191A181919191A1A1B1A
1A1A1A1A1A1A1B1B19191A1919191A1A1A1B1B1A191A1A1A1A1A1A1A1A1819191A1A1A1A
1A1A1B191A1A1A1A1A19191A1A1A19181A1A1B1A1A191A191A1B1A1A1A1B1A191A1A1A1A
1A1A1A1B1A1B191A1A191A1B1A19191B1A191A191A191A1A1A1A191A191A1A191A1A1A19
19191A19191A191A1B1A1A191A1A191A191A1A19191A1A191A1A19191A1A191A19191919
19191A19181A18191A1A1A191A1A1919191A1A191A1A1A19191819191918191919191A18
191A1919191819181A1919191A191A191819181819181718191918191A18181919191719
1A181918181A1A1918191918171A18191819191919181917191818191918171817191819
181918181819191919181918181A181819181817181919181918191918181919181A1818
1A191918181819191918191A1919181919191A1A181A191919191A1919191A1919191919
1A191A1919181819
19181819191A181818191A1A1919191A18191A1919191A191A1A1A1A1918191919171919
19181919191A1919191918191919191819191918191A1A1A1919191919191919191A1818
19181919181819181A191818161819181918191917181A18191818181819191819191918
1918191A181819191919191919181A191A1A1919191919191A181918181C1919191A191A
1A1A1A19191A1A1A1A191A1A19181A1A1A1A19181A19191A1A191919191A1A191A1A1A1A
191A1A191A1A1B1A1B1A1A1A191A1A1B19191A1A1B191A1A1A1A1B1A1A1B1A1A1A1B1B1A
191A1A191A1A1919191A1919191A1A1A181A191B1A1A191A1A1A19191A1A19191A1A1A19
19191919181A1919191A191A1A191A1A191A1A191A19191A1A19181B1A1A1A191A191A1A
1A191A181A1A1A1A181B1A18191A1B191A1A191A191A181A19191A1A1B191A1A19191919
191A1A181A1A19191A181A19191919191A1A19181A1A1A18191719191919191818191919
18191918191919181A181A191919181918191A18191919171A18191A181A171818191919
19191817181819181A1919191918191919181918181919181A181918171717191A191819
181719181818191818181718191919181818191919181918181819171918191819181919
191A1918191719191918191A191A191919181818181919181A1B1A18191918181918191A
1919181818181819
19181918181919191919191919181819191A1819191A181A191A1B1A191919191A191918
1A1918181919191A19191819191A1919191919181919191A19191818191818181919181B
1918181919191719191A18191918181919181819181919191917181918191A1918191919
19191919191A19191A191918181919191919191819191919191A191A1A1A1A191A19191A
1919191A1919191819191A1A1919181A191919181918191919191A1A1A1A1A19191B1A19
1B19191A1A1B1A1A1A1A1B1A1B191A191919191A1A1A1A19191A1A191A191B19191B1A1A
191A1A1B1B191A18191A1A1A1A1B191A1A191A1A1A1B1A191919191A19191A19191B1A1A
191A1A1A1A1A1A191A1A191A1A1A181A1A1A191A1A191A191A191A1A1A1A1A1A191A1A19
1A1A191A1919191A1A191A1B1A19181A1B1A1A1A19191A191A19181A1919191A181A1918
191919191A1A19191A181918191919191A181819191A1A18191A1919191A1A1919191919
1918191819191818191A191A19181918191919191A181919191919191919191818181919
18181818181819191919181718181919181819191819181A1A181A191819191919191818
191919181918191818191818181918181917181919191919181919181818191919181919
1919181818191919191919191919181A1919181918181819181919191919191919191919
181919191A191A18
181818191919181A191919181919191A181919181819191A191A1A191A1A1A19181A1A19
19191919191A191819191A181919191A191A19191819191819181818191819191919191B
1918191918191918191919181A191918191818181A191919191A19191819181A18191818
191919191919191819191819191A19181819191919191919181819191919181A1819181A
1A1919191A19191A1A191A1A1A191B191A1A1A1A191A1A191A1A1A1A1918181A1A19191A
18191A1B1A191A191A1A191A1B1A1A1B1A1A1A1A191A1A1A19191A1B1A1A1A1A1A1B1B19
1C1A1A1A181B1A191A1A1A1A1A1A1A1A1A1B1A1A181A1B1A19191A1B1A1A191A1A1A1B1B
1A1A1A1B191A1B1A191A181A191A1A191B19191A1B191A1A1A191919191A1A191B1A1A19
1A191A1A1B1919191A1A1A181A1A181A1A1A191A1A191A1819191A1B1A19191A191A1A19
191A191A181A1A18191918191A181A191919181A18191919191919191A19191A191A1A19
191A19181918191919191919191919191918191818181919191918191919181919191818
19181919191919191A191A1A191A1819181918191919191919181A181919181819191818
191919181919171918171719191818181618191818191819171A19181918191919191819
181818181A1919181919191919181918191918181818181919191918181918181818191A
1919191919191819
191918191A19181A191A18181A19181918181A1919191A19191B191A1A18191919181919
191919191918191A19181819191919191819191919191919181818181818191919191818
1919191819191A19181918191A181818181A181818191819191719191918191918181918
19191919191A1B1A191A19191A1B1819191A181A1918191A1B191918191919191A18191A
1A19191A191A1A191A19181A191A191A191A191A1919191A191A1A1A191918191B19181A
1A1B1A1A19191B1B191A191B191A1B1A1A1A1A1A1A1A191A19191A1A1A191A191B1A1B19
19191919191A19191B1A1A1A1A1B19191B1A19191A1A191A181A1B191A1A191919191A19
1A1919191919181A191A191A19181919181A1B1A1B191B19191A19191A1A1A1A191A1A1A
1A1A191A18191A1919191A1A1A1A1A1A1A1A19191A19191919191A181819191B1918191A
1A191B1A1A1A191919191A1919191818191A1A191B1B191A191A1918181A181819191A19
191918191A191A18191A181919181919191A19191919191919181918181A191918191819
1919191917191819181919191919191919191919181A19191819181A1817181918181717
1818181819191A1917191818181819181819181818181819191918181919191919181819
1819191917181918191A19181A1918191919191A191A1818191818181918191819191819
19171A1817191619
19191918191919191819191819181919191918181A191919191A19191A19191A1919181A
191818181B1A181919191A17191A19181819191819191919181A19191919191919181918
191919191819191819191819191919191819171818191919191919191919191A19191819
19191A191917191918191A19181A1919181A1919191A191A19191819191819181A19191A
191B1A19191A191A191A19191A191A191A1A1A1A1A191919191919191A19191A1A191A1A
1A1A191A191A1A1A1A191A18191A1A1A19191919191A1A1A19191A1A191A1A191A191A19
1A1A1A1A191A1A19191A191918191A19191A1A1A19191A1A19191A1A191B191A1A1A1A19
1A1A191A19191A191A1A1A1B1A1B191A191919191A191A1A1B191A191A19191919191A1A
1A191A191A1A19191A19191A191A1919191A1919181A191A1A1918191A19191A1A18181A
181919191918191A1A1A191A191A19181919191A1A191918191A191919191B1A18181919
1818191819191918181919191A191A1918191818191A1819191819181819191919181818
181A1817191919191919181A171919181918191919181918181917181918181918171918
18191918181A18181A191818181819181818181918171918191719191819181819191818
191819191819191A181918181A18191919181919191A19191719181918191819181A1918
19181A191A191818
1A181819191B1A1819181819191A19191818191B191A19191C1A1A19191919191A181818
19191919191919181918191A1919191A191A1A19191A18191A181A1A1818181819191918
181919191A18191919181818181A181A1819191917191817191919181919191819191819
181919181818181919191918191919191919191A1A191A1919191A191A1A1A191A191919
191A1A1A181A191819191B18191A19181A191A19191A191B1A1A1B191A1A1A191A1A1A1A
191A1A1A191919191A191B1A191A1B1B1B191A1A19191A1B1A1B19191A1A1B1A1919191A
1A1A181A1A191A191A191B19191A19191A1A191B1A191A1A19191A1B1B1A1A181A1A1A1A
1A1A1A1A1A191A1A1B1A1919191A1A181A181A19191A191B1B19191B1919191A191B191A
1A191A1A191A19191A19191B191A1B19191A191A1A1A191B191A19191A1A191A19181919
181A191918181919191A191918191A1A1818191919191919181A1A191A1919191A191919
1A191918191A18191918181A19191A191919191A181A1A191A1919181919191918191819
191919191919191819191A1919171919181919181819191A181918191918181818191917
171919181918181719191819191817181719191918181819191A19181819181918181818
1919181918181819181818191918191918191917181819191918181918191A191A191819
1919191918181819
191819191A191A191918181A1818191919181A1A191A191A1A1A1A181819191919191919
1918191819191A191918191919181918181919191A181919191918191918181919181818
1918191A1919191918181819191819191918181918191818181818191818181919181918
19181918181A18181918191A19191A191B181919191A1A191918191A191A19191A1A1A19
19191A191B19191A1918191A1A1A1A1A191919191A19191A191A191A1A1919191A1A191A
191A1A1A191A19191B181A1B1A1A1A191A1A1A1A191A1A1919191A1B1A1A1A19191A1A1A
1A191B1A191A191A1919191919191A1A1A191A1B1A1919191A191B191B1A1A1A1A1A1A19
1A19191A191A1A1A19181919191A1B1A1A1A1A1919191A19191A1A1B1A191A1A1A191B19
1A1A1A1A191A1A19191A191A1A1A1A1A191A1B18191A18191A191A19191A191B1919191A
191A191A1919191918191919181A191919181919191918191819191A1A1919181A1A1919
191A1A191919191A1A191A1819191A19191A181919191A1817191A19191A19181A191818
1918191919181A17181918191A191A181A19191818191819181917191918191818181918
181718191918191919191819181917181A17181A1918181918181817181919191A181918
1919181919181919191818191919171919191919171919171918181A1A19181819191918
1918181A18181819
19171A1819191819181917191B1A1919191919191A1A1A19191918191918191A19191919
18191A181A19191818191719191919191919191919181919191919191919181818191919
191919191A1919181819181919191A191918191918181919191919181919191A181A1919
1A18191A181819191919181A181A19191A18181A191A181A1918191A191A1A191A19181A
19191A1A19191A18191818191A1A1A191919191A191A1B1A1A1A19191919191B191A191A
1A191A1A1B1A1B191A1819191B1918191A1B1A1A191A1A1A1A1A1A19191B1A1919191A1A
1C1A19191A1B191A191A1A1A1A1A1A1A1A1A1A191818191B1A19181B191B1A1A1A18191A
1A191B1919191B191B191A19191A1A191A1A1A1A1B1919191A191A191A1A191A191A191B
1A1A191A1A1A1A1A1A1A1A1A1A19191A1919191A191B19191A191919181918191A191918
191A1918181919191819191B191919181A18191A191A191919181819191A181919191819
19181A1A191919191A19191A1A191918191919181A1918191A18181A18191919191A1818
19181919191A18181918181A191919191918191818181819181919191819181A17191919
18191818181818191719191819191A181919181A1818181919181919191A171819191918
1A1919191A19191919191818191918181818191819191919191918181918181819181918
1918191818181819
1918181A1A18191819191919191919191919181919191A1A191A1819191819181919191A
1919191818191919181A1918191919181919191718191818191919191819191919191819
18191918191A1818191918191918181719181819191818181A19181A181A191A181A1919
18191819181919191919191B1919191819191819181919191B19191919191A1919191A19
191819181A1919181A1919191919191918191A1A191A191A191A1A191A191919191A1A1A
1A1B1919191B19191A1919181A1A191A1B1B19191A1A1A19191A1A1A1A1A1A1A1A1A191A
1A1A1A19191A191A19191A181A191A19191B1A1A1A1A1A191B1A1A1A1A1B1A191A191A1A
1A191A191918191A1919181B1A1A1919191A1A1B1A1A191A181A19191A191A191A1A1A19
1A1A19191919191A1919191A191A1B1919191919191919191A191A1919191A19181A191A
181A1A191A18191A1918191A19191A1A191918191919191A191A1A191819191919191819
1A19181A19191918191A191A1919191819191817191918191A19191918191A19191A1919
1819181819191919181A1919191817181819171918181A1819191A191919181818181919
191819191817181918181819191A19191818181818191719191918191818181818191819
1819181817171919181917191818181817191A191817181818191718181A181917181818
1819181917181819
18181919181819191819181A191919191B18191A181A1B181A191918191919181A1A1919
181919191818181919181B191A19191818181A1919191919181A19191919191918191918
19181A17191818181719181A18181918181819191A171819191919181919191818191918
191918191919181819181919191919191A191A181A19191819181A191A18191919181919
191A19191A1A1A181A19191A1919191A1718191A1918191A1B1A181A1A19191A191A1A18
19191A1A191B1B19181B1A1A1A1A1A191919191A1A1A1A181A1A19191A1A1A1A191A1A1A
1919191A1B191A1B1A1B1A19191A1A1A191A1A1A191A1A191A1A1A191A1819191A181A1A
1A1A1A1A1A1B1A181B1B19191A1A1A1A1B19191B1A191A1A191B19191A1919191A1A1919
1A1A1A19191A1919191B1A19191B1A1A1A19191A1A191A191A1B18191A19191819191819
1919191A19191A171918191919191919191819191819191919191A18191919191A191A19
1919191819191919191919191A1A19191A1919191A191A191A1919191919181819181A19
1A181919191919191A1918191A191919181818171818191A191918181817181A19181819
191918181819181A1919181918191918191819191818181A191917191818181A17191917
19181918191818181818181819191818181818181919181A181A18181919171818181919
1819191918181819
1A19191919191819191818191A1819181919191919191A181A191A18181A1A1A17181919
1919191A18181A1919181818191819181919181817191918191919181919191919191A19
1A1818181918181919191918181919171819171919181918191819191818181819191918
1819181818191818191917181819191819191819181919191A191919191818191A191918
1A1A181A1A18181A191918191918191B181A18191A18191A1A191A191A1A1A1B191A1919
1A1A191A1B191A191B191A191A191B19191919191A191B1A191919191A1B1B1A191A1A19
1A191A1A1A1B1A1A1A191A1A1A1A1A191A1A191A19191919191A19181A1B1A1A1B1A181A
1A1A191A1A1A1919181A191A19181A1A1B1A1A1A1A191A1A1919191A1B19191A1A1A191A
191A1A19181919191A19191919191A1A19181A1A191A1A19181A191918191A19181A1918
18181918181919191A1A1919181918191918181A1A1A1A1A1919181A1919191A19191919
191919191919191919191919191A1919191A18191919171A181A19191919191919181918
191A1919181919191918191A191818181819191919191918181819181919191919181818
17181A181718181917181818191718181818181818191818181818181919191918191A19
191918171A18181A1A171818181A18181817191819191A17181819181819191918191918
17181A1719181819
1817191A1919191A191917191A1919181917181919181A18181818181819191819191919
1A1919181B191A1919181819181919181A18171A181918191919191818191819191A1819
191919191819171918191A1819181918191A18191917191A191918181917181919181A1B
19191919191819191919191A191A19191A1919191A19191919191919191A1A191919191A
191A191A191A191919191A1A191A191A1A19191818191A1A1A1B1B1A1A1A1A1B191A1919
1A1A191B1A191A1919191A191A191B1A1A1A1A1B191A191A1A191A191B1A1A18191A1A1A
1A191A191A181B1A1A1A1A1B1A1A18191A1B191A1919191A181A1A1A1A1A1A191A1A1A1A
1A19181B1A191A1A1A1A191A1A1A1A191A1A1B1819191A1A1A1A1A1A1C191A191A1A191A
1A1A1A1A191A1A19191A1A191A1A181A191819191A1A191A19181919191A1A1A191A191A
1A191A1918191A191A191919181819191918191A1B19191A1819191A1818191819191A19
1918181A19181819191919191818191919191819181A191A181918191919181919191A18
1919191819191919191A19181918181818191818181818181818181A1819191918181918
18191819181718191819171819171819181819181A181918191917181A1A181818191818
191919181A19191917191819191819171919191718191818191919191818181818181819
171A181818181818
191918181818191919181819191919191919181918181919181A18191918191818191818
1918191A1A19191819181A19181919181A18191A1919191A1919191918181A1A18191A19
1919181A191818181818191918191819191919191A1818191918181A1918181819191919
19181818181918191918181A1A191A181818191A18191A1A1A1A1919181A18191A19191A
1A1A1A18181A191A191A1A1918191A191A181919191A1B1B181A191A1A1A1A19191A1A19
191A1A1A1A181B1A1A1B1A1A1A1B1B1A1A1A1A1A1A1A1A1A1A19191A191A1A191A1A191A
191A1A1A1A1A1A1A1A1A191A191B1A191A191A1A1B191A191A1A18191A1919191A1A1919
1A191A181B1A1919191A191A191A1919191A1A1A19191A1B191A1A191A1B1A1A1A181A1A
1A1A1A191B19191A1A1A19191A1A1918191A1A1919191A1A191A191919191819191A1A19
191A1919191919181A191919181819181918181A1A1A1A18191A191A19181A191A191918
18181A191A1A191A19181918181919181A19191819191919181919191819191A18181919
1A191B19191A1A19191819191819191819191819181819181818191A1919181819171819
17171A191819191919181818191A1818181718191818171818171A181918181818181818
19181A19181819181919191818181818181818171919191A181A1818191819191A181818
181A181919181819
1919191918191918171819191919191A1A1918191A1818181919181A181A171918181A1A
191919191A19181918191819191A1818181819191918191819181A191819191919181819
19191A1A1919191918191A181919191919191A181919191919181819191919191A191918
18171A191919191818181A191819191A19191A1A19181919181A1919191A1A1A1A191919
19181A1A1B1919191A19191A191A19181A1A1919191A19191A19181A1A1A19191A1B1A1A
1A1A1A1A191A1A1A1A1A191B1B1A1A191A191A191A191A1B1A1B1A1A1819191A1B1A1A19
19191A191A1A191A191A1A1919191B19191A1A1B191A19191A1A18191A1A1919191A191A
1919191A191A1A19191A1B1A191A191A1A191A1919191A191919191A1A19191A1A1A1919
1A1A1A1919191819191A19191A1A18191918191919191A1919181A1A191919191A191919
18191A18191A19191919191919191A191A191A19191A1819191919191919181A1A1A1919
1818181A1819191A1919191B19181918181A19191918191819181919181819191A1A1A19
1919191A1A1819191A18191919181919191A181919191819181919191A18181817191918
18181918191818171818191918191818181A191918181917181819191819191818181919
1719191A1A19181A181818181819181918181918191A1919191918191818191818181917
191A191A17171818
191919191B1918191918181A19191819191818191A19191918191A1A1919191819181919
191A1718191919191919191919191818191819191919181919181A1918181918191A1918
181819171A181919181A1819191817181818191A18181918191918191919181A19181919
191919191A1A1A191818181A171818191A1A191A191A19191A1A181A19191A1A1A1A1919
1919171A191A19191A19181A181A1A1919191A1A191919191A1A1A1A1A1B1A1A1A191A1A
1A1A191A1A1A1A191B191A1A1B1B19191A1A1A1B1A1A1B191A1B1A1A1A1A1A1A19191918
191A1A191A1A19191A1A1A1A191A191A1919191A1A181A1A19191919191A18191A1A1919
191A181918191A1B1A191A1919191A1A1A1A191A1919191A191A191A191A1A1A1A1A1A19
1A1A191819191A191A1A1A18191A1919191919191A19191919191919191919191A1B1919
19181919181A191A181919191919181919191A19191A191919191B19181918181A191819
18191919191818191A191A19191A191719191A171819181A191918181918181818191918
1818191919181919191A191A18181919181818191918191819181818191919191A181918
19191A18191918191918171818191819191A171819191918191919171718191819181818
191A1918191918191819181818181819181818171919191817191919191A1918181A1819
1917191818191819
191918191819191A191919191919191A1818191819191819191818191A18181918191919
1818191A1A1A191A19181A19181A191919181B1A1818181A19181619191919181918191A
18181919191A191919181918191919181818191819171818191919181919181919191819
18191918181918181A191A191918191A191819191919181919191919191B191A1919191A
191919191A19191A19191A1A1A1A1B1919181A1918191A1A1A1A191A1A191A1A1A1A1919
191A1A1A1A1A19191A1A1A191A1A1A1A1A1B1A1A191A19191A1A1A1A191B19191A1A1919
1A191A191A1B191A1A1919191A1A191A1A1A1A191A1B191A191A1A1A1919191A1A191919
1A1A1A1A1A1A1A19191A19191A1A19191A191A191A1919191A1919191A181A1A191A1A1A
1919191819191A181A1A1B1B1A1A1919191A19191A191A1A1B19181919191819191A1A19
191919191A1A1819181A1A1819191918191A1A18191918191A1819191919191918191919
1A181A19191A1A19181A1819191819191918181A19191818191919191819191818191819
18191A17181718191A1819181A1A1819191919191A1817191A1917181919181A19181818
1918181818181916171818181718181A1819191918181818191818181719191819181919
181917181918171919191918181818181918181918191919191918191818181A18191919
1918191917181819
19191818181A1819191819181919191818181A1818181A191819191A19191A18191A171A
1819191A1A19191A1918191819191A1919181919191918191A1918191818181A1918181A
181918181818181819191919191818191919181819191A191A1A18191819191918191918
1A19191A1919181A1A1A19191A1A18191B1A18191A1B19191A18191A1818191A19191919
191A191918191819191A181919191A1A1917191A191A1A1A191A1A1A19191A1A1A191A1A
191A1A1919191A191A1A1A191A191A19191A1A1A1A1A1A1A1A1B1B191A1A1A1A191B191A
1B191A1B191B1918191A1B191A19191919191A181A19181A191A19191A1A1919191A191A
1919191919191A1A1A1A1A1B1A19181A191A191A1A1A1A19191919191919191919191919
1A1A191919191A191A1918191919191A1919191A191A1918191A181A1B1A191817191A19
19191A191A1A19191A181919191A19191919191919191918191818181818181819181818
19171719191A1A181919191A18181819191919181A1A19191919191A18191A17191A1919
1918181A18181A181919191718191919191A181919191819191717191818191918191919
1918181919191719191A19191A1A181818191A181818171718181A191819191919181A19
19181917191918181918181A18171918191918181A191819171919181819171919181818
1819171818191719
19181818191A1918191A19181819191819191919181A19181818191818191818191A1819
1918191A191A191919191A1A191919191818191918181918191A1719181A191B181A1917
1A19181A1A181918191918181919191818191818181A1919181A181A181A191918191919
18181818191819181918181919191A181818191919191919191A19191A191A1918191919
1A191A1A19191A19191A191A1A1A1A1A181A1B191A1A1A1A191A1A1A1B1B1A191A191B19
191A191918191A1A1B191A1B191A1A1A1A1A1A1A191A1A1A1B1A191B1A1B1A1A1A1A191B
191A19191A191919191A1B191A1B191A1A1A1A1A181A1A1A1A1A1A191A1919191B181919
18191A191A1A191A191A1A1A1A191A191A19191A1A191A19181B191A19191A1A1A1B1819
1A1A1A191A1A1A1A1A19191A1A1918191A1A1A1A19191A1A191919181918191919191919
191919191819191819191A191A191A191A1819191919191919191A1A1918191918191819
1A19191919191918191A1918191918191919191919191918191818191A18181919191718
19191A18171A191917181719191919181A18181918191819191919191818191918181819
18191818171817181918191918171819191917181918181919181818191818181817171A
1818191919191819181A1819181818191919191918181819181919181A19191918181819
1918181818171819
1918171A191A1A191918191819191818181919191919191A191919191A1919181818181A
191A19191918191A191A1918191818181919181919181918191919191919191919191819
191919181A181A1A1817181819171918181A1819181A1A191A18181A181918181A191919
191918181919181A18181A191918181919191A191A1A1B191A191819191918191B1A1919
19191A1818191919191919191919191919191A18191A1A1A191A191A191A191A191A191A
1919191A19191A1B191A1B1B1A1B1B1A1A1A19191A1A191A191A191A191A19191B19191A
1A1A1A1A1A1B1B1A191A191A19191919191A1A181A19191A18191919191B1A1919191919
1A191A1A1A191B1A1A1919191A18191919191919191A1B181A191A191A191A18191A1A18
1A1A1919191A191918191A1819191A1A191A1A18191919181A19191A1919191919191A18
1819191919191A1819191819191A18191A19191919181819191918181918191919181919
19191A181A1A18191919191919181A18191919191918181A1918181A1917171A181A1917
19181818181819191A191918181919191918191A18181719191819181718181819191919
1918191918181918181818171818181817181918181919181A1918191818181A17181818
18181919191918181918181818181717181818181819181819181A1A191A191919181819
191919191719191A
19181818181818191818191A191A1918181919181A19181A1818191A19191A191919191A
19191A19191A191819181A191919181919191919191A18191919191A1919171919191A18
1A19191819181819191A19191A1918181819191819191919191918191919191818181918
191818191919181919191A1919191A191A191919191A18181919191A1919191A191A1919
1918191A181A1A1A1A1919191A1A1A191A1919191A18191A1A1B191A1A1B1A191A1A1A1A
1A1A191A1A19181A191919191B1A1A191A1A1A1A1A1A19191A1A1A191A1A1A191A191A1A
18181A19191A19191B191A1A19191A191A191A1A1A191A1A1B191919191A181A1A191A19
1A18191A191A1A1A191B1A191A1A1A191A1A1A181A181A191A1A191A1919191A1B1A1919
191918181A19191A191A191A181A1A191A1A19191A171A191919191A1A1A19191A191819
181919191919181A1919191918191A1818191818191A18191A1A1919181A191819181918
1919191A1A191A19191819191A18191919191A1919191818191919191819191818191A19
181918191918191818181918191918181817171817181918181818191818181818191818
1918181918181918171919181818181819181819181919181918181819191718191A1918
1A18191819191818191818181818181819191818181819191919191A181A1A1919181918
1817191918181719
1919191718191A18191A181A1918191918171819181918181819181A191919191A1A1919
1A191A19191A1B1B1819191A19191918171A181918181718191A1A1A1A19191818191919
171917191A18181819181A19191918191919181A191919191918181A191919181A181919
181A171A1918181918191919181A181919181A191919191A19191A191A19191A1A181918
181A19191A191A18191A19191A191819181A191919191A19191A191919191A19191A1A19
1A1A19191A1A181A1A181A1A1A1A1A1A1A1A191B1A1A1A191A1A1919191A1A1B181A1A18
191A1A1A1A1A19181A1A191A1A1A1A1B19181919191A1B19191A1A1B19191A191919191B
1A1919191A1A1A19191A191A1A19191A191A1A1A1918181A1A1B1B1A19191A1A181A1A19
1918191919191A19191A1A181A191918181A1818191919181918181A19191A191A191918
1A19181818181919191A19181A181A1B1818191918191A1A19191A181919191919191919
1A1A19191919191819191818191919191919181819181817171919191819191918191919
181A1A181919191918191819191819181919181819181918181818171718191818181918
18181819181818181819191818181818191A19181819181817191818191919181A191818
18191917181A191919181918181919181919191818191818181919181A18181918181718
1818171919191719
19191A18181719191818191A181A1919191919191919181918181A18191A181918191918
191A191A181B1A1B1919181819191A191A1819191818181918191A19181918181A191919
181A191919191A1819181818191918181919181918191918191918181919191918181919
19191819191A181919191919181818191A181B1A19171A1A19191A191A1A1A181A191919
19191919191918191A191B191A18191819191A1A191A18191A1A1A191A1A19191B1A1A1A
19191B1A19191919191A191A1A191A1A1A1A191A1A1919181A1A1A1A19191A1919191A1A
191A1A1A19191A1A1B1B1919181919191A191A1B1A191A19191A1A1A1A1A1A1A1A191A19
1A18191A1A191A1A1919191B1A1A19191919191A19191A1A191A1A191A1919181A191A19
191919191A18191A191A19181919191A1919191A1A1A191A17191A1A1919191A19191818
181A191819191A1819191A1919191A19181818181A19181919191A181919191A191A1818
1A1817181919181A19191919191819191919181918181918181918191919191719181A19
19181A181818191919181A19191919171918191818181818191819191919181818181A18
1918181819181719181819191717191818181818191A1819181818181918191818191918
19181918191A181817191918191919191819181817181818181A1A191919181919181918
181919181A181818
191818191818191A191819191818191A19191818191819181A1A191A191819191A191919
181A1A1A1B1A191A191A181A1A181819191919181A1819191919181919191A181A1A191A
1A1919181918191819191919191818171A191818191919181B1919191A19181A19191918
1919181A19191919191A18191919181A1919171919181A19191A19191918191A1A1A1A1A
1A191918191A19191A191919181B1A19191A191A181919191A191919191A19181A1A1A1B
1A191A191A1B191A19191B1B1A1A191A191A1A1A191A191B19191B191918191A1A1A1B1A
1A19191A1A191B1A1B19191A191919181A1A18191A19181819191A1A1A1A1A1819181919
1919191A1A1A191A1A1A1A19181A1A1B191A1A1A1A191A191A191B19191918181A191A1A
1819191A19191A191919191919181A18191819191A1A19181A181918191A1A1918181818
19191A181719191A19191A1919191B1B19191A191919191A19191919191A191919191919
1A19191918191A1A1818181A1918191A19181819181918191A1919181919171718181919
181A19191A191818181918191918191919181919181818181A18181819191819191A1919
181818191918181819191918181818181819191918191819171819181919171718171718
19191818181818181918191817191818191818181918191919181918191918191A191918
1718191919181819
1A181819191A1918191819191819191A191919191919191918191A181A1919191818191A
19181A1A1B1A1B1B191A18191A1919191919181A18191918191A1919191818191A1A191A
191A18191918191819191719181919191919191919181819181918181A1A181919181918
1A1919191A191919191A181A191A191919191A18181B1919181918191A19181919191A1B
1918191919191A1A1A191A1A1919181A181919191A1A191919191A18191B1919191A191A
191A191A191A1A191919191A1A1A191A191A191B1A1A1A1B1A1A1A19191B191919191A19
1A19191A1A1B1A19191919191A1B19191918191A1A1A18181A19191B1A1919191A19191A
1A1A191918191919191A1A1919191B19191A1A1A1A191A191A19191A181A1919191B1A18
1A191819191918191919191A1919191A1A19191A19181A1A19191A181919191919191919
1A1919191A191A1A1A191A181A1A1C1B1A1A191A191819191A1818191919191A19181919
19191B1A191818191A191919191919191919191919171A1819191817191918191818181A
1919181819191A1A19181818191819191919181819191919181918181918191718181819
1818181919181819181718181A1917181718181919191919191A19181819191818191919
1918181818191719181A1919191819181A18181919181918181A19181A19181A18181819
1918181819181819
1919181919181A1919191819191A191819191918191919181919191A191A191919191919
1A1919191A1A1A1A19181819181919191919181A191919191819191A191918191919181A
1919191A1A1A191A19191A191819191718191819191919181818191A1918191918181A19
191918181A191A1819181A19191A19191A1919191A1A1A1919191818181818181918181A
1919191A191A1919191A1A1A191B18181A19181918191A1919191B191A1A1919191A1A19
1A191919191A1A191A181B1A191A1A1B1B1A191A1B191A19191A19191A191919191A181A
1A19191A191B191919191918191A191B19191B1919191A1A191A19191A1A1A191A1A191A
191A1919191A191A191B1A19191A1A1919191A19191A19191B19191A1A1A181A19191919
19191918181A1919191A191919191A191A191A18191A19191919181B1B19191919181A19
181919191A191919191A191919191A1A18191919191A1919181819191918191919191919
1A1B1A1A1919191918191A1A19191A1919191918181918191919181A1919181A19181919
18191A181819191A191919191919191719181919191918181919191918181918181A1818
191818181918171917181818191819181819171917191918181918191818191819181819
191B171818191818181818181718191A1919191818191918181818191819181918191819
1919181819171719
19181818181A19181919191918191A1919181919191819191A191919191A1A19191A1919
19191A1A1A1A1B1A1919181A1919181A1919191918191918191A1A1A1A1A191A19191818
1919191A19181A181A19191919191819191818191818191919181A1A191A191919181819
1A1819191A191919191919191A1919191A191A181A19191A1819191A191A191918191918
1A191919191A191A1A1A191A191A1A191A18191A1819191A1A1A1A1A191818191A191B1A
191A1A191B1A1A1919191A1A1A19191A1A18191B1A1A191A1C1A1A191A191A1A1919191A
181A19191A1A1A1A1A191B191A19191A191A1A1919191A1A1919191A191A1A1A19191B19
1A191A19191A1A1B19191A1819191A1A1A191A1A1A1A1A1B19191A1A1A19191918191919
1A1919191A1819191919191919191919191A18181A191B19191A19191919191A19191A19
19191A191A1A19191919191A1A1A19181A19191A1919191A19181A1A1719181A1A191A1B
1C211C1B1A1A19191A19191A19191918191819191919181919191919181A181A18191918
1919181918191919191819181A191819181A1A191917181A19181A181918191917171818
181819181918171818181818181918181819181919181919181818181819191919191818
1819181918181919181918191819191918181818181918191A1919191817181A191A1917
1918181718181718
19191819181918191A18191719191819191A1919191A191918191A1918191A1A1A191A19
1A1919191A1A19191A191919191919181A181A19181918181A1819191918181919191919
19181A1A1919181A19181819181919191918191A181919191919191A1919191919191919
191A18191819191A19191A1A1919191A191A1A1918191A19191A1A1A1819191919181919
1A181919191A19191A1A19191919191A1A1A1A19191A1A19191A1919191A191A1A1A1919
1A1A191A1A1A1A191A191A1A1A1A1A191A1A1B1A191A191A1A1A191A19191A1B191A1919
19191918191A1919191A18191A1918191A1A1919191B191919191A1A1A191B1A19191819
191A181A191A1A1A1A1919191A19191919191A181918191A191B1A191A181A1A1918191A
19191A19191919181A18191818191918191919181918181918191819191919191919191A
1918191919181A1A1A1A18191A1918191A1B18191A18181A19191919191818191A1A1B2B
69BE5D1D181B181819191919191A191A1817181918191818191819181919191918181C19
19181918191918181819191919191819191918181A191A18181818171817191918181819
1819181919191817181919191918181818181818191A1718181818181818181818181819
181817181818181818191918181918191919181919191918181818181818191918181819
1919181819181719
1918181918191A1819191A1919181B191919191819181918191919191A1819191A1A1919
191919191B19191A1819181A1A1818191A191A1919191819181919191818181B19191919
181819191A19191819191819191719191818191918191A19191A18191A1A19191A191819
191A19191A1A19181919191A19191A191A19191919191919191A1A181819191A18191A18
19191A1B1A191919191918191A191A1A181A19191819191A19191919191A191919191918
1A19191A19191A1A191A1A1A19191A191A1A1B1A1A19181A1919191A1A1A1A1A1A191B19
191A181A1A191A1919191A1A1919181B191819191919191A1919191A191A1A191A1A1A1A
19191A1A1B191A1A1B1A19191918191A1A191A1A191819191A191819191A191919191919
19191A18191A19181A191918191A191A18191819191A1A191A181A1918181A18191A1819
1A191A1A1A1A191A19191A19191A1A1919191A191A18191A1A181918191919191A181821
F3FFB0201119191919191918171919181819191819181A19191819191818181818181818
18181819181918191918191918181A191A19191819191818181818181818181918191918
191819191917191818191819181718191819181918191719181818171719181918181818
18191919191817191818181819181818191819191919191B19191919191A191918181819
1719191818191A19
1919181918191918191919191A191918191A1A19191A1B191A191A18191A191A1A1A1919
1A1819191A1A1A19191819191A1919191819191919181819191A18191918191919191919
18191919191A17191919181A19171918191717181919191A1A1919191919191A1A181918
18181919181A191919191A1919181A19181A191A192019191A191819191B19191A191819
1A1A19191A1919181919181A191A191919191A1919191A1A19191A191A191A1A1A1A181A
191A1A18191A1A1A1B1B1A1A1A1A191A1A181A191A1A1A19191A1A1A1919191A191A191A
1A1A1A19191A191A1B191A19191A191919191A181A1919191A1919191A1A19191A191A19
191A1A19191A19191A181A1A18191919191A181A191A1A1A19191819191A1919191A1A19
1819181819191A19191A191919191A1A181A19191919191918191919191919191A191919
1A1A1A1919191A19191A1A1A1B181A181919191919181919191918191918191819191A18
090006000C18181818191A1819181819191A1A1919181819191819181918181919191919
191918181818191819191819181918181919181918181919191818191918181818191917
191818181818181918181918191718171819181818171819181A18181918181918191717
181819181918181818191919181918181819191919191818191919181918191A191A1819
1819181919181918
191919181A19191B191819191A191A19191819191819191918191A191A191B1A191A1A1A
191A1A191919191918191A1919191919191A1A191A19181A191919191818181919181919
1918191A181919191919191719181919191917191A191718191A191A1A18191A18191A19
181A181919191A181919191B1919181A19181919191D1A191919191A191B1A191A19191A
19191A19191A1819191A191A1A19191A19191A1B1919181A19191A1A1919191A1A191A1A
1A19191919181B1A191A1A19191B1B1A19191A1A1A1A1A19191A191A1A1A191B1919191A
1A1A1A1A19191919181A1A191A1A191A1A1A1A1A191A191819191A181A1A191A1A1A1A1A
191A1919191B1A191A1B191C191A191A1919181A191A1A1A191A18191819191A1A191A19
1B191A181919191A1A181819181A1919191918181A1A191A1819191919191A181A1B1B1A
19191A1919191819191919191A1A19191A191A1919191919191919191919191A19191818
0E03050A18191818191A1818191819191918191818181817191919181818191819181919
181718191818171818181918181819171819181919191819191919191918181919171818
191818191819181918171919181818181A18171818171917181A19171818181719171819
18191A19181818191818181918191B1819191A18191919191819191A1818181819181818
1918191918191818
1A19181919191A1919191A1918191819181818191919181A1A1A1919191A19191919181A
1A1919191918181919181818191819191A19191818191A19191A1A191A191919191A1A19
19181A19181A1818181819191719171819191818191A1818191919191919181A1918181A
19191A191A1919191A1819191A18191A191918191A181919191A191A1A1A19191A1A1919
1919191B19191819191A191A1919191A1A191919191A18191A1A191A191919191A19191A
1A1A19191A1A1A191A19191919191B1A1A1B19181A191A1A1A1A191A19191A191919191A
1A1B191A191A19191A1A19191A1A1819181A191A191A1A1A1919181919191A1A1A1A1919
191919191A19191A1A1919191A1A19181918191A191919191A191A191918191A19181819
1A1A1B1A1919191A19191919191A19191919191A19191A19191919191A19181919191919
1919191819191A19191A1A1A19191919191A1A1B19181919181A1919191919191918191A
18151A181819191A1819191919181A1819181918191A17191919191A1819191819191819
191819191A181919171A1919191A191A1918191818191918181818191919181819191818
1819181717171819171819181818181818191818181818191A1719181818171818181818
1819171818181918181919191819181A1A1818191919191A191819181818191819181919
1A19191817191818
1918191919191B181818191A1A191A19191819181A191819191A1A191919191A191A1919
191919181A19191A19181818181A191818181A191A181919191819191A19191918191919
1919191A19191919181919181A19191A1A181918191919191A191819191A181A19191819
1919181919191A1A1A191A191A191918191A19191A19181918191819191B191A1A1A1919
1A1A1B181A1A1919191A1A181A1A1B1A1A19191A1A181A191A191919191C1B1A19191A19
1A1A191A1A19191919191A1A1A1A191A191A1A1818191A19191A19191A1A1A1A1919191A
1A1A191A1A1919191A1A19191A191B1B181A1A191A191A1A191A191A18191A18191A1819
191B1919191A1A191A1A1A191A1A1A19191A191A1A1B1A19191919181A1918191A1A1A19
1A18191919191A1A18191A191919191919191918191A191919191A1919191918191B1A1A
1B1A191919191B1A19191A181A1A1919191A191A1A1919191A19181A1A19191919181919
1A191919181818181A191919191A181917191919191819181A181918181A1A1819191919
1818181A18191A19171918171A1918181918181919181918191919181919181818191818
191818191819181819191719181918181818191818171818181918191718191718181718
18181918181919191819191A1819191919191A1918191918191919181919191819191917
1818191918181819
19191819191A19191919191A19191919191A1918171A191A1A19181A1919191B1A191819
19191919191A191819181919191A1A191A1919181A181919181919191918181919181818
181A1A191918191919191919191919181A1A181918191918191819191819181A19181918
1819191A1918191A191818191919191919191B1919181A19191919181A1A1A1919191A19
1A191919181A1919181A19191A19181A19191A1A1A19191A1A18191A191A191A191A1A19
1B191A191A19191919191A19191919191A1A1A1A191A18191A1A1A18191A1819181A1A19
191A19191B19191A1A1A1A19191918181A191A1919191919181A1A1A191A1A1B1A1A1A1B
1A191A1A1B1A1A1A1A1A191A191A19191919181917181A1A1A1A181A191A1A171A1A1A19
1A19181A191A191919191818191818191918191918191919191A191919191A191A1A1A1B
1A1B18191918191A19191A18191919191A19191A19191A1A1B1818181919191919191919
1919191A18191919181A1917191819191919191A18191918181918191919181818191818
1918181919191919191A1919181918181817191819191919181818181818181919181918
171919181818181819181818191819181718191918171818191819181719181918191818
181818181819181918181818191A191B1919191719191919181918191919181918191818
1819191817191819
191819191A19191919181918191A191A18181919191A191A191A19191918191819191919
191A191A1918181A191A1919191A191A1A19191A1A1A191819191919181A19191819181A
1A191819191919191919181918181919191818191A1A1A19191A1A1919191918191A1A19
181919191A19181A19191919191A1A1919191819191A191A191819191A18191918191A1A
191A1819181A19191918181A1A191A1A191919191A191B1819181A191A191A1919191819
1A1A191A181A1919191A191A1A18191A1A1A18191A1A191A19191A1A1A1A1A19191B1919
1A1A1A191919191B1A1A1A1A1A191919191A191A1A181A1919191A1A191A1A1A1A1A1919
191A1A1A1A191A191919191A191A1A191A1A1B1819181A19191A1919191A1919191A1919
19191919191A19191A19191A19181819181919191A1919181819171A1A1919191919191A
1A1B1A19191A191819191B181A1A19191A1A191A191A191A191A1A191819191819181918
1A181919191819191919191918191A19191A19181A1919181918191A1919191918181818
18181918181818181918181A191919191919181919181719171819191819181918181919
18191818191717181A19181918191819181818181719191818171819191917181A181818
19171918181818181919191A18191B1B1919191919191A181819181A1A19191918191919
1718181819171919
191919191A181A19181819181A191A191919191A19191A1918191919191A18191919191A
191A191A19181A191918181919181A191A1A191919191A191918191819191A1919191818
19191918191919181919191A191918191719191919181819191919191A18191819191A19
1A1919191A191B181A191919191A19191819191A19191A191919191A18191A19191A1A1A
1A1A181A1A1B1A1A191919191919191A1A1A1819191A1A1A19191A1A1A1A191B1A1A191A
19191A1A19191B19191A1A19191A191A1A191A1A191A191B1A1A1A1A191A191A1B191A1A
19191919191919181A191A191A1A191A19191919181919191A1A1A1A19191A1A191A1A19
1A1A19191A191A1A19191A19191818191A1A1A19191919191A19191A1C19191A1A181919
1819181A1B191918181919191A191919191918191918191A181A1A19191A1A1A1A191A1A
1A1A19191918191A1A191919181918191819191A1918191A191A1A181A18191918191919
19191818191A191A1919191919181A19191819181A181918181719181818181818191919
1817191919181719191918191A181718181919181919181A181819191818181919181817
181818181918191818181718181819181818171918181918191817171A18181718191717
191A1A18191819191A1718171819181A1A19191819181819191A1818181919191A181818
1919191919181719
181A181819191A1919191A19181A191A1A1B191919181A1818191919181819181A191A1A
1A1A1919191A1A1A191918191918191A1A191A19191919191919191819191A1919191A19
19191919191A19191919191919181919191A18181A1A191A181A1A191919191A191A1A19
191819191B19191A1918191A1919181919181A19191A1A181A1919191919181919191A19
19191A19181A1A191A18191819191B191919181A1A1A1A1A1B1A1919191A19191A181718
1A191A1A191B1A1A191A1A1B1A1A19191A1A1B1B1A1B1A191919191A191A1A191819191A
18191A191919181A1C1A191A19181A1A18181918191818191919191A191919191A1A1A19
1A19191A1A191A19191919191A1A191A1919191A191A191919191919191A19191A1A1919
1A1919191919191A1A191919191918191A1A191919191A1A19191918191A181819191918
181A191919191A1A1919191A191A19191A1A1A1A191A19191A19191818191A1919181918
1918191A191A19191719181919191A1918181918191818191A181A181919191819181718
181817181918181918171919191919181819191818191A19191818181819171918181918
181918181A181718191718191A1818191818171717181919181718181719181918181818
19171918191819181A1819181919191B1A19191918181A1A19191A181919181A171A1917
1817181818171817
19191A191919191A19191B191A191A1A1918181918191919191819171919181919191A19
19181919191A1A19191919191A1919191A19191A1A1A1819191A191A1919191A1A19191A
18181A19191A1A1819181919191A19191919181818191A1A1A1A191A1919191A191A1917
191B1A191A1A191919191A191A1A19181919181919191919181A18181919191A19191919
19191A1A1A1919191A1A18191919191A19191A19191819181A1A1A191918191919191A1A
1A1A1A191919191B1A1A19191A191A1A1A1A191A1A19191A1A1B1A1A191A1A191A1A191A
181A19191B191919191919191A19191A1A19191A191919181A18181919191A181A191A19
191A1A191A19181B191A19181A1919191919181A191A19191A19191A19181A1918181919
1819191A1A19191819181A19191918191A19191919181A1819181A1919191B19191A1919
1919191A1919191A1A1A1A191919191919191A1A1A19191A1A1A19191919191919191819
1919181A191818191819181719191918181818191918181A1917191A1819191918181918
1919181919181A1918181819191819191A181A19181919181918181918181A1818191819
1918181718181918181818181818181718171818181718181818191A1918181718191819
171818181818181918181818191918191918191819181918181819191917191818181818
1818181918181719
1A191919191918191919191919191A18181918191A19191A191A19191818191919181B19
191A1919191A191919191819191A181A1A19171919191919191A19191918191919191A19
1A1A191A191A19191A1919191918191A191919191919191A191A181B1A1A191919191919
191A191A191B191919181919191919191A1819191A19191A1A19191A19191A1819191819
191B181A1A191A19191919191A191A1A19181A1A191918181A19181A1A1A191818191A19
181A191A1A1A191A1A191A1A1919191A191A1A1A18191A1A191B191A191A191A191A1819
1A19191A1A1A18181A191819191919191919191919191A1A19191A19181919191A19191A
191918191B1919181B1919191A19181B19191A191A1B19191A19191A191A191A1A19191A
181919191A1A19191919191B191B1619181A1A191918191A1A191A18191A19191919191A
1A1919191A19191A1A18191A181A1918191A191B1A191A1A1A191A1A1A1A1819181A1919
1919191919191A1A181918181A1918181818191919191918171918191919181818181818
191919181819191818191818181819181919191919191A19181818171817181918181819
181817171818191818181818181918181818181818171817171818181818191818181817
18181919181818181818191918181A191819181A181A1919191818181918181819181717
1819191817181618
1A191918181919191A191A1A19191A1A191919191919191819191A19181919191A191919
191B191A19191818191A19191918191A1A1A191A1A1A1919191A1A1A191A1A19191A191A
191819191918191A1919191B1919181A181A19191A1A18191A19191B1A19191B191A1919
1A191918191A19191A1A19191819191A181B18191A191A19191A18191A191A191A1A1919
1A1A191A1A191919191A18181919191A1A1A191A191919191A1A1A1A191A1919191A191B
1919191A1B1B1A1A1A1A1B1A191B1A191A1A191A18191A19191A191A1A19191A1819191A
1A1A1B1919191A1919191A19191A1B191A1B191A19181A1A1918181A1A1919191B191A19
181A19191A191A191A1B1A191A1A1919191919191919191A1A1A1A191A191917191A1A18
1A18191A1918191919191819191A17181A1A191A191A1919191719191A191A1819191919
18181918191A191A181A1818191919191A191A191A1A1A1B191919191919181919191918
1818181919191818191918181A1819181919191918191A19191918191919191919191918
191919181918171818191817191919191918181918181819181918181819181918181918
191819191918191718181818191818181818181819171818171918181818171818181919
1819191918181919191919181A181A191818191818191819181819181818181819191818
1819191817191718
1819181A1918191819191A1919191A1A19191719181A1819191A1A19191A191A19191B1A
191A191A1A18191A1A1919191A1819181919181A191A191B19181A19191A1A1919191919
1819191A181A1819191A181A1A1819191919191A18191A1919191A191A18191919191B19
191A1919191A18191A191919191A19191A19191A1A1919191A1A1819191A1A1B191A1919
1919191A181A181A19191819181A1A191A1A1A18191A1A1A191A1A1A1919191919181B1A
1A1A1A1A1A191A1A1A191A191A1B1A1A191919191A1A19191A1A1A191A1A1A1A19181919
1918191919191819191A1A1919191919191819191919191A1A18181B19191A1A1A1A1919
1919191A191B181A18191A1A191B191A191A191A19181A191A191A181B1A1A1919191A1A
1A19191A19191A1819191A1A1A1A1A1A19191919191918181A19181A181A1A1919191919
181A191919191A1919191919191919191A1A1A19191A1A1A191918191819191A18181918
18191819181819191718191919181919191919181819191819191818191A181818191A18
18181818191918191919171818191A191919191818181918181818191818191818181817
191917181918171918181818181817181918171818181818181818171818181917181917
19191818181819181819191819191918181817191A1819181918191A171918181A181918
1819191918171818
1A19191919191819191819191A19191A191A1A1A191A1A1919191919181819191919191A
19191A1919191B1819191919191A191919191A1919181A191819191919191A1A19181918
19181B181B181919191A18181919181A191A1918181919191A191919191B19191A19191A
1A1A1A1A1A1B19191A191A191819181A1A1918191A191A1A181919191919191A191A1A1A
1A1919191A191B1A1A1A1A1A1919191919191A19191A1A19191A1A191A191B1A1A18191A
1A1A1A1A191A1B1A1A1A19191A191A191A1A181A191A181919191A19191B191A19191919
191919191A18191919191A18181A1A1A1919191B181A1918191A1B1A191919191A1B1919
191919191A1A191B19191B18191819181A191A191A191A19191A191A1819181919191819
191919191919191918191919191A1919191A181A1A1A18191919191A1A191A19181A1A1A
19181919191A191819191A191A1918191A1A1A1A1919191A1919191919191A1B1A19191A
19191919181919181919191A1A1917181918191818191919191719181A191A1918181919
1919191A1917181918191919181819181919191819191818191919191817181919191819
181918181818181818181819181818181717181817171818181718171817171819191718
191918181818181918191819181817181919181818191A18191919171919181819191919
171718191819181A
1918181A19191919191919191B19191A1A1A19191919191A1A19191919191818191A1919
19191A1A1B1A1A1A1A1A19191A18191A171A1919191A191A19191A19191919191A191919
1A19181A19191A1A1919191817191919181B1818191919181919191A1A181A19191A171A
19181A191A1919181A19191919191A19191A19181919191B1A191919191A1A191A1A1A19
1A1A19191A191A1A1A19191919191A1A1A1A19191919191919191A1B1A191919191A191A
1A1A1A1A191A1A1A191B1B19191919191A191A1919191919191A1A191918191A1A191A19
191A1819181A1A1A191A191A191A1A1A1919181A191A191819181B1A1919191A1A191A19
19191A191A1918191819191818191A191A191A1A19191919191A19191918181A18181A1A
19191A19191A1A191A19191819191919181A19191A181819191919191919181719191919
19191919191919191B181A19191A19181A19191A1919191B191918181919181A1819181A
1A191A19191A181919191A191A19191919191817191A1819191919191918191918181A19
18191818181919181917191818191918191818181918181719191818181A181818181817
191918181918181919181819181818161918171718171718191917181818191717181919
181818181919191819191818191819181717191818181818181918171818191819181918
191918181A191919
181A18191A1A1919181A191A191A191A1A181A1819191A191A191819191A191919191919
1A1B1A18181718191A19191819181A18191A19191A191919191A1919191918181A191A1A
181A19191919181A191819191819191918181A19191918191919181919191A18191A191A
1A1A19181A181818191919191A1A1A1A1917181A19181A19191A191A1819191A19191919
1A1A1A1B191A1A19181A1A1919191A191A19191A1919191919191B1A1A1A191A1A1A191A
19191A191A191A19181A1A1A1A191A1A1A181A1918191A191A19191A1A1A1A18191A191A
19191A1A191A191A1919191A191A18191A191A1A181819191919191919191A19191A1A19
1919191A1919181819191918191919181918191A1A1A1A1B1A19181A1A191A1A19191A19
191919191A1A1919191919191819191A19181A1A1A191919191919191A1A191A191A1819
191918191818181919191919191919181A181A1B1A191819181919191819191918191919
1918191919191A18191A191918191A1819191819181A1918191919181918191718191919
19191918181818191A18181A191A1A191818191918181818191717181818181718171918
191819181918181818171919181718181718181719181918181918181817171819181918
181819191819181818181817191918171918191919181817181819181817171817191818
1819191819171719
19181919191918191A191A191A1A18191A1A1A1A191A1819191919181A1A191A1A191919
18191A191B191A1919191919181919191A1918191A1919181A191919191A1919181A1A19
1819191A1818191919191918181A1919181919191918191B18191818191819191A18191A
191A191A19181A191A1A191A1A1A19191918181A1919191B1919191919191A1B1919181A
1A1919191A191A1A18191819181A1A19191919191A1A191A191A1A1A19191919191A1B1B
191919191A1A1A1A1919191A1A1A1A1A1919191919181A1919191B1919181919191A191A
1A191B1A1A191919181A191A1919191A191919191A18191A1919181A19191A1A1A1A1919
1A1919181A1A1A1A191919191A1A1A1919191A191A1919191A1A1A1A191A191918191A19
181A191A1919191A19191A191A18181919191A1B1A191818191918191819191A1A181819
1819181817181A191919191A1A191A181A191A191B1A1A191819191819191919191A1819
191919191919181A191A191919191B19191A19191A19181819191919191A191919191919
181918181719171919181918191918191919191918181818181819181817191818191819
191818181718171818191917181818181819181718181818181718171818191A18181817
191818181818181818181818191817181A18191919191817181919181818171A19191819
1919191818181717
191918191A1A191919191919191919191A19191A191B1A1A191A1A191A19191919181A1A
1919191A1919191919181919191A191918191919191A1919191A1918191A181918181A19
18191A1919191919191A181918191A1919191919191B19181A18191A1A191A1A19191A19
191A1A191819191A19191919191918191A1A191A191919191A1A1918181919181919191A
19191A181A191A191919191A1A18191A1A181A19191919191A1A1B191A19191A1A1A1A1B
1C191A1A1B1B1A1B191919191A1A19191A191A1A181A1A1B1A191A1A191A1A1919191A1A
1A19191A1A1919191919181B1A191919181918191919191A1919181A1A1A191919191919
19181A1919191919191A191A191919191A181B191A1819191B1A191A19191919191A1A19
1919181A1918171A18191A19191A191A191919181919191A171A1A191919191818181919
1A19191A18191918191819171A1919181A191A1A1A19191919191819191918191A191919
1A191A191919191919191A191A1819191919191919181B17181919191919191819191918
17181718191818191918191819191818191A171818181818191818181918191818181818
181918181819171818191818181818181818181718181717191718181818191818181819
18191819181818181718181818181919181817181918181A1A1919191919191817181918
1818171818181819
181817181A181918181718191A1918191817171918191919181818181919181917181918
171718191718171817181818181718171717181818191818191819181819171817171717
181817171818181817191817171718181718191919171816181816181918181918181619
171818181818181918171819191919191918171818181717181819181818181918191917
181918181819171918191818181917171818181817181718181917181718181819191818
181817181819191818181719191A19191A18181818191718181818181818181919191819
191919181818171818171718181818171818181817171818181718191818181819191919
181917181819181717181718181717171718181B19181816171918171918171818181718
181717181917181817191818191816181818181817191918181A18181816181817181718
171918191718171717181817181718161717181917181819181818181617181618171717
181718171818181719191818171718171619181717171718181817171716181816181817
171617161718171716171717171817161717161818171818171717171718161718161817
171718171817171617171716151618171816171616171716171817161818161617171717
171717171717171716171516161717171717161617171916181817171717181816171716
1616171816181617
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{350, 350},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005N0001GR000`400?l00000o`00003oo`3IfMUO
0=WIf@00o`3IfMUO0=WIf@00o`3IfMUO0=WIf@00o`3IfMUO0=WIf@00o`3IfMUO0=WIf@00o`3IfMUO
0=WIf@006`3IfMT2000003@0fMWI1@0000020=WIf@800000103IfMT2000002l0fMWI100000030=WI
f@800000103IfMT2000002l0fMWI0P0000040=WIf@800000103IfMT200000300fMWI0`0000020=WI
f@800000103IfMT200000300fMWI0P0000040=WIf@800000103IfMT2000000P0fMWI000J0=WIf@04
0000003IfMT0fMWI000003D0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@040000003IfMT0
fMWI00000080fMWI00<000000=WIf@3IfMT0;03IfMT00`000000fMWI0=WIf@030=WIf@040000003I
fMT0fMWI00000080fMWI00@000000=WIf@3IfMT00000;@3IfMT010000000fMWI0=WIf@0000020=WI
f@040000003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT00000<03IfMT010000000fMWI0=WI
f@0000020=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT0;03IfMT010000000
fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT000001`3I
fMT001X0fMWI00@000000=WIf@3IfMT00000=@3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI
00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0fMWI0080
fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@00000_0=WIf@050000003IfMT0
fMWI0=WIf@0000000P3IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI02/0fMWI
1@0000001@3IfMT000000=WIf@3IfMT000000080fMWI00@000000=WIf@3IfMT00000<@3IfMT01000
0000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT01@3I
fMT001X0fMWI00@000000=WIf@3IfMT00000=@3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI
00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@0^0=WIf@050000003IfMT0fMWI0=WI
f@0000000P3IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI02h0fMWI00@00000
0=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI02/0fMWI
00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI
000002l0fMWI0P0000030=WIf@040000003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT00000
1`3IfMT001X0fMWI00@000000=WIf@3IfMT00000=@3IfMT01@000000fMWI0=WIf@3IfMT000000080
fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@0/0=WIf@040000003IfMT0fMWI
00000080fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@00000]0=WIf@040000
003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@00000^
0=WIf@030000003IfMT000000080fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WI
f@00000_0=WIf@030000003IfMT0fMWI0080fMWI00@000000=WIf@3IfMT000000P3IfMT010000000
fMWI0=WIf@0000070=WIf@006`3IfMT2000003D0fMWI0P0000040=WIf@800000103IfMT200000300
fMWI0P0000040=WIf@800000103IfMT2000002l0fMWI0P0000040=WIf@800000103IfMT200000300
fMWI0P0000030=WIf@800000103IfMT200000300fMWI0`0000030=WIf@800000103IfMT2000000P0
fMWI003o0=WIfEl0fMWI003o0=WIfEl0fMWI003o0=WIfEl0fMWI003o0=WIfEl0fMWI003o0=WIfEl0
fMWI003o0=WIfEl0fMWI000F0=WIfOl00000B00000010=WIf@005P3IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0:
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0:
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0:
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT02@3IfMT200000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0>P3IfMT00`000000fMWI0=WIf@0k0=WI
f@030000003IfMT0fMWI03X0fMWI00<000000=WIf@3IfMT0>P3IfMT00`000000fMWI0=WIf@0k0=WI
f@030000003IfMT0fMWI00X0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WIfD@0
fMWI0@0000010=WIf@003P3IfMT2000000H0fMWI00<000000=WIf@3IfMT0o`3IfMU40=WIf@400000
0@3IfMT000d0fMWI00@000000=WIf@3IfMT000001@3IfMT00`000000fMWI0=WIf@3o0=WIfD@0fMWI
0@0000010=WIf@003@3IfMT010000000fMWI0=WIf@0000050=WIf@<00000o`3IfMU20=WIf@<00000
0@3IfMT000d0fMWI00@000000=WIf@3IfMT000001@3IfMT00`000000fMWI0=WIf@030=WIf@0601HF
5P0E5AD05QHF01HF5P0G5aL05ADE0`0G5aL301HF5P0401DE5@0G5aL05QHF01LG5`805QHF00<05aLG
01HF5P0G5aL0100G5aL401HF5P<05aLG0P0F5QH00`0G5aL05QHF01LG5`0601LG5`805QHF00@05aLG
01PH600G5aL05QHF1@0G5aL201HF5P0301LG5`0H61P061PH008061PH0P0F5QH301PH60<05aLG0P0H
61P301LG5`0301HF5P0H61P05aLG00<061PH00<05QHF01PH600G5aL00`0G5aL301PH600401LG5`0H
61P05aLG01LG5`<061PH00@05aLG01TI6@0F5QH06ATI0`0H61P0100G5aL061PH01PH600G5aL201PH
600301LG5`0H61P061PH00H061PH00<06QXJ01PH600I6AT0100H61P201TI6@<061PH00D06ATI01PH
600I6AT06QXJ01PH600401TI6@806QXJ0`0I6AT01`0J6QX061PH01TI6@0J6QX06ATI01/K6`0J6QX0
0P0I6AT01P0K6a/06QXJ01XJ6P0J6QX06a/K01XJ6P@06a/K0P0J6QX01@0K6a/06QXJ01/K6`0J6QX0
71`L00@06QXJ00D06a/K01TI6@0J6QX06QXJ01/K6`0401XJ6P0501/K6`0J6QX06a/K01/K6`0J6QX0
0P0K6a/501XJ6P0301/K6`0I6AT06QXJ00H06QXJ00@06ATI01XJ6P0J6QX06a/K0P0J6QX0100I6AT0
61PH01TI6@0I6AT301XJ6P<06ATI1@0J6QX00`0K6a/061PH01TI6@0201XJ6P8061PH0`0I6AT00`0H
61P06ATI01PH600301PH600301TI6@0H61P05aLG00D061PH00<06ATI01PH600H61P01@0H61P00`0G
5aL061PH01PH600201HF5P8061PH00P05aLG01PH600G5aL061PH01LG5`0F5QH05aLG01HF5P805aLG
00<05QHF01LG5`0G5aL0100G5aL0300F5QH061PH01TI6@0G5aL05QHF01DE5@0H61P05aLG01PH600G
5aL061PH01LG5`@05QHF00<061PH01LG5`0G5aL0100F5QH00`0G5aL05QHF01HF5P0301LG5`0401HF
5P0G5aL05QHF01HF5PH0fMWI0@0000010=WIf@003@3IfMT010000000fMWI0=WIf@0000050=WIf@03
0000003IfMT0fMWI00<0fMWI00D05aLG01PH600I6AT06ATI01PH600201LG5`L061PH00D06ATI01PH
600I6AT061PH01TI6@0;01PH600301TI6@0H61P061PH008061PH00@06ATI01PH600H61P061PH0P0I
6AT01`0G5aL061PH01TI6@0J6QX061PH01TI6@0H61P00`0I6AT01P0H61P06ATI01TI6@0J6QX06ATI
01LG5`@06ATI00L06QXJ01TI6@0J6QX06ATI01XJ6P0I6AT061PH00<06ATI00P061PH01XJ6P0I6AT0
6QXJ01PH600I6AT061PH01XJ6PD06ATI0P0J6QX00`0I6AT061PH01TI6@0201TI6@0701PH600J6QX0
6QXJ01XJ6P0I6AT06QXJ01TI6@0201XJ6P0301/K6`0J6QX06ATI00<06QXJ00<06a/K01XJ6P0K6a/0
0`0J6QX02P0I6AT06QXJ01TI6@0J6QX06ATI01XJ6P0I6AT06a/K01XJ6P0K6a/301XJ6P0301/K6`0J
6QX06a/K008071`L1P0K6a/201XJ6P0301`L700K6a/06a/K008071`L00/06a/K01`L700K6a/06QXJ
01`L700K6a/071`L01/K6`0L71`06a/K01dM7@0301`L70D07AdM00<071`L01dM7@0M7Ad01P0L71`0
0`0M7Ad071`L01`L700501dM7@0501`L700K6a/071`L01`L700M7Ad00P0L71`401dM7@0301`L700M
7Ad07AdM00<071`L00D06a/K01dM7@0L71`06a/K01`L700201/K6`0501dM7@0L71`071`L01/K6`0L
71`00P0K6a/01P0J6QX071`L01`L700K6a/06QXJ01`L70806a/K00<06QXJ01`L700K6a/00P0K6a/0
1@0M7Ad071`L01`L700J6QX071`L00<06a/K00D06QXJ01/K6`0K6a/06a/K01XJ6P0201TI6@H06QXJ
00<06ATI01/K6`0I6AT00`0J6QX0100H61P06QXJ01TI6@0I6AT301XJ6P0301TI6@0J6QX06QXJ00@0
6ATI0P0H61P0100J6QX06ATI01TI6@0H61P301TI6@0401LG5`0H61P06ATI01PH60806QXJ00@061PH
01TI6@0J6QX06QXJ0P0I6AT00`0H61P06ATI01PH600301TI6@0301PH600I6AT061PH008061PH00<0
5aLG01TI6@0H61P00P0G5aL01`0H61P05QHF01LG5`0H61P05aLG01HF5P0G5aL00P0H61P201TI6@03
01PH600G5aL0fMWI00D0fMWI0@0000010=WIf@003P3IfMT2000000H0fMWI00<000000=WIf@3IfMT0
0`3IfMT0100J6QX06ATI01TI6@0I6AT201PH600301TI6@0J6QX06QXJ00@06ATI00<061PH01TI6@0H
61P00P0J6QX201PH60806QXJ00<06ATI01XJ6P0I6AT0100I6AT301XJ6P0501TI6@0J6QX06ATI01XJ
6P0I6AT00P0J6QX0100I6AT06QXJ01TI6@0I6AT201XJ6PD06ATI00@061PH01/K6`0J6QX06ATI1@0J
6QX0100I6AT06QXJ01TI6@0J6QX201/K6`D06QXJ00D06a/K01XJ6P0I6AT06QXJ01/K6`0201XJ6P80
6a/K100J6QX201/K6`0301XJ6P0I6AT06ATI00806QXJ0P0K6a/501XJ6P0401/K6`0L71`06a/K01`L
70@06a/K00L06QXJ01/K6`0K6a/06QXJ01`L700K6a/071`L00<06QXJ0`0K6a/02@0J6QX06a/K01XJ
6P0L71`06a/K01`L700K6a/06QXJ01dM7@0201`L70806a/K00<07AdM01`L700L71`01@0L71`201/K
6`8071`L0P0M7Ad00`0L71`07AdM01/K6`0201dM7@0401`L700M7Ad071`L01hN7P<071`L0P0M7Ad0
100N7Qh071`L01hN7P0M7Ad201hN7P807AdM00H07QhN01`L700O7al07QhN01dM7@0L71`401dM7@03
01`L700M7Ad07AdM00@07AdM0P0L71`02`0N7Qh07AdM01dM7@0M7Ad07QhN01`L700M7Ad07QhN01`L
700M7Ad07QhN00<07AdM00H06a/K01dM7@0L71`071`L01dM7@0L71`201dM7@<071`L00<06a/K01`L
700L71`0200L71`01@0K6a/071`L01dM7@0L71`06a/K008071`L0P0J6QX201`L70806a/K00H06QXJ
01/K6`0J6QX06a/K01`L700K6a/301XJ6P0501`L700J6QX06QXJ01/K6`0J6QX00P0K6a/0100J6QX0
6ATI01XJ6P0I6AT201XJ6P0801TI6@0J6QX06ATI01XJ6P0K6a/06QXJ01TI6@0K6a/201XJ6P806ATI
00D061PH01XJ6P0J6QX06QXJ01PH600301TI6@0401XJ6P0H61P05aLG01XJ6P<06ATI00D06QXJ01TI
6@0J6QX061PH01XJ6P0201TI6@0301PH600J6QX06ATI008061PH0P0I6AT01@0H61P06ATI01PH600H
61P05aLG00<061PH0P0J6QX00`0H61P06ATI01PH600301PH60H0fMWI0@0000010=WIf@005P3IfMT0
0`000000fMWI0=WIf@030=WIf@806ATI00<061PH01TI6@0J6QX00P0I6AT00`0J6QX06ATI01TI6@02
01PH60806ATI00D061PH01/K6`0J6QX06a/K01XJ6P0301TI6@0401XJ6P0H61P06ATI01/K6`H06ATI
00<06a/K01TI6@0H61P00`0I6AT201XJ6P0301TI6@0J6QX06QXJ00806ATI100J6QX0100I6AT06a/K
01XJ6P0I6AT201XJ6P0>01PH600K6a/06a/K01TI6@0J6QX06ATI01/K6`0J6QX06ATI01/K6`0J6QX0
6ATI01/K6`0J6QX301/K6`0901XJ6P0I6AT06QXJ01`L700K6a/06QXJ01/K6`0J6QX06ATI00@06QXJ
00<06a/K01TI6@0K6a/00`0J6QX00`0K6a/06QXJ01XJ6P0201/K6`0401XJ6P0K6a/06a/K01/K6`<0
6QXJ00<06ATI01/K6`0K6a/00`0K6a/00`0L71`06a/K01/K6`0201/K6`0501`L700K6a/06a/K01XJ
6P0L71`00`0K6a/04@0L71`06a/K01`L700K6a/07AdM01`L700K6a/071`L01/K6`0M7Ad06a/K01`L
700M7Ad071`L01/K6`0L71`07AdM00806a/K0P0L71`00`0M7Ad07QhN01`L700201dM7@0301lO7`0L
71`071`L008071`L00@07AdM01hN7P0M7Ad07QhN100M7Ad00`0N7Qh07AdM01dM7@0201`L700301dM
7@0N7Qh07QhN00807alO0`0M7Ad00`0N7Qh07AdM01hN7P0301hN7PH07AdM0`0N7Qh401dM7@<07QhN
0`0M7Ad00`0L71`07AdM01hN7P0201dM7@0601hN7P0M7Ad06a/K01dM7@0L71`07AdM0P0L71`201/K
6`8071`L00<07AdM01/K6`0K6a/0100L71`00`0K6a/071`L01/K6`0201dM7@0A01`L700K6a/071`L
01XJ6P0L71`06a/K01`L700J6QX06a/K01`L700K6a/06QXJ01/K6`0J6QX06a/K01`L700K6a/00P0J
6QX00`0K6a/071`L01/K6`0201XJ6P0301/K6`0J6QX06a/K00806QXJ100K6a/00`0J6QX06ATI01XJ
6P0201/K6`0301XJ6P0I6AT06a/K00806QXJ1@0I6AT02P0J6QX06ATI01PH600I6AT06QXJ01TI6@0K
6a/06QXJ01TI6@0J6QX301TI6@<061PH0`0I6AT00`0H61P06ATI01XJ6P0301TI6@<061PH00<06QXJ
01TI6@0I6AT00`0H61P0100G5aL061PH01PH600H61P60=WIf@4000000@3IfMT001H0fMWI00<00000
0=WIf@3IfMT00`3IfMT02`0I6AT06QXJ01PH600I6AT06QXJ01TI6@0J6QX06ATI01XJ6P0I6AT06QXJ
00<06ATI1@0J6QX201TI6@806QXJ00<06ATI01/K6`0I6AT00P0J6QX401TI6@0401XJ6P0I6AT06a/K
01TI6@806QXJ00<06ATI01PH600I6AT00`0I6AT501XJ6P0501/K6`0J6QX06QXJ01XJ6P0K6a/01P0J
6QX00`0L71`06ATI01XJ6P0401/K6`0601XJ6P0K6a/06QXJ01/K6`0J6QX06a/K0P0J6QX0100L71`0
6QXJ01XJ6P0J6QX401/K6`0301XJ6P0K6a/06QXJ00@06a/K00@06QXJ01/K6`0K6a/06QXJ0P0K6a/0
300L71`06a/K01`L700K6a/06QXJ01/K6`0L71`06QXJ01`L700K6a/06QXJ01/K6`8071`L1P0K6a/3
01`L700301/K6`0J6QX071`L008071`L0`0M7Ad501`L70807AdM00@06a/K01dM7@0M7Ad071`L1P0M
7Ad01@0N7Qh07AdM01dM7@0N7Qh071`L00807QhN00<07AdM01hN7P0M7Ad0100N7Qh01@0O7al071`L
01hN7P0N7Qh07AdM00D07QhN0P0O7al201hN7P0901lO7`0M7Ad07QhN01hN7P0L71`07QhN01lO7`0N
7Qh071`L00<07QhN0`0M7Ad201hN7P0301dM7@0N7Qh07QhN00807AdM00<07QhN01dM7@0P82000`0N
7Qh01P0M7Ad071`L01`L700L71`07QhN01dM7@8071`L100M7Ad00`0L71`07AdM01dM7@0501`L7007
01/K6`0L71`071`L01`L700K6a/07AdM01`L700201/K6`0601`L700M7Ad071`L01/K6`0L71`07AdM
0`0K6a/01`0L71`07AdM01/K6`0K6a/07AdM01XJ6P0K6a/00P0L71`201/K6`8071`L00D06a/K01XJ
6P0J6QX06a/K01XJ6P0201/K6`0301XJ6P0K6a/06QXJ00D06QXJ00d06a/K01TI6@0J6QX06QXJ01TI
6@0J6QX06ATI01XJ6P0I6AT06a/K01XJ6P0I6AT06QXJ00806ATI0P0J6QX01P0H61P06QXJ01TI6@0J
6QX061PH01TI6@<06QXJ0P0I6AT0100J6QX061PH01PH600J6QX601TI6@0501PH600I6AT06ATI01TI
6@0H61P00P0I6AT201PH600301XJ6P3IfMT0fMWI00@0fMWI0@0000010=WIf@005P3IfMT00`000000
fMWI0=WIf@030=WIf@0601XJ6P0I6AT06a/K01TI6@0J6QX06ATI0P0J6QX01P0K6a/06QXJ01TI6@0J
6QX06ATI01XJ6P806ATI0P0J6QX201/K6`0301TI6@0J6QX06ATI00806QXJ00D06ATI01XJ6P0I6AT0
6QXJ01TI6@0201XJ6P0301TI6@0J6QX06a/K00D06QXJ0P0I6AT00`0K6a/06ATI01XJ6P0<01XJ6P80
6a/K0P0J6QX301/K6`0301XJ6P0K6a/06QXJ00806QXJ00<06a/K01XJ6P0K6a/01@0K6a/01`0J6QX0
6a/K01/K6`0K6a/06QXJ01`L700J6QX0100K6a/01P0L71`06QXJ01XJ6P0K6a/071`L01XJ6P@06a/K
00<06QXJ01`L700K6a/00P0K6a/01@0L71`06a/K01/K6`0K6a/06QXJ00H06a/K00H071`L01/K6`0K
6a/071`L01/K6`0M7Ad401`L700501/K6`0L71`07AdM01dM7@0L71`00P0M7Ad00`0L71`06a/K01`L
700301`L700501/K6`0L71`07AdM01dM7@0N7Qh00P0L71`01P0N7Qh07AdM01dM7@0L71`07AdM01hN
7P807AdM00/07QhN01dM7@0N7Qh07QhN01dM7@0N7Qh07AdM01`L700O7al07QhN01dM7@0201hN7P04
01lO7`0M7Ad07AdM01dM7@@07QhN0P0O7al201hN7P0501dM7@0N7Qh07QhN01hN7P0O7al01@0N7Qh4
01dM7@0301hN7P0M7Ad07AdM00807alO100N7Qh00`0M7Ad071`L01`L700301dM7@0801hN7P0M7Ad0
7AdM01hN7P0M7Ad07QhN01dM7@0L71`201dM7@0401hN7P0M7Ad071`L01dM7@<071`L00@07AdM01/K
6`0L71`06a/K0P0L71`00`0K6a/071`L01`L700201`L700401/K6`0L71`071`L01XJ6P8071`L00<0
6QXJ01/K6`0K6a/00`0L71`01@0K6a/071`L01/K6`0L71`06QXJ00806a/K0P0J6QX00`0K6a/06QXJ
01`L700301XJ6P0501`L700J6QX06a/K01TI6@0K6a/00P0J6QX0100I6AT06QXJ01TI6@0K6a/201XJ
6P0301/K6`0I6AT06QXJ00D06QXJ00<06a/K01XJ6P0I6AT0100J6QX301TI6@0301XJ6P0I6AT061PH
00806QXJ00<06ATI01PH600I6AT00P0I6AT01P0J6QX061PH01XJ6P0J6QX061PH01TI6@@061PH00<0
6QXJ01TI6@3IfMT01@3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0P0J6QX0
1`0I6AT06QXJ01PH600J6QX06ATI01XJ6P0I6AT00`0H61P00`0I6AT06QXJ01TI6@0201/K6`<06ATI
00<061PH01TI6@0I6AT00P0J6QX00`0I6AT06QXJ01XJ6P0401XJ6P0401TI6@0J6QX06QXJ01XJ6P80
6ATI0P0K6a/0100J6QX06ATI01/K6`0J6QX201TI6@806QXJ00<06ATI01XJ6P0J6QX00`0J6QX01P0K
6a/06QXJ01XJ6P0J6QX071`L01TI6@806a/K100J6QX0100I6AT06a/K01/K6`0K6a/201XJ6P<06a/K
00<06QXJ01/K6`0K6a/00P0K6a/201XJ6P806a/K00<06QXJ01/K6`0L71`00P0K6a/201`L700301/K
6`0J6QX06a/K00806a/K00D06QXJ01/K6`0L71`07AdM01`L700201/K6`0301XJ6P0L71`06a/K0080
71`L00<07AdM01/K6`0M7Ad01P0K6a/00`0M7Ad071`L01`L700401`L700301dM7@0L71`071`L0080
71`L00@07AdM01`L700L71`071`L0P0M7Ad03`0L71`07AdM01`L700N7Qh071`L01dM7@0N7Qh07AdM
01hN7P0M7Ad07QhN01dM7@0N7Qh07AdM01hN7P0301dM7@0801`L700N7Qh07QhN01hN7P0M7Ad07QhN
01dM7@0O7al201dM7@807QhN00<07AdM01hN7P0N7Qh00`0M7Ad501hN7P0401lO7`0N7Qh07QhN01lO
7`@07QhN00/07AdM01hN7P0N7Qh07alO01dM7@0L71`07AdM01lO7`0N7Qh07AdM01lO7`0201hN7P03
01lO7`0N7Qh07AdM00807AdM0P0N7Qh01@0M7Ad06a/K01hN7P0N7Qh071`L00<07AdM0P0L71`01`0N
7Qh071`L01dM7@0M7Ad06a/K01`L700M7Ad0100L71`0100M7Ad071`L01`L700L71`201/K6`0401dM
7@0K6a/071`L01`L70806QXJ0P0K6a/00`0L71`06a/K01/K6`0201`L70<06a/K00<071`L01/K6`0L
71`00P0K6a/00`0M7Ad06a/K01XJ6P0201/K6`0701`L700J6QX06QXJ01XJ6P0L71`06a/K01TI6@02
01XJ6P0401/K6`0J6QX06QXJ01TI6@@06QXJ0P0I6AT00`0J6QX06ATI01TI6@0201TI6@0401XJ6P0I
6AT06ATI01TI6@806QXJ00@06ATI01XJ6P0H61P06QXJ100I6AT00`0H61P06ATI01XJ6P0201TI6@80
6QXJ00H061PH01TI6@0J6QX06ATI01PH600G5aL501PH600301TI6@3IfMT0fMWI00@0fMWI0@000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0401XJ6P0I6AT06ATI01XJ6P806ATI00<06QXJ
01/K6`0I6AT00`0J6QX01@0K6a/06ATI01TI6@0J6QX06a/K00<06QXJ00@06ATI01/K6`0J6QX06ATI
0P0J6QX0100I6AT06QXJ01XJ6P0J6QX201TI6@0401XJ6P0I6AT06QXJ01TI6@<06QXJ00<06a/K01XJ
6P0K6a/00P0J6QX01P0K6a/06QXJ01/K6`0K6a/06QXJ01TI6@<06a/K00D06ATI01/K6`0K6a/06ATI
01/K6`0201TI6@806QXJ0`0K6a/301XJ6P806a/K00@06ATI01XJ6P0J6QX06QXJ0P0K6a/201`L7080
6a/K0P0J6QX01P0K6a/071`L01`L700M7Ad06a/K01XJ6P<071`L00<06a/K01dM7@0K6a/0100K6a/2
01`L70806a/K00P071`L01XJ6P0K6a/071`L01dM7@0K6a/071`L01dM7@@071`L00<07AdM01`L700L
71`00P0L71`00`0M7Ad06a/K01dM7@0201`L70L07AdM0`0L71`201dM7@0801hN7P0M7Ad07QhN01hN
7P0M7Ad07QhN01dM7@0L71`201dM7@0301lO7`0L71`07alO00807AdM00@07alO01hN7P0N7Qh07alO
0P0M7Ad0100O7al07AdM01hN7P0N7Qh201lO7`<07AdM0`0N7Qh201lO7`0301hN7P0P82007alO00<0
7QhN00L07alO01hN7P0O7al0820P01lO7`0N7Qh07alO00807QhN00<07alO01hN7P0N7Qh00P0N7Qh2
01dM7@03020P800O7al07alO00<07QhN00<07AdM01hN7P0N7Qh00P0M7Ad00`0O7al071`L01dM7@02
01hN7P807AdM0P0N7Qh201dM7@0401hN7P0M7Ad07AdM01/K6`8071`L00<07AdM01`L700L71`00P0M
7Ad0100L71`06a/K01dM7@0M7Ad301`L70<06a/K00<071`L01/K6`0L71`00`0K6a/00`0L71`06a/K
01XJ6P0201/K6`0301`L700M7Ad071`L00806a/K00<071`L01XJ6P0K6a/01@0K6a/201XJ6P0301TI
6@0J6QX06a/K00D06ATI00<06QXJ01TI6@0J6QX00P0J6QX0100I6AT06QXJ01TI6@0J6QX201TI6@08
01/K6`0I6AT06QXJ01XJ6P0I6AT06QXJ01TI6@0J6QX201TI6@0501XJ6P0I6AT06QXJ01TI6@0J6QX0
200I6AT00`0H61P06QXJ01TI6@0201TI6@0501XJ6P0H61P06ATI01TI6@0K6a/01P3IfMT100000040
fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00@06a/K01PH600I6AT06QXJ100I6AT0100H61P0
6QXJ01XJ6P0I6AT201XJ6P0301`L700J6QX06QXJ00<06QXJ0P0I6AT201XJ6P0301TI6@0J6QX06a/K
00806QXJ00<06ATI01XJ6P0J6QX00`0J6QX02@0I6AT06QXJ01/K6`0J6QX06a/K01TI6@0J6QX06ATI
01/K6`0201XJ6P0301TI6@0J6QX06QXJ00806QXJ00@06ATI01XJ6P0K6a/06ATI0`0K6a/0100I6AT0
6a/K01/K6`0I6AT201XJ6P0401/K6`0J6QX06a/K01/K6`806QXJ00@071`L01/K6`0J6QX071`L0P0K
6a/01@0L71`06QXJ01/K6`0K6a/071`L00@06a/K0P0L71`301/K6`0301`L700K6a/071`L00<06a/K
0P0L71`301/K6`8071`L00X07AdM01XJ6P0K6a/07AdM01`L700K6a/071`L01/K6`0L71`06a/K0`0L
71`00`0N7Qh071`L01`L700201dM7@8071`L0`0N7Qh03P0L71`07QhN01hN7P0M7Ad071`L01dM7@0L
71`07AdM01`L700M7Ad07QhN01`L700N7Qh07alO0P0M7Ad0200N7Qh07AdM01dM7@0M7Ad07QhN01dM
7@0O7al071`L1`0N7Qh201dM7@<07alO0P0N7Qh201lO7`0501hN7P0O7al07alO01hN7P0O7al00P0N
7Qh01`0O7al07QhN01hN7P0N7Qh07alO01hN7P0P8200100O7al00`0M7Ad07QhN01dM7@0201dM7@80
7alO0P0M7Ad201hN7P0701lO7`0N7Qh07AdM01hN7P0M7Ad07QhN01dM7@0201hN7P807AdM00<07QhN
01dM7@0M7Ad00P0N7Qh00`0M7Ad071`L01hN7P0201dM7@0301`L700M7Ad071`L00@07AdM00<06a/K
01`L700L71`00P0L71`201/K6`0301`L700M7Ad07AdM00<071`L0`0K6a/02@0J6QX071`L01/K6`0K
6a/06QXJ01/K6`0J6QX06a/K01dM7@0401/K6`0501XJ6P0K6a/06QXJ01`L700K6a/00P0J6QX01`0K
6a/06QXJ01/K6`0J6QX06a/K01XJ6P0I6AT00`0J6QX00`0I6AT06QXJ01/K6`0201XJ6P0301TI6@0J
6QX06QXJ00<06ATI0P0J6QX00`0H61P06a/K01/K6`0201XJ6P806ATI00P06QXJ01TI6@0H61P06QXJ
01TI6@0J6QX06a/K01XJ6P@06ATI100H61P201TI6@8061PH00D06ATI01PH600I6AT06ATI01XJ6P06
0=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0200K6a/06ATI01TI6@0J6QX0
6ATI01PH600J6QX06ATI0P0J6QX00`0H61P06ATI01XJ6P0201TI6@0301/K6`0J6QX06a/K00806QXJ
00P06ATI01XJ6P0I6AT06ATI01XJ6P0I6AT06QXJ01TI6@806QXJ0`0I6AT00`0J6QX06ATI01XJ6P05
01XJ6P0601/K6`0J6QX06ATI01TI6@0J6QX06a/K0P0J6QX0100I6AT06a/K01XJ6P0J6QX201/K6`05
01`L700J6QX06a/K01TI6@0J6QX01@0K6a/01@0J6QX06a/K01`L700J6QX071`L00<06a/K0P0J6QX2
01/K6`806QXJ00H06a/K01`L700K6a/06QXJ01`L700J6QX201/K6`0301`L700K6a/06a/K00806a/K
0P0L71`00`0K6a/071`L01/K6`0301`L700801XJ6P0K6a/06a/K01/K6`0L71`07AdM01`L700K6a/2
01`L700501/K6`0M7Ad06a/K01dM7@0K6a/00`0M7Ad0100K6a/071`L01hN7P0N7Qh701`L700501hN
7P0M7Ad07AdM01hN7P0L71`00P0M7Ad201hN7P<07AdM0P0N7Qh01@0O7al07QhN01dM7@0O7al07QhN
00807AdM00H07QhN01dM7@0O7al071`L01hN7P0O7al301hN7P0301lO7`0N7Qh0820P00807QhN00H0
7AdM01lO7`0O7al07alO020P800M7Ad201lO7`<07QhN00X07alO01hN7P0N7Qh07alO020P800N7Qh0
7alO01hN7P0M7Ad07alO0P0N7Qh0100O7al07AdM01dM7@0M7Ad301hN7P0501lO7`0N7Qh07AdM01dM
7@0N7Qh00P0O7al0100M7Ad07alO01dM7@0O7al201dM7@<07QhN0P0M7Ad00`0N7Qh07AdM01dM7@02
01`L700:01dM7@0N7Qh07AdM01`L700M7Ad071`L01dM7@0N7Qh071`L01dM7@@071`L00<06a/K01hN
7P0L71`0100L71`201dM7@0501/K6`0L71`071`L01`L700K6a/00`0J6QX00`0K6a/06QXJ01XJ6P02
01/K6`<06QXJ100K6a/01P0L71`06QXJ01/K6`0J6QX06ATI01`L70806QXJ00<06ATI01XJ6P0I6AT0
1`0J6QX0300K6a/06QXJ01XJ6P0J6QX06ATI01XJ6P0K6a/06ATI01PH600K6a/06QXJ01PH60<06QXJ
00@06ATI01XJ6P0J6QX06ATI0`0J6QX201PH60<06ATI0P0H61P301TI6@0401PH600I6AT06ATI01TI
6@H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0601XJ6P0I6AT06QXJ01PH
600J6QX06ATI0P0J6QX01@0I6AT06QXJ01/K6`0I6AT06QXJ00806ATI00<06QXJ01/K6`0J6QX00`0J
6QX01P0H61P06QXJ01XJ6P0J6QX06ATI01/K6`/06QXJ00<06ATI01PH600I6AT00P0J6QX201TI6@<0
6QXJ00<06ATI01/K6`0I6AT00P0J6QX01P0K6a/06QXJ01XJ6P0L71`06QXJ01/K6`806QXJ00D071`L
01/K6`0J6QX06a/K01XJ6P0301/K6`<06QXJ00<06a/K01XJ6P0L71`00P0K6a/201XJ6PD06a/K100L
71`00`0K6a/071`L01`L700201/K6`0301XJ6P0K6a/071`L00806a/K00<071`L01XJ6P0L71`00P0K
6a/401`L700401dM7@0L71`06a/K01dM7@<071`L00<07AdM01`L700K6a/00P0L71`0100K6a/071`L
01dM7@0L71`201dM7@0701hN7P0L71`07QhN01`L700M7Ad07QhN01`L700201dM7@0301hN7P0M7Ad0
7QhN00@07QhN0`0M7Ad00`0O7al07QhN01hN7P0201hN7P0601dM7@0N7Qh07AdM01dM7@0O7al07QhN
0P0M7Ad02@0O7al07QhN01hN7P0O7al07QhN01lO7`0N7Qh07alO01hN7P0201lO7`04020P800N7Qh0
7QhN020P80807alO0`0N7Qh501lO7`0501hN7P0O7al07QhN020P800O7al00P0N7Qh00`0M7Ad07QhN
01hN7P0501hN7P09020P800N7Qh07alO01lO7`0M7Ad071`L01hN7P0M7Ad07QhN00807AdM00<07QhN
01dM7@0L71`01@0M7Ad00`0L71`07QhN01dM7@0201hN7P0401dM7@0L71`07AdM01dM7@8071`L00L0
7AdM01`L700L71`07AdM01`L700K6a/07AdM00806a/K0P0L71`00`0K6a/071`L01`L700201/K6`03
01`L700K6a/071`L00<06a/K00@071`L01dM7@0J6QX06QXJ0P0K6a/00`0L71`06a/K01XJ6P0201XJ
6P0301TI6@0K6a/06a/K00806QXJ0P0K6a/201XJ6P0601/K6`0J6QX06a/K01XJ6P0I6AT06QXJ0P0I
6AT00`0H61P06QXJ01XJ6P0401XJ6P806ATI00@061PH01TI6@0J6QX06a/K100I6AT0100H61P06ATI
01TI6@0J6QX201TI6@0401PH600I6AT06ATI01PH60<06ATI0P0J6QX01@0H61P06ATI01PH600H61P0
6QXJ00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@806ATI00<06QXJ01TI
6@0J6QX00P0I6AT501XJ6P0301/K6`0J6QX06QXJ00<06QXJ00<06a/K01XJ6P0J6QX00P0I6AT501XJ
6P0301PH600J6QX06ATI00D06QXJ0P0I6AT301XJ6P0501TI6@0J6QX06QXJ01/K6`0I6AT00`0J6QX0
2P0K6a/071`L01TI6@0I6AT06a/K01XJ6P0K6a/071`L01/K6`0I6AT201/K6`0401XJ6P0K6a/06QXJ
01/K6`D06QXJ00D071`L01/K6`0K6a/06a/K01XJ6P0201`L70806a/K00H071`L01XJ6P0M7Ad06a/K
01TI6@0L71`301/K6`0301`L700K6a/06QXJ00@06a/K00P071`L01/K6`0M7Ad06a/K01`L700K6a/0
71`L01dM7@8071`L00<06a/K01dM7@0K6a/0100M7Ad02@0K6a/071`L01`L700L71`07AdM01`L700K
6a/071`L01dM7@0201/K6`0301dM7@0N7Qh07AdM00@07AdM00<071`L01dM7@0M7Ad0100N7Qh0100O
7al07QhN01dM7@0M7Ad301hN7P0301dM7@0O7al07alO00807alO00T07QhN01lO7`0M7Ad07QhN01lO
7`0M7Ad07QhN01dM7@0N7Qh00P0O7al01@0P82007alO01hN7P0N7Qh07alO00<07QhN0P0O7al00`0N
7Qh07alO01lO7`0401hN7P<0820P00@07alO01hN7P0M7Ad0820P0P0O7al0100N7Qh07alO01hN7P0O
7al201hN7P0401dM7@0N7Qh07QhN01hN7P807AdM00P07QhN01lO7`0N7Qh07alO01hN7P0O7al07QhN
01dM7@807QhN00H071`L01hN7P0M7Ad07alO01dM7@0N7Qh501dM7@0301`L700N7Qh071`L00807AdM
00@071`L01dM7@0M7Ad071`L0P0M7Ad0200L71`07AdM01`L700L71`06a/K01dM7@0L71`06QXJ0P0L
71`01P0K6a/06QXJ01/K6`0J6QX071`L01XJ6P806a/K0`0L71`601/K6`0501XJ6P0K6a/06a/K01/K
6`0L71`00P0K6a/01@0J6QX06a/K01TI6@0I6AT06a/K00<06QXJ00@06ATI01/K6`0K6a/06QXJ0`0I
6AT00`0J6QX06a/K01TI6@0301TI6@H06QXJ00<06ATI01XJ6P0J6QX00P0I6AT0200H61P06ATI01XJ
6P0I6AT06a/K01XJ6P0I6AT05aLG1@0I6AT00`0H61P06ATI01TI6@0201TI6@H0fMWI0@0000010=WI
f@005P3IfMT2000000@0fMWI0P0J6QX201TI6@0301XJ6P0I6AT06QXJ00806ATI0P0J6QX0100I6AT0
6QXJ01XJ6P0J6QX501TI6@0501XJ6P0K6a/06QXJ01XJ6P0K6a/00P0J6QX01@0I6AT06QXJ01/K6`0J
6QX06ATI00H06QXJ00<06a/K01XJ6P0J6QX00P0J6QX00`0I6AT06a/K01/K6`0401XJ6P806a/K0P0J
6QX201/K6`D06QXJ0P0K6a/01`0J6QX06a/K01XJ6P0K6a/071`L01/K6`0L71`00P0K6a/201XJ6P04
01dM7@0L71`06a/K01XJ6PD06a/K00<071`L01/K6`0L71`00P0K6a/01P0J6QX06a/K01`L700L71`0
6a/K01dM7@<071`L00H06a/K01`L700L71`06QXJ01`L700K6a/201`L700901/K6`0L71`06a/K01dM
7@0L71`06a/K01`L700M7Ad06a/K008071`L00@07AdM01`L700M7Ad07alO0P0M7Ad01P0L71`07QhN
01dM7@0L71`07AdM01hN7P<07AdM0P0N7Qh00`0M7Ad07QhN01hN7P0201hN7P0501`L700N7Qh07QhN
01dM7@0N7Qh00P0O7al501hN7P0301lO7`0N7Qh07QhN00<07QhN1@0O7al01@0N7Qh07alO01hN7P0O
7al07AdM00<07alO00@07QhN01lO7`0P82007QhN0`0P8200100N7Qh07alO01hN7P0N7Qh301lO7`80
7QhN0P0O7al501hN7P0301lO7`0M7Ad07QhN00807QhN00<07alO01dM7@0N7Qh01@0N7Qh0100M7Ad0
7QhN01hN7P0N7Qh301dM7@807QhN00<071`L01hN7P0M7Ad00P0M7Ad00`0L71`07AdM01dM7@0201dM
7@8071`L0P0M7Ad0100L71`07AdM01dM7@0M7Ad201`L70<07AdM0P0K6a/01@0M7Ad06a/K01`L700K
6a/071`L00806a/K00<071`L01XJ6P0L71`00P0L71`00`0K6a/071`L01XJ6P0201/K6`0501`L700J
6QX06a/K01XJ6P0K6a/00P0J6QX201/K6`0301XJ6P0I6AT06a/K00@06QXJ00<06a/K01TI6@0J6QX0
0P0J6QX201TI6@806QXJ00D06ATI01XJ6P0I6AT06QXJ01TI6@0201XJ6P<06ATI0P0J6QX01@0I6AT0
6QXJ01TI6@0I6AT06QXJ00<06ATI00<06QXJ01TI6@0I6AT00P0I6AT0200J6QX061PH01TI6@0J6QX0
61PH01TI6@0J6QX06ATI1@3IfMT200000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0`0J
6QX01P0I6AT06QXJ01TI6@0I6AT061PH01XJ6P806ATI00@06a/K01XJ6P0I6AT06ATI100J6QX00`0K
6a/06QXJ01XJ6P0201TI6@0401XJ6P0I6AT06QXJ01PH60<06QXJ00D071`L01TI6@0J6QX06a/K01TI
6@0201XJ6P0301/K6`0J6QX06a/K00@06QXJ00H06ATI01XJ6P0I6AT06a/K01TI6@0K6a/701XJ6P07
01/K6`0L71`06a/K01`L700J6QX06ATI01`L700501/K6`0401`L700J6QX071`L01/K6`806QXJ00<0
6a/K01XJ6P0K6a/00P0K6a/301`L70806QXJ0`0K6a/01@0L71`06a/K01`L700L71`06a/K00<071`L
0`0K6a/201`L700301/K6`0L71`071`L00L071`L00T07AdM01`L700K6a/071`L01dM7@0L71`07QhN
01`L700N7Qh00P0M7Ad0100L71`07AdM01dM7@0L71`201hN7P807AdM00H071`L01dM7@0O7al07QhN
01`L700N7Qh201dM7@0501hN7P0M7Ad07AdM01dM7@0N7Qh00P0O7al201hN7P0301dM7@0N7Qh07QhN
00@07QhN00<07alO01hN7P0O7al00P0N7Qh301lO7`0301hN7P0P82007AdM00807QhN0P0P82000`0N
7Qh07alO01lO7`0201lO7`06020P800N7Qh07QhN01lO7`0N7Qh0820P1`0N7Qh00`0O7al07QhN01dM
7@0201hN7P807alO0P0N7Qh00`0O7al07QhN01lO7`0401hN7P0501lO7`0N7Qh07AdM01hN7P0M7Ad0
0`0N7Qh01@0M7Ad07QhN01hN7P0M7Ad07QhN00<07AdM0P0L71`00`0M7Ad071`L01/K6`0601`L7080
6a/K00X07AdM01`L700K6a/06a/K01dM7@0L71`06a/K01`L700K6a/06QXJ0P0L71`301/K6`8071`L
00@07AdM01`L700L71`06a/K0P0J6QX01@0K6a/06QXJ01`L700K6a/06QXJ00806a/K00D06QXJ01TI
6@0J6QX06a/K01TI6@0401XJ6P0301TI6@0K6a/06a/K00<06ATI00L06QXJ01TI6@0K6a/06ATI01XJ
6P0I6AT06a/K00806QXJ00<06ATI01XJ6P0H61P01P0I6AT501XJ6P806ATI0P0J6QX0100I6AT06QXJ
01PH600J6QX201TI6@0301XJ6P0I6AT06ATI00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI
0=WIf@030=WIf@806ATI0P0J6QX02`0I6AT06QXJ01XJ6P0I6AT06a/K01TI6@0K6a/06QXJ01TI6@0J
6QX06ATI00806QXJ0P0I6AT01`0K6a/06ATI01TI6@0I6AT06a/K01TI6@0J6QX0100I6AT201/K6`80
6ATI0P0J6QX01P0I6AT06QXJ01XJ6P0K6a/06QXJ01TI6@806QXJ00D06ATI01XJ6P0J6QX06ATI01PH
600201/K6`0301XJ6P0K6a/06QXJ00<06QXJ00@06a/K01XJ6P0J6QX06QXJ0`0K6a/01@0L71`06a/K
01/K6`0K6a/06QXJ00<06a/K00@071`L01/K6`0L71`071`L0`0K6a/201`L700501/K6`0J6QX07AdM
01/K6`0L71`0100K6a/201`L70807AdM100K6a/201`L700401/K6`0L71`06a/K01/K6`<07AdM00<0
71`L01dM7@0M7Ad00P0L71`301dM7@0301`L700K6a/07AdM00807AdM00@071`L01dM7@0N7Qh071`L
0`0M7Ad00`0N7Qh07AdM01dM7@0301dM7@@07QhN00<07alO01dM7@0L71`00`0N7Qh01P0O7al07QhN
01dM7@0O7al07QhN020P80807QhN0`0O7al00`0M7Ad07alO01lO7`0201lO7`0301hN7P0O7al07alO
00D07alO100P82000`0N7Qh07alO01hN7P0201lO7`807QhN100O7al00`0N7Qh07alO01lO7`0401lO
7`807QhN00P07alO01hN7P0O7al07alO01dM7@0N7Qh07alO01hN7P807AdM00@0820P01lO7`0M7Ad0
7alO0P0N7Qh01@0O7al07QhN01hN7P0L71`07AdM00807QhN0`0M7Ad0200L71`07AdM01dM7@0M7Ad0
7QhN01`L700N7Qh071`L0`0M7Ad201hN7P807AdM00@07QhN01`L700M7Ad06a/K100L71`00`0K6a/0
71`L01`L700301/K6`0401XJ6P0L71`071`L01/K6`8071`L00<06QXJ01dM7@0K6a/00`0K6a/00`0L
71`06a/K01/K6`0201XJ6P0801`L700J6QX06a/K01XJ6P0K6a/06ATI01XJ6P0I6AT201XJ6P0301TI
6@0K6a/06QXJ00806a/K0`0J6QX01@0H61P06a/K01TI6@0H61P06QXJ00806ATI00<06QXJ01TI6@0J
6QX00P0I6AT0100G5aL06ATI01XJ6P0J6QX201TI6@0701XJ6P0H61P061PH01TI6@0J6QX06ATI01XJ
6P0301TI6@0301XJ6P0I6AT06QXJ00806ATI1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0
fMWI00<0fMWI0P0I6AT01`0H61P06QXJ01/K6`0I6AT06QXJ01TI6@0J6QX00P0K6a/0100I6AT06QXJ
01TI6@0I6AT301XJ6P0601PH600J6QX06ATI01TI6@0H61P06QXJ0P0I6AT301XJ6P0401/K6`0L71`0
6ATI01TI6@H06QXJ00<06a/K01XJ6P0I6AT00P0J6QX0200K6a/06ATI01XJ6P0J6QX06a/K01XJ6P0K
6a/06QXJ0`0K6a/02P0J6QX06a/K01/K6`0L71`06a/K01XJ6P0K6a/06ATI01/K6`0J6QX201/K6`03
01TI6@0K6a/06ATI00<06a/K100L71`301/K6`8071`L0P0K6a/301`L700301XJ6P0L71`06a/K0080
6a/K00@07AdM01`L700L71`06a/K0P0L71`00`0K6a/071`L01`L700201`L700501dM7@0N7Qh07AdM
01dM7@0L71`00P0M7Ad00`0L71`07QhN01dM7@0201`L700301dM7@0L71`07AdM00<07AdM0P0L71`3
01dM7@0301`L700M7Ad07AdM00807QhN0P0M7Ad701hN7P07020P800N7Qh07alO01lO7`0N7Qh07alO
01dM7@0601lO7`0301hN7P0O7al07QhN00@07QhN0P0O7al2020P80H07alO00D07QhN01lO7`0O7al0
820P01hN7P0201lO7`08020P800O7al07alO020P800O7al07AdM01lO7`0P820201hN7P807alO00<0
7QhN01lO7`0M7Ad00P0O7al0100N7Qh07alO020P800O7al701hN7P807AdM00<071`L01lO7`0N7Qh0
0`0N7Qh201dM7@0801hN7P0O7al07AdM01dM7@0L71`07AdM01lO7`0L71`401hN7P0301lO7`0M7Ad0
71`L008071`L00<07AdM01`L700L71`00P0K6a/501`L70@06a/K00<07AdM01`L700L71`00`0L71`5
01/K6`0401TI6@0K6a/071`L01TI6@<06a/K00@06ATI01XJ6P0I6AT06a/K0P0J6QX01@0I6AT06QXJ
01XJ6P0I6AT06QXJ00806ATI00<06QXJ01TI6@0J6QX00`0J6QX00`0K6a/06QXJ01TI6@0301TI6@D0
6QXJ00P06a/K01XJ6P0H61P06QXJ01TI6@0K6a/06ATI01/K6`<06ATI00H061PH01TI6@0I6AT06ATI
01/K6`0H61P301TI6@H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@H06ATI
0P0J6QX00`0I6AT06QXJ01TI6@0201XJ6P806ATI00@06QXJ01TI6@0H61P06ATI0`0J6QX301TI6@@0
6QXJ00<06ATI01XJ6P0J6QX00`0J6QX00`0I6AT06a/K01TI6@0301XJ6P0301/K6`0J6QX06ATI00<0
6QXJ00<06ATI01XJ6P0J6QX00P0J6QX00`0I6AT06QXJ01TI6@0201/K6`0301dM7@0L71`06a/K00D0
6a/K00<06QXJ01/K6`0K6a/01@0K6a/02@0J6QX06a/K01dM7@0L71`06a/K01`L700J6QX071`L01/K
6`0301`L700301XJ6P0L71`06a/K008071`L00<06QXJ01`L700L71`01`0L71`00`0K6a/07AdM01`L
700501dM7@0501`L700N7Qh07QhN01hN7P0M7Ad00`0L71`201dM7@0601hN7P0M7Ad07AdM01`L700M
7Ad071`L0P0N7Qh01@0M7Ad07QhN01lO7`0M7Ad07alO00807QhN0`0M7Ad00`0O7al07AdM01hN7P02
01lO7`807QhN0`0O7al01`0N7Qh07alO01lO7`0N7Qh07alO01hN7P0Q8B400P0N7Qh201lO7`05020P
800N7Qh07alO01hN7P0P82000P0O7al01P0P82007alO01hN7P0M7Ad0820P01hN7P807alO0P0P8204
01lO7`06020P800O7al07alO020P800O7al07QhN0P0O7al00`0M7Ad07QhN01lO7`0201lO7`0:01dM
7@0N7Qh07alO01dM7@0O7al0820P01hN7P0O7al07QhN01dM7@<07QhN00@07alO01hN7P0N7Qh07QhN
0P0O7al0200N7Qh07AdM01hN7P0M7Ad07alO01hN7P0M7Ad07QhN0`0M7Ad301hN7P0301lO7`0P8200
7QhN00807QhN00<071`L01/K6`0L71`00P0M7Ad00`0L71`06a/K01/K6`0501`L70@06a/K0`0L71`2
01/K6`0401`L700K6a/06a/K01/K6`<06QXJ00<06a/K01TI6@0K6a/00P0J6QX00`0K6a/06QXJ01/K
6`0201XJ6P0501/K6`0J6QX06QXJ01/K6`0I6AT00P0J6QX00`0I6AT06QXJ01XJ6P0601XJ6P0301PH
600J6QX06ATI00806ATI00<06QXJ01TI6@0I6AT00`0J6QX0100I6AT06QXJ01TI6@0H61P201TI6@04
01XJ6P0I6AT06QXJ01TI6@806QXJ00L06ATI01/K6`0H61P06ATI01XJ6P0H61P06ATI00H0fMWI0@00
00010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0401XJ6P0I6AT06QXJ01TI6@@06QXJ00@0
6ATI01/K6`0J6QX06a/K0P0I6AT01P0K6a/06QXJ01TI6@0J6QX06ATI01/K6`<06ATI0P0J6QX00`0K
6a/06QXJ01XJ6P0201/K6`D06QXJ00D06a/K01XJ6P0I6AT06ATI01/K6`0301XJ6P806ATI1@0J6QX0
0`0K6a/06QXJ01XJ6P0201XJ6P806a/K00@06ATI01/K6`0J6QX06QXJ0P0K6a/00`0L71`06QXJ01XJ
6P0301XJ6PH06a/K00<071`L01/K6`0J6QX00P0K6a/00`0L71`06a/K01/K6`0301`L70<06a/K00D0
71`L01dM7@0K6a/071`L01/K6`0301`L700401dM7@0L71`06a/K01dM7@<071`L0P0M7Ad01@0L71`0
6a/K01`L700M7Ad07alO00<07QhN1P0M7Ad00`0N7Qh07AdM01lO7`0201hN7P0501dM7@0N7Qh07QhN
01hN7P0M7Ad00`0N7Qh01@0O7al07AdM01hN7P0N7Qh07alO00@07QhN00D07alO01hN7P0N7Qh07alO
01hN7P0201lO7`<07QhN00L07alO01hN7P0O7al07alO020P800O7al07QhN0080820P00D07alO01hN
7P0Q8B407alO01hN7P0301lO7`0;020P800O7al07alO020P800O7al0820P01hN7P0O7al0820P01lO
7`0P82000`0O7al0100P82007QhN01lO7`0M7Ad201hN7P0401lO7`0N7Qh07QhN01lO7`807QhN00@0
7alO01hN7P0M7Ad07alO0P0N7Qh0100O7al0820P01lO7`0O7al501hN7P0401dM7@0O7al07AdM01hN
7P<07AdM00L07QhN01dM7@0M7Ad07QhN01lO7`0P82008R8R00808b<S00<0820P01hN7P0N7Qh00`0M
7Ad401`L700801dM7@0L71`07AdM01XJ6P0L71`06a/K01XJ6P0K6a/301`L70806a/K00@071`L01/K
6`0M7Ad06QXJ0`0K6a/00`0L71`06ATI01XJ6P0401XJ6P@06a/K100J6QX201/K6`0601TI6@0J6QX0
6a/K01XJ6P0I6AT06QXJ1@0I6AT0100H61P06ATI01PH600J6QX401TI6@0301/K6`0J6QX06ATI00P0
6ATI00<06QXJ01TI6@0I6AT00P0I6AT00`0H61P06ATI01XJ6P0201PH600301XJ6P3IfMT0fMWI00@0
fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0301TI6@0J6QX06ATI00806QXJ
0P0I6AT301XJ6P<06ATI00T06a/K01TI6@0J6QX06ATI01XJ6P0I6AT06QXJ01PH600I6AT0100J6QX0
2@0M7Ad06a/K01`L700L71`06a/K01XJ6P0K6a/06QXJ01TI6@0201XJ6P806ATI00@06QXJ01TI6@0J
6QX06ATI0`0J6QX01`0L71`06QXJ01XJ6P0J6QX06a/K01XJ6P0L71`00`0K6a/00`0J6QX06a/K01/K
6`0201/K6`806QXJ00D06a/K01XJ6P0L71`06a/K01XJ6P0301/K6`0301dM7@0K6a/06QXJ008071`L
0P0J6QX301`L700401/K6`0L71`07AdM01XJ6P8071`L00D06a/K01`L700L71`06QXJ01dM7@0201`L
700801/K6`0L71`06a/K01`L700K6a/07AdM01/K6`0L71`401dM7@8071`L0P0M7Ad00`0N7Qh07AdM
01dM7@0301`L700301dM7@0N7Qh07AdM00<07AdM00L07QhN01dM7@0N7Qh07QhN01dM7@0L71`07QhN
00807AdM0`0N7Qh03@0M7Ad07QhN01hN7P0N7Qh07alO01dM7@0O7al07AdM01lO7`0N7Qh07AdM01lO
7`0N7Qh00P0O7al00`0P82007QhN01lO7`0201lO7`05020P800N7Qh0820P020P800O7al00P0P8200
100O7al0820P020P800O7al3020P800601lO7`0P8200820P020P800O7al0820P0P0O7al0100Q8B40
820P01lO7`0P820401lO7`0301hN7P0O7al07QhN00807alO00@0820P01lO7`0O7al07alO0`0N7Qh0
0`0P82007QhN01hN7P0201lO7`0301dM7@0N7Qh07alO00<07QhN0P0P82002@0O7al07QhN01hN7P0O
7al07AdM01hN7P0M7Ad07alO01hN7P0201dM7@0701hN7P0O7al0820P02DU9@0T92@08R8R01hN7P02
01dM7@8071`L00<07QhN01`L700L71`00P0M7Ad00`0L71`07AdM01/K6`0301`L700401dM7@0K6a/0
6a/K01/K6`8071`L00H06a/K01`L700K6a/071`L01/K6`0L71`201/K6`0301`L700K6a/06a/K00<0
6a/K00`06QXJ01/K6`0J6QX06a/K01XJ6P0K6a/06ATI01/K6`0J6QX06a/K01XJ6P0I6AT201/K6`80
6QXJ00@06a/K01TI6@0I6AT06ATI1@0J6QX00`0I6AT061PH01XJ6P0401TI6@0501PH600I6AT061PH
01/K6`0I6AT00`0J6QX0100I6AT061PH01TI6@0I6AT401XJ6P0401PH600J6QX06ATI01XJ6PH0fMWI
0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0301XJ6P0H61P06QXJ00806ATI00T0
6QXJ01TI6@0K6a/06QXJ01TI6@0J6QX06a/K01TI6@0K6a/00P0J6QX00`0I6AT06QXJ01XJ6P0201XJ
6P0501TI6@0J6QX06a/K01/K6`0J6QX00P0K6a/201`L70@06a/K0P0J6QX0100I6AT06QXJ01XJ6P0K
6a/301TI6@0301XJ6P0K6a/06ATI00806QXJ00@06ATI01XJ6P0K6a/06QXJ0`0K6a/01P0J6QX071`L
01/K6`0J6QX06a/K01TI6@806a/K00<071`L01/K6`0J6QX00P0K6a/0100L71`06QXJ01XJ6P0K6a/2
01`L700301/K6`0J6QX06QXJ00<071`L00L07AdM01`L700K6a/071`L01dM7@0K6a/07AdM00806a/K
0`0L71`00`0M7Ad06a/K01`L700501`L700401dM7@0L71`071`L01/K6`<07AdM00P071`L01hN7P0N
7Qh071`L01dM7@0L71`07AdM01hN7P<07AdM00P07QhN01dM7@0N7Qh07alO01dM7@0N7Qh07AdM01hN
7P807alO0P0N7Qh0200L71`07AdM01hN7P0M7Ad07QhN01lO7`0N7Qh07AdM100N7Qh301lO7`0301hN
7P0O7al07alO00807QhN00T0820P01lO7`0O7al08B4Q01hN7P0O7al0820P01lO7`0N7Qh00`0O7al0
1`0Q8B40820P01lO7`0O7al08B4Q020P800N7Qh00`0O7al2020P800301lO7`0P82007alO00L07alO
00L0820P01lO7`0O7al0820P01hN7P0O7al0820P00807alO00D0820P01hN7P0O7al07QhN01lO7`03
01hN7P807alO0`0N7Qh201lO7`0501dM7@0N7Qh07QhN01lO7`0P82000`0N7Qh201dM7@0501hN7P0M
7Ad07QhN01lO7`0P82000P0S8b<00`0Q8B407AdM01lO7`0401dM7@0601`L700K6a/071`L01`L700M
7Ad071`L0P0M7Ad00`0L71`07AdM01`L700201/K6`8071`L00D07AdM01`L700L71`06a/K01`L7002
01/K6`0301XJ6P0K6a/071`L00806a/K00@071`L01/K6`0L71`06QXJ0`0K6a/301XJ6P0301/K6`0J
6QX06QXJ00<06QXJ00D06a/K01PH600J6QX06ATI01/K6`0201XJ6P0401TI6@0J6QX06a/K01TI6@80
6QXJ00D061PH01XJ6P0I6AT06QXJ01TI6@0301XJ6P806ATI0`0J6QX0100H61P06ATI01TI6@0I6AT3
01XJ6P0601/K6`0J6QX06ATI01TI6@0H61P06ATI1P3IfMT100000040fMWI000F0=WIf@030000003I
fMT0fMWI00<0fMWI100I6AT201XJ6P0301TI6@0J6QX06ATI00P06QXJ00<06a/K01XJ6P0J6QX00`0I
6AT00`0H61P06QXJ01/K6`0201`L700901dM7@0N7Qh071`L01XJ6P0K6a/06QXJ01/K6`0J6QX06ATI
00X06QXJ00@071`L01XJ6P0J6QX06a/K0P0J6QX01@0K6a/071`L01/K6`0L71`06QXJ00806a/K0`0L
71`00`0J6QX071`L01/K6`0401/K6`0601XJ6P0K6a/06QXJ01`L700K6a/071`L0P0K6a/01P0M7Ad0
71`L01/K6`0K6a/071`L01/K6`<071`L00T07AdM01`L700L71`071`L01dM7@0K6a/071`L01dM7@0K
6a/00`0M7Ad201/K6`0501hN7P0L71`07AdM01`L700K6a/00P0M7Ad01P0L71`07QhN01hN7P0M7Ad0
71`L01hN7P<07AdM00@071`L01dM7@0N7Qh07AdM100N7Qh00`0M7Ad07QhN01dM7@0:01hN7P<07alO
00D07QhN01lO7`0N7Qh0820P01hN7P0301lO7`<0820P0P0O7al00`0P82007QhN01lO7`03020P8004
01lO7`0P8200820P01hN7P80820P00<07QhN020P800P82000`0O7al2020P8004024Q8@0P82008B4Q
024Q8@80820P0P0O7al00`0P82007alO01lO7`02020P80807alO00<07QhN01lO7`0O7al00P0P8202
01lO7`04020P800O7al0820P01hN7P807alO0P0N7Qh00`0O7al07QhN020P800201hN7P0301lO7`0N
7Qh07alO00<07AdM0`0N7Qh02@0M7Ad07QhN01lO7`0P82007alO020P800Q8B407QhN01dM7@0301hN
7P0601dM7@0L71`07AdM01/K6`0L71`07AdM0P0L71`00`0M7Ad071`L01`L700301`L700301dM7@0L
71`07AdM00806a/K0P0L71`501/K6`0301`L700K6a/06QXJ00806QXJ100K6a/201XJ6P0301/K6`0J
6QX07AdM00806ATI00<06a/K01XJ6P0J6QX00`0J6QX01@0I6AT06QXJ01XJ6P0K6a/06QXJ00806ATI
00<06QXJ01TI6@0J6QX00`0J6QX00`0I6AT06QXJ01XJ6P0201TI6@0301XJ6P0I6AT06ATI00<06ATI
00@06QXJ01TI6@0I6AT06QXJ0P0I6AT00`0J6QX06ATI01XJ6P0201TI6@0301XJ6P3IfMT0fMWI00@0
fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0401XJ6P0I6AT06a/K01TI6@@0
6QXJ00@06ATI01XJ6P0K6a/06ATI100J6QX201/K6`0301XJ6P0I6AT06ATI00<06QXJ0P0K6a/01`0J
6QX06a/K01dM7@0N7Qh07AdM01/K6`0L71`00P0J6QX00`0K6a/06QXJ01/K6`0301XJ6P0501TI6@0J
6QX06QXJ01/K6`0J6QX00P0K6a/01@0I6AT06QXJ01XJ6P0J6QX06ATI00806a/K00@06QXJ01/K6`0K
6a/06ATI0`0K6a/0100J6QX06a/K01/K6`0J6QX201/K6`0901XJ6P0K6a/06a/K01/K6`0J6QX06a/K
01`L700I6AT06a/K008071`L0P0K6a/301`L700401dM7@0L71`071`L01/K6`@071`L00/07QhN01/K
6`0L71`071`L01/K6`0L71`06a/K01dM7@0L71`07AdM01/K6`0201dM7@<071`L00D07AdM01`L700N
7Qh07QhN01lO7`0201dM7@0601hN7P0M7Ad07QhN01dM7@0N7Qh07alO0P0N7Qh02`0O7al07QhN01dM
7@0N7Qh07alO01dM7@0O7al07AdM01lO7`0P82007AdM00807QhN00D07AdM01lO7`0O7al07alO020P
800201lO7`05020P800N7Qh07alO01lO7`0N7Qh00`0P82001P0O7al08B4Q01lO7`0O7al0820P01lO
7`80820P00<07alO01hN7P0P82000P0P8200100Q8B407alO01lO7`0P820201lO7`09024Q8@0P8200
7alO020P800O7al08B4Q020P800Q8B40820P00807alO00H08B4Q01lO7`0O7al0820P024Q8@0N7Qh2
01lO7`05020P800N7Qh07alO020P800O7al00P0P8200300O7al0820P01hN7P0O7al0820P01dM7@0N
7Qh07alO01hN7P0M7Ad07alO01dM7@@07QhN00<07AdM01hN7P0N7Qh00P0N7Qh00`0O7al07QhN01dM
7@0301lO7`0;020P800O7al07QhN01dM7@0N7Qh07alO01hN7P0M7Ad071`L01/K6`0L71`0100M7Ad0
0`0K6a/071`L01`L700401`L70806a/K00H07AdM01/K6`0K6a/06a/K01`L700J6QX401/K6`8071`L
0P0J6QX301/K6`<06QXJ00<06a/K01XJ6P0I6AT00P0K6a/501XJ6P0501/K6`0J6QX06QXJ01TI6@0J
6QX00`0I6AT01@0J6QX06ATI01TI6@0I6AT061PH00806QXJ0`0I6AT02`0K6a/06QXJ01TI6@0J6QX0
61PH01XJ6P0I6AT06QXJ01TI6@0K6a/06QXJ00806ATI00@06QXJ01TI6@0I6AT06QXJ0P0I6AT60=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT301TI6@0401PH600J6QX06ATI01TI
6@806QXJ00<06a/K01TI6@0I6AT00`0J6QX201/K6`0301TI6@0H61P06QXJ00806QXJ0P0I6AT00`0J
6QX06a/K01/K6`0201/K6`0401`L700K6a/06QXJ01/K6`806ATI00@06a/K01TI6@0K6a/06QXJ1@0I
6AT01P0J6QX06a/K01XJ6P0L71`06QXJ01`L70<06a/K00<06QXJ01TI6@0K6a/02P0K6a/01`0J6QX0
6a/K01/K6`0L71`06a/K01XJ6P0L71`00P0K6a/0100L71`06a/K01`L700K6a/201dM7@0401`L700K
6a/071`L01/K6`8071`L00<07AdM01`L700L71`00P0M7Ad01P0L71`07AdM01`L700M7Ad07QhN01dM
7@8071`L100M7Ad00`0L71`07AdM01`L700201`L700401dM7@0N7Qh07AdM01hN7P807AdM00D07QhN
01lO7`0N7Qh07alO01hN7P0201dM7@0301lO7`0N7Qh07QhN00807QhN00T07AdM020P800N7Qh07QhN
01lO7`0M7Ad07alO01hN7P0O7al00P0N7Qh301lO7`807QhN0P0O7al00`0N7Qh07alO01lO7`0201lO
7`80820P0P0O7al01`0P82007alO024Q8@0P82007alO024Q8@0O7al00P0Q8B4;020P800701lO7`0P
8200820P024Q8@0P82008B4Q01lO7`02020P8004024Q8@0O7al07QhN020P80807alO00H07QhN01lO
7`0N7Qh07QhN01lO7`0P820401lO7`0501hN7P0O7al07QhN020P800O7al00P0N7Qh501lO7`807AdM
0P0N7Qh01P0M7Ad07QhN01lO7`0N7Qh07alO01hN7P<07alO00L07QhN01dM7@0M7Ad07AdM01`L700M
7Ad071`L00<07AdM100L71`01@0M7Ad071`L01dM7@0L71`06a/K008071`L0P0K6a/00`0L71`06a/K
01/K6`0201`L70@06a/K00@06QXJ01/K6`0K6a/06QXJ100K6a/00`0L71`06a/K01/K6`0201/K6`80
6QXJ0P0K6a/01@0L71`06QXJ01/K6`0L71`06QXJ00<06ATI00@061PH01TI6@0I6AT06QXJ0P0I6AT3
01XJ6P0501TI6@0J6QX06ATI01XJ6P0I6AT00P0J6QX401TI6@0301PH600I6AT06QXJ00<06QXJ00L0
61PH01XJ6P0J6QX06QXJ01TI6@0H61P06ATI00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI
0=WIf@030=WIf@806QXJ00@06ATI01XJ6P0H61P06QXJ0P0I6AT201XJ6P0501TI6@0J6QX061PH01TI
6@0J6QX00P0I6AT00`0J6QX06a/K01XJ6P0301XJ6P806ATI0P0K6a/601XJ6P0301/K6`0J6QX06QXJ
00H06QXJ00<06ATI01XJ6P0J6QX00P0J6QX201/K6`0301XJ6P0K6a/071`L00806a/K00T06ATI01XJ
6P0K6a/06a/K01XJ6P0I6AT06QXJ01/K6`0J6QX0100K6a/01@0L71`06a/K01/K6`0L71`06QXJ00H0
6a/K00X071`L01/K6`0L71`071`L01dM7@0J6QX06a/K01dM7@0K6a/07QhN0P0K6a/01`0M7Ad071`L
01dM7@0M7Ad07QhN01`L700N7Qh00`0L71`01@0M7Ad071`L01`L700L71`07QhN00807AdM00@07QhN
01`L700L71`07QhN200M7Ad01@0N7Qh07alO01hN7P0N7Qh07alO00807QhN00<0820P01dM7@0N7Qh0
0`0O7al00`0N7Qh07alO01hN7P0201lO7`05020P800N7Qh07alO01lO7`0P8200100O7al02@0P8200
7QhN01hN7P0O7al07QhN024Q8@0O7al0820P01lO7`02020P8004024Q8@0O7al08B4Q01lO7`<0820P
00@07alO020P800P82008B4Q0P0P82000`0N7Qh08B4Q020P8002020P800701lO7`0P8200820P020P
800O7al08R8R01lO7`02020P80807alO00@0820P01hN7P0O7al07QhN0P0P8200100O7al0820P01lO
7`0N7Qh201lO7`807QhN0P0P8200100O7al07QhN01lO7`0M7Ad201hN7P08020P800N7Qh07QhN01hN
7P0O7al07AdM01hN7P0O7al201dM7@0<01lO7`0M7Ad071`L01`L700M7Ad07QhN01`L700M7Ad071`L
01hN7P0M7Ad07QhN0P0M7Ad301`L700301dM7@0L71`071`L008071`L00@06a/K01dM7@0M7Ad06QXJ
0`0K6a/201`L700301dM7@0L71`07AdM008071`L0P0K6a/01P0L71`06a/K01/K6`0K6a/06QXJ01`L
70806a/K00<071`L01/K6`0I6AT01`0J6QX201/K6`<06ATI00L061PH01XJ6P0J6QX06QXJ01/K6`0J
6QX06a/K00806ATI00D061PH01TI6@0I6AT06ATI01XJ6P0301TI6@0301/K6`0J6QX06QXJ00<06ATI
0P0J6QX0100I6AT06QXJ01XJ6P0K6a/201XJ6P0401PH600I6AT06ATI01TI6@H0fMWI0@0000010=WI
f@005P3IfMT2000000@0fMWI00D061PH01TI6@0J6QX06ATI01XJ6P0201PH600301XJ6P0I6AT06QXJ
00806ATI00@06QXJ01/K6`0J6QX06ATI0P0J6QX00`0I6AT06QXJ01TI6@0201XJ6P806ATI00@06a/K
01XJ6P0I6AT071`L0P0J6QX00`0K6a/06QXJ01/K6`0401XJ6P0401TI6@0J6QX06a/K01/K6`<06QXJ
00<06ATI01XJ6P0J6QX00P0K6a/0100J6QX06a/K01/K6`0I6AT201XJ6P806a/K0P0J6QX0100L71`0
6a/K01lO7`0L71`201XJ6P0801`L700K6a/06a/K01dM7@0J6QX06ATI01/K6`0J6QX401/K6`<071`L
00X07AdM01`L700K6a/071`L01dM7@0L71`06a/K01dM7@0K6a/071`L0P0M7Ad01P0L71`07AdM01dM
7@0N7Qh07AdM01hN7P<071`L100M7Ad201hN7P8071`L00@07AdM01hN7P0M7Ad07AdM0P0N7Qh01`0M
7Ad07QhN01hN7P0N7Qh07alO01hN7P0M7Ad0100N7Qh701lO7`0401hN7P0O7al07QhN01lO7`<0820P
100O7al01P0N7Qh07alO020P800P82008B4Q020P80807alO0`0P820201lO7`80820P00D07alO020P
800R8R807alO024Q8@02020P8004024Q8@0P82008R8R024Q8@<0820P00D07alO020P800P82008B4Q
01lO7`03020P8004024Q8@0P8200820P01hN7P807alO0P0P82001`0Q8B407alO01lO7`0N7Qh0820P
01lO7`0P8200100O7al00`0P82007QhN01hN7P0201lO7`0401hN7P0O7al07alO01hN7P<07alO00<0
7QhN01dM7@0N7Qh00P0N7Qh201dM7@<07QhN00H07AdM01hN7P0M7Ad071`L01lO7`0M7Ad201`L7080
7AdM1@0L71`201dM7@@071`L00D07AdM01`L700K6a/071`L01/K6`0301`L700801/K6`0L71`06a/K
01`L700K6a/06QXJ01`L700J6QX201/K6`0401`L700K6a/06QXJ01/K6`806QXJ0P0K6a/01P0I6AT0
6a/K01/K6`0K6a/06QXJ01`L70806ATI00D06a/K01TI6@0K6a/06QXJ01TI6@0201XJ6P0601/K6`0J
6QX06a/K01XJ6P0I6AT06a/K0`0J6QX0100H61P06QXJ01XJ6P0I6AT201XJ6P<06ATI0P0J6QX201TI
6@0401XJ6P0I6AT06ATI01XJ6P<06ATI1@3IfMT200000040fMWI000F0=WIf@030000003IfMT0fMWI
00<0fMWI00D06QXJ01TI6@0J6QX06ATI01/K6`0301TI6@0501XJ6P0I6AT06QXJ01/K6`0J6QX00P0I
6AT00`0J6QX061PH01TI6@0301TI6@0401XJ6P0K6a/06a/K01TI6@806a/K00<06ATI01XJ6P0J6QX0
0P0J6QX00`0K6a/06QXJ01XJ6P0201XJ6P806a/K00L06QXJ01TI6@0J6QX06QXJ01TI6@0J6QX06ATI
00D06a/K0P0L71`00`0J6QX06a/K01/K6`0201XJ6P@06a/K00T06QXJ01/K6`0K6a/06a/K01`L700K
6a/071`L01/K6`0L71`0100K6a/00`0M7Ad06a/K01`L700401`L700401XJ6P0M7Ad07AdM01/K6`80
71`L00<06a/K01`L700L71`00P0L71`03@0N7Qh07AdM01`L700L71`07alO01`L700M7Ad071`L01hN
7P0M7Ad07QhN01XJ6P0O7al00P0L71`201dM7@8071`L00@07AdM01`L700N7Qh07alO0P0N7Qh0100O
7al07AdM01hN7P0O7al301hN7P03020P800N7Qh07alO00D07alO00H07QhN01lO7`0O7al07QhN024Q
8@0P820501lO7`<0820P00/07alO024Q8@0P82007alO020P800Q8B40820P01lO7`0P82008B4Q020P
8003024Q8@<0820P00`08B4Q020P800O7al08B4Q020P800Q8B40820P01lO7`0Q8B408R8R024Q8@0N
7Qh5020P8005024Q8@0N7Qh0820P024Q8@0O7al0100P82000`0N7Qh0820P01lO7`02020P800301lO
7`0P82007QhN00807alO00D0820P01lO7`0O7al07QhN020P800201lO7`0301hN7P0O7al07alO0080
7alO00H07QhN020P800N7Qh07AdM01lO7`0M7Ad201hN7P807AdM00D07QhN01lO7`0N7Qh07QhN01lO
7`0601dM7@<071`L00`06a/K01`L700L71`071`L01dM7@0L71`07AdM01`L700K6a/071`L01/K6`0L
71`201/K6`0401`L700K6a/07AdM01/K6`@071`L00<06QXJ01/K6`0K6a/00P0K6a/01@0L71`06a/K
01`L700K6a/06QXJ00806a/K00@071`L01XJ6P0K6a/071`L0P0K6a/00`0J6QX071`L01/K6`0401XJ
6P0301TI6@0K6a/06QXJ00<06QXJ00<06ATI01/K6`0I6AT00`0J6QX0100I6AT06QXJ01XJ6P0J6QX2
01TI6@0601XJ6P0I6AT06QXJ01TI6@0J6QX06ATI100J6QX00`0I6AT06QXJ01XJ6P060=WIf@400000
0@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT201TI6@0801XJ6P0I6AT06QXJ01XJ6P0H61P0
6QXJ01TI6@0J6QX201TI6@0301XJ6P0I6AT06ATI00806QXJ00D06ATI01XJ6P0J6QX06a/K01XJ6P02
01TI6@806QXJ0P0K6a/00`0J6QX06a/K01/K6`0201XJ6P0701TI6@0J6QX06QXJ01/K6`0J6QX06ATI
01XJ6P0201/K6`0401TI6@0L71`06a/K01/K6`<06QXJ00<06a/K01XJ6P0L71`0100K6a/00`0L71`0
6a/K01/K6`0201/K6`0301XJ6P0K6a/07AdM00806a/K00D071`L01/K6`0K6a/071`L01/K6`0201`L
70806a/K2`0L71`0100M7Ad06a/K01`L700M7Ad201`L70807AdM0P0L71`00`0M7Ad071`L01dM7@03
01dM7@0501`L700K6a/071`L01dM7@0L71`0100M7Ad00`0N7Qh07alO01dM7@0201hN7P0401`L700M
7Ad07QhN01dM7@807alO0P0N7Qh00`0O7al07AdM01hN7P0501lO7`0401hN7P0P82007QhN020P80@0
7alO0`0P82001@0Q8B40820P01lO7`0P82007alO0080820P00@08B4Q020P800P82008B4Q0`0P8200
1P0Q8B40820P024Q8@0O7al08B4Q020P80808B4Q00<08R8R024Q8@0P82000P0P8202024Q8@0901lO
7`0Q8B408R8R028R8P0P82008B4Q01lO7`0P82008B4Q0080820P00<07alO024Q8@0Q8B400P0O7al0
100N7Qh0820P01lO7`0Q8B4301lO7`0401hN7P0O7al07alO01hN7P80820P100O7al02`0N7Qh07alO
01lO7`0N7Qh07alO01dM7@0N7Qh0820P01dM7@0O7al07AdM00807alO0P0N7Qh201dM7@<07QhN00<0
7AdM01lO7`0M7Ad00P0M7Ad01@0N7Qh07AdM01dM7@0N7Qh071`L00@07AdM100L71`01@0M7Ad06a/K
01`L700M7Ad071`L00806a/K100L71`00`0K6a/071`L01/K6`0201XJ6P0301/K6`0L71`06a/K00D0
6a/K00<06QXJ01/K6`0K6a/0100J6QX201/K6`806QXJ00D06a/K01XJ6P0J6QX06QXJ01TI6@0601XJ
6P0301TI6@0J6QX06QXJ00806QXJ00@06ATI01XJ6P0I6AT06a/K0`0J6QX00`0K6a/06QXJ01/K6`02
01XJ6P0401TI6@0J6QX06ATI01XJ6P806ATI00<06QXJ01/K6`3IfMT01@3IfMT100000040fMWI000F
0=WIf@030000003IfMT0fMWI00<0fMWI00H06ATI01PH600J6QX06ATI01PH600J6QX601TI6@806QXJ
100I6AT00`0H61P06QXJ01XJ6P0501XJ6P0301TI6@0K6a/06QXJ00@06QXJ00<06a/K01XJ6P0I6AT0
0P0I6AT201XJ6P<06ATI00<06QXJ01/K6`0K6a/01`0K6a/201XJ6PD06a/K00@071`L01/K6`0J6QX0
6QXJ100K6a/301`L700301dM7@0L71`071`L00806a/K0`0L71`0100K6a/071`L01/K6`0K6a/501`L
700301/K6`0M7Ad071`L00<071`L00<07QhN01dM7@0N7Qh00P0M7Ad01@0N7Qh07AdM01`L700L71`0
7AdM008071`L00D07AdM01hN7P0L71`071`L01dM7@0201hN7P0301lO7`0M7Ad07AdM00807QhN00<0
7AdM01hN7P0M7Ad00P0N7Qh0100P82007alO01hN7P0N7Qh301lO7`0;01hN7P0O7al07alO01lO7`0N
7Qh07alO020P800N7Qh07alO020P800O7al00P0P82000`0O7al0820P020P800201lO7`<0820P00<0
8R8R024Q8@0Q8B400P0Q8B42020P80@08B4Q1@0P8200100Q8B408R8R028R8P0R8R82024Q8@<0820P
0P0Q8B401@0P82008B4Q020P800R8R80820P00808B4Q1@0P82001@0O7al08B4Q020P800P82007alO
00<0820P00<07alO020P800P82001@0O7al0100P82007QhN01dM7@0N7Qh201lO7`0501hN7P0M7Ad0
7AdM01dM7@0O7al00`0N7Qh01P0M7Ad07QhN01hN7P0N7Qh07AdM01hN7P8071`L00@07AdM020P800M
7Ad07AdM0P0L71`401dM7@0401`L700N7Qh071`L01dM7@H071`L00D06a/K01`L700L71`06a/K01`L
700201/K6`0501`L700K6a/06a/K01/K6`0L71`00P0K6a/00`0J6QX06a/K01`L700301/K6`0<01XJ
6P0K6a/06a/K01XJ6P0K6a/071`L01XJ6P0K6a/06QXJ01TI6@0K6a/06ATI100J6QX01P0I6AT06QXJ
01XJ6P0J6QX06ATI01/K6`D06QXJ0P0I6AT00`0J6QX06ATI01/K6`0201XJ6P806a/K00<06QXJ01TI
6@0I6AT00P0J6QX01@0I6AT06QXJ01TI6@0I6AT06QXJ00H0fMWI0@0000010=WIf@005P3IfMT00`00
0000fMWI0=WIf@030=WIf@0801TI6@0J6QX06QXJ01XJ6P0K6a/061PH01TI6@0H61P801XJ6P0301TI
6@0J6QX06QXJ00D06QXJ0`0I6AT201XJ6P0801TI6@0J6QX06QXJ01TI6@0K6a/06ATI01XJ6P0I6AT2
01/K6`806QXJ0P0K6a/201XJ6PL06a/K00<071`L01/K6`0K6a/00P0K6a/00`0L71`06QXJ01/K6`05
01/K6`0601XJ6P0M7Ad07AdM01XJ6P0L71`07AdM0`0L71`00`0K6a/071`L01/K6`0201`L700301/K
6`0L71`06a/K00<071`L1P0M7Ad201`L70D07AdM0P0N7Qh00`0L71`07AdM01dM7@0201dM7@0601`L
700N7Qh07AdM01hN7P0L71`07AdM0`0N7Qh201dM7@807QhN00<07alO01hN7P0O7al00P0N7Qh0300O
7al07QhN01hN7P0O7al07QhN01lO7`0P82007QhN01lO7`0N7Qh07alO020P80<07alO0P0P82000`0R
8R807alO020P8003024Q8@0301lO7`0Q8B408B4Q0080820P0P0R8R800`0Q8B408R8R024Q8@03024Q
8@06020P800Q8B40820P024Q8@0P82007alO0`0Q8B401P0P82008B4Q020P800P82008B4Q01lO7`80
820P1@0Q8B42020P80808B4Q00@07alO020P800P8200820P0P0Q8B42020P8004024Q8@0P82007QhN
024Q8@807alO00L07QhN01lO7`0O7al0820P01hN7P0P82007QhN00@07alO00P0820P01lO7`0N7Qh0
7alO01`L700N7Qh07AdM01lO7`@07QhN00@07alO01hN7P0M7Ad07QhN0P0M7Ad201hN7P0301`L700M
7Ad07AdM00807AdM00<07QhN01dM7@0M7Ad00P0M7Ad0100N7Qh071`L01`L700M7Ad301`L700801dM
7@0L71`06a/K01/K6`0L71`07AdM01`L700M7Ad201`L700401XJ6P0K6a/06a/K01/K6`8071`L00<0
6QXJ01/K6`0L71`01@0J6QX701/K6`0701XJ6P0K6a/06QXJ01/K6`0J6QX06ATI01/K6`0301XJ6P04
01/K6`0J6QX06ATI01TI6@<06QXJ00D06ATI01XJ6P0I6AT06QXJ01TI6@0201XJ6P0<01/K6`0I6AT0
6a/K01/K6`0I6AT06QXJ01TI6@0J6QX06ATI01/K6`0J6QX06ATI1P3IfMT100000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI00<06ATI01PH600I6AT00P0J6QX501TI6@0301XJ6P0K6a/06ATI
00@06ATI00@06QXJ01TI6@0J6QX06ATI0`0J6QX00`0I6AT06a/K01`L700201TI6@0401XJ6P0I6AT0
6a/K01/K6`8061PH00<06QXJ01/K6`0J6QX00P0J6QX0100I6AT071`L01TI6@0K6a/401XJ6P806a/K
0P0L71`01`0K6a/06QXJ01/K6`0M7Ad06ATI01/K6`0J6QX0100K6a/01@0J6QX06a/K01/K6`0L71`0
6a/K00<071`L00<06a/K01`L700L71`00P0L71`201XJ6P<071`L00X06a/K01`L700L71`07AdM01hN
7P0L71`07AdM01`L700M7Ad07QhN0P0L71`0100M7Ad07QhN01dM7@0N7Qh201dM7@0301hN7P0M7Ad0
7AdM00807AdM00H06a/K01`L700N7Qh07AdM01hN7P0M7Ad201hN7P0801dM7@0N7Qh07AdM01hN7P0M
7Ad07QhN01lO7`0N7Qh201dM7@807alO00@07QhN01lO7`0O7al07QhN1@0O7al00`0Q8B407alO01lO
7`04020P800301lO7`0Q8B407alO00807alO00<08B4Q020P800Q8B400P0P82000`0O7al0820P024Q
8@02020P8003024Q8@0P8200820P00808B4Q0P0P8202024Q8@06020P800Q8B408B4Q024Q8@0R8R80
8B4Q0P0P8202024Q8@05028R8P0Q8B408B4Q028R8P0P82000P0Q8B40200R8R808B4Q024Q8@0P8200
8B4Q020P800Q8B40820P0P0Q8B401@0P82007alO020P800Q8B407alO0080820P00<07alO020P800O
7al00P0O7al00`0N7Qh07alO01lO7`0601lO7`80820P00<07QhN020P800O7al00P0O7al00`0N7Qh0
7AdM01hN7P0301hN7P0601dM7@0O7al07QhN01dM7@0N7Qh07alO0P0M7Ad01P0N7Qh07AdM01dM7@0L
71`07QhN01/K6`8071`L00@07AdM01`L700L71`071`L0P0M7Ad201`L700501/K6`0L71`06a/K01`L
700K6a/00P0J6QX00`0L71`06a/K01`L700201/K6`0301XJ6P0K6a/06a/K00<06a/K00<06QXJ01/K
6`0I6AT00`0K6a/00`0L71`06QXJ01TI6@0501XJ6P<06a/K0P0J6QX00`0I6AT06QXJ01XJ6P0501XJ
6P0301TI6@0J6QX06QXJ00806QXJ00<06ATI01XJ6P0J6QX00`0J6QX201TI6@0401XJ6P0I6AT06a/K
01XJ6P<06ATI1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00<06ATI01PH
600I6AT00P0I6AT201PH60806ATI100J6QX01@0I6AT06QXJ01XJ6P0K6a/061PH00<06QXJ00<06ATI
01/K6`0J6QX00P0I6AT201XJ6P806a/K00<06ATI01/K6`0J6QX00P0J6QX01@0K6a/06QXJ01XJ6P0I
6AT06a/K00@06QXJ1P0K6a/01P0L71`06a/K01/K6`0K6a/071`L01XJ6PP06a/K0P0L71`401/K6`0:
01dM7@0K6a/06a/K01XJ6P0M7Ad071`L01/K6`0M7Ad06a/K01`L70807AdM0P0L71`01P0J6QX071`L
01`L700K6a/07QhN01`L70807AdM00<071`L01dM7@0M7Ad00P0M7Ad201hN7P0301dM7@0K6a/07AdM
008071`L00L07alO01hN7P0N7Qh07alO01`L700N7Qh07alO00807QhN00<07AdM01hN7P0M7Ad00`0O
7al201hN7P0501lO7`0N7Qh07alO01lO7`0P82000`0O7al00`0N7Qh0820P01lO7`02020P800301lO
7`0P82007alO00807alO0P0P8200100O7al08B4Q024Q8@0P8202024Q8@0;01lO7`0R8R808B4Q01lO
7`0R8R80820P028R8P0Q8B40820P024Q8@0R8R800P0P82000`0R8R80820P024Q8@02024Q8@06028R
8P0Q8B408B4Q024Q8@0P82008B4Q0P0R8R80100S8b<0820P028R8P0P8202024Q8@03028R8P0Q8B40
8B4Q00<08R8R00H08B4Q020P800P8200820P024Q8@0P820201lO7`03024Q8@0O7al07alO00D0820P
00<07alO020P800O7al00P0O7al0100N7Qh07alO01lO7`0P820201lO7`807QhN00<0820P01hN7P0N
7Qh01@0N7Qh01@0O7al07QhN01hN7P0O7al07AdM00807QhN0P0M7Ad00`0N7Qh07AdM01dM7@0401dM
7@0501`L700M7Ad07AdM01`L700N7Qh00`0M7Ad201`L700501/K6`0L71`06a/K01`L700K6a/00P0L
71`0200M7Ad06a/K01/K6`0J6QX071`L01/K6`0L71`06a/K0P0J6QX00`0I6AT06a/K01/K6`0301/K
6`0301XJ6P0K6a/06QXJ00@06QXJ00<06ATI01XJ6P0K6a/00P0J6QX401/K6`/06QXJ0P0I6AT0100J
6QX061PH01/K6`0K6a/401XJ6P0401TI6@0J6QX06QXJ01XJ6P806ATI1P3IfMT100000040fMWI000F
0=WIf@030000003IfMT0fMWI00<0fMWI0P0J6QX01P0H61P06ATI01/K6`0H61P06ATI01XJ6P<06ATI
0P0J6QX00`0H61P06ATI01/K6`0501XJ6P<06ATI00@06QXJ01TI6@0J6QX06ATI0P0J6QX01@0K6a/0
6QXJ01XJ6P0K6a/06ATI00<06a/K0`0J6QX301/K6`0401XJ6P0I6AT06a/K01XJ6P8071`L0P0K6a/0
1@0L71`06a/K01/K6`0J6QX06a/K00806QXJ100K6a/02`0L71`07AdM01/K6`0K6a/071`L01/K6`0M
7Ad06a/K01dM7@0L71`06a/K008071`L00D07AdM01/K6`0M7Ad06a/K01`L700201dM7@0:01hN7P0M
7Ad071`L01dM7@0L71`06a/K01`L700M7Ad071`L01hN7P<07AdM00<071`L01dM7@0M7Ad00P0M7Ad0
100L71`07AdM01dM7@0M7Ad201hN7P0401lO7`0M7Ad07QhN01lO7`<07QhN00<07alO01hN7P0O7al0
100O7al01@0P82007alO01lO7`0O7al0820P00807alO100P82000`0O7al0820P020P8005020P8005
024Q8@0P8200820P020P800O7al00P0Q8B40100P82008B4Q024Q8@0Q8B43020P80808B4Q00<0820P
028R8P0Q8B40100Q8B40100R8R808B4Q024Q8@0Q8B42028R8P<08B4Q00@08R8R024Q8@0R8R808R8R
0P0Q8B401@0R8R808B4Q024Q8@0S8b<08B4Q00<0820P0`0Q8B40100P82008R8R024Q8@0R8R82024Q
8@07020P800R8R80820P01lO7`0P82007alO024Q8@0201lO7`05020P800O7al07alO01hN7P0P8200
0P0O7al0100P82007alO01dM7@0O7al501hN7P807alO00@07QhN01lO7`0N7Qh07QhN0P0M7Ad00`0N
7Qh07AdM01`L700301dM7@0301`L700M7Ad07AdM00@07AdM00@071`L01dM7@0L71`07AdM0`0L71`0
100N7Qh071`L01`L700L71`201/K6`0801`L700M7Ad06a/K01/K6`0L71`06a/K01XJ6P0L71`301/K
6`8071`L0P0K6a/201XJ6P0501/K6`0J6QX06a/K01`L700K6a/00P0J6QX00`0I6AT06a/K01PH6002
01XJ6P0301TI6@0J6QX06QXJ00806QXJ00@06ATI01XJ6P0J6QX06a/K2P0J6QX00`0I6AT06QXJ01/K
6`0201XJ6P0701TI6@0J6QX06QXJ01TI6@0J6QX06ATI01XJ6P060=WIf@4000000@3IfMT001H0fMWI
00<000000=WIf@3IfMT00`3IfMT401TI6@0601/K6`0I6AT06QXJ01TI6@0J6QX06a/K0`0J6QX00`0I
6AT06QXJ01TI6@0601XJ6P0301TI6@0J6QX06ATI00/06QXJ00<06a/K01TI6@0K6a/00P0K6a/00`0J
6QX06a/K01XJ6P0201/K6`0801XJ6P0L71`06a/K01/K6`0L71`06QXJ01/K6`0M7Ad701/K6`0401XJ
6P0I6AT06a/K01/K6`8071`L00H06a/K01`L700L71`06a/K01XJ6P0L71`301/K6`8071`L00L06a/K
01`L700L71`06a/K01`L700K6a/071`L00807AdM00@06a/K01dM7@0L71`07AdM0P0L71`201dM7@04
01`L700M7Ad07AdM01hN7P807AdM00<071`L01dM7@0L71`01@0N7Qh00`0O7al07AdM01dM7@0201hN
7P0701lO7`0N7Qh07alO01hN7P0O7al07QhN020P800201lO7`03020P800M7Ad07alO00<0820P0P0O
7al00`0P82008B4Q020P8003020P80@08B4Q00L0820P024Q8@0Q8B40820P028R8P0Q8B40820P0080
8R8R00H08B4Q020P800Q8B40820P024Q8@0P8202028R8P05020P800Q8B408B4Q028R8P0Q8B400P0R
8R82024Q8@808b<S0`0Q8B42028R8P04020P800R8R808R8R020P80808R8R0`0Q8B402@0P82008B4Q
020P800P82008R8R024Q8@0P82008B4Q028R8P03020P800401lO7`0P8200820P024Q8@80820P00@0
7alO020P800O7al0820P1@0O7al00`0P82007alO01hN7P0201lO7`807QhN00<07alO01hN7P0M7Ad0
0P0N7Qh01P0O7al07QhN01dM7@0O7al07QhN01dM7@<07QhN00@0820P01dM7@0N7Qh071`L0P0N7Qh3
01dM7@03020P800N7Qh07QhN008071`L0P0M7Ad201/K6`@071`L0P0M7Ad00`0K6a/071`L01/K6`02
01`L700301/K6`0L71`06QXJ00<06a/K00H071`L01XJ6P0J6QX06QXJ01/K6`0L71`401/K6`D06QXJ
00<06a/K01XJ6P0I6AT00P0J6QX301TI6@0501/K6`0H61P06a/K01XJ6P0K6a/00P0J6QX0100I6AT0
6QXJ01TI6@0J6QX201TI6@<06QXJ00H06a/K01TI6@0I6AT06ATI01XJ6P0H61P301TI6@H0fMWI0@00
00010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0:01TI6@0H61P061PH01XJ6P0I6AT06QXJ
01TI6@0J6QX06ATI01XJ6P<06ATI0P0J6QX0100I6AT06QXJ01XJ6P0I6AT301XJ6P0301TI6@0J6QX0
6QXJ00@06QXJ00<06a/K01TI6@0J6QX00`0I6AT201XJ6P0301/K6`0L71`06QXJ00D06QXJ1@0K6a/0
100L71`06a/K01/K6`0L71`401/K6`0401`L700K6a/06a/K01XJ6P806a/K0P0L71`02P0K6a/071`L
01`L700L71`06a/K01`L700M7Ad071`L01dM7@0L71`201/K6`8071`L00T07AdM01/K6`0L71`07AdM
01/K6`0M7Ad071`L01hN7P0L71`00P0M7Ad201`L700601dM7@0N7Qh071`L01hN7P0M7Ad071`L0P0M
7Ad0100L71`07AdM01lO7`0O7al401hN7P0301lO7`0N7Qh07QhN00807AdM00L07QhN01lO7`0O7al0
7alO020P800O7al07AdM00<0820P0P0O7al01P0P82007alO020P800Q8B407alO020P80808B4Q00<0
820P024Q8@0P8200100Q8B42028R8P80820P0`0Q8B43028R8P06024Q8@0R8R80820P024Q8@0R8R80
8b<S0P0R8R82024Q8@04028R8P0P82008B4Q028R8P808B4Q200R8R82024Q8@808R8R00@08B4Q028R
8P0Q8B408b<S0P0Q8B401@0P82008R8R028R8P0P82008B4Q00<08R8R00@0820P024Q8@0P82007alO
0`0P8202024Q8@04020P800O7al07alO024Q8@<07alO00L07QhN01lO7`0P82007alO01hN7P0O7al0
820P00807alO00@07QhN01lO7`0O7al07alO0P0P820201lO7`0301hN7P0O7al07QhN00807AdM0P0N
7Qh01`0M7Ad071`L01hN7P0L71`07QhN01`L700M7Ad00P0N7Qh201dM7@0501`L700M7Ad071`L01`L
700M7Ad00P0L71`00`0M7Ad071`L01/K6`0201`L700301/K6`0L71`071`L00806a/K00H071`L01/K
6`0K6a/071`L01XJ6P0K6a/401XJ6P0501/K6`0J6QX06QXJ01XJ6P0K6a/00P0J6QX201/K6`0501TI
6@0J6QX06QXJ01TI6@0J6QX00P0I6AT401XJ6P806ATI00D06QXJ01/K6`0J6QX06QXJ01TI6@0401XJ
6P<06ATI0P0J6QX01`0I6AT06QXJ01XJ6P0J6QX061PH01HF5P0I6AT01P3IfMT100000040fMWI000F
0=WIf@030000003IfMT0fMWI00<0fMWI0P0I6AT01P0K6a/06QXJ01TI6@0I6AT061PH01TI6@806QXJ
00D06a/K01XJ6P0I6AT06ATI01/K6`0501XJ6P0401TI6@0J6QX06QXJ01/K6`806QXJ00<06a/K01TI
6@0L71`00`0J6QX301/K6`0401XJ6P0K6a/06QXJ01`L70806a/K100J6QX00`0I6AT06QXJ01/K6`08
01/K6`806QXJ00D06a/K01XJ6P0J6QX06a/K01XJ6P0301/K6`0601`L700K6a/071`L01`L700K6a/0
71`L0P0K6a/00`0L71`07QhN01dM7@0301`L700801dM7@0L71`07AdM01dM7@0L71`07AdM01`L700K
6a/201`L70807QhN200M7Ad00`0N7Qh07alO01hN7P0201hN7P03020P800N7Qh0820P00807AdM100N
7Qh0200O7al07QhN01lO7`0O7al07QhN020P800O7al07QhN0P0O7al3020P8004024Q8@0P82007alO
024Q8@80820P00P08B4Q020P800P82008B4Q028R8P0Q8B408R8R020P80808R8R0P0Q8B400`0R8R80
8B4Q024Q8@03024Q8@05028R8P0Q8B408R8R024Q8@0P82000P0S8b<0100R8R808B4Q024Q8@0Q8B44
028R8P0302<S8`0R8R808B4Q00808b<S00<0820P024Q8@0Q8B400P0R8R80100S8b<08B4Q02<S8`0R
8R82024Q8@04028R8P0Q8B40820P028R8P@08B4Q00<08R8R020P800Q8B401@0Q8B402@0O7al08B4Q
020P800Q8B407alO01hN7P0P82007alO020P800201lO7`04024Q8@0N7Qh07alO020P80<07alO0P0P
8200200O7al0820P01hN7P0N7Qh0820P01hN7P0O7al07QhN0`0M7Ad201hN7P0301dM7@0N7Qh07AdM
00@07QhN0`0M7Ad201hN7P806a/K00<071`L01dM7@0M7Ad00P0M7Ad601`L700301/K6`0L71`06a/K
00806QXJ00<071`L01/K6`0L71`00P0K6a/00`0J6QX06a/K01/K6`0301/K6`0601TI6@0J6QX06a/K
01/K6`0J6QX071`L0P0K6a/201XJ6P0301TI6@0J6QX06QXJ00806ATI00D06a/K01TI6@0K6a/06QXJ
01/K6`0201XJ6P<06ATI00L06QXJ01TI6@0K6a/06QXJ01/K6`0I6AT06QXJ00806ATI00@06a/K01`L
700J6QX06QXJ100I6AT60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0100J
6QX061PH01PH600H61P201XJ6P0301TI6@0H61P06QXJ00<06QXJ0`0I6AT00`0K6a/06ATI01TI6@02
01XJ6P0801/K6`0J6QX06ATI01/K6`0I6AT06QXJ01/K6`0I6AT401XJ6P0301/K6`0I6AT06QXJ00<0
6a/K0P0I6AT0100J6QX06a/K01XJ6P0K6a/201XJ6P0301`L700I6AT06a/K00H06a/K00D071`L01XJ
6P0L71`06a/K01`L700201/K6`0701`L700K6a/06QXJ01/K6`0L71`06a/K01XJ6P0201/K6`0601`L
700K6a/06a/K01`L700K6a/071`L0P0M7Ad0100K6a/07AdM01dM7@0N7Qh201dM7@0401`L700M7Ad0
7AdM01hN7P@07AdM00D07alO01hN7P0N7Qh07QhN01lO7`0401dM7@@07QhN0P0O7al00`0P82007QhN
01lO7`0501hN7P<07alO00L0820P01lO7`0O7al08B4Q01lO7`0P82007alO00D0820P0`0Q8B400`0O
7al0820P024Q8@02024Q8@808R8R00<0820P028R8P0Q8B400P0Q8B40100R8R808B4Q024Q8@0P8207
028R8P808B4Q00@08b<S024Q8@0Q8B408b<S0P0Q8B43028R8P08024Q8@0S8b<08R8R024Q8@0R8R80
8b<S020P800R8R83024Q8@04028R8P0Q8B408B4Q024Q8@808R8R0P0Q8B43028R8P@08B4Q00<08R8R
024Q8@0Q8B400`0Q8B401P0P82007alO020P800Q8B40820P01lO7`@0820P0P0O7al00`0N7Qh0820P
01lO7`0201lO7`04024Q8@0N7Qh07alO01lO7`<0820P0`0O7al601hN7P<07AdM0`0N7Qh301dM7@03
01lO7`0L71`07AdM00<071`L00<07AdM01`L700K6a/00`0L71`0100K6a/071`L01`L700K6a/201`L
700401XJ6P0K6a/06a/K01/K6`806QXJ0P0K6a/01@0J6QX06a/K01/K6`0J6QX06a/K00H06QXJ00l0
6a/K01XJ6P0K6a/06QXJ01TI6@0K6a/06ATI01XJ6P0I6AT06QXJ01/K6`0J6QX06ATI01/K6`0I6AT0
0`0J6QX0100I6AT06QXJ01TI6@0I6AT201XJ6P0301TI6@0J6QX06QXJ00806QXJ0P0I6AT301XJ6P03
01TI6@3IfMT0fMWI00@0fMWI0@0000010=WIf@005P3IfMT2000000@0fMWI00T06ATI01XJ6P0I6AT0
6ATI01PH600I6AT061PH01XJ6P0I6AT00P0J6QX00`0I6AT06QXJ01PH600201XJ6P0301TI6@0J6QX0
6QXJ00806QXJ00<061PH01XJ6P0I6AT00P0J6QX01@0I6AT06a/K01XJ6P0J6QX06a/K008071`L00<0
6a/K01XJ6P0J6QX01P0J6QX01@0K6a/06QXJ01XJ6P0J6QX06a/K00806QXJ0P0K6a/00`0L71`06a/K
01/K6`0301/K6`@071`L00<06a/K01dM7@0L71`00P0K6a/201`L700501dM7@0K6a/071`L01`L700K
6a/00P0L71`01@0M7Ad071`L01hN7P0M7Ad071`L00807AdM00@071`L01dM7@0M7Ad06a/K0P0M7Ad0
2@0L71`07QhN01dM7@0M7Ad07QhN01dM7@0L71`07AdM01lO7`0401hN7P0301lO7`0N7Qh07QhN0080
7QhN00H07AdM01lO7`0N7Qh07AdM01hN7P0O7al201hN7P0301lO7`0N7Qh07alO0080820P0`0O7al8
020P8004024Q8@0O7al08R8R020P80808R8R00H0820P02<S8`0R8R808R8R020P800Q8B45028R8P03
024Q8@0R8R808B4Q00808R8R00<0820P024Q8@0Q8B400P0R8R801@0Q8B408b<S028R8P0R8R808B4Q
00@08R8R00H092@T024Q8@0S8b<092@T028R8P0P8209028R8P808B4Q00X08b<S024Q8@0R8R808B4Q
028R8P0Q8B408b<S028R8P0Q8B408b<S0P0Q8B400`0R8R80820P024Q8@06020P80<07alO0P0Q8B40
100P82007alO024Q8@0N7Qh401lO7`03024Q8@0P82007alO00<07alO0P0N7Qh00`0P82007QhN01hN
7P0201hN7P0301dM7@0N7Qh07QhN00807AdM00<07QhN01dM7@0N7Qh00`0N7Qh00`0M7Ad071`L01hN
7P0201dM7@0801`L700K6a/07AdM01/K6`0L71`06a/K01`L700M7Ad501`L700301/K6`0L71`06a/K
00@06a/K00T06QXJ01/K6`0L71`06a/K01XJ6P0L71`07AdM01XJ6P0K6a/0100J6QX0100K6a/071`L
01XJ6P0K6a/201XJ6P0401TI6@0K6a/06ATI01PH60H06QXJ00@06ATI01XJ6P0J6QX06a/K0`0I6AT0
1`0K6a/061PH01TI6@0I6AT06QXJ01TI6@0K6a/00P0I6AT00`0H61P06ATI01PH60050=WIf@800000
0@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT401TI6@0401XJ6P0H61P06ATI01TI6@<06QXJ
00@061PH01TI6@0J6QX06ATI0P0J6QX00`0I6AT06QXJ01TI6@0201XJ6P0401TI6@0J6QX06ATI01TI
6@<06QXJ00X06a/K01XJ6P0J6QX06a/K01XJ6P0K6a/06QXJ01`L700J6QX06a/K0P0J6QX0100L71`0
6a/K01/K6`0J6QX201/K6`0401XJ6P0K6a/06a/K01`L70<06a/K00@07AdM01XJ6P0L71`071`L100K
6a/01P0M7Ad06a/K01/K6`0K6a/07AdM01/K6`@071`L00@07AdM01`L700L71`071`L100M7Ad00`0N
7Qh07AdM01dM7@0201dM7@0901`L700M7Ad071`L01`L700M7Ad071`L01dM7@0K6a/07AdM00807alO
00<07QhN01dM7@0M7Ad00P0N7Qh201lO7`0401hN7P0M7Ad07alO01lO7`807QhN00D0820P01lO7`0N
7Qh07alO01hN7P0301lO7`0301hN7P0O7al07QhN00807alO0P0P82002`0Q8B40820P020P800P8200
7alO020P800Q8B408R8R024Q8@0O7al08R8R00808B4Q0`0R8R86024Q8@@08R8R0P0S8b<01P0Q8B40
8R8R024Q8@0R8R808b<S028R8P808B4Q0P0R8R80100Q8B408b<S02<S8`0R8R8202<S8`808B4Q00<0
8R8R02<S8`0S8b<00P0S8b<3028R8P808b<S100R8R8202<S8`03028R8P0S8b<08R8R00808b<S0`0R
8R801@0P82008R8R01lO7`0Q8B40820P00<08B4Q100P820401lO7`09020P800O7al07alO020P800N
7Qh07alO020P800Q8B40820P00P07alO0P0N7Qh00`0M7Ad07QhN01hN7P0201dM7@0601`L700M7Ad0
7AdM01hN7P0O7al07QhN200M7Ad01@0L71`06a/K01`L700L71`07AdM008071`L0P0K6a/01@0L71`0
6a/K01`L700K6a/07AdM00806a/K00@07AdM01`L700K6a/06a/K0`0J6QX00`0I6AT06a/K01/K6`05
01/K6`0601XJ6P0K6a/06QXJ01TI6@0K6a/06ATI0P0J6QX01@0I6AT06QXJ01TI6@0J6QX06a/K00<0
6QXJ100I6AT0100J6QX06ATI01XJ6P0J6QX201TI6@0701XJ6P0I6AT06QXJ01TI6@0J6QX06ATI01PH
600201TI6@H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0301TI6@0H61P0
6ATI00806QXJ0`0I6AT00`0J6QX06ATI01XJ6P0201TI6@806QXJ100I6AT0100J6QX06ATI01TI6@0K
6a/301XJ6P0401TI6@0K6a/06a/K01/K6`806QXJ0`0K6a/201XJ6P0301TI6@0K6a/06QXJ00@06QXJ
0P0K6a/01P0I6AT06a/K01`L700J6QX06a/K01XJ6P806a/K0P0J6QX201`L70806a/K00X071`L01dM
7@0K6a/071`L01/K6`0L71`06a/K01dM7@0K6a/07AdM1@0L71`301dM7@0601`L700M7Ad07AdM01dM
7@0N7Qh071`L0P0M7Ad201`L70D07AdM00<07QhN01dM7@0M7Ad00P0N7Qh0100M7Ad07alO01lO7`0N
7Qh201lO7`L07QhN00@07AdM01lO7`0O7al07alO0`0P82001@0O7al0820P01lO7`0P82007alO0080
820P00<08B4Q020P800Q8B400`0Q8B400`0P82008B4Q024Q8@03024Q8@03028R8P0Q8B408R8R0080
8R8R00<08B4Q028R8P0Q8B40100Q8B400`0R8R808b<S028R8P03028R8P0902<S8`0Q8B408b<S02<S
8`0R8R808b<S028R8P0Q8B408b<S00808R8R00@08B4Q02<S8`0S8b<08b<S100R8R800`0S8b<08R8R
028R8P02024Q8@808R8R00D08b<S028R8P0S8b<09BDU02<S8`02028R8P04020P800R8R808b<S02<S
8`<08R8R0P0Q8B400`0R8R808B4Q01lO7`03020P8003024Q8@0R8R807alO00<08B4Q00P07alO020P
800O7al0820P01lO7`0P82008B4Q020P80807alO00@0820P01lO7`0O7al07QhN0P0O7al501hN7P07
01lO7`0N7Qh07QhN01dM7@0O7al07QhN01dM7@0201hN7P807AdM00D07QhN01dM7@0M7Ad071`L01dM
7@0401`L700301dM7@0K6a/06a/K008071`L00<06a/K01XJ6P0K6a/0100K6a/00`0L71`06a/K01/K
6`0201`L700401XJ6P0K6a/06a/K01/K6`806QXJ100K6a/301XJ6P<06a/K00D06QXJ01TI6@0I6AT0
6QXJ01/K6`0401XJ6P0301TI6@0J6QX06ATI00<06QXJ00@06a/K01TI6@0J6QX06ATI0P0J6QX00`0I
6AT06a/K01TI6@0301XJ6P0401PH600I6AT06ATI01TI6@H0fMWI0@0000010=WIf@005P3IfMT00`00
0000fMWI0=WIf@030=WIf@806ATI00@06QXJ01/K6`0I6AT06ATI0P0J6QX01`0I6AT06QXJ01TI6@0J
6QX06ATI01XJ6P0K6a/00`0J6QX0100H61P06ATI01XJ6P0J6QX301TI6@0401XJ6P0I6AT06a/K01/K
6`D06QXJ00@06a/K01XJ6P0K6a/06QXJ0P0K6a/00`0J6QX071`L01/K6`0401XJ6P@06a/K00H06QXJ
01/K6`0K6a/06a/K01`L700K6a/301`L700501/K6`0L71`071`L01/K6`0L71`00P0K6a/00`0M7Ad0
6a/K01`L700201`L700501/K6`0L71`071`L01dM7@0K6a/01@0M7Ad201`L700701dM7@0N7Qh07QhN
01dM7@0N7Qh07AdM01`L700201hN7P807AdM00<07QhN01dM7@0O7al00`0N7Qh00`0O7al07AdM01lO
7`0401hN7P807alO0P0P8200200Q8B40820P028R8P0P82008B4Q01lO7`0P82007alO0`0P82000`0Q
8B40820P024Q8@02024Q8@@0820P0P0Q8B401@0R8R80820P028R8P0Q8B408R8R00808B4Q100R8R80
0`0Q8B408b<S02<S8`0402<S8`0;028R8P0S8b<08b<S02@T900R8R8092@T02<S8`0Q8B408b<S028R
8P0S8b<00P0R8R8402<S8`0302@T900S8b<08R8R00@08R8R00@08b<S028R8P0R8R808R8R0P0S8b<2
028R8P0302<S8`0T92@08R8R00808b<S0P0R8R801@0S8b<09BDU02DU9@0Q8B408b<S00D08B4Q00@0
820P028R8P0R8R80820P0P0O7al6020P800;01lO7`0P8200820P01lO7`0P82007QhN020P800N7Qh0
820P01lO7`0P82000`0N7Qh201lO7`0801hN7P0O7al07QhN01hN7P0M7Ad07alO01hN7P0M7Ad201hN
7P0401`L700O7al07AdM01hN7P@07AdM0P0L71`0200N7Qh071`L01`L700K6a/071`L01dM7@0L71`0
6a/K0P0L71`301/K6`0501`L700M7Ad06a/K01/K6`0L71`01@0J6QX02`0L71`06ATI01XJ6P0K6a/0
6QXJ01/K6`0I6AT071`L01/K6`0J6QX071`L00806QXJ00<06ATI01XJ6P0H61P00P0I6AT201/K6`@0
6QXJ00H06a/K01XJ6P0J6QX06ATI01/K6`0J6QX501TI6@806QXJ1@0I6AT60=WIf@4000000@3IfMT0
01H0fMWI00<000000=WIf@3IfMT00`3IfMT301TI6@806QXJ00<061PH01XJ6P0J6QX00P0J6QX301TI
6@0401/K6`0J6QX06ATI01TI6@<06QXJ00<061PH01TI6@0I6AT00`0I6AT01P0J6QX06ATI01XJ6P0K
6a/06QXJ01/K6`806QXJ0P0K6a/0100L71`06QXJ01`L700L71`301/K6`806QXJ00<06a/K01XJ6P0J
6QX00P0K6a/00`0L71`06a/K01/K6`0501/K6`0701`L700J6QX071`L01XJ6P0L71`06a/K01`L7002
01dM7@0401`L700K6a/07AdM01/K6`<071`L0`0M7Ad0100L71`07AdM01dM7@0M7Ad201hN7PH07AdM
00@071`L01hN7P0N7Qh07QhN0P0M7Ad00`0O7al07QhN01hN7P0401lO7`0301hN7P0M7Ad07alO00<0
7QhN0`0O7al2024Q8@P0820P00<08B4Q028R8P0P82000`0P8200200Q8B40820P024Q8@0Q8B408R8R
024Q8@0P82008B4Q100R8R801@0P82008R8R028R8P0S8b<08B4Q00808R8R00H092@T028R8P0R8R80
8B4Q02<S8`0R8R8202<S8`03028R8P0S8b<08R8R00D08R8R00H08b<S028R8P0R8R808b<S02@T900R
8R8202<S8`05028R8P0S8b<08R8R028R8P0S8b<00P0R8R8202<S8`0<028R8P0S8b<08R8R028R8P0T
92@08R8R02<S8`0R8R808b<S02@T900R8R808b<S0`0T92@0100R8R8092@T024Q8@0R8R83024Q8@0:
028R8P0P82008B4Q024Q8@0O7al0820P01lO7`0P82007alO01hN7P@0820P00<07alO020P800N7Qh0
0P0O7al0200N7Qh07alO020P800N7Qh0820P01lO7`0N7Qh07alO0P0N7Qh401lO7`<07QhN00X07AdM
01lO7`0N7Qh07QhN01`L700N7Qh07AdM01`L700M7Ad071`L100M7Ad00`0L71`07AdM01/K6`0301`L
70<06a/K00<071`L01/K6`0L71`00`0K6a/02@0L71`06a/K01XJ6P0K6a/071`L01/K6`0J6QX06a/K
01XJ6P0601/K6`<06QXJ00<07AdM01XJ6P0J6QX00P0K6a/201XJ6P0301/K6`0J6QX06QXJ00806QXJ
00d06ATI01XJ6P0J6QX06QXJ01/K6`0I6AT06QXJ01TI6@0J6QX06a/K01XJ6P0I6AT06QXJ00806ATI
00<06QXJ01TI6@0I6AT01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0P0J
6QX201TI6@0601XJ6P0I6AT06ATI01XJ6P0I6AT06a/K0`0I6AT301XJ6P0301TI6@0J6QX06ATI00<0
6QXJ00@06ATI01XJ6P0K6a/06ATI0P0J6QX01P0K6a/06QXJ01XJ6P0J6QX06a/K01XJ6PD06a/K100J
6QX00`0K6a/071`L01/K6`0601/K6`0501`L700J6QX06a/K01XJ6P0K6a/00P0L71`01@0K6a/071`L
01XJ6P0L71`06a/K00<071`L00@06a/K01`L700L71`06a/K1@0L71`00`0M7Ad07QhN01`L700301`L
700401dM7@0N7Qh07QhN01hN7P807AdM0`0N7Qh00`0O7al07QhN01hN7P0301hN7P0901dM7@0O7al0
7alO020P800N7Qh07alO01hN7P0P82007alO0080820P0`0O7al00`0P82008B4Q024Q8@02028R8P80
8B4Q00<07QhN01lO7`0O7al00`0P8202024Q8@03028R8P0P82008B4Q00@08B4Q00<0820P024Q8@0Q
8B400`0R8R80100Q8B408R8R028R8P0Q8B4202<S8`8092@T0P0S8b<00`0T92@08b<S02@T900702<S
8`0302@T900S8b<08b<S00808b<S00<092@T028R8P0S8b<00P0T92@302<S8`04028R8P0S8b<092@T
02@T90808b<S00H092@T02<S8`0S8b<08b<S02@T900S8b<3028R8P0402@T900R8R808b<S02@T9080
9BDU00L092@T028R8P0R8R808R8R02<S8`0Q8B408b<S00808B4Q0P0P8202024Q8@<0820P0P0O7al2
020P800701hN7P0P82008B4Q01lO7`0N7Qh0820P01hN7P0501lO7`0501hN7P0O7al07alO01hN7P0O
7al0100N7Qh0100M7Ad0820P01hN7P0O7al201hN7P0501`L700M7Ad07AdM01`L700N7Qh00P0M7Ad0
300N7Qh06a/K01dM7@0L71`07QhN01dM7@0L71`06a/K01dM7@0L71`06a/K01dM7@806a/K00T071`L
01/K6`0L71`07AdM01`L700J6QX07AdM01`L700J6QX00P0K6a/00`0J6QX06a/K01/K6`0301XJ6P03
01`L700K6a/06QXJ00806QXJ00L06a/K01XJ6P0J6QX06a/K01TI6@0J6QX06a/K00<06ATI00@06QXJ
01TI6@0J6QX06a/K0`0J6QX00`0I6AT06QXJ01XJ6P0301XJ6P806ATI0P0J6QX0100I6AT06QXJ01TI
6@0J6QX60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT02@0I6AT06QXJ01XJ
6P0I6AT06a/K01XJ6P0I6AT06QXJ01TI6@0201XJ6P0501/K6`0J6QX06QXJ01XJ6P0K6a/00`0J6QX0
0`0K6a/06QXJ01/K6`0201TI6@<06a/K00D06ATI01/K6`0J6QX06a/K01XJ6P0201/K6`806QXJ0P0K
6a/0100L71`06a/K01/K6`0J6QX601/K6`0301`L700K6a/06a/K00806a/K00<06QXJ01/K6`0K6a/0
0P0K6a/0200L71`06QXJ01`L700K6a/07AdM01`L700M7Ad06a/K0`0M7Ad00`0K6a/071`L01`L7003
01`L70807AdM00D071`L01dM7@0N7Qh07AdM01`L700201hN7P0701`L700M7Ad07AdM01dM7@0N7Qh0
7AdM01hN7P0201dM7@0601lO7`0N7Qh07QhN01hN7P0O7al07QhN0`0O7al00`0N7Qh07alO01hN7P02
01lO7`04020P800N7Qh08B4Q020P80807alO0P0R8R801@0P82007alO020P800P82007alO0080820P
00<07alO028R8P0R8R800P0P82001@0Q8B408R8R028R8P0O7al08B4Q00H08R8R00D08B4Q02<S8`0Q
8B408b<S028R8P0202<S8`04028R8P0T92@08b<S028R8P<08b<S00P08R8R02<S8`0R8R8092@T02<S
8`0T92@08b<S028R8PD08b<S00@092@T028R8P0R8R808b<S0`0T92@01P0S8b<092@T02DU9@0T92@0
8b<S028R8P808b<S00D092@T02<S8`0T92@08R8R02DU9@0602<S8`8092@T0P0S8b<02@0Q8B408R8R
028R8P0Q8B40820P024Q8@0R8R808B4Q028R8P03024Q8@808R8R00T08B4Q01lO7`0P8200820P024Q
8@0O7al0820P01lO7`0N7Qh00P0P8200100Q8B407alO01lO7`0P820201lO7`07020P800O7al07QhN
020P800O7al07QhN01lO7`0201hN7P0401dM7@0P82007QhN01dM7@807QhN00<07AdM01hN7P0M7Ad0
1@0M7Ad0100L71`07AdM01`L700K6a/201`L700401/K6`0L71`06a/K01/K6`8071`L0P0M7Ad501/K
6`0301`L700K6a/06a/K00806a/K0P0L71`02@0J6QX06a/K01XJ6P0I6AT06QXJ01/K6`0I6AT06QXJ
01/K6`0401XJ6P0301/K6`0J6QX06ATI00806ATI00@06QXJ01TI6@0I6AT06QXJ0P0K6a/201TI6@03
01XJ6P0I6AT061PH00806QXJ0P0H61P00`0J6QX061PH01PH600201XJ6P0301PH603IfMT0fMWI00@0
fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@806ATI00<06QXJ01TI6@0J6QX0
0P0J6QX01@0H61P06ATI01TI6@0J6QX06ATI00<06QXJ00D06a/K01XJ6P0J6QX06a/K01XJ6P0301TI
6@0801/K6`0I6AT06a/K01XJ6P0I6AT06QXJ01/K6`0J6QX301/K6`0501`L700J6QX06QXJ01`L700J
6QX00P0K6a/01@0I6AT06a/K01/K6`0K6a/071`L00806a/K0`0L71`0100J6QX071`L01/K6`0L71`3
01/K6`8071`L00<06a/K01`L700M7Ad00P0L71`01@0K6a/071`L01dM7@0L71`07AdM00<071`L0P0M
7Ad00`0N7Qh07AdM01`L700201hN7P0801dM7@0L71`07QhN01`L700M7Ad071`L01dM7@0O7al501hN
7P0401dM7@0N7Qh07QhN01lO7`<07QhN100O7al0100N7Qh07alO020P800O7al4020P8003024Q8@0R
8R808R8R00808B4Q100P8200100Q8B40820P02<S8`0Q8B42020P8007028R8P0Q8B408B4Q020P800Q
8B408R8R024Q8@03028R8P808B4Q00<08R8R02@T900R8R800`0S8b<01`0T92@08R8R02<S8`0U9BD0
8b<S02@T900U9BD0100S8b<302@T90808b<S00X09BDU02<S8`0S8b<092@T02<S8`0T92@08b<S02DU
9@0S8b<09BDU0`0S8b<202@T900702DU9@0S8b<092@T02<S8`0T92@08b<S02@T9002028R8P@08b<S
00<08R8R02<S8`0S8b<0100S8b<0100R8R808B4Q028R8P0Q8B44028R8P04020P800Q8B40820P028R
8PH0820P00@07alO024Q8@0O7al08B4Q0`0O7al01P0Q8B40820P01hN7P0N7Qh07alO01hN7P<07alO
00<08B4Q01hN7P0N7Qh00`0N7Qh00`0M7Ad07alO01lO7`0301hN7PP07AdM00<071`L01/K6`0L71`0
0P0L71`00`0K6a/07AdM01dM7@0301`L70806a/K00<071`L01dM7@0M7Ad00P0L71`00`0K6a/071`L
01/K6`0301`L70@06a/K1P0J6QX00`0K6a/06ATI01XJ6P0201XJ6P806ATI00D06a/K01TI6@0I6AT0
6ATI01/K6`0801XJ6P806ATI00<061PH01TI6@0J6QX00`0I6AT201XJ6PH0fMWI0@0000010=WIf@00
5P3IfMT00`000000fMWI0=WIf@030=WIf@806QXJ00<06ATI01XJ6P0J6QX00P0I6AT00`0H61P06QXJ
01XJ6P0201TI6@<06QXJ00<06ATI01XJ6P0I6AT00P0J6QX0100I6AT06QXJ01XJ6P0I6AT201XJ6P04
01TI6@0J6QX06QXJ01`L70806a/K0P0J6QX201`L700301XJ6P0L71`06QXJ00<06a/K00<06QXJ01/K
6`0K6a/00P0K6a/301`L70<06a/K0`0L71`0100K6a/071`L01/K6`0K6a/401`L700801dM7@0L71`0
6a/K01`L700K6a/071`L01dM7@0N7Qh201`L700301dM7@0N7Qh071`L00<07QhN1@0M7Ad00`0N7Qh0
7AdM01hN7P0401hN7P0501lO7`0N7Qh07QhN01lO7`0M7Ad00P0N7Qh201lO7`0?01hN7P0M7Ad0820P
01lO7`0P82007alO01hN7P0O7al0820P01lO7`0P82008B4Q020P800Q8B407alO00<08B4Q00<0820P
028R8P0Q8B400`0Q8B43028R8P808B4Q00D08R8R024Q8@0R8R808b<S02@T9003028R8P0902<S8`0T
92@08b<S02DU9@0R8R8092@T02<S8`0T92@08b<S008092@T00@09BDU02@T900U9BD08b<S100T92@0
0`0S8b<092@T02@T900202DU9@0302@T900U9BD092@T00D092@T00<08b<S02@T900T92@00P0T92@0
0`0S8b<092@T02@T900302@T9006028R8P0S8b<08b<S02<S8`0R8R808b<S0P0T92@01P0R8R808b<S
028R8P0R8R808b<S028R8P808b<S00@08R8R024Q8@0R8R808B4Q0P0R8R82024Q8@09028R8P0Q8B40
8B4Q020P800Q8B40820P02@T900P82007alO00<0820P0P0O7al00`0P82007alO01lO7`0301lO7`09
020P800O7al0820P01lO7`0N7Qh07alO01hN7P0O7al07QhN00807alO0P0N7Qh201dM7@0301hN7P0M
7Ad07QhN00807AdM00<071`L01dM7@0L71`00P0M7Ad00`0L71`07AdM01`L700201dM7@@071`L00<0
7AdM01`L700K6a/00P0L71`01@0M7Ad071`L01`L700L71`06QXJ00<06a/K00D071`L01/K6`0L71`0
71`L01XJ6P0501/K6`0301XJ6P0K6a/06QXJ00806QXJ100K6a/301XJ6P0301TI6@0J6QX06QXJ00<0
6QXJ00@06ATI01XJ6P0J6QX06QXJ0P0I6AT01P0H61P06QXJ01XJ6P0J6QX06ATI01XJ6P806ATI1P3I
fMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00D06a/K01TI6@0J6QX06ATI01/K
6`0201XJ6P@06ATI00<06QXJ01/K6`0I6AT01@0J6QX00`0I6AT06QXJ01XJ6P0201TI6@0401/K6`0I
6AT06ATI01TI6@806QXJ00T06a/K01XJ6P0J6QX06QXJ01`L700J6QX06ATI01XJ6P0K6a/00P0J6QX0
1@0I6AT06a/K01`L700J6QX071`L00<06a/K00<071`L01/K6`0K6a/00P0L71`00`0K6a/071`L01/K
6`0201`L700301/K6`0L71`06QXJ008071`L00<06a/K01`L700L71`00P0L71`00`0N7Qh07AdM01dM
7@0501`L70807AdM00<07QhN01`L700M7Ad00P0N7Qh201dM7@0501hN7P0M7Ad07QhN01hN7P0M7Ad0
100O7al00`0N7Qh07alO01hN7P0401hN7P80820P0`0O7al00`0P82007alO024Q8@02024Q8@05020P
800Q8B40820P024Q8@0P82000P0Q8B40200R8R808b<S028R8P0Q8B40820P024Q8@0R8R808B4Q1@0R
8R80100S8b<08B4Q02<S8`0S8b<2028R8P0302<S8`0T92@08b<S00808R8R0P0T92@02@0S8b<092@T
02@T900S8b<08R8R02<S8`0T92@09BDU02<S8`0502@T900302<S8`0T92@08b<S00<092@T00<08b<S
02@T900T92@00P0S8b<202@T90808b<S00<092@T02DU9@0T92@00P0T92@0100S8b<092@T028R8P0T
92@202<S8`8092@T0`0S8b<202@T90808b<S00<08R8R02<S8`0R8R800P0S8b<0100R8R80820P028R
8P0R8R82024Q8@0402<S8`0Q8B40820P024Q8@80820P00D0=cLg038b<P0P8200820P024Q8@02020P
800301lO7`0P82008B4Q00<07alO00@0820P01hN7P0P8200820P0`0O7al0100M7Ad07QhN01hN7P0N
7Qh401lO7`0301hN7P0M7Ad07QhN00807AdM0P0L71`00`0N7Qh07AdM01dM7@0301dM7@0301/K6`0L
71`071`L00806a/K00D071`L01/K6`0L71`071`L01/K6`0301`L700401/K6`0L71`06a/K01XJ6PD0
6a/K00<06QXJ01/K6`0I6AT01@0K6a/301XJ6P0301/K6`0J6QX06QXJ00806QXJ00<06a/K01XJ6P0I
6AT01`0J6QX201TI6@0:01/K6`0J6QX06ATI01TI6@0K6a/06ATI01XJ6P0I6AT061PH01XJ6P806ATI
1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00H06QXJ01TI6@0K6a/06a/K
01XJ6P0I6AT601XJ6P0:01TI6@0J6QX06ATI01XJ6P0I6AT06QXJ01PH600K6a/06ATI01XJ6P806ATI
00@06QXJ01TI6@0J6QX06a/K0P0J6QX0100K6a/06QXJ01XJ6P0I6AT201/K6`0301XJ6P0K6a/06QXJ
00806a/K0`0J6QX301/K6`0301XJ6P0K6a/06QXJ00806a/K00L071`L01/K6`0K6a/071`L01dM7@0L
71`06a/K00<071`L00<06a/K01dM7@0K6a/00P0K6a/01@0L71`07AdM01`L700M7Ad07QhN00806a/K
00@07AdM01hN7P0M7Ad071`L0`0M7Ad00`0O7al07QhN01dM7@0201dM7@P07QhN00<07alO01hN7P0O
7al00`0O7al00`0P82007QhN01lO7`0301lO7`@0820P00l07alO024Q8@0Q8B408B4Q020P800Q8B40
8R8R020P800Q8B40820P028R8P0Q8B408R8R024Q8@0R8R800`0Q8B400`0S8b<08B4Q028R8P04028R
8P808b<S00D092@T024Q8@0S8b<08b<S02@T900202<S8`0802@T900S8b<08b<S02DU9@0T92@08b<S
02@T900U9BD202@T900602<S8`0T92@092@T02<S8`0U9BD09RHV0`0U9BD202@T900502<S8`0U9BD0
92@T02@T900V9RH00P0U9BD00`0T92@08b<S02<S8`0302@T900402DU9@0T92@092@T02<S8`8092@T
0P0S8b<00`0T92@08b<S02<S8`0202@T900402DU9@0S8b<08b<S028R8P<08b<S00@08R8R02<S8`0Q
8B408R8R0P0Q8B42028R8P@08B4Q0P0P8202024Q8@0501lO7`0P82007alO01lO7`0Q8B400P0P8200
100O7al0820P01lO7`0P820201lO7`807QhN00<07alO01hN7P0P82000`0O7al02P0N7Qh0820P01hN
7P0N7Qh07alO01hN7P0M7Ad07alO01`L700O7al301dM7@0501`L700M7Ad07AdM02DU9@0P82000P0M
7Ad0200K6a/07AdM01dM7@0M7Ad071`L01dM7@0K6a/071`L0P0M7Ad00`0J6QX071`L01`L700301/K
6`806QXJ0P0K6a/02P0L71`06QXJ01`L700J6QX06ATI01XJ6P0I6AT06a/K01XJ6P0K6a/201XJ6P04
01/K6`0J6QX06QXJ01XJ6P806ATI00<06QXJ01TI6@0J6QX00P0J6QX0100I6AT06QXJ01XJ6P0I6AT3
01XJ6P0401TI6@0J6QX06QXJ01TI6@<06QXJ00<06ATI01XJ6P3IfMT01@3IfMT100000040fMWI000F
0=WIf@030000003IfMT0fMWI00<0fMWI00@06ATI01XJ6P0I6AT06a/K0P0J6QX00`0I6AT06QXJ01TI
6@0601XJ6P0301`L700K6a/06QXJ00806a/K00<06QXJ01TI6@0J6QX00P0J6QX301/K6`<06QXJ0P0K
6a/00`0J6QX06ATI01XJ6P0401/K6`0601XJ6P0K6a/06QXJ01`L700K6a/06QXJ0P0K6a/00`0J6QX0
6a/K01XJ6P0201/K6`@071`L00@06a/K01`L700K6a/06a/K0`0L71`01`0K6a/07AdM01/K6`0L71`0
6a/K01dM7@0N7Qh00P0L71`01@0M7Ad07QhN01`L700K6a/071`L00807AdM00<07QhN01dM7@0N7Qh0
0P0M7Ad00`0O7al07AdM01hN7P0301hN7P05020P800M7Ad07alO020P800N7Qh00P0O7al201hN7P03
020P800N7Qh08B4Q00<07alO00H0820P024Q8@0P82008B4Q01lO7`0P8206024Q8@06028R8P0Q8B40
8R8R024Q8@0R8R808B4Q1@0R8R80100S8b<08R8R028R8P0R8R8202@T9006028R8P0S8b<092@T02@T
900S8b<08R8R0`0T92@0100S8b<092@T02DU9@0T92@702DU9@0502<S8`0U9BD09RHV02<S8`0U9BD0
0`0T92@202DU9@8092@T00<09BDU02HV9P0T92@00P0T92@01@0U9BD08b<S02HV9P0T92@09BDU0080
92@T0P0U9BD302<S8`0402@T900S8b<08b<S02@T90@08b<S0P0T92@01@0S8b<08R8R028R8P0S8b<0
8B4Q00808R8R00D08b<S024Q8@0S8b<08R8R024Q8@04028R8P0302<S8`0Q8B408B4Q00H0820P00<0
8b<S020P800Q8B40100O7al0200P82007QhN01hN7P0P82007alO020P800O7al07QhN0P0P82001P0N
7Qh07alO01lO7`0O7al07AdM01hN7P@07AdM00<071`L01hN7P0M7Ad00P0L71`01P0M7Ad071`L01dM
7@0N7Qh07AdM01/K6`<07AdM00@06a/K01`L700L71`06QXJ0`0L71`00`0K6a/071`L01`L700301/K
6`8071`L0P0J6QX201/K6`806QXJ0`0K6a/401XJ6P0901`L700K6a/06QXJ01TI6@0K6a/06ATI01XJ
6P0K6a/06ATI00806QXJ00<061PH01TI6@0J6QX00P0J6QX00`0K6a/06QXJ01/K6`0201XJ6P0301TI
6@0H61P06ATI00806QXJ1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0P0K
6a/0100J6QX06a/K01TI6@0J6QX201TI6@@06QXJ0`0I6AT03`0J6QX06a/K01XJ6P0J6QX06ATI01XJ
6P0I6AT061PH01XJ6P0I6AT06a/K01TI6@0J6QX06ATI01XJ6P0301/K6`806QXJ00<06a/K01`L700I
6AT00P0K6a/201XJ6P0801`L700K6a/06a/K01dM7@0K6a/071`L01/K6`0M7Ad201/K6`806QXJ00@0
71`L01/K6`0L71`07AdM0`0L71`00`0N7Qh071`L01/K6`0201/K6`0301`L700M7Ad07AdM00807AdM
00H071`L01hN7P0L71`06a/K01dM7@0L71`201dM7@0501`L700N7Qh07QhN01dM7@0N7Qh00`0M7Ad4
01hN7P06020P800N7Qh07alO01lO7`0P82007QhN0P0O7al0100P82007alO01lO7`0N7Qh5020P8003
024Q8@0O7al08B4Q00<0820P0`0Q8B401`0R8R808B4Q020P800Q8B408b<S020P800S8b<00`0R8R80
1`0S8b<08R8R028R8P0S8b<092@T02<S8`0T92@00P0R8R80300T92@08R8R02<S8`0S8b<092@T02<S
8`0U9BD08b<S02DU9@0T92@09BDU02@T90809BDU00<092@T02DU9@0U9BD0200U9BD00`0T92@09BDU
02HV9P0202@T900402DU9@0T92@09BDU02HV9P809BDU00@092@T02DU9@0T92@09RHV0P0U9BD302<S
8`<092@T00D09BDU02@T900S8b<09BDU02@T900202<S8`0302@T900S8b<08b<S00809BDU00D092@T
028R8P0S8b<08b<S028R8P02024Q8@0302<S8`0R8R808R8R00808R8R0P0Q8B42028R8P<08B4Q00D0
7alO024Q8@0P8200820P024Q8@03020P800601lO7`0P82007QhN01lO7`0P82007alO0P0N7Qh2020P
80@07alO00L0820P01hN7P0N7Qh07QhN01lO7`0N7Qh07AdM00H07QhN00<07AdM01hN7P0M7Ad00`0M
7Ad01`0L71`06a/K01dM7@0K6a/07AdM01`L700K6a/00P0L71`601/K6`8071`L0`0K6a/201XJ6P<0
6a/K00@06QXJ01/K6`0J6QX06a/K0`0J6QX0100I6AT06QXJ01XJ6P0I6AT801XJ6P0501TI6@0K6a/0
6QXJ01TI6@0J6QX00`0I6AT01P0K6a/06ATI01XJ6P0I6AT06QXJ01TI6@H0fMWI0@0000010=WIf@00
5P3IfMT2000000@0fMWI0P0J6QX02`0I6AT06QXJ01TI6@0K6a/06ATI01XJ6P0I6AT06QXJ01TI6@0J
6QX06a/K00806QXJ01006ATI01/K6`0J6QX06ATI01XJ6P0I6AT06a/K01`L700J6QX06ATI01XJ6P0I
6AT06a/K01XJ6P0K6a/071`L0P0J6QX00`0K6a/06QXJ01/K6`0301XJ6P0301/K6`0J6QX06QXJ00<0
6QXJ00<071`L01dM7@0J6QX00P0K6a/401`L700401/K6`0L71`06a/K01/K6`<071`L00<06a/K01`L
700L71`00P0L71`02@0K6a/071`L01dM7@0L71`07QhN01`L700N7Qh071`L01hN7P0701dM7@807QhN
00@07AdM01hN7P0O7al07alO0P0N7Qh301lO7`04024Q8@0P82007AdM01lO7`@08B4Q00T0820P01lO
7`0O7al0820P01lO7`0P82008B4Q020P800O7al00`0Q8B401P0R8R808B4Q028R8P0P82008R8R024Q
8@@08R8R00<08B4Q02<S8`0R8R800P0R8R801P0S8b<092@T02<S8`0S8b<092@T02<S8`<092@T0P0S
8b<202@T900302DU9@0S8b<092@T008092@T1P0U9BD402@T900302DU9@0V9RH09BDU00809RHV00H0
92@T02DU9@0V9RH09RHV02@T900V9RH302DU9@0302HV9P0U9BD092@T00@09BDU00<09RHV02@T900V
9RH00P0V9RH202DU9@D092@T00<09BDU02@T900U9BD00`0T92@202<S8`07028R8P0S8b<08R8R02<S
8`0Q8B408R8R024Q8@0202<S8`05028R8P0Q8B408R8R028R8P0S8b<00P0Q8B400`0R8R808B4Q024Q
8@02020P8005024Q8@0R8R808R8R024Q8@0R8R800`0O7al01@0P82007QhN020P800Q8B407QhN0080
7alO00L07QhN020P800N7Qh07QhN020P800M7Ad07alO00807QhN00<07alO01dM7@0N7Qh00P0N7Qh3
01dM7@0?01hN7P0M7Ad07AdM01dM7@0N7Qh07AdM01`L700M7Ad071`L01dM7@0L71`07AdM01/K6`0M
7Ad06a/K008071`L00<06a/K01`L700K6a/00P0L71`01`0J6QX071`L01XJ6P0K6a/071`L01/K6`0J
6QX01@0K6a/01@0J6QX06a/K01/K6`0J6QX06a/K00<06QXJ00@071`L01/K6`0J6QX06QXJ0P0I6AT3
01XJ6P0301/K6`0I6AT06QXJ00806QXJ00<061PH01XJ6P0I6AT01@0I6AT50=WIf@8000000@3IfMT0
01H0fMWI00<000000=WIf@3IfMT00`3IfMT0200J6QX06ATI01XJ6P0I6AT06QXJ01/K6`0J6QX06ATI
0P0J6QX02@0K6a/06QXJ01XJ6P0K6a/06ATI01XJ6P0K6a/06QXJ01/K6`0201XJ6P0301/K6`0J6QX0
6a/K00<06QXJ00@071`L01/K6`0K6a/06a/K0P0J6QX03`0K6a/071`L01/K6`0K6a/06QXJ01/K6`0J
6QX06ATI01XJ6P0L71`06QXJ01/K6`0L71`06QXJ01TI6@0201/K6`0501XJ6P0K6a/06a/K01/K6`0L
71`00`0K6a/0100J6QX071`L01`L700K6a/401`L70<06a/K0`0M7Ad0100L71`07AdM01dM7@0L71`2
01hN7P@07AdM00D07QhN01dM7@0N7Qh0820P01hN7P0201lO7`807AdM0P0O7al0100P82007alO01lO
7`0Q8B43020P8004024Q8@0P8200820P01lO7`808B4Q0`0P82001P0Q8B40820P01lO7`0Q8B408R8R
020P80808R8R00<08b<S024Q8@0S8b<01P0R8R8202<S8`03028R8P0S8b<08b<S00<08b<S00<092@T
02<S8`0S8b<00P0T92@00`0U9BD092@T02DU9@0202@T900302HV9P0U9BD09BDU00<09BDU00@09RHV
02DU9@0U9BD09RHV0P0U9BD202HV9P0702@T900X:2P09RHV02HV9P0U9BD09RHV02DU9@0302HV9P05
02DU9@0V9RH09bLW02LW9`0V9RH01@0U9BD01@0T92@09RHV02HV9P0U9BD092@T00809BDU00T08b<S
02HV9P0U9BD092@T02DU9@0S8b<092@T02HV9P0U9BD0100T92@202<S8`0402@T900S8b<08b<S028R
8P808b<S100R8R8202<S8`808R8R0`0Q8B42028R8P0502@T900Q8B408B4Q024Q8@0N7Qh01@0O7al0
0`0N7Qh07alO01hN7P0401lO7`0801hN7P0O7al07QhN01dM7@0N7Qh07AdM01`L700M7Ad201hN7P80
7AdM00<07QhN01dM7@0N7Qh0100M7Ad02@0L71`06a/K01dM7@0L71`07AdM01`L700K6a/071`L01/K
6`0201`L700801/K6`0L71`071`L01/K6`0L71`06a/K01`L700J6QX301/K6`806QXJ0`0K6a/01P0I
6AT06a/K01XJ6P0K6a/06QXJ01/K6`<06QXJ00H06a/K01XJ6P0K6a/06a/K01XJ6P0K6a/201XJ6P03
01/K6`0J6QX06a/K00806QXJ0`0I6AT201/K6`0501TI6@0H61P06QXJ01TI6@0J6QX01P3IfMT10000
0040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0`0J6QX0100K6a/06QXJ01XJ6P0H61P201TI
6@0301XJ6P0I6AT06QXJ00@06QXJ00<06a/K01TI6@0I6AT02P0J6QX01@0K6a/071`L01XJ6P0K6a/0
71`L00@06a/K0P0J6QX02P0L71`06QXJ01/K6`0K6a/071`L01dM7@0L71`06a/K01XJ6P0L71`601/K
6`P071`L00D06a/K01`L700M7Ad07AdM01/K6`0201`L700301hN7P0M7Ad07AdM00D07AdM00<07QhN
01dM7@0N7Qh00P0M7Ad201hN7P807AdM00<07alO01hN7P0O7al00`0O7al2020P8004028R8P0P8200
8b<S024Q8@80820P00@08B4Q020P800Q8B407alO0P0P82001@0R8R808B4Q024Q8@0R8R808b<S0080
8B4Q00H08R8R024Q8@0Q8B408B4Q028R8P0Q8B4402<S8`0402@T900S8b<08b<S02DU9@8092@T00L0
8b<S02@T900S8b<09BDU02<S8`0V9RH08b<S00/09BDU0P0V9RH01@0U9BD09RHV02DU9@0U9BD09RHV
00809BDU00d09RHV02DU9@0V9RH09RHV02PX:00V9RH09bLW02DU9@0X:2P09bLW02HV9P0W9bL09BDU
00809RHV00<09bLW02DU9@0T92@00`0U9BD00`0T92@09BDU02HV9P0602DU9@0302@T900U9BD09BDU
00<09BDU00<092@T02<S8`0S8b<01P0S8b<00`0T92@08R8R02<S8`03028R8P04024Q8@0T92@08b<S
028R8P808B4Q00D08R8R02<S8`0Q8B40820P02<S8`02024Q8@0301lO7`0P82008B4Q00@0820P00@0
8B4Q01hN7P0P8200820P0P0O7al301hN7P0701lO7`0N7Qh07QhN01dM7@0N7Qh07AdM01hN7P0301dM
7@0301hN7P0M7Ad07AdM00<071`L0P0M7Ad401`L700601dM7@0L71`071`L01/K6`0L71`07AdM0`0L
71`00`0K6a/071`L01`L700201/K6`0601XJ6P0K6a/06QXJ01/K6`0J6QX06a/K100J6QX0100L71`0
6QXJ01`L700J6QX301/K6`<06QXJ00<06ATI01XJ6P0I6AT00`0J6QX0100I6AT06a/K01TI6@0K6a/7
01XJ6P0301TI6@0K6a/06ATI00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WI
f@0701XJ6P0I6AT06ATI01PH600I6AT06QXJ01/K6`0201XJ6P0301TI6@0K6a/06QXJ00806QXJ0P0I
6AT01@0K6a/06QXJ01XJ6P0K6a/06QXJ00806a/K00@06QXJ01TI6@0J6QX06ATI0P0J6QX0200L71`0
6ATI01XJ6P0K6a/06QXJ01/K6`0L71`06a/K0`0J6QX201/K6`0301`L700J6QX06a/K00806QXJ00<0
71`L01XJ6P0K6a/0100L71`201/K6`0901dM7@0L71`07AdM01`L700N7Qh071`L01XJ6P0L71`07AdM
008071`L00L07AdM01`L700M7Ad07AdM01`L700M7Ad071`L00807AdM00<071`L01dM7@0N7Qh0100M
7Ad0100N7Qh07AdM01dM7@0N7Qh201lO7`0701hN7P0O7al07alO01lO7`0P82007alO020P8002024Q
8@04028R8P0Q8B408B4Q020P80808B4Q00D07QhN024Q8@0O7al08B4Q01lO7`02024Q8@<08R8R0P0S
8b<00`0Q8B408b<S02<S8`02028R8P06024Q8@0R8R808R8R028R8P0T92@08R8R0`0S8b<202@T900:
02<S8`0T92@092@T02<S8`0U9BD092@T02<S8`0U9BD092@T02HV9P<09BDU0P0V9RH00`0U9BD09RHV
02DU9@0202DU9@809RHV00H09bLW02HV9P0V9RH09BDU02LW9`0T92@202HV9P0302LW9`0V9RH09RHV
0080:2PX00P09bLW02HV9P0V9RH09BDU02HV9P0W9bL09RHV02DU9@@09RHV00L09bLW02HV9P0W9bL0
9RHV02@T900V9RH09BDU00809RHV00@09BDU02<S8`0T92@09BDU0P0T92@00`0S8b<092@T02@T9003
02<S8`03028R8P0S8b<08b<S00808b<S00H08R8R02<S8`0S8b<08B4Q028R8P0S8b<2028R8P05024Q
8@0R8R808R8R028R8P0Q8B400P0R8R80100P82008B4Q020P800O7al3020P80808B4Q00<07QhN024Q
8@0P82000P0O7al00`0P82007QhN01lO7`0201hN7P807AdM00@07QhN01`L700N7Qh07AdM0`0N7Qh0
100M7Ad07QhN01`L700L71`201hN7P0501dM7@0L71`07AdM01`L700M7Ad00`0L71`02`0K6a/071`L
01`L700L71`06a/K01`L700M7Ad06a/K01`L700K6a/071`L00806QXJ00`06a/K01XJ6P0J6QX06a/K
01`L700I6AT06a/K01TI6@0J6QX06a/K01XJ6P0K6a/301XJ6P0501`L700J6QX06QXJ01TI6@0L71`0
0P0J6QX01@0K6a/06QXJ01XJ6P0J6QX06a/K00D06QXJ00D06ATI01XJ6P0J6QX06QXJ01PH600201TI
6@H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0401XJ6P0I6AT06ATI01TI
6@806QXJ00<06a/K01XJ6P0K6a/00P0J6QX00`0I6AT06QXJ01XJ6P0201XJ6P0301/K6`0J6QX06QXJ
00<06a/K0P0J6QX00`0I6AT061PH01XJ6P0301/K6`0901`L700J6QX06a/K01/K6`0J6QX06a/K01XJ
6P0K6a/06QXJ00D06a/K00<071`L01/K6`0K6a/00P0K6a/02@0J6QX071`L01XJ6P0J6QX06a/K01`L
700M7Ad071`L01/K6`0201dM7@@071`L00H06a/K01dM7@0L71`071`L01dM7@0K6a/201dM7@0501hN
7P0M7Ad071`L01`L700M7Ad00P0N7Qh00`0M7Ad07QhN01hN7P0201hN7P0301dM7@0O7al07QhN0080
7QhN0P0O7al201hN7P07020P800O7al0820P028R8P0Q8B408R8R024Q8@02020P800401lO7`0P8200
820P024Q8@<0820P00<07alO024Q8@0R8R800`0Q8B401@0P82008R8R028R8P0S8b<08R8R00@08b<S
00<08R8R02@T900S8b<00P0S8b<01`0T92@08b<S02DU9@0U9BD08b<S02@T900U9BD00P0T92@302DU
9@0402HV9P0U9BD09RHV02@T90<09RHV00D09BDU02HV9P0U9BD09BDU02LW9`0202HV9P0<02DU9@0W
9bL09RHV02LW9`0V9RH0:2PX02LW9`0V9RH0:2PX02LW9`0Y:BT0:2PX0P0W9bL202HV9P0502LW9`0V
9RH09bLW02DU9@0W9bL00P0V9RH202DU9@809RHV00/09BDU02LW9`0W9bL09BDU02@T900V9RH092@T
02HV9P0U9BD09RHV02DU9@0502@T900402<S8`0T92@08b<S02DU9@808b<S00L092@T02<S8`0S8b<0
8b<S028R8P0S8b<08B4Q00<08R8R0P0Q8B400`0S8b<08B4Q028R8P02028R8P@0820P0P0O7al00`0N
7Qh08B4Q01lO7`02020P800501lO7`0N7Qh0820P01lO7`0N7Qh00`0O7al201dM7@0901lO7`0N7Qh0
7QhN01dM7@0N7Qh071`L01hN7P0M7Ad071`L00807AdM00<071`L01hN7P0L71`0100L71`01P0M7Ad0
71`L01`L700M7Ad071`L01/K6`8071`L0`0K6a/201`L70@06a/K0P0J6QX01P0K6a/071`L01/K6`0L
71`07AdM01XJ6P806a/K00<06ATI01XJ6P0K6a/00P0J6QX00`0I6AT06QXJ01XJ6P0201/K6`0301XJ
6P0K6a/06QXJ00806a/K00H06QXJ01TI6@0I6AT06QXJ01TI6@0J6QX301TI6@0301PH600I6AT06ATI
00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0:01XJ6P0I6AT06ATI01XJ
6P0I6AT061PH01XJ6P0I6AT06QXJ01/K6`806QXJ00L06a/K01TI6@0J6QX06a/K01TI6@0K6a/06ATI
00<06QXJ00D06a/K01XJ6P0K6a/06QXJ01TI6@0401XJ6P<06a/K00<06QXJ01/K6`0J6QX00P0L71`3
01XJ6P0701/K6`0L71`06QXJ01`L700K6a/071`L01XJ6P0201/K6`8071`L0P0K6a/01@0L71`06a/K
01`L700N7Qh071`L00<07AdM100L71`201dM7@0501hN7P0M7Ad07AdM01dM7@0L71`00`0M7Ad00`0N
7Qh07AdM01dM7@0201dM7@807QhN0P0O7al00`0N7Qh07alO020P800401lO7`03020P800O7al0820P
00@0820P00<07alO020P800Q8B400`0P82001P0Q8B40820P020P800Q8B408R8R020P80808R8R00<0
8B4Q028R8P0Q8B40100R8R8202<S8`09028R8P0T92@092@T02@T900S8b<092@T02<S8`0T92@08b<S
00809BDU00L09RHV02DU9@0U9BD09BDU02@T900U9BD09RHV00809BDU00D09bLW02HV9P0U9BD09BDU
02LW9`0202HV9P0502LW9`0X:2P09RHV02LW9`0V9RH0100W9bL00`0V9RH09bLW02DU9@0202PX:080
9RHV00D0:2PX02LW9`0W9bL09bLW02PX:00302LW9`0402HV9P0W9bL09RHV02DU9@@09bLW0P0U9BD2
02HV9P809BDU00X09RHV02DU9@0V9RH09RHV02DU9@0S8b<09RHV02DU9@0T92@08b<S0P0T92@202DU
9@<092@T00T08b<S02@T900R8R808R8R02@T900R8R808B4Q028R8P0S8b<00`0Q8B40100R8R808b<S
024Q8@0R8R82024Q8@04028R8P0Q8B408B4Q01lO7`808B4Q00<0820P024Q8@0Q8B400`0P820201lO
7`0501dM7@0O7al07QhN01hN7P0O7al0100N7Qh0100M7Ad07QhN01hN7P0N7Qh301dM7@0301`L700M
7Ad07AdM00D071`L00<07QhN01dM7@0L71`00P0L71`0100M7Ad06a/K01`L700K6a/201`L70806a/K
00<071`L01/K6`0K6a/00P0K6a/01@0J6QX071`L01`L700K6a/071`L00@06QXJ00<06a/K01XJ6P0K
6a/00P0J6QX01P0L71`06QXJ01XJ6P0I6AT06a/K01TI6@<06QXJ00D06ATI01XJ6P0I6AT06a/K01XJ
6P0201TI6@806QXJ0P0I6AT00`0J6QX0fMWI0=WIf@040=WIf@4000000@3IfMT001H0fMWI00<00000
0=WIf@3IfMT00`3IfMT01@0J6QX06ATI01XJ6P0J6QX06a/K00D06QXJ00L06ATI01XJ6P0K6a/06QXJ
01TI6@0J6QX06ATI00806QXJ00<06a/K01XJ6P0J6QX0100J6QX00`0L71`06a/K01/K6`0301XJ6P0:
01`L700K6a/071`L01/K6`0J6QX06a/K01XJ6P0L71`06a/K01XJ6P8071`L0P0K6a/201`L700401/K
6`0J6QX06a/K01XJ6P@071`L00H07QhN01/K6`0M7Ad07AdM01`L700K6a/401dM7@0301`L700M7Ad0
6a/K00@071`L0`0M7Ad201hN7P0401lO7`0M7Ad07QhN01dM7@<07QhN1P0O7al0100P82007alO024Q
8@0P820201lO7`80820P00H07alO020P800Q8B408B4Q020P800Q8B42020P800<024Q8@0S8b<0820P
028R8P0Q8B408R8R024Q8@0R8R808B4Q028R8P0S8b<092@T0P0S8b<302@T900302<S8`0T92@092@T
008092@T00@08b<S02HV9P0U9BD092@T0P0U9BD01`0T92@09BDU02HV9P0V9RH09BDU02LW9`0U9BD0
0P0W9bL202HV9P0402LW9`0V9RH09bLW02PX:0@09bLW00D0:2PX02LW9`0W9bL09bLW02HV9P0202LW
9`0302PX:00Y:BT09bLW0080:BTY00<0:2PX02LW9`0X:2P00P0W9bL01`0X:2P09bLW02LW9`0X:2P0
9RHV02LW9`0V9RH00P0W9bL202HV9P0302LW9`0V9RH09bLW00809RHV0P0U9BD00`0V9RH09BDU02DU
9@0202DU9@8092@T00<08R8R02<S8`0U9BD00`0T92@502<S8`03028R8P0S8b<08b<S00808b<S0`0R
8R80100Q8B408R8R028R8P0R8R83024Q8@04028R8P0P82007alO024Q8@80820P00P08B4Q028R8P0Q
8B408B4Q01lO7`0P82008B4Q01hN7P807alO0P0N7Qh01@0O7al07QhN01hN7P0O7al07QhN00807AdM
00L07QhN01`L700N7Qh07QhN01`L700K6a/07QhN00<07AdM0P0L71`00`0M7Ad071`L01`L700301dM
7@8071`L100K6a/00`0L71`06a/K01/K6`0301/K6`0901`L700K6a/06a/K01dM7@0J6QX06a/K01TI
6@0K6a/071`L00806a/K00@06QXJ01/K6`0K6a/06ATI0P0J6QX01P0K6a/06QXJ01/K6`0J6QX06a/K
01TI6@806QXJ00<06a/K01`L700J6QX00`0J6QX00`0I6AT06QXJ01XJ6P0301TI6@H0fMWI0@000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@806ATI00P06QXJ01TI6@0J6QX06ATI01XJ6P0I
6AT06a/K01TI6@<06QXJ00D06a/K01TI6@0J6QX06QXJ01/K6`0201XJ6P0501/K6`0J6QX06QXJ01XJ
6P0K6a/0100J6QX201/K6`0501XJ6P0K6a/06QXJ01/K6`0L71`00P0K6a/00`0J6QX06a/K01/K6`04
01/K6`8071`L00@06a/K01`L700K6a/06a/K0P0L71`201/K6`0301dM7@0L71`071`L00<071`L0P0M
7Ad0100K6a/07AdM01`L700N7Qh201`L70807AdM00@07QhN01dM7@0M7Ad07AdM0P0N7Qh01@0L71`0
7QhN01hN7P0N7Qh07AdM00807QhN00<07alO020P800O7al00`0O7al2020P800701hN7P0P82007alO
024Q8@0P82007alO01hN7P04020P800701lO7`0Q8B408R8R024Q8@0R8R808B4Q020P8003028R8P05
024Q8@0R8R808b<S02<S8`0R8R800`0S8b<02@0T92@08b<S02<S8`0S8b<09BDU02@T900R8R8092@T
02<S8`0202DU9@0602HV9P0T92@092@T02DU9@0V9RH09BDU0`0V9RH00`0U9BD09bLW02LW9`0402LW
9`<0:2PX00@09RHV02LW9`0W9bL0:2PX0P0W9bL202PX:00;02TY:@0W9bL0:2PX02PX:00W9bL0:RXZ
02PX:00W9bL09RHV02PX:00W9bL00P0X:2P202LW9`0302PX:00V9RH09RHV00809RHV00<0:2PX02LW
9`0W9bL00P0V9RH0200U9BD09RHV02DU9@0V9RH09BDU02HV9P0U9BD09RHV0P0U9BD00`0T92@09BDU
02<S8`0202@T900502DU9@0T92@092@T028R8P0S8b<00`0T92@01@0S8b<08B4Q02<S8`0R8R8092@T
00808R8R00T08B4Q028R8P0Q8B40820P024Q8@0R8R808B4Q020P800R8R800P0P82000`0Q8B407alO
01lO7`03024Q8@<0820P00D08B4Q01hN7P0N7Qh07alO020P800301lO7`<07QhN00<07alO01hN7P0N
7Qh00P0M7Ad201hN7PD07AdM00<06a/K01dM7@0M7Ad0100L71`01P0M7Ad071`L01`L700K6a/071`L
01/K6`8071`L00L07AdM01`L700L71`071`L01/K6`0L71`06a/K008071`L00@06a/K01`L700L71`0
71`L0`0K6a/00`0J6QX06a/K01XJ6P0201XJ6P806a/K00@06QXJ01TI6@0I6AT06ATI0`0J6QX00`0L
71`06QXJ01XJ6P0401XJ6P0501TI6@0H61P06ATI01PH600J6QX01P3IfMT100000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI00<06QXJ01PH600I6AT00P0J6QX0100I6AT06QXJ01XJ6P0J6QX2
01TI6@H06QXJ00<06a/K01TI6@0K6a/00P0J6QX0100K6a/06QXJ01TI6@0K6a/301TI6@0401XJ6P0K
6a/06QXJ01/K6`806QXJ00P06a/K01TI6@0K6a/06QXJ01/K6`0L71`06a/K01`L70@06a/K00@06QXJ
01/K6`0K6a/06a/K0P0L71`201/K6`D071`L00`06a/K01`L700N7Qh071`L01/K6`0M7Ad071`L01dM
7@0L71`07AdM01`L700M7Ad201`L70807QhN00T07AdM01hN7P0N7Qh07QhN01lO7`0M7Ad07QhN01lO
7`0N7Qh00P0O7al2020P800501lO7`0N7Qh07alO01lO7`0P82000P0O7al2020P800401lO7`0P8200
820P020P80808B4Q00<08R8R024Q8@0Q8B400P0Q8B42028R8P04024Q8@0R8R808b<S028R8P808b<S
00H092@T02<S8`0S8b<08b<S02HV9P0S8b<302@T900302DU9@0T92@09BDU008092@T00D09BDU02@T
900T92@09RHV02DU9@0302HV9PD09bLW00<09RHV02LW9`0W9bL00`0W9bL202PX:080:BTY00<09bLW
02PX:00X:2P01@0X:2P202TY:@80:2PX00L0:BTY02PX:00X:2P0:2PX02TY:@0W9bL0:2PX0080:BTY
0P0W9bL202PX:0809bLW0P0V9RH402LW9`0502DU9@0W9bL09bLW02LW9`0U9BD00P0V9RH302DU9@05
02HV9P0T92@092@T02DU9@0T92@00P0S8b<01@0T92@08b<S02<S8`0S8b<092@T00808B4Q00D092@T
02<S8`0Q8B408b<S024Q8@03028R8P06020P800R8R808B4Q024Q8@0P82008B4Q0P0P82000`0O7al0
8B4Q020P8003020P800301lO7`0Q8B407alO00<07alO0`0N7Qh01@0O7al07QhN01hN7P0N7Qh07alO
00<07QhN00@07AdM01`L700L71`071`L0P0M7Ad201`L700501/K6`0M7Ad071`L01`L700M7Ad00P0L
71`00`0K6a/071`L01`L700201`L700501/K6`0L71`06a/K01/K6`0L71`00P0K6a/201`L700401/K
6`0J6QX071`L01dM7@<071`L00H06QXJ01/K6`0K6a/06QXJ01/K6`0L71`501XJ6P0601/K6`0J6QX0
6QXJ01/K6`0I6AT06a/K0P0J6QX01`0I6AT06QXJ01TI6@0J6QX06ATI01/K6`0J6QX00P0I6AT60=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT02@0J6QX06ATI01TI6@0I6AT05aLG
01/K6`0J6QX06ATI01XJ6P0201TI6@0301/K6`0J6QX06QXJ00806QXJ0P0K6a/301XJ6P0401TI6@0K
6a/06a/K01/K6`<06QXJ00<06ATI01XJ6P0K6a/00`0J6QX00`0K6a/06QXJ01/K6`0201/K6`0401`L
700J6QX071`L01XJ6P<06a/K00@071`L01/K6`0L71`071`L0P0K6a/201`L700:01dM7@0L71`071`L
01`L700K6a/071`L01/K6`0M7Ad071`L01hN7P<071`L00@07AdM01/K6`0M7Ad071`L0P0N7Qh201dM
7@807QhN00@07AdM01hN7P0O7al07alO1@0N7Qh00`0O7al0820P01lO7`0301lO7`08020P800Q8B40
820P01lO7`0R8R807alO020P800O7al4024Q8@0901lO7`0P82008R8R028R8P0P82008R8R020P800S
8b<08B4Q00808R8R0`0S8b<00`0R8R808b<S02@T900302@T90@09BDU00D092@T02DU9@0V9RH09RHV
02DU9@0302HV9P0:02LW9`0V9RH09bLW02PX:00W9bL09RHV02LW9`0V9RH0:2PX02LW9`80:BTY0P0W
9bL402TY:@D0:2PX00@0:BTY02XZ:P0Y:BT0:RXZ0P0Y:BT202PX:00302TY:@0W9bL0:BTY0080:2PX
00<0:BTY02PX:00Y:BT00`0X:2P0100Y:BT09RHV02PX:00W9bL202PX:0809bLW00l0:2PX02HV9P0X
:2P09RHV02LW9`0X:2P092@T02HV9P0U9BD09RHV02DU9@0V9RH09BDU02HV9P0T92@00P0U9BD00`0T
92@08b<S02@T900302@T900302<S8`0R8R8092@T00<08b<S00<08R8R024Q8@0R8R80100Q8B46020P
800=024Q8@0P8200820P01hN7P0O7al07QhN01lO7`0P82008B4Q020P800O7al07QhN01dM7@0301lO
7`807AdM00<07alO01hN7P0N7Qh00P0M7Ad00`0N7Qh071`L01dM7@0201dM7@0401hN7P0M7Ad071`L
01hN7P<071`L00X07AdM01`L700K6a/06a/K01`L700K6a/071`L01XJ6P0K6a/071`L0P0K6a/01P0M
7Ad071`L01`L700K6a/071`L01/K6`<071`L00<06a/K01`L700J6QX0100J6QX00`0I6AT06QXJ01XJ
6P0301XJ6P0401TI6@0J6QX06QXJ01XJ6P806ATI00H06QXJ01/K6`0I6AT06ATI01XJ6P0I6AT201XJ
6P806ATI00<06QXJ0=WIf@3IfMT0103IfMT100000040fMWI00000`3IfMT000000000000300000080
fMWI0P0000040=WIf@8000001P3IfMT00`000000fMWI0=WIf@030=WIf@0301XJ6P0I6AT06QXJ0080
6ATI0P0J6QX00`0K6a/06QXJ01XJ6P0601XJ6P0301/K6`0J6QX06a/K00D06QXJ00H06a/K01XJ6P0J
6QX06QXJ01TI6@0J6QX301/K6`0301XJ6P0K6a/06a/K00<06a/K00<071`L01/K6`0L71`0100K6a/3
01`L700301/K6`0L71`071`L00<071`L00D06a/K01`L700L71`07AdM01`L700201dM7@0301`L700M
7Ad071`L00<07AdM00@071`L01dM7@0M7Ad07QhN0P0M7Ad01@0O7al07QhN01dM7@0N7Qh07alO00@0
7QhN0P0O7al00`0N7Qh07alO01lO7`0201lO7`0:020P800O7al0820P024Q8@0O7al08B4Q01lO7`0P
82008B4Q01lO7`<08B4Q00<08R8R024Q8@0Q8B400`0R8R83024Q8@808R8R0P0S8b<01@0T92@08R8R
02@T900S8b<09BDU008092@T0P0U9BD01@0T92@08b<S02HV9P0U9BD092@T00@09RHV0`0U9BD01@0V
9RH09bLW02LW9`0W9bL09RHV00809bLW00P0:2PX02LW9`0W9bL0:2PX02TY:@0W9bL0:RXZ02TY:@80
:2PX00<0:RXZ02PX:00X:2P00P0Z:RX302PX:00502`/;00Z:RX0:BTY02XZ:P0X:2P00P0Y:BT01@0X
:2P0:BTY02PX:00Y:BT09RHV00D0:BTY0P0X:2P00`0Y:BT0:2PX02PX:00202LW9`0302PX:00W9bL0
9RHV00809bLW0P0U9BD202LW9`809BDU00D09RHV02@T900T92@092@T02HV9P0302@T90808b<S00<0
9BDU02<S8`0S8b<00P0T92@3028R8P03024Q8@0R8R80820P0080820P0`0R8R84024Q8@@0820P00<0
8B4Q01lO7`0O7al00P0N7Qh401lO7`0301dM7@0N7Qh07alO00807QhN00<07alO01hN7P0M7Ad02`0M
7Ad301`L700401dM7@0L71`071`L01/K6`@071`L00<06QXJ01`L700L71`00P0L71`01@0K6a/071`L
01`L700K6a/06QXJ00D06a/K00@071`L01XJ6P0K6a/06ATI0P0K6a/701XJ6P0501/K6`0I6AT06QXJ
01XJ6P0K6a/0100J6QX00`0I6AT06QXJ01/K6`0301XJ6P0301TI6@3IfMT0fMWI00@0fMWI0@000001
0=WIf@000`3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00@000000=WIf@3IfMT000000P3I
fMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<06a/K01TI6@0K6a/00`0J
6QX01P0I6AT06QXJ01XJ6P0J6QX06ATI01/K6`<06ATI00<06QXJ01`L700J6QX00P0J6QX401/K6`03
01TI6@0J6QX06QXJ00806QXJ00D06ATI01XJ6P0J6QX06ATI01/K6`0401XJ6P<06a/K00<06QXJ01/K
6`0K6a/00P0K6a/401`L700401/K6`0L71`06a/K01`L70806a/K00L06QXJ01`L700L71`07QhN01dM
7@0K6a/07AdM00<071`L00L07AdM01`L700N7Qh07AdM01/K6`0N7Qh071`L00<07AdM100N7Qh201lO
7`0401dM7@0O7al07QhN01hN7P807alO0P0N7Qh00`0O7al0820P020P8002024Q8@03020P800Q8B40
7alO00@0820P0P0Q8B42020P80<08R8R0`0S8b<00`0T92@08b<S028R8P0302<S8`0:02DU9@0T92@0
8b<S02DU9@0S8b<092@T02DU9@0T92@09bLW02DU9@809RHV00/092@T02DU9@0U9BD09bLW02DU9@0V
9RH09bLW02TY:@0W9bL0:2PX02LW9`0202PX:0809bLW0P0X:2P0300Z:RX0:BTY02TY:@0X:2P0:BTY
02PX:00Y:BT09bLW02XZ:P0X:2P0:BTY02/[:`<0:RXZ00<0:b/[02XZ:P0Z:RX00P0Y:BT00`0X:2P0
:BTY02TY:@0302TY:@0302PX:00Y:BT0:RXZ0080:RXZ0`0Y:BT00`0X:2P09bLW02PX:00202PX:003
02TY:@0X:2P0:2PX00<09bLW0`0V9RH0300T92@09bLW02HV9P0V9RH09BDU02HV9P0U9BD09RHV02<S
8`0T92@09BDU02@T90808b<S0P0T92@502<S8`03028R8P0S8b<08b<S00@08B4Q00<08R8R024Q8@0P
82000`0Q8B40100P82007alO01lO7`0P820201lO7`<0820P00<07alO01hN7P0N7Qh0100O7al201hN
7P0301lO7`0N7Qh07QhN00807QhN0P0M7Ad00`0L71`07QhN01dM7@0401dM7@0;01`L700M7Ad07AdM
01`L700M7Ad071`L01lO7`0M7Ad071`L01/K6`0N7Qh00P0M7Ad01@0K6a/071`L01`L700L71`06QXJ
00806a/K00@06QXJ01/K6`0I6AT06QXJ100K6a/0100J6QX06a/K01/K6`0L71`301XJ6P806ATI0P0J
6QX02`0K6a/071`L01/K6`0K6a/06ATI01/K6`0I6AT06QXJ01TI6@0J6QX06ATI00<06QXJ1P3IfMT1
00000040fMWI00030=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT010000000fMWI0=WIf@00
00020=WIf@030000003IfMT0fMWI00<0fMWI0`0000030=WIf@0501TI6@0K6a/06ATI01XJ6P0K6a/0
0P0J6QX00`0K6a/06QXJ01/K6`0201TI6@0301XJ6P0K6a/06QXJ00806a/K00@06QXJ01TI6@0K6a/0
6QXJ0P0K6a/201XJ6P0301/K6`0J6QX06a/K00806QXJ0P0K6a/401XJ6P0501/K6`0J6QX06a/K01/K
6`0L71`00`0K6a/401`L700301/K6`0L71`07AdM00<071`L00@06a/K01`L700K6a/071`L0`0K6a/2
01`L70D07AdM0`0L71`0100N7Qh071`L01dM7@0M7Ad201hN7P0301`L700O7al07alO00807alO00D0
7QhN01dM7@0O7al07alO024Q8@0201hN7P0301lO7`0N7Qh0820P00<0820P00D08B4Q020P800P8200
7alO024Q8@03020P8005024Q8@0P82008B4Q024Q8@0R8R800P0S8b<01@0R8R808b<S028R8P0T92@0
8b<S00<092@T00@08R8R02<S8`0T92@092@T1P0U9BD202HV9P0:02DU9@0V9RH09bLW02PX:00V9RH0
9bLW02HV9P0W9bL09RHV02LW9`80:2PX00<0:RXZ02PX:00X:2P00P0X:2P202TY:@0302XZ:P0Y:BT0
:2PX0080:BTY00`0:2PX02XZ:P0Y:BT0:RXZ02TY:@0Z:RX0:BTY02/[:`0Z:RX0:b/[02TY:@0Z:RX3
02TY:@0402PX:00Y:BT0:b/[02/[:`80:RXZ0`0Y:BT0200Z:RX0:2PX02TY:@0Y:BT0:2PX02TY:@0Z
:RX0:BTY0P0X:2P00`0W9bL0:2PX02LW9`0202LW9`0302HV9P0U9BD09BDU00809BDU00H09RHV02DU
9@0U9BD09BDU02@T900U9BD202@T900602<S8`0U9BD08b<S02@T900S8b<092@T0P0S8b<3028R8P03
024Q8@0S8b<08R8R00<08R8R00<0820P024Q8@0Q8B400P0Q8B40100P82007alO020P800Q8B42020P
800801lO7`0Q8B407alO01lO7`0P82007alO01hN7P0O7al201hN7P0501dM7@0O7al07alO01dM7@0L
71`00P0M7Ad0100N7Qh07AdM01lO7`0N7Qh201dM7@0501hN7P0M7Ad071`L01`L700M7Ad00P0L71`0
0`0M7Ad06a/K01dM7@0601`L70D06a/K00<06QXJ01/K6`0K6a/0100K6a/00`0L71`06QXJ01XJ6P02
01/K6`0301`L700K6a/071`L00<06QXJ00D06a/K01XJ6P0K6a/06ATI01XJ6P0301`L70806a/K00<0
6QXJ01TI6@0J6QX00P0J6QX00`0H61P06QXJ01TI6@040=WIf@<000000@3IfMT000<0fMWI00D00000
0=WIf@3IfMT0fMWI000000020=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT0
0`3IfMT00`000000fMWI0=WIf@030=WIf@806ATI00@06QXJ01TI6@0I6AT06QXJ1@0I6AT401XJ6P08
01/K6`0J6QX06QXJ01XJ6P0I6AT06QXJ01/K6`0I6AT501XJ6P806a/K0P0J6QX0100K6a/06QXJ01XJ
6P0J6QX301/K6`0401`L700J6QX06QXJ01/K6`8071`L0P0K6a/0100L71`07AdM01/K6`0N7Qh201dM
7@<071`L00<06a/K01`L700K6a/0100M7Ad301`L70D07AdM00@071`L01dM7@0M7Ad07AdM100N7Qh0
1`0O7al07QhN01lO7`0N7Qh0820P01lO7`0N7Qh00P0O7al0100N7Qh0820P01lO7`0O7al4020P800D
01lO7`0Q8B40820P020P800R8R808B4Q020P800R8R808B4Q020P800S8b<08B4Q028R8P0Q8B4092@T
028R8P0T92@08b<S02@T900S8b<402@T90809BDU0P0T92@202DU9@0802@T900U9BD09bLW02HV9P0W
9bL09RHV02LW9`0X:2P202LW9`0302PX:00W9bL09bLW00@0:2PX00D0:RXZ02PX:00Y:BT0:BTY02/[
:`0302TY:@0802XZ:P0[:b/0:b/[02TY:@0[:b/0:RXZ02/[:`0Z:RX302/[:`0402`/;00[:b/0:RXZ
02XZ:P80:b/[0`0Z:RX0100/;2`0:RXZ02/[:`0[:b/302TY:@0602XZ:P0Y:BT0:BTY02XZ:P0Y:BT0
:2PX0P0Y:BT202PX:00402TY:@0X:2P09RHV02HV9P@09bLW00<09RHV02DU9@0T92@01@0U9BD302@T
900302DU9@0T92@092@T00808b<S00D092@T02<S8`0T92@08R8R02<S8`02028R8P0302<S8`0R8R80
8R8R00<08R8R00<08B4Q02<S8`0R8R800P0Q8B45020P80807alO00D0820P01lO7`0O7al07alO01hN
7P0201lO7`0301hN7P0O7al07alO00<07QhN00<07AdM01hN7P0L71`00`0M7Ad01P0N7Qh07AdM01dM
7@0L71`07AdM01/K6`807AdM0P0L71`02@0M7Ad06a/K01`L700L71`07AdM01`L700K6a/07QhN01/K
6`0201`L70806a/K00@06ATI01`L700L71`071`L0P0K6a/02@0L71`06a/K01XJ6P0K6a/06QXJ01`L
700J6QX06a/K01XJ6P0301/K6`0301XJ6P0I6AT06a/K00<06a/K00<06QXJ01/K6`0K6a/0100I6AT0
100J6QX06ATI01TI6@0J6QX60=WIf@4000000@3IfMT000<0fMWI00D000000=WIf@3IfMT0fMWI0000
00020=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI
0=WIf@030=WIf@806QXJ00D06ATI01XJ6P0J6QX06QXJ01TI6@0201XJ6P806ATI100J6QX301/K6`80
6QXJ00D06ATI01/K6`0K6a/06QXJ01/K6`0501XJ6P806a/K00@06QXJ01/K6`0K6a/071`L0`0J6QX4
01/K6`0401dM7@0K6a/06a/K01dM7@<071`L0`0K6a/0100L71`06QXJ01/K6`0J6QX201`L70807AdM
00X071`L01hN7P0N7Qh07AdM01hN7P0M7Ad06a/K01hN7P0M7Ad07QhN0P0M7Ad0100N7Qh07AdM01dM
7@0M7Ad301lO7`0501hN7P0P8200820P01lO7`0N7Qh00P0O7al0100P82007alO01lO7`0O7al2020P
8003024Q8@0P8200820P00808B4Q00D0820P024Q8@0O7al08B4Q028R8P04024Q8@808b<S0`0R8R82
02<S8`0902@T900S8b<092@T02@T900U9BD092@T02DU9@0T92@09BDU00809RHV00@09BDU02LW9`0W
9bL09BDU0`0V9RH202LW9`0502PX:00W9bL0:2PX02TY:@0X:2P00P0Z:RX202TY:@0:02XZ:P0Y:BT0
:b/[02XZ:P0[:b/0:RXZ02/[:`0Z:RX0:b/[02XZ:P80;2`/00<0:RXZ02/[:`0[:b/00P0Z:RX202/[
:`0302`/;00];Bd0;2`/00D0:b/[00@0:RXZ02/[:`0[:b/0:RXZ0P0[:b/402XZ:P80:BTY00<0:b/[
02TY:@0X:2P00P0X:2P0100Y:BT0:2PX02TY:@0X:2P202LW9`0502PX:00Y:BT09bLW02HV9P0U9BD0
0P0V9RH502DU9@0602@T900S8b<092@T02@T900S8b<092@T0P0S8b<0100T92@08R8R024Q8@0R8R83
02<S8`<08R8R00D08b<S024Q8@0R8R808B4Q020P8002024Q8@<0820P00<07alO01hN7P0P82000`0O
7al201hN7P0301lO7`0P82007QhN00@07QhN00T071`L01hN7P0M7Ad07QhN01dM7@0L71`07AdM01lO
7`0M7Ad00P0L71`00`0M7Ad071`L01hN7P0601`L700501dM7@0L71`071`L01`L700M7Ad00`0L71`3
01/K6`8071`L0P0K6a/01@0I6AT06a/K01XJ6P0L71`06QXJ00806a/K0P0J6QX0100L71`06QXJ01XJ
6P0K6a/201TI6@806QXJ00P06ATI01`L700J6QX06ATI01/K6`0J6QX06a/K01TI6@806QXJ00@06ATI
01XJ6P0I6AT061PH1P3IfMT100000040fMWI00020=WIf@800000103IfMT2000000@0fMWI0P000006
0=WIf@030000003IfMT0fMWI00<0fMWI0`0J6QX00`0K6a/061PH01XJ6P0301TI6@0401XJ6P0I6AT0
6QXJ01XJ6P<06a/K0P0J6QX01`0K6a/06QXJ01XJ6P0J6QX06a/K01XJ6P0K6a/00P0J6QX00`0K6a/0
6QXJ01XJ6P0201/K6`0601`L700J6QX06QXJ01TI6@0K6a/06QXJ1@0K6a/0100L71`06a/K01/K6`0K
6a/201dM7@0601`L700K6a/06QXJ01`L700J6QX07AdM0P0K6a/201`L70807AdM00@07QhN01dM7@0M
7Ad07QhN0P0M7Ad0100L71`07AdM01dM7@0L71`301dM7@0801hN7P0O7al07alO01dM7@0N7Qh07AdM
01hN7P0M7Ad201lO7`0401hN7P0P82007QhN01hN7P807alO0P0P820201lO7`07020P800Q8B408B4Q
024Q8@0O7al0820P024Q8@04028R8P0302<S8`0R8R808b<S00808b<S0`0T92@00`0U9BD08b<S02<S
8`0302@T900602DU9@0V9RH0:2PX02HV9P0U9BD09bLW0P0V9RH01P0W9bL09RHV02HV9P0X:2P0:BTY
02PX:0809bLW0P0Y:BT00`0X:2P0:BTY02XZ:P0202XZ:P0502TY:@0X:2P0:RXZ02XZ:P0Y:BT01@0[
:b/202XZ:P0602d];@0Z:RX0:RXZ02XZ:P0/;2`0:b/[0`0/;2`00`0[:b/0;2`/02/[:`0202`/;00<
02XZ:P0[:b/0:b/[02/[:`0];Bd0:b/[02XZ:P0/;2`0:RXZ02/[:`0Z:RX0:BTY0`0Z:RX00`0Y:BT0
:2PX02TY:@0202TY:@0302PX:00Y:BT0:2PX0080:2PX100W9bL01`0V9RH09bLW02DU9@0W9bL09BDU
02HV9P0U9BD00P0T92@01@0U9BD092@T02@T900T92@09BDU008092@T00<08b<S028R8P0S8b<00P0S
8b<0200R8R808B4Q028R8P0Q8B408b<S028R8P0S8b<0820P0`0Q8B401`0P82008B4Q028R8P0O7al0
8B4Q020P800Q8B400P0P820201lO7`05020P800N7Qh07alO01hN7P0O7al00`0N7Qh00`0O7al07QhN
01dM7@0601dM7@0301`L700M7Ad07AdM00<07AdM0`0L71`00`0K6a/071`L01`L700201`L700901dM
7@0L71`07AdM01/K6`0M7Ad06a/K01`L700K6a/071`L00@06a/K00<06QXJ01/K6`0J6QX00P0K6a/0
1@0J6QX071`L01XJ6P0K6a/06ATI00806QXJ00H06a/K01XJ6P0J6QX06QXJ01TI6@0J6QX201/K6`80
6QXJ0P0K6a/00`0I6AT06a/K01XJ6P0201XJ6P0301TI6@3IfMT0fMWI00@0fMWI0@0000010=WIf@00
5P3IfMT00`000000fMWI0=WIf@030=WIf@0501XJ6P0I6AT06QXJ01TI6@0K6a/00P0J6QX00`0H61P0
6QXJ01TI6@0201XJ6P806ATI1`0J6QX00`0K6a/06QXJ01/K6`0201XJ6P806a/K0P0J6QX201/K6`07
01TI6@0K6a/06a/K01/K6`0J6QX06a/K01XJ6P0201`L70@06a/K00@071`L01/K6`0L71`06QXJ0P0L
71`01`0M7Ad071`L01/K6`0K6a/071`L01dM7@0L71`00P0M7Ad00`0N7Qh07AdM01dM7@0201dM7@03
01/K6`0L71`07AdM00807AdM00D07QhN01dM7@0M7Ad07AdM01lO7`0201hN7P807alO0P0N7Qh00`0P
82007QhN01lO7`0201lO7`05020P800N7Qh0820P024Q8@0O7al00P0P82001@0Q8B40820P020P800P
82007alO00808R8R0`0Q8B42028R8P0602<S8`0T92@08b<S02<S8`0U9BD092@T100S8b<01@0U9BD0
92@T02DU9@0U9BD09RHV00<09BDU00D09RHV02PX:00V9RH09RHV02PX:00202LW9`0402HV9P0Y:BT0
:2PX02PX:080:BTY00H0:RXZ02PX:00Y:BT0:2PX02XZ:P0/;2`202XZ:P0502/[:`0Z:RX0;2`/02/[
:`0/;2`00P0[:b/202`/;00702d];@0/;2`0:RXZ02h^;P0/;2`0:b/[02`/;00202d];@0>02/[:`0]
;Bd0:RXZ02d];@0/;2`0:b/[02d];@0[:b/0;2`/02d];@0[:b/0;Bd]02`/;00Z:RX202/[:`0502`/
;00Z:RX0:b/[02`/;00Z:RX00`0[:b/01`0Z:RX0:BTY02TY:@0Y:BT0:RXZ02PX:00Y:BT01@0X:2P0
1@0W9bL0:2PX02LW9`0U9BD09RHV00H09BDU00L092@T02DU9@0S8b<09BDU028R8P0S8b<092@T0080
8b<S0P0R8R80100S8b<08R8R028R8P0S8b<2024Q8@0<028R8P0Q8B408B4Q020P800Q8B408R8R01lO
7`0P82007alO020P800Q8B407alO0P0P820201lO7`807QhN00<07AdM01lO7`0M7Ad00`0N7Qh01@0O
7al07QhN01dM7@0O7al07QhN00807AdM00@07QhN01dM7@0M7Ad071`L0P0M7Ad00`0N7Qh071`L01/K
6`0301`L700801/K6`0L71`071`L01`L700M7Ad06a/K01XJ6P0K6a/401`L700401XJ6P0L71`06a/K
01`L70<06a/K0P0J6QX00`0K6a/06QXJ01XJ6P0201/K6`0501XJ6P0L71`06a/K01/K6`0J6QX00`0K
6a/201XJ6P0901/K6`0J6QX06QXJ01XJ6P0I6AT06QXJ01/K6`0I6AT06QXJ00H0fMWI0@0000010=WI
f@005P3IfMT00`000000fMWI0=WIf@030=WIf@0301TI6@0J6QX06ATI00<06ATI1`0J6QX01`0I6AT0
6QXJ01XJ6P0J6QX06a/K01XJ6P0H61P00P0J6QX00`0I6AT06QXJ01XJ6P0301/K6`806QXJ00X06a/K
01XJ6P0J6QX06a/K01`L700J6QX06a/K01XJ6P0K6a/071`L0P0K6a/0300L71`06QXJ01`L700M7Ad0
6a/K01XJ6P0L71`06a/K01`L700K6a/071`L01/K6`D071`L1@0M7Ad0200N7Qh07AdM01dM7@0M7Ad0
7QhN01dM7@0N7Qh071`L100N7Qh01@0M7Ad07alO01hN7P0P82007QhN00807alO00@0820P01hN7P0P
82007alO1@0P8202024Q8@<0820P0P0Q8B42020P8003028R8P0Q8B408R8R00<08R8R00H08b<S02@T
900T92@09BDU02@T900U9BD502@T90<09RHV00H09BDU02LW9`0X:2P09RHV02LW9`0Y:BT202LW9`08
02PX:00W9bL0:BTY02XZ:P0X:2P0:BTY02PX:00W9bL602XZ:P<0:b/[00P0;Rh^02/[:`0/;2`0;Bd]
02h^;P0];Bd0;Rh^02`/;0<0;Rh^0P0];Bd01P0^;Rh0;Bd]02d];@0];Bd0;2`/02l_;`80;Bd]0P0/
;2`302d];@0302/[:`0/;2`0;Bd]0080;2`/00<0;Bd]02`/;00/;2`00P0[:b/00`0/;2`0:b/[02/[
:`0202XZ:P0302TY:@0Z:RX0:BTY0080:2PX00<0:BTY02PX:00W9bL00`0X:2P0100W9bL0:2PX02LW
9`0V9RH202LW9`<09RHV0`0U9BD202@T900302<S8`0T92@092@T00<08b<S100R8R802P0Q8B408b<S
024Q8@0Q8B408b<S020P800Q8B408R8R024Q8@0P8203024Q8@H0820P0P0O7al201hN7P0301dM7@0N
7Qh07alO00807QhN0P0M7Ad00`0L71`07QhN01dM7@0201dM7@0801hN7P0M7Ad071`L01`L700M7Ad0
7QhN01dM7@0L71`201dM7@0501`L700N7Qh07AdM01`L700K6a/00P0L71`01@0M7Ad06a/K01TI6@0L
71`07AdM00<06a/K00P06QXJ01`L700K6a/06ATI01XJ6P0L71`06a/K01`L70@06QXJ100K6a/301XJ
6P0301/K6`0I6AT06QXJ00806QXJ00H061PH01XJ6P0K6a/06ATI01/K6`0I6AT201XJ6PH0fMWI0@00
00010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0501XJ6P0I6AT06ATI01XJ6P0I6AT00`0J
6QX0100K6a/06ATI01PH600I6AT201/K6`806QXJ00D06a/K01XJ6P0J6QX06QXJ01`L700201XJ6P03
01`L700I6AT06QXJ00D06QXJ00D06a/K01XJ6P0L71`06a/K01XJ6P0201/K6`0:01`L700K6a/06a/K
01/K6`0L71`06a/K01`L700J6QX06a/K01`L70@06a/K00L071`L01dM7@0K6a/06a/K01`L700M7Ad0
71`L00807QhN00@07AdM01`L700L71`07AdM0P0L71`201dM7@<07QhN0P0M7Ad01P0N7Qh07alO01hN
7P0M7Ad07alO01hN7P<07alO00D0820P01lO7`0P8200820P024Q8@02020P800301lO7`0R8R80820P
00<0820P00H08B4Q028R8P0Q8B40820P024Q8@0P8202024Q8@0402<S8`0R8R8092@T02<S8`<09BDU
00`09RHV02DU9@0U9BD092@T02DU9@0T92@09BDU02LW9`0U9BD09RHV02LW9`0V9RH402LW9`0402PX
:00Y:BT0:BTY02XZ:P80:BTY00H0:RXZ02/[:`0Y:BT0:RXZ02/[:`0Y:BT202XZ:P0402/[:`0/;2`0
:b/[02/[:`80;2`/00l0;Bd]02`/;00^;Rh0;Rh^02`/;00^;Rh0;2`/02d];@0^;Rh0;2`/02/[:`0_
;bl0;Rh^02d];@0^;Rh00`0];Bd00`0_;bl0;Rh^02h^;P0202h^;P<0;Bd]00<0;2`/02d];@0];Bd0
0P0/;2`00`0[:b/0;2`/02`/;00202`/;0@0:RXZ00@0:BTY02PX:00X:2P0:RXZ0P0Y:BT01P0X:2P0
:RXZ02PX:00X:2P09bLW02TY:@809RHV00D09BDU02HV9P0U9BD09RHV02LW9`0302DU9@0302@T900U
9BD092@T00<092@T1@0S8b<01@0R8R808b<S028R8P0Q8B408R8R00L08B4Q0`0P8202024Q8@05020P
800N7Qh0820P01lO7`0P82000`0N7Qh0100O7al07QhN01hN7P0N7Qh301dM7@0801lO7`0M7Ad07AdM
01hN7P0M7Ad07QhN01/K6`0N7Qh401`L700301/K6`0M7Ad071`L008071`L00@07AdM01`L700L71`0
6a/K0`0L71`0100K6a/07AdM01dM7@0K6a/301`L70806QXJ00<06a/K01XJ6P0K6a/00`0K6a/00`0J
6QX06a/K01/K6`0201XJ6P0701TI6@0K6a/06QXJ01XJ6P0L71`06QXJ01/K6`0201TI6@0901/K6`0J
6QX06ATI01XJ6P0I6AT06QXJ01/K6`0G5aL06ATI00H0fMWI0@0000010=WIf@005P3IfMT00`000000
fMWI0=WIf@030=WIf@0501TI6@0J6QX06QXJ01TI6@0K6a/00P0J6QX01P0I6AT06a/K01XJ6P0K6a/0
6QXJ01/K6`<06QXJ00H06a/K01XJ6P0J6QX06QXJ01/K6`0J6QX201/K6`806QXJ00<06a/K01XJ6P0J
6QX00P0K6a/01P0J6QX06a/K01XJ6P0J6QX06ATI01/K6`806QXJ00L071`L01/K6`0J6QX06a/K01`L
700M7Ad071`L00806a/K00<071`L01/K6`0K6a/00`0L71`0100M7Ad071`L01dM7@0M7Ad301`L7003
01dM7@0L71`071`L00D07AdM00@07QhN01dM7@0N7Qh07AdM0P0O7al0300N7Qh07AdM01dM7@0M7Ad0
7alO01hN7P0P82007alO020P800Q8B40820P01lO7`<0820P00<07alO020P800R8R800`0Q8B40100P
82008B4Q024Q8@0Q8B42028R8P0302<S8`0R8R80820P00808b<S00T08R8R02@T900T92@09BDU02HV
9P0T92@09BDU02<S8`0T92@00`0U9BD00`0V9RH09BDU02LW9`0402LW9`80:2PX00H09bLW02TY:@0Z
:RX0:RXZ02TY:@0Z:RX202TY:@0302XZ:P0[:b/0:RXZ0080:b/[00D0;2`/02d];@0];Bd0;2`/02d]
;@0202h^;P07034a<@0^;Rh0;Bd]02d];@0_;bl0;Rh^030`<00202h^;P80;Bd]0`0_;bl00`0^;Rh0
;bl_02h^;P0202h^;P0602d];@0_;bl0;Rh^02d];@0_;bl0;Rh^0P0];Bd00`0^;Rh0;Bd]02`/;002
02d];@<0;2`/0P0[:b/0200/;2`0:RXZ02XZ:P0Y:BT0:b/[02TY:@0[:b/0:BTY0`0X:2P01@0W9bL0
:BTY02PX:00Y:BT09RHV00<09bLW100V9RH302@T90809BDU0P0T92@202<S8`0802DU9@0S8b<08b<S
02@T900S8b<092@T028R8P0S8b<2028R8P03024Q8@0R8R808B4Q00@0820P00@08B4Q020P800Q8B40
8B4Q0P0P82001P0N7Qh07alO01lO7`0O7al0820P01lO7`D07QhN00@07AdM01hN7P0N7Qh07QhN0`0M
7Ad201`L700301hN7P0L71`071`L00807AdM00D071`L01/K6`0L71`07AdM01`L700201dM7@0601/K
6`0L71`06a/K01`L700K6a/071`L0P0K6a/401`L700301XJ6P0K6a/06a/K00<06a/K00<06QXJ01/K
6`0J6QX01P0J6QX00`0K6a/06ATI01/K6`0401XJ6P<06ATI00<06QXJ01PH600I6AT00P0I6AT60=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0100J6QX06a/K01XJ6P0J6QX201/K
6`806QXJ00<071`L01XJ6P0J6QX0100J6QX0100K6a/071`L01/K6`0L71`:01XJ6P806a/K00@06QXJ
01/K6`0K6a/071`L0`0K6a/0100J6QX071`L01`L700M7Ad201`L70<06a/K100L71`00`0K6a/071`L
01`L700201`L700301/K6`0M7Ad071`L008071`L0`0M7Ad0200L71`07AdM01hN7P0N7Qh07AdM01hN
7P0M7Ad07QhN0`0M7Ad201lO7`0301hN7P0O7al0820P00<07alO0P0P82000`0O7al0820P024Q8@06
020P8003024Q8@0R8R808B4Q00<08R8R00<08B4Q02<S8`0R8R800P0R8R800`0S8b<092@T02<S8`03
02@T900702<S8`0U9BD09BDU02@T900U9BD09RHV02DU9@0202HV9P0302LW9`0V9RH09RHV0080:2PX
0P0W9bL00`0X:2P0:RXZ02TY:@0202XZ:P0502/[:`0Y:BT0:RXZ02TY:@0[:b/00P0Y:BT0300[:b/0
;2`/02/[:`0/;2`0:b/[02h^;P0];Bd0;2`/02l_;`0^;Rh0<30`02h^;P<0;bl_00L0<30`02h^;P0]
;Bd0;bl_030`<00_;bl0<30`00<0;Rh^00<0;bl_02h^;P0_;bl0100^;Rh01`0];Bd0;bl_02h^;P0_
;bl0;Rh^02d];@0^;Rh01@0/;2`01@0];Bd0:b/[02d];@0/;2`0:RXZ0080:b/[00D0:RXZ02TY:@0Y
:BT0:RXZ02/[:`0302TY:@0402PX:00W9bL0:2PX02PX:0<09bLW00@09RHV02LW9`0V9RH09BDU0`0T
92@00`0S8b<09BDU02@T900202@T900402DU9@0T92@08b<S02<S8`<08R8R00<08b<S028R8P0R8R80
100Q8B400`0P82008R8R024Q8@03020P8004024Q8@0P8200820P01hN7P<07alO00<0820P01lO7`0N
7Qh01P0N7Qh201dM7@0301hN7P0M7Ad07AdM00<07AdM00@07QhN01dM7@0M7Ad07AdM0P0L71`00`0M
7Ad071`L01`L700501`L700701dM7@0L71`06a/K01/K6`0L71`06a/K01`L700201/K6`0301`L700K
6a/06a/K00806QXJ00<06ATI01XJ6P0K6a/0100K6a/00`0I6AT06QXJ01/K6`0201XJ6P806a/K0`0J
6QX00`0I6AT06QXJ01TI6@0401XJ6P0301TI6@3IfMT0fMWI00@0fMWI0@0000010=WIf@005P3IfMT0
0`000000fMWI0=WIf@030=WIf@806QXJ00<06ATI01XJ6P0I6AT0100J6QX00`0I6AT06a/K01/K6`05
01XJ6P0501/K6`0I6AT06QXJ01/K6`0J6QX00P0I6AT0100J6QX06a/K01XJ6P0K6a/201XJ6PH06a/K
0P0L71`201/K6`0601XJ6P0K6a/071`L01/K6`0L71`07AdM0P0K6a/01@0L71`06a/K01`L700L71`0
6a/K00D071`L00<06a/K01`L700L71`00P0M7Ad00`0N7Qh07AdM01dM7@0201dM7@0=01hN7P0M7Ad0
7QhN01hN7P0M7Ad07QhN01dM7@0N7Qh07alO01`L700M7Ad07alO01hN7P03020P80807alO0`0P8200
1@0O7al0820P024Q8@0O7al0820P00808B4Q0P0P82001@0R8R808B4Q024Q8@0R8R808B4Q00808R8R
00H08b<S02@T900T92@092@T02<S8`0T92@602DU9@0402@T900W9bL09RHV02PX:0809RHV00<09bLW
02PX:00W9bL00`0Y:BT00`0X:2P0:BTY02TY:@0302XZ:P0402/[:`0/;2`0;2`/02/[:`80;2`/00L0
;Rh^02`/;00];Bd0;Bd]02h^;P0_;bl0<30`0080;bl_00<0;Rh^030`<00_;bl00`0_;bl0100`<300
;bl_034a<@0`<30202l_;`@0<30`00@0;bl_030`<00_;bl0<30`0P0a<C401@0^;Rh0;bl_02h^;P0_
;bl0;Rh^00<0;Bd]0P0/;2`04`0];Bd0;2`/02d];@0];Bd0;2`/02XZ:P0/;2`0:b/[02XZ:P0[:b/0
:BTY02XZ:P0Y:BT0:b/[02TY:@0W9bL0:2PX02LW9`0X:2P00P0W9bL0100V9RH0:2PX02HV9P0W9bL2
02HV9PD09BDU00L092@T02DU9@0U9BD09BDU02@T900S8b<092@T00808R8R00D092@T02<S8`0Q8B40
8R8R02<S8`02024Q8@0401lO7`0Q8B408R8R020P80D08B4Q0P0O7al00`0P82007alO01lO7`0201hN
7P807AdM0P0N7Qh0100M7Ad07alO01dM7@0O7al301hN7P0501`L700M7Ad07AdM01dM7@0L71`00`0M
7Ad701`L700301/K6`0M7Ad071`L00<06a/K00<06QXJ01`L700K6a/00P0J6QX201/K6`806QXJ00H0
6a/K01PH600K6a/06a/K01XJ6P0K6a/301XJ6P0701TI6@0J6QX06a/K01XJ6P0L71`06QXJ01/K6`03
01XJ6P806a/K0P0J6QX0100I6AT06QXJ01TI6@0J6QX60=WIf@4000000@3IfMT001H0fMWI00<00000
0=WIf@3IfMT00`3IfMT401XJ6P0501TI6@0J6QX06a/K01TI6@0K6a/00P0J6QX0300K6a/06ATI01XJ
6P0I6AT06a/K01XJ6P0I6AT071`L01TI6@0J6QX06ATI01/K6`<06QXJ00<06ATI01XJ6P0K6a/01P0K
6a/201XJ6P0401TI6@0K6a/06QXJ01`L70806a/K0P0L71`01P0K6a/07AdM01/K6`0L71`06a/K01XJ
6P8071`L00@07AdM01`L700M7Ad06a/K0P0L71`00`0N7Qh071`L01dM7@0301dM7@0501hN7P0M7Ad0
7AdM01lO7`0N7Qh00P0O7al01@0N7Qh0820P01hN7P0O7al07QhN00807alO00D07QhN01lO7`0O7al0
820P01lO7`04020P8003024Q8@0P8200820P00808B4Q00D0820P028R8P0Q8B408R8R02<S8`03028R
8P0302<S8`0Q8B408R8R008092@T00@09BDU02@T900T92@092@T0`0U9BD01P0T92@09BDU02HV9P0W
9bL09RHV02LW9`809RHV00D09bLW02PX:00X:2P0:BTY02PX:00202TY:@D0:RXZ00D0:b/[02`/;00/
;2`0:b/[02`/;00302d];@80;Rh^0P0];Bd202l_;`08034a<@0_;bl0<30`030`<00a<C40<30`034a
<@0`<302034a<@06038b<P0`<300<30`034a<@0_;bl0<S8b0P0`<3001`0b<S80<30`030`<00b<S80
<30`034a<@0_;bl00P0a<C401P0^;Rh0<30`02l_;`0^;Rh0;Bd]02l_;`80;Bd]00<0;Rh^02d];@0/
;2`00`0];Bd0100[:b/0;Bd]02`/;00[:b/202XZ:P0302TY:@0X:2P0:BTY00<0:BTY00@0:2PX02LW
9`0X:2P09bLW1@0V9RH402DU9@0;02@T900U9BD09BDU02@T900V9RH08b<S02@T900S8b<08R8R02@T
900S8b<00P0R8R801@0Q8B40820P028R8P0S8b<08R8R00808B4Q0P0P82000`0Q8B40820P020P8003
01lO7`<0820P0P0N7Qh00`0P82007alO01`L700201hN7P0301lO7`0M7Ad07AdM00807AdM00@07QhN
01dM7@0M7Ad071`L0P0M7Ad00`0N7Qh07AdM01dM7@0201`L700501dM7@0L71`07AdM01/K6`0M7Ad0
0`0K6a/0100L71`06a/K01/K6`0M7Ad201/K6`0301`L700K6a/06QXJ00806a/K00H06QXJ01dM7@0J
6QX06QXJ01/K6`0J6QX401/K6`0501`L700J6QX06a/K01XJ6P0K6a/00P0J6QX00`0K6a/06QXJ01/K
6`0201XJ6P0301TI6@0J6QX06ATI00<06ATI1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0
fMWI00<0fMWI00<06a/K01TI6@0K6a/00P0J6QX0100I6AT06QXJ01PH600I6AT201XJ6P806ATI0P0J
6QX301/K6`0601TI6@0K6a/06QXJ01/K6`0L71`06a/K0P0J6QX201/K6`0301XJ6P0K6a/06a/K0080
71`L00L06a/K01`L700J6QX071`L01XJ6P0K6a/06QXJ00806a/K00<06QXJ01`L700K6a/00`0K6a/0
100M7Ad071`L01/K6`0K6a/201`L700301/K6`0L71`071`L00D071`L0P0M7Ad00`0L71`07QhN01dM
7@0301dM7@0301hN7P0M7Ad07alO00<07alO00H07QhN020P800N7Qh07QhN020P800O7al2020P8004
01lO7`0P82007alO024Q8@80820P00`08B4Q020P800Q8B408R8R020P800Q8B408R8R02<S8`0Q8B40
8R8R02@T900R8R8202<S8`<092@T00<09RHV02@T900T92@00P0U9BD00`0T92@09RHV02DU9@0402DU
9@0402PX:00W9bL0:2PX02HV9P80:2PX0P0Y:BT01@0Z:RX0:b/[02TY:@0Y:BT0:b/[0080:RXZ00<0
:b/[02`/;00/;2`0100];Bd0100/;2`0;bl_02l_;`0`<30202l_;`0402h^;P0`<300<30`034a<@<0
<30`00T0<S8b034a<@0a<C40<S8b034a<@0`<300<c<c034a<@0b<S800P0`<3003@0b<S80<C4a034a
<@0a<C40<30`034a<@0b<S80<30`034a<@0`<300;bl_030`<00_;bl00P0^;Rh01`0_;bl0;Rh^02h^
;P0];Bd0;Rh^02d];@0^;Rh00P0];Bd302/[:`<0:RXZ00<0:BTY02XZ:P0X:2P01P0X:2P302LW9`<0
9RHV00L09BDU02@T900U9BD092@T02DU9@0T92@09BDU008092@T00H08b<S02@T900S8b<08R8R02<S
8`0R8R8202<S8`808R8R00@08B4Q028R8P0Q8B40820P0P0Q8B40100P82008B4Q020P800P820201lO
7`06020P800O7al07alO020P800N7Qh07alO0P0N7Qh00`0O7al07QhN01hN7P0301hN7P0501dM7@0N
7Qh07alO01dM7@0L71`00`0M7Ad201`L700301dM7@0L71`07AdM008071`L0P0K6a/301`L700401XJ
6P0K6a/071`L01`L70806a/K00@06QXJ01/K6`0K6a/071`L0P0J6QX01`0K6a/06ATI01/K6`0K6a/0
6QXJ01TI6@0K6a/00`0J6QX0100K6a/06QXJ01XJ6P0J6QX301/K6`@06QXJ0`0I6AT00`0J6QX06ATI
01XJ6P060=WIf@4000000@3IfMT001H0fMWI0P0000040=WIf@H06QXJ00<06ATI01XJ6P0K6a/00`0J
6QX00`0I6AT06QXJ01/K6`0201XJ6P806a/K00H06ATI01XJ6P0K6a/06QXJ01/K6`0J6QX201/K6`80
6QXJ00<06a/K01XJ6P0K6a/00P0K6a/02@0M7Ad06a/K01TI6@0L71`06a/K01XJ6P0L71`06a/K01XJ
6P0401`L700601/K6`0M7Ad071`L01XJ6P0L71`07AdM0P0L71`00`0M7Ad071`L01`L700301`L7006
01dM7@0L71`07AdM01hN7P0M7Ad071`L0P0M7Ad201hN7P0301lO7`0N7Qh07AdM00P07alO00<0820P
01lO7`0P82000`0P82002`0O7al08b<S024Q8@0Q8B40820P024Q8@0R8R808B4Q02<S8`0R8R808B4Q
00808R8R00X08B4Q02<S8`0R8R808b<S02@T900R8R808b<S02@T900U9BD092@T0P0U9BD202HV9P05
02DU9@0W9bL0:2PX02LW9`0U9BD00`0W9bL202XZ:P0302PX:00Z:RX0:RXZ0080:b/[00/0:RXZ02/[
:`0Z:RX0;2`/02d];@0/;2`0;Bd]02h^;P0`<300;Rh^034a<@0402l_;`80<30`00<0<C4a038b<P0a
<C400P0b<S802@0`<300<C4a034a<@0a<C40<c<c038b<P0c<c<0<S8b03@d=002034a<@@0<c<c00<0
<S8b034a<@0c<c<00P0b<S80100a<C40<S8b034a<@0`<302034a<@80;Rh^0P0_;bl302h^;P0402d]
;@0_;bl0;2`/02d];@80;2`/0P0[:b/202`/;00502/[:`0Z:RX0:RXZ02TY:@0Z:RX00P0Y:BT202PX
:00402LW9`0V9RH09bLW02LW9`809BDU00<0:2PX02@T900U9BD00`0U9BD00`0T92@09BDU02<S8`04
02@T900302<S8`0T92@08R8R00808R8R00<08B4Q028R8P0Q8B400P0Q8B400`0R8R808B4Q020P8003
020P800401hN7P0O7al0820P01lO7`<0820P00<07alO01hN7P0O7al00P0N7Qh201lO7`0;01hN7P0M
7Ad07alO01hN7P0M7Ad071`L01dM7@0N7Qh07AdM01`L700M7Ad0100L71`00`0M7Ad071`L01`L7004
01`L700601/K6`0L71`07AdM01/K6`0L71`06QXJ100K6a/201XJ6P0601`L700K6a/06a/K01`L700K
6a/06QXJ100K6a/00`0L71`06a/K01/K6`0201/K6`0<01XJ6P0K6a/06QXJ01`L700J6QX06a/K01XJ
6P0H61P06QXJ01TI6@0K6a/06QXJ1@3IfMT200000040fMWI000F0=WIf@030000003IfMT0fMWI00<0
fMWI0P0J6QX01P0I6AT06QXJ01/K6`0I6AT06QXJ01/K6`@06QXJ00D06a/K01XJ6P0J6QX06QXJ01TI
6@0301XJ6P0301/K6`0J6QX06QXJ00<06a/K0`0J6QX201/K6`0501`L700J6QX06a/K01/K6`0L71`0
0`0K6a/0200M7Ad06a/K01/K6`0M7Ad071`L01dM7@0L71`06a/K1P0L71`201dM7@8071`L0P0M7Ad0
1`0L71`07AdM01`L700M7Ad07QhN01dM7@0N7Qh00`0M7Ad00`0O7al07QhN01hN7P0201dM7@@07alO
0P0P82000`0N7Qh07alO01lO7`0201lO7`80820P0P0Q8B44020P80H08B4Q00X08b<S028R8P0S8b<0
8b<S028R8P0S8b<09BDU02@T900S8b<09RHV100U9BD0200V9RH09bLW02LW9`0V9RH09bLW02HV9P0W
9bL0:2PX0P0Z:RX202TY:@0402PX:00Z:RX0:b/[02XZ:P<0:b/[0`0/;2`00`0];Bd0;bl_02h^;P02
02h^;P0702l_;`0`<300;bl_034a<@0`<300<C4a030`<003038b<P0503<c<`0d=3@0<c<c038b<P0a
<C400P0d=3@403<c<`80=3@d00P0<c<c03@d=00d=3@0<c<c038b<P0c<c<0<S8b03<c<`80<S8b00<0
<c<c034a<@0b<S800P0a<C401P0_;bl0<C4a02l_;`0`<300;bl_030`<0<0;bl_00P0;Bd]02l_;`0]
;Bd0;2`/02XZ:P0];Bd0;2`/02/[:`80:RXZ0P0[:b/402TY:@0402PX:00W9bL0:BTY02PX:0809bLW
0P0V9RH00`0W9bL09RHV02DU9@0402DU9@0602@T900U9BD092@T02<S8`0R8R808b<S0P0R8R801@0Q
8B4092@T02<S8`0R8R808b<S00808B4Q00@0820P024Q8@0Q8B408B4Q0P0O7al2020P80807alO00@0
820P01hN7P0P8200820P1P0O7al201dM7@0501lO7`0M7Ad07AdM01dM7@0N7Qh00P0M7Ad201hN7P04
01`L700M7Ad07AdM01dM7@8071`L00<07QhN01`L700L71`01P0L71`301/K6`0401XJ6P0L71`06a/K
01/K6`806QXJ00H071`L01XJ6P0J6QX071`L01/K6`0J6QX501/K6`806QXJ00D06a/K01XJ6P0I6AT0
6QXJ01/K6`0301XJ6P0501TI6@0J6QX06QXJ01PH600J6QX01P3IfMT100000040fMWI000F0=WIf@03
0000003IfMT0fMWI00<0fMWI00<06QXJ01/K6`0I6AT00`0J6QX0100I6AT06QXJ01XJ6P0K6a/201XJ
6P0401/K6`0J6QX06ATI01XJ6P806a/K0`0J6QX01@0K6a/06QXJ01/K6`0K6a/06ATI00806a/K0`0J
6QX01`0K6a/071`L01/K6`0J6QX06a/K01`L700K6a/00P0L71`00`0J6QX07AdM01/K6`0401`L7003
01/K6`0M7Ad071`L008071`L00@06a/K01dM7@0M7Ad07QhN0P0M7Ad01@0K6a/07AdM01dM7@0M7Ad0
71`L00807AdM0P0N7Qh0100M7Ad07alO01hN7P0O7al201hN7P0401lO7`0N7Qh07alO020P80<07alO
00@08B4Q01lO7`0R8R80820P0P0Q8B400`0O7al0820P024Q8@04024Q8@03028R8P0S8b<08R8R00@0
8R8R00@08B4Q02<S8`0S8b<08b<S0P0T92@0100U9BD092@T02@T900U9BD202HV9P0302DU9@0W9bL0
9bLW00809bLW00<09RHV02LW9`0X:2P01P0Y:BT202XZ:P<0;2`/00D0:b/[02`/;00/;2`0;Rh^02l_
;`0202h^;P80;bl_0`0`<300200a<C40<30`034a<@0a<C40<c<c03@d=00a<C40<c<c0P0b<S80100a
<C40=CDe03<c<`0f=SH303@d=0<0<c<c00H0=CDe03<c<`0c<c<0<c<c03@d=00c<c<2038b<P0803<c
<`0b<S80<C4a034a<@0b<S80<C4a038b<P0a<C44030`<0@0;bl_00@0;Rh^02d];@0^;Rh0;bl_100/
;2`0100[:b/0:BTY02`/;00[:b/202XZ:P0502PX:00Y:BT0:2PX02XZ:P0X:2P00P0W9bL02@0X:2P0
9RHV02HV9P0V9RH09bLW02DU9@0T92@09BDU02@T900202<S8`0402@T900S8b<08R8R02<S8`L08R8R
00<08B4Q028R8P0Q8B40100Q8B43020P80L07alO00T07QhN020P800N7Qh07QhN01dM7@0O7al07QhN
01`L700N7Qh00`0M7Ad0100O7al071`L01dM7@0M7Ad301`L700301/K6`0L71`071`L008071`L0P0M
7Ad301`L700701XJ6P0L71`071`L01`L700M7Ad071`L01/K6`0201`L700601/K6`0J6QX06QXJ01/K
6`0J6QX06a/K0P0J6QX301/K6`0301dM7@0N7Qh06a/K00806QXJ0`0K6a/0100J6QX06a/K01/K6`0I
6AT301XJ6P0301TI6@0J6QX06QXJ00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@03
0=WIf@0301XJ6P0I6AT06QXJ00806QXJ00@06a/K01XJ6P0J6QX06QXJ0`0K6a/00`0I6AT06QXJ01TI
6@0301XJ6P0501/K6`0J6QX06a/K01XJ6P0K6a/00P0J6QX00`0K6a/06QXJ01XJ6P0201XJ6PD06a/K
00<071`L01/K6`0K6a/00`0K6a/201`L700601XJ6P0L71`06QXJ01/K6`0L71`07AdM0`0L71`01@0M
7Ad071`L01`L700M7Ad071`L00807AdM0`0L71`201dM7@0701hN7P0M7Ad07AdM01dM7@0L71`07AdM
01lO7`0401hN7P0801lO7`0M7Ad07alO01lO7`0N7Qh0820P01lO7`0P820201lO7`80820P1@0Q8B40
1@0R8R808B4Q024Q8@0Q8B408R8R00<08b<S00H08R8R02@T900S8b<092@T02<S8`0T92@202DU9@80
92@T00<09BDU02LW9`0[:b/00P0V9RH01@0Y:BT0:2PX02LW9`0X:2P09bLW00@0:BTY00D0:RXZ02TY
:@0[:b/0:RXZ02/[:`0202`/;00902d];@0^;Rh0;2`/02l_;`0^;Rh0;bl_02h^;P0_;bl0<30`0080
<C4a00@0<S8b034a<@0b<S80<S8b0`0c<c<01@0d=3@0<c<c03@d=00d=3@0=SHf0080=CDe00L0=SHf
03De=@0d=3@0=cLg03@d=00e=CD0=3@d00@0=CDe00d0<c<c03De=@0d=3@0<S8b03@d=00e=CD0<c<c
038b<P0d=3@0<c<c038b<P0a<C40<S8b0080<30`00L0<S8b034a<@0a<C40<C4a02l_;`0^;Rh0;Bd]
0080;Rh^00D0<30`02l_;`0/;2`0;Bd]02/[:`0202`/;00602/[:`0Y:BT0:RXZ02/[:`0Y:BT0:RXZ
0`0Y:BT202LW9`<09RHV00<09BDU02HV9P0W9bL00P0U9BD0100V9RH092@T02@T900T92@302<S8`<0
8R8R0P0S8b<3028R8P05024Q8@0R8R808B4Q020P800R8R800P0Q8B401@0P82007alO01hN7P0Q8B40
820P00<07alO00D07QhN01lO7`0O7al07AdM01lO7`0201hN7P0301lO7`0L71`07AdM00@07AdM0P0N
7Qh901`L700301/K6`0M7Ad06a/K008071`L00L06a/K01`L700J6QX06a/K01XJ6P0K6a/07AdM0080
6a/K00/071`L01/K6`0J6QX06a/K01XJ6P0K6a/06QXJ01/K6`0J6QX06a/K01dM7@0201`L700501XJ
6P0K6a/06a/K01XJ6P0K6a/00P0J6QX301/K6`0501XJ6P0K6a/06QXJ01XJ6P0I6AT01P3IfMT10000
0040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00<06QXJ01TI6@0J6QX00P0J6QX0100I6AT0
6QXJ01XJ6P0I6AT201XJ6P0501TI6@0K6a/06QXJ01XJ6P0I6AT00P0J6QX201/K6`@06QXJ00@071`L
01XJ6P0J6QX06QXJ0`0K6a/0100J6QX06a/K01/K6`0K6a/201XJ6P0301/K6`0J6QX06a/K00806a/K
00<07AdM01`L700K6a/00`0L71`02@0M7Ad06a/K01`L700M7Ad071`L01dM7@0L71`07AdM01`L7002
01dM7@0501hN7P0L71`07AdM01dM7@0N7Qh00P0M7Ad501hN7P0401lO7`0N7Qh07AdM020P80<07QhN
0P0P820401lO7`05024Q8@0P8200820P01lO7`0P82000P0Q8B42020P8003028R8P0S8b<08R8R0080
8B4Q00@08b<S028R8P0S8b<08R8R0`0S8b<01P0U9BD092@T02DU9@0U9BD09RHV02DU9@<09RHV0P0W
9bL202PX:00302TY:@0X:2P0:BTY0080:BTY0`0Z:RX202/[:`80;2`/00@0:RXZ02d];@0^;Rh0;Bd]
0`0_;bl01`0`<300<C4a030`<00a<C40<30`03<c<`0b<S800P0c<c<01P0b<S80=3@d03<c<`0a<C40
=SHf03@d=0<0=CDe00@0=SHf03De=@0e=CD0<c<c0`0f=SH01P0h>3P0=cLg03Hf=P0f=SH0=CDe03Hf
=P80=CDe00<0=SHf03@d=00d=3@00P0d=3@203<c<`0B038b<P0a<C40<c<c03<c<`0a<C40<30`038b
<P0`<300<C4a030`<00_;bl0;Rh^02d];@0^;Rh0;bl_02h^;P0];Bd0;2`/0P0[:b/0300/;2`0:b/[
02TY:@0[:b/0:RXZ02PX:00Z:RX0:BTY02LW9`0Y:BT09bLW02PX:0809bLW00<0:2PX02LW9`0V9RH0
0P0V9RH202DU9@D092@T00<08b<S028R8P0R8R800`0R8R801P0S8b<08R8R02@T900R8R80820P028R
8P808B4Q00<0820P024Q8@0Q8B400P0P82002@0Q8B40820P024Q8@0O7al0820P01lO7`0N7Qh07AdM
01lO7`0301dM7@@07QhN0P0M7Ad00`0O7al07AdM01`L700201dM7@<071`L00<06a/K01`L700M7Ad0
0P0L71`201/K6`D071`L00D06a/K01dM7@0L71`07AdM01/K6`0201`L70806a/K0P0J6QX301/K6`03
01`L700J6QX07AdM008071`L0P0K6a/201XJ6P0401`L700J6QX06QXJ01TI6@@06QXJ00<06ATI01XJ
6P0J6QX01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00@06QXJ01TI6@0J
6QX06ATI1@0J6QX00`0I6AT06QXJ01XJ6P0401XJ6P806a/K00@071`L01/K6`0K6a/06ATI0P0J6QX2
01/K6`806QXJ00<071`L01XJ6P0J6QX00P0K6a/00`0L71`06a/K01/K6`0201XJ6P806a/K00H071`L
01/K6`0K6a/06a/K01`L700J6QX301`L70807AdM00P06a/K01dM7@0L71`071`L01hN7P0M7Ad071`L
01hN7P807AdM00@071`L01dM7@0N7Qh07AdM0P0N7Qh00`0M7Ad07alO020P800601hN7P<07alO00<0
820P01lO7`0O7al00P0P82000`0O7al0820P020P8004020P8004024Q8@0R8R808R8R024Q8@<08R8R
0P0S8b<0200T92@08R8R02@T900T92@08b<S02HV9P0T92@09BDU0P0T92@01P0U9BD09RHV02HV9P0X
:2P09bLW02PX:080:BTY00<0:2PX02TY:@0Z:RX0100Z:RX302/[:`0602`/;00^;Rh0;Rh^02l_;`0]
;Bd0;Rh^0P0_;bl2030`<0@0<S8b00@0=3@d038b<P0d=3@0=CDe0P0d=3@01@0e=CD0=3@d03Hf=P0f
=SH0=CDe00<0=SHf00D0=cLg03Hf=P0h>3P0=cLg03De=@0203Hf=P80=cLg0P0f=SH0100g=cL0>3Ph
03De=@0g=cL203Hf=P0303@d=00e=CD0=3@d00<0=3@d00@0<c<c038b<P0b<S80<c<c0P0b<S82034a
<@05030`<00a<C40;Rh^030`<00_;bl00P0^;Rh02P0];Bd0;2`/02`/;00[:b/0;2`/02/[:`0Z:RX0
:b/[02XZ:P0Y:BT302PX:00502TY:@0X:2P0:2PX02LW9`0Y:BT00P0V9RH302DU9@<092@T00@09BDU
02<S8`0T92@08R8R0P0S8b<0100R8R8092@T02<S8`0Q8B42028R8P<08B4Q0P0P8202024Q8@0601lO
7`0P82007alO01hN7P0O7al07QhN0P0O7al00`0N7Qh07alO01hN7P0701hN7P0701lO7`0N7Qh07QhN
01dM7@0L71`07AdM01`L700301dM7@0401`L700K6a/07AdM01hN7P<07AdM00<071`L01dM7@0M7Ad0
0P0L71`02P0M7Ad071`L01/K6`0K6a/06QXJ01/K6`0L71`06a/K01`L700K6a/301XJ6P0601/K6`0J
6QX06QXJ01XJ6P0K6a/06QXJ0P0K6a/0100J6QX06a/K01XJ6P0I6AT301XJ6P0301`L700I6AT06QXJ
00806QXJ0P0I6AT60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT00`0K6a/0
6QXJ01TI6@0501XJ6P806a/K0`0J6QX201/K6`0801TI6@0J6QX06a/K01XJ6P0K6a/06QXJ01`L700K
6a/501XJ6P0501/K6`0J6QX06a/K01XJ6P0K6a/00P0L71`201/K6`0401`L700M7Ad06a/K01XJ6PH0
71`L00H06a/K01`L700K6a/07AdM01/K6`0M7Ad201`L700301dM7@0L71`07AdM00807AdM0P0N7Qh4
01dM7@<07QhN0P0M7Ad01P0N7Qh07alO01hN7P0M7Ad07alO01hN7P<07alO00H0820P01lO7`0P8200
820P024Q8@0P8202024Q8@0:020P800Q8B408B4Q028R8P0Q8B408b<S028R8P0S8b<08R8R02@T9080
8b<S00T08R8R02<S8`0T92@092@T02HV9P0U9BD08b<S02DU9@0V9RH00P0U9BD202HV9P0602PX:00W
9bL09bLW02PX:00Y:BT0:RXZ0P0Y:BT00`0Z:RX0:b/[02/[:`0202/[:`0302d];@0/;2`0;Bd]0080
;Rh^00L0;bl_02d];@0_;bl0<30`034a<@0`<300<C4a00<0<c<c0P0d=3@01@0e=CD0=3@d03Hf=P0e
=CD0=cLg0080=SHf00@0=cLg03Ti>@0g=cL0=cLg0P0h>3P01P0i>CT0>3Ph03Ti>@0g=cL0>3Ph03Lg
=`<0>3Ph00@0=cLg03Ti>@0h>3P0>CTi0`0g=cL00`0h>3P0=cLg03Lg=`0203Hf=P0503De=@0d=3@0
=CDe03@d=00e=CD00P0b<S800`0c<c<0<S8b030`<002034a<@07030`<00a<C40;bl_02h^;P0];Bd0
;Rh^02d];@0202`/;00302/[:`0/;2`0:b/[0080:RXZ00<0:b/[02TY:@0X:2P00P0Y:BT01@0W9bL0
:2PX02LW9`0V9RH0:2PX00809bLW00L09RHV02DU9@0T92@09BDU02HV9P0T92@08b<S008092@T00H0
8b<S02@T900S8b<08b<S028R8P0S8b<4028R8P<08B4Q1`0P82000`0O7al08B4Q020P800401lO7`03
01hN7P0O7al07QhN00H07QhN0P0M7Ad201`L700301dM7@0K6a/07AdM00H07AdM0`0K6a/00`0L71`0
6a/K01/K6`0301/K6`8071`L00@06a/K01`L700M7Ad071`L0P0K6a/01@0J6QX06a/K01/K6`0J6QX0
6a/K00@06QXJ00D06a/K01XJ6P0I6AT06a/K01TI6@0201/K6`D06QXJ00<06a/K01XJ6P0J6QX01P3I
fMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0P0J6QX01@0I6AT06QXJ01XJ6P0I
6AT06QXJ00806ATI0`0J6QX01P0K6a/06QXJ01/K6`0J6QX06a/K01XJ6P<06a/K1@0J6QX201/K6`07
01XJ6P0K6a/06a/K01XJ6P0I6AT07AdM01/K6`0201`L70@06a/K00@06QXJ01/K6`0K6a/06a/K100L
71`201/K6`0301dM7@0L71`07AdM00807AdM00P071`L01dM7@0L71`071`L01hN7P0L71`07AdM01hN
7P<07AdM00<07QhN01dM7@0O7al00`0O7al02P0N7Qh07alO01lO7`0O7al07QhN020P800O7al0820P
01lO7`0P8202024Q8@0401lO7`0Q8B40820P020P80808R8R00D08B4Q020P800R8R808B4Q02<S8`02
02@T900502<S8`0R8R808R8R02<S8`0T92@00P0U9BD00`0V9RH092@T02DU9@0302@T90809RHV0P0X
:2P502TY:@0402XZ:P0X:2P0:RXZ02XZ:P<0;2`/00P0:b/[02d];@0^;Rh0<30`02l_;`0^;Rh0;bl_
034a<@80<30`00@0<S8b03<c<`0b<S80=CDe0`0d=3@203De=@0503Ti>@0g=cL0>3Ph03Hf=P0i>CT0
0P0g=cL0100h>3P0>SXj03Ti>@0g=cL203Ph>00603/k>`0i>CT0>CTi03/k>`0i>CT0>3Ph100i>CT0
1@0h>3P0=cLg03Lg=`0g=cL0>3Ph00@0=SHf00D0=3@d03Lg=`0f=SH0<c<c03@d=00303<c<`07038b
<P0a<C40<S8b030`<00_;bl0;Rh^02l_;`0202h^;P80;Bd]00L0;Rh^02/[:`0[:b/0;2`/02XZ:P0Y
:BT0:b/[00D0:BTY0P0X:2P0100V9RH09bLW02LW9`0W9bL402DU9@0702@T900S8b<08b<S02DU9@0S
8b<08R8R02@T900302<S8`<08R8R00H08B4Q028R8P0P82008R8R020P800Q8B44020P800801lO7`0P
82007alO01lO7`0P82007alO01hN7P0P820201lO7`807QhN00<07alO01hN7P0M7Ad00P0N7Qh01@0L
71`07AdM01`L700M7Ad071`L00807AdM00<07alO01/K6`0L71`00P0M7Ad01`0K6a/071`L01/K6`0L
71`07AdM01/K6`0L71`01`0K6a/0100J6QX06a/K01XJ6P0L71`301XJ6P806a/K00@06QXJ01/K6`0J
6QX06a/K100J6QX0100K6a/06QXJ01/K6`0J6QX201/K6`0601XJ6P0I6AT06ATI01XJ6P0I6AT06QXJ
1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0P0J6QX00`0I6AT06QXJ01XJ
6P0201XJ6P0501TI6@0J6QX06ATI01TI6@0K6a/00`0J6QX201/K6`806QXJ0P0K6a/301XJ6P806a/K
00<06QXJ01/K6`0J6QX00P0J6QX0100I6AT071`L01TI6@0M7Ad201XJ6P0501/K6`0J6QX071`L01/K
6`0L71`00P0K6a/601`L70807AdM1@0L71`301dM7@0601`L700M7Ad07AdM01hN7P0L71`07QhN0P0O
7al201hN7P0?01lO7`0N7Qh07alO01lO7`0N7Qh07alO020P800O7al07QhN01lO7`0P82007QhN020P
800Q8B40820P00808B4Q00<0820P024Q8@0Q8B400P0Q8B401@0R8R808b<S028R8P0S8b<08R8R00<0
8b<S1@0T92@202DU9@0;02HV9P0U9BD09BDU02DU9@0W9bL09RHV02LW9`0X:2P0:b/[02XZ:P0X:2P0
0`0Z:RX302/[:`0402h^;P0/;2`0;Bd]02d];@80;Rh^00H0;bl_030`<00`<300<30`038b<P0a<C42
038b<P80=3@d00L0=SHf03De=@0f=SH0=SHf03De=@0h>3P0=cLg0080>CTi0P0h>3P02@0j>SX0>c/k
03/k>`0j>SX0?3`l03Xj>P0l?3`0>c/k03Xj>P0503/k>`0303Xj>P0k>c/0>CTi00<0>SXj0`0i>CT3
03Lg=`0303De=@0g=cL0=SHf0080=3@d00D0=CDe038b<P0c<c<0=3@d038b<P02034a<@80<30`0140
<C4a030`<00_;bl0;bl_02h^;P0];Bd0;2`/02d];@0/;2`0;Bd]02/[:`0/;2`0:b/[02XZ:P0X:2P0
:BTY02XZ:P0202PX:0<09bLW0P0V9RH602DU9@0402@T900S8b<09BDU02<S8`8092@T0P0R8R801@0S
8b<08B4Q028R8P0R8R808B4Q0080820P00<08R8R024Q8@0O7al00P0P82001P0O7al0820P020P800Q
8B407alO020P80807alO00<0820P01lO7`0N7Qh01`0N7Qh201dM7@807QhN00<07AdM01`L700L71`0
0P0L71`0100M7Ad071`L01dM7@0K6a/201dM7@0301/K6`0M7Ad06a/K00D071`L0P0K6a/00`0L71`0
6a/K01XJ6P0201`L700301/K6`0L71`06QXJ00806a/K00D06QXJ01`L700K6a/06ATI01/K6`0401XJ
6P0601/K6`0J6QX06ATI01/K6`0J6QX06a/K0P0J6QX301TI6@H0fMWI0@0000010=WIf@005P3IfMT0
0`000000fMWI0=WIf@030=WIf@0301XJ6P0I6AT06ATI00<06ATI2P0J6QX201/K6`806QXJ0`0K6a/0
0`0J6QX06a/K01/K6`0301/K6`0401dM7@0L71`06a/K01/K6`806QXJ0P0K6a/00`0I6AT071`L01`L
700501`L70806a/K0`0L71`01@0M7Ad071`L01hN7P0L71`06a/K00L07AdM00@07alO01dM7@0O7al0
7QhN0P0M7Ad0100O7al07QhN01hN7P0P820201hN7P0601lO7`0P82007QhN01lO7`0P82007QhN0P0P
8204024Q8@06020P800Q8B408B4Q028R8P0P82008b<S0P0Q8B42028R8P0302<S8`0R8R808R8R0080
8b<S00@092@T02DU9@0S8b<092@T0`0U9BD402HV9P80:2PX100Y:BT302XZ:P0702`/;00];Bd0;2`/
02d];@0/;2`0;Bd]02`/;00202l_;`80<30`0P0a<C43038b<P0403@d=00e=CD0=CDe03Lg=`80=SHf
00<0=CDe03Ph>00g=cL00`0j>SX01P0k>c/0>SXj03Xj>P0l?3`0>c/k03`l?080?Cdm0P0n?Sh01`0k
>c/0?Cdm03`l?00m?Cd0?3`l03dm?@0l?3`00P0m?Cd00`0k>c/0>SXj03/k>`0303Xj>P0303Ti>@0h
>3P0>CTi0080>3Ph100f=SH203De=@<0<c<c0`0b<S82034a<@80<30`00@0;bl_02h^;P0];Bd0;Bd]
1P0/;2`0100Y:BT0:RXZ02TY:@0Y:BT302PX:00502LW9`0V9RH09bLW02PX:00W9bL00P0V9RH202@T
90<09BDU00<092@T02<S8`0S8b<00P0S8b<0100R8R808B4Q028R8P0S8b<2020P8006024Q8@0R8R80
8R8R028R8P0Q8B40820P0P0O7al02`0Q8B407alO020P800O7al07QhN01lO7`0N7Qh0820P01hN7P0O
7al0820P00D07QhN00L07AdM01hN7P0K6a/07QhN01dM7@0N7Qh07AdM008071`L0P0M7Ad301`L7004
01dM7@0K6a/071`L01`L70806a/K100L71`301XJ6P0301/K6`0J6QX06QXJ00806a/K0P0J6QX00`0I
6AT071`L01/K6`0201XJ6P0301`L700J6QX06a/K00806QXJ100K6a/00`0I6AT06QXJ01XJ6P0401TI
6@H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0301XJ6P0H61P06ATI00<0
6QXJ00P06ATI01XJ6P0J6QX06a/K01XJ6P0K6a/06QXJ01/K6`<06QXJ00<06a/K01XJ6P0J6QX0100K
6a/01P0J6QX06a/K01XJ6P0J6QX06a/K01XJ6P806a/K00@06ATI01/K6`0L71`06QXJ0P0L71`0200K
6a/071`L01`L700K6a/071`L01/K6`0L71`06QXJ100L71`01@0K6a/07AdM01`L700K6a/071`L0080
7AdM00H071`L01dM7@0N7Qh07QhN01`L700M7Ad201hN7P0701dM7@0N7Qh07QhN01lO7`0N7Qh07alO
01hN7P0301lO7`03020P800O7al07QhN0080820P00D07alO024Q8@0O7al08B4Q020P8002024Q8@03
020P800R8R808R8R00808R8R00@08b<S028R8P0S8b<08R8R0`0S8b<01P0T92@08b<S02DU9@0T92@0
9BDU02@T90@09RHV0P0W9bL00`0Y:BT0:2PX02LW9`0202PX:00302XZ:P0X:2P0:b/[0080:RXZ0`0]
;Bd00`0/;2`0;Rh^02d];@0202l_;`06030`<00_;bl0<30`030`<00b<S80<c<c0P0d=3@01P0c<c<0
=CDe03Hf=P0f=SH0=CDe03Lg=`80>3Ph0P0j>SX01P0k>c/0?3`l03`l?00i>CT0>c/k03`l?0<0?Cdm
0P0n?Sh00`0o?cl0?Cdm03hn?P0203hn?P<0?Cdm00<0?Shn03dm?@0l?3`00P0l?3`00`0m?Cd0>c/k
03Xj>P0203Xj>P0603Ph>00i>CT0>3Ph03Ph>00f=SH0>3Ph0P0f=SH01`0e=CD0=3@d03<c<`0c<c<0
<S8b03<c<`0d=3@00`0`<3000`0_;bl0;Rh^02d];@0202d];@0902`/;00[:b/0;2`/02d];@0/;2`0
:RXZ02TY:@0Z:RX0:BTY00D0:2PX00D09bLW02HV9P0V9RH09BDU02LW9`0202DU9@@092@T00<08b<S
02DU9@0T92@00P0R8R801@0S8b<08R8R028R8P0Q8B40820P00808B4Q0P0P82000`0O7al08B4Q020P
8002020P800:01hN7P0P82007alO01lO7`0N7Qh0820P01dM7@0N7Qh07AdM01hN7P807alO0P0N7Qh2
01lO7`0401hN7P0M7Ad07AdM01dM7@8071`L00@07QhN01dM7@0L71`071`L0P0M7Ad201`L700301/K
6`0L71`07AdM008071`L00<06a/K01dM7@0L71`0100K6a/00`0L71`06QXJ01/K6`0201XJ6PD06a/K
0P0J6QX01P0K6a/06ATI01/K6`0J6QX06a/K01TI6@806QXJ00@06a/K01TI6@0J6QX06QXJ0P0I6AT0
0`0J6QX06ATI01XJ6P060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT00`0K
6a/06ATI01XJ6P0201TI6@0301XJ6P0I6AT06QXJ00806QXJ00<06ATI01XJ6P0K6a/00P0J6QX301/K
6`D06QXJ00<06a/K01XJ6P0J6QX00`0K6a/201XJ6P0801/K6`0L71`06a/K01`L700K6a/071`L01/K
6`0L71`301/K6`0601XJ6P0L71`071`L01`L700K6a/071`L0`0M7Ad00`0L71`07QhN01dM7@0201dM
7@0401lO7`0M7Ad07QhN01hN7P8071`L0P0N7Qh00`0M7Ad07QhN01hN7P0501hN7P0301lO7`0N7Qh0
7QhN00807alO00L0820P024Q8@0O7al08B4Q020P800O7al0820P00<08B4Q00<07alO024Q8@0Q8B40
0`0R8R800`0T92@08R8R02<S8`0202<S8`0302@T900S8b<092@T00<09BDU00H09RHV02@T900U9BD0
:2PX02HV9P0Y:BT202PX:00302LW9`0X:2P0:RXZ0080:BTY01H0:RXZ02TY:@0[:b/0:RXZ02d];@0[
:b/0;Bd]02h^;P0];Bd0;bl_030`<00^;Rh0;bl_030`<00b<S80<C4a038b<P0c<c<0=CDe03@d=00e
=CD0=SHf0P0h>3P0100g=cL0>3Ph03Ti>@0i>CT303/k>`0403dm?@0k>c/0?clo03dm?@80?clo00L0
?Shn0410@010@400@D510410@011@D40@T920080@D5100P0?Shn03lo?`0n?Sh0?clo0410@00n?Sh0
?3`l03dm?@80?3`l00<0?Cdm03/k>`0l?3`00P0k>c/203Ti>@0703Xj>P0i>CT0=cLg03Ph>00f=SH0
=CDe03Hf=P0203@d=00303De=@0c<c<0<c<c0080<S8b0`0`<3001@0_;bl0;Rh^02h^;P0];Bd0;Rh^
0080:b/[00P0:RXZ02TY:@0Y:BT0:RXZ02PX:00Y:BT0:2PX02TY:@809bLW00@0:BTY02HV9P0V9RH0
9BDU0`0V9RH00`0T92@09BDU02<S8`0202<S8`0402@T900S8b<08b<S02@T90808R8R00L08B4Q02<S
8`0Q8B408R8R024Q8@0R8R80820P00@08B4Q0P0P82001@0O7al07QhN01lO7`0O7al07QhN00<07alO
00<0820P01lO7`0O7al00P0N7Qh0100O7al07AdM01hN7P0O7al301dM7@8071`L0P0M7Ad02@0L71`0
7AdM01`L700M7Ad06QXJ01`L700M7Ad071`L01/K6`0201`L700601/K6`0M7Ad06QXJ01`L700J6QX0
71`L0P0K6a/00`0J6QX071`L01/K6`0301`L700301/K6`0J6QX06QXJ00806a/K00D06ATI01XJ6P0J
6QX06QXJ01/K6`0301XJ6P0301TI6@0J6QX06ATI00806QXJ0P0I6AT60=WIf@4000000@3IfMT001H0
fMWI0P0000040=WIf@<06QXJ0P0I6AT301XJ6P0301TI6@0K6a/06QXJ00@06QXJ00<06ATI01XJ6P0K
6a/00`0J6QX0100K6a/071`L01/K6`0J6QX201/K6`0601`L700M7Ad06a/K01/K6`0J6QX071`L0`0K
6a/201`L700401/K6`0L71`071`L01`L70806a/K00<071`L01/K6`0K6a/01@0L71`0100M7Ad071`L
01dM7@0L71`301dM7@<07QhN0P0M7Ad01@0N7Qh071`L01dM7@0N7Qh07AdM00807alO0P0P820201lO
7`03020P800O7al07alO00807alO0`0P82001P0N7Qh0820P024Q8@0Q8B408b<S028R8P808B4Q00D0
8b<S028R8P0P820092@T02<S8`02028R8P0402<S8`0T92@09BDU02@T90809BDU00<092@T02DU9@0V
9RH00`0V9RH01P0X:2P09bLW02LW9`0Y:BT0:2PX02TY:@<0:b/[00@0;2`/02XZ:P0/;2`0;Bd]0`0^
;Rh202l_;`04030`<00a<C40<C4a034a<@80<c<c00h0=3@d03De=@0f=SH0>3Ph03De=@0f=SH0>3Ph
03Xj>P0i>CT0>3Ph03Xj>P0l?3`0>c/k03dm?@80?3`l00D0?clo03dm?@0n?Sh0@41003lo?`020451
@@060492@P11@D40@T920451@@13@d<0@4101011@D400`12@T80@41003hn?P0303hn?P0303dm?@0k
>c/0>c/k0080?3`l0P0i>CT203Ph>080=cLg0P0f=SH0100e=CD0=SHf03<c<`0d=3@3038b<P0403<c
<`0a<C40<30`02l_;`80;Rh^00L0;Bd]02l_;`0[:b/0:b/[02`/;00[:b/0:RXZ0080:b/[0P0Y:BT3
02PX:00302LW9`0V9RH09RHV00<09RHV00D09BDU02HV9P0T92@09BDU02HV9P0202@T900402<S8`0R
8R808b<S028R8P808b<S00<08R8R024Q8@0R8R800`0P82001@0Q8B407alO01lO7`0Q8B40820P0080
7alO00D0820P01lO7`0O7al07QhN020P800201lO7`0301hN7P0O7al07QhN00<07alO0P0M7Ad00`0O
7al07AdM01dM7@0401dM7@X071`L00@07AdM01XJ6P0L71`071`L0P0K6a/01@0L71`06a/K01/K6`0J
6QX071`L00806a/K00@06ATI01XJ6P0K6a/06QXJ0P0K6a/00`0I6AT06QXJ01XJ6P0201XJ6P0901/K
6`0J6QX06QXJ01TI6@0K6a/06ATI01/K6`0J6QX06ATI00806QXJ0P0I6AT50=WIf@8000000@3IfMT0
01H0fMWI00<000000=WIf@3IfMT00`3IfMT501XJ6P0501/K6`0I6AT06QXJ01XJ6P0K6a/01@0J6QX2
01TI6@@06a/K0P0J6QX0100K6a/06QXJ01XJ6P0J6QX301/K6`806QXJ00L06a/K01XJ6P0J6QX071`L
01/K6`0L71`06a/K008071`L0P0K6a/201`L700301/K6`0L71`071`L00<07AdM00@071`L01dM7@0L
71`07QhN0`0M7Ad0100N7Qh07AdM01hN7P0N7Qh301dM7@D07alO00@07QhN01lO7`0P82007QhN0P0O
7al01@0P82007alO01lO7`0P82008B4Q00807alO00H08R8R02<S8`0R8R808B4Q02<S8`0Q8B42028R
8P0302<S8`0R8R808R8R00808b<S00D092@T028R8P0U9BD08b<S02DU9@0202HV9P809bLW00@09RHV
02DU9@0V9RH09RHV0P0W9bL0100Z:RX09bLW02TY:@0X:2P202/[:`80;2`/00@0;Bd]02`/;00];Bd0
;Bd]0P0^;Rh202l_;`04034a<@0`<300<30`038b<P<0<c<c0140=SHf03De=@0e=CD0=SHf03Lg=`0h
>3P0=cLg03Xj>P0k>c/0>CTi03/k>`0m?Cd0?3`l03hn?P0m?Cd0?Shn0410@0020451@@0>0410@013
@d<0@d=304=3@`14A4@0ADE504=3@`14A4@0ADE504A4A015ADD0@d=30451@@14A4@30451@@<0@410
00P0?clo0410@00n?Sh0?Shn03dm?@0j>SX0?3`l03/k>`<0>CTi00L0>3Ph03Lg=`0f=SH0=cLg03De
=@0f=SH0=CDe00<0<c<c00<0<C4a03<c<`0a<C400P0`<30202h^;P0302d];@0^;Rh0;Bd]0080;2`/
0P0Z:RX00`0Y:BT0:RXZ02PX:00202PX:00402LW9`0X:2P09bLW02PX:0809RHV0P0U9BD602@T90<0
8b<S0P0R8R80100S8b<08R8R024Q8@0Q8B42028R8PD08B4Q0P0P82000`0Q8B407alO01lO7`0201lO
7`08020P800O7al07QhN01lO7`0M7Ad07alO01hN7P0M7Ad201hN7P807AdM00<07QhN01dM7@0M7Ad0
1@0M7Ad301`L700401/K6`0M7Ad071`L01/K6`807AdM0`0L71`01@0K6a/071`L01TI6@0K6a/07AdM
00806a/K0P0J6QX00`0L71`06a/K01/K6`0201XJ6P0301/K6`0L71`06QXJ00<06a/K00<06QXJ01/K
6`0I6AT00P0J6QX201TI6@0501XJ6P0I6AT06ATI01TI6@0J6QX01P3IfMT100000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI00D06QXJ01/K6`0K6a/06QXJ01TI6@0201XJ6P806a/K00D06QXJ
01TI6@0K6a/06a/K01TI6@0:01XJ6P0501`L700K6a/06a/K01/K6`0J6QX0100K6a/01@0L71`06a/K
01/K6`0K6a/07AdM00<071`L00<06a/K01`L700L71`00`0L71`0100K6a/071`L01/K6`0M7Ad401`L
70<07AdM00H071`L01hN7P0N7Qh07AdM01hN7P0P820201hN7P0301lO7`0N7Qh07alO00@07alO0P0N
7Qh00`0P82007alO01lO7`02020P80807alO0P0P82000`0Q8B40820P028R8P03024Q8@@08R8R00L0
8b<S02@T900T92@08R8R02@T900U9BD09RHV00809BDU00P0:2PX02HV9P0W9bL09RHV02LW9`0V9RH0
9bLW02TY:@<0:2PX0P0Z:RX01@0[:b/0:RXZ02/[:`0[:b/0;2`/0080;Bd]00<0;Rh^02l_;`0`<300
0P0`<3002`0a<C40<c<c034a<@0c<c<0=3@d03De=@0h>3P0=SHf03Ph>00g=cL0>CTi00<0>c/k0P0m
?Cd00`0n?Sh0@41003hn?P020410@080@D5100@0@d=30492@P14A4@0ADE50P17AdL02@18B4P0AdM7
04A4A015ADD0ATI604E5A@16ATH0ADE504M7A`0204A4A00504=3@`14A4@0@D510492@P11@D401010
@400100o?cl0?Shn03/k>`0m?Cd303/k>`0303Xj>P0h>3P0=cLg0080=SHf0P0e=CD01`0d=3@0<c<c
03@d=00`<300<S8b030`<00a<C400`0`<3000`0_;bl0;Bd]02d];@0202/[:`0302d];@0[:b/0:b/[
0080:BTY00H0:2PX02TY:@0X:2P09bLW02HV9P0X:2P202LW9`0402HV9P0U9BD09BDU02@T90<09BDU
00<092@T02<S8`0T92@00P0S8b<4028R8P808B4Q0P0P82000`0R8R80820P024Q8@03020P800601lO
7`0P82007QhN01lO7`0N7Qh07alO1@0N7Qh02P0M7Ad07QhN01hN7P0L71`07QhN01dM7@0L71`07QhN
01dM7@0N7Qh201dM7@8071`L0P0M7Ad301/K6`0401`L700M7Ad06a/K01`L70<06a/K0P0L71`00`0K
6a/06QXJ01XJ6P0301/K6`0601XJ6P0L71`071`L01/K6`0J6QX06a/K0`0J6QX01P0K6a/071`L01XJ
6P0J6QX06ATI01XJ6P806ATI0`0J6QX0100K6a/06ATI01/K6`0K6a/60=WIf@4000000@3IfMT001H0
fMWI00<000000=WIf@3IfMT00`3IfMT601XJ6P0301`L700J6QX071`L00@06QXJ0P0K6a/301XJ6P06
01/K6`0J6QX06ATI01XJ6P0K6a/06QXJ100K6a/0200J6QX06a/K01`L700K6a/06QXJ01`L700J6QX0
6a/K100L71`00`0K6a/07AdM01dM7@0601`L700601dM7@0L71`07AdM01dM7@0N7Qh07AdM0P0N7Qh0
100M7Ad07QhN01dM7@0M7Ad201hN7P807alO00D07QhN01lO7`0O7al07QhN01lO7`0301hN7P0:020P
800N7Qh08B4Q020P800N7Qh08B4Q01lO7`0P82007alO024Q8@80820P00<08R8R02<S8`0Q8B400`0Q
8B400`0S8b<08R8R028R8P0202<S8`09028R8P0T92@09RHV02<S8`0U9BD09RHV02DU9@0V9RH09BDU
00809bLW00D09RHV02PX:00Y:BT0:2PX02LW9`0202TY:@<0:RXZ0P0[:b/202d];@80;bl_00<0;Rh^
02l_;`0a<C400P0`<30403<c<`0303@d=00e=CD0=cLg0080=cLg00P0>3Ph03Xj>P0j>SX0>c/k03`l
?00n?Sh0?Cdm03hn?P80?clo0P11@D420492@P0904=3@`15ADD0AdM704M7A`18B4P0BDU904Q8B017
AdL0B4Q800<0AdM700H0ATI604M7A`16ATH0ADE504M7A`16ATH204E5A@0504A4A012@T80@T920492
@P10@4000P11@D403`0n?Sh0?Cdm03hn?P0l?3`0?Shn03Xj>P0i>CT0>3Ph03Lg=`0h>3P0=SHf03Lg
=`0e=CD0=3@d03De=@0203@d=080<S8b00`0<30`034a<@0_;bl0;bl_02h^;P0];Bd0;bl_02d];@0[
:b/0;2`/02/[:`0Z:RX302/[:`0602LW9`0Z:RX0:2PX02LW9`0X:2P09RHV0P0W9bL0100V9RH09BDU
02DU9@0U9BD402@T90808b<S00<08R8R02<S8`0T92@00P0R8R86024Q8@0701lO7`0P8200820P01lO
7`0P82007alO01hN7P0301lO7`05020P800O7al07QhN01hN7P0M7Ad0100N7Qh00`0M7Ad071`L01hN
7P0201hN7P<07AdM0P0L71`01@0K6a/071`L01`L700M7Ad06a/K008071`L0`0K6a/0100L71`06a/K
01`L700K6a/201XJ6P0501/K6`0J6QX06QXJ01/K6`0L71`01@0K6a/0300I6AT06QXJ01/K6`0K6a/0
6QXJ01/K6`0J6QX06a/K01XJ6P0K6a/06QXJ01`L70@06QXJ00<06ATI01XJ6P3IfMT01@3IfMT10000
0040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0P0J6QX201TI6@0301XJ6P0I6AT06QXJ00P0
6QXJ00L06ATI01XJ6P0L71`06QXJ01`L700J6QX071`L00806a/K00D071`L01/K6`0K6a/06a/K01XJ
6P0701/K6`0401`L700K6a/071`L01dM7@P071`L00H07AdM01`L700M7Ad071`L01dM7@0L71`201dM
7@0301hN7P0M7Ad07AdM00P07QhN00L0820P01hN7P0P82007alO020P800O7al0820P00807QhN0P0O
7al3020P8005024Q8@0P82007alO024Q8@0R8R800`0Q8B40100R8R808b<S02<S8`0R8R8302<S8`03
02@T900S8b<09BDU00<092@T0P0V9RH00`0W9bL09RHV02DU9@0302LW9`80:2PX00D0:BTY02PX:00Z
:RX0:b/[02XZ:P0202`/;00502d];@0_;bl0;Rh^030`<00_;bl00P0`<3001P0a<C40<S8b038b<P0b
<S80=3@d03De=@80=SHf00<0>3Ph03Hf=P0i>CT00P0j>SX01@0m?Cd0?3`l03`l?00n?Sh0?clo00<0
@D5100<0@d=304E5A@15ADD00P16ATH01017AdL0B4Q804Q8B01;Bd/204Y:BP80BDU900D0B4Q804Y:
BP1;Bd/0BTY:04Q8B00304U9B@0404M7A`16ATH0ATI604M7A`80ATI60P13@d<01P12@T80@D5103lo
?`10@400?clo03hn?P80?Cdm00@0>c/k03Xj>P0g=cL0>CTi0P0h>3P01@0g=cL0=SHf03@d=00c<c<0
<S8b0080<c<c00H0<30`034a<@0`<300<30`02h^;P0_;bl202h^;P0502d];@0/;2`0:b/[02`/;00[
:b/00P0Z:RX202TY:@0302LW9`0X:2P09bLW00<09bLW0P0U9BD04P0S8b<09BDU02@T900T92@09BDU
02@T900S8b<092@T02<S8`0Q8B408b<S028R8P0S8b<08R8R024Q8@0R8R80820P028R8PD0820P100O
7al01P0N7Qh07AdM01lO7`0O7al07QhN01lO7`807AdM0P0N7Qh00`0O7al07QhN01dM7@0201hN7P06
01`L700M7Ad07alO01dM7@0L71`06a/K0P0L71`01P0K6a/071`L01/K6`0K6a/071`L01/K6`<071`L
0`0K6a/01@0L71`06a/K01`L700K6a/071`L00806QXJ00<071`L01/K6`0L71`00P0J6QX00`0I6AT0
6QXJ01/K6`0601XJ6P0901PH600I6AT06QXJ01TI6@0J6QX061PH01/K6`0H61P06QXJ00H0fMWI0@00
00010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0501XJ6P0I6AT06QXJ01TI6@0J6QX00`0K
6a/0100J6QX06ATI01XJ6P0J6QX201`L700301/K6`0J6QX06a/K00806QXJ00<06a/K01XJ6P0K6a/0
0P0K6a/00`0L71`06a/K01/K6`0601/K6`L071`L00D07AdM01/K6`0L71`071`L01/K6`0201`L7080
7AdM00d07QhN01dM7@0K6a/071`L01dM7@0N7Qh07AdM01lO7`0M7Ad07QhN01dM7@0N7Qh07AdM00<0
7QhN0P0O7al0100M7Ad0820P01hN7P0N7Qh301lO7`80820P100O7al01P0P82008R8R020P800Q8B40
820P024Q8@808R8R00H092@T02<S8`0R8R808b<S02@T900S8b<302@T900702DU9@0T92@092@T02@T
900U9BD09RHV02LW9`0302HV9P0<02PX:00W9bL0:2PX02TY:@0Z:RX0:b/[02TY:@0Z:RX0;2`/02XZ
:P0/;2`0;Bd]0`0^;Rh302l_;`04034a<@0b<S80<c<c03<c<`80=3@d00<0=CDe03Hf=P0h>3P00P0i
>CT203`l?00503dm?@0l?3`0?clo03dm?@10@4000P11@D401P14A4@0@d=304M7A`16ATH0AdM704Q8
B080BDU900@0C4a<04];B`1<C4`0Bd];0P1<C4`00`1=CDd0C4a<04e=C@0204a<C00304m?C`1<C4`0
BTY:0080BTY:00`0BDU904Q8B019BDT0AdM704Q8B017AdL0@d=304E5A@12@T80A4A40451@@10@402
03lo?`0403`l?00o?cl0?3`l03Xj>P<0>CTi0P0h>3P0100g=cL0=CDe03De=@0d=3@3038b<P0D030`
<00_;bl0;bl_02h^;P0];Bd0;2`/02d];@0/;2`0:b/[02`/;00[:b/0:RXZ02`/;00X:2P0:BTY02PX
:00V9RH0:2PX02HV9P0W9bL302HV9P809BDU100T92@01P0S8b<08B4Q02<S8`0R8R808B4Q02<S8`@0
8R8R0P0Q8B40100O7al0820P020P800N7Qh401lO7`0401dM7@0N7Qh07alO01hN7P<07alO00<07QhN
01dM7@0O7al00P0N7Qh201dM7@807QhN00T07AdM01hN7P0L71`06a/K01`L700M7Ad071`L01/K6`0L
71`00P0M7Ad301`L70806a/K00@06QXJ01`L700K6a/07AdM0`0K6a/0100J6QX06a/K01XJ6P0K6a/2
01XJ6P0701/K6`0L71`06a/K01XJ6P0K6a/06QXJ01/K6`0201`L700401TI6@0K6a/06QXJ01/K6`@0
6QXJ00@06ATI01XJ6P0J6QX06ATI1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0
fMWI00P06QXJ01TI6@0I6AT06QXJ01/K6`0I6AT06QXJ01TI6@<06QXJ00T06a/K01TI6@0K6a/06QXJ
01/K6`0J6QX06a/K01XJ6P0K6a/00`0J6QX00`0K6a/06ATI01/K6`0401/K6`0301`L700K6a/06QXJ
00<06a/K0P0L71`0100M7Ad071`L01dM7@0M7Ad201`L700301/K6`0M7Ad06a/K008071`L0P0M7Ad2
01`L700901/K6`0M7Ad07AdM01lO7`0M7Ad07QhN01dM7@0N7Qh07AdM00807QhN0P0O7al301hN7P<0
7alO0P0P8200100Q8B40820P020P800Q8B42020P80808B4Q00<08R8R024Q8@0Q8B400P0R8R800`0P
82008B4Q02<S8`0302<S8`03028R8P0T92@092@T00<08b<S00@092@T02DU9@0V9RH09BDU0P0V9RH0
100W9bL09RHV02PX:00Y:BT302PX:00302TY:@0Z:RX0:b/[00<0;2`/00L0;Bd]02h^;P0^;Rh0;Rh^
030`<00a<C40<30`0080<S8b00D0<c<c03@d=00e=CD0=3@d03De=@0203Ph>080>CTi0P0k>c/01@0m
?Cd0?Shn0410@010@400@d=30080@T9200P0A4A404E5A@17AdL0BDU904Q8B019BDT0BTY:04];B`80
CTi>00<0Cdm?051@D01>CTh00P1>CTh00`1=CDd0Cdm?051@D00304i>CP0304a<C01;Bd/0C4a<0080
Bd];00l0BDU904M7A`18B4P0ATI604E5A@16ATH0ADE50492@P11@D40@T920451@@0m?Cd0?clo03`l
?00m?Cd00P0k>c/203Ti>@0803Ph>00f=SH0=cLg03De=@0d=3@0<c<c03@d=00b<S82034a<@80<30`
00D0;Rh^02d];@0^;Rh0;2`/02XZ:P0302`/;00602XZ:P0Y:BT0:BTY02TY:@0Z:RX0:2PX0P0W9bL0
1P0V9RH09bLW02HV9P0V9RH09BDU02HV9P808b<S00@092@T028R8P0S8b<092@T0P0R8R80100S8b<0
8R8R02<S8`0R8R84024Q8@0401lO7`0Q8B40820P020P80<07alO00@0820P01hN7P0N7Qh07QhN0P0O
7al00`0N7Qh07alO01hN7P0201hN7P0701lO7`0N7Qh07QhN01dM7@0N7Qh07AdM01hN7P0301dM7@H0
71`L00<06a/K01`L700K6a/00P0K6a/0100L71`06a/K01/K6`0J6QX301/K6`0701XJ6P0K6a/06a/K
01`L700J6QX06a/K01XJ6P0201/K6`H06QXJ0`0K6a/00`0I6AT06QXJ01XJ6P0201XJ6P0501TI6@0J
6QX06ATI01TI6@0J6QX01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0P0J
6QX0100H61P06ATI01XJ6P0J6QX201/K6`806ATI0P0J6QX00`0K6a/06QXJ01XJ6P0301/K6`0901XJ
6P0K6a/06a/K01XJ6P0L71`06a/K01XJ6P0K6a/071`L00@06QXJ0P0K6a/0200L71`06a/K01`L700L
71`07AdM01hN7P0L71`07AdM0P0L71`0100M7Ad071`L01`L700L71`201/K6`0401`L700K6a/07AdM
01`L70807AdM00D071`L01dM7@0M7Ad07QhN01dM7@0301hN7P0301dM7@0N7Qh07QhN00807QhN00@0
7alO01hN7P0O7al07QhN100O7al3020P8008024Q8@0R8R80820P020P800Q8B408R8R02<S8`0R8R82
024Q8@0402<S8`0Q8B4092@T02<S8`<092@T0P0U9BD0100T92@09BDU02<S8`0T92@302HV9P80:2PX
00D09bLW02PX:00Y:BT0:RXZ02TY:@0502/[:`80;Rh^0P0_;bl00`0`<300;bl_038b<P02034a<@80
<c<c00H0=SHf03Lg=`0f=SH0=SHf03Xj>P0h>3P203/k>`0303`l?00m?Cd0@4100080@41000<0@T92
04=3@`13@d<00P15ADD00`17AdL0Bd];04Y:BP0204];B`0504i>CP1=CDd0Cdm?051@D01ADE400P1@
D5001@1CDe<0DU9B051@D01ADE40DU9B00<0DE5A00H0D51@04i>CP1>CTh0D51@04a<C01=CDd204];
B`0304Y:BP17AdL0AdM70080AdM700D0ADE504=3@`12@T80@D5103lo?`0203hn?P0503/k>`0l?3`0
>SXj03Xj>P0h>3P00P0g=cL00`0f=SH0=3@d03De=@0303<c<`04030`<00_;bl0<30`02l_;`<0;Rh^
00@0;Bd]02`/;00/;2`0;2`/0`0Z:RX202PX:00602TY:@0W9bL09bLW02PX:00Y:BT09RHV0P0U9BD0
100V9RH092@T02@T900T92@402<S8`0602@T900Q8B4092@T024Q8@0R8R808b<S0P0Q8B401P0P8200
7alO020P800Q8B40820P01lO7`80820P1@0O7al01`0M7Ad07QhN01lO7`0O7al07AdM01hN7P0O7al0
0P0N7Qh01`0O7al07AdM01dM7@0L71`07QhN01`L700M7Ad00P0L71`201dM7@T071`L00D06ATI01/K
6`0I6AT06QXJ01`L700201/K6`0301XJ6P0L71`06a/K00@06QXJ00D071`L01XJ6P0J6QX06QXJ01TI
6@0601XJ6P0501/K6`0J6QX06QXJ01XJ6P0I6AT00`0J6QX60=WIf@4000000@3IfMT001H0fMWI00<0
00000=WIf@3IfMT00`3IfMT00`0K6a/06ATI01/K6`0301XJ6P0601PH600J6QX06QXJ01TI6@0K6a/0
6ATI0P0J6QX0100K6a/06QXJ01XJ6P0J6QX301/K6`0401`L700J6QX06a/K01/K6`@071`L00@06a/K
01`L700J6QX06a/K100L71`00`0K6a/07AdM01`L700201`L700401dM7@0L71`071`L01`L70807AdM
00D071`L01hN7P0M7Ad07AdM01/K6`0201dM7@0;01`L700M7Ad07AdM01dM7@0N7Qh071`L01lO7`0M
7Ad0820P01lO7`0M7Ad00P0N7Qh301lO7`06020P800O7al0820P024Q8@0P82007alO0P0P82000`0O
7al08B4Q020P8002024Q8@04020P800R8R808R8R028R8PH08b<S00<09BDU02@T900T92@00P0U9BD0
0`0V9RH09BDU02HV9P0402HV9P0502PX:00Y:BT0:2PX02PX:00Y:BT00P0Z:RX202`/;00502d];@0^
;Rh0;Bd]02d];@0^;Rh00P0`<300100a<C40<30`038b<P0c<c<203@d=00503Hf=P0g=cL0=cLg03Lg
=`0j>SX00P0k>c/0200j>SX0?Cdm03hn?P0o?cl0@41004=3@`12@T80@D510P15ADD02P16ATH0BTY:
04Y:BP1:BTX0C4a<04m?C`1@D500Cdm?051@D01BDU8205=CD`03059BDP1DE5@0E5AD0080EEEE0P1D
E5@0201BDU80De=C05EEE@1BDU80DE5A04m?C`1@D500CTi>0P1<C4`00`19BDT0BTY:04Q8B00204M7
A`0604I6AP15ADD0A4A40492@P10@400?clo0P0m?Cd03P0l?3`0>c/k03Xj>P0k>c/0=SHf03Lg=`0e
=CD0=cLg03Hf=P0d=3@0<c<c038b<P0`<300<C4a0P0`<30302h^;P80;Bd]00<0;2`/02XZ:P0[:b/0
0`0Z:RX02@0X:2P09bLW02LW9`0X:2P09bLW02HV9P0W9bL09RHV02LW9`0202DU9@0402@T900S8b<0
8b<S02<S8`8092@T00@08B4Q02<S8`0Q8B408b<S0P0R8R801`0S8b<08B4Q024Q8@0P82008B4Q020P
800Q8B400P0P82000`0O7al0820P020P800201lO7`0701dM7@0N7Qh07QhN01lO7`0N7Qh07alO01hN
7P0401dM7@0501lO7`0M7Ad071`L01hN7P0L71`00P0M7Ad00`0N7Qh07AdM01`L700201dM7@D071`L
00L06QXJ01`L700K6a/06QXJ01/K6`0J6QX071`L00806a/K00D06QXJ01/K6`0K6a/06QXJ01`L7004
01/K6`0401`L700K6a/06QXJ01TI6@806QXJ0P0K6a/0100J6QX06a/K01TI6@0K6a/201XJ6P<06ATI
1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0`0J6QX201/K6`806QXJ00<0
6ATI01/K6`0J6QX0100J6QX00`0K6a/06QXJ01XJ6P0201XJ6P0301/K6`0J6QX06a/K00806a/K00<0
6QXJ01TI6@0J6QX00`0K6a/201`L700301XJ6P0L71`06QXJ008071`L0P0N7Qh201`L700301dM7@0L
71`06a/K00807AdM0P0L71`0100M7Ad07QhN01dM7@0L71`201dM7@8071`L100M7Ad0300O7al07QhN
01hN7P0N7Qh07AdM01hN7P0O7al0820P01hN7P0O7al0820P01hN7P<07alO00@08B4Q020P800P8200
820P0`0Q8B42028R8P09024Q8@0R8R808R8R024Q8@0R8R808B4Q02<S8`0R8R8092@T00808b<S00l0
92@T02<S8`0S8b<09RHV02DU9@0V9RH09BDU02LW9`0X:2P09bLW02TY:@0X:2P0:BTY02PX:00Y:BT0
0`0Z:RX202`/;00302d];@0_;bl0;Rh^0080;Rh^0P0`<302034a<@03038b<P0c<c<0=3@d0080=SHf
0`0i>CT02@0j>SX0?3`l03/k>`0m?Cd0?clo0451@@0o?cl0@T9204=3@`0204E5A@0504Q8B017AdL0
C4a<04i>CP1=CDd00P1?Cdl2051@D003059BDP1DE5@0EEEE0080EEEE00L0F5QH05EEE@1HF5P0EeMG
05YJFP1FEUH0F5QH00@0EUIF00T0E5AD059BDP1BDU80DU9B04m?C`1@D500CTi>04];B`1<C4`00P1:
BTX03@19BDT0ATI604A4A014A4@0@D510410@00o?cl0@41003hn?P0k>c/0?3`l03Xj>P0i>CT00P0h
>3P203Hf=P0403De=@0d=3@0<S8b038b<P<0<C4a00D0<30`02d];@0^;Rh0;Rh^02d];@0302`/;003
02TY:@0Z:RX0:b/[0080:2PX00@09RHV02PX:00W9bL09bLW0`0V9RH202DU9@0302@T900V9RH08b<S
00@08b<S00<08B4Q02<S8`0R8R800`0R8R80100P82008B4Q028R8P0R8R82024Q8@<0820P1P0O7al0
0`0N7Qh07AdM01hN7P0401hN7P0@01dM7@0N7Qh07AdM01dM7@0N7Qh07alO01dM7@0L71`07AdM01hN
7P0L71`07AdM01`L700M7Ad071`L01dM7@8071`L0P0K6a/201`L70P06a/K0`0J6QX01@0K6a/06QXJ
01`L700J6QX06a/K00D06QXJ0P0I6AT02@0K6a/06QXJ01XJ6P0I6AT06QXJ01/K6`0J6QX06ATI01XJ
6P060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0100I6AT06QXJ01XJ6P0I
6AT201XJ6P0401/K6`0I6AT06ATI01XJ6P<06a/K00H06QXJ01/K6`0J6QX06a/K01XJ6P0K6a/201XJ
6P0301`L700K6a/06a/K00@06a/K00D071`L01/K6`0K6a/06a/K01`L700201/K6`0301`L700K6a/0
71`L00<071`L00<06a/K01dM7@0L71`00P0M7Ad04P0L71`07AdM01`L700L71`06a/K01`L700N7Qh0
7AdM01hN7P0M7Ad07alO01hN7P0M7Ad07alO01hN7P0M7Ad07QhN01dM7@807QhN0P0O7al01`0P8200
7QhN01lO7`0P82007alO01hN7P0P82000P0Q8B43020P80<08B4Q0P0R8R800`0Q8B408R8R02<S8`03
028R8P808b<S00@09BDU02@T900U9BD08b<S0P0V9RH01@0T92@09BDU02DU9@0W9bL09BDU00809bLW
00<0:2PX02TY:@0Y:BT00`0Z:RX0100[:b/0:RXZ02d];@0/;2`302h^;P0502l_;`0`<300<C4a034a
<@0b<S800P0d=3@03P0g=cL0=CDe03@d=00g=cL0>3Ph03Ti>@0l?3`0?Cdm03lo?`0n?Sh0@4100492
@P13@d<0A4A40P16ATH00`19BDT0BTY:04a<C00204i>CP80DE5A00<0D51@05=CD`1FEUH00P1GEeL2
05UIF@80FUYJ00<0FEUI05aLG01MGEd00P1LG5`0101MGEd0Fe]K05YJFP1KFe/205QHF00605EEE@1H
F5P0EUIF05=CD`1BDU80CTi>0P1?Cdl204];B`0304Q8B019BDT0AdM70080ADE500@0A4A40451@@0o
?cl0?clo0P0m?Cd00`0k>c/0?3`l03Xj>P0203Ph>00403Lg=`0f=SH0=CDe03<c<`<0<S8b0P0_;bl2
02h^;P@0;Bd]0`0Z:RX01@0[:b/0:2PX02LW9`0Y:BT0:2PX00809bLW00@09RHV02LW9`0U9BD092@T
0`0U9BD202@T900302DU9@0S8b<08b<S00808b<S0P0R8R80100S8b<08B4Q024Q8@0P8203024Q8@0:
020P800R8R80820P020P800Q8B407alO01hN7P0P82007alO01hN7P807alO00@07QhN01lO7`0L71`0
71`L0`0M7Ad00`0O7al07AdM01hN7P0401dM7@<07QhN100L71`00`0M7Ad071`L01/K6`0201/K6`05
01`L700K6a/06a/K01`L700J6QX00P0L71`00`0K6a/06QXJ01/K6`0201/K6`806QXJ00D06a/K01XJ
6P0J6QX06QXJ01/K6`0601XJ6P0301TI6@0J6QX06QXJ00806QXJ00<06ATI01XJ6P0I6AT01P3IfMT1
00000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00D06QXJ01TI6@0J6QX06a/K01TI6@03
01XJ6P0301TI6@0K6a/06QXJ00806QXJ00@071`L01/K6`0J6QX06QXJ0`0K6a/201XJ6P0401/K6`0J
6QX071`L01`L70806a/K00D071`L01/K6`0K6a/071`L01/K6`0201`L700501/K6`0M7Ad071`L01`L
700K6a/00P0L71`401dM7@0301`L700K6a/07AdM00D07AdM00<07QhN01dM7@0M7Ad00`0M7Ad201hN
7P0301dM7@0O7al07AdM00807QhN00L07AdM01hN7P0N7Qh07alO020P800N7Qh07alO00@0820P00D0
8B4Q01lO7`0Q8B40820P028R8P02024Q8@0402<S8`0R8R808b<S02<S8`808R8R00L08b<S028R8P0T
92@09RHV02DU9@0T92@09RHV00<09BDU0P0V9RH202LW9`0?02HV9P0Y:BT0:BTY02XZ:P0Y:BT0:RXZ
02TY:@0[:b/0;2`/02d];@0/;2`0;Bd]02l_;`0^;Rh0;bl_0080<C4a0P0b<S8203<c<`0603@d=00f
=SH0=CDe03Ph>00i>CT0>c/k0P0m?Cd203lo?`0?0410@012@T80@d=304=3@`18B4P0AdM704Q8B019
BDT0C4a<04i>CP1@D500DU9B05ADE01FEUH0EEEE0080F5QH00H0G5aL05UIF@1KFe/0G5aL05mOG`1L
G5`205mOG`0305eMG@1PH600GEeM0080GUiN0P1KFe/00`1LG5`0FUYJ05MGE`0205QHF00505EEE@1B
DU80DU9B04m?C`1>CTh00P1;Bd/204M7A`80ADE500`0@d=30492@P12@T80?clo03hn?P0m?Cd0?3`l
03/k>`0j>SX0>3Ph03Lg=`0f=SH303@d=080<c<c0P0a<C401`0_;bl0;Rh^02l_;`0_;bl0;Bd]02`/
;00];Bd00P0[:b/0100Y:BT0;2`/02XZ:P0Z:RX202PX:0<09bLW0P0V9RH00`0U9BD09bLW02DU9@02
02DU9@0302@T900S8b<09BDU00@08b<S00D08B4Q02<S8`0P82008R8R020P8002024Q8@<0820P00@0
8B4Q020P800O7al07QhN0`0O7al201hN7P807alO0`0N7Qh501dM7@0501hN7P0M7Ad07AdM01dM7@0N
7Qh00`0M7Ad00`0L71`07AdM01`L700601`L700301dM7@0L71`07AdM008071`L200K6a/00`0J6QX0
6a/K01XJ6P0301XJ6P0301/K6`0J6QX06ATI00806QXJ00L061PH01XJ6P0J6QX06ATI01XJ6P0K6a/0
6QXJ00806ATI1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00@06a/K01TI
6@0K6a/06ATI0P0K6a/0100J6QX06ATI01TI6@0J6QX201/K6`806QXJ00H06a/K01XJ6P0K6a/06QXJ
01/K6`0J6QX301/K6`0701XJ6P0L71`071`L01/K6`0I6AT06a/K01`L700301/K6`<071`L00@06a/K
01dM7@0K6a/07AdM0P0L71`02P0M7Ad06a/K01`L700M7Ad071`L01hN7P0M7Ad06a/K01dM7@0K6a/2
01dM7@0401hN7P0M7Ad07QhN01hN7P807AdM00@07QhN01dM7@0N7Qh07QhN0P0O7al201hN7P807alO
00<0820P01lO7`0O7al00P0P82000`0O7al0820P024Q8@02024Q8@808R8R00<0820P028R8P0R8R80
0`0R8R8502<S8`0602HV9P0T92@08b<S02<S8`0V9RH092@T0P0V9RH01`0U9BD09bLW02LW9`0X:2P0
9RHV02LW9`0X:2P00P0Y:BT00`0[:b/0:RXZ02/[:`0302`/;080;Rh^00H0;bl_034a<@0a<C40<S8b
034a<@0c<c<203@d=080=cLg0P0i>CT02@0k>c/0?Cdm03lo?`0n?Sh0@4100451@@13@d<0A4A404I6
AP0204Q8B00404U9B@1<C4`0CDe=051@D080De=C00<0EEEE05IFEP1GEeL00`1JFUX01@1NGUh0GemO
061PH01RHV80IFEU0080I6AT00D0Hf=S06ATI01UIFD0IVIV069RHP0206=SH`80H61P00@0GemO05aL
G01LG5`0Fe]K0P1FEUH2059BDP80D51@00L0CDe=04Y:BP1:BTX0B4Q804I6AP14A4@0ADE50080@D51
00P0@41003lo?`0n?Sh0?Cdm03`l?00j>SX0>3Ph03Lg=`80=CDe00<0=SHf038b<P0b<S800P0`<300
0`0a<C40<30`02l_;`0202h^;P80;Bd]0P0[:b/00`0/;2`0:RXZ02XZ:P0202PX:00302LW9`0V9RH0
9bLW00809RHV00D09bLW02DU9@0U9BD09RHV02DU9@0402@T900502<S8`0T92@08b<S02<S8`0Q8B40
0P0R8R802@0O7al08B4Q020P800R8R808B4Q01lO7`0P82007alO020P800201lO7`03020P800N7Qh0
7QhN00@07QhN00<07alO01hN7P0L71`00P0M7Ad0100N7Qh07AdM01hN7P0N7Qh201dM7@0301hN7P0M
7Ad071`L00D07AdM00@071`L01dM7@0L71`06a/K0`0L71`601/K6`0301`L700K6a/06a/K00@06a/K
0P0J6QX401/K6`0301XJ6P0K6a/06QXJ00<06QXJ00<06ATI01XJ6P0J6QX00P0I6AT00`0J6QX06ATI
0=WIf@050=WIf@4000000@3IfMT001H0fMWI0P0000040=WIf@0301XJ6P0K6a/06a/K00806a/K00@0
6QXJ01`L700J6QX06QXJ100K6a/201XJ6P0401/K6`0I6AT06QXJ01XJ6P<06a/K00@06QXJ01/K6`0K
6a/06QXJ100K6a/301`L70@06a/K0P0J6QX02@0M7Ad071`L01dM7@0K6a/071`L01dM7@0K6a/071`L
01dM7@0201`L70807AdM00@07QhN01`L700O7al07alO200N7Qh0100O7al07QhN01lO7`0M7Ad301lO
7`03024Q8@0O7al07QhN0080820P0P0O7al0100P82007alO024Q8@0P8202028R8P03024Q8@0R8R80
8R8R00<08b<S00H08R8R02@T900T92@08b<S02DU9@0T92@202HV9P0802DU9@0T92@09BDU02DU9@0W
9bL0:BTY02PX:00W9bL202PX:00702TY:@0Z:RX0:b/[02XZ:P0/;2`0;Bd]02`/;00202d];@0402l_
;`0a<C40<C4a034a<@<0<c<c00@0=3@d03De=@0g=cL0=cLg0`0j>SX01@0m?Cd0?Shn0492@P11@D40
@T920080ADE500<0BDU904M7A`1:BTX00P1>CTh03P1@D500DU9B05ADE01FEUH0EeMG05aLG01KFe/0
GUiN061PH01RHV80Hf=S06ATI01VIVH0J6QX0P1YJFT02`1ZJVX0J6QX06MWI`1ZJVX0JFUY06QXJ01W
IfL0IVIV06ATI01SHf<0HV9R0080HF5Q00D0G5aL05YJFP1KFe/0EeMG05EEE@0205=CD`05051@D01>
CTh0CDe=04];B`17AdL00P16ATH204=3@`<0@4100140?3`l03Xj>P0l?3`0>CTi03Hf=P0g=cL0=CDe
03@d=00e=CD0<S8b03<c<`0`<300<C4a02l_;`0`<300;bl_02h^;P0202d];@80;2`/00@0:b/[02XZ
:P0[:b/0:BTY0`0X:2P0100Y:BT0:2PX02LW9`0W9bL202HV9P@09BDU00@08R8R02<S8`0T92@08R8R
0P0S8b<0100Q8B408R8R028R8P0P8205024Q8@0401lO7`0Q8B408B4Q01hN7PD07alO00L07QhN01dM
7@0M7Ad07alO01hN7P0M7Ad07QhN00@07AdM00<071`L01dM7@0M7Ad00P0M7Ad0100L71`07AdM01`L
700N7Qh201`L700301/K6`0L71`071`L008071`L00@06a/K01`L700J6QX071`L1@0K6a/00`0M7Ad0
71`L01/K6`0501/K6`@06QXJ00H06a/K01`L700K6a/06ATI01XJ6P0K6a/301XJ6P0401`L700J6QX0
6QXJ01XJ6PD0fMWI0P0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@@06QXJ00L06a/K
01XJ6P0K6a/06QXJ01`L700K6a/06ATI00H06QXJ0P0K6a/00`0J6QX06a/K01/K6`0201/K6`@071`L
00L06a/K01`L700K6a/06QXJ01dM7@0L71`06QXJ00806a/K00H071`L01/K6`0L71`06a/K01`L700K
6a/201dM7@0601/K6`0M7Ad071`L01`L700N7Qh071`L100M7Ad601hN7P0>01lO7`0N7Qh07QhN01hN
7P0O7al07QhN01lO7`0N7Qh07alO020P800N7Qh0820P01lO7`0N7Qh3020P8005028R8P0Q8B408R8R
020P800Q8B401`0S8b<01@0U9BD08b<S02DU9@0S8b<092@T00D09BDU00L09bLW02HV9P0W9bL09bLW
02PX:00Y:BT0:2PX0080:BTY00D0;2`/02/[:`0Z:RX0;Bd]02`/;00302d];@0:02l_;`0a<C40<C4a
034a<@0c<c<0=3@d03<c<`0f=SH0=CDe03Lg=`80>3Ph00<0?Cdm03`l?00n?Sh00P10@4001P12@T80
@d=304I6AP17AdL0BDU904Y:BP80CDe=0P1@D500101EEED0EUIF05QHF01KFe/205iNGP08069RHP1Q
HF40Hf=S06QXJ01WIfL0JVYZ06][J`1]KFd206a/K00306i^KP1]KFd0L71`00<0Jf][0140JFUY06QX
J01WIfL0IVIV06=SH`1QHF40GUiN05mOG`1KFe/0FUYJ05QHF01GEeL0E5AD059BDP1>CTh0CDe=04a<
C00204Q8B00304E5A@14A4@0A4A40080@D510P0n?Sh203`l?00303Ti>@0h>3P0=cLg0080=CDe0P0d
=3@2038b<P03034a<@0`<300<30`0080;bl_0P0/;2`00`0[:b/0;2`/02/[:`0202/[:`0402PX:00Y
:BT0:2PX02TY:@809bLW00<09RHV02LW9`0U9BD00P0V9RH302@T90808b<S00H09BDU02<S8`0S8b<0
8R8R024Q8@0S8b<2028R8P0:020P800R8R808B4Q024Q8@0P82008B4Q01lO7`0Q8B40820P01hN7P80
820P0P0O7al0100P82007QhN01lO7`0N7Qh301dM7@0401`L700M7Ad07AdM01dM7@@071`L00L06a/K
01dM7@0M7Ad07AdM01`L700M7Ad071`L00807AdM0`0L71`401/K6`0301`L700K6a/06a/K00<06a/K
00<06QXJ01/K6`0J6QX00P0K6a/01P0J6QX06a/K01XJ6P0J6QX071`L01/K6`<06QXJ100I6AT00`0K
6a/06QXJ01/K6`0301TI6@H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@04
01XJ6P0I6AT06QXJ01/K6`@06QXJ0P0K6a/401XJ6P<06a/K00D06ATI01/K6`0L71`06a/K01`L7007
01/K6`0301XJ6P0L71`071`L008071`L00@06a/K01`L700L71`071`L0P0K6a/00`0N7Qh06a/K01`L
700201`L700501dM7@0L71`07AdM01dM7@0L71`00P0M7Ad00`0N7Qh07AdM01dM7@0401hN7P0301dM
7@0P82007QhN00D07alO0P0N7Qh00`0P82007QhN01lO7`0201lO7`06020P800O7al08B4Q020P800Q
8B40820P0P0Q8B43028R8P<08b<S00X08R8R02<S8`0S8b<092@T02<S8`0U9BD092@T02DU9@0T92@0
9BDU0`0V9RH01@0W9bL0:2PX02PX:00Y:BT0:2PX00@0:BTY00<0:b/[02`/;00[:b/00P0];Bd01@0/
;2`0;Rh^034a<@0_;bl0<30`00<0<S8b0P0e=CD01@0h>3P0>SXj03Ti>@0l?3`0?Cdm0080?Shn00d0
@D510410@015ADD0A4A404E5A@18B4P0BDU904e=C@1>CTh0D51@05=CD`1EEED0EUIF0080FEUI0`1O
Gel01P1VIVH0JFUY06UYJ@1/K6`0JVYZ06m_K`80L71`0P1dM7@0401cLg<0M7Ad07AdM01bLW80Lg=c
07AdM01`L700KVi^06a/K01YJFT0IVIV06QXJ01UIFD0HF5Q05mOG`1MGEd205UIF@0605ADE01CDe<0
DU9B04m?C`1>CTh0C4a<0P19BDT204I6AP0304=3@`11@D40@D510080?clo00D0?Cdm03/k>`0j>SX0
>3Ph03Lg=`0203Hf=P0803@d=00b<S80<c<c030`<00^;Rh0<30`02l_;`0];Bd202l_;`0802h^;P0Z
:RX0:b/[02XZ:P0Y:BT0:b/[02PX:00Y:BT302PX:00502LW9`0U9BD09RHV02HV9P0W9bL00P0T92@0
0`0U9BD08b<S02@T900202@T900602<S8`0R8R8092@T028R8P0Q8B40820P0P0Q8B401P0S8b<08B4Q
024Q8@0Q8B40820P01lO7`80820P100O7al401hN7P<07AdM00H07alO01dM7@0N7Qh07QhN01dM7@0K
6a/201dM7@0301`L700N7Qh071`L00807AdM00D071`L01dM7@0K6a/071`L01dM7@0301`L700401dM
7@0K6a/07AdM01`L70@06a/K00D071`L01/K6`0J6QX06a/K01XJ6P0201/K6`0401`L700K6a/071`L
01XJ6P806a/K00<06QXJ01/K6`0J6QX00P0I6AT01`0K6a/06ATI01XJ6P0H61P06ATI01XJ6P0I6AT0
1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0P0I6AT0100J6QX06ATI01/K
6`0J6QX201/K6`806QXJ00<06a/K01XJ6P0J6QX0100J6QX201/K6`8071`L00<06QXJ01/K6`0K6a/0
1@0K6a/00`0L71`06QXJ01XJ6P0201`L700801/K6`0L71`071`L01`L700K6a/07AdM01/K6`0L71`2
01dM7@0501/K6`0L71`07AdM01dM7@0N7Qh00P0L71`201dM7@0401`L700N7Qh07QhN01dM7@@07QhN
0P0O7al01`0N7Qh07alO01lO7`0N7Qh07alO020P800N7Qh00P0P820201lO7`04020P800O7al0820P
020P80808B4Q00@0820P028R8P0R8R808R8R0P0Q8B42028R8P0502@T900S8b<092@T02DU9@0S8b<0
0P0U9BD00`0V9RH09BDU02DU9@0202HV9P809bLW100X:2P302TY:@0402/[:`0/;2`0;2`/02`/;0<0
;Bd]00X0;bl_02h^;P0a<C40<C4a030`<00d=3@0<c<c03Hf=P0e=CD0>3Ph0P0j>SX05P0k>c/0?clo
03dm?@0n?Sh0@T920410@011@D40A4A404Q8B019BDT0C4a<04i>CP1?Cdl0DE5A05ADE01EEED0EeMG
05]KF`1MGEd0HV9R06ATI01VIVH206YZJP0406e]K@1_Kfl0L71`079bLP80MGEe00@0MgMg07QhN01h
N7P0NGUi0`1fMWH02P1eMGD0LG5a079bLP1`L700KFe]06][J`1VIVH0J6QX06ATI01RHV8205aLG009
05YJFP1HF5P0E5AD05=CD`1ADE40CDe=04];B`1:BTX0BDU90080ATI60P14A4@03P10@400?Shn03hn
?P0l?3`0>SXj03Ti>@0k>c/0>3Ph03Hf=P0e=CD0=3@d03<c<`0a<C40<S8b0P0`<3001@0^;Rh0;bl_
02l_;`0];Bd0;2`/00<0:b/[0P0Z:RX01@0X:2P0:BTY02LW9`0X:2P09bLW00809RHV00<09BDU02HV
9P0V9RH00`0U9BD0100T92@08b<S02@T900T92@3028R8P0402<S8`0Q8B408R8R028R8P808B4Q00H0
820P024Q8@0Q8B40820P01hN7P0O7al2020P800<01lO7`0P82007QhN01hN7P0O7al07QhN01dM7@0N
7Qh07alO01dM7@0L71`07AdM0P0N7Qh00`0L71`07AdM01`L700201dM7@8071`L00H07AdM01/K6`0L
71`07AdM01`L700K6a/301dM7@0301/K6`0L71`07AdM008071`L0P0K6a/01@0L71`06QXJ01/K6`0K
6a/06ATI008071`L0P0J6QX01@0K6a/06ATI01XJ6P0K6a/06QXJ00<06a/K00X06QXJ01TI6@0K6a/0
6QXJ01/K6`0I6AT06QXJ01TI6@0K6a/06ATI1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0
fMWI00<0fMWI0P0J6QX01P0I6AT06a/K01XJ6P0K6a/06ATI01/K6`806QXJ0P0K6a/02`0I6AT06QXJ
01/K6`0J6QX071`L01/K6`0I6AT06a/K01XJ6P0K6a/06QXJ00<06a/K00H071`L01/K6`0K6a/06a/K
01XJ6P0L71`401/K6`0301XJ6P0K6a/071`L008071`L100M7Ad02@0K6a/07AdM01/K6`0L71`07AdM
01hN7P0M7Ad071`L01hN7P0201`L70807QhN0`0O7al0200N7Qh07AdM01hN7P0N7Qh07alO01hN7P0O
7al0820P0P0O7al2020P800501lO7`0P8200820P020P800Q8B400P0P82000`0Q8B40820P028R8P02
028R8P@08b<S00H08R8R02<S8`0U9BD092@T02HV9P0T92@302HV9P0302@T900V9RH09RHV0080:2PX
00H09bLW02PX:00W9bL0:RXZ02PX:00Y:BT302/[:`0602h^;P0];Bd0;Rh^02l_;`0^;Rh0;bl_0P0`
<3002P0c<c<0=3@d03De=@0g=cL0>3Ph03Lg=`0i>CT0?3`l03dm?@0n?Sh203lo?`0L0451@@13@d<0
ATI604M7A`1:BTX0Bd];04a<C01?Cdl0D51@05ADE01HF5P0FUYJ05]KF`1NGUh0HF5Q06ATI01WIfL0
JFUY06][J`1`L700LG5a07IfMP1hN7P0NWYj07]kN`1nOWh0OGem07inOP80PH6100D0OGem07moO`1l
O7`0O7al07UiN@0207IfMP0807AdM01^KVh0K6a/06YZJP1YJFT0IfMW06EUI@1QHF4205]KF`0B05QH
F01DE5@0De=C05ADE01?Cdl0CDe=04U9B@18B4P0ATI604E5A@12@T80@d=30410@00o?cl0?Cdm03/k
>`0j>SX0>CTi0P0g=cL303Hf=P04038b<P0`<300<30`030`<080;bl_0P0];Bd01@0Z:RX0;2`/02`/
;00/;2`0:RXZ00<0:BTY00D0:2PX02HV9P0W9bL09RHV02LW9`0202HV9P0302DU9@0V9RH092@T0080
92@T0`0S8b<00`0T92@08B4Q02<S8`02028R8P0302<S8`0Q8B408R8R00D08B4Q0`0P820401lO7`@0
7QhN100M7Ad201hN7P0501dM7@0N7Qh07AdM01hN7P0M7Ad00P0L71`01@0M7Ad071`L01`L700L71`0
6a/K00<071`L00<07QhN01`L700L71`00`0K6a/0100L71`06QXJ01XJ6P0J6QX601/K6`806QXJ0P0K
6a/00`0J6QX06a/K01/K6`0201`L70806QXJ00D06a/K01`L700J6QX06QXJ01PH600301TI6@0301XJ
6P3IfMT0fMWI00@0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@806QXJ0P0K
6a/00`0J6QX06a/K01/K6`0201/K6`806QXJ00<06a/K01XJ6P0K6a/01@0J6QX401/K6`0B01`L700K
6a/06a/K01`L700K6a/071`L01/K6`0L71`06QXJ01`L700K6a/06QXJ01`L700K6a/071`L01/K6`0L
71`07AdM1@0L71`201dM7@8071`L00T07QhN01`L700N7Qh07AdM01hN7P0M7Ad07alO01hN7P0O7al0
0P0N7Qh401lO7`80820P0P0N7Qh301lO7`03024Q8@0O7al07alO00@0820P0P0R8R800`0Q8B408R8R
028R8P0202<S8`<08R8R0P0S8b<00`0V9RH092@T02DU9@0202DU9@D09RHV00D09bLW02PX:00Y:BT0
:2PX02XZ:P0202TY:@0602/[:`0/;2`0;2`/02TY:@0];Bd0;Rh^0P0];Bd01@0^;Rh0<S8b034a<@0`
<300<C4a0080=3@d0`0h>3P0100k>c/0?Cdm03dm?@0n?Sh20410@00:04E5A@14A4@0ATI604Q8B01;
Bd/0C4a<04i>CP1CDe<0E5AD05MGE`80FUYJ00h0GEeM069RHP1UIFD0IfMW06e]K@1^KVh0LG5a07Ee
M@1fMWH0Ng]k07emO@1nOWh0Ph>308F5Q@<0QhN70P28R8P03P27QhL0QHF508>3P`22PX80OWin07al
O01iNGT0M7Ad07=cL`1aLG40KFe]06UYJ@1VIVH0IFEU0P1OGel03@1MGEd0EeMG05ADE01DE5@0D51@
04e=C@1;Bd/0BDU904Q8B016ATH0ADE50492@P11@D400P0n?Sh01`0k>c/0?3`l03Ti>@0i>CT0>3Ph
03Hf=P0e=CD00P0d=3@01@0b<S80<30`02l_;`0`<300;bl_0080;Rh^00<0:b/[02d];@0/;2`00P0Z
:RX302TY:@0402LW9`0Y:BT09bLW02PX:0<09bLW0P0U9BD00`0T92@09RHV02DU9@0202@T900502<S
8`0R8R808b<S02<S8`0R8R800`0Q8B42028R8P03024Q8@0O7al0820P00@0820P0`0O7al201hN7P04
01lO7`0M7Ad07alO01dM7@D07QhN0P0L71`00`0N7Qh07AdM01`L700301dM7@0301`L700K6a/07AdM
00<07AdM0P0N7Qh00`0L71`07AdM01/K6`0201/K6`0301XJ6P0L71`06QXJ00D06a/K00L071`L01/K
6`0K6a/06ATI01`L700K6a/071`L00806a/K00<06QXJ01/K6`0K6a/00P0K6a/401XJ6P0401PH600J
6QX06QXJ01TI6@H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0301XJ6P0K
6a/06QXJ00<06QXJ00<06a/K01XJ6P0J6QX01P0K6a/01@0I6AT071`L01XJ6P0K6a/071`L00<06a/K
00L071`L01XJ6P0K6a/06a/K01XJ6P0K6a/071`L00<06a/K00@07AdM01`L700L71`071`L0P0K6a/0
0`0M7Ad071`L01`L700201`L700301/K6`0M7Ad071`L00807AdM00<071`L01/K6`0M7Ad0100M7Ad0
0`0N7Qh07AdM01lO7`0201hN7P09020P800O7al07alO01lO7`0P82007QhN020P800O7al0820P0080
7alO0`0P82000`0Q8B40820P020P8002020P80808B4Q0`0R8R80100U9BD08b<S02<S8`0S8b<2028R
8P8092@T00<09BDU02HV9P0U9BD00P0U9BD302HV9P80:2PX00<09bLW02TY:@0Y:BT00P0Y:BT01@0[
:b/0;2`/02/[:`0Z:RX0;Bd]0080;Rh^0`0_;bl00`0c<c<0<S8b03@d=00203De=@80=cLg0P0i>CT0
1@0j>SX0?Shn0410@00o?cl0@T920080ADE500l0B4Q804Y:BP1;Bd/0CDe=055AD@1BDU80EUIF05QH
F01KFe/0GEeM065QH@1UIFD0J6QX06][J`1^KVh00P1dM7@01@1kNg/0O7al08:2PP22PX80QXJ600<0
RXZ:0100Shn?08f=S@2=SHd0Rh^;08b<S02;Rh/0QhN708F5Q@21PH40P82007emO@1jNWX0MGEe079b
LP1`L700Jf][0P1VIVH0201RHV80GemO05iNGP1IFET0EeMG05EEE@1BDU80Cdm?0P1<C4`03`19BDT0
ATI604E5A@13@d<0@T920451@@0n?Sh0>c/k03`l?00j>SX0>3Ph03Lg=`0h>3P0=SHf03@d=00203<c
<`04034a<@0_;bl0<30`02l_;`80;Rh^00<0;Bd]02h^;P0[:b/00`0Z:RX01P0Y:BT0:2PX02PX:00Y
:BT0:2PX02HV9P809bLW00<09RHV02DU9@0V9RH00P0T92@0100S8b<092@T02@T900S8b<2028R8P03
02@T900S8b<08b<S00808R8R00<08B4Q028R8P0P82000P0Q8B46020P800301hN7P0O7al07alO00@0
7QhN0`0M7Ad01P0N7Qh07AdM01dM7@0M7Ad071`L01hN7P807AdM00L071`L01/K6`0L71`07AdM01`L
700M7Ad071`L00807AdM00@071`L01dM7@0L71`06QXJ0P0K6a/301`L70806a/K00H06QXJ01/K6`0K
6a/06QXJ01/K6`0J6QX201/K6`0301XJ6P0K6a/06a/K00D06a/K1P0J6QX00`0I6AT06QXJ01TI6@06
0=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT301XJ6P<06a/K00D06QXJ01/K
6`0K6a/06a/K01PH600201TI6@<06QXJ00@06a/K01XJ6P0K6a/06QXJ0P0K6a/201`L700301/K6`0J
6QX071`L008071`L0P0K6a/201`L70<06a/K00<06QXJ01/K6`0L71`0100L71`01`0M7Ad071`L01dM
7@0M7Ad071`L01dM7@0N7Qh00`0M7Ad01P0N7Qh07AdM01dM7@0M7Ad07alO01hN7P<07alO00<07QhN
01lO7`0N7Qh00P0O7al01`0P82007QhN01lO7`0N7Qh0820P024Q8@0O7al00`0Q8B400`0O7al08B4Q
024Q8@03028R8P808b<S00L08R8R02<S8`0S8b<08b<S02@T900U9BD09RHV008092@T0`0U9BD202HV
9P0302LW9`0V9RH0:2PX00809bLW0P0Y:BT03P0Z:RX0:BTY02XZ:P0Z:RX0;2`/02d];@0^;Rh0;bl_
02d];@0a<C40<30`034a<@0b<S80<c<c0`0e=CD0100h>3P0>CTi03Xj>P0k>c/303lo?`80@D5100D0
ATI604E5A@19BDT0BTY:04i>CP02059BDP0A05ADE01HF5P0Fe]K05mOG`1PH600IFEU06QXJ01[Jf/0
L71`07IfMP1kNg/0OGem0861P@27QhL0RHV908^;R`2>SXh00P2CTi<00`2EUID0UYJF09RHV00209VI
V@0709JFUP2EUID0Ti>C096AT@2;Rh/0RXZ:08F5Q@0207inOP0>07UiN@1cLg<0LG5a06e]K@1[Jf/0
IFEU06=SH`1NGUh0G5aL05YJFP1GEeL0De=C055AD@1>CTh204Y:BP0=04Q8B016ATH0A4A40492@P10
@400?Shn03dm?@0l?3`0>SXj03Ph>00g=cL0>3Ph03@d=00203<c<`0403@d=00a<C40<30`030`<080
;Rh^00D0;Bd]02`/;00/;2`0;Bd]02/[:`0302XZ:P0302TY:@0Z:RX0:BTY00@09bLW00@09RHV02@T
900U9BD09BDU0`0T92@01P0S8b<08R8R028R8P0R8R808b<S028R8P808B4Q00<08b<S024Q8@0R8R80
0P0P82000`0O7al08B4Q020P8002020P80D07alO0P0N7Qh01@0O7al07QhN01dM7@0M7Ad07QhN00@0
7AdM00L07alO01dM7@0M7Ad071`L01dM7@0K6a/07AdM008071`L00<06a/K01dM7@0M7Ad00`0L71`4
01/K6`0501XJ6P0K6a/071`L01`L700J6QX00P0L71`201/K6`0401XJ6P0K6a/06QXJ01XJ6PD06a/K
0`0J6QX01P0I6AT06QXJ01TI6@0K6a/06QXJ01TI6@<06QXJ1P3IfMT100000040fMWI000F0=WIf@03
0000003IfMT0fMWI00<0fMWI0P0K6a/201XJ6P0701/K6`0J6QX06QXJ01`L700J6QX06a/K01TI6@04
01XJ6P806a/K0P0L71`201XJ6P0501/K6`0L71`06a/K01`L700K6a/00P0J6QX00`0K6a/071`L01/K
6`0201`L700301/K6`0L71`06a/K00<06a/K00H071`L01/K6`0L71`07AdM01/K6`0M7Ad201hN7P@0
7AdM00D07QhN01dM7@0M7Ad07QhN01dM7@0301hN7P807alO00<0820P01lO7`0N7Qh00P0N7Qh0100O
7al0820P01lO7`0P820201lO7`80820P0P0Q8B43020P8003024Q8@0R8R808B4Q00808R8R00D08b<S
028R8P0Q8B408b<S02DU9@0202<S8`8092@T0P0V9RH202DU9@0302LW9`0V9RH09bLW00809bLW00H0
:2PX02LW9`0Y:BT0:RXZ02TY:@0Z:RX202/[:`0:02d];@0^;Rh0;Rh^02h^;P0_;bl0<30`02l_;`0`
<300<C4a038b<P80=3@d00`0=CDe03Lg=`0i>CT0>SXj03dm?@0l?3`0?clo0410@011@D40ADE504I6
AP17AdL204];B`0904m?C`1ADE40E5AD05IFEP1KFe/0GEeM065QH@1TI6@0J6QX0080LG5a00/0Lg=c
07UiN@1lO7`0PH6108J6QP2=SHd0T92@09BDU02KVi/0WIfM0:6QX@020:>SX`0:0:JVYP2UYJD0YZJV
0:FUY@2QXJ40WIfM09VIV@2EUID0Ti>C08j>SP80QXJ600H0Ogmo07YjNP1fMWH0LW9b06m_K`1ZJVX2
06=SH`0;05iNGP1LG5`0G5aL05IFEP1EEED0DE5A04i>CP1;Bd/0BDU904Q8B015ADD00P12@T801`10
@400?Cdm03`l?00k>c/0>SXj03Ti>@0g=cL00P0f=SH203<c<`0402l_;`0b<S80;bl_030`<080;bl_
0P0];Bd00`0/;2`0:b/[02TY:@0202TY:@0302XZ:P0Y:BT0:2PX0080:2PX00L09bLW02HV9P0U9BD0
9RHV02DU9@0T92@09BDU008092@T00H08b<S02@T900S8b<08R8R02<S8`0R8R8202<S8`05024Q8@0R
8R808R8R020P800Q8B400P0P8200100Q8B407alO01lO7`0P820201lO7`0401hN7P0P82007QhN01hN
7P807AdM00H07QhN01`L700N7Qh07AdM01hN7P0M7Ad201hN7P0501dM7@0N7Qh071`L01`L700M7Ad0
100L71`00`0M7Ad071`L01`L700201/K6`0401`L700K6a/071`L01`L70806a/K00D071`L01XJ6P0M
7Ad071`L01XJ6P0201`L70@06QXJ00<06a/K01XJ6P0K6a/00P0J6QX201/K6`0801`L700J6QX06QXJ
01`L700I6AT06QXJ01TI6@0J6QX201TI6@H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WI
f@030=WIf@0301XJ6P0I6AT06a/K00806QXJ0P0K6a/01@0J6QX06ATI01XJ6P0J6QX06a/K00806QXJ
1P0K6a/00`0J6QX06a/K01XJ6P0201/K6`0301XJ6P0K6a/06a/K00<06a/K00<071`L01/K6`0K6a/0
2`0L71`01`0M7Ad071`L01`L700N7Qh071`L01hN7P0M7Ad00P0L71`00`0N7Qh07AdM01dM7@0401hN
7P0401dM7@0O7al07QhN020P80807QhN100O7al01P0P82008B4Q01hN7P0P82008R8R01lO7`808B4Q
00<08R8R024Q8@0Q8B400P0R8R800`0Q8B408R8R02<S8`0302<S8`809BDU0P0T92@01@0U9BD092@T
02HV9P0U9BD09RHV00<09bLW0P0Y:BT00`0X:2P0:BTY02TY:@0302/[:`0402d];@0/;2`0;Bd]034a
<@80;bl_02`0<C4a038b<P0b<S80<c<c03De=@0f=SH0=cLg03Ti>@0h>3P0>SXj03dm?@0l?3`0?Shn
0492@P13@d<0A4A404Q8B019BDT0BTY:04a<C01ADE40E5AD05EEE@1JFUX0GEeM05mOG`1RHV80IVIV
06a/K01_Kfl0Lg=c07UiN@1nOWh0P82008F5Q@2>SXh0T92@09NGU`2HV9P0WYjN0:>SX`2XZ:P0ZJVY
0:^[Z`80[:b/01P0[jn_0:NWY`2WYjL0YZJV0:2PX02KVi/0V9RH09:BTP2:RXX0R8R808>3P`20P800
NGUi07EeM@1aLG40K6a/06QXJ01WIfL0HV9R05iNGP1MGEd0F5QH05EEE@1CDe<204e=C@0404U9B@17
AdL0A4A404=3@`80@D5100<0?Shn03`l?00j>SX00P0i>CT0200h>3P0=SHf03@d=00e=CD0<c<c034a
<@0`<300;bl_0P0a<C40100];Bd0;Rh^02d];@0[:b/202`/;00302XZ:P0[:b/0:BTY0080:BTY0P0X
:2P202LW9`0502HV9P0U9BD09BDU02DU9@0S8b<0100T92@202<S8`<08R8R00<08B4Q028R8P0Q8B40
0P0Q8B42020P800401lO7`0P8200820P01lO7`807QhN00D07alO01hN7P0N7Qh07AdM01hN7P0201lO
7`0801dM7@0N7Qh07AdM01hN7P0M7Ad07QhN01`L700N7Qh201`L700401dM7@0N7Qh07AdM01dM7@80
71`L00@07AdM01`L700L71`07AdM0P0K6a/0300L71`06a/K01`L700K6a/071`L01XJ6P0K6a/06QXJ
01/K6`0L71`06a/K01`L70806a/K0P0J6QX01P0K6a/06QXJ01XJ6P0I6AT071`L01/K6`@06QXJ00<0
6a/K01XJ6P0J6QX00P0J6QX201/K6`0301TI6@3IfMT0fMWI00@0fMWI0@0000010=WIf@005P3IfMT0
0`000000fMWI0=WIf@030=WIf@0301XJ6P0I6AT06QXJ00<06QXJ0`0K6a/00`0J6QX06a/K01TI6@02
01XJ6P0601/K6`0I6AT071`L01`L700J6QX071`L1@0K6a/01@0L71`06a/K01XJ6P0J6QX071`L00<0
6a/K00@071`L01/K6`0K6a/06a/K0P0L71`01P0M7Ad071`L01`L700L71`07AdM01hN7P@07AdM00D0
71`L01hN7P0N7Qh07AdM01hN7P0401dM7@807QhN0`0O7al00`0N7Qh07alO020P800301lO7`05024Q
8@0P8200820P020P800O7al0100P82000`0Q8B40820P020P8002020P8003028R8P0S8b<092@T0080
8R8R0`0S8b<01@0U9BD09RHV02@T900V9RH09BDU00@09bLW00@09RHV02PX:00X:2P0:BTY0`0Z:RX2
02/[:`0302d];@0/;2`0;Bd]0080;Rh^00L0;bl_034a<@0b<S80<30`038b<P0c<c<0=3@d0080=SHf
00T0>CTi03/k>`0j>SX0?3`l03dm?@10@400@d=304E5A@16ATH00P19BDT0201<C4`0CDe=055AD@1E
EED0EUIF05]KF`1PH600Hf=S0P1XJ6P04@1aLG40M7Ad07QhN01nOWh0Q8B408J6QP2?Shl0Ti>C09ZJ
VP2SXj<0YZJV0:f][@2`/;00/[:b0;Jf]P2i^KT0_;bl0080^[Zj01/0]kNg0;Bd]02`/;00[Zj^0:>S
X`2QXJ40Vi^K09NGU`2=SHd0R8R808F5Q@21PH40NWYj07QhN01bLW80KFe]06][J`1XJ6P0IfMW069R
HP1NGUh0Fe]K05EEE@1ADE40Cdm?04];B`1:BTX00P15ADD02@13@d<0@T9203hn?P0n?Sh0>c/k03Ti
>@0j>SX0>3Ph03Hf=P0203@d=00303<c<`0a<C40<30`0080<30`0P0^;Rh01`0];Bd0;Rh^02`/;00[
:b/0:RXZ02PX:00[:b/00`0X:2P0100Z:RX09bLW02PX:00U9BD302HV9P0302DU9@0T92@09BDU0080
9BDU0P0T92@302<S8`<08B4Q00<08R8R024Q8@0R8R800P0Q8B43020P800401lO7`0P82007alO01lO
7`L07QhN00<07alO01dM7@0N7Qh01@0M7Ad01`0L71`07AdM01hN7P0M7Ad06a/K01`L700N7Qh00`0L
71`00`0K6a/071`L01dM7@0401`L70806a/K00<06QXJ01/K6`0K6a/00P0J6QX301/K6`0301XJ6P0K
6a/06QXJ00806QXJ00@06a/K01XJ6P0K6a/06QXJ0P0K6a/301TI6@0601XJ6P0I6AT06a/K01XJ6P0I
6AT06QXJ1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI100J6QX201/K6`H0
6QXJ00@06ATI01XJ6P0K6a/06QXJ0`0K6a/01@0J6QX06a/K01XJ6P0K6a/06QXJ00<06a/K00H071`L
01/K6`0K6a/06QXJ01`L700K6a/401`L700401/K6`0L71`06a/K01`L70807AdM00`071`L01hN7P0M
7Ad07AdM01/K6`0O7al07QhN01dM7@0N7Qh07AdM01hN7P0M7Ad501hN7P0601lO7`0M7Ad07QhN01hN
7P0P82007AdM0P0P82001P0Q8B40820P020P800Q8B40820P024Q8@807alO0P0P8202024Q8@03028R
8P0Q8B408R8R00<08R8R0P0S8b<302@T90809BDU0P0V9RH0100U9BD09bLW02DU9@0X:2P202LW9`<0
:2PX00D0:BTY02XZ:P0Z:RX0;2`/02/[:`0202d];@0402l_;`0];Bd0;bl_02l_;`80<30`0P0b<S82
03<c<`0803De=@0f=SH0>3Ph03Xj>P0k>c/0?Shn03lo?`10@40204=3@`0A04Q8B017AdL0BDU904i>
CP1ADE40DU9B05ADE01HF5P0G5aL065QH@1TI6@0J6QX06][J`1aLG40N7Qh07YjNP20P8000P2:RXX0
1P2DU9@0WIfM0:6QX@2WYjL0ZZZZ0;6a/@80^[Zj00@0`<300<;2`P33`l<0aLG50P30`<001P2j^[X0
^k^k0;>c/`2/[:`0Z:RX0:6QX@80U9BD00L0S8b<08V9R@22PX80Ogmo07UiN@1eMGD0L71`0080Jf][
00X0JFUY06IVIP1PH600GUiN05MGE`1ADE40Cdm?04a<C01:BTX0AdM70P14A4@01@13@d<0?clo03dm
?@0l?3`0>SXj0080=cLg00<0=SHf03Lg=`0c<c<00`0b<S83030`<0@0;Bd]00D0:RXZ02`/;00[:b/0
:BTY02XZ:P0402PX:00602LW9`0V9RH09RHV02LW9`0U9BD09RHV0P0T92@202DU9@808b<S00@08R8R
02<S8`0R8R808B4Q0P0R8R80100S8b<08R8R024Q8@0Q8B42020P800601lO7`0P8200820P01hN7P0P
82007alO0`0N7Qh00`0O7al07AdM01hN7P0201dM7@@07QhN00L07AdM01hN7P0N7Qh07QhN01lO7`0L
71`07AdM00<071`L00H06a/K01dM7@0L71`06a/K01dM7@0L71`201/K6`0301`L700K6a/06QXJ00@0
6a/K00<06ATI01XJ6P0K6a/00`0K6a/301XJ6P0301TI6@0J6QX06a/K00806QXJ00<06ATI01XJ6P0K
6a/00P0J6QX01P0I6AT061PH01XJ6P0J6QX06ATI01XJ6PH0fMWI0@0000010=WIf@005P3IfMT20000
00@0fMWI0P0K6a/00`0J6QX06a/K01/K6`0201XJ6P806a/K100J6QX0100I6AT06QXJ01XJ6P0L71`4
01/K6`0301XJ6P0K6a/06QXJ00806QXJ0P0K6a/01P0L71`06a/K01/K6`0J6QX07AdM01`L70<06a/K
00H071`L01/K6`0K6a/071`L01/K6`0L71`201dM7@0301hN7P0M7Ad07AdM008071`L00P07AdM01hN
7P0N7Qh07QhN01dM7@0O7al07AdM01lO7`P07QhN00@07alO020P800O7al08B4Q0P0P82000`0Q8B40
7alO024Q8@02020P80@08B4Q00<08R8R02<S8`0S8b<00P0R8R802@0T92@08b<S02<S8`0T92@09BDU
02HV9P0U9BD09RHV02DU9@0202HV9P0302DU9@0W9bL09bLW00809bLW0P0Y:BT202XZ:P0402TY:@0[
:b/0:b/[02/[:`80;2`/00<0;Rh^034a<@0a<C400P0a<C4303@d=00403Hf=P0e=CD0>3Ph03Xj>P80
>c/k00<0?clo0410@011@D400P13@d<06@17AdL0BDU904e=C@1>CTh0DE5A05ADE01FEUH0G5aL061P
H01UIFD0IfMW06YZJP1aLG40Lg=c07YjNP20P800QhN708n?S`2CTi<0VIVI0:JVYP2YZJT0/[:b0;Fe
]@31`L400P3;bl/08@3?cll0d];B0=KFeP3De=@0dm?C0=;BdP39bLT0a/K60<30`02h^;P0];Bd0:RX
Z02QXJ40VIVI09JFUP2CTi<0RHV908>3P`21PH40O7al07UiN@1gMgL0M7Ad075aL@1]KFd0IfMW065Q
H@1JFUX0EEEE05=CD`1>CTh0CDe=04M7A`0204I6AP0;0451@@10@400?clo03`l?00k>c/0>SXj03Ph
>00f=SH0=cLg03Hf=P0d=3@00P0b<S83030`<00302l_;`0^;Rh0;Rh^0080;2`/0`0Z:RX302TY:@03
02PX:00V9RH0:2PX00809RHV00<09BDU02HV9P0U9BD00`0T92@202<S8`0402@T900R8R808b<S028R
8P808B4Q0P0R8R80100P82008B4Q020P800Q8B4201lO7`06020P800Q8B407alO020P800O7al07QhN
0P0O7al401hN7P0301lO7`0N7Qh07QhN00<07AdM00L07QhN01dM7@0M7Ad07QhN01`L700M7Ad06a/K
008071`L00<07AdM01`L700L71`00P0L71`0100M7Ad071`L01`L700K6a/301`L70806a/K00<06QXJ
01`L700L71`01P0K6a/201XJ6P0;01/K6`0J6QX06QXJ01/K6`0J6QX06a/K01XJ6P0I6AT06QXJ01/K
6`0I6AT00P0J6QX00`0I6AT061PH0=WIf@040=WIf@8000000@3IfMT001H0fMWI00<000000=WIf@3I
fMT00`3IfMT201/K6`0801`L700K6a/06ATI01XJ6P0I6AT06a/K01XJ6P0K6a/201XJ6P0301/K6`0J
6QX06QXJ00H06a/K00D06QXJ01/K6`0K6a/071`L01XJ6P0201/K6`0401`L700J6QX071`L01XJ6P80
71`L00/06a/K01`L700M7Ad071`L01/K6`0L71`06a/K01hN7P0L71`07AdM01`L700601dM7@0301hN
7P0O7al07AdM00807AdM00<07alO01hN7P0N7Qh0100N7Qh201lO7`0301hN7P0O7al07alO00@0820P
00<07QhN020P800R8R800P0P8204024Q8@<08R8R0P0S8b<01`0R8R808b<S02@T900S8b<092@T02DU
9@0V9RH00P0U9BD01`0V9RH09bLW02HV9P0V9RH09bLW02HV9P0X:2P00P0Y:BT302XZ:P80;2`/0`0]
;Bd202l_;`@0<S8b00<0<c<c03Lg=`0e=CD00P0h>3P0200i>CT0?3`l03`l?00n?Sh0@T920410@014
A4@0ATI60P18B4P07@1<C4`0D51@05ADE01DE5@0FEUI05YJFP1PH600IFEU06QXJ01^KVh0Kfm_07Yj
NP1oOgl0PX:208j>SP2FUYH0Vi^K0:>SX`2a/K40];Bd0;bl_033`l<0c/k>0=SHf03Lg=`0iNGU0>OW
i`3[jn/0j>SX0080iNGU01/0g=cL0=KFeP3>c/h0a<C40;bl_02e]KD0[:b/0:JVYP2MWId0W9bL09NG
U`2CTi<0SXj>08^;R`26QXH0PX:207emO@1lO7`0MgMg06QXJ01SHf<0Fe]K05MGE`1CDe<0DE5A04i>
CP1:BTX00P16ATH01P12@T80@41003lo?`0l?3`0>c/k03Xj>P80>3Ph00P0=SHf03@d=00b<S80=3@d
030`<00a<C40<30`02l_;`80;Rh^0P0];Bd0100/;2`0:b/[02XZ:P0Z:RX402TY:@0802LW9`0V9RH0
9RHV02LW9`0U9BD08b<S02HV9P0U9BD202@T900402DU9@0T92@08R8R02<S8`<08R8R0P0Q8B40100R
8R808B4Q024Q8@0Q8B42020P8004024Q8@0O7al0820P020P80807alO00L07QhN01lO7`0M7Ad07alO
01dM7@0N7Qh07alO00807QhN00H07AdM01hN7P0M7Ad07AdM01`L700M7Ad201hN7P807AdM00@06a/K
01dM7@0M7Ad07AdM0P0K6a/01@0L71`06a/K01/K6`0M7Ad071`L00806a/K0P0L71`01`0J6QX06ATI
01/K6`0K6a/071`L01/K6`0J6QX00P0K6a/00`0L71`06QXJ01XJ6P0201/K6`0501`L700J6QX06QXJ
01XJ6P0K6a/01@0J6QX0100I6AT06a/K01XJ6P0J6QX60=WIf@4000000@3IfMT001H0fMWI00<00000
0=WIf@3IfMT00`3IfMT01`0J6QX061PH01XJ6P0K6a/06ATI01XJ6P0K6a/0100J6QX201/K6`806QXJ
00<06a/K01TI6@0L71`00P0K6a/401XJ6P0401/K6`0L71`06QXJ01`L70@06a/K00<071`L01/K6`0L
71`01P0L71`01@0K6a/07AdM01`L700M7Ad071`L00<07AdM00@07QhN01dM7@0M7Ad07AdM1@0N7Qh0
0`0P82007AdM01hN7P0201hN7P807alO00@07QhN020P800O7al07alO100P82001@0Q8B407alO024Q
8@0Q8B40820P00808R8R00<08B4Q028R8P0R8R800`0R8R801@0S8b<092@T02<S8`0T92@09BDU0080
9RHV00P092@T02DU9@0V9RH09RHV02LW9`0V9RH0:2PX02LW9`<0:2PX0P0Y:BT01@0[:b/0;2`/02`/
;00[:b/0;Bd]0080;Rh^00H0<30`034a<@0c<c<0<S8b03<c<`0d=3@203De=@0803Ph>00g=cL0>c/k
03/k>`0n?Sh0@41003lo?`11@D4204A4A00[04I6AP1<C4`0CDe=051@D01CDe<0E5AD05]KF`1MGEd0
HV9R06MWI`1[Jf/0Kfm_075aL@1iNGT0PH6108F5Q@2=SHd0V9RH09jNWP2XZ:P0/[:b0;Zj^P36a/H0
c<c<0=KFeP3QhN40i^KV0>[ZjP3clo<0mOGe0??cl`3dm?@0jn_[0>SXj03Shn<0eMGE0<c<c034a<@0
^k^k0;2`/02/[:`0XZ:R09nOW`0209VIV@0<09ZJVP2FUYH0T92@08Z:RP26QXH0PX:207MgM`1YJFT0
HV9R05]KF`1DE5@0DU9B0P1>CTh0101:BTX0B4Q804M7A`12@T8203hn?P0=03dm?@0j>SX0>SXj03Ph
>00g=cL0=CDe03Hf=P0c<c<0<S8b03<c<`0a<C40<30`034a<@0302h^;P80;2`/00@0;Bd]02TY:@0Y
:BT0:BTY1@0X:2P00`0V9RH09bLW02LW9`0302DU9@8092@T00L08b<S02@T900T92@08b<S028R8P0S
8b<092@T00808B4Q1@0P8202024Q8@03020P800O7al08B4Q0080820P00@07alO01hN7P0N7Qh07alO
0P0N7Qh01P0M7Ad07alO01dM7@0M7Ad07QhN01lO7`807AdM00<07QhN01`L700L71`00P0M7Ad201/K
6`0701dM7@0K6a/07AdM01dM7@0K6a/071`L01dM7@0201XJ6P0=01`L700K6a/071`L01/K6`0L71`0
6ATI01/K6`0L71`06QXJ01/K6`0J6QX06a/K01TI6@0301/K6`D06QXJ0P0I6AT00`0J6QX06a/K01/K
6`0201XJ6P806ATI00<06QXJ01TI6@3IfMT01@3IfMT100000040fMWI000F0=WIf@030000003IfMT0
fMWI00<0fMWI100J6QX201TI6@806QXJ00H06a/K01XJ6P0J6QX06a/K01TI6@0K6a/201XJ6P0301/K
6`0J6QX071`L00806a/K0P0J6QX0100K6a/06QXJ01`L700J6QX201/K6`0301`L700K6a/06a/K0080
6a/K00<071`L01/K6`0K6a/0100L71`301dM7@0301`L700K6a/07QhN00@07AdM0P0N7Qh201dM7@80
7alO100N7Qh201lO7`0601hN7P0O7al07QhN01lO7`0P82007AdM0`0O7al2020P8005028R8P0Q8B40
8B4Q020P800Q8B400P0R8R80100Q8B408R8R02<S8`0R8R8302<S8`0602@T900S8b<092@T02@T900U
9BD092@T0P0V9RH01`0U9BD09RHV02DU9@0W9bL0:BTY02PX:00Y:BT00P0Z:RX0100[:b/0:RXZ02/[
:`0[:b/202`/;00:02d];@0`<300<30`034a<@0`<300<C4a03@d=00e=CD0=SHf03De=@80>3Ph00T0
>c/k03`l?00n?Sh0?clo0410@013@d<0ATI604A4A019BDT00P1=CDd01P1DE5@0DU9B05MGE`1LG5`0
Fe]K06ATI080JVYZ0100Lg=c07AdM01lO7`0Q8B408R8R02CTi<0WinO0::RXP2`/;00_kno0<;2`P3E
eMD0fm_K0>WYj@3dm?@0nOWi1P3oool0603hn?P0l_;b0>WYj@3Hf=P0e=CD0<C4a02k^k/0]KFe0:n_
[`2[Zj/0[:b/0;6a/@2`/;00[:b/09jNWP2BTY80Q8B407emO@1`L700IfMW069RHP1HF5P0EEEE055A
D@80CDe=00T0B4Q804M7A`14A4@0@d=30410@00n?Sh0?3`l03/k>`0j>SX00P0h>3P01P0f=SH0=CDe
03De=@0c<c<0<C4a03<c<`80<30`00L0;bl_02h^;P0^;Rh0;2`/02/[:`0/;2`0:RXZ0080:BTY00L0
:RXZ02TY:@0X:2P09bLW02HV9P0W9bL09RHV00809BDU0P0V9RH00`0T92@09BDU02<S8`03028R8P80
8b<S00@0820P028R8P0Q8B408B4Q0P0R8R80100P82008B4Q01lO7`0R8R82020P80<07alO0P0N7Qh6
01lO7`0801dM7@0N7Qh07AdM01hN7P0M7Ad07QhN01dM7@0L71`301dM7@@071`L00<07AdM01`L700K
6a/00`0K6a/00`0M7Ad071`L01`L700201/K6`0301XJ6P0K6a/06QXJ00<06a/K100J6QX01`0L71`0
6QXJ01/K6`0K6a/06QXJ01TI6@0J6QX00`0K6a/00`0J6QX06a/K01/K6`0201XJ6P0301/K6`0J6QX0
6ATI00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@@06QXJ00H06ATI01/K
6`0J6QX06a/K01XJ6P0I6AT201XJ6P0701/K6`0J6QX06a/K01/K6`0M7Ad06a/K01XJ6P0401/K6`04
01XJ6P0L71`06a/K01/K6`<071`L100K6a/201`L700501dM7@0L71`071`L01`L700M7Ad00P0L71`2
01/K6`8071`L00<07AdM01`L700L71`0100N7Qh00`0O7al07QhN01lO7`0201hN7P807alO0P0P8205
01lO7`0301hN7P0P8200820P00807alO00<08B4Q020P800Q8B400P0Q8B42020P80808B4Q00X08R8R
020P800R8R808B4Q02DU9@0S8b<092@T02<S8`0U9BD092@T0`0U9BD202HV9P0402DU9@0W9bL09bLW
02HV9P<0:BTY00@0:RXZ02`/;00[:b/0:RXZ0P0/;2`0200^;Rh0;Bd]02l_;`0a<C40<30`034a<@0b
<S80<c<c0P0f=SH0900g=cL0>CTi03Lg=`0k>c/0?3`l03hn?P0o?cl0@T9204A4A015ADD0AdM704Y:
BP1>CTh0DE5A05=CD`1EEED0FEUI05eMG@1OGel0Hf=S06YZJP1]KFd0Lg=c07EeM@1oOgl0R8R808n?
S`2GUiL0YJFU0:f][@2j^[X0alO70=3@d03Ph>00k>c/0?Shn0X0oooo01`0mOGe0>OWi`3Rh^80d];B
0<K6aP31`L40^;Rh0;^k^`2m_Kd0a<C40<71`@2a/K40W9bL08n?S`1mOGd0Lg=c06][J`1RHV80GemO
05QHF01EEED0DU9B04e=C@1<C4`0B4Q804M7A`15ADD0@d=30P10@400100m?Cd0>c/k03/k>`0i>CT2
03Lg=`0303Hf=P0e=CD0=3@d0080<C4a00D0;bl_034a<@0^;Rh0;bl_02d];@0202`/;00302XZ:P0[
:b/0:BTY0080:2PX00<0:BTY02PX:00W9bL00`0W9bL00`0V9RH09bLW02DU9@0202DU9@0302@T900S
8b<092@T00@08b<S0P0R8R83024Q8@0301lO7`0R8R808B4Q0080820P00@08B4Q020P800P82007alO
0P0P82000`0N7Qh07alO01lO7`0201hN7P0401lO7`0M7Ad07alO01hN7P807AdM00D07QhN01dM7@0M
7Ad07AdM01hN7P0501`L700401/K6`0L71`06a/K01`L70806a/K00@071`L01/K6`0J6QX071`L0`0K
6a/00`0J6QX06a/K01/K6`0201`L700301TI6@0J6QX071`L00@06QXJ0P0I6AT201/K6`806QXJ0P0K
6a/201TI6@<06QXJ00<06ATI01XJ6P3IfMT01@3IfMT100000040fMWI000F0=WIf@030000003IfMT0
fMWI00<0fMWI00@06a/K01XJ6P0J6QX06QXJ0P0K6a/00`0J6QX06a/K01TI6@0201XJ6P806a/K0`0J
6QX201/K6`0601`L700K6a/06QXJ01hN7P0K6a/06QXJ0P0L71`00`0K6a/071`L01`L700201/K6`80
71`L0P0K6a/00`0L71`06a/K01`L700201`L70<07AdM0P0L71`00`0M7Ad071`L01hN7P0201`L7080
7AdM0P0N7Qh01P0M7Ad07QhN01dM7@0N7Qh07AdM01hN7P<07alO00<07QhN01lO7`0O7al00P0P8200
1@0O7al08B4Q020P800P82007alO00D0820P0P0R8R801@0Q8B408b<S028R8P0S8b<08R8R00<08b<S
0`0T92@202DU9@0602HV9P0W9bL09RHV02HV9P0W9bL09RHV100X:2P0400Z:RX0:b/[02XZ:P0[:b/0
;Bd]02`/;00];Bd0;Rh^02d];@0^;Rh0<C4a030`<00c<c<0<S8b03<c<`0d=3@203De=@0503Ti>@0h
>3P0?3`l03/k>`0o?cl00P10@4007014A4@0AdM704I6AP1;Bd/0CTi>059BDP1EEED0De=C05]KF`1O
Gel0H61P06EUI@1/K6`0L71`07EeM@1gMgL0PH6108V9R@2ATI40VYZJ0:b/[02a/K40`/;20<g=c@3D
e=@0j>SX0>k^kP3moOd:0?ooo`0O0?knoP3_knl0inOW0=WIf@38b<P0a<C40;no_`30`<00`L710<G5
a@30`<00[Jf]09BDU02;Rh/0N7Qh07EeM@1YJFT0Hf=S065QH@1IFET0E5AD059BDP1>CTh0Cdm?04Y:
BP17AdL0ADE504=3@`10@400?clo03`l?00203/k>`80>CTi00H0=cLg03De=@0d=3@0<C4a03<c<`0b
<S8302l_;`0502h^;P0];Bd0:b/[02XZ:P0/;2`00`0Z:RX00`0Y:BT0:2PX02PX:00202LW9`0302DU
9@0V9RH09BDU00809RHV00@09BDU02@T900T92@08b<S0P0T92@5028R8P03024Q8@0R8R808B4Q00<0
820P00@08B4Q01lO7`0P8200820P0P0O7al01`0N7Qh0820P01lO7`0N7Qh07alO01dM7@0N7Qh00P0M
7Ad501hN7P0401dM7@0N7Qh07QhN01lO7`<07AdM00<071`L01dM7@0L71`0100L71`00`0M7Ad071`L
01/K6`0201/K6`0401`L700K6a/06a/K01XJ6P806a/K00<06QXJ01/K6`0J6QX00P0J6QX501/K6`80
6QXJ00@06a/K01PH600K6a/061PH0P0I6AT01P0J6QX06ATI01XJ6P0I6AT06QXJ01TI6@H0fMWI0@00
00010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0301/K6`0J6QX06QXJ00806a/K00D06QXJ
01/K6`0J6QX06a/K01XJ6P0201/K6`0301XJ6P0K6a/06QXJ00D06a/K00@071`L01/K6`0L71`071`L
0`0K6a/00`0L71`06a/K01/K6`0301/K6`0301dM7@0L71`07AdM00807AdM1@0L71`00`0N7Qh071`L
01`L700:01dM7@0501hN7P0O7al07QhN01hN7P0O7al00P0N7Qh00`0P82007alO020P800301lO7`0?
020P800O7al0820P020P800Q8B40820P024Q8@0O7al0820P024Q8@0P82008R8R02<S8`0R8R808b<S
00808R8R00L092@T028R8P0T92@092@T02DU9@0S8b<09BDU00809RHV00<09bLW02HV9P0W9bL00`0V
9RH01@0W9bL0:BTY02TY:@0[:b/0:BTY0080:b/[00X0;2`/02d];@0^;Rh0;Rh^030`<00a<C40<30`
03<c<`0b<S80<c<c0`0e=CD203Ti>@0603/k>`0n?Sh0?3`l03lo?`12@T80A4A40P17AdL0601;Bd/0
Cdm?059BDP1EEED0EeMG05QHF01NGUh0HF5Q06QXJ01^KVh0LG5a07QhN01lO7`0QHF508^;R`2ATI40
WIfM0:j^[P2d];@0a/K60=KFeP3MgMd0lO7a0?[jnP`0oooo01`0nOWi0??cl`3QhN40e=CD0<c<c032
`/80_Kfm0;Vi^@2g]kL0[:b/09VIV@2:RXX0PX:207IfMP1`L700J6QX065QH@1OGel0FUYJ05IFEP1C
De<0D51@04i>CP1:BTX0AdM704A4A013@d<0@D510P0o?cl0100l?3`0>SXj03Ph>00f=SH203Lg=`03
03De=@0c<c<0<c<c0080<30`00@0<C4a02l_;`0^;Rh0;Bd]0P0/;2`202/[:`0302TY:@0Z:RX0:BTY
00D0:2PX00<09bLW02HV9P0U9BD00P0U9BD00`0T92@09BDU02@T900402<S8`09028R8P0S8b<08R8R
024Q8@0S8b<08B4Q028R8P0Q8B408R8R00<0820P00<08B4Q020P800P82001@0O7al0100M7Ad07QhN
01lO7`0M7Ad301hN7P807AdM0P0N7Qh01@0L71`07AdM01dM7@0L71`07AdM00@071`L00<07AdM01`L
700L71`01P0L71`201/K6`0401`L700J6QX06a/K01XJ6P<06a/K00D06QXJ01/K6`0J6QX06QXJ01/K
6`0301XJ6P0601/K6`0J6QX06QXJ01XJ6P0K6a/071`L0P0J6QX0100I6AT06QXJ01XJ6P0J6QX60=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0100J6QX06a/K01XJ6P0I6AT201XJ
6P806a/K1@0J6QX0100I6AT06QXJ01/K6`0K6a/201XJ6P806a/K00H071`L01/K6`0L71`06a/K01`L
700M7Ad201/K6`0301`L700J6QX071`L00<071`L00D07AdM01`L700M7Ad07QhN01dM7@0201`L7004
01/K6`0M7Ad071`L01/K6`807AdM00@071`L01dM7@0M7Ad07AdM0P0N7Qh201dM7@807QhN00P07AdM
01lO7`0N7Qh07QhN01lO7`0N7Qh07alO01hN7P807alO0P0P82002P0O7al08B4Q020P800P82008B4Q
028R8P0P82008B4Q028R8P0S8b<2024Q8@05028R8P0S8b<08b<S02@T900S8b<01P0T92@0100U9BD0
9bLW02LW9`0V9RH402LW9`0302PX:00Z:RX0:BTY0080:b/[00D0:RXZ02/[:`0/;2`0;Bd]02h^;P02
02l_;`05034a<@0`<300<S8b038b<P0d=3@00P0e=CD203Lg=`0403Xj>P0m?Cd0?Shn03lo?`80@T92
00@0@d=304I6AP18B4P0Bd];0P1ADE4205=CD`0B05]KF`1OGel0I6AT06YZJP1`L700M7Ad07UiN@1k
Ng/0PX:208j>SP2CTi<0WinO0:j^[P2h^;P0alO70=_Kf`3Shn<0mOGe3P3oool05`3kno/0i^KV0=KF
eP3=cLd0`/;20;^k^`2g]kL0[Jf]0:>SX`2DU9@0Ph>307alO01eMGD0Kfm_06YZJP1RHV80H61P05UI
F@1FEUH0De=C055AD@1>CTh0Bd];0080AdM700<0@d=30451@@10@4000P0m?Cd0100k>c/0>3Ph03Ph
>00g=cL303@d=080<c<c00<0;bl_030`<00^;Rh0100];Bd0100[:b/0:BTY02XZ:P0Z:RX202TY:@08
02PX:00W9bL09bLW02LW9`0U9BD09RHV02@T900U9BD702@T90808R8R1@0Q8B44020P80807alO0P0P
820401lO7`07020P800N7Qh07QhN01hN7P0M7Ad07QhN01dM7@0301hN7P0301dM7@0N7Qh071`L00<0
7AdM00@07QhN01dM7@0L71`07AdM0P0L71`0100M7Ad071`L01`L700L71`401/K6`8071`L00<06a/K
01XJ6P0K6a/00P0K6a/0100L71`06QXJ01XJ6P0K6a/201`L700301/K6`0J6QX06a/K00806a/K00@0
6QXJ01/K6`0J6QX06a/K200J6QX60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3I
fMT201XJ6P806ATI00@06QXJ01/K6`0J6QX06ATI0P0K6a/00`0J6QX06a/K01/K6`0201/K6`0301XJ
6P0L71`06a/K00806a/K0P0L71`00`0K6a/07AdM01`L700201/K6`0301`L700K6a/06a/K008071`L
00<07AdM01`L700L71`00`0M7Ad00`0L71`07AdM01/K6`0:01`L70807QhN00<071`L01hN7P0N7Qh0
1P0N7Qh501lO7`03020P800O7al07alO00807alO0`0P8200200Q8B40820P028R8P0Q8B40820P028R
8P0S8b<08R8R0P0S8b<02P0R8R8092@T02<S8`0S8b<09BDU02@T900U9BD092@T02DU9@0W9bL202HV
9P<09bLW00H0:RXZ02TY:@0Z:RX0:BTY02XZ:P0[:b/202XZ:P80;2`/00D0;Rh^02l_;`0_;bl0<30`
034a<@02038b<P0403@d=00e=CD0=SHf03Ph>080>CTi01l0>SXj03lo?`0o?cl0@4100492@P14A4@0
B4Q804U9B@1<C4`0Cdm?055AD@1EEED0EUIF05YJFP1PH600Hf=S06UYJ@1_Kfl0LW9b07YjNP22PX80
QhN708n?S`2GUiL0X:2P0;2`/02j^[X0c<c<0=gMg@3Zj^X0o_kn00l0oooo01<0k>c/0=OGe`3?cll0
_kno0;Vi^@2][Jd0WinO09NGU`2<S8`0Ph>307emO@1bLW80Kfm_06MWI`1RHV80GemO05YJFP1FEUH0
E5AD0080D51@00@0Bd];04U9B@15ADD0A4A40P11@D400`0o?cl0?3`l03/k>`0203Ti>@0403Ph>00f
=SH0=3@d03<c<`80<S8b00H0<C4a02h^;P0_;bl0;Rh^02l_;`0[:b/202`/;0<0:b/[00d0:BTY02XZ
:P0Y:BT0:2PX02TY:@0W9bL09RHV02DU9@0V9RH092@T02DU9@0T92@08b<S00<092@T00<08R8R02<S
8`0R8R800`0R8R80200Q8B408R8R028R8P0Q8B40820P028R8P0Q8B40820P0P0Q8B400`0P82007alO
01hN7P0301lO7`0301dM7@0N7Qh07alO00<07AdM00H071`L01hN7P0M7Ad07QhN01dM7@0L71`201dM
7@0501`L700M7Ad071`L01/K6`0L71`01@0K6a/0100L71`06a/K01/K6`0L71`301/K6`0701dM7@0L
71`06QXJ01/K6`0L71`06a/K01XJ6P0301`L70D06a/K00<06QXJ01/K6`0I6AT00P0K6a/201XJ6P05
01TI6@0J6QX06QXJ01TI6@0J6QX01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0
fMWI00<06QXJ01/K6`0K6a/00P0J6QX0200L71`06QXJ01XJ6P0J6QX06ATI01XJ6P0K6a/06QXJ0P0K
6a/01@0J6QX06a/K01`L700L71`06a/K00D071`L00D06a/K01dM7@0K6a/071`L01dM7@0401/K6`04
01dM7@0N7Qh07QhN01dM7@8071`L00<06a/K01`L700M7Ad00P0M7Ad01@0L71`07AdM01dM7@0M7Ad0
71`L00807QhN00X07AdM01hN7P0L71`07AdM01hN7P0M7Ad07alO01hN7P0P82007alO100N7Qh201lO
7`0301hN7P0O7al07alO0080820P00<08B4Q028R8P0Q8B400P0P82000`0Q8B408R8R024Q8@03028R
8P0602@T900R8R808R8R028R8P0S8b<092@T0P0U9BD0100S8b<09BDU02HV9P0V9RH302LW9`0402PX
:00W9bL0:2PX02PX:080:RXZ00D0;2`/02/[:`0/;2`0;2`/02/[:`0202d];@0D030`<00b<S80<S8b
03<c<`0b<S80=3@d03De=@0f=SH0=CDe03Ti>@0j>SX0>c/k03dm?@0n?Sh0@D510492@P14A4@0ATI6
04U9B@1;Bd/2055AD@0305ADE01FEUH0FEUI0080HF5Q00h0J6QX075aL@1cLg<0NWYj07moO`29RHT0
Shn?09BDU02UYJD0/k>c0;no_`3<c<`0hN7Q0>o_ka00oooo01H0kNg]0=WIf@3>c/h0_;bl0;Jf]P2W
YjL0W9bL09NGU`28R8P0O7al07UiN@1cLg<0Kfm_06QXJ01SHf<0GemO05aLG01EEED0DU9B04i>CP1?
Cdl0C4a<0P18B4P03P15ADD0@T920410@00m?Cd0>c/k03Xj>P0i>CT0>3Ph03Lg=`0f=SH0=CDe03@d
=00c<c<0<C4a0P0_;bl0200`<300;Rh^02h^;P0^;Rh0:b/[02`/;00[:b/0:RXZ0`0Y:BT202PX:006
02HV9P0W9bL09bLW02HV9P0T92@09RHV0P0T92@202<S8`0302@T900S8b<08b<S00808R8R00<08B4Q
028R8P0R8R800P0Q8B40100R8R808B4Q024Q8@0O7al2020P8006024Q8@0O7al07alO020P800Q8B40
7alO1@0N7Qh201`L700401dM7@0N7Qh07QhN01hN7P807AdM0P0L71`0100M7Ad071`L01`L700M7Ad3
01`L70<07AdM1@0L71`401/K6`0501`L700K6a/06a/K01`L700J6QX0100K6a/00`0L71`06QXJ01/K
6`0201XJ6P0501/K6`0J6QX06a/K01XJ6P0I6AT0100J6QX301TI6@H0fMWI0@0000010=WIf@0000<0
fMWI0000000000000P0000030=WIf@800000103IfMT2000000H0fMWI00<000000=WIf@3IfMT00`3I
fMT201XJ6P0401TI6@0J6QX06QXJ01/K6`806QXJ00H06ATI01XJ6P0K6a/06QXJ01TI6@0J6QX201/K
6`@071`L0P0J6QX00`0K6a/071`L01/K6`0201/K6`0301`L700K6a/071`L00<071`L00P06a/K01dM
7@0N7Qh07AdM01`L700M7Ad06a/K01`L70807AdM00<071`L01dM7@0M7Ad00P0M7Ad201`L70<07AdM
00L071`L01dM7@0M7Ad07AdM01hN7P0M7Ad07alO00807AdM00H07QhN01dM7@0N7Qh07alO01hN7P0O
7al3020P800401lO7`0P82008B4Q024Q8@80820P1@0Q8B43028R8P808b<S00H08R8R02DU9@0T92@0
9BDU02HV9P0U9BD202HV9P809BDU00@09bLW02PX:00X:2P0:2PX0P0Y:BT00`0X:2P0:RXZ02/[:`02
02/[:`80;Bd]00D0;bl_02h^;P0^;Rh0<C4a030`<00303<c<`0S03De=@0f=SH0>CTi03Ph>00j>SX0
?3`l03hn?P0m?Cd0?clo0492@P14A4@0ATI604Y:BP1;Bd/0CDe=059BDP1DE5@0EUIF05]KF`1QHF40
I6AT06QXJ01`L700M7Ad07emO@1nOWh0QXJ609:BTP2HV9P0Y:BT0;Fe]@2l_;`0d=3@0>KViP3/k>`0
403oool04`3[jn/0f=SH0<o?c`32`/80];Bd0:NWY`2JVYX0Ti>C08Z:RP20P800O7al071`L01]KFd0
JFUY061PH01OGel0Fe]K05IFEP1DE5@00P1>CTh0201;Bd/0B4Q804Q8B013@d<0@D510410@00n?Sh0
>c/k0`0j>SX00`0h>3P0=CDe03@d=003038b<P<0<30`00<0;Bd]02h^;P0[:b/00P0/;2`202/[:`03
02XZ:P0Y:BT0:2PX0080:BTY00L0:2PX02HV9P0V9RH09bLW02DU9@0V9RH09BDU00<092@T00<09BDU
02@T900S8b<00P0R8R801@0Q8B408R8R024Q8@0R8R808B4Q0080820P00<08B4Q020P800P82000`0P
820201lO7`D07QhN00<07AdM01hN7P0M7Ad00`0N7Qh201lO7`0301hN7P0M7Ad07AdM00807AdM00@0
7QhN01dM7@0M7Ad06a/K0`0L71`201dM7@0301`L700M7Ad071`L008071`L00<07AdM01/K6`0L71`0
0`0K6a/01`0M7Ad06QXJ01XJ6P0J6QX06a/K01XJ6P0K6a/00P0J6QX301/K6`806QXJ00<06ATI01XJ
6P0J6QX01@0J6QX00`0I6AT06QXJ0=WIf@050=WIf@4000000@3IfMT000030=WIf@000000fMWI00@0
fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@0000050=WIf@030000003IfMT0
fMWI00<0fMWI00@06ATI01/K6`0I6AT06ATI100J6QX201/K6`0601TI6@0K6a/06ATI01/K6`0J6QX0
71`L0P0K6a/201`L70806a/K0`0L71`00`0K6a/071`L01`L700201/K6`0401`L700M7Ad06a/K01`L
70807AdM1`0L71`0100N7Qh07AdM01/K6`0K6a/301dM7@0601`L700M7Ad071`L01lO7`0N7Qh07AdM
1@0N7Qh201lO7`04020P800O7al07alO020P80<07alO00<0820P01lO7`0N7Qh00P0Q8B42020P8080
8R8R00@0820P024Q8@0R8R808B4Q0P0R8R800`0S8b<092@T02@T900202<S8`8092@T0`0U9BD00`0W
9bL09RHV02LW9`0302PX:00302TY:@0Z:RX0:RXZ0080:RXZ00<0:b/[02`/;00/;2`00`0^;Rh00`0_
;bl0<C4a034a<@0203<c<`0703@d=00e=CD0=CDe03Ph>00i>CT0>SXj03`l?00203hn?P030410@012
@T80ATI60080BDU901H0C4a<04m?C`1?Cdl0EEEE05IFEP1JFUX0GemO069RHP1XJ6P0Kfm_079bLP1j
NWX0Ogmo08B4Q02DU9@0V9RH0:>SX`2c/k<0_;bl0<k>cP3Rh^80k>c/403oool05`3[jn/0f=SH0<c<
c02j^[X0/k>c0:>SX`2GUiL0Ti>C08V9R@1lO7`0NGUi07=cL`1^KVh0IfMW069RHP1OGel0Fe]K05IF
EP1DE5@0DE5A04m?C`1;Bd/0AdM70080A4A400D0@D510410@00m?Cd0?Cdm03Xj>P0203Ph>00403Lg
=`0f=SH0=3@d03@d=080<C4a00P0<30`02l_;`0^;Rh0;bl_02d];@0[:b/0;Bd]02/[:`80:RXZ00H0
:BTY02XZ:P0Y:BT0:BTY02PX:00W9bL202HV9P0602DU9@0V9RH092@T02DU9@0R8R8092@T1@0S8b<0
1P0R8R808B4Q024Q8@0P82008B4Q020P80<08B4Q00L0820P024Q8@0P8200820P01lO7`0P82007alO
00D07QhN00H07alO01hN7P0N7Qh07AdM01lO7`0M7Ad201hN7P0601dM7@0O7al07alO01`L700M7Ad0
71`L0`0K6a/201dM7@0301`L700K6a/07AdM008071`L00D06a/K01`L700M7Ad071`L01/K6`0401`L
700401/K6`0J6QX06a/K01/K6`8071`L00D06a/K01XJ6P0K6a/06QXJ01/K6`0301XJ6P0301/K6`0J
6QX06QXJ00806QXJ0P0I6AT201XJ6P0301TI6@3IfMT0fMWI00@0fMWI0@0000010=WIf@000P3IfMT0
0`000000fMWI0=WIf@020=WIf@040000003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT00000
1@3IfMT3000000<0fMWI00<06a/K01XJ6P0J6QX00P0I6AT201/K6`0:01XJ6P0K6a/06a/K01/K6`0J
6QX06a/K01XJ6P0L71`06a/K01`L70806a/K00@07AdM01/K6`0K6a/071`L2P0K6a/301`L700401dM
7@0L71`071`L01dM7@8071`L00D07QhN01`L700L71`07QhN01dM7@0201`L70H07AdM00L07QhN01dM
7@0N7Qh07QhN01dM7@0N7Qh0820P00@07alO00D07QhN01lO7`0O7al07alO028R8P02020P8003028R
8P0P82008B4Q00808B4Q00<08R8R024Q8@0Q8B400P0R8R8302<S8`0402@T900S8b<08b<S02@T90<0
9BDU0`0V9RH302LW9`80:BTY00@0:2PX02XZ:P0Z:RX0:b/[1@0/;2`202h^;P80;bl_02L0<S8b034a
<@0c<c<0=3@d03De=@0f=SH0=cLg03Ti>@0j>SX0>c/k03dm?@10@400@D5103lo?`15ADD0AdM704Q8
B01<C4`0CTi>055AD@1EEED0F5QH05]KF`1OGel0HV9R06UYJ@1`L700MGEe07QhN01nOWh0Q8B408j>
SP2FUYH0Y:BT0;:b/P2l_;`0c<c<0>;RhP3YjNT03`3oool02P3lo?`0jNWY0=GEe@3:b/X0_;bl0;6a
/@2TY:@0V9RH092@T025QHD207]kN`0;079bLP1_Kfl0J6QX06=SH`1OGel0G5aL05EEE@1DE5@0D51@
04e=C@19BDT00P17AdL204=3@`070492@P0m?Cd0>c/k03/k>`0i>CT0>3Ph03Lg=`0203De=@80<c<c
00D0<C4a030`<00^;Rh0<30`02h^;P0302d];@0502`/;00];Bd0:RXZ02XZ:P0Y:BT00P0X:2P00`0W
9bL0:2PX02LW9`0202LW9`0:02DU9@0W9bL09BDU02HV9P0T92@08b<S02DU9@0R8R808b<S024Q8@@0
8R8R00@0820P024Q8@0P82008B4Q0P0O7al01P0P82008B4Q020P800Q8B40820P01hN7P807alO00H0
7QhN01dM7@0O7al07QhN020P800N7Qh501dM7@807QhN0P0M7Ad02`0N7Qh07AdM01dM7@0K6a/07AdM
01`L700M7Ad071`L01/K6`0L71`07AdM008071`L00H06a/K01dM7@0L71`07AdM01hN7P0M7Ad201XJ
6P0401`L700K6a/06a/K01`L70D06a/K00<06QXJ01/K6`0K6a/00P0K6a/301XJ6P806ATI100J6QX0
0`0I6AT0fMWI0=WIf@020=WIf@<000000@3IfMT000<0fMWI00D000000=WIf@3IfMT0fMWI00000002
0=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WI
f@030=WIf@806QXJ00H06ATI01/K6`0K6a/06a/K01XJ6P0K6a/201XJ6P0501TI6@0J6QX06a/K01/K
6`0L71`00`0K6a/01@0L71`07AdM01/K6`0L71`06QXJ008071`L00@06a/K01`L700K6a/06a/K0P0L
71`00`0K6a/071`L01`L700501`L700301/K6`0L71`07AdM008071`L0P0M7Ad01P0L71`07QhN01`L
700M7Ad07QhN01`L70807QhN0P0L71`201hN7P0301dM7@0N7Qh07alO0080820P00<07QhN01lO7`0O
7al00P0P820201lO7`07024Q8@0P82007alO01lO7`0P82008B4Q020P8003028R8P808B4Q00<08b<S
028R8P0S8b<00`0S8b<01@0T92@09BDU02@T900U9BD09RHV00<09BDU00D0:2PX02LW9`0X:2P09bLW
02PX:00202TY:@0@02PX:00Z:RX0:b/[02`/;00^;Rh0:b/[02d];@0^;Rh0;Bd]030`<00a<C40<30`
03<c<`0a<C40<c<c03De=@80=cLg0P0i>CT07P0k>c/0?Shn03lo?`11@D40@d=304A4A019BDT0B4Q8
04];B`1?Cdl0D51@05ADE01FEUH0Fe]K061PH01SHf<0JFUY06m_K`1aLG40MgMg07alO025QHD0TI6A
09NGU`2TY:@0]KFe0;Zj^P37alL0h>3P0>k^kPl0oooo01d0n?Sh0>KViP3Bd]80b/[:0;Rh^02a/K40
X:2P09BDU02@T900QXJ607inOP1iNGT0LG5a06e]K@1ZJVX0H61P05iNGP1IFET0EEEE05ADE01>CTh0
CDe=04];B`17AdL0ATI604A4A012@T80@41003dm?@0203/k>`0303Ti>@0h>3P0=CDe0080=3@d00@0
<c<c034a<@0`<300<30`0`0_;bl00`0];Bd0;2`/02d];@0202`/;0<0:BTY00D0:2PX02LW9`0V9RH0
9bLW02PX:00302HV9P<09BDU00@092@T02<S8`0S8b<08R8R0P0S8b<01P0P82008R8R028R8P0S8b<0
8R8R024Q8@@0820P0P0Q8B400`0P82007alO01lO7`0301lO7`0301dM7@0N7Qh07QhN00@07QhN00@0
7AdM01lO7`0N7Qh07AdM0P0N7Qh00`0M7Ad07QhN01/K6`0201dM7@806a/K0P0L71`00`0J6QX06a/K
01/K6`0201`L70807AdM00D071`L01dM7@0M7Ad07QhN01dM7@0701/K6`0301XJ6P0K6a/06ATI00@0
6QXJ00H06a/K01XJ6P0J6QX06a/K01XJ6P0I6AT201XJ6P0401/K6`0I6AT061PH01XJ6PH0fMWI0@00
00010=WIf@0000D0fMWI0000003IfMT0fMWI000000020=WIf@040000003IfMT0fMWI00000080fMWI
00@000000=WIf@3IfMT000001@3IfMT00`000000fMWI0=WIf@030=WIf@0401TI6@0J6QX06ATI01/K
6`D06QXJ1@0K6a/00`0J6QX06a/K01/K6`0501/K6`0501XJ6P0L71`06a/K01`L700K6a/0100L71`0
0`0M7Ad071`L01XJ6P0401`L700501/K6`0M7Ad06a/K01`L700K6a/0100M7Ad00`0N7Qh07AdM01`L
700401dM7@0401hN7P0O7al07AdM01dM7@807QhN00<07alO01hN7P0P82000`0N7Qh4020P800301lO
7`0P8200820P0080820P00`08B4Q020P800Q8B408R8R024Q8@0S8b<08R8R024Q8@0S8b<08B4Q028R
8P0S8b<402@T90809BDU00@09RHV02DU9@0V9RH09BDU0P0X:2P00`0W9bL0:2PX02LW9`0202TY:@04
02XZ:P0Y:BT0:b/[02`/;080;Bd]00L0;2`/02h^;P0`<300<30`034a<@0b<S80<c<c00<0=CDe02<0
=cLg03Ti>@0i>CT0>c/k03dm?@0n?Sh0@D510492@P15ADD0AdM704U9B@1;Bd/0Cdm?055AD@1DE5@0
EUIF05]KF`1PH600HV9R06QXJ01[Jf/0LG5a07EeM@1jNWX0PX:2096AT@2DU9@0XZ:R0;2`/02h^;P0
alO70=OGe`3Shn<0m?Cd0?knoP0<0?ooo`0K0?Win@3alO40h>3P0<_;b`32`/80]KFe0:j^[P2MWId0
Ti>C092@T021PH40OGem07EeM@1`L700KVi^06MWI`1QHF40GemO05QHF01EEED0DU9B04m?C`1@D500
BTY:04M7A`16ATH0@d=30080@41000<0?Cdm03/k>`0k>c/00P0g=cL203De=@80<c<c0P0a<C40400`
<300;Rh^030`<00];Bd0;Rh^02`/;00[:b/0:RXZ02/[:`0X:2P0:RXZ02TY:@0Z:RX0:2PX02HV9P0W
9bL202HV9P0<02DU9@0T92@09BDU02HV9P0T92@08b<S02DU9@0Q8B408R8R02@T900R8R80820P1@0Q
8B42020P8004024Q8@0O7al0820P028R8P807alO00<0820P01lO7`0N7Qh00P0M7Ad401hN7P<07alO
00<07QhN01dM7@0M7Ad01@0M7Ad00`0K6a/07AdM01dM7@0201dM7@0401`L700K6a/07AdM01dM7@80
71`L0P0M7Ad201hN7P807AdM0`0L71`01@0M7Ad071`L01/K6`0J6QX06a/K00D06QXJ00@06ATI01/K
6`0J6QX06a/K0P0J6QX0100I6AT06a/K01TI6@0K6a/201TI6@0301/K6`0J6QX0fMWI00D0fMWI0@00
00010=WIf@000P3IfMT2000000@0fMWI0P0000040=WIf@8000001P3IfMT00`000000fMWI0=WIf@03
0=WIf@0401/K6`0I6AT06a/K01TI6@P06QXJ0P0K6a/01@0L71`06a/K01XJ6P0K6a/06QXJ00@06a/K
0P0L71`201/K6`0301`L700K6a/071`L00806a/K00D071`L01XJ6P0K6a/071`L01/K6`0401`L7080
7AdM0P0L71`0100M7Ad071`L01dM7@0N7Qh201`L700501dM7@0N7Qh071`L01dM7@0O7al00`0N7Qh0
1@0O7al07QhN01lO7`0Q8B407alO0080820P00H07alO020P800P82007alO020P800N7Qh2020P8080
7alO00@0820P024Q8@0Q8B408R8R0`0Q8B42028R8P0302@T900S8b<08R8R00<092@T00H08b<S02DU
9@0V9RH09RHV02LW9`0V9RH202LW9`0?02TY:@0W9bL09bLW02TY:@0Z:RX0:BTY02/[:`0/;2`0:b/[
02`/;00^;Rh0;Bd]02h^;P0a<C40<30`0080<C4a00P0<c<c03@d=00e=CD0=CDe03Hf=P0h>3P0>CTi
03/k>`80?Shn00<0@d=30451@@14A4@00P19BDT0601:BTX0Cdm?051@D01FEUH0EEEE05aLG01NGUh0
I6AT06QXJ01]KFd0Kfm_07MgM`1lO7`0PX:208f=S@2BTY80XZ:R0:^[Z`2c/k<0`l?30=GEe@3Ph>00
lo?c0?[jnP`0oooo00/0l_;b0>g]k@3GemL0bl_;0;no_`2^[Zh0ZJVY09fMW@2?Shl0Rh^;08:2PP02
07MgM`0A075aL@1ZJVX0J6QX069RHP1OGel0FEUI05ADE01BDU80CTi>04e=C@1:BTX0ATI604A4A013
@d<0?clo0451@@0n?Sh00P0k>c/203Ph>00603Hf=P0e=CD0=CDe03@d=00b<S80<C4a0P0`<30202h^
;P0402d];@0/;2`0:b/[02XZ:P80:b/[0P0Y:BT0100Z:RX0:2PX02PX:00W9bL302HV9P809BDU00D0
92@T02<S8`0T92@08b<S02@T900202<S8`07028R8P0S8b<08R8R028R8P0Q8B40820P02<S8`04020P
800601lO7`0Q8B407alO020P800N7Qh07AdM0P0O7al00`0N7Qh0820P01hN7P0201hN7P<07AdM00H0
7QhN01dM7@0M7Ad07QhN01`L700M7Ad301`L70807AdM0`0L71`0100K6a/071`L01`L700M7Ad201`L
700501/K6`0M7Ad07QhN01hN7P0M7Ad00P0L71`00`0K6a/06QXJ01/K6`0301XJ6P0501/K6`0J6QX0
6a/K01XJ6P0K6a/00P0J6QX01@0K6a/06QXJ01XJ6P0J6QX06ATI00<06QXJ00@061PH01TI6@0J6QX0
6a/K1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00@06QXJ01LG5`0I6AT0
6ATI0`0J6QX201/K6`0401XJ6P0K6a/06QXJ01XJ6P806a/K00T071`L01/K6`0L71`06a/K01`L700K
6a/06QXJ01/K6`0J6QX00`0L71`00`0K6a/071`L01/K6`0201/K6`0401XJ6P0K6a/06QXJ01dM7@H0
71`L00h07AdM01`L700L71`071`L01dM7@0K6a/07AdM01lO7`0M7Ad06a/K01dM7@0N7Qh07AdM01hN
7P807AdM00D07QhN01dM7@0M7Ad07alO01hN7P0601lO7`06020P800O7al0820P01lO7`0P82007alO
0`0Q8B40400R8R80820P024Q8@0Q8B408b<S028R8P0Q8B408b<S028R8P0S8b<09BDU02@T900S8b<0
9BDU02HV9P0U9BD302HV9P0402LW9`0X:2P09bLW02LW9`80:2PX00@0:BTY02/[:`0Z:RX0:b/[0P0/
;2`0200];Bd0;Rh^02d];@0_;bl0<30`034a<@0b<S80<c<c0P0d=3@09@0e=CD0=SHf03Xj>P0h>3P0
>c/k03dm?@0o?cl0@4100492@P14A4@0ATI604Q8B01:BTX0D51@04m?C`1DE5@0EEEE05YJFP1NGUh0
H61P06MWI`1[Jf/0L71`07IfMP1hN7P0PH6108f=S@2@T900Vi^K0:JVYP2^[Zh0_;bl0<O7a`3De=@0
i^KV0>o_k`3lo?`02P3oool05`3clo<0iNGU0=oOg`3Cdm<0`<300;Rh^02[Zj/0YjNW09^KV`2?Shl0
QhN70861P@1iNGT0Lg=c06a/K01YJFT0Hf=S05iNGP1LG5`0F5QH05ADE01BDU80CTi>0080Bd];0P16
ATH03011@D40@4100410@00l?3`0>SXj03/k>`0h>3P0=cLg03@d=00c<c<0=3@d03<c<`80<S8b00<0
<30`02l_;`0_;bl00P0];Bd01`0Z:RX0:b/[02/[:`0Y:BT0:b/[02XZ:P0Y:BT00P0X:2P01@0U9BD0
9bLW02LW9`0V9RH09BDU00809RHV0P0T92@0100S8b<092@T02@T900R8R8202<S8`03028R8P0Q8B40
8B4Q00@08B4Q100P82002`0N7Qh07alO020P800N7Qh0820P01hN7P0O7al07QhN01lO7`0N7Qh07alO
00<07QhN00L07AdM01hN7P0N7Qh07QhN01dM7@0N7Qh07AdM00L071`L00D06a/K01hN7P0L71`071`L
01dM7@0201/K6`8071`L00P06a/K01`L700L71`071`L01/K6`0J6QX071`L01/K6`@06QXJ0`0K6a/<
01XJ6P0301/K6`0J6QX06QXJ00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WI
f@0301XJ6P0I6AT06QXJ00<06QXJ00D06a/K01`L700K6a/06ATI01/K6`0201XJ6P0401/K6`0L71`0
6a/K01`L70806a/K00L071`L01/K6`0K6a/06a/K01`L700K6a/071`L00<06a/K0`0L71`501/K6`80
71`L00<07AdM01`L700M7Ad00P0L71`00`0M7Ad071`L01dM7@0201dM7@8071`L00<07AdM01`L700M
7Ad00P0M7Ad0100L71`07alO01hN7P0N7Qh301lO7`0301hN7P0O7al07alO00@0820P00D07QhN020P
800P8200820P01lO7`03020P80808R8R0P0Q8B400`0S8b<092@T02<S8`0202<S8`03028R8P0T92@0
9BDU00@09BDU00D09bLW02HV9P0V9RH09bLW02PX:00402TY:@0<02PX:00[:b/0:RXZ02XZ:P0/;2`0
;Bd]02/[:`0];Bd0;Rh^02l_;`0`<300<S8b0P0a<C401@0b<S80=3@d03De=@0f=SH0>3Ph0080>c/k
0240?3`l03lo?`11@D40@D5104E5A@17AdL0B4Q804];B`1>CTh0D51@05=CD`1GEeL0F5QH05eMG@1P
H600I6AT06UYJ@1]KFd0Lg=c07QhN01oOgl0QhN708b<S02GUiL0YZJV0:VYZ@2d];@0`<300<[:bP3I
fMT0h^;R0?3`l03inOT01`3oool07@3inOT0lo?c0>KViP3IfMT0dm?C0<[:bP2i^KT0/K6a0::RXP2P
X:00Ti>C08V9R@27QhL0OGem07QhN01aLG40Jf][06MWI`1QHF40GEeM05]KF`1GEeL0DE5A051@D01?
Cdl0BTY:04Q8B016ATH0A4A40080@41000@0?clo03/k>`0k>c/0>3Ph0P0g=cL01P0h>3P0=3@d03<c
<`0a<C40=3@d034a<@80;bl_00H0;Rh^02d];@0^;Rh0;2`/02XZ:P0[:b/202TY:@0:02XZ:P0Y:BT0
:2PX02HV9P0W9bL0:2PX02LW9`0U9BD09RHV02<S8`809BDU00@092@T028R8P0T92@092@T1@0R8R80
1P0S8b<08R8R028R8P0P82008b<S020P80808B4Q0P0P82000`0O7al0820P01hN7P0201hN7P0301lO
7`0N7Qh07AdM00807AdM00D0820P01dM7@0M7Ad07AdM01hN7P0201dM7@807QhN00<071`L01dM7@0K
6a/00P0L71`0100M7Ad071`L01dM7@0L71`201/K6`0301dM7@0L71`06a/K008071`L0P0K6a/401`L
700301/K6`0L71`06a/K00806a/K0P0J6QX301/K6`0701TI6@0J6QX06a/K01TI6@0K6a/06QXJ01TI
6@0201XJ6P0601/K6`0J6QX06QXJ01XJ6P0I6AT06QXJ1P3IfMT100000040fMWI000F0=WIf@030000
003IfMT0fMWI00<0fMWI00H06QXJ01/K6`0I6AT06QXJ01/K6`0I6AT301XJ6P0501TI6@0K6a/06a/K
01XJ6P0K6a/00P0J6QX0100L71`06a/K01XJ6P0K6a/201`L70<06a/K00L071`L01/K6`0J6QX071`L
01/K6`0L71`06a/K00@071`L0P0K6a/0100L71`06a/K01`L700L71`201dM7@0301`L700M7Ad07AdM
00807AdM00H071`L01dM7@0M7Ad07AdM01`L700O7al701hN7P03020P800M7Ad07alO00<07alO00<0
8B4Q020P800P82001@0P82001@0O7al0820P028R8P0Q8B408R8R00808B4Q00@08b<S028R8P0S8b<0
8b<S0P0U9BD0100S8b<092@T02DU9@0W9bL202@T900302LW9`0V9RH09bLW00@09bLW0P0Y:BT00`0[
:b/0:RXZ02`/;00202`/;080;Bd]0P0^;Rh2030`<00803<c<`0a<C40=3@d03@d=00e=CD0=cLg03Ph
>00i>CT303dm?@0Q0410@012@T80@T9204E5A@16ATH0BTY:04e=C@1>CTh0E5AD05=CD`1GEeL0GUiN
05mOG`1TI6@0J6QX06a/K01bLW80MGEe07inOP25QHD0RXZ:09BDU02OWil0YZJV0;6a/@30`<00a<C4
0=3@d03IfMT0i^KV0?7al@3dm?@0o_kn00@0oooo01L0n_[j0?;blP3]kNd0hN7Q0=7Ad@3=cLd0`L71
0;Bd]02_[jl0X:2P09bLW02BTY80RHV908>3P`1kNg/0MWIf071`L01YJFT0IVIV069RHP1MGEd0FUYJ
05IFEP02059BDP0404i>CP1;Bd/0AdM704I6AP80@d=300@0@T9203lo?`0l?3`0>SXj0P0h>3P203Lg
=`0903@d=00a<C40<S8b038b<P0a<C40<30`02l_;`0^;Rh0;bl_00<0;2`/0`0Z:RX0100Y:BT0:2PX
02PX:00W9bL202HV9P0302LW9`0T92@09BDU00<09BDU0P0T92@01P0R8R808b<S02<S8`0S8b<092@T
024Q8@<08R8R00<08B4Q020P800Q8B400`0P8200100O7al0820P024Q8@0M7Ad201hN7P0301lO7`0N
7Qh07alO00<07alO0P0N7Qh0100M7Ad07QhN01hN7P0L71`201hN7P0401dM7@0L71`07AdM01hN7P80
71`L00@06a/K01`L700L71`07AdM0P0K6a/01@0L71`06a/K01/K6`0M7Ad06a/K00@071`L00P06a/K
01XJ6P0L71`06QXJ01/K6`0L71`06a/K01XJ6P806a/K00@06QXJ01/K6`0J6QX06QXJ0`0K6a/01@0J
6QX06ATI01XJ6P0J6QX06ATI00<06QXJ00<06ATI01/K6`3IfMT01@3IfMT100000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI00<06QXJ01TI6@0J6QX00P0J6QX02@0K6a/06QXJ01XJ6P0K6a/0
6QXJ01/K6`0I6AT06QXJ01TI6@0201XJ6P0301/K6`0L71`06QXJ008071`L0P0K6a/02@0J6QX071`L
01`L700K6a/071`L01dM7@0L71`06a/K01XJ6P0601`L70806a/K0P0M7Ad0100L71`07AdM01dM7@0K
6a/201dM7@8071`L00P07AdM01hN7P0N7Qh07QhN01dM7@0L71`07QhN01dM7@<07QhN00P0820P01lO
7`0N7Qh0820P01lO7`0P82007QhN01lO7`@0820P00<07alO024Q8@0Q8B400P0P8202024Q8@808R8R
00<08B4Q028R8P0S8b<00P0S8b<0100R8R8092@T02@T900T92@302DU9@0402HV9P0U9BD09bLW02HV
9P809bLW00D0:BTY02PX:00[:b/0:BTY02XZ:P0202/[:`0302d];@0/;2`0;Bd]0080;Rh^03@0;bl_
034a<@0a<C40<S8b03<c<`0d=3@0=SHf03De=@0g=cL0>3Ph03Ti>@0j>SX0?Cdm03`l?00n?Sh0@D51
04=3@`16ATH0AdM704U9B@1=CDd0CTi>059BDP1EEED0EUIF05]KF`1LG5`0H61P06EUI@1YJFT0LG5a
07=cL`1jNWX0PX:208F5Q@2<S8`0VIVI09jNWP2YZJT0]KFe0;Zj^P34a<@0c<c<0=CDe03Ng]h0h^;R
0>WYj@3bl_80lO7a0?3`l03_knl0iNGU0P3MgMd0703De=@0aLG50<71`@2e]KD0Z:RX0:FUY@2KVi/0
U9BD08f=S@22PX80P82007]kN`1bLW80Kfm_06UYJ@1VIVH0HF5Q05YJFP1HF5P0EeMG051@D01>CTh0
C4a<04U9B@18B4P0ADE504=3@`10@40203hn?P0303/k>`0j>SX0>SXj0080=cLg0180=3@d03<c<`0c
<c<0<S8b034a<@0c<c<0<30`02l_;`0^;Rh0;Bd]02/[:`0Z:RX0;2`/02XZ:P0Y:BT0:2PX02XZ:P0W
9bL202PX:0809bLW00H09RHV02DU9@0V9RH09RHV02DU9@0T92@202DU9@0502@T900R8R8092@T02<S
8`0Q8B400P0R8R801P0P82008R8R020P800Q8B40820P024Q8@807alO0P0P820201lO7`05024Q8@0N
7Qh07QhN01dM7@0N7Qh00`0M7Ad00`0N7Qh07AdM01hN7P0201dM7@0401`L700N7Qh07AdM01`L70<0
7AdM00@071`L01dM7@0L71`071`L0P0K6a/02P0L71`06a/K01hN7P0L71`06a/K01`L700K6a/071`L
01/K6`0L71`201/K6`0701`L700K6a/06a/K01XJ6P0K6a/071`L01/K6`0201TI6@0701XJ6P0K6a/0
6a/K01TI6@0J6QX06ATI01/K6`0401XJ6P0401/K6`0I6AT06QXJ01XJ6P806ATI1P3IfMT100000040
fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0P0J6QX00`0K6a/06QXJ01TI6@0201XJ6P0501`L
700K6a/06QXJ01XJ6P0K6a/01@0J6QX201dM7@806a/K00H071`L01/K6`0K6a/071`L01/K6`0L71`3
01/K6`0401`L700K6a/06a/K01`L70806a/K0P0L71`301dM7@0401`L700M7Ad07AdM01`L70807AdM
00@071`L01dM7@0L71`071`L0P0N7Qh02@0M7Ad07QhN01hN7P0O7al07QhN020P800M7Ad07QhN020P
800201hN7PD07alO00@0820P01lO7`0P82008B4Q0`0P8202024Q8@L08R8R0P0S8b<202@T90809BDU
00@092@T02DU9@0V9RH09BDU0P0V9RH0200U9BD09bLW02LW9`0W9bL0:BTY02XZ:P0Y:BT0:b/[0P0Z
:RX302/[:`80;Bd]00@0;Rh^030`<00`<300=3@d0P0c<c<00`0f=SH0=3@d03Hf=P0203Ph>00>03Ti
>@0l?3`0?3`l03dm?@11@D40@d=304I6AP15ADD0BDU904];B`1=CDd0CTi>055AD@1FEUH205YJFP0I
05mOG`1VIVH0J6QX06m_K`1`L700MWIf07inOP21PH40R8R809:BTP2FUYH0XZ:R0:b/[02^[Zh0^;Rh
0;fm_@34a<@0cLg=0=;BdP3EeMD0fMWI0=[JfP3Ng]h0emOG0=?Cd`020<c<c00A0<;2`P2i^KT0];Bd
0:ZZZP2QXJ40W9bL096AT@2<S8`0QHF50820P01lO7`0MGEe06i^KP1ZJVX0IFEU069RHP1MGEd00P1I
FET02`1DE5@0D51@04i>CP1;Bd/0BTY:04I6AP14A4@0@T920451@@0n?Sh0?Cdm0080>c/k00@0>CTi
03Ph>00h>3P0=cLg0P0d=3@0100b<S80<30`030`<00`<30202h^;P0302d];@0^;Rh0;2`/0080:b/[
0P0Y:BT202PX:00402LW9`0V9RH09RHV02LW9`809RHV00<092@T02DU9@0T92@00P0S8b<00`0T92@0
8R8R02<S8`02028R8P0402<S8`0R8R808R8R024Q8@<08R8R0`0P82000`0Q8B40820P020P800301lO
7`06020P800O7al07QhN01hN7P0M7Ad07QhN0`0M7Ad00`0N7Qh07AdM01hN7P0301dM7@0301hN7P0L
71`07QhN00L071`L00/06a/K01`L700K6a/06a/K01`L700K6a/07AdM01`L700M7Ad06a/K01`L7004
01/K6`0501`L700K6a/06a/K01/K6`0J6QX00P0K6a/301XJ6P806ATI0P0J6QX01P0I6AT06QXJ01XJ
6P0J6QX06a/K01XJ6P<06ATI1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI
00H06a/K01TI6@0K6a/06QXJ01/K6`0I6AT301XJ6P806a/K00<06QXJ01`L700J6QX01@0K6a/201`L
70806a/K00@071`L01dM7@0K6a/06a/K0P0L71`201XJ6P0301`L700K6a/071`L008071`L00X06a/K
01dM7@0L71`071`L01dM7@0L71`07AdM01hN7P0M7Ad07QhN0P0L71`0100M7Ad07QhN01dM7@0M7Ad3
01hN7P0501dM7@0N7Qh07alO01hN7P0O7al00P0N7Qh01P0O7al07QhN01hN7P0N7Qh07alO020P80<0
7alO0P0P82000`0Q8B40820P020P8002024Q8@H08R8R0`0S8b<01@0R8R8092@T02<S8`0U9BD092@T
00<09BDU1@0V9RH0100X:2P09bLW02XZ:P0Y:BT202XZ:P0402/[:`0];Bd0;2`/02`/;080;Rh^00D0
;bl_030`<00`<300<S8b03<c<`0203De=@80=SHf00D0=cLg03Xj>P0j>SX0?3`l03hn?P0203lo?`0N
0451@@14A4@0ADE504M7A`1;Bd/0C4a<051@D01BDU80De=C05UIF@1JFUX0GUiN06=SH`1WIfL0JFUY
06a/K01eMGD0NWYj07moO`25QHD0SXj>09>CT`2LW9`0YZJV0:RXZ02a/K40]kNg0;fm_@34a<@0b/[:
0`3=cLd05P3>c/h0clo?0<W9b@36a/H0`/;20;^k^`2d];@0[jn_0:RXZ02MWId0VYZJ08n?S`2<S8`0
PX:207alO01jNWX0LG5a06][J`1YJFT0H61P06=SH`1KFe/205MGE`06051@D01=CDd0CDe=04];B`18
B4P0AdM70P13@d<01P11@D40?clo03lo?`0k>c/0>SXj03Ti>@80=cLg00D0=SHf038b<P0c<c<0=3@d
034a<@0202l_;`80;Rh^00L0:b/[02`/;00Y:BT0:BTY02/[:`0Z:RX09bLW0080:2PX00@09bLW02PX
:00V9RH09bLW0P0V9RH202@T900302HV9P0T92@092@T008092@T0`0S8b<01@0Q8B408b<S02<S8`0R
8R80820P00808B4Q00<0820P01lO7`0O7al00P0P82001P0N7Qh07alO020P800O7al07QhN020P80H0
7QhN0`0M7Ad02@0N7Qh07AdM01dM7@0L71`07AdM01`L700M7Ad071`L01/K6`0201`L700701dM7@0L
71`071`L01/K6`0M7Ad06a/K01`L700201/K6`0401XJ6P0L71`06a/K01`L70<06a/K00H071`L01XJ
6P0K6a/071`L01/K6`0L71`501XJ6P0301TI6@0K6a/06QXJ00806QXJ0P0K6a/301XJ6P0401TI6@0J
6QX06QXJ01XJ6PH0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0401/K6`0I
6AT06ATI01/K6`806QXJ00@071`L01XJ6P0K6a/06ATI0P0K6a/00`0J6QX06a/K01/K6`0301/K6`03
01`L700K6a/06a/K00806a/K0`0L71`0100K6a/071`L01/K6`0L71`501/K6`0601`L700K6a/071`L
01dM7@0L71`06a/K0`0L71`02@0N7Qh071`L01/K6`0K6a/07AdM01`L700N7Qh071`L01dM7@0601hN
7P0901lO7`0N7Qh07QhN01hN7P0O7al0820P01`L700P82007QhN00807alO0P0P82000`0O7al0820P
024Q8@02024Q8@04020P800Q8B408B4Q02<S8`808B4Q00P09BDU02<S8`0R8R808R8R02DU9@0T92@0
8R8R02<S8`809BDU00@09RHV02DU9@0U9BD09BDU0P0W9bL00`0Y:BT0:2PX02TY:@0302TY:@80:RXZ
0P0[:b/0200];Bd0;Rh^02d];@0_;bl0<S8b02h^;P0a<C40<S8b0`0e=CD0500g=cL0>3Ph03Lg=`0j
>SX0>c/k03`l?00o?cl0@D510410@014A4@0@d=304M7A`18B4P0C4a<051@D01?Cdl0E5AD05IFEP1H
F5P0G5aL0P1SHf<04`1XJ6P0Jf][071`L01fMWH0O7al0861P@28R8P0RXZ:09FEU@2IVIT0WYjN0:>S
X`2YZJT0[jn_0;Fe]@2h^;P0_Kfm0<30`02o_kl00P2n_[h0602m_Kd0^;Rh0;>c/`2[Zj/0ZZZZ0:>S
X`2JVYX0UIFE09:BTP28R8P0Q8B407moO`1gMgL0M7Ad06e]K@1ZJVX0IFEU069RHP1OGel0FUYJ05EE
E@1GEeL0DU9B04i>CP80Bd];00@0BDU904A4A014A4@0@T920`0n?Sh01@0k>c/0>SXj03Ti>@0i>CT0
=SHf0080=3@d00@0<S8b034a<@0^;Rh0<30`0P0_;bl00`0^;Rh0;2`/02d];@0302/[:`0302XZ:P0Y
:BT0:BTY0080:2PX0`0W9bL01P0V9RH09BDU02DU9@0S8b<09RHV02DU9@<092@T0P0S8b<2028R8P0:
024Q8@0P82008B4Q020P800R8R808B4Q020P800O7al0820P01lO7`80820P00<07QhN01lO7`0M7Ad0
0`0N7Qh00`0M7Ad07QhN01hN7P0201dM7@<07QhN100M7Ad201hN7P807AdM00X071`L01/K6`0K6a/0
7QhN01`L700M7Ad071`L01dM7@0L71`06a/K0P0L71`02P0M7Ad06a/K01/K6`0K6a/071`L01XJ6P0K
6a/06QXJ01/K6`0J6QX201/K6`0301XJ6P0K6a/06a/K00H06QXJ00<06ATI01XJ6P0I6AT00`0I6AT4
01XJ6P0301TI6@3IfMT0fMWI00@0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WI
f@<06QXJ00L06ATI01XJ6P0J6QX06ATI01XJ6P0L71`06QXJ00@06a/K0P0J6QX201/K6`<071`L00@0
6a/K01`L700K6a/071`L0P0K6a/00`0L71`06a/K01/K6`0201`L700301/K6`0L71`071`L00L071`L
00<07AdM01`L700L71`00`0M7Ad0100L71`07AdM01`L700L71`401hN7P0301lO7`0M7Ad07AdM0080
7AdM100N7Qh00`0O7al07QhN01lO7`0201lO7`H0820P00D07alO020P800R8R80820P02<S8`03028R
8P<08b<S0P0U9BD0100S8b<092@T02DU9@0U9BD202HV9P0702DU9@0V9RH09RHV02LW9`0V9RH0:2PX
02LW9`0302TY:@80:RXZ00L0;2`/02/[:`0^;Rh0;2`/02h^;P0_;bl0;Rh^0080<30`00H0<C4a03@d
=00d=3@0=SHf03Ph>00g=cL203Ph>00303Xj>P0l?3`0?clo0080?clo00D0ADE504A4A018B4P0B4Q8
04];B`02051@D00c05=CD`1FEUH0EeMG05aLG01PH600Hf=S06MWI`1XJ6P0Kfm_07EeM@1dM7@0OWin
08>3P`26QXH0T92@09RHV02JVYX0XZ:R0:6QX@2XZ:P0[Zj^0:n_[`2f][H0^;Rh0;Jf]P2d];@0][Jf
0;:b/P2_[jl0[Jf]0:ZZZP2RXZ80W9bL09NGU`2?Shl0SXj>08B4Q01oOgl0Ng]k07EeM@1cLg<0K6a/
06MWI`1TI6@0HV9R05eMG@1HF5P0EUIF059BDP1ADE40Cdm?0080BTY:00L0B4Q804A4A012@T80@D51
0410@00o?cl0?Cdm00<0>c/k00T0>3Ph03Hf=P0d=3@0<C4a03<c<`0a<C40<30`02l_;`0`<3000P0^
;Rh202d];@0702`/;00[:b/0:RXZ02TY:@0Z:RX0:BTY02PX:00202LW9`809RHV0P0T92@302DU9@07
02HV9P0U9BD092@T02HV9P0T92@08b<S024Q8@03028R8P04020P800R8R808B4Q024Q8@80820P00<0
7alO020P800P82000`0P8200100N7Qh07AdM01hN7P0O7al201hN7P0301lO7`0N7Qh07QhN00807QhN
00H071`L01dM7@0O7al07QhN01lO7`0N7Qh201dM7@<071`L00<07AdM01/K6`0L71`00`0L71`01@0K
6a/071`L01/K6`0L71`06QXJ008071`L00<06a/K01XJ6P0L71`00`0K6a/01P0J6QX06a/K01XJ6P0J
6QX06a/K01TI6@806QXJ0P0K6a/00`0J6QX06a/K01TI6@0201TI6@0401/K6`0J6QX06QXJ01TI6@80
6QXJ00<06ATI01XJ6P3IfMT01@3IfMT100000040fMWI000F0=WIf@800000103IfMT0100J6QX06a/K
01/K6`0K6a/601XJ6P0301TI6@0J6QX06QXJ00806a/K0`0L71`01`0K6a/06QXJ01TI6@0K6a/071`L
01/K6`0L71`00`0K6a/201`L700501dM7@0L71`071`L01dM7@0L71`00P0K6a/00`0M7Ad071`L01dM
7@0201`L700301dM7@0N7Qh071`L00<071`L00T07AdM01`L700M7Ad07QhN01dM7@0N7Qh07AdM01lO
7`0P82001@0N7Qh0100O7al07QhN01hN7P0O7al201hN7P<07alO00<08B4Q020P800P82000P0P8203
024Q8@05020P800R8R808R8R028R8P0Q8B400P0S8b<00`0U9BD0:2PX02HV9P0202@T90<09BDU00@0
92@T02HV9P0U9BD09RHV0P0W9bL302PX:080:BTY100[:b/01@0];Bd0;Rh^02h^;P0^;Rh0;bl_0080
<30`0P0a<C402@0c<c<0=3@d03De=@0f=SH0>3Ph03/k>`0m?Cd0?3`l03hn?P020410@080@d=300<0
ADE504Q8B01<C4`00P1=CDd05P1BDU80De=C05ADE01IFET0GEeM065QH@1TI6@0IVIV06UYJ@1_Kfl0
MGEe07IfMP1mOGd0PH6108N7Q`2?Shl0SHf=09FEU@2FUYH0Vi^K0:2PX02RXZ820:JVYP80Z:RX01P0
YjNW0:>SX`2RXZ80WinO09ZJVP2EUID0TY:B08b<S02:RXX0Q8B407inOP1mOGd0MGEe06m_K`1]KFd0
JFUY06EUI@1OGel0GUiN05aLG01GEeL0De=C055AD@1>CTh204];B`0304Q8B015ADD0ADE50080@D51
00@0@41003hn?P0l?3`0?Cdm0P0j>SX01`0g=cL0=CDe03De=@0f=SH0<C4a03<c<`0a<C400P0^;Rh0
2@0_;bl0;Bd]02/[:`0];Bd0:b/[02TY:@0[:b/0:RXZ02PX:00202TY:@0302LW9`0V9RH0:2PX0080
9RHV00<09BDU02@T900T92@00P0T92@01@0U9BD092@T02@T900T92@08b<S00D08R8R00@0820P028R
8P0R8R80820P2@0O7al501hN7P0501lO7`0M7Ad07QhN01hN7P0M7Ad00P0N7Qh301dM7@0:01hN7P0M
7Ad07AdM01`L700N7Qh071`L01/K6`0M7Ad06a/K01`L70806a/K00P07AdM01`L700M7Ad07AdM01/K
6`0L71`06a/K01XJ6P806a/K00@06QXJ01/K6`0K6a/06a/K0P0J6QX01P0K6a/06QXJ01XJ6P0I6AT0
6QXJ01TI6@@06QXJ00T06a/K01XJ6P0J6QX06ATI01XJ6P0I6AT06QXJ01TI6@0J6QX01@3IfMT20000
0040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0`0J6QX00`0K6a/06QXJ01/K6`0301/K6`03
01XJ6P0K6a/06QXJ00806QXJ0`0K6a/01@0L71`06a/K01/K6`0L71`07AdM008071`L00H06a/K01XJ
6P0M7Ad06a/K01`L700K6a/501`L700301/K6`0L71`06a/K00D071`L0`0M7Ad201`L70<07AdM00@0
6a/K01dM7@0M7Ad07QhN100O7al01P0M7Ad07QhN01hN7P0N7Qh07alO01dM7@807QhN0P0O7al4020P
8003024Q8@0P82008B4Q00<08B4Q0P0R8R801`0S8b<08B4Q028R8P0S8b<08B4Q02<S8`0U9BD00P0T
92@00`0S8b<09BDU02@T900202DU9@0402@T900U9BD09RHV02DU9@809RHV100X:2P0100Z:RX0:b/[
02/[:`0[:b/202`/;00402d];@0^;Rh0;bl_02l_;`<0<C4a0P0c<c<01P0d=3@0=cLg03Lg=`0i>CT0
>c/k03Xj>P80?Cdm00@0?clo0410@013@d<0@T920P18B4P204e=C@0g051@D01CDe<0De=C05QHF01M
GEd0G5aL05mOG`1UIFD0J6QX06a/K01^KVh0M7Ad07MgM`1kNg/0Ogmo08>3P`27QhL0RXZ:08b<S02B
TY80U9BD09FEU@2IVIT0W9bL09^KV`2NWYh0VIVI09^KV`2DU9@0Ti>C09:BTP2>SXh0Rh^;08F5Q@20
P800OWin07UiN@1gMgL0LW9b06a/K01XJ6P0I6AT061PH01NGUh0FUYJ05QHF01FEUH0DE5A051@D01?
Cdl0Bd];04Y:BP17AdL0ATI604=3@`020410@00903lo?`0k>c/0?3`l03dm?@0k>c/0>3Ph03De=@0d
=3@0=CDe0080<30`00L0;bl_030`<00`<300;bl_02d];@0/;2`0;Bd]0080;2`/00D0:2PX02/[:`0Y
:BT0:BTY02PX:00302LW9`0602HV9P0U9BD09BDU02DU9@0V9RH08b<S0P0T92@01`0U9BD09RHV02@T
900R8R808b<S028R8P0Q8B400`0R8R84024Q8@<0820P0P0O7al00`0N7Qh07alO01lO7`0301hN7P03
01lO7`0N7Qh07QhN00L07AdM00@071`L01dM7@0M7Ad07AdM0`0L71`201dM7@<071`L00<06a/K01dM
7@0K6a/00P0K6a/01@0I6AT06a/K01`L700M7Ad071`L00806a/K00H071`L01/K6`0L71`071`L01/K
6`0J6QX201/K6`0401XJ6P0I6AT06QXJ01XJ6P806a/K00L06QXJ01/K6`0J6QX06ATI01XJ6P0I6AT0
6a/K00806QXJ0`0I6AT60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT201XJ
6P806ATI00@06a/K01XJ6P0K6a/06QXJ0P0K6a/01@0J6QX06a/K01XJ6P0L71`06a/K008071`L00<0
6QXJ01`L700L71`00P0L71`201/K6`<071`L00@06a/K01dM7@0L71`06a/K0`0L71`201dM7@<071`L
00<06a/K01`L700L71`00P0L71`00`0M7Ad071`L01dM7@0201dM7@807QhN0P0M7Ad601hN7P807alO
100N7Qh01@0P82007QhN01lO7`0O7al0820P00807alO00<0820P024Q8@0Q8B400`0P82001@0R8R80
8B4Q020P800R8R808B4Q00<08R8R00L08b<S02@T900T92@09BDU02@T900S8b<092@T00<09BDU0`0V
9RH00`0X:2P09bLW02PX:00502TY:@0>02XZ:P0/;2`0;2`/02d];@0/;2`0;bl_02h^;P0_;bl0<30`
038b<P0a<C40<c<c038b<P0d=3@203Hf=P0303Ph>00i>CT0>c/k0080?Cdm0P0o?cl03`11@D40A4A4
04I6AP1:BTX0CDe=04Y:BP1?Cdl0DE5A059BDP1EEED0FEUI05]KF`1NGUh0H61P06=SH`0206][J`0>
07=cL`1gMgL0MgMg07alO020P800Ph>308R8R029RHT0S8b<096AT@2DU9@0UIFE09JFUP2HV9P209JF
UP0>09>CT`2BTY80T92@08^;R`26QXH0QHF50820P01lO7`0NWYj07MgM`1dM7@0Kfm_06][J`1XJ6P2
06=SH`0805eMG@1IFET0EeMG05=CD`1@D500Cdm?04i>CP1:BTX204Q8B00404E5A@12@T80@D5103lo
?`80?Cdm0P0k>c/00`0j>SX0>3Ph03De=@0303<c<`80<C4a0P0_;bl00`0];Bd0;Rh^02d];@0202`/
;00302/[:`0Z:RX0:RXZ0080:RXZ0P0W9bL00`0X:2P09bLW02HV9P0302DU9@0702@T900U9BD08b<S
02<S8`0T92@08b<S02@T900202<S8`03028R8P0S8b<08R8R00808B4Q00<0820P024Q8@0Q8B400`0P
82000`0N7Qh07alO020P800301lO7`0501hN7P0O7al07QhN01dM7@0N7Qh00P0M7Ad0100O7al07AdM
01hN7P0L71`201dM7@0401`L700M7Ad07AdM01hN7P806a/K1@0L71`301/K6`0301`L700K6a/071`L
00<071`L00P06a/K01`L700K6a/071`L01/K6`0L71`06a/K01`L70D06a/K00@06ATI01/K6`0J6QX0
6QXJ0`0K6a/501XJ6P0301TI6@0J6QX06ATI00806ATI1P3IfMT100000040fMWI000F0=WIf@030000
003IfMT0fMWI00<0fMWI00L06QXJ01TI6@0I6AT06QXJ01/K6`0J6QX06a/K00<06QXJ00L06a/K01TI
6@0J6QX06QXJ01/K6`0J6QX071`L00806QXJ00<071`L01/K6`0K6a/00P0K6a/01@0L71`06QXJ01`L
700K6a/07AdM008071`L0`0K6a/201dM7@8071`L00D06a/K01dM7@0K6a/071`L01dM7@0201`L7003
01dM7@0L71`071`L00807AdM1P0N7Qh01@0M7Ad07QhN01hN7P0N7Qh07AdM00807QhN00d071`L01lO
7`0O7al07QhN01lO7`0Q8B407alO020P800O7al08B4Q020P800N7Qh0820P00@08B4Q00<08R8R02<S
8`0Q8B400P0R8R8502<S8`<092@T0P0U9BD202LW9`0402DU9@0W9bL09RHV02LW9`80:2PX00L09bLW
02/[:`0Z:RX0:b/[02`/;00];Bd0;2`/0080;Bd]0P0_;bl01@0a<C40<30`034a<@0a<C40=3@d0080
<S8b0P0f=SH04@0i>CT0>3Ph03/k>`0k>c/0?Cdm03hn?P0o?cl0@D5104E5A@14A4@0ATI604Y:BP1;
Bd/0CTi>051@D01ADE40EEEE0080EeMG0P1MGEd04P1QHF40IFEU06YZJP1]KFd0KVi^075aL@1eMGD0
OGem07alO022PX80P82008F5Q@28R8P0RHV908Z:RP2<S8`0SHf=08b<S080Rh^;0240QhN708J6QP21
PH40PH6107inOP1jNWX0N7Qh07EeM@1aLG40KFe]06YZJP1UIFD0Hf=S05iNGP1KFe/0FEUI05IFEP1D
E5@0DE5A04m?C`1>CTh0Bd];04U9B@17AdL0@d=304A4A012@T80?Shn03lo?`0k>c/0>SXj03`l?00j
>SX00P0g=cL02@0e=CD0<c<c03@d=00c<c<0<S8b02l_;`0];Bd0;bl_02d];@0302`/;080:b/[0P0Z
:RX01P0Y:BT0:RXZ02PX:00V9RH0:2PX02HV9P809BDU0P0T92@01@0V9RH092@T02DU9@0T92@09BDU
00808b<S100R8R801`0Q8B408R8R024Q8@0Q8B40820P01lO7`0Q8B400`0P820601lO7`0401hN7P0M
7Ad07AdM01hN7PH07AdM00<07QhN01dM7@0L71`00P0N7Qh301dM7@0301/K6`0L71`07AdM00H071`L
00D06a/K01`L700L71`06QXJ01`L700801/K6`806QXJ0P0K6a/201XJ6P0301/K6`0J6QX06QXJ00<0
6QXJ00L06a/K01XJ6P0J6QX06QXJ01/K6`0J6QX06ATI00<06QXJ1P3IfMT100000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI00D06a/K01XJ6P0J6QX06a/K01`L700501XJ6P0:01/K6`0J6QX0
6a/K01TI6@0J6QX06a/K01XJ6P0K6a/071`L01XJ6PD06a/K00@06QXJ01/K6`0L71`06a/K0`0L71`0
100J6QX071`L01dM7@0J6QX301`L700301dM7@0L71`071`L00<071`L00<07AdM01`L700M7Ad0100M
7Ad02P0N7Qh07AdM01dM7@0N7Qh07alO01hN7P0M7Ad07QhN01dM7@0O7al201hN7P04024Q8@0P8200
820P01hN7P807alO00<07QhN020P800P8200100P8200100Q8B40820P020P800Q8B43028R8P0802<S
8`0T92@08b<S02<S8`0T92@08b<S02@T900S8b<402DU9@8092@T00<0:2PX02LW9`0W9bL00`0X:2P0
0`0Z:RX0:BTY02/[:`0202XZ:P80;Bd]00<0;2`/02h^;P0^;Rh00P0_;bl01@0`<300<C4a03<c<`0c
<c<0=CDe0080=SHf00<0=cLg03Xj>P0j>SX00P0k>c/02@0n?Sh0@4100410@012@T80@d=304A4A019
BDT0B4Q804Y:BP0204i>CP06055AD@1EEED0EUIF05YJFP1LG5`0GUiN0P1SHf<02`1WIfL0Jf][06][
J`1_Kfl0Lg=c07IfMP1hN7P0NWYj07emO@1lO7`0OWin0080P8200P21PH401@23Ph<0P8200861P@20
P800Ng]k0080N7Qh00H0M7Ad071`L01^KVh0JVYZ06][J`1TI6@2061PH00605aLG01JFUX0EeMG05=C
D`1DE5@0Cdm?0P1>CTh04019BDT0ADE504M7A`12@T80@d=30410@00n?Sh0?Cdm03`l?00j>SX0>c/k
03Ph>00g=cL0=SHf03De=@0c<c<2034a<@80<30`00H0;bl_030`<00];Bd0;Bd]02`/;00Z:RX202/[
:`<0:RXZ00<09RHV02PX:00W9bL00P0W9bL302HV9P0502@T900U9BD08b<S02@T900S8b<00`0T92@0
100R8R808b<S024Q8@0Q8B43028R8P03020P800R8R80820P00@07alO00T0820P01lO7`0N7Qh07alO
01hN7P0P82007QhN01dM7@0N7Qh00P0M7Ad01P0N7Qh071`L01dM7@0N7Qh07AdM01hN7P807AdM0P0L
71`01`0M7Ad071`L01dM7@0M7Ad07QhN01`L700K6a/0100L71`201/K6`0301`L700K6a/06a/K0080
6a/K00<071`L01/K6`0L71`00`0K6a/00`0L71`06QXJ01XJ6P0301/K6`0301XJ6P0K6a/06a/K0080
6a/K1@0J6QX00`0I6AT06QXJ01XJ6P0201TI6@806QXJ1P3IfMT100000040fMWI000F0=WIf@030000
003IfMT0fMWI00<0fMWI00<06QXJ01/K6`0J6QX00P0J6QX201/K6`<06QXJ00<06ATI01/K6`0K6a/0
0P0K6a/201XJ6P0401/K6`0L71`06a/K01XJ6PD06a/K1@0L71`01P0K6a/071`L01XJ6P0L71`06a/K
01dM7@<071`L00<07QhN01`L700L71`0100M7Ad00`0N7Qh071`L01`L700201hN7P0301`L700N7Qh0
71`L00@07AdM1@0N7Qh201lO7`03020P800O7al07QhN00807alO00@0820P01lO7`0P82008B4Q0P0P
8200100Q8B40820P024Q8@0S8b<3024Q8@0302<S8`0T92@08b<S00<08b<S0P0T92@0100S8b<09RHV
02DU9@0U9BD302HV9P0302LW9`0V9RH09bLW0080:2PX00<0:BTY02`/;00Z:RX0100[:b/0100_;bl0
;Bd]02d];@0_;bl2030`<0<0<S8b00D0<c<c03@d=00f=SH0=cLg03Xj>P0203Ti>@0303`l?00n?Sh0
?clo0080@41000@0A4A404=3@`18B4P0B4Q80P1;Bd/01`1?Cdl0DE5A059BDP1EEED0EUIF05QHF01O
Gel00P1PH6001P1UIFD0IfMW06YZJP1^KVh0LG5a079bLP80MGEe00<0NGUi07YjNP1kNg/0101mOGd0
1@1oOgl0O7al07]kN`1hN7P0NGUi0080Lg=c00/0Kfm_06][J`1[Jf/0LW9b06a/K01SHf<0GemO061P
H01LG5`0EUIF05ADE002059BDP0:04m?C`1<C4`0C4a<04Q8B015ADD0ATI60492@P11@D40?clo03dm
?@80?3`l00D0>CTi03Ph>00h>3P0=cLg03Hf=P0203De=@<0<C4a0P0_;bl0100^;Rh0;2`/02h^;P0/
;2`202/[:`0402XZ:P0X:2P0:BTY02XZ:P80:2PX00H09bLW02PX:00V9RH09RHV02DU9@0V9RH302DU
9@0602<S8`0R8R808b<S02DU9@0S8b<08R8R0`0S8b<2028R8P80820P00/08R8R024Q8@0O7al07alO
01hN7P0O7al0820P01lO7`0P82007alO01hN7P0201lO7`0401dM7@0N7Qh07QhN01hN7P807AdM00<0
7QhN01dM7@0N7Qh00P0M7Ad0100L71`07AdM01dM7@0L71`301dM7@0501hN7P0M7Ad07AdM01`L700K
6a/0100L71`0100M7Ad071`L01`L700L71`201/K6`0501TI6@0J6QX06QXJ01`L700J6QX00`0K6a/0
100J6QX06a/K01XJ6P0L71`801/K6`0301XJ6P0I6AT06QXJ00806ATI00<06a/K01TI6@0I6AT01P3I
fMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00D06a/K01XJ6P0K6a/06ATI01/K
6`0201XJ6P0301/K6`0J6QX06ATI00@06QXJ00@06a/K01XJ6P0J6QX071`L0`0K6a/00`0L71`06a/K
01/K6`0201/K6`8071`L0P0K6a/0300L71`06a/K01/K6`0M7Ad071`L01/K6`0L71`07AdM01/K6`0L
71`07AdM01`L70807AdM00@071`L01dM7@0L71`071`L100M7Ad0100N7Qh07AdM01dM7@0M7Ad201hN
7P0401dM7@0K6a/07QhN01lO7`807QhN0`0O7al02P0P82007alO01hN7P0P82008R8R020P800O7al0
8B4Q020P800O7al2024Q8@03020P800R8R808B4Q00808R8R00<08b<S024Q8@0S8b<00P0R8R8402@T
90809BDU00@09RHV02DU9@0U9BD09RHV0P0W9bL202PX:00802LW9`0Y:BT0:BTY02TY:@0Z:RX0;Bd]
02XZ:P0/;2`302d];@0402l_;`0^;Rh0<C4a034a<@80<S8b00L0<C4a03<c<`0d=3@0>3Ph03Ti>@0g
=cL0>SXj0080>c/k00@0?Shn03dm?@0o?cl0@T920P15ADD204Q8B00H04a<C01:BTX0Cdm?055AD@1C
De<0E5AD05QHF01IFET0G5aL05iNGP1PH600Hf=S06MWI`1YJFT0JVYZ06][J`1]KFd0L71`079bLP1e
MGD0MWIf07AdM01fMWH0MgMg0P1fMWH02@1eMGD0Lg=c075aL@1aLG40KVi^06][J`1XJ6P0JFUY06MW
I`02065QH@07061PH01LG5`0G5aL05QHF01DE5@0De=C055AD@0204e=C@0904Y:BP19BDT0ADE504E5
A@12@T80@4100451@@0n?Sh0?Cdm0080>c/k0P0i>CT01@0g=cL0=CDe03De=@0d=3@0<c<c0080<C4a
00@0<S8b02l_;`0^;Rh0;Rh^0P0/;2`0100[:b/0:RXZ02/[:`0[:b/302PX:00702LW9`0X:2P09bLW
02LW9`0V9RH09bLW02@T900302DU9@8092@T00@09BDU02<S8`0S8b<08b<S0P0T92@202<S8`808B4Q
00@08R8R024Q8@0R8R808B4Q0`0O7al00`0N7Qh07alO01hN7P0301lO7`0501hN7P0O7al07QhN01hN
7P0O7al00`0N7Qh0200M7Ad07QhN01dM7@0K6a/07QhN01dM7@0L71`07QhN0P0L71`00`0M7Ad071`L
01dM7@0301`L700301/K6`0L71`071`L00@071`L00<06a/K01TI6@0L71`00P0K6a/00`0I6AT06QXJ
01/K6`0201/K6`<06QXJ0P0K6a/0100J6QX071`L01/K6`0J6QX201/K6`<06QXJ00<06a/K01XJ6P0I
6AT00P0J6QX301TI6@H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0301XJ
6P0K6a/06QXJ00806QXJ00@06a/K01XJ6P0J6QX06a/K0P0J6QX0100L71`06a/K01XJ6P0K6a/201`L
70@06a/K00D071`L01/K6`0K6a/06a/K01`L700301/K6`8071`L0P0K6a/00`0L71`06QXJ01`L7002
01/K6`0701dM7@0L71`07AdM01`L700M7Ad071`L01hN7P0201`L70807QhN00@071`L01hN7P0N7Qh0
7AdM0P0L71`0100M7Ad07QhN01hN7P0N7Qh201dM7@807QhN00@07AdM01hN7P0O7al0820P0P0O7al0
0`0N7Qh07alO020P800201lO7`@08B4Q00<0820P024Q8@0Q8B400P0Q8B401P0S8b<08R8R024Q8@0R
8R808b<S02@T90<08b<S00@092@T02HV9P0U9BD09RHV0P0U9BD00`0X:2P09BDU02LW9`0302PX:004
02TY:@0X:2P0:2PX02`/;080:b/[00<0;2`/02h^;P0];Bd00P0^;Rh01@0`<300;Rh^034a<@0c<c<0
<C4a0080<c<c00<0=3@d03Hf=P0g=cL00P0i>CT02P0j>SX0?Cdm03`l?00n?Sh0?clo0492@P13@d<0
ADE504I6AP18B4P204Y:BP0<04m?C`1@D500DE5A05ADE01EEED0EUIF05UIF@1KFe/0GemO065QH@1T
I6@0IVIV0P1XJ6P0101YJFT0KFe]06m_K`1^KVh2075aL@0S07=cL`1dM7@0LG5a079bLP1_Kfl0K6a/
06m_K`1]KFd0JVYZ06UYJ@1WIfL0IFEU06ATI01RHV80H61P05eMG@1IFET0Fe]K05EEE@1BDU80DE5A
04m?C`1>CTh0Bd];04Q8B019BDT0ATI604E5A@13@d<0@T9203lo?`0m?Cd0>c/k03Ti>@0j>SX00P0i
>CT0100g=cL0=CDe03@d=00c<c<2038b<P03030`<00a<C40;Rh^0080;bl_0P0];Bd0100/;2`0:b/[
02/[:`0Y:BT402PX:00602HV9P0W9bL09bLW02LW9`0V9RH09BDU1@0T92@00`0U9BD092@T02<S8`02
02<S8`<08R8R00H08B4Q028R8P0Q8B408R8R020P800Q8B42020P80808B4Q00@07QhN01lO7`0O7al0
7alO0P0N7Qh301dM7@@07QhN0P0M7Ad0100N7Qh07AdM01dM7@0M7Ad201`L700701dM7@0L71`071`L
01dM7@0L71`07AdM01/K6`0201dM7@<071`L00<06a/K01dM7@0K6a/00P0L71`0100K6a/071`L01XJ
6P0J6QX301/K6`806QXJ00H06a/K01`L700L71`06a/K01TI6@0J6QX201/K6`806QXJ00<071`L01XJ
6P0J6QX01P0J6QX00`0I6AT061PH0=WIf@050=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`0J6QX06ATI01XJ6P0201/K6`806QXJ00<06a/K01XJ6P0K6a/00`0K6a/201XJ6P03
01/K6`0J6QX06a/K00806a/K00@071`L01/K6`0K6a/071`L0`0K6a/00`0J6QX06a/K01`L700201`L
700901XJ6P0K6a/071`L01dM7@0K6a/071`L01dM7@0K6a/07AdM008071`L00<07AdM01`L700M7Ad0
0P0M7Ad0100L71`07AdM01dM7@0L71`501dM7@807QhN0P0M7Ad301hN7P0401lO7`0M7Ad07alO01hN
7P<0820P00@08B4Q01lO7`0Q8B40820P0P0Q8B400`0P82008B4Q024Q8@02024Q8@808R8R00L08b<S
02@T900P82008b<S028R8P0S8b<092@T00808b<S1@0U9BD01@0T92@09bLW02HV9P0V9RH09bLW0080
:BTY00@0:2PX02XZ:P0[:b/0:b/[0P0/;2`302d];@0702l_;`0^;Rh0;bl_030`<00b<S80<30`03@d
=00203<c<`0503Hf=P0g=cL0>3Ph03Ti>@0h>3P00P0k>c/00`0m?Cd0?Shn0451@@0204=3@`0404A4
A016ATH0BDU904Q8B080Bd];00@0Cdm?055AD@1BDU80E5AD0P1GEeL0101KFe/0GemO05mOG`1QHF42
06=SH`0306IVIP1WIfL0IVIV0080Jf][00<0K6a/06YZJP1/K6`00P1YJFT01`1/K6`0JFUY06IVIP1W
IfL0J6QX06EUI@1RHV800P1QHF40301KFe/0FEUI05UIF@1FEUH0EEEE05=CD`1?Cdl0D51@04];B`1<
C4`0BTY:04U9B@80ADE500H0A4A40451@@11@D40?Shn03`l?00k>c/203Xj>P0603Lg=`0f=SH0=cLg
03@d=00e=CD0<c<c0P0a<C400`0`<300;bl_02l_;`0202h^;P0502`/;00];Bd0:b/[02/[:`0Z:RX0
0`0Y:BT00`0X:2P09bLW02HV9P0202HV9P0302DU9@0V9RH092@T00H092@T00D08R8R02@T900S8b<0
8B4Q028R8P0302<S8`@08B4Q00<0820P01lO7`0O7al00P0O7al02@0P82007QhN01hN7P0N7Qh0820P
01lO7`0M7Ad07QhN01dM7@0301hN7P807AdM00@07QhN01dM7@0M7Ad071`L0P0M7Ad501`L700601dM
7@0L71`07QhN01`L700M7Ad06QXJ0`0K6a/00`0L71`06a/K01/K6`0301/K6`0301dM7@0K6a/071`L
00@06a/K00<06QXJ01/K6`0K6a/00P0K6a/00`0J6QX06a/K01/K6`0201/K6`0401XJ6P0K6a/06QXJ
01XJ6P806ATI00D06a/K01XJ6P0K6a/06QXJ01TI6@060=WIf@4000000@3IfMT001H0fMWI00<00000
0=WIf@3IfMT00`3IfMT201XJ6P0301/K6`0J6QX06QXJ00806QXJ0P0I6AT01P0K6a/071`L01`L700K
6a/071`L01XJ6P806a/K0P0J6QX201`L700301/K6`0J6QX06a/K00806a/K00L06QXJ01`L700K6a/0
71`L01/K6`0L71`06a/K00D071`L00X07AdM01/K6`0K6a/071`L01dM7@0L71`07AdM01`L700K6a/0
7QhN100M7Ad01P0L71`07AdM01dM7@0L71`07QhN01dM7@H07QhN00<07alO01hN7P0O7al00`0N7Qh2
020P800701hN7P0P8200820P01lO7`0Q8B40820P01lO7`02024Q8@06028R8P0Q8B408b<S028R8P0S
8b<08B4Q0`0S8b<00`0T92@08b<S02DU9@0202@T90809BDU100V9RH01`0W9bL0:BTY02PX:00W9bL0
:BTY02XZ:P0Y:BT00`0[:b/03`0/;2`0;Bd]02h^;P0];Bd0;Rh^02l_;`0`<300;bl_02h^;P0b<S80
=3@d038b<P0e=CD0=SHf03Lg=`0203Ti>@0403Xj>P0l?3`0?Cdm03hn?P80@41000d0@T9204A4A014
A4@0ATI604M7A`1:BTX0Bd];04a<C01?Cdl0CTi>059BDP1CDe<0E5AD0080F5QH0180Fe]K05eMG@1M
GEd0H61P05mOG`1QHF40HV9R06EUI@1TI6@0Hf=S06ATI01UIFD0IVIV06EUI@1TI6@0Hf=S065QH@1R
HV8205mOG`0605iNGP1KFe/0Fe]K05UIF@1HF5P0EeMG0P1DE5@00`1?Cdl0CDe=04e=C@0204U9B@04
04I6AP15ADD0@d=30492@P80@41000H0?Shn03dm?@0k>c/0>SXj03Ti>@0h>3P203Hf=P80<c<c00<0
=CDe038b<P0a<C400P0`<3000`0_;bl0;Rh^02`/;00202d];@0302/[:`0Z:RX0:b/[0080:BTY00P0
:2PX02TY:@0W9bL0:2PX02LW9`0V9RH09BDU02HV9P<09BDU0P0T92@01@0S8b<092@T02DU9@0T92@0
8R8R00808b<S00D08R8R02<S8`0R8R808R8R020P8004024Q8@0401lO7`0Q8B407alO020P80@07alO
0`0N7Qh01P0L71`07QhN01hN7P0M7Ad07QhN01lO7`807QhN0P0L71`201dM7@0701hN7P0L71`071`L
01`L700M7Ad071`L01dM7@0301`L700301XJ6P0K6a/07AdM008071`L00<06QXJ01`L700L71`00P0K
6a/301`L700301/K6`0L71`071`L00@06a/K1P0J6QX0100K6a/06QXJ01XJ6P0I6AT201/K6`@06QXJ
00<06ATI01XJ6P0J6QX01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00@0
6QXJ01/K6`0I6AT06ATI0P0J6QX0100K6a/06QXJ01/K6`0K6a/301XJ6P0401`L700K6a/06QXJ01XJ
6P<06a/K00<071`L01/K6`0K6a/00P0K6a/00`0J6QX071`L01/K6`0301XJ6P0401/K6`0L71`06a/K
01`L70806a/K00@071`L01/K6`0L71`07AdM0`0L71`00`0N7Qh071`L01dM7@0201dM7@0401`L700M
7Ad07AdM01`L70807AdM0P0N7Qh201dM7@0701hN7P0O7al07QhN01lO7`0N7Qh07alO01hN7P0401lO
7`04020P800Q8B40820P01lO7`80820P00<08B4Q020P800Q8B400`0Q8B401P0R8R808b<S024Q8@0S
8b<08B4Q02<S8`8092@T00D08b<S02@T900T92@08b<S02@T900302DU9@0302HV9P0X:2P09BDU00<0
9bLW00@09RHV02LW9`0Z:RX0:BTY100[:b/01`0/;2`0;Bd]02h^;P0];Bd0;bl_030`<00a<C400P0b
<S800`0c<c<0=CDe03De=@0203De=@0403Ti>@0h>3P0>CTi03/k>`80?Shn00X0?clo0451@@11@D40
@D5104A4A015ADD0AdM704U9B@1;Bd/0C4a<0P1>CTh2055AD@0B05=CD`1FEUH0EeMG05IFEP1JFUX0
G5aL05]KF`1MGEd0GemO065QH@1SHf<0H61P06EUI@1RHV80H61P069RHP1SHf<0HF5Q0P1PH6003`1Q
HF40G5aL05]KF`1KFe/0FEUI05YJFP1HF5P0EeMG05ADE01BDU80D51@04m?C`1>CTh0BDU904Y:BP02
04M7A`<0@d=300/0@41003lo?`0o?cl0?3`l03/k>`0i>CT0>SXj03Ph>00f=SH0=3@d03De=@0203<c
<`05034a<@0b<S80<30`02h^;P0_;bl00`0];Bd0100/;2`0:RXZ02`/;00Y:BT202XZ:P0302PX:00W
9bL09bLW00809bLW00P09RHV02LW9`0V9RH09BDU02HV9P0T92@09BDU02<S8`8092@T00@08b<S02@T
900S8b<08b<S100R8R80100S8b<08B4Q024Q8@0Q8B42020P800401lO7`0P82007alO01hN7P@07alO
100N7Qh00`0O7al07QhN01hN7P0301dM7@807QhN00P071`L01dM7@0L71`071`L01hN7P0L71`07AdM
01hN7P8071`L00<07AdM01/K6`0L71`00P0L71`01`0M7Ad06a/K01`L700L71`06a/K01`L700K6a/0
0P0L71`00`0K6a/07AdM01/K6`0601/K6`D06QXJ00@06ATI01XJ6P0J6QX06a/K0`0J6QX01@0K6a/0
6QXJ01TI6@0I6AT06QXJ00806ATI1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0
fMWI0P0J6QX01`0I6AT06QXJ01/K6`0I6AT06QXJ01/K6`0J6QX00P0K6a/00`0J6QX071`L01/K6`07
01/K6`0401TI6@0L71`06a/K01XJ6P@071`L00<06a/K01`L700L71`00P0L71`00`0J6QX071`L01`L
700301`L70807AdM00D071`L01/K6`0L71`07AdM01`L700301dM7@0501`L700M7Ad07AdM01hN7P0M
7Ad0100N7Qh0100M7Ad07QhN01lO7`0M7Ad201lO7`0401hN7P0O7al07QhN01hN7P<0820P00P07alO
020P800P8200820P024Q8@0P82008B4Q020P80<08R8R00H08b<S028R8P0S8b<08R8R02<S8`0U9BD3
02<S8`8092@T00@09BDU02@T900T92@09BDU0P0V9RH302LW9`0402TY:@0X:2P0:2PX02TY:@80:RXZ
00<0:b/[02`/;00/;2`00P0/;2`01@0];Bd0;Rh^02h^;P0^;Rh0<30`0080<C4a0`0b<S80100g=cL0
=SHf03Hf=P0f=SH203Xj>P0303`l?00j>SX0?Cdm0080?clo00@0@4100492@P14A4@0A4A40P18B4P0
2`1:BTX0Bd];04a<C01>CTh0Cdm?051@D01BDU80De=C05IFEP1EEED0FEUI0080FUYJ00L0Fe]K05aL
G01NGUh0Fe]K05eMG@1OGel0GUiN00<0GEeM00L0G5aL05]KF`1JFUX0FUYJ05UIF@1HF5P0EUIF00<0
De=C00H0DE5A04m?C`1>CTh0CDe=04Y:BP1;Bd/204I6AP0904E5A@12@T80@T920410@00o?cl0?Shn
03`l?00j>SX0>CTi0080=cLg0P0f=SH0100d=3@0<c<c03<c<`0c<c<2034a<@03030`<00_;bl0;bl_
00<0;2`/0P0[:b/00`0/;2`0:BTY02XZ:P0302PX:00302LW9`0X:2P09RHV00809bLW0P0V9RH00`0U
9BD092@T02DU9@0202<S8`0902@T900S8b<08R8R02<S8`0R8R8092@T028R8P0S8b<08R8R0080820P
00D08B4Q020P800P82008B4Q020P8002024Q8@0401lO7`0N7Qh07QhN01hN7P807alO0`0N7Qh00`0O
7al07QhN01dM7@0701dM7@0701hN7P0M7Ad07AdM01`L700M7Ad071`L01dM7@0301`L700401dM7@0L
71`07AdM01`L70806a/K00<071`L01/K6`0K6a/00`0K6a/01@0L71`06a/K01/K6`0K6a/06QXJ00@0
6a/K100J6QX00`0K6a/06QXJ01/K6`0201XJ6P0801TI6@0J6QX06a/K01XJ6P0I6AT06a/K01TI6@0J
6QX201TI6@H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0301/K6`0J6QX0
6QXJ00@06QXJ00<06ATI01XJ6P0K6a/00P0J6QX01`0K6a/071`L01/K6`0K6a/071`L01/K6`0L71`0
0P0J6QX00`0L71`06a/K01/K6`0401/K6`8071`L0P0K6a/201`L700501/K6`0L71`071`L01`L700K
6a/00`0L71`201dM7@0501`L700M7Ad071`L01dM7@0L71`00P0M7Ad00`0L71`07AdM01dM7@0201hN
7P<07AdM0P0O7al00`0N7Qh07alO01hN7P0201lO7`0301hN7P0O7al07alO00<07alO0P0P820201lO
7`06020P800Q8B408B4Q024Q8@0S8b<08B4Q0`0R8R800`0Q8B408R8R02<S8`0502<S8`0302@T900U
9BD09RHV00@09RHV0P0W9bL202HV9P0302PX:00Z:RX0:b/[0080:BTY0`0[:b/0100/;2`0;Bd]02`/
;00];Bd202l_;`80<30`00@0<S8b03<c<`0b<S80=CDe0P0d=3@303Hf=P0803/k>`0j>SX0?3`l03dm
?@0l?3`0?clo0410@011@D4204=3@`0I04E5A@16ATH0AdM704Q8B01:BTX0Bd];04a<C01=CDd0CTi>
051@D01ADE40EEEE05ADE01EEED0EeMG05IFEP1GEeL0EUIF05MGE`1IFET0FUYJ05UIF@1JFUX0F5QH
05UIF@0205MGE`<0EEEE00<0De=C05ADE01@D5000P1?Cdl01@1>CTh0C4a<04];B`1:BTX0ATI60080
AdM700D0ADE50451@@14A4@0@D5103lo?`0203`l?00403/k>`0j>SX0>CTi03Ph>080=SHf00/0=CDe
03@d=00d=3@0<C4a03<c<`0a<C40<30`02d];@0/;2`0;Rh^02d];@0202`/;00502XZ:P0[:b/0:b/[
02PX:00Z:RX0100X:2P0200V9RH09BDU02LW9`0V9RH092@T02DU9@0V9RH09BDU0P0T92@202<S8`05
028R8P0Q8B408b<S02<S8`0R8R800`0Q8B400`0O7al0820P024Q8@04020P800501lO7`0P82007alO
01hN7P0P8200100O7al201hN7P<07AdM00<07QhN01dM7@0M7Ad00P0M7Ad00`0L71`07AdM01`L7007
01`L70<07AdM100L71`00`0K6a/071`L01/K6`0201/K6`8071`L00<06QXJ01`L700K6a/00P0K6a/0
2P0J6QX06a/K01`L700J6QX06a/K01XJ6P0K6a/06QXJ01TI6@0J6QX201/K6`806QXJ00L06ATI01XJ
6P0K6a/06QXJ01TI6@0J6QX06ATI00806QXJ1P3IfMT100000040fMWI000F0=WIf@800000103IfMT6
01XJ6P@06a/K0P0J6QX01`0M7Ad06a/K01`L700K6a/06QXJ01/K6`0J6QX0100K6a/02P0M7Ad06a/K
01/K6`0K6a/06QXJ01/K6`0L71`06a/K01XJ6P0K6a/201XJ6P0301/K6`0M7Ad071`L008071`L00<0
7AdM01/K6`0L71`00P0L71`00`0M7Ad071`L01dM7@0601dM7@0401`L700O7al07alO01hN7P807alO
00H07AdM01hN7P0O7al07QhN01lO7`0N7Qh601lO7`05020P800Q8B407alO01lO7`0P82000P0Q8B40
1`0R8R808B4Q024Q8@0R8R808b<S028R8P0T92@00P0Q8B400`0R8R808b<S02@T900202<S8`8092@T
00@09BDU02@T900W9bL09bLW0P0V9RH0100W9bL09RHV02LW9`0W9bL202TY:@0502PX:00Z:RX0:RXZ
02XZ:P0[:b/00`0/;2`202d];@0=02l_;`0a<C40;bl_030`<00b<S80<c<c03@d=00e=CD0<c<c03@d
=00f=SH0>3Ph03Ti>@0203/k>`0403`l?00m?Cd0?3`l03hn?P80@4100P13@d<02015ADD0AdM704M7
A`19BDT0Bd];04a<C01;Bd/0CTi>0P1?Cdl00`1@D500E5AD05ADE00205ADE080EEEE00H0EeMG05QH
F01GEeL0F5QH05MGE`1EEED305MGE`0405=CD`1DE5@0E5AD055AD@80D51@00D0CTi>04e=C@1;Bd/0
Bd];04Y:BP0204M7A`0404E5A@13@d<0@T920451@@80@4100P0m?Cd03@0l?3`0>c/k03Xj>P0i>CT0
=cLg03Hf=P0e=CD0=3@d038b<P0c<c<0<C4a038b<P0a<C400P0_;bl02`0];Bd0;Rh^02d];@0[:b/0
;Bd]02XZ:P0/;2`0:BTY02PX:00Z:RX0:BTY00809bLW00H0:2PX02DU9@0W9bL09RHV02DU9@0V9RH2
02DU9@0402@T900S8b<08b<S02<S8`808R8R0P0Q8B400`0S8b<08R8R028R8P03024Q8@08020P800Q
8B40820P020P800O7al08R8R01lO7`0P820601lO7`807QhN00<07AdM01hN7P0N7Qh00`0M7Ad00`0L
71`07AdM01dM7@0301`L700301hN7P0L71`071`L008071`L00D06a/K01dM7@0L71`071`L01dM7@02
01`L700701/K6`0L71`06a/K01`L700M7Ad071`L01/K6`0201`L700301/K6`0L71`06QXJ00806a/K
0P0J6QX201/K6`806QXJ00T071`L01XJ6P0J6QX06a/K01TI6@0J6QX06a/K01XJ6P0I6AT00P0J6QX0
0`0K6a/06ATI01XJ6P0301TI6@D0fMWI0P0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WI
f@<06ATI0P0J6QX301/K6`0501`L700J6QX06a/K01/K6`0L71`00`0K6a/0100J6QX06a/K01XJ6P0J
6QX501/K6`0301`L700K6a/07AdM00D071`L00D06a/K01`L700M7Ad071`L01XJ6P0201`L70807AdM
00X071`L01dM7@0K6a/07AdM01`L700M7Ad071`L01dM7@0L71`07AdM0P0L71`01@0O7al07AdM01/K
6`0N7Qh07AdM00807alO0P0M7Ad00`0P82007QhN01hN7P0201lO7`0501hN7P0O7al07alO01hN7P0O
7al00`0P8200100Q8B40820P020P800R8R82024Q8@04028R8P0Q8B408b<S028R8P@08b<S00@092@T
02<S8`0S8b<08b<S0P0T92@402DU9@0502LW9`0T92@09RHV02HV9P0W9bL00P0X:2P01@0Y:BT0:RXZ
02TY:@0Z:RX0:b/[0080;2`/00P0;Bd]02h^;P0^;Rh0;Rh^030`<00_;bl0<C4a030`<080<S8b00@0
<c<c03@d=00e=CD0=SHf0P0g=cL0100h>3P0>CTi03Xj>P0k>c/203`l?00703lo?`10@400@4100492
@P15ADD0@d=304I6AP0204Q8B080BTY:0P1<C4`0101=CDd0D51@055AD@1?Cdl3055AD@09059BDP1C
De<0E5AD05ADE01BDU80De=C05ADE01BDU80De=C00<0DE5A00X0D51@04i>CP1?Cdl0CTi>04Y:BP1;
Bd/0BTY:04U9B@17AdL0B4Q80P14A4@01P11@D40@4100451@@0n?Sh0?clo03`l?080>c/k00D0>SXj
03Ph>00g=cL0=3@d03De=@0303<c<`80<C4a00L0<30`02l_;`0^;Rh0;bl_02h^;P0];Bd0;Rh^00D0
:b/[00<0:BTY02LW9`0Y:BT00P0X:2P00`0W9bL09RHV02PX:00202HV9P0302DU9@0T92@092@T00<0
92@T00D08b<S028R8P0R8R808R8R02<S8`02024Q8@0502<S8`0Q8B408B4Q020P800Q8B400P0P8200
0`0O7al0820P020P8002020P800601lO7`0N7Qh0820P01lO7`0N7Qh07alO0P0M7Ad601hN7P0401/K
6`0M7Ad07AdM01`L70807AdM00<06a/K01dM7@0M7Ad00`0L71`00`0N7Qh071`L01`L700201`L7003
01/K6`0L71`071`L00@06a/K00<071`L01/K6`0L71`00`0L71`801/K6`806QXJ00@06ATI01XJ6P0K
6a/06QXJ0P0I6AT301XJ6P0601TI6@0J6QX06QXJ01/K6`0J6QX06ATI1P3IfMT100000040fMWI000F
0=WIf@030000003IfMT0fMWI00<0fMWI00<06ATI01/K6`0J6QX00`0J6QX201/K6`0301`L700K6a/0
71`L00<06a/K00P071`L01/K6`0K6a/06QXJ01/K6`0J6QX06a/K01TI6@806a/K00/06QXJ01`L700L
71`06a/K01`L700K6a/071`L01XJ6P0L71`06a/K01XJ6P0301`L700401dM7@0K6a/06a/K01`L7080
7AdM0P0L71`301dM7@0601`L700M7Ad07AdM01hN7P0L71`07QhN0P0M7Ad301hN7P0301lO7`0N7Qh0
7QhN00<07alO00T07QhN01lO7`0N7Qh07alO020P800O7al08B4Q020P800O7al00P0P8202024Q8@80
820P0P0Q8B42028R8P03024Q8@0R8R808b<S00<08b<S0P0U9BD0100T92@08b<S02DU9@0U9BD202@T
900402HV9P0X:2P0:2PX02HV9P809bLW00D0:RXZ02TY:@0Y:BT0:b/[02TY:@0202XZ:P0502/[:`0/
;2`0:b/[02d];@0/;2`00P0_;bl0100`<300<S8b030`<00a<C4303@d=00403Hf=P0g=cL0=cLg03De
=@80>3Ph00X0>CTi03Xj>P0m?Cd0?3`l03hn?P10@400@D510492@P13@d<0@T920P14A4@01@15ADD0
ATI604M7A`1:BTX0BDU90080C4a<0P1>CTh0101?Cdl0CDe=04i>CP1@D503055AD@03059BDP1ADE40
DE5A0080DU9B00D0D51@04m?C`1>CTh0Cdm?04a<C00204];B`80BTY:00D0BDU904I6AP13@d<0AdM7
04=3@`020492@P<0?clo00@0?Cdm03/k>`0l?3`0>c/k0P0h>3P01@0g=cL0=SHf03De=@0d=3@0<c<c
00<0<C4a00H0<S8b030`<00`<300;Bd]02h^;P0];Bd202/[:`0:02`/;00Z:RX0:b/[02XZ:P0Y:BT0
:2PX02TY:@0X:2P09bLW02HV9P80:2PX00<092@T02DU9@0V9RH00P0T92@02P0U9BD092@T02<S8`0R
8R808b<S028R8P0S8b<08R8R024Q8@0R8R83024Q8@07028R8P0O7al0820P020P800O7al08B4Q020P
800401lO7`@07QhN00<07AdM01lO7`0N7Qh00`0N7Qh201`L700401dM7@0L71`07QhN01`L70807AdM
00@071`L01dM7@0L71`071`L100M7Ad301`L700501dM7@0K6a/071`L01/K6`0J6QX00P0K6a/02P0L
71`06QXJ01/K6`0K6a/071`L01/K6`0J6QX06a/K01XJ6P0K6a/201XJ6P806a/K0P0J6QX01P0K6a/0
6QXJ01XJ6P0K6a/06QXJ01PH60806a/K00D06ATI01/K6`0J6QX06QXJ01PH600201TI6@H0fMWI0@00
00010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@806QXJ00<06a/K01XJ6P0J6QX00`0J6QX0
0`0K6a/06QXJ01/K6`0501/K6`0301`L700K6a/06a/K00806a/K0P0J6QX201/K6`0501`L700K6a/0
6a/K01`L700K6a/00`0L71`00`0K6a/071`L01`L700501`L70<07AdM0P0L71`01@0M7Ad071`L01`L
700K6a/071`L00@07AdM0P0N7Qh01@0O7al07QhN01dM7@0N7Qh07AdM00<07alO0P0N7Qh201lO7`03
020P800N7Qh07alO00<07alO00<0820P01lO7`0Q8B400P0Q8B401@0R8R808B4Q024Q8@0R8R808b<S
00<08R8R0P0T92@01`0S8b<09BDU02@T900T92@08b<S02DU9@0T92@0100U9BD01@0V9RH09bLW02PX
:00V9RH09bLW0080:2PX00H0:RXZ02TY:@0Z:RX0:RXZ02`/;00[:b/202`/;00802h^;P0_;bl0<30`
02d];@0`<300<C4a038b<P0a<C4203<c<`0603@d=00c<c<0=CDe03De=@0f=SH0>3Ph0P0i>CT203Xj
>P0303`l?00o?cl0?clo0080@41000X0@D5104A4A014A4@0ADE504A4A015ADD0B4Q804U9B@18B4P0
BDU90`1;Bd/0101<C4`0Cdm?04m?C`1@D50404i>CP03051@D01<C4`0C4a<0080C4a<00<0CDe=04];
B`1:BTX00P17AdL00`19BDT0ATI604Q8B00204E5A@80@D510100@41003hn?P0o?cl0?Shn03dm?@0l
?3`0>3Ph03Xj>P0i>CT0>3Ph03Ti>@0f=SH0=3@d03De=@0d=3@0<c<c0`0a<C40100_;bl0;Rh^02l_
;`0^;Rh202d];@0302`/;00Z:RX0:RXZ00@0:RXZ00<0:2PX02LW9`0W9bL00P0W9bL00`0V9RH09BDU
02DU9@0202DU9@0302@T900S8b<092@T00<08b<S00d08R8R02<S8`0R8R808b<S024Q8@0R8R808B4Q
02<S8`0R8R80820P024Q8@0P82008B4Q0080820P0P0O7al00`0P82007alO01hN7P0201lO7`03020P
800M7Ad07AdM00807AdM00@07alO01dM7@0N7Qh07QhN0P0M7Ad01@0L71`06a/K01`L700L71`07QhN
00807AdM0P0L71`0100K6a/071`L01`L700K6a/301`L700301/K6`0L71`06a/K00@06a/K00P071`L
01/K6`0L71`06a/K01`L700K6a/06QXJ01/K6`806QXJ00<06a/K01XJ6P0I6AT00`0K6a/201TI6@@0
6QXJ00D06a/K01XJ6P0J6QX06QXJ01PH600201XJ6P0301TI6@0J6QX0fMWI00D0fMWI0@0000010=WI
f@005P3IfMT00`000000fMWI0=WIf@030=WIf@0301/K6`0J6QX06QXJ00806QXJ00<06a/K01TI6@0J
6QX00`0J6QX00`0I6AT06a/K01`L700201/K6`0301dM7@0K6a/06QXJ00806QXJ0P0K6a/01P0J6QX0
6a/K01/K6`0K6a/071`L01TI6@806a/K00H071`L01/K6`0M7Ad07AdM01XJ6P0M7Ad701`L700301hN
7P0L71`07AdM00X07AdM0P0N7Qh00`0L71`07QhN01hN7P0201hN7P03020P800O7al07alO00<07alO
0P0N7Qh00`0O7al0820P020P8002020P8005024Q8@0P82008B4Q024Q8@0R8R800P0Q8B4202<S8`80
8R8R0P0S8b<00`0R8R808b<S02@T900202@T900902<S8`0U9BD092@T02DU9@0V9RH09BDU02LW9`0V
9RH0:2PX00809bLW0P0X:2P01@0Y:BT0:RXZ02XZ:P0Y:BT0:b/[0080;2`/00L0;Bd]02`/;00/;2`0
;Bd]02l_;`0^;Rh0<30`0080<C4a00D0<S8b03@d=00b<S80<S8b03De=@0203Lg=`0<03Hf=P0i>CT0
>3Ph03Lg=`0j>SX0>3Ph03`l?00m?Cd0?Shn03lo?`10@400@T920P11@D4204=3@`0704E5A@17AdL0
AdM704Q8B019BDT0B4Q804M7A`0204U9B@<0BTY:00P0C4a<04Y:BP1;Bd/0C4a<04];B`1:BTX0BDU9
04M7A`<0B4Q800@0ATI604M7A`15ADD0ADE50`12@T801@11@D40?clo03lo?`0n?Sh0?Cdm0080?3`l
00<0>SXj03Ti>@0h>3P00`0f=SH0100d=3@0<c<c03@d=00a<C42038b<P04034a<@0_;bl0<C4a02l_
;`80;Rh^00@0;2`/02/[:`0[:b/0:BTY0P0Z:RX202TY:@80:2PX0`0W9bL00`0V9RH09BDU02DU9@02
02DU9@0302<S8`0T92@092@T008092@T00<08b<S024Q8@0R8R800P0R8R82024Q8@<08R8R00@08B4Q
020P800Q8B408B4Q0P0P820401lO7`07020P800N7Qh07alO01lO7`0N7Qh07AdM01hN7P0301dM7@80
7QhN00D071`L01dM7@0M7Ad07AdM01hN7P0201`L700301hN7P0L71`07AdM00807AdM0`0L71`0100K
6a/071`L01/K6`0K6a/201`L700301/K6`0L71`071`L00<06a/K00L06QXJ01`L700K6a/06a/K01XJ
6P0I6AT06a/K00806QXJ00D061PH01/K6`0K6a/06a/K01TI6@0301XJ6P0301/K6`0J6QX06QXJ00@0
6QXJ00@06ATI01XJ6P0J6QX06QXJ0P0I6AT60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`0K6a/06ATI01/K6`0201XJ6P0301TI6@0K6a/06QXJ00<06a/K0`0J6QX301/K6`03
01XJ6P0K6a/06a/K00806a/K0`0J6QX401/K6`8071`L00<06a/K01`L700L71`00P0K6a/00`0L71`0
7AdM01/K6`0201/K6`0301dM7@0L71`071`L00807AdM00<071`L01dM7@0M7Ad00P0M7Ad01`0N7Qh0
7AdM01hN7P0M7Ad07QhN01dM7@0N7Qh00P0M7Ad0100N7Qh07alO01lO7`0O7al301hN7P0501lO7`0N
7Qh0820P01hN7P0O7al00`0P82003`0R8R808B4Q024Q8@0P82008B4Q020P800Q8B408R8R02<S8`0R
8R80820P028R8P0Q8B408b<S028R8P0202<S8`0402@T900S8b<092@T02@T90809BDU0P0V9RH202DU
9@0602HV9P0U9BD09RHV02LW9`0X:2P0:RXZ0P0Y:BT202/[:`0602XZ:P0[:b/0:b/[02d];@0/;2`0
;Bd]100^;Rh01P0`<300<C4a038b<P0a<C40<S8b03<c<`<0=3@d00@0=SHf03Ph>00h>3P0>3Ph0P0j
>SX01@0l?3`0>c/k03hn?P0l?3`0?Cdm00<0@41000H0@d=30492@P14A4@0A4A404E5A@18B4P204I6
AP0504Q8B017AdL0BDU904U9B@1:BTX00P19BDT504Y:BP80BDU90P17AdL204Q8B00404I6AP14A4@0
@T920492@P<0@4100P0o?cl02`0k>c/0>SXj03/k>`0j>SX0>CTi03Ph>00f=SH0=cLg03De=@0f=SH0
=CDe0080<c<c00@0=3@d030`<00a<C40;Rh^0P0_;bl302d];@0402`/;00];Bd0;Bd]02/[:`80:RXZ
0P0Y:BT00`0X:2P0:BTY02PX:00202LW9`809RHV00@09BDU02HV9P0U9BD092@T100S8b<01@0R8R80
8B4Q02<S8`0R8R808b<S00<08R8R00@08B4Q020P800R8R808B4Q0P0R8R801P0O7al0820P020P800O
7al08B4Q020P80@07alO00<07QhN01dM7@0N7Qh00P0O7al00`0N7Qh07AdM01dM7@0201dM7@0301/K
6`0M7Ad07QhN00807AdM0`0L71`301dM7@0301`L700M7Ad06a/K00@06a/K0P0L71`0300J6QX06a/K
01/K6`0J6QX06a/K01`L700K6a/06QXJ01`L700J6QX06a/K01XJ6P806a/K00<06QXJ01/K6`0K6a/0
0`0K6a/01P0I6AT06QXJ01XJ6P0J6QX06ATI01/K6`D06QXJ00@06ATI01XJ6P0J6QX06ATI1P3IfMT1
00000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00<06QXJ01/K6`0K6a/00`0J6QX01@0K
6a/071`L01/K6`0K6a/06QXJ00T06a/K0P0J6QX201/K6`0601XJ6P0L71`06a/K01/K6`0J6QX06a/K
0P0L71`00`0J6QX06a/K01/K6`0401`L700301/K6`0M7Ad071`L008071`L0P0M7Ad0100L71`07AdM
01hN7P0O7al201dM7@0601`L700M7Ad07QhN01dM7@0N7Qh071`L0P0N7Qh201dM7@807QhN0`0O7al0
100N7Qh07alO01lO7`0P820601lO7`04024Q8@0P82008R8R028R8P808B4Q00@08R8R024Q8@0S8b<0
8B4Q0P0S8b<01@0Q8B408R8R02<S8`0T92@08b<S00<092@T100U9BD00`0W9bL09RHV02LW9`0202LW
9`0302PX:00Y:BT0:2PX0080:BTY0`0Z:RX01P0[:b/0;2`/02/[:`0];Bd0;Rh^02l_;`@0<30`00<0
<S8b034a<@0b<S800P0b<S8303De=@80=SHf00L0=cLg03Ti>@0i>CT0>c/k03Xj>P0l?3`0>c/k00<0
?Cdm00H0@4100451@@10@400@d=30492@P13@d<204A4A00904I6AP13@d<0ADE504M7A`15ADD0B4Q8
04I6AP17AdL0B4Q800@0ATI600<0ADE504A4A015ADD00`14A4@02@13@d<0@D510410@00o?cl0?Shn
0410@00o?cl0>c/k03`l?00303/k>`0403Ph>00i>CT0=cLg03Hf=P<0=CDe00<0=3@d038b<P0c<c<0
0P0`<3000`0a<C40;bl_02h^;P0302h^;P0702d];@0/;2`0;2`/02XZ:P0X:2P0:RXZ02TY:@0302PX
:00802LW9`0V9RH09RHV02LW9`0U9BD09bLW02HV9P0T92@202DU9@@092@T00T08b<S028R8P0R8R80
8R8R02<S8`0Q8B408R8R024Q8@0P82000P0R8R82024Q8@80820P00H07alO020P800O7al0820P01lO
7`0P820201lO7`0301hN7P0P82007QhN00@07QhN00H07alO01dM7@0N7Qh07AdM01hN7P0M7Ad201hN
7P0401dM7@0L71`07QhN01dM7@<071`L00D07AdM01`L700L71`071`L01/K6`0501`L700301/K6`0L
71`071`L00@06a/K00@071`L01/K6`0K6a/06a/K0P0J6QX00`0K6a/06QXJ01XJ6P0201XJ6P0401TI
6@0J6QX06QXJ01TI6@806QXJ00@06a/K01`L700J6QX06a/K0`0J6QX00`0K6a/06ATI01XJ6P060=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT201XJ6P0301TI6@0J6QX06a/K0080
6a/K00@06QXJ01TI6@0J6QX06ATI0P0J6QX03@0L71`06a/K01/K6`0K6a/071`L01XJ6P0K6a/06QXJ
01/K6`0L71`06QXJ01`L700J6QX00`0K6a/00`0M7Ad071`L01`L700201dM7@0301/K6`0L71`06a/K
008071`L00D07AdM01/K6`0M7Ad071`L01dM7@0401`L70L07AdM00<071`L01dM7@0N7Qh00`0M7Ad0
0`0N7Qh07AdM01hN7P0301hN7P0301lO7`0P82007alO0080820P00<07alO020P800O7al00P0P8204
024Q8@03028R8P0Q8B408b<S00L08R8R100S8b<0100U9BD09RHV02@T900T92@202DU9@0302HV9P0W
9bL09RHV00<09bLW0P0X:2P02P0W9bL0:BTY02TY:@0Z:RX0:b/[02XZ:P0[:b/0:RXZ02/[:`0/;2`3
02d];@80;bl_00D0<30`034a<@0a<C40<C4a038b<P0203De=@0403@d=00e=CD0=CDe03Hf=P80=cLg
00X0>CTi03Ph>00k>c/0>c/k03Xj>P0m?Cd0?3`l03dm?@0n?Sh0?clo0P11@D402P0o?cl0@T920492
@P13@d<0@D5104E5A@14A4@0ADE504I6AP12@T8204E5A@80A4A400<0ADE504A4A015ADD00P14A4@2
0492@P80@41000P0?clo03hn?P0n?Sh0>c/k03hn?P0m?Cd0>c/k03`l?080>SXj00@0>CTi03Lg=`0f
=SH0=SHf0P0e=CD00`0d=3@0=CDe038b<P02034a<@03038b<P0^;Rh0<30`00@0;Rh^00P0;2`/02d]
;@0[:b/0:b/[02XZ:P0Y:BT0:RXZ02TY:@80:2PX100W9bL01P0V9RH09bLW02PX:00X:2P09RHV02DU
9@8092@T0P0S8b<00`0T92@08b<S02<S8`03028R8P0702<S8`0Q8B408R8R024Q8@0R8R808B4Q028R
8P02020P8004024Q8@0O7al0820P024Q8@807QhN00@07alO01hN7P0O7al07QhN0`0O7al0100N7Qh0
7AdM01dM7@0M7Ad201`L70807AdM0P0N7Qh201dM7@0401`L700N7Qh07AdM01dM7@806a/K0P0L71`0
0`0K6a/071`L01`L700301/K6`0301`L700K6a/071`L00806a/K0P0J6QX301/K6`0501XJ6P0K6a/0
6QXJ01/K6`0J6QX01`0K6a/201XJ6P0501TI6@0K6a/06a/K01TI6@0K6a/00P0J6QX01@0I6AT06a/K
01TI6@0I6AT06QXJ00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@806QXJ
00D06a/K01TI6@0J6QX06ATI01/K6`0201XJ6P0301/K6`0J6QX06QXJ00@06QXJ00<06a/K01XJ6P0K
6a/00P0J6QX301/K6`806QXJ00<071`L01/K6`0K6a/00P0K6a/00`0L71`06a/K01`L700301/K6`03
01`L700M7Ad07AdM008071`L00<06a/K01`L700M7Ad00P0L71`201dM7@8071`L00<07AdM01lO7`0M
7Ad00P0M7Ad00`0L71`07QhN01hN7P0401hN7PD07alO0P0N7Qh00`0P82007alO020P800201lO7`03
020P800Q8B408B4Q00<08B4Q00H0;2`/028R8P0R8R80820P028R8P0P8203028R8PD08b<S00<08R8R
02<S8`0S8b<0100U9BD302HV9P80:2PX00H09bLW02PX:00Y:BT0:2PX02XZ:P0Y:BT302XZ:P0402/[
:`0/;2`0;Rh^02d];@80;bl_00<0;Rh^030`<00_;bl00P0a<C42038b<P80<c<c00X0=3@d03De=@0d
=3@0=SHf03Lg=`0e=CD0>CTi03Ph>00j>SX0>c/k0P0j>SX00`0l?3`0>c/k03dm?@0203hn?P060410
@011@D40@D510410@011@D40@4100P12@T801011@D40@d=30492@P12@T8204A4A0060451@@14A4@0
@D5104=3@`14A4@0@d=30P11@D403@10@400?clo03dm?@10@400?Shn03`l?00k>c/0?Cdm03Xj>P0k
>c/0>3Ph03Lg=`0h>3P00P0e=CD203Hf=P@0<c<c00D0<C4a038b<P0`<300;Rh^02l_;`0202h^;P06
02d];@0/;2`0;Bd]02/[:`0Z:RX0:b/[0`0Y:BT02@0X:2P09bLW02LW9`0W9bL09BDU02HV9P0W9bL0
9RHV02PX:00302HV9P809BDU00D08b<S02DU9@0R8R808b<S028R8P0202<S8`04028R8P0Q8B408B4Q
028R8P808B4Q00P0820P024Q8@0Q8B40820P01lO7`0P82007alO020P80807QhN00@07alO020P800N
7Qh07alO0P0M7Ad201hN7P0501lO7`0N7Qh07AdM01dM7@0L71`00P0M7Ad01@0L71`07AdM01hN7P0L
71`07AdM00807QhN1P0L71`201/K6`0301`L700K6a/06a/K008071`L00<07AdM01/K6`0K6a/00P0K
6a/0100L71`06a/K01/K6`0L71`201/K6`0601`L700K6a/06a/K01TI6@0K6a/06QXJ0P0K6a/01@0J
6QX06a/K01/K6`0J6QX06ATI00H06QXJ0P0I6AT00`0J6QX06a/K01TI6@060=WIf@4000000@3IfMT0
01H0fMWI00<000000=WIf@3IfMT00`3IfMT0200J6QX061PH01TI6@0J6QX071`L01XJ6P0K6a/06QXJ
100K6a/01@0J6QX06a/K01XJ6P0K6a/06QXJ008071`L00@06QXJ01/K6`0K6a/071`L0P0K6a/0100L
71`06a/K01`L700K6a/201`L70806a/K00/06QXJ01`L700M7Ad07AdM01/K6`0L71`06a/K01`L700M
7Ad071`L01hN7P0301`L700401hN7P0L71`071`L01`L70@07AdM0P0N7Qh201dM7@0501hN7P0M7Ad0
7AdM020P800M7Ad00P0N7Qh01@0O7al07QhN01lO7`0N7Qh07alO00808B4Q100P820201lO7`06020P
800Q8B408R8R024Q8@0P82008B4Q1P0R8R801`0S8b<09BDU028R8P0S8b<09BDU02@T900S8b<00`0T
92@0100U9BD09RHV02@T900W9bL202PX:0809bLW00<0:2PX02LW9`0W9bL00P0Z:RX302TY:@0402/[
:`0/;2`0;Bd]02`/;0<0;Rh^0P0`<300100_;bl0<C4a030`<00c<c<2038b<P0403<c<`0e=CD0=CDe
03De=@80=SHf0P0h>3P203Ti>@0303Ph>00l?3`0>c/k00@0?Cdm00<0?Shn03lo?`0n?Sh00P10@400
1P0o?cl0@D510410@00o?cl0@4100451@@80@4100P11@D401`10@400@T920410@00n?Sh0?clo03hn
?P0m?Cd00`0l?3`203/k>`<0>SXj00<0>CTi03Ph>00g=cL00P0f=SH0100e=CD0=3@d03<c<`0d=3@2
038b<P0303<c<`0_;bl0<C4a0080;bl_00T0;Rh^02d];@0/;2`0;2`/02/[:`0/;2`0:b/[02XZ:P0[
:b/00P0X:2P0100Y:BT0:2PX02PX:00W9bL202PX:0<09RHV00<09BDU02HV9P0U9BD00`0T92@01@0S
8b<092@T02<S8`0S8b<092@T00808R8R00<08B4Q020P800Q8B40100Q8B40100O7al0820P020P800P
820401lO7`05020P800N7Qh07alO020P800N7Qh00P0O7al01@0N7Qh07AdM01dM7@0O7al07QhN0080
7AdM00P07QhN01dM7@0L71`07AdM01hN7P0L71`07AdM01`L70807QhN00D07AdM01/K6`0K6a/071`L
01dM7@0301/K6`0301`L700K6a/071`L00806a/K00D071`L01/K6`0M7Ad06a/K01dM7@0601/K6`80
6QXJ00<06a/K01XJ6P0K6a/00P0J6QX01@0K6a/06QXJ01XJ6P0J6QX06ATI00806QXJ00D06ATI01XJ
6P0J6QX06QXJ01/K6`0201XJ6P806ATI1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI
00<0fMWI0P0J6QX0100K6a/06QXJ01/K6`0J6QX401/K6`<06QXJ00@06ATI01XJ6P0K6a/06a/K0P0L
71`601/K6`8071`L0`0K6a/00`0M7Ad071`L01`L700201`L70@06a/K0P0L71`00`0M7Ad071`L01dM
7@0201`L700301hN7P0L71`07AdM00807AdM00<07QhN01dM7@0M7Ad00`0M7Ad00`0L71`07AdM01dM
7@0201hN7P0601dM7@0O7al07alO01lO7`0N7Qh0820P0P0O7al2020P800401lO7`0P82007alO020P
80807alO0`0Q8B40200P82008B4Q028R8P0R8R808B4Q028R8P0Q8B408R8R0P0Q8B42028R8P808b<S
00H092@T02<S8`0S8b<092@T02HV9P0U9BD202HV9P0302DU9@0W9bL09RHV00809RHV00T09bLW02PX
:00W9bL09bLW02PX:00[:b/0;2`/02XZ:P0[:b/00P0/;2`302d];@<0;Rh^0`0_;bl00`0`<300<C4a
030`<00203@d=00803<c<`0e=CD0<c<c03De=@0f=SH0=cLg03Ph>00g=cL203Ph>0<0>SXj00D0?3`l
03dm?@0l?3`0>c/k03dm?@0203hn?P0603dm?@0l?3`0?clo03hn?P10@400?clo0P10@4000`0n?Sh0
@41003lo?`0303lo?`80?Shn00<0?3`l03dm?@0m?Cd00`0l?3`0100j>SX0>CTi03Ph>00h>3P203Lg
=`80=SHf00<0=3@d03De=@0c<c<00P0c<c<3034a<@80;bl_00<0;Bd]02l_;`0_;bl00P0];Bd0100^
;Rh0;Bd]02XZ:P0[:b/202XZ:P<0:BTY0P0X:2P202LW9`809RHV00/09BDU02LW9`0U9BD09RHV02DU
9@0S8b<09BDU02@T900R8R808b<S024Q8@02028R8P05024Q8@0R8R808R8R024Q8@0R8R80100Q8B40
0`0P82008B4Q020P8003024Q8@0?01hN7P0P82007alO01hN7P0O7al07QhN01lO7`0N7Qh07AdM01hN
7P0O7al07AdM01lO7`0N7Qh071`L00H07AdM00D071`L01dM7@0L71`071`L01/K6`0201`L700301dM
7@0L71`07AdM00@071`L00<06a/K01`L700K6a/00`0K6a/01P0L71`06ATI01/K6`0K6a/06QXJ01`L
70806a/K00<071`L01/K6`0K6a/00P0J6QX0100K6a/06ATI01XJ6P0K6a/201XJ6P0301/K6`0J6QX0
6QXJ00806QXJ0P0K6a/00`0I6AT06QXJ01TI6@0201TI6@0301XJ6P3IfMT0fMWI00@0fMWI0@000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0601XJ6P0K6a/06a/K01XJ6P0K6a/06ATI0P0J
6QX02@0I6AT06a/K01XJ6P0K6a/06QXJ01TI6@0K6a/06QXJ01/K6`0301XJ6PD06a/K00H071`L01/K
6`0L71`06a/K01`L700K6a/201`L700401dM7@0L71`071`L01`L70806a/K00D071`L01dM7@0L71`0
71`L01/K6`0501`L70807AdM0`0L71`201dM7@D07QhN00L07AdM01hN7P0N7Qh07AdM01lO7`0P8200
7QhN00@07alO00<0820P01lO7`0P82000`0P8206024Q8@@08R8R00<08b<S028R8P0T92@00`0S8b<0
1`0T92@08R8R02<S8`0R8R8092@T02DU9@0T92@00`0U9BD202HV9P0<02DU9@0V9RH09RHV02PX:00Y
:BT09bLW02PX:00Z:RX0:BTY02/[:`0Z:RX0:b/[0`0];Bd01@0/;2`0;Bd]02h^;P0];Bd0;Rh^0080
<30`00P0<C4a030`<00`<300<30`038b<P0d=3@0<c<c03@d=080=CDe00X0=3@d03Lg=`0g=cL0=SHf
03Ph>00g=cL0>3Ph03Xj>P0k>c/0>SXj100l?3`02@0k>c/0?Cdm03`l?00l?3`0?Cdm03lo?`0k>c/0
?clo03`l?00203dm?@0503lo?`0n?Sh0?Shn03dm?@0l?3`00`0k>c/203Xj>P<0>CTi0`0h>3P00`0f
=SH0=CDe03Lg=`0203@d=006038b<P0c<c<0<c<c034a<@0b<S80<C4a0P0_;bl202h^;P0302l_;`0]
;Bd0:b/[0080;Bd]0P0[:b/0100Z:RX0:b/[02TY:@0Y:BT502PX:00502LW9`0X:2P09bLW02HV9P0T
92@00P0U9BD202@T900702DU9@0S8b<08b<S02@T900S8b<08R8R02@T900202<S8`808B4Q0P0P8200
200R8R808B4Q01lO7`0P82008B4Q01lO7`0P82008B4Q1@0O7al201hN7P0301lO7`0N7Qh07QhN0080
7QhN00P07alO01hN7P0L71`07AdM01hN7P0M7Ad071`L01hN7P807AdM0`0L71`201dM7@0301hN7P0L
71`071`L008071`L00`07AdM01`L700J6QX071`L01/K6`0L71`06a/K01`L700K6a/06QXJ01/K6`0L
71`401/K6`0601XJ6P0K6a/06a/K01XJ6P0L71`06a/K100J6QX0100I6AT06QXJ01XJ6P0J6QX201TI
6@@06QXJ00<06a/K01TI6@0I6AT00`0H61P60=WIf@4000000@3IfMT001H0fMWI0P0000040=WIf@<0
6QXJ00<06a/K01XJ6P0K6a/00P0J6QX01@0I6AT06a/K01XJ6P0J6QX06a/K00<06QXJ100K6a/0200J
6QX071`L01`L700L71`06QXJ01`L700K6a/06QXJ0`0L71`0100K6a/071`L01XJ6P0L71`201/K6`@0
71`L00D06a/K01dM7@0M7Ad071`L01dM7@0301`L700301dM7@0L71`071`L008071`L00H07AdM01hN
7P0M7Ad071`L01hN7P0L71`301hN7P04020P800O7al07QhN01dM7@<07alO00<08B4Q01lO7`0O7al0
0P0P82000`0O7al0820P024Q8@02020P8003024Q8@0R8R808B4Q00808R8R00L0820P028R8P0S8b<0
8R8R024Q8@0S8b<08R8R00808b<S00<08B4Q028R8P0T92@00P0S8b<01@0U9BD08R8R02@T900V9RH0
9bLW00809RHV00<09BDU02HV9P0W9bL00`0X:2P302TY:@0302PX:00Y:BT0:RXZ0080:b/[00@0;2`/
02/[:`0/;2`0;Rh^100_;bl00`0a<C40;bl_034a<@02034a<@80<S8b0P0c<c<01P0e=CD0<c<c03Hf
=P0f=SH0=cLg03Hf=P80=cLg00<0>3Ph03Lg=`0h>3P00`0j>SX00`0i>CT0>SXj03Xj>P0203Xj>P04
03/k>`0l?3`0?3`l03/k>`D0?3`l00D0>c/k03`l?00k>c/0>CTi03Xj>P0203Ti>@80>3Ph00<0>CTi
03Ph>00h>3P00P0f=SH0100e=CD0=3@d03<c<`0d=3@203<c<`<0<C4a0P0`<300300^;Rh0<30`02h^
;P0_;bl0;Bd]02/[:`0/;2`0;Bd]02/[:`0Y:BT0:b/[02XZ:P80:BTY00<0:2PX02LW9`0W9bL00P0X
:2P00`0W9bL09BDU02HV9P0202HV9P0402@T900U9BD08b<S02DU9@8092@T00H08b<S028R8P0S8b<0
8b<S028R8P0Q8B43028R8P09024Q8@0R8R808R8R028R8P0Q8B407alO020P800Q8B407alO0080820P
00<07alO01hN7P0P82000P0O7al201hN7P807alO0P0M7Ad201hN7P0401`L700N7Qh07AdM01dM7@80
71`L00H07QhN01dM7@0M7Ad06a/K01`L700M7Ad301`L70806a/K0P0L71`201/K6`0401`L700K6a/0
71`L01`L70D06a/K0P0J6QX201/K6`0301`L700K6a/071`L00806QXJ0P0K6a/01P0J6QX06ATI01XJ
6P0I6AT06QXJ01/K6`D06QXJ00<06ATI01/K6`0J6QX0100J6QX00`0I6AT06QXJ0=WIf@040=WIf@80
00000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0100J6QX06ATI01TI6@0J6QX201/K6`03
01TI6@0J6QX06ATI00806QXJ00<06a/K01TI6@0K6a/00P0K6a/01`0J6QX06a/K01/K6`0K6a/071`L
01/K6`0J6QX0100K6a/00`0L71`06QXJ01`L700601/K6`X071`L0P0M7Ad01`0L71`07AdM01/K6`0L
71`07AdM01`L700M7Ad00P0N7Qh201dM7@0601hN7P0M7Ad07QhN01hN7P0O7al07QhN0P0O7al00`0N
7Qh0820P01hN7P0201lO7`0;01hN7P0O7al0820P020P800N7Qh08B4Q020P800N7Qh08R8R024Q8@0P
82000P0Q8B42028R8P03024Q8@0R8R808B4Q00@08R8R00<08b<S028R8P0T92@0100T92@202HV9P04
02DU9@0V9RH09BDU02DU9@809RHV00H09bLW02PX:00Y:BT0:RXZ02TY:@0X:2P402XZ:P0602/[:`0Z
:RX0:b/[02`/;00];Bd0;2`/0`0^;Rh202l_;`05034a<@0`<300<C4a02l_;`0b<S800P0c<c<203De
=@0303Lg=`0e=CD0=CDe0080=SHf00H0=CDe03Ph>00g=cL0>SXj03Ph>00j>SX203Ti>@80>SXj00D0
>CTi03Xj>P0k>c/0>c/k03Xj>P0203/k>`80>SXj00<0>c/k03Xj>P0k>c/0100i>CT303Ph>00403Ti
>@0h>3P0=cLg03Ph>080=SHf00X0=CDe03@d=00c<c<0<C4a03@d=00b<S80<c<c030`<00a<C40<30`
0`0^;Rh01@0];Bd0;2`/02d];@0];Bd0:b/[0080;2`/00<0:b/[02TY:@0Y:BT00`0Y:BT202PX:003
02TY:@0X:2P0:2PX00809RHV00T09bLW02@T900V9RH092@T02DU9@0T92@08b<S02@T900R8R800`0S
8b<0200R8R808b<S024Q8@0R8R80820P024Q8@0P82008B4Q1P0P820201lO7`03020P800O7al07QhN
00807QhN00@0820P01hN7P0N7Qh07AdM0P0O7al0100N7Qh07AdM01hN7P0N7Qh301dM7@0501hN7P0L
71`071`L01dM7@0L71`00P0K6a/01`0L71`06QXJ01/K6`0K6a/07AdM01/K6`0L71`00`0K6a/0100L
71`06QXJ01/K6`0L71`201/K6`0501XJ6P0K6a/06a/K01/K6`0L71`0100K6a/501XJ6P806a/K0P0J
6QX00`0I6AT06QXJ01TI6@0201XJ6P0:01/K6`0J6QX06ATI01/K6`0I6AT06QXJ01TI6@0J6QX06ATI
01PH60H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@P06QXJ00D06ATI01XJ
6P0K6a/06QXJ01/K6`0401XJ6P0301/K6`0L71`071`L00<06a/K00<071`L01/K6`0K6a/00P0L71`6
01/K6`0301`L700K6a/06a/K00T071`L00<06a/K01`L700L71`00P0L71`01`0K6a/071`L01dM7@0M
7Ad071`L01hN7P0M7Ad0200N7Qh00`0O7al0820P01lO7`02020P80<07alO00@0820P01lO7`0Q8B40
820P0P0O7al4020P80808B4Q00<08R8R024Q8@0Q8B401P0S8b<2028R8P<08b<S0`0U9BD0200V9RH0
9BDU02HV9P0V9RH09BDU02HV9P0W9bL0:BTY0P0X:2P01@0Y:BT0:2PX02PX:00[:b/0:BTY0080:b/[
100/;2`402h^;P0502l_;`0^;Rh0;Rh^030`<00b<S800P0a<C402P0b<S80<c<c038b<P0c<c<0=CDe
03@d=00f=SH0=CDe03@d=00f=SH203Lg=`0303Ti>@0g=cL0>3Ph0080>3Ph00L0>CTi03Lg=`0h>3P0
>CTi03Xj>P0h>3P0>SXj0080>3Ph0`0j>SX303Ph>00:03Ti>@0g=cL0=cLg03Hf=P0h>3P0=SHf03@d
=00g=cL0=CDe03Hf=P80<c<c00L0=3@d034a<@0d=3@0<S8b034a<@0`<300<C4a0080<30`00P0;Rh^
02d];@0^;Rh0;Bd]02h^;P0/;2`0;Bd]02`/;0<0:b/[00H0;2`/02/[:`0Z:RX0:RXZ02TY:@0X:2P3
02LW9`0802PX:00V9RH092@T02DU9@0T92@09RHV02DU9@0S8b<202@T900302<S8`0T92@08R8R0080
8R8R00P08b<S024Q8@0R8R80820P024Q8@0S8b<08R8R020P80<08B4Q00<0820P01lO7`0O7al00P0O
7al0100P82007QhN01lO7`0O7al201hN7P0301lO7`0N7Qh07QhN00D07QhN00T07AdM01hN7P0L71`0
7QhN01dM7@0L71`07AdM01`L700K6a/00P0M7Ad201`L700401/K6`0L71`07AdM01`L70806a/K00l0
7AdM01`L700L71`06a/K01`L700K6a/071`L01XJ6P0K6a/06QXJ01`L700K6a/06QXJ01/K6`0L71`0
0P0J6QX401/K6`<06QXJ00@061PH01XJ6P0J6QX06QXJ0P0I6AT00`0J6QX06ATI01/K6`0201XJ6P03
01TI6@0J6QX06QXJ00806QXJ00<06ATI01XJ6P3IfMT01@3IfMT100000040fMWI000F0=WIf@030000
003IfMT0fMWI00<0fMWI00<06QXJ01/K6`0H61P00P0J6QX01@0K6a/06QXJ01`L700K6a/06QXJ00<0
6a/K00<06QXJ01/K6`0K6a/00P0J6QX00`0K6a/071`L01/K6`0301/K6`806QXJ0P0K6a/301`L7005
01/K6`0L71`071`L01/K6`0M7Ad00P0L71`00`0K6a/071`L01`L700301`L700601/K6`0L71`071`L
01dM7@0L71`07AdM0P0L71`00`0N7Qh07AdM01`L700501dM7@H07QhN00D07alO01dM7@0O7al07QhN
01lO7`0201hN7P0601lO7`0P82008B4Q020P800O7al08B4Q0`0P82000`0O7al0820P024Q8@03024Q
8@06028R8P0P82008B4Q024Q8@0S8b<08R8R0P0S8b<202@T90808b<S00@09BDU02@T900T92@092@T
1@0U9BD00`0V9RH0:2PX02LW9`0202LW9`80:BTY00l0:2PX02XZ:P0[:b/0:b/[02XZ:P0];Bd0:b/[
02d];@0[:b/0;Rh^02d];@0^;Rh0;2`/02l_;`0^;Rh0100`<3002`0a<C40<S8b034a<@0d=3@0<S8b
03@d=00b<S80<c<c03De=@0d=3@0=CDe0080=SHf00T0>3Ph03Lg=`0g=cL0=SHf03Lg=`0f=SH0>CTi
03Hf=P0e=CD00P0h>3P00`0i>CT0=SHf03Ti>@0203Ph>0@0=SHf00<0=CDe03Hf=P0e=CD00P0e=CD0
100f=SH0=3@d03@d=00d=3@403<c<`<0<C4a00@0<S8b030`<00^;Rh0;Rh^0P0_;bl02P0^;Rh0;2`/
02d];@0/;2`0;Bd]02/[:`0/;2`0:RXZ02TY:@0[:b/202TY:@0302PX:00Z:RX09bLW00@09bLW00P0
9BDU02HV9P0U9BD08b<S02@T900U9BD092@T02<S8`8092@T00@08b<S028R8P0R8R808b<S100Q8B40
0`0R8R808b<S020P8002020P800601lO7`0P8200820P020P800O7al08B4Q0P0P820401lO7`0301hN
7P0M7Ad07alO00807QhN00@07AdM01lO7`0O7al07QhN100M7Ad00`0N7Qh07AdM01dM7@0201`L7003
01/K6`0L71`071`L008071`L00@06a/K01dM7@0K6a/071`L0P0K6a/00`0J6QX06a/K01/K6`0201dM
7@0301/K6`0L71`06a/K00@06a/K00X06QXJ01/K6`0J6QX06a/K01`L700J6QX071`L01/K6`0J6QX0
6a/K0`0J6QX201/K6`0:01TI6@0K6a/06a/K01XJ6P0I6AT06QXJ01TI6@0K6a/06QXJ01TI6@806QXJ
0P0I6AT60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT01P0J6QX06ATI01/K
6`0J6QX06a/K01TI6@D06QXJ00@06a/K01XJ6P0J6QX06QXJ0`0K6a/00`0L71`06QXJ01/K6`0201XJ
6P0401/K6`0L71`06a/K01`L70806a/K00<071`L01/K6`0K6a/0100K6a/00`0L71`06a/K01`L7004
01`L700701/K6`0L71`071`L01/K6`0L71`07AdM01`L700201dM7@0401/K6`0N7Qh071`L01dM7@80
7QhN00D071`L01hN7P0N7Qh07alO01hN7P0201lO7`0601hN7P0O7al07alO01hN7P0O7al07QhN0P0O
7al2020P800301lO7`0Q8B407alO00H0820P0`0R8R800`0Q8B408R8R024Q8@02028R8P808b<S0P0R
8R800`0U9BD092@T02<S8`0302@T900802DU9@0T92@09RHV02DU9@0V9RH09bLW02HV9P0U9BD202LW
9`0602HV9P0X:2P0:2PX02TY:@0X:2P0:BTY100Z:RX00`0/;2`0;Bd]02d];@0202h^;P0A02`/;00^
;Rh0;Bd]030`<00^;Rh0;Bd]02l_;`0`<300<C4a02l_;`0b<S80<C4a038b<P0c<c<0=3@d03De=@0c
<c<00`0d=3@203Hf=P0603De=@0h>3P0=cLg03Lg=`0e=CD0=SHf0`0g=cL203Hf=P0403Ph>00f=SH0
>3Ph03De=@80=SHf1@0e=CD01`0d=3@0=SHf03De=@0d=3@0<c<c03De=@0b<S800P0c<c<01`0`<300
<S8b034a<@0a<C40<30`02l_;`0^;Rh00P0/;2`202h^;P0502d];@0/;2`0;Bd]02`/;00Z:RX00P0[
:b/302TY:@0902XZ:P0X:2P09bLW02PX:00W9bL09RHV02PX:00W9bL09RHV00809BDU00@092@T02DU
9@0V9RH09BDU0P0T92@402<S8`07028R8P0S8b<08R8R024Q8@0R8R808B4Q028R8P05020P8003024Q
8@0P8200820P00<07alO0P0N7Qh00`0Q8B407alO01hN7P0301lO7`0501hN7P0M7Ad07alO01dM7@0N
7Qh00`0M7Ad0100O7al07AdM01dM7@0M7Ad301`L700501/K6`0M7Ad071`L01`L700J6QX00P0L71`0
1@0J6QX071`L01/K6`0L71`06a/K008071`L00<06a/K01XJ6P0K6a/00P0K6a/201XJ6P0501/K6`0J
6QX06a/K01XJ6P0K6a/00`0J6QX00`0K6a/06QXJ01/K6`0601XJ6P0301TI6@0J6QX06QXJ00@06QXJ
00@06ATI01/K6`0I6AT06QXJ0P0I6AT60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT0
0`3IfMT01P0J6QX06ATI01TI6@0J6QX06a/K01TI6@806QXJ0P0K6a/00`0J6QX06ATI01/K6`0401XJ
6P0501/K6`0J6QX071`L01/K6`0L71`01@0K6a/0100L71`06a/K01/K6`0K6a/201`L700601/K6`0L
71`06a/K01/K6`0M7Ad06QXJ0P0L71`00`0M7Ad071`L01`L700401`L700401dM7@0L71`06a/K01`L
70807AdM0`0L71`01P0N7Qh07AdM01hN7P0L71`07alO01dM7@807QhN0P0O7al401hN7P<07alO1P0P
82000`0Q8B407alO024Q8@02020P80808B4Q00@08R8R020P800Q8B408B4Q0P0R8R800`0T92@08b<S
02<S8`0202<S8`L092@T00H09RHV02@T900V9RH09RHV02DU9@0W9bL202HV9P0;02PX:00V9RH0:RXZ
02PX:00Z:RX0:BTY02XZ:P0[:b/0:BTY02/[:`0Z:RX00P0/;2`202d];@@0;Rh^00D0;bl_034a<@0_
;bl0;bl_02h^;P02034a<@04030`<00b<S80<c<c03@d=080<c<c00<0=CDe03<c<`0d=3@00`0e=CD0
100d=3@0=SHf03De=@0e=CD203Hf=P80=CDe00D0=cLg03De=@0g=cL0=SHf03@d=00303De=@0303Hf
=P0c<c<0=3@d00<0=3@d00D0<c<c034a<@0b<S80<S8b03<c<`02034a<@D0<30`00D0;bl_02d];@0]
;Bd0;2`/02d];@0302`/;00402/[:`0/;2`0:b/[02XZ:P80:b/[0P0Y:BT202PX:0809bLW00<0:2PX
02LW9`0W9bL00P0V9RH02@0U9BD09RHV02HV9P0V9RH092@T02<S8`0T92@08b<S028R8P0302<S8`03
024Q8@0R8R808R8R00@08R8R00<0820P024Q8@0P82000P0P82000`0O7al07QhN01hN7P0201lO7`08
01hN7P0O7al07QhN01hN7P0P82007alO01hN7P0O7al501hN7P807alO00<07AdM01`L700M7Ad00P0M
7Ad301`L700501dM7@0L71`071`L01/K6`0M7Ad00`0L71`00`0K6a/06QXJ01/K6`0301`L700601XJ
6P0K6a/06a/K01XJ6P0L71`06QXJ0`0K6a/02@0I6AT06a/K01XJ6P0J6QX06a/K01XJ6P0I6AT06QXJ
01TI6@0401XJ6P0601TI6@0K6a/06a/K01XJ6P0I6AT06QXJ0P0I6AT201XJ6P0301TI6@0J6QX06a/K
00806ATI00<06QXJ0=WIf@3IfMT0103IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0
fMWI00@06a/K01XJ6P0J6QX06QXJ0P0K6a/02@0J6QX06a/K01XJ6P0J6QX06a/K01XJ6P0K6a/07AdM
01XJ6P0401/K6`0801XJ6P0K6a/071`L01/K6`0J6QX06a/K01XJ6P0K6a/201XJ6P806a/K00H071`L
01/K6`0K6a/06a/K01`L700J6QX301/K6`D071`L00T07AdM01`L700L71`07AdM01`L700M7Ad07QhN
01`L700N7Qh01P0M7Ad00`0N7Qh07AdM01dM7@0201dM7@@07QhN00<07alO01hN7P0O7al00P0N7Qh0
2@0P82007alO020P800P82008B4Q01hN7P0P82007alO020P8006024Q8@03028R8P0Q8B408R8R00D0
8b<S00<08R8R02<S8`0U9BD00P0U9BD01@0W9bL092@T02DU9@0U9BD09RHV00809BDU01409RHV02@T
900W9bL09RHV02TY:@0X:2P0:BTY02PX:00Y:BT0:2PX02TY:@0X:2P0:b/[02PX:00Z:RX0:b/[02XZ
:P0302/[:`@0;Rh^0`0_;bl2030`<005034a<@0_;bl0<C4a030`<00b<S801P0c<c<0100e=CD0<c<c
03@d=00c<c<203@d=00903<c<`0d=3@0=3@d03De=@0d=3@0=CDe03@d=00c<c<0=3@d0080<c<c00P0
=CDe03<c<`0c<c<0<c<c038b<P0c<c<0<S8b03<c<`80<C4a00D0<S8b034a<@0_;bl0;bl_034a<@04
02l_;`80;Rh^0`0/;2`00`0Z:RX0;2`/02/[:`0202XZ:P0302TY:@0[:b/0:BTY00@0:BTY00T0:2PX
02LW9`0W9bL09BDU02PX:00V9RH09BDU02HV9P0T92@00P0U9BD202@T900402<S8`0T92@08b<S028R
8P<08b<S00<08B4Q02<S8`0Q8B40100Q8B42020P8007028R8P0P82007alO01lO7`0P82007alO020P
800501lO7`0:020P800M7Ad07QhN01hN7P0M7Ad07alO01dM7@0N7Qh07AdM01hN7P807AdM0`0L71`0
1@0M7Ad06a/K01`L700L71`06a/K00H071`L0P0K6a/01@0L71`06a/K01/K6`0K6a/06QXJ008071`L
100K6a/201XJ6P806a/K1@0J6QX0100K6a/071`L01XJ6P0K6a/201XJ6P0401TI6@0J6QX06QXJ01XJ
6P806ATI00<06QXJ01/K6`0J6QX01@0J6QX301TI6@H0fMWI0@0000010=WIf@005P3IfMT00`000000
fMWI0=WIf@030=WIf@0801XJ6P0I6AT06ATI01TI6@0J6QX06a/K01XJ6P0I6AT301XJ6P0401/K6`0J
6QX06QXJ01XJ6P8071`L00L06a/K01`L700K6a/071`L01XJ6P0K6a/06QXJ00L06a/K00<06QXJ01`L
700L71`00P0K6a/201`L700401dM7@0K6a/071`L01/K6`<071`L00@06a/K01XJ6P0M7Ad07AdM100L
71`00`0M7Ad071`L01hN7P0201dM7@0301hN7P0M7Ad07AdM00<07AdM100N7Qh00`0M7Ad07QhN01hN
7P0301lO7`<0820P0`0O7al0100P82008B4Q01lO7`0Q8B42028R8P03024Q8@0R8R808R8R00808B4Q
0P0R8R800`0S8b<092@T02<S8`0302<S8`0402DU9@0S8b<08b<S02<S8`8092@T0P0U9BD00`0T92@0
9BDU02LW9`0202HV9P0302LW9`0X:2P09RHV0080:2PX00<09bLW02PX:00X:2P00P0Y:BT202XZ:P05
02TY:@0];Bd0:b/[02/[:`0/;2`00P0];Bd0100_;bl0<30`030`<00^;Rh402l_;`<0<30`00D0<C4a
038b<P0b<S80<S8b03<c<`0303@d=0@0<c<c00<0=3@d03<c<`0c<c<00P0c<c<503@d=00803<c<`0d
=3@0<c<c03<c<`0b<S80<c<c038b<P0c<c<3038b<P<0<C4a00H0;Rh^030`<00_;bl0<30`02l_;`0^
;Rh502d];@0802`/;00Z:RX0:RXZ02XZ:P0/;2`0:BTY02XZ:P0X:2P302TY:@80:2PX00`09bLW02HV
9P0V9RH09bLW02HV9P0W9bL09BDU02HV9P0U9BD09RHV02DU9@0T92@202<S8`0302@T900S8b<08R8R
00<08b<S00H08B4Q028R8P0Q8B408B4Q020P800R8R83024Q8@807alO00D0820P01hN7P0O7al0820P
01hN7P0701lO7`807QhN00L07alO01hN7P0N7Qh07QhN01dM7@0N7Qh07AdM008071`L00H07AdM01`L
700L71`071`L01dM7@0N7Qh201`L700901/K6`0L71`071`L01`L700M7Ad06a/K01`L700K6a/06QXJ
00<071`L00@06a/K01`L700K6a/06QXJ0P0L71`201/K6`0<01XJ6P0I6AT06QXJ01`L700J6QX06a/K
01XJ6P0K6a/06QXJ01/K6`0J6QX06a/K0P0J6QX00`0K6a/06QXJ01/K6`0201TI6@0301/K6`0I6AT0
6a/K00806QXJ00H06a/K01TI6@0I6AT06ATI01XJ6P0I6AT60=WIf@4000000@3IfMT001H0fMWI00<0
00000=WIf@3IfMT00`3IfMT201XJ6P0301TI6@0J6QX06QXJ00806QXJ00L06ATI01XJ6P0K6a/06a/K
01XJ6P0K6a/06QXJ00@06a/K00L06QXJ01/K6`0K6a/06a/K01XJ6P0K6a/06QXJ00806a/K00<06QXJ
01/K6`0J6QX00`0K6a/0100J6QX071`L01`L700K6a/201`L70807AdM00<071`L01/K6`0K6a/00P0L
71`01`0M7Ad071`L01hN7P0M7Ad07alO01dM7@0L71`00P0M7Ad01@0N7Qh07AdM01`L700N7Qh07AdM
00@07QhN00@07AdM01hN7P0N7Qh07QhN0`0O7al401hN7P0401lO7`0N7Qh07alO024Q8@807alO0P0P
82000`0Q8B408R8R024Q8@02020P8004028R8P0Q8B408B4Q024Q8@D08R8R00H092@T024Q8@0S8b<0
8b<S02DU9@0S8b<202DU9@8092@T0`0U9BD00`0V9RH09bLW02HV9P0202LW9`0402TY:@0X:2P09bLW
02LW9`<0:BTY00<0:2PX02TY:@0Z:RX00P0Y:BT02`0[:b/0;2`/02/[:`0^;Rh0;bl_02h^;P0_;bl0
;Rh^02d];@0_;bl0;Rh^0080;bl_00<0<C4a030`<00`<3000`0a<C42038b<P0:03<c<`0b<S80<c<c
038b<P0a<C40<S8b03<c<`0a<C40<S8b034a<@80<c<c00X0<S8b03@d=00c<c<0<c<c038b<P0c<c<0
<S8b034a<@0b<S80<C4a0P0`<300100_;bl0<30`034a<@0a<C4202l_;`05034a<@0^;Rh0<30`02h^
;P0];Bd00P0^;Rh01P0/;2`0;Bd]02`/;00[:b/0;2`/02TY:@80:b/[00<0:RXZ02TY:@0[:b/00P0X
:2P0100Y:BT0:2PX02LW9`0Y:BT202HV9P809bLW00L09RHV02DU9@0V9RH09BDU02HV9P0T92@09RHV
00809BDU00<08b<S028R8P0S8b<00`0R8R83024Q8@0402<S8`0R8R808B4Q020P80808B4Q0`0P8200
100O7al0820P01hN7P0N7Qh401lO7`03020P800O7al07alO00<07QhN1`0M7Ad0200L71`07AdM01dM
7@0M7Ad07QhN01dM7@0L71`06a/K0P0M7Ad201`L700501/K6`0L71`06QXJ01dM7@0K6a/00`0L71`0
0`0J6QX06a/K01XJ6P0501/K6`0301`L700J6QX06a/K00<06QXJ00L06a/K01XJ6P0K6a/061PH01XJ
6P0K6a/06ATI00806QXJ0`0K6a/201XJ6P0801TI6@0J6QX06QXJ01XJ6P0I6AT06QXJ01TI6@0K6a/2
01TI6@806QXJ1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0P0K6a/00`0J
6QX06a/K01/K6`0201XJ6P806a/K0`0J6QX201`L70806QXJ00L06a/K01XJ6P0K6a/071`L01XJ6P0K
6a/06QXJ00<06a/K00d071`L01/K6`0J6QX06a/K01dM7@0L71`06QXJ01/K6`0L71`06QXJ01/K6`0M
7Ad06QXJ008071`L00D07AdM01/K6`0L71`06a/K01`L700401dM7@8071`L2P0M7Ad00`0N7Qh07AdM
01hN7P0201dM7@0601hN7P0O7al07alO01dM7@0L71`0820P100O7al00`0N7Qh0820P01hN7P0201lO
7`D0820P1@0Q8B42028R8P808b<S00D08R8R02<S8`0R8R8092@T02<S8`0302@T900802DU9@0T92@0
9BDU02<S8`0U9BD09bLW02DU9@0V9RH402LW9`0602PX:00Z:RX09bLW02HV9P0Y:BT0:2PX0P0Y:BT2
02XZ:P@0:b/[00L0;2`/02d];@0_;bl0;Bd]02h^;P0];Bd0;Rh^0080;bl_00H0;Rh^030`<00`<300
<30`034a<@0`<303034a<@<0<S8b00<0<C4a038b<P0a<C40100b<S800`0`<300<c<c034a<@02038b
<P0303<c<`0a<C40<S8b00@0<C4a00@0;bl_034a<@0a<C40;bl_0P0`<30302h^;P80;bl_0P0^;Rh0
2`0];Bd0:b/[02`/;00/;2`0:b/[02`/;00[:b/0:BTY02/[:`0Z:RX0:2PX0080:BTY0P0X:2P302TY
:@<09bLW00H09RHV02DU9@0V9RH092@T02DU9@0S8b<302DU9@8092@T0P0S8b<2028R8P0302<S8`0Q
8B4092@T00L08B4Q00T0820P01lO7`0P82007QhN01lO7`0Q8B407alO024Q8@0N7Qh00P0O7al201hN
7P0301lO7`0N7Qh07QhN00807QhN0`0M7Ad02P0N7Qh07AdM01dM7@0L71`07AdM01/K6`0M7Ad07QhN
01/K6`0L71`201dM7@0<01`L700N7Qh071`L01dM7@0L71`06QXJ01/K6`0J6QX071`L01/K6`0L71`0
7AdM0`0K6a/301`L700301XJ6P0K6a/06a/K00806QXJ00D06a/K01XJ6P0J6QX06a/K01XJ6P0201/K
6`X06QXJ00H06ATI01XJ6P0I6AT06a/K01TI6@0K6a/201TI6@0401XJ6P0I6AT06ATI01TI6@H0fMWI
0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0301/K6`0J6QX06QXJ00806QXJ00`0
6a/K01XJ6P0J6QX06a/K01XJ6P0K6a/06QXJ01/K6`0L71`06a/K01XJ6P0I6AT201XJ6P0401/K6`0J
6QX06QXJ01XJ6P806a/K0P0L71`01@0K6a/071`L01`L700K6a/071`L00806a/K1P0L71`201/K6`04
01`L700K6a/071`L01dM7@8071`L0`0M7Ad0100N7Qh07AdM01`L700L71`501dM7@0901`L700M7Ad0
7AdM01dM7@0O7al07AdM01hN7P0M7Ad07alO00D07QhN0P0O7al2020P800401lO7`0N7Qh0820P01lO
7`D0820P00@08B4Q02<S8`0Q8B40820P0`0Q8B42028R8P03024Q8@0S8b<08b<S00H092@T00P09BDU
02@T900V9RH09BDU02HV9P0U9BD09RHV02PX:0809bLW00/0:2PX02LW9`0X:2P0:2PX02HV9P0W9bL0
:BTY02PX:00Y:BT0:b/[02PX:00302XZ:P0502/[:`0/;2`0;2`/02d];@0^;Rh00P0/;2`01P0];Bd0
;Rh^02h^;P0^;Rh0;bl_02h^;P<0;bl_0P0`<302034a<@0502l_;`0a<C40<30`038b<P0`<3001@0a
<C400`0`<300<C4a038b<P03034a<@03030`<00b<S80<30`0080<30`00<0<C4a02l_;`0`<3000P0_
;bl0200];Bd0;bl_02l_;`0_;bl0;Bd]02l_;`0/;2`0;Rh^0`0/;2`02P0[:b/0:BTY02/[:`0[:b/0
;2`/02/[:`0Y:BT0:RXZ02TY:@0W9bL202PX:0<09bLW00H0:2PX02DU9@0V9RH09BDU02HV9P0T92@4
02DU9@0302@T900U9BD08R8R00808b<S0P0R8R801`0Q8B408b<S02<S8`0R8R808B4Q028R8P0S8b<0
1`0Q8B400`0O7al0820P01lO7`0401lO7`0301hN7P0P82007QhN00807alO00@07QhN01dM7@0M7Ad0
7AdM0`0N7Qh301dM7@8071`L00H07AdM01`L700L71`06a/K01dM7@0K6a/201`L700501/K6`0L71`0
71`L01`L700K6a/00`0L71`0100J6QX06a/K01/K6`0I6AT201`L70806a/K0P0L71`01@0J6QX06a/K
01XJ6P0I6AT06a/K00806QXJ00D06ATI01XJ6P0J6QX06QXJ01TI6@0501XJ6P0501TI6@0J6QX06QXJ
01XJ6P0I6AT0100J6QX201TI6@<06QXJ00<06ATI0=WIf@3IfMT0103IfMT100000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI0P0J6QX201/K6`0501XJ6P0K6a/06QXJ01/K6`0J6QX00`0K6a/0
100L71`06a/K01XJ6P0J6QX201/K6`0B01XJ6P0K6a/06QXJ01/K6`0I6AT071`L01TI6@0L71`06a/K
01`L700J6QX06a/K01XJ6P0L71`06a/K01`L700K6a/06QXJ0P0L71`0100K6a/071`L01`L700J6QX2
01/K6`0801dM7@0K6a/071`L01dM7@0L71`06a/K01hN7P0M7Ad201`L700801dM7@0N7Qh07AdM01`L
700M7Ad071`L01dM7@0N7Qh201dM7@807QhN0P0M7Ad00`0P82007QhN01hN7P0301hN7P<07alO0P0P
820201lO7`80820P00T07alO020P800Q8B408B4Q020P800S8b<08R8R024Q8@0P82000P0R8R801@0S
8b<08R8R028R8P0S8b<08R8R008092@T00X08b<S02@T900U9BD092@T02<S8`0U9BD08b<S02@T900U
9BD09RHV0`0U9BD202HV9P809bLW0P0X:2P01@0Y:BT09bLW02TY:@0Z:RX0:2PX00<0:RXZ00<0:BTY
02/[:`0Z:RX00P0[:b/302`/;00502d];@0/;2`0;Bd]02`/;00^;Rh00`0_;bl0100^;Rh0;bl_030`
<00^;Rh2030`<0<0;bl_00D0<C4a030`<00`<300<C4a030`<00402l_;`05034a<@0`<300<C4a02l_
;`0a<C400P0_;bl0100^;Rh0<30`02l_;`0`<30402l_;`0402h^;P0];Bd0;Rh^02d];@80;2`/00@0
:b/[02`/;00[:b/0:b/[0`0Z:RX202TY:@0802XZ:P0X:2P09bLW02LW9`0X:2P09RHV02LW9`0V9RH4
02LW9`0402HV9P0U9BD09BDU02DU9@808b<S0`0T92@202<S8`05028R8P0Q8B408B4Q02<S8`0P8200
0P0R8R80100Q8B40820P028R8P0P8203024Q8@05028R8P0P8200820P020P800Q8B400P0O7al0100P
82007QhN01lO7`0P820201lO7`807AdM00<0820P01hN7P0O7al00`0M7Ad01P0N7Qh07AdM01dM7@0M
7Ad071`L01dM7@8071`L00<07AdM01/K6`0M7Ad00P0L71`00`0K6a/071`L01dM7@0301/K6`8071`L
00@06QXJ01`L700J6QX06QXJ0P0K6a/201XJ6P8071`L0P0K6a/00`0I6AT06a/K01XJ6P0201/K6`<0
6QXJ00<071`L01XJ6P0K6a/01`0J6QX00`0I6AT06QXJ01XJ6P0301XJ6P0501/K6`0L71`06ATI01XJ
6P0H61P00P0I6AT60=WIf@4000000@3IfMT001H0fMWI0P0000040=WIf@0401XJ6P0I6AT06QXJ01XJ
6P806a/K00<06QXJ01/K6`0K6a/01P0K6a/00`0J6QX071`L01`L700201/K6`0401XJ6P0K6a/06a/K
01XJ6P806a/K00D06QXJ01`L700J6QX071`L01XJ6P0301/K6`@071`L00H07AdM01hN7P0L71`06a/K
01dM7@0L71`401dM7@0401`L700N7Qh07AdM01/K6`807AdM0P0L71`301dM7@0401hN7P0M7Ad071`L
01hN7PD07AdM00<07alO01dM7@0N7Qh00`0N7Qh01P0M7Ad07alO01lO7`0O7al0820P024Q8@807alO
0P0P82002P0O7al0820P028R8P0Q8B40820P024Q8@0R8R808B4Q028R8P0Q8B4202<S8`05024Q8@0R
8R808R8R024Q8@0T92@0100S8b<0200T92@09BDU02@T900U9BD092@T02LW9`0V9RH09bLW0P0V9RH2
02LW9`<0:2PX00@0:BTY02PX:00Z:RX0:BTY0P0X:2P00`0Y:BT0:2PX02PX:00202XZ:P0402/[:`0/
;2`0;2`/02XZ:P<0:b/[00<0;Rh^02d];@0];Bd00P0^;Rh0100];Bd0;bl_02l_;`0`<30602l_;`08
030`<00a<C40;bl_02h^;P0`<300;bl_030`<00a<C4202l_;`03030`<00_;bl0<30`00<0;bl_00P0
<30`02h^;P0`<300;Rh^02l_;`0^;Rh0;Bd]02h^;PD0;2`/00P0:BTY02/[:`0[:b/0:RXZ02/[:`0Z
:RX0:b/[02XZ:P80:BTY0`0X:2P00`0W9bL0:2PX02HV9P0302LW9`<09RHV00<09BDU02HV9P0U9BD0
0P0T92@202DU9@<092@T00@08R8R02<S8`0R8R808R8R0`0Q8B401P0O7al08R8R020P800P82008B4Q
01lO7`<08B4Q1@0P82001@0N7Qh0820P01lO7`0P82007QhN00@07alO1@0N7Qh301dM7@<071`L00D0
7AdM01`L700L71`071`L01dM7@0401`L70@06a/K00<071`L01/K6`0K6a/00`0K6a/02P0L71`06a/K
01XJ6P0K6a/071`L01/K6`0L71`06QXJ01/K6`0J6QX201/K6`0301XJ6P0K6a/06QXJ00806a/K200J
6QX01P0K6a/06QXJ01XJ6P0J6QX06ATI01/K6`806QXJ00L06ATI01XJ6P0J6QX06ATI01XJ6P0I6AT0
6QXJ00D0fMWI0P0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0401XJ6P0I6AT06ATI
01/K6`806QXJ00H06a/K01TI6@0K6a/06QXJ01/K6`0L71`201/K6`0301XJ6P0K6a/06a/K00<06QXJ
00H071`L01XJ6P0K6a/071`L01/K6`0J6QX301`L70<06a/K00<071`L01/K6`0K6a/00P0K6a/01P0L
71`07AdM01`L700M7Ad071`L01/K6`8071`L100M7Ad201`L700301dM7@0K6a/071`L008071`L00@0
7AdM01`L700M7Ad071`L100M7Ad501hN7P<07AdM00@07QhN01lO7`0O7al07QhN0`0O7al3020P80@0
8B4Q00D0820P028R8P0Q8B40820P028R8P02024Q8@808R8R00D08B4Q028R8P0R8R808R8R02<S8`02
028R8P0602DU9@0T92@092@T02@T900R8R808b<S0P0T92@202DU9@0302@T900U9BD09bLW0080:2PX
0P0W9bL202PX:00302LW9`0X:2P0:BTY0080:2PX0P0Y:BT00`0X:2P0:BTY02TY:@0302XZ:P0302`/
;00[:b/0:b/[00<0;Bd]00D0;2`/02d];@0^;Rh0;Bd]02/[:`0202d];@0302h^;P0_;bl0;Bd]0080
;Rh^0`0_;bl202h^;P@0;bl_0P0^;Rh00`0_;bl0;Rh^02l_;`0302l_;`0902d];@0_;bl0;Bd]02d]
;@0^;Rh0;Bd]02`/;00];Bd0:b/[00<0;2`/0P0[:b/0100Z:RX0:b/[02XZ:P0X:2P402TY:@0502PX
:00Z:RX0:BTY02TY:@0W9bL00P0V9RH01@0W9bL09RHV02HV9P0W9bL09RHV00@09BDU00<092@T02<S
8`0U9BD00P0T92@01P0R8R808b<S02<S8`0R8R808b<S02@T90808B4Q00H08R8R020P800P82008B4Q
02<S8`0Q8B44020P8004024Q8@0O7al07QhN020P80L07alO00@07QhN01lO7`0N7Qh07QhN0P0L71`0
1P0N7Qh07AdM01lO7`0N7Qh06a/K01dM7@806a/K00<07QhN01dM7@0L71`00P0L71`201/K6`0501`L
700K6a/06a/K01`L700K6a/00`0L71`0100K6a/071`L01XJ6P0K6a/201`L70806a/K00H06QXJ01/K
6`0K6a/06a/K01`L700K6a/601XJ6P0301/K6`0J6QX06QXJ00806a/K00@06ATI01XJ6P0K6a/06QXJ
0P0I6AT00`0K6a/06ATI01XJ6P0601XJ6P806ATI00<06QXJ01TI6@3IfMT01@3IfMT100000040fMWI
000F0=WIf@030000003IfMT0fMWI00<0fMWI00D06QXJ01TI6@0K6a/06QXJ01TI6@0301XJ6P0501/K
6`0J6QX06QXJ01XJ6P0K6a/00P0J6QX201/K6`806QXJ1@0K6a/02@0J6QX071`L01/K6`0L71`06QXJ
01`L700K6a/071`L01/K6`0201`L700501/K6`0L71`071`L01`L700K6a/00P0L71`01P0J6QX071`L
01`L700K6a/071`L01/K6`<07AdM00H071`L01/K6`0M7Ad071`L01dM7@0L71`201dM7@0301`L700M
7Ad07AdM00807AdM00@07QhN01dM7@0N7Qh07AdM1P0N7Qh01@0P82007alO01lO7`0O7al07QhN0080
7alO0`0P82001@0Q8B407alO024Q8@0P82008R8R00@08B4Q100R8R80100Q8B408R8R02<S8`0R8R82
02<S8`D092@T0P0U9BD0100T92@09RHV02DU9@0U9BD302HV9P809bLW00L09RHV02PX:00W9bL0:BTY
02LW9`0X:2P09bLW00<0:2PX00H0:BTY02PX:00Y:BT0:BTY02PX:00Y:BT302XZ:P80;2`/00H0:b/[
02`/;00];Bd0;Bd]02`/;00];Bd402`/;00602d];@0/;2`0;Bd]02d];@0_;bl0;Bd]0P0_;bl00`0]
;Bd0;bl_02h^;P0202d];@0402h^;P0/;2`0;Bd]02`/;080;Rh^0`0];Bd202`/;00402d];@0[:b/0
:b/[02`/;080:b/[00d0:BTY02XZ:P0Z:RX0:RXZ02TY:@0Z:RX0:2PX02XZ:P0X:2P0:BTY02PX:00W
9bL0:BTY00D09bLW0P0V9RH01`0W9bL09RHV02DU9@0U9BD09RHV02DU9@0T92@00P0U9BD01@0T92@0
8b<S028R8P0T92@08b<S00808R8R00D08B4Q028R8P0R8R808B4Q020P8003024Q8@05020P800Q8B40
7alO020P800N7Qh00P0O7al01P0P82007alO01lO7`0P82007QhN01lO7`807QhN0`0O7al01P0N7Qh0
7AdM01dM7@0N7Qh07AdM01hN7P807AdM0P0L71`201dM7@0=01hN7P0M7Ad071`L01/K6`0L71`07AdM
01`L700K6a/06QXJ01/K6`0L71`07AdM01`L700401/K6`806QXJ00<06ATI01/K6`0K6a/00P0J6QX0
2`0K6a/06QXJ01/K6`0K6a/06QXJ01/K6`0I6AT06QXJ01dM7@0J6QX071`L00806a/K100J6QX201/K
6`0301XJ6P0I6AT06QXJ00<06QXJ00L06ATI01/K6`0H61P06ATI01XJ6P0I6AT06QXJ00<06ATI00<0
6QXJ0=WIf@3IfMT0103IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0`0K6a/0
0`0J6QX06a/K01/K6`0201XJ6P0501/K6`0I6AT06QXJ01XJ6P0K6a/00P0J6QX201/K6`0601XJ6P0K
6a/06QXJ01/K6`0J6QX06a/K0P0J6QX00`0L71`06a/K01/K6`0201/K6`8071`L0`0K6a/00`0L71`0
6a/K01`L700201/K6`8071`L00<06a/K01`L700K6a/00P0M7Ad01@0K6a/071`L01`L700L71`07AdM
008071`L00<07AdM01`L700M7Ad0100M7Ad0100O7al07AdM01dM7@0M7Ad401hN7P0401dM7@0O7al0
7QhN01hN7P807alO00D0820P01hN7P0O7al07alO020P800201lO7`<0820P00X08B4Q020P800Q8B40
8R8R024Q8@0R8R808B4Q028R8P0Q8B40820P0`0R8R801P0S8b<08B4Q028R8P0S8b<092@T02<S8`80
9BDU00<08b<S02@T900U9BD00P0U9BD202@T900302LW9`0V9RH09bLW00809bLW00H09RHV02LW9`0V
9RH0:2PX02LW9`0Y:BT302PX:00802TY:@0W9bL0:BTY02TY:@0X:2P0:BTY02XZ:P0Y:BT302XZ:P80
:b/[00L0;2`/02/[:`0/;2`0;2`/02/[:`0/;2`0;Rh^0080;Bd]00X0;2`/02d];@0^;Rh0;2`/02h^
;P0];Bd0;Rh^02d];@0^;Rh0;Bd]0P0^;Rh02`0/;2`0;Rh^02`/;00];Bd0;Rh^02d];@0/;2`0:b/[
02d];@0/;2`0:b/[0080;Bd]00D0:b/[02`/;00[:b/0:b/[02XZ:P0202/[:`0502TY:@0Z:RX0:BTY
02TY:@0X:2P00P0Y:BT0100Z:RX0:BTY02PX:00Y:BT202PX:00302HV9P0W9bL0:2PX00<09BDU00H0
92@T02DU9@0U9BD09BDU02HV9P0U9BD302@T900302<S8`0T92@08R8R00808R8R0P0S8b<2028R8P04
020P800R8R80820P028R8P80820P0P0Q8B4201lO7`03020P800Q8B40820P0080820P0P0O7al401hN
7P0601dM7@0O7al07QhN01hN7P0M7Ad07alO0P0M7Ad01`0N7Qh07alO01hN7P0L71`07AdM01hN7P0K
6a/00P0M7Ad201`L70807AdM100L71`00`0K6a/06QXJ01`L700201`L700401XJ6P0K6a/06a/K01dM
7@/06a/K0P0J6QX401/K6`0301`L700K6a/071`L00<06QXJ00H06a/K01`L700K6a/06a/K01XJ6P0I
6AT201XJ6P0301TI6@0J6QX06a/K00<06QXJ00@061PH01XJ6P0H61P061PH1P3IfMT100000040fMWI
000F0=WIf@030000003IfMT0fMWI00<0fMWI00<06QXJ01/K6`0J6QX00P0J6QX00`0K6a/06QXJ01/K
6`0201XJ6P<06a/K00<06QXJ01/K6`0K6a/00P0K6a/0100J6QX06a/K01/K6`0K6a/201XJ6P0401/K
6`0J6QX071`L01XJ6P806a/K00<06QXJ01`L700K6a/00P0K6a/00`0L71`06a/K01/K6`0501`L7003
01/K6`0L71`071`L00@06a/K0P0M7Ad01`0L71`07AdM01dM7@0K6a/07AdM01`L700M7Ad00P0N7Qh0
1@0M7Ad07QhN01dM7@0N7Qh071`L00<07AdM00<07QhN01dM7@0O7al00P0N7Qh01@0P82007QhN01hN
7P0O7al0820P00807alO00<0820P01lO7`0P82000`0P82001@0Q8B40820P024Q8@0Q8B408b<S0080
8B4Q00@08R8R024Q8@0Q8B408R8R0P0Q8B400`0R8R808b<S02<S8`0302@T900802DU9@0T92@092@T
02HV9P0U9BD092@T02HV9P0S8b<202DU9@@09RHV00D0:2PX02HV9P0W9bL0:2PX02LW9`0302PX:006
02HV9P0X:2P0:RXZ02PX:00Y:BT0:2PX0`0Z:RX0100X:2P0:BTY02/[:`0/;2`302/[:`<0;2`/0P0[
:b/00`0/;2`0:b/[02d];@0302`/;00402d];@0/;2`0;Bd]02d];@<0;2`/00H0;Bd]02`/;00/;2`0
;Bd]02`/;00[:b/302`/;00802/[:`0Z:RX0:b/[02`/;00];Bd0;2`/02/[:`0Z:RX202TY:@0702XZ
:P0Y:BT0:2PX02TY:@0X:2P0:BTY02LW9`0302PX:0809bLW00P0:2PX02DU9@0U9BD0:2PX02HV9P0U
9BD09RHV02DU9@<092@T0`0U9BD01P0T92@09BDU02<S8`0S8b<08B4Q02<S8`D08B4Q0P0R8R82024Q
8@0301lO7`0P8200820P00808B4Q00@07alO024Q8@0O7al0820P0`0O7al00`0P82007alO01hN7P02
01lO7`0701hN7P0O7al07QhN01`L700M7Ad07QhN01`L700301hN7P0801dM7@0L71`07QhN01dM7@0N
7Qh07AdM01`L700M7Ad301`L700601/K6`0L71`071`L01/K6`0M7Ad071`L0P0K6a/00`0M7Ad06a/K
01/K6`0201XJ6P806a/K00<071`L01/K6`0K6a/00P0K6a/201XJ6P0301/K6`0J6QX06QXJ00806QXJ
0P0K6a/00`0J6QX06a/K01XJ6P0201XJ6P0501/K6`0J6QX06a/K01XJ6P0K6a/01@0J6QX0100I6AT0
6QXJ01TI6@0J6QX201TI6@806QXJ00<061PH01TI6@3IfMT01@3IfMT100000040fMWI000F0=WIf@03
0000003IfMT0fMWI00<0fMWI0P0J6QX201/K6`806QXJ00@06a/K01XJ6P0K6a/06QXJ0P0K6a/00`0J
6QX06a/K01XJ6P0201XJ6P@06a/K00H06ATI01/K6`0K6a/06QXJ01/K6`0L71`801/K6`0901`L700K
6a/06a/K01dM7@0L71`06a/K01dM7@0L71`07AdM00D071`L00@07QhN01/K6`0L71`071`L100M7Ad0
0`0L71`07AdM01lO7`0201dM7@0401hN7P0M7Ad07AdM01dM7@<07QhN0P0M7Ad0100O7al07QhN01hN
7P0N7Qh501lO7`03020P800N7Qh07alO00807alO0P0P82002@0O7al08B4Q020P800Q8B40820P024Q
8@0P82008B4Q020P8002028R8P04024Q8@0P82008b<S024Q8@808R8R00T08b<S02@T900R8R808b<S
02@T900S8b<09RHV02<S8`0T92@0100U9BD0100V9RH09BDU02DU9@0W9bL202HV9P0302PX:00W9bL0
9bLW0080:2PX00H09RHV02LW9`0W9bL0:2PX02TY:@0X:2P202TY:@80:RXZ00H0:b/[02XZ:P0[:b/0
;2`/02/[:`0/;2`202/[:`0302XZ:P0[:b/0;2`/0080:b/[1P0/;2`01P0];Bd0;2`/02d];@0/;2`0
;Rh^02/[:`@0;2`/0`0[:b/202`/;00502XZ:P0[:b/0:b/[02XZ:P0[:b/00`0Z:RX00`0Y:BT0:b/[
02XZ:P0202TY:@0:02PX:00Y:BT09bLW02TY:@0[:b/0:2PX02LW9`0X:2P09BDU02LW9`809RHV1P0U
9BD202@T90809BDU00<092@T02DU9@0T92@00P0R8R801@0S8b<08R8R02<S8`0P82008b<S0080820P
0P0Q8B40100R8R807alO024Q8@0P8202024Q8@80820P0P0O7al2020P800501hN7P0O7al0820P024Q
8@0O7al01P0N7Qh01P0M7Ad07QhN01`L700N7Qh07AdM01hN7P<07AdM0`0L71`01@0K6a/071`L01dM
7@0M7Ad06a/K008071`L00<06QXJ01`L700L71`00P0L71`201/K6`0601XJ6P0K6a/06QXJ01`L700K
6a/06QXJ0`0K6a/0100I6AT06QXJ01XJ6P0K6a/801XJ6P<06ATI1@0J6QX00`0I6AT06QXJ01TI6@02
01XJ6P806a/K1@0J6QX00`0I6AT06QXJ01XJ6P060=WIf@4000000@3IfMT001H0fMWI00<000000=WI
f@3IfMT00`3IfMT201/K6`0401`L700I6AT06a/K01`L70<06a/K0P0J6QX0100K6a/06QXJ01XJ6P0L
71`201/K6`0401`L700K6a/06a/K01TI6@806a/K00@071`L01/K6`0J6QX06QXJ0`0K6a/201`L7080
6a/K0P0L71`00`0K6a/071`L01/K6`0501`L700301dM7@0K6a/07AdM00H071`L0`0M7Ad00`0L71`0
7AdM01dM7@0201hN7P0501dM7@0N7Qh071`L01hN7P0M7Ad00P0O7al201hN7P0301dM7@0O7al07QhN
00807QhN00L07AdM01hN7P0P82007alO01hN7P0Q8B40820P00807alO00<0820P01lO7`0O7al00`0P
82000`0Q8B40820P020P8003024Q8@03020P800R8R808R8R00808b<S00@08B4Q02<S8`0S8b<08b<S
0P0T92@02@0R8R808b<S02@T900U9BD092@T02DU9@0T92@09BDU02<S8`0202DU9@P09RHV00L09bLW
02HV9P0X:2P09bLW02PX:00W9bL0:2PX00<0:BTY00<0:RXZ02TY:@0Y:BT00P0Z:RX00`0Y:BT0:b/[
02XZ:P0402/[:`0302XZ:P0[:b/0;2`/0080:RXZ00L0;2`/02XZ:P0[:b/0:RXZ02d];@0[:b/0;2`/
0080:b/[00<0;2`/02/[:`0/;2`00P0[:b/00`0/;2`0:b/[02XZ:P0302XZ:P0302/[:`0Z:RX0:RXZ
0080:BTY0`0Z:RX0100Y:BT0:RXZ02PX:00Z:RX402PX:0@09bLW00<09RHV02LW9`0V9RH00P0U9BD0
2P0V9RH08b<S02@T900U9BD092@T02DU9@0S8b<092@T02<S8`0T92@202<S8`808R8R00<0820P028R
8P0S8b<00P0Q8B400`0R8R80820P024Q8@03024Q8@<0820P00L07alO024Q8@0P8200820P01lO7`0N
7Qh0820P00807alO00@07QhN020P800N7Qh07alO0P0N7Qh301dM7@<07QhN0P0M7Ad00`0N7Qh071`L
01dM7@0201dM7@0301`L700M7Ad07AdM008071`L00@06a/K01`L700L71`06a/K0P0J6QX0100M7Ad0
71`L01XJ6P0L71`201/K6`806QXJ0P0K6a/01@0J6QX06a/K01/K6`0J6QX06a/K00@06QXJ00<071`L
01XJ6P0J6QX00P0I6AT201/K6`0401XJ6P0K6a/06QXJ01TI6@<06QXJ00<06a/K01XJ6P0J6QX00P0J
6QX01@0K6a/06ATI01TI6@0J6QX061PH00806QXJ00@061PH01TI6@0I6AT06ATI1P3IfMT100000040
fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00<071`L01/K6`0K6a/00P0J6QX201/K6`@06QXJ
1@0K6a/201XJ6P0501/K6`0J6QX06QXJ01/K6`0L71`00P0J6QX00`0K6a/071`L01/K6`0201/K6`03
01XJ6P0K6a/06QXJ00806a/K00@07AdM01`L700M7Ad071`L0P0K6a/301`L700801/K6`0L71`071`L
01`L700M7Ad071`L01/K6`0L71`201dM7@0301`L700M7Ad071`L008071`L00D07AdM01hN7P0M7Ad0
7AdM01hN7P0201dM7@D07QhN1@0O7al00`0N7Qh07alO01hN7P02020P800=01lO7`0P8200820P01lO
7`0P82007alO020P800Q8B407alO024Q8@0P82008R8R01lO7`03024Q8@@08R8R00D08b<S028R8P0S
8b<08b<S028R8P0202@T9003028R8P0T92@092@T00D092@T00L09RHV02DU9@0V9RH09RHV02DU9@0V
9RH09bLW00809RHV0P0W9bL00`0V9RH09bLW02PX:00402PX:00302XZ:P0W9bL0:2PX00D0:BTY00<0
:2PX02TY:@0Y:BT00P0[:b/0100Z:RX0:b/[02/[:`0Z:RX302/[:`0802`/;00[:b/0:b/[02/[:`0Z
:RX0:b/[02`/;00[:b/202XZ:P0302`/;00Z:RX0;2`/00@0:RXZ00H0:BTY02/[:`0Z:RX0:b/[02TY
:@0Z:RX202TY:@0602XZ:P0X:2P0:BTY02LW9`0Y:BT0:RXZ100X:2P01@0W9bL09RHV02PX:00U9BD0
9bLW00809BDU00D092@T02HV9P0S8b<09BDU02<S8`0302DU9@0402<S8`0U9BD08b<S02@T90808b<S
0`0R8R82024Q8@0402<S8`0R8R808R8R024Q8@80820P00H08B4Q020P800P8200820P024Q8@0O7al2
020P800:01lO7`0P8200820P01hN7P0P82007alO01dM7@0N7Qh0820P01lO7`807QhN00@07AdM01hN
7P0M7Ad07QhN1P0M7Ad00`0N7Qh07AdM01dM7@0201dM7@8071`L00L06a/K01`L700M7Ad06a/K01`L
700K6a/06QXJ00806a/K00L071`L01XJ6P0L71`06a/K01`L700J6QX06a/K00806ATI00@06a/K01XJ
6P0J6QX06a/K0P0J6QX00`0I6AT06QXJ01XJ6P0401XJ6P0901/K6`0H61P06QXJ01XJ6P0L71`06QXJ
01/K6`0J6QX06a/K00<06QXJ00D061PH01XJ6P0J6QX06QXJ01`L700301XJ6P0301TI6@0H61P05aLG
00806ATI1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00<07AdM01`L700K
6a/00`0J6QX00`0I6AT06a/K01XJ6P0201TI6@0401XJ6P0K6a/06ATI01/K6`806QXJ0P0K6a/01@0I
6AT06a/K01`L700K6a/06ATI00806QXJ0P0K6a/201XJ6P0401/K6`0L71`071`L01/K6`8071`L00<0
6QXJ01`L700M7Ad0100L71`00`0K6a/071`L01`L700201dM7@0301`L700M7Ad071`L008071`L00@0
7AdM01`L700M7Ad07AdM0`0L71`201dM7@0301hN7P0M7Ad07QhN00<07AdM00D07QhN01lO7`0N7Qh0
7alO01hN7P0301lO7`0301hN7P0O7al07QhN00807alO00D07QhN01lO7`0P8200820P01lO7`03020P
8003028R8P0P8200820P0080820P00@08R8R024Q8@0R8R808B4Q0P0P8202024Q8@0302<S8`0T92@0
8R8R00@08b<S00L092@T02DU9@0S8b<08b<S02@T900U9BD092@T00<09BDU00<09RHV02DU9@0T92@0
0P0U9BD302HV9P0402@T900W9bL09bLW02PX:0809bLW0P0X:2P202LW9`0302PX:00W9bL0:BTY0080
:BTY00T0:RXZ02TY:@0Y:BT0:RXZ02TY:@0Z:RX0:b/[02XZ:P0Y:BT00P0Z:RX0100[:b/0:RXZ02/[
:`0Z:RX302`/;00302/[:`0/;2`0:b/[00<0:b/[00<0:RXZ02TY:@0X:2P00P0Z:RX202PX:0@0:BTY
00@0:RXZ02PX:00X:2P0:2PX0`0W9bL01P0X:2P0:BTY02HV9P0X:2P09bLW02HV9P809bLW00<09RHV
02LW9`0U9BD0100U9BD402@T900302DU9@0T92@092@T00@08b<S0P0R8R801@0P82008B4Q028R8P0Q
8B408R8R00@08B4Q00@0820P028R8P0O7al08B4Q0P0N7Qh501lO7`0301hN7P0O7al07alO00807QhN
00@07AdM01hN7P0M7Ad07AdM0P0N7Qh00`0M7Ad07QhN01`L700201hN7P0401dM7@0L71`07AdM01dM
7@8071`L0P0N7Qh00`0L71`06a/K01`L700201`L70<06a/K00D071`L01/K6`0L71`071`L01/K6`02
01XJ6P@06a/K00<06QXJ01/K6`0K6a/00`0J6QX03`0K6a/06QXJ01/K6`0J6QX06ATI01XJ6P0K6a/0
6QXJ01PH600J6QX06a/K01XJ6P0I6AT06QXJ01TI6@0201XJ6P0501TI6@0J6QX06ATI01XJ6P0I6AT0
0P0J6QX401TI6@806QXJ00<06ATI01XJ6P0I6AT01P3IfMT100000040fMWI000F0=WIf@030000003I
fMT0fMWI00<0fMWI00@07alO01/K6`0K6a/06ATI1@0J6QX00`0I6AT06QXJ01TI6@0201XJ6P0301TI
6@0J6QX06QXJ00<06QXJ00@06a/K01XJ6P0K6a/06a/K0P0J6QX00`0K6a/06QXJ01XJ6P0201/K6`80
6QXJ00<06a/K01XJ6P0K6a/00`0K6a/00`0L71`06a/K01`L700201/K6`<071`L100K6a/601`L7080
7AdM0P0N7Qh0200M7Ad07QhN01dM7@0N7Qh07AdM01hN7P0M7Ad07QhN0P0O7al00`0N7Qh07alO01lO
7`0201hN7P0301lO7`0N7Qh0820P00807alO00<0820P01lO7`0N7Qh00`0P82002`0O7al0820P024Q
8@0R8R807alO024Q8@0P82007alO024Q8@0P82008R8R00808B4Q00<08R8R024Q8@0S8b<00P0R8R80
1@0T92@08b<S024Q8@0S8b<092@T00809BDU00L092@T02<S8`0S8b<08b<S02@T900U9BD092@T00@0
9BDU00@092@T02LW9`0V9RH09BDU0P0V9RH00`0W9bL09RHV02PX:00402LW9`0502PX:00Y:BT0:BTY
02TY:@0Z:RX00P0Y:BT0100X:2P0:BTY02XZ:P0X:2P202TY:@0602PX:00Y:BT0:BTY02TY:@0Z:RX0
;2`/100Z:RX01@0[:b/0:RXZ02`/;00Y:BT0:b/[00<0:BTY00<0:b/[02TY:@0Y:BT00P0X:2P0100Y
:BT0:RXZ02PX:00Y:BT202PX:00302LW9`0X:2P09bLW00D09bLW0P0V9RH202LW9`0302HV9P0W9bL0
92@T00809RHV00<092@T02DU9@0U9BD00P0U9BD00`0T92@09BDU02@T900402@T900402<S8`0T92@0
8B4Q02<S8`808R8R00@0820P028R8P0R8R808B4Q0`0P82000`0Q8B40820P024Q8@02020P800301lO
7`0N7Qh07alO00807alO00D07QhN01lO7`0N7Qh07alO01hN7P0201lO7`<07QhN00<071`L01dM7@0O
7al0100M7Ad02@0L71`07AdM01hN7P0M7Ad071`L01hN7P0L71`07AdM01/K6`0201`L700501dM7@0N
7Qh071`L01/K6`0I6AT0100K6a/00`0L71`06a/K01/K6`0201XJ6P0601`L700K6a/06a/K01XJ6P0K
6a/071`L0P0K6a/01P0J6QX06a/K01/K6`0K6a/06QXJ01/K6`806ATI00<06a/K01XJ6P0J6QX00P0I
6AT601XJ6P0301PH600K6a/06QXJ00806ATI00@06a/K01TI6@0I6AT06ATI0P0J6QX401TI6@H0fMWI
0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0401lO7`0L71`06ATI01/K6`806QXJ
00<06ATI01XJ6P0K6a/00`0J6QX0100K6a/06QXJ01XJ6P0I6AT401XJ6P0701/K6`0J6QX06a/K01XJ
6P0I6AT06QXJ01/K6`0301XJ6P0301/K6`0J6QX06a/K00806a/K00D06QXJ01`L700L71`071`L01/K
6`0201`L70@06a/K00@071`L01/K6`0L71`06a/K0P0L71`0100K6a/071`L01dM7@0M7Ad201`L7003
01hN7P0O7al07QhN00807AdM0`0L71`00`0N7Qh071`L01`L700201hN7P03020P800N7Qh07alO0080
7QhN100O7al01@0N7Qh07alO01lO7`0O7al07QhN00<07alO00<0820P01lO7`0P82000P0P82002@0Q
8B407alO028R8P0R8R80820P024Q8@0P82008B4Q020P8003028R8P0402<S8`0R8R808R8R02@T9080
8b<S00D08R8R02@T900S8b<092@T02HV9P0402DU9@0:02@T900U9BD092@T02DU9@0W9bL09BDU02LW
9`0U9BD09RHV02DU9@809RHV00D0:2PX02LW9`0V9RH09bLW02HV9P0302TY:@L0:2PX00<0:BTY02PX
:00X:2P0100Y:BT01`0W9bL0:RXZ02TY:@0Z:RX0:2PX02TY:@0Z:RX00P0[:b/302TY:@0502XZ:P0Y
:BT0:RXZ02PX:00Z:RX01P0X:2P01@0V9RH0:2PX02PX:00W9bL0:2PX00809RHV0P0W9bL01@0V9RH0
9bLW02HV9P0W9bL09RHV00809BDU00P09RHV02@T900T92@092@T02DU9@0T92@09BDU028R8P@092@T
00<08b<S02@T900S8b<00`0R8R802@0S8b<08R8R028R8P0Q8B40820P028R8P0Q8B408R8R020P8002
024Q8@@0820P00<07alO020P800O7al00P0N7Qh0100O7al07QhN01lO7`0O7al501hN7P0401dM7@0N
7Qh07AdM01hN7P807AdM100L71`00`0M7Ad071`L01/K6`0401`L700401/K6`0M7Ad06a/K01`L7080
6a/K00@06QXJ01`L700K6a/06QXJ0P0K6a/02@0J6QX06a/K01XJ6P0J6QX06a/K01XJ6P0K6a/06QXJ
01/K6`0901XJ6P0301TI6@0J6QX06QXJ00<06QXJ00<06a/K01TI6@0I6AT00P0K6a/00`0I6AT06QXJ
01TI6@0401XJ6P806ATI00<06a/K01TI6@0I6AT0100I6AT60=WIf@4000000@3IfMT00080fMWI0P00
00040=WIf@800000103IfMT2000000H0fMWI00<000000=WIf@3IfMT00`3IfMT0100N7Qh06a/K01XJ
6P0I6AT201/K6`806QXJ00@06a/K01XJ6P0J6QX06QXJ0P0K6a/0100I6AT06QXJ01XJ6P0K6a/201XJ
6P0301/K6`0J6QX06a/K00@06a/K0P0J6QX0100K6a/071`L01`L700K6a/201XJ6PD06a/K00<06QXJ
01`L700L71`00P0K6a/01@0N7Qh07AdM01dM7@0L71`06a/K008071`L00@07AdM01`L700L71`06a/K
0P0M7Ad0200N7Qh07AdM01`L700L71`07QhN01dM7@0N7Qh07AdM0P0N7Qh00`0M7Ad07QhN01hN7P03
01hN7P0301dM7@0O7al07alO00807QhN0P0O7al01P0N7Qh0820P01lO7`0N7Qh07alO024Q8@H0820P
00L08B4Q020P800P82008B4Q020P800Q8B408R8R00808B4Q00@08R8R024Q8@0R8R808b<S0P0R8R80
0`0S8b<092@T02<S8`0202@T900302DU9@0R8R809BDU008092@T100U9BD202@T900302HV9P0T92@0
9BDU00809BDU0P0W9bL302HV9P809bLW00@09RHV02PX:00X:2P0:BTY0P0W9bL01`0Y:BT0:2PX02PX
:00X:2P0:BTY02PX:00Y:BT00`0X:2P202TY:@0502PX:00Y:BT0:BTY02XZ:P0Y:BT00P0Z:RX202TY
:@0402XZ:P0X:2P0:2PX02TY:@D0:2PX00/09bLW02PX:00X:2P09RHV02PX:00Y:BT09bLW02PX:00V
9RH09bLW02HV9P0202LW9`0602HV9P0W9bL09bLW02DU9@0W9bL09RHV0P0U9BD0100V9RH09BDU02DU
9@0T92@202DU9@04028R8P0S8b<092@T02DU9@808b<S00D092@T02<S8`0Q8B408R8R02<S8`02024Q
8@06028R8P0Q8B40820P028R8P0Q8B408R8R0P0P82001`0Q8B40820P020P800N7Qh08B4Q01lO7`0P
82000P0O7al201hN7P807alO0P0N7Qh301lO7`0701dM7@0O7al07alO01`L700N7Qh07AdM01hN7P02
01dM7@8071`L00D07QhN01dM7@0L71`07AdM01`L700201dM7@0301`L700K6a/06a/K00D071`L00H0
6a/K01XJ6P0K6a/06QXJ01/K6`0J6QX401/K6`0701`L700K6a/06ATI01XJ6P0K6a/06QXJ01/K6`03
01XJ6P0301/K6`0J6QX06QXJ00L06QXJ0P0I6AT00`0J6QX061PH01XJ6P0401XJ6P806ATI00@06QXJ
01TI6@0J6QX06ATI0P0J6QX301TI6@H0fMWI0@0000010=WIf@0000D0fMWI0000003IfMT0fMWI0000
00020=WIf@040000003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT000001@3IfMT00`000000
fMWI0=WIf@030=WIf@0401`L700K6a/06QXJ01/K6`806QXJ0P0K6a/501XJ6P<06a/K0P0J6QX201/K
6`806QXJ00H06ATI01XJ6P0K6a/06ATI01/K6`0J6QX301/K6`0301XJ6P0L71`071`L00<06a/K00D0
71`L01/K6`0L71`06a/K01`L700201/K6`0501`L700K6a/06a/K01`L700K6a/00`0L71`301dM7@80
71`L0`0M7Ad0100L71`07AdM01dM7@0M7Ad201hN7P0401dM7@0N7Qh07AdM01dM7@807QhN00@07alO
01dM7@0O7al07AdM0`0O7al201hN7P<07alO00<07QhN01lO7`0O7al00P0O7al00`0M7Ad07alO020P
8004020P80808B4Q00@08R8R024Q8@0Q8B408b<S0P0R8R800`0S8b<08R8R028R8P02028R8P0702<S
8`0R8R808R8R02@T900S8b<092@T02<S8`0202@T900=02<S8`0T92@09BDU02HV9P0U9BD09RHV02DU
9@0T92@09BDU02HV9P0U9BD09RHV02DU9@0402HV9P0302DU9@0W9bL09bLW00809bLW00H0:2PX02LW
9`0W9bL09bLW02PX:00Y:BT202PX:00402TY:@0X:2P09bLW02TY:@@0:2PX1P0Y:BT01`0X:2P0:BTY
02TY:@0W9bL0:2PX02LW9`0X:2P01@0W9bL00`0V9RH09bLW02LW9`0402HV9P<09bLW0P0V9RH0100T
92@09RHV02HV9P0V9RH302DU9@0502<S8`0T92@09BDU02DU9@0S8b<00P0T92@302<S8`8092@T0P0S
8b<2024Q8@03028R8P0Q8B408R8R00H08B4Q00P08R8R020P800O7al0820P01lO7`0Q8B407alO01hN
7PP07alO00D07QhN01lO7`0L71`07QhN01dM7@0201hN7P0401dM7@0N7Qh07AdM01hN7PD07AdM0P0L
71`01@0M7Ad071`L01/K6`0M7Ad06QXJ00<071`L0P0K6a/201`L700501/K6`0L71`06QXJ01/K6`0L
71`01P0K6a/00`0J6QX06a/K01/K6`0201/K6`0301XJ6P0K6a/06a/K00@06ATI0P0J6QX0100I6AT0
6QXJ01TI6@0J6QX301/K6`0;01TI6@0J6QX06QXJ01XJ6P0K6a/06QXJ01TI6@0J6QX061PH01XJ6P0I
6AT00`0J6QX401TI6@H0fMWI0@0000010=WIf@000`3IfMT01@000000fMWI0=WIf@3IfMT000000080
fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@030=WIf@<000000`3IfMT01@0L
71`06QXJ01XJ6P0K6a/06QXJ00<06a/K00<06QXJ01`L700K6a/00P0J6QX201/K6`806QXJ00<06a/K
01XJ6P0J6QX00P0J6QX01@0K6a/06QXJ01/K6`0L71`06QXJ008071`L0P0J6QX01P0L71`06a/K01`L
700J6QX071`L01XJ6P@071`L00L06a/K01dM7@0M7Ad071`L01/K6`0L71`06a/K008071`L00<06a/K
01`L700L71`00P0M7Ad03P0L71`07AdM01dM7@0K6a/071`L01dM7@0N7Qh07AdM01`L700N7Qh07AdM
01`L700O7al07AdM0`0N7Qh01P0M7Ad07QhN01hN7P0O7al07QhN01dM7@<07QhN00D07alO01dM7@0N
7Qh07QhN01lO7`0201hN7P80820P00H07QhN024Q8@0P82008B4Q01lO7`0P8207024Q8@04028R8P0Q
8B408B4Q024Q8@<08R8R00L092@T028R8P0S8b<08b<S028R8P0T92@08b<S00809RHV0`0T92@00`0U
9BD092@T02@T900202DU9@0302@T900U9BD09BDU00809RHV00<09bLW02HV9P0V9RH00P0W9bL202PX
:00:02HV9P0W9bL0:BTY02HV9P0Y:BT09bLW02TY:@0X:2P0:BTY02LW9`80:2PX00@0:BTY02PX:00X
:2P0:BTY100X:2P03@0Z:RX0:BTY02PX:00W9bL0:2PX02LW9`0X:2P0:BTY02PX:00U9BD0:2PX02LW
9`0X:2P00P0W9bL00`0V9RH09BDU02PX:00202LW9`D09RHV0P0U9BD202HV9P@09BDU00H092@T02HV
9P0U9BD08b<S028R8P0S8b<202@T900402<S8`0R8R809BDU02<S8`<08R8R00H08b<S028R8P0Q8B40
8B4Q028R8P0Q8B42028R8P808B4Q00H08R8R020P800P82008R8R01lO7`0N7Qh601lO7`0301hN7P0O
7al0820P00@07QhN00<07alO01dM7@0M7Ad01P0M7Ad201hN7P807AdM00D06a/K01`L700L71`071`L
01/K6`0301`L700501dM7@0K6a/071`L01`L700K6a/00P0L71`01@0K6a/071`L01XJ6P0L71`06a/K
00806QXJ0P0K6a/00`0J6QX071`L01/K6`0301`L700301XJ6P0K6a/06a/K00H06QXJ00<06a/K01XJ
6P0J6QX00`0J6QX201TI6@0501XJ6P0K6a/06a/K01/K6`0J6QX00P0I6AT00`0J6QX06ATI01TI6@02
01TI6@0401XJ6P0I6AT06ATI01PH60806ATI103IfMT300000040fMWI00040=WIf@040000003IfMT0
fMWI00000080fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@030=WIf@030000
003IfMT0fMWI00<0fMWI0P0K6a/00`0I6AT06QXJ01XJ6P0301/K6`0501TI6@0J6QX06a/K01XJ6P0K
6a/00P0I6AT201/K6`0301XJ6P0K6a/06a/K00806QXJ00<06a/K01XJ6P0J6QX00P0K6a/201XJ6P06
01`L700J6QX06QXJ01`L700K6a/071`L0P0K6a/0100L71`06a/K01`L700K6a/501`L70806a/K100L
71`00`0M7Ad071`L01dM7@0401`L700301hN7P0M7Ad071`L00807AdM00d07alO01hN7P0M7Ad07AdM
01hN7P0M7Ad07QhN01dM7@0O7al07QhN020P800N7Qh07alO00<07QhN00@07alO01hN7P0N7Qh07QhN
0P0O7al00`0P82007alO01lO7`04020P800301lO7`0P82008B4Q0080820P0`0Q8B401P0P82008B4Q
024Q8@0Q8B408R8R024Q8@808R8R0P0S8b<01P0Q8B408b<S028R8P0S8b<08R8R02<S8`<092@T00P0
8b<S02@T900U9BD092@T02DU9@0T92@09BDU02@T90809RHV00P092@T02DU9@0U9BD09BDU02HV9P0U
9BD09RHV02PX:0809RHV00`09bLW02HV9P0X:2P0:2PX02LW9`0V9RH0:2PX02LW9`0X:2P09bLW02TY
:@0X:2P302LW9`0302PX:00W9bL0:2PX0080:2PX00D09bLW02TY:@0Y:BT0:BTY02LW9`0202PX:003
02LW9`0X:2P09RHV00<09bLW00@09BDU02LW9`0V9RH09RHV0P0W9bL302HV9P0302DU9@0V9RH09BDU
00D09BDU00D092@T02DU9@0S8b<08b<S02DU9@0302@T9007028R8P0S8b<08b<S02<S8`0R8R808b<S
028R8P0202<S8`808R8R00<0820P024Q8@0P82000P0P8204024Q8@03020P800Q8B407alO00<07alO
00<08B4Q01lO7`0O7al00P0P82001P0O7al07QhN01lO7`0P82007QhN01dM7@D07QhN0P0M7Ad0100N
7Qh07AdM01hN7P0M7Ad201`L700301dM7@0L71`07AdM00807AdM0P0L71`00`0M7Ad071`L01dM7@02
01/K6`0601dM7@0J6QX06QXJ01`L700K6a/071`L0P0K6a/0100J6QX06a/K01/K6`0K6a/201XJ6P07
01TI6@0J6QX071`L01/K6`0I6AT06QXJ01/K6`0401XJ6P806a/K0P0J6QX201TI6@0401XJ6P0I6AT0
6a/K01TI6@806QXJ00<06ATI01XJ6P0J6QX00P0J6QX01`0K6a/06QXJ01TI6@0J6QX06a/K01TI6@0J
6QX00P0I6AT301XJ6PH0fMWI0@0000010=WIf@0000D0fMWI0000003IfMT0fMWI000000020=WIf@04
0000003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT000001@3IfMT00`000000fMWI0=WIf@03
0=WIf@806QXJ00@06ATI01XJ6P0J6QX06a/K0P0J6QX01@0K6a/06ATI01XJ6P0J6QX06a/K00<06ATI
00H06QXJ01/K6`0I6AT06QXJ01/K6`0J6QX201`L700401TI6@0K6a/06a/K01/K6`<06QXJ00<071`L
01/K6`0K6a/00`0K6a/00`0L71`06a/K01/K6`0201`L70<06a/K0`0L71`00`0K6a/071`L01`L7004
01dM7@0301lO7`0M7Ad07AdM00<071`L0P0M7Ad00`0L71`07QhN01hN7P0401hN7P@07AdM00D07QhN
01`L700N7Qh07QhN01lO7`0201hN7P0401dM7@0O7al07alO01hN7P<07alO0P0N7Qh201lO7`<0820P
00H07alO024Q8@0P8200820P028R8P0P8205024Q8@@08R8R00@0820P028R8P0R8R808R8R0`0S8b<3
02@T900302<S8`0T92@092@T008092@T00H09bLW02DU9@0T92@09RHV02DU9@0T92@202DU9@809RHV
0P0U9BD0100W9bL09RHV02LW9`0V9RH602LW9`809RHV0`0W9bL00`0V9RH0:2PX02PX:00302PX:0<0
9bLW0P0X:2P00`0Y:BT0:2PX02DU9@0202LW9`0702HV9P0W9bL09RHV02HV9P0W9bL0:2PX02DU9@02
02HV9P809BDU0`0V9RH01P0U9BD09RHV02DU9@0U9BD092@T02DU9@<092@T00T08b<S02@T900U9BD0
8b<S02@T900S8b<08R8R02<S8`0T92@00P0S8b<0100Q8B408R8R024Q8@0Q8B42028R8P<08B4Q1@0P
8200100Q8B40820P024Q8@0O7al3020P800301hN7P0O7al07QhN00<07alO00X07QhN01dM7@0O7al0
7QhN01dM7@0O7al07AdM01hN7P0M7Ad071`L0P0N7Qh301dM7@0801hN7P0L71`071`L01dM7@0L71`0
6a/K01`L700K6a/601`L700301dM7@0K6a/06QXJ00<071`L00<06a/K01XJ6P0K6a/00P0K6a/00`0L
71`06QXJ01XJ6P0301XJ6P0301/K6`0J6QX06QXJ00D06QXJ0`0I6AT01`0J6QX06ATI01XJ6P0K6a/0
61PH01TI6@0K6a/00`0J6QX01@0I6AT06QXJ01TI6@0I6AT06QXJ00<06ATI00D061PH01XJ6P0I6AT0
61PH01/K6`0201TI6@0301XJ6P0I6AT06ATI00H0fMWI0@0000010=WIf@000P3IfMT2000000@0fMWI
0P0000040=WIf@8000001P3IfMT00`000000fMWI0=WIf@030=WIf@0301XJ6P0I6AT06QXJ00<06QXJ
0P0K6a/01P0I6AT06QXJ01XJ6P0K6a/06QXJ01/K6`806QXJ0P0K6a/0100J6QX06ATI01XJ6P0I6AT2
01XJ6P0301/K6`0J6QX06ATI00H06QXJ100K6a/201`L700401dM7@0J6QX06QXJ01/K6`T071`L00<0
7AdM01hN7P0O7al00`0M7Ad01P0L71`07AdM01`L700N7Qh07AdM01hN7P<07AdM00@07QhN01dM7@0N
7Qh07AdM0P0N7Qh0100M7Ad07alO01dM7@0N7Qh201lO7`08020P800N7Qh07QhN01hN7P0P82007QhN
01lO7`0N7Qh401lO7`<0820P00<07alO020P800Q8B400P0Q8B42020P8006024Q8@0P82008B4Q024Q
8@0R8R808B4Q0P0R8R800`0Q8B408b<S024Q8@02028R8P808b<S00@08R8R02<S8`0T92@08b<S0P0T
92@01P0S8b<092@T02DU9@0T92@09RHV02<S8`809BDU00<09RHV02@T900U9BD00P0U9BD402HV9P03
02DU9@0V9RH09RHV00@09RHV0P0W9bL202HV9P809bLW00@09RHV02LW9`0W9bL09bLW0P0X:2P00`0U
9BD0:2PX02PX:00202PX:0809bLW00T09RHV02DU9@0V9RH09RHV02DU9@0V9RH09bLW02HV9P0W9bL0
0P0V9RH0100U9BD09RHV02LW9`0V9RH302DU9@0402@T900U9BD092@T02DU9@<092@T00@09BDU02@T
900U9BD08b<S0`0T92@00`0R8R808b<S02<S8`0302<S8`808B4Q0P0R8R82024Q8@808R8R1P0Q8B43
020P8004024Q8@0P82007alO01lO7`<0820P00@07QhN01lO7`0O7al07alO0P0N7Qh02@0M7Ad07QhN
01lO7`0M7Ad07QhN01dM7@0N7Qh071`L01hN7P0201dM7@0501hN7P0L71`071`L01/K6`0M7Ad00P0L
71`01@0K6a/071`L01/K6`0L71`06a/K008071`L00D07QhN01XJ6P0L71`06QXJ01`L700201/K6`03
01`L700J6QX06a/K00@06QXJ00D06ATI01/K6`0K6a/06QXJ01/K6`0201XJ6P0401TI6@0J6QX06a/K
01TI6@806QXJ00<06ATI01/K6`0J6QX00P0I6AT201XJ6P0701TI6@0J6QX06QXJ01PH600I6AT06a/K
01XJ6P0201TI6@0301XJ6P0I6AT06QXJ00806QXJ00@06a/K01XJ6P0I6AT06QXJ0`0I6AT00`0H61P0
fMWI0=WIf@040=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT00`0K6a/06ATI
01XJ6P0201/K6`0401TI6@0J6QX06a/K01TI6@806a/K00H06QXJ01`L700J6QX06QXJ01/K6`0J6QX3
01/K6`0301XJ6P0I6AT06QXJ00@06a/K00<06QXJ01/K6`0K6a/00P0L71`00`0K6a/071`L01/K6`02
01/K6`0301`L700J6QX06a/K008071`L0P0K6a/301`L700801dM7@0L71`071`L01dM7@0L71`07QhN
01lO7`0N7Qh201`L700701dM7@0L71`07AdM01dM7@0L71`07AdM01`L700501dM7@D07QhN00<07alO
01hN7P0N7Qh0100O7al00`0M7Ad07QhN01lO7`0201lO7`80820P1P0O7al2020P80808B4Q0P0P8200
0`0R8R808B4Q024Q8@0201lO7`03024Q8@0R8R808B4Q00808B4Q0P0R8R801P0S8b<08R8R028R8P0S
8b<08R8R02@T90<08b<S00T09BDU02@T900U9BD092@T02<S8`0U9BD08R8R02@T900U9BD00P0T92@2
02DU9@0502HV9P0U9BD09RHV02HV9P0U9BD00`0V9RH00`0W9bL09BDU02HV9P0202LW9`809RHV0P0W
9bL00`0V9RH09BDU02HV9P0302HV9P809BDU00@09RHV02DU9@0W9bL0:2PX0P0V9RH202LW9`0702HV
9P0U9BD09BDU02DU9@0V9RH09bLW02HV9P0302DU9@809RHV0P0U9BD01@0T92@09BDU02DU9@0T92@0
9BDU00D092@T0P0S8b<01P0T92@08b<S028R8P0S8b<08R8R02@T90808B4Q00<08b<S028R8P0Q8B40
0P0Q8B42028R8P03024Q8@0P82008B4Q00808B4Q00<0820P024Q8@0P82000P0O7al00`0P82007alO
020P8002020P80807alO00@0820P01lO7`0O7al07alO100N7Qh201lO7`D07AdM00D071`L01dM7@0M
7Ad071`L01hN7P0201dM7@@071`L00@07AdM01`L700L71`07AdM0P0L71`01@0K6a/06QXJ01`L700L
71`06a/K008071`L00L06QXJ01/K6`0K6a/06a/K01XJ6P0I6AT06QXJ00<06a/K00D06QXJ01`L700K
6a/06QXJ01TI6@0301XJ6P0701/K6`0I6AT06a/K01XJ6P0H61P06QXJ01/K6`0301XJ6P0601TI6@0J
6QX06ATI01/K6`0J6QX06ATI0`0J6QX00`0K6a/06QXJ01TI6@0201XJ6P806ATI00H06QXJ01TI6@0J
6QX061PH01TI6@0J6QX60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT01@0J
6QX06ATI01/K6`0J6QX06a/K00806QXJ00@06a/K01XJ6P0J6QX06a/K1@0J6QX00`0L71`06a/K01/K
6`0201XJ6P806a/K0P0J6QX0100K6a/06QXJ01XJ6P0K6a/201XJ6P806a/K100L71`201/K6`8071`L
0P0K6a/00`0L71`07AdM01`L700201`L700301/K6`0L71`06a/K008071`L00D07AdM01lO7`0M7Ad0
7AdM01`L700201hN7P0601dM7@0L71`06a/K01dM7@0L71`07QhN100M7Ad01@0L71`07AdM01dM7@0M
7Ad07alO00807QhN0P0M7Ad03P0O7al0820P01hN7P0P82007alO01hN7P0O7al07QhN01lO7`0P8200
7alO01hN7P0P82007QhN0P0O7al3020P8003024Q8@0P8200820P00808B4Q0P0P82000`0O7al08B4Q
024Q8@02024Q8@808R8R00@08B4Q02<S8`0Q8B408b<S0P0R8R8202<S8`0302@T900R8R809BDU0080
92@T00L09BDU028R8P0S8b<09BDU02<S8`0T92@09RHV00<09BDU0P0T92@01P0U9BD092@T02DU9@0U
9BD09RHV02LW9`809RHV00<09bLW02DU9@0V9RH00`0U9BD00`0V9RH09bLW02HV9P0402HV9P0702DU
9@0V9RH09RHV02DU9@0V9RH0:2PX02@T900202HV9P0602@T900U9BD09RHV02HV9P0W9bL09RHV100U
9BD00`0T92@09RHV02DU9@0702@T90808b<S00H08B4Q02<S8`0S8b<08b<S02@T900S8b<3028R8P03
02<S8`0R8R808R8R00808R8R00L08B4Q02<S8`0R8R80820P024Q8@0R8R808B4Q0080820P00X07alO
020P800P82007QhN024Q8@0O7al0820P01hN7P0O7al0820P0P0O7al00`0P82007alO024Q8@0201lO
7`0301hN7P0M7Ad07AdM00807AdM00D07alO01hN7P0N7Qh07alO01hN7P0601dM7@0901`L700M7Ad0
7AdM01dM7@0K6a/07AdM01/K6`0M7Ad06a/K00@071`L00@07AdM01`L700K6a/06QXJ0P0K6a/0100L
71`06a/K01/K6`0K6a/301XJ6P0701/K6`0J6QX06QXJ01XJ6P0I6AT06QXJ01/K6`0201XJ6P0501/K
6`0J6QX06ATI01XJ6P0I6AT00P0J6QX201TI6@0301XJ6P0K6a/06QXJ00806QXJ00@06a/K01TI6@0K
6a/06ATI0P0J6QX201TI6@0801PH600I6AT061PH01XJ6P0K6a/06ATI01PH600J6QX201TI6@0301PH
600I6AT0fMWI00D0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0501XJ6P0I
6AT06QXJ01XJ6P0K6a/01P0J6QX01@0I6AT06QXJ01/K6`0J6QX06a/K00806QXJ00<06ATI01XJ6P0J
6QX00`0J6QX01P0L71`06a/K01XJ6P0K6a/06ATI01XJ6P806a/K00<071`L01dM7@0L71`00P0L71`4
01/K6`8071`L1@0K6a/401`L700301hN7P0M7Ad07QhN00@071`L00P07AdM01hN7P0M7Ad07AdM01`L
700K6a/07AdM01hN7P@07AdM00<07QhN01dM7@0M7Ad01`0N7Qh00`0O7al07QhN01hN7P0201lO7`05
01hN7P0P82007alO01hN7P0M7Ad00P0O7al01P0N7Qh0820P024Q8@0P82008B4Q020P80807alO00D0
820P024Q8@0P82008R8R020P8002024Q8@07020P800Q8B408b<S028R8P0S8b<08R8R024Q8@0302<S
8`808R8R00<092@T02<S8`0R8R800P0T92@00`0R8R808b<S02<S8`0402@T90809BDU0P0T92@402DU
9@<09RHV0P0U9BD01@0V9RH09BDU02@T900T92@09bLW00809RHV00<0:2PX02HV9P0V9RH00P0U9BD3
02HV9P0302LW9`0V9RH09BDU00809bLW00@09RHV02DU9@0U9BD092@T0`0U9BD01@0T92@09RHV02@T
900U9BD09RHV008092@T00P09BDU02@T900U9BD09BDU02@T900S8b<08R8R02DU9@8092@T00@08b<S
028R8P0S8b<08R8R0P0S8b<01@0Q8B408b<S028R8P0S8b<0820P00<08R8R0`0Q8B400`0P82008B4Q
024Q8@02020P8005024Q8@0P8200820P01lO7`0P82000P0Q8B400`0O7al0820P01lO7`0301lO7`<0
7QhN00<07alO01hN7P0N7Qh00`0N7Qh00`0O7al07QhN01dM7@0201dM7@0601`L700M7Ad07AdM01`L
700M7Ad071`L100M7Ad00`0L71`06a/K01`L700401/K6`8071`L00L07AdM01`L700K6a/06a/K01XJ
6P0K6a/06QXJ00@06a/K0`0J6QX401/K6`0901XJ6P0K6a/06ATI01XJ6P0K6a/061PH01TI6@0J6QX0
6ATI00<06QXJ00H06ATI01XJ6P0J6QX06QXJ01`L700I6AT301XJ6P0301/K6`0J6QX06a/K00@06QXJ
00P06a/K01XJ6P0J6QX06QXJ01/K6`0J6QX06ATI01PH60<06ATI1P3IfMT100000040fMWI000F0=WI
f@030000003IfMT0fMWI00<0fMWI00H06QXJ01/K6`0J6QX06a/K01TI6@0K6a/201XJ6P0401TI6@0J
6QX06ATI01/K6`806QXJ00@06a/K01XJ6P0J6QX06ATI100J6QX201/K6`806QXJ00P06ATI01`L700K
6a/06a/K01XJ6P0I6AT071`L01/K6`@071`L200K6a/701`L70807AdM00<071`L01dM7@0M7Ad01`0L
71`201hN7P0401dM7@0L71`07AdM01`L70807QhN00<07AdM01hN7P0N7Qh00P0N7Qh01P0M7Ad07alO
01lO7`0O7al0820P01hN7P<07alO00@0820P01lO7`0O7al07QhN0`0O7al00`0N7Qh07alO01lO7`03
020P80808B4Q00<07alO020P800Q8B400P0Q8B400`0P82008B4Q024Q8@05024Q8@H08R8R0`0S8b<0
1P0T92@08b<S02<S8`0T92@08R8R02<S8`8092@T00H09BDU02@T900U9BD092@T02HV9P0S8b<202@T
900502DU9@0T92@09RHV02DU9@0V9RH00P0T92@302DU9@809RHV00D09BDU02HV9P0V9RH092@T02HV
9P0202DU9@809RHV00T092@T02DU9@0V9RH09bLW02HV9P0U9BD092@T02DU9@0T92@00`0U9BD202@T
90809BDU00D092@T02<S8`0U9BD08b<S02@T900202<S8`<092@T00D08b<S02@T900T92@08b<S02@T
900202<S8`808R8R00<08B4Q028R8P0T92@00P0R8R83024Q8@03028R8P0P8200820P00<08B4Q00P0
820P01lO7`0Q8B40820P024Q8@0O7al07QhN020P80<07alO00H0820P01hN7P0P82007QhN01lO7`0M
7Ad601hN7P807AdM0P0N7Qh01P0O7al07QhN01dM7@0O7al07AdM01`L70807AdM00<071`L01dM7@0M
7Ad00P0L71`0100K6a/071`L01`L700L71`201/K6`@071`L00@06a/K01XJ6P0K6a/071`L1@0K6a/3
01XJ6PD06a/K00<06ATI01XJ6P0J6QX00`0J6QX0100K6a/06QXJ01XJ6P0L71`201XJ6P0301/K6`0J
6QX06QXJ00806QXJ00@06a/K01TI6@0J6QX06a/K0`0I6AT201XJ6P0301TI6@0J6QX06ATI00806ATI
00<061PH01XJ6P0I6AT00`0I6AT60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3I
fMT01`0J6QX06ATI01TI6@0I6AT06a/K01XJ6P0I6AT00P0K6a/201XJ6P0401/K6`0I6AT06a/K01/K
6`806QXJ00D06a/K01XJ6P0I6AT06QXJ01/K6`0301XJ6P0601/K6`0I6AT06a/K01XJ6P0L71`07AdM
0`0K6a/00`0L71`06a/K01`L700301/K6`0401XJ6P0K6a/071`L01`L70<06a/K1P0L71`00`0M7Ad0
7QhN01`L700201dM7@0901`L700M7Ad07QhN01`L700M7Ad07QhN01`L700M7Ad071`L00D07AdM00L0
7QhN01dM7@0N7Qh07AdM01hN7P0O7al07AdM00807alO00@07QhN01lO7`0O7al0820P0P0O7al0200P
82007alO01lO7`0O7al07QhN01lO7`0N7Qh0820P0`0O7al0200N7Qh0820P020P800P82008B4Q028R
8P0O7al08B4Q0P0P8202024Q8@03028R8P0S8b<08R8R00808R8R00H08b<S028R8P0R8R808R8R02<S
8`0R8R8302<S8`0302@T900S8b<092@T00808b<S00L092@T02<S8`0T92@09BDU02@T900S8b<09BDU
008092@T00D09BDU02HV9P0S8b<09BDU02HV9P0202DU9@0302@T900U9BD09BDU00809BDU00D092@T
02DU9@0V9RH09BDU02HV9P0202DU9@<092@T00X09RHV02@T900V9RH09bLW02@T900U9BD092@T02DU
9@0T92@09BDU0P0T92@00`0V9RH092@T02@T900202@T900302<S8`0T92@08b<S008092@T0`0S8b<0
1P0T92@08b<S02<S8`0S8b<08R8R02<S8`808R8R00<08b<S024Q8@0T92@0100R8R802@0Q8B408R8R
024Q8@0Q8B40820P024Q8@0P82008R8R02<S8`02024Q8@80820P00D07alO020P800Q8B40820P01lO
7`03020P800301lO7`0N7Qh07QhN00807alO00<07QhN01lO7`0N7Qh01`0N7Qh201dM7@0301hN7P0L
71`071`L00807AdM00/06QXJ01dM7@0L71`071`L01dM7@0L71`07AdM01`L700K6a/071`L01dM7@03
01/K6`0401`L700J6QX06a/K01`L70806QXJ00X071`L01XJ6P0K6a/06QXJ01`L700K6a/06QXJ01/K
6`0J6QX06a/K0P0J6QX0100K6a/071`L01XJ6P0I6AT201XJ6P0601TI6@0K6a/06QXJ01XJ6P0I6AT0
6QXJ0`0I6AT01@0K6a/06ATI01XJ6P0I6AT06a/K00806QXJ0`0I6AT0100H61P06QXJ01TI6@0J6QX3
01TI6@806QXJ00<061PH01TI6@0I6AT00P0I6AT60=WIf@4000000@3IfMT001H0fMWI00<000000=WI
f@3IfMT00`3IfMT01@0J6QX06ATI01XJ6P0H61P06QXJ00806ATI100J6QX00`0K6a/06QXJ01XJ6P04
01XJ6P806a/K0P0J6QX00`0K6a/071`L01XJ6P0201XJ6P0501/K6`0L71`06a/K01XJ6P0K6a/01@0L
71`00`0J6QX071`L01/K6`0201/K6`8071`L00@06QXJ01/K6`0K6a/071`L0`0K6a/02P0L71`07AdM
01`L700L71`06a/K01dM7@0K6a/07AdM01`L700M7Ad301/K6`0401`L700M7Ad07AdM01hN7PX07AdM
0`0N7Qh0100M7Ad07QhN01lO7`0O7al201hN7P0501lO7`0N7Qh07QhN01hN7P0P82000P0O7al01@0Q
8B40820P020P800P82008B4Q0080820P00D07alO020P800P82008B4Q020P8003024Q8@03028R8P0Q
8B40820P00<08B4Q00D08R8R020P800Q8B4092@T02<S8`02028R8P0402<S8`0R8R808R8R02@T9080
8b<S0P0T92@00`0S8b<092@T02<S8`0202<S8`H092@T00P08b<S02HV9P0T92@09BDU02@T900S8b<0
9BDU02<S8`H09BDU00D09RHV02@T900U9BD092@T02HV9P0702@T900302DU9@0S8b<092@T008092@T
0P0U9BD202@T900302<S8`0U9BD08b<S008092@T100S8b<01P0R8R808b<S02@T900S8b<092@T02<S
8`808R8R00H08b<S028R8P0R8R808R8R02<S8`0R8R82024Q8@03028R8P0Q8B408B4Q00808B4Q00<0
8R8R024Q8@0P82000`0Q8B401@0O7al0820P01lO7`0O7al07QhN00807alO00@0820P01lO7`0N7Qh0
820P0`0O7al201hN7P0401lO7`0N7Qh07QhN01lO7`<07AdM00@07alO01dM7@0M7Ad07AdM0P0L71`0
0`0N7Qh07AdM01`L700201`L70807AdM0`0L71`201/K6`0401dM7@0K6a/071`L01/K6`8071`L0`0K
6a/00`0J6QX06a/K01`L700201XJ6P0701`L700I6AT06ATI01XJ6P0K6a/06QXJ01TI6@0301XJ6P03
01/K6`0J6QX06a/K00@06QXJ00<06ATI01XJ6P0J6QX00P0K6a/201XJ6P<06ATI0P0J6QX00`0K6a/0
6QXJ01XJ6P0201XJ6P0301TI6@0J6QX061PH00806ATI0P0J6QX501TI6@0301XJ6P3IfMT0fMWI00@0
fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@806QXJ00D06ATI01XJ6P0J6QX0
6ATI01XJ6P0201/K6`0301XJ6P0L71`06QXJ00806QXJ100K6a/00`0J6QX071`L01XJ6P0201XJ6P80
6a/K00<071`L01XJ6P0K6a/00P0K6a/201XJ6P806a/K0P0L71`401/K6`0501`L700K6a/06QXJ01/K
6`0J6QX00P0K6a/0100L71`06a/K01dM7@0L71`201/K6`8071`L00@07AdM01`L700M7Ad071`L0P0M
7Ad201`L700401dM7@0L71`071`L01`L70L07AdM00<071`L01dM7@0N7Qh0100N7Qh301lO7`0701hN
7P0O7al07QhN01lO7`0N7Qh07alO01hN7P0401lO7`<0820P0P0O7al4020P8004024Q8@0P8200820P
028R8P80820P00<07alO020P800Q8B400P0P8204024Q8@D08R8R0`0S8b<0100V9RH08B4Q028R8P0S
8b<2028R8P@08b<S00<092@T02DU9@0T92@00`0T92@0100U9BD09RHV02@T900U9BD302@T900602DU
9@0V9RH092@T02@T900U9BD092@T0P0U9BD202@T90<09BDU00@08b<S02DU9@0T92@09BDU0P0S8b<0
1@0U9BD092@T02<S8`0T92@09BDU008092@T00D09BDU02@T900R8R808R8R02@T900302<S8`07028R
8P0T92@08R8R02<S8`0R8R808B4Q02<S8`04028R8PD08B4Q00H08R8R020P800Q8B408R8R024Q8@0P
8202024Q8@0>01lO7`0P82007alO020P800Q8B40820P01lO7`0P82007QhN020P800O7al07QhN01lO
7`0N7Qh201lO7`0401hN7P0M7Ad07QhN01hN7P<07AdM00<07QhN01dM7@0M7Ad01P0M7Ad01`0L71`0
7AdM01dM7@0L71`07AdM01`L700M7Ad00`0L71`00`0K6a/071`L01dM7@0201`L700501dM7@0L71`0
6a/K01/K6`0L71`0100K6a/301XJ6P0901`L700J6QX071`L01`L700K6a/071`L01XJ6P0K6a/06QXJ
00806a/K0`0J6QX01@0I6AT06a/K01TI6@0I6AT061PH00<06QXJ00T06a/K01XJ6P0J6QX06a/K01TI
6@0J6QX06ATI01PH600I6AT00P0J6QX201TI6@<06QXJ00H06ATI01XJ6P0I6AT06ATI01PH600J6QX3
01TI6@H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0301XJ6P0I6AT06ATI
00<06QXJ00<061PH01XJ6P0J6QX00P0J6QX201/K6`0301`L700K6a/071`L008071`L00<06a/K01`L
700L71`00`0K6a/201`L700301/K6`0J6QX06QXJ00L06a/K00@06QXJ01/K6`0L71`071`L0`0K6a/0
1`0L71`06QXJ01XJ6P0K6a/06QXJ01`L700K6a/01@0L71`00`0K6a/071`L01`L700401`L700301dM
7@0L71`07QhN008071`L00@07AdM01`L700L71`07AdM0P0N7Qh0100L71`07AdM01dM7@0M7Ad501hN
7P0301dM7@0N7Qh07AdM00807alO00T0820P01lO7`0O7al07alO01hN7P0O7al0820P01hN7P0Q8B40
100O7al00`0P82007alO024Q8@07020P8004024Q8@0R8R808B4Q028R8P808B4Q00<08b<S024Q8@0Q
8B400P0Q8B4202<S8`05024Q8@0R8R808b<S02<S8`0R8R800P0S8b<01P0T92@08R8R02@T900S8b<0
92@T02<S8`D092@T0P0S8b<502@T900402DU9@0T92@08b<S02@T90809BDU00D08R8R02DU9@0U9BD0
92@T02DU9@0302@T900302<S8`0T92@08b<S00<09BDU0`0T92@302<S8`@092@T00P08b<S02@T900S
8b<08b<S02DU9@0S8b<092@T02<S8`<08R8R00D08b<S028R8P0R8R808R8R02<S8`04028R8P03020P
800Q8B408B4Q0080820P00T08B4Q028R8P0P82008B4Q020P800Q8B407alO020P800Q8B400P0P8200
100O7al0820P01lO7`0P820401lO7`0501hN7P0O7al07alO01hN7P0P82000`0N7Qh01@0O7al07QhN
01hN7P0M7Ad071`L00<07AdM00<071`L01dM7@0M7Ad00`0L71`00`0M7Ad06a/K01`L700201dM7@05
01TI6@0L71`071`L01/K6`0L71`00P0K6a/00`0M7Ad06a/K01`L700201XJ6P0601/K6`0J6QX06a/K
01/K6`0J6QX06a/K0P0J6QX0100K6a/06QXJ01`L700K6a/201XJ6P0301TI6@0J6QX06a/K00<06QXJ
00P06a/K01TI6@0J6QX06QXJ01TI6@0K6a/06ATI01XJ6P806ATI100J6QX201/K6`806QXJ00H061PH
01XJ6P0I6AT06QXJ01TI6@0H61P401TI6@806QXJ0`0I6AT60=WIf@4000000@3IfMT001H0fMWI0P00
00040=WIf@0501XJ6P0I6AT06QXJ01XJ6P0K6a/00P0I6AT201XJ6P0601/K6`0J6QX06a/K01`L700K
6a/07QhN0`0M7Ad01P0K6a/071`L01`L700K6a/06QXJ01/K6`806QXJ00H06a/K01XJ6P0J6QX06QXJ
01/K6`0L71`401/K6`0301XJ6P0L71`06a/K00D06a/K00D07AdM01/K6`0K6a/06a/K01dM7@0201/K
6`0501`L700M7Ad071`L01dM7@0L71`00P0K6a/401`L70807AdM00@071`L01hN7P0L71`071`L0P0M
7Ad201`L700401hN7P0M7Ad07AdM01`L70807AdM00@07alO01hN7P0N7Qh07AdM0P0N7Qh201dM7@03
01lO7`0N7Qh07alO00H07alO00<07QhN01lO7`0O7al00P0O7al2020P80<07alO00<08B4Q01lO7`0Q
8B400P0Q8B401@0O7al08B4Q024Q8@0Q8B40820P00808B4Q00<07alO028R8P0Q8B400`0Q8B4402<S
8`05028R8P0S8b<08b<S02<S8`0R8R800P0S8b<302@T90<08b<S00<092@T02DU9@0T92@00`0S8b<0
0`0T92@09BDU02@T900202@T900502<S8`0T92@08b<S02DU9@0T92@00P0S8b<202@T900302DU9@0S
8b<08b<S008092@T0`0R8R8302<S8`0802@T900S8b<09BDU028R8P0T92@08R8R02@T900S8b<2028R
8P0302<S8`0R8R808R8R00808b<S0`0R8R80100Q8B408R8R02<S8`0R8R83024Q8@07028R8P0P8200
8B4Q02<S8`0R8R808B4Q020P8002024Q8@80820P00<07QhN024Q8@0P82000P0O7al2020P800601hN
7P0P82007alO01lO7`0N7Qh0820P1@0N7Qh01@0M7Ad07QhN01hN7P0N7Qh07AdM00<07QhN0P0M7Ad0
1@0L71`07AdM01`L700L71`07AdM008071`L00@07QhN01/K6`0M7Ad06a/K0`0L71`401/K6`0601`L
700K6a/071`L01`L700K6a/071`L100K6a/00`0J6QX06a/K01/K6`0201XJ6P<06a/K00<06QXJ01/K
6`0L71`00P0K6a/0100I6AT06QXJ01/K6`0J6QX201TI6@0801/K6`0J6QX06ATI01TI6@0H61P06QXJ
01PH600I6AT201XJ6P<06ATI0P0J6QX201TI6@0301PH600I6AT06ATI00806ATI00L06QXJ01TI6@0I
6AT06ATI01PH600I6AT06QXJ00<06ATI1@3IfMT200000040fMWI000F0=WIf@030000003IfMT0fMWI
00<0fMWI00<06QXJ01TI6@0I6AT00P0K6a/501XJ6P8071`L00/07alO024Q8@0R8R8092@T02DU9@0S
8b<07QhN01dM7@0L71`06a/K01TI6@0201XJ6P0301`L700K6a/06QXJ00806a/K00<06QXJ01/K6`0K
6a/0100K6a/0100L71`06a/K01/K6`0L71`201/K6`8071`L1P0K6a/02@0L71`06a/K01dM7@0L71`0
6a/K01dM7@0K6a/071`L01dM7@0301`L700301dM7@0N7Qh071`L00807AdM0P0L71`01P0M7Ad071`L
01`L700K6a/07AdM01hN7PD07AdM00<07QhN01dM7@0M7Ad00P0N7Qh00`0O7al07AdM01hN7P0301lO
7`0901hN7P0O7al07alO01lO7`0P82008B4Q01lO7`0P82007alO0080820P0P0O7al0100P82007alO
020P800P8202024Q8@0301lO7`0P8200820P00<0820P00@08R8R024Q8@0Q8B40820P0P0Q8B401P0R
8R808b<S028R8P0R8R808B4Q02<S8`@08R8R00H092@T028R8P0R8R808R8R02<S8`0T92@502<S8`08
02@T900S8b<08b<S02@T900S8b<092@T02<S8`0T92@202<S8`8092@T00H08R8R02<S8`0S8b<08b<S
02@T900R8R8202<S8`8092@T00@08b<S02@T900T92@08b<S0P0U9BD0100T92@08R8R02<S8`0T92@3
02<S8`808R8R0P0S8b<2028R8P0602@T900R8R808R8R02<S8`0R8R808B4Q0P0R8R800`0Q8B40820P
020P8003024Q8@08028R8P0P82008B4Q020P800Q8B407alO020P800O7al2020P80807alO0P0P8200
1@0N7Qh07alO020P800P82007alO00807QhN00<07alO01hN7P0O7al00P0N7Qh03@0P82007QhN01hN
7P0N7Qh071`L01dM7@0L71`07QhN01dM7@0L71`07QhN01dM7@0L71`00P0M7Ad0100L71`07AdM01`L
700K6a/301`L700301/K6`0L71`06a/K00<071`L0P0K6a/201XJ6P806a/K00P071`L01/K6`0L71`0
6a/K01XJ6P0L71`06a/K01`L70<06QXJ00<06ATI01XJ6P0K6a/00P0K6a/201XJ6P0301TI6@0J6QX0
6QXJ00<06QXJ0P0I6AT0100K6a/06ATI01XJ6P0J6QX301TI6@0501/K6`0J6QX06ATI01XJ6P0K6a/0
0`0I6AT00`0K6a/06QXJ01XJ6P0301TI6@0401XJ6P0I6AT06ATI01/K6`@06ATI1P3IfMT100000040
fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0P0I6AT0100J6QX06ATI01XJ6P0K6a/301XJ6P0<
01/K6`0L71`07QhN01hN7P0U9BD0:2PX02d];@0/;2`09bLW020P800N7Qh071`L0`0K6a/0100J6QX0
6a/K01/K6`0J6QX201/K6`0501`L700K6a/06QXJ01TI6@0J6QX01@0K6a/01@0J6QX06a/K01/K6`0K
6a/06QXJ00<06a/K00<071`L01/K6`0L71`0100K6a/00`0L71`06a/K01/K6`0301`L700301dM7@0L
71`06a/K00H07AdM00H07QhN01dM7@0M7Ad071`L01hN7P0L71`301dM7@0301hN7P0M7Ad07QhN00<0
7QhN00H071`L01hN7P0N7Qh07AdM01hN7P0O7al201hN7P0501lO7`0P82007alO01hN7P0O7al00P0P
82002@0Q8B40820P01lO7`0O7al0820P024Q8@0P82007QhN024Q8@02020P800601hN7P0P82008B4Q
01lO7`0P82008B4Q0`0R8R800`0P82008R8R028R8P03028R8P808b<S0`0R8R8302<S8`808R8R00H0
92@T02<S8`0S8b<08R8R02<S8`0T92@202<S8`03028R8P0T92@08B4Q00H08b<S00D09BDU02@T900S
8b<09BDU02@T900302<S8`04028R8P0S8b<08b<S02@T90808b<S00T092@T02<S8`0S8b<08b<S028R
8P0S8b<092@T02<S8`0R8R800P0S8b<00`0T92@08b<S028R8P03028R8P808b<S100R8R801`0S8b<0
8B4Q028R8P0P82008B4Q028R8P0Q8B40100P8202024Q8@07020P800O7al07alO020P800O7al0820P
01lO7`02020P800301lO7`0N7Qh07QhN00807QhN00<07AdM020P800O7al00`0O7al201hN7P0501dM
7@0N7Qh07QhN01`L700M7Ad00P0N7Qh00`0L71`07AdM01`L700201`L700501dM7@0L71`07AdM01`L
700M7Ad0100L71`201/K6`0801`L700J6QX06a/K01dM7@0L71`06a/K01XJ6P0L71`201/K6`0401XJ
6P0L71`06QXJ01XJ6P@06a/K00P06QXJ01/K6`0I6AT06QXJ01PH600K6a/06ATI01XJ6P806a/K00D0
6ATI01XJ6P0K6a/06QXJ01TI6@0201XJ6P0401TI6@0J6QX06ATI01/K6`@06QXJ00D06a/K01TI6@0J
6QX06a/K01PH600601XJ6P0401TI6@0J6QX06ATI01TI6@806QXJ00@06ATI01XJ6P0K6a/06ATI0P0J
6QX60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT00`0I6AT06QXJ01PH6004
01XJ6P0@01/K6`0J6QX071`L01dM7@0O7al09BDU03@d=00m?Cd0C4a<04e=C@0k>c/09RHV02<S8`0L
71`06a/K01`L70806QXJ00H06a/K01XJ6P0J6QX06QXJ01TI6@0J6QX401/K6`0401XJ6P0K6a/06a/K
01/K6`8071`L00D06a/K01XJ6P0K6a/06QXJ01/K6`0201`L70@06a/K00<071`L01/K6`0K6a/00`0L
71`01P0K6a/071`L01/K6`0L71`07AdM01`L70806a/K00<071`L01dM7@0L71`00P0M7Ad01P0L71`0
6a/K01dM7@0M7Ad071`L01dM7@<071`L100N7Qh01P0M7Ad071`L01hN7P0N7Qh07AdM01lO7`807QhN
00H07alO01hN7P0M7Ad07AdM01lO7`0N7Qh201lO7`04020P800N7Qh08B4Q020P80807alO00<0820P
01hN7P0N7Qh00`0P8200100O7al08R8R01lO7`0P8202024Q8@03020P800Q8B408B4Q00808R8R00@0
8B4Q028R8P0R8R808B4Q1P0R8R80100S8b<08R8R024Q8@0Q8B4202<S8`06028R8P0T92@08b<S02<S
8`0R8R808b<S0P0R8R8202<S8`<092@T00<08b<S02@T900S8b<00P0S8b<2028R8P0602<S8`0T92@0
8b<S02<S8`0Q8B408b<S0`0R8R80100S8b<092@T028R8P0R8R8202<S8`<08R8R0`0S8b<00`0R8R80
8B4Q028R8P02028R8P0402<S8`0Q8B408R8R028R8P<08B4Q00<08R8R024Q8@0O7al00P0P82001P0O
7al0820P020P800P82007alO024Q8@80820P00H07alO020P800N7Qh07alO020P800N7Qh301lO7`03
01hN7P0O7al07alO00<07QhN00<07alO01hN7P0N7Qh00P0M7Ad00`0N7Qh07AdM01hN7P0201hN7P<0
7AdM00P06a/K01`L700M7Ad07QhN01dM7@0L71`06a/K01dM7@@06a/K100L71`0100M7Ad06a/K01`L
700I6AT201/K6`0301`L700K6a/06a/K00806a/K00H06QXJ01/K6`0J6QX06QXJ01`L700J6QX301/K
6`806QXJ00<06ATI01XJ6P0J6QX00P0K6a/00`0J6QX06ATI01XJ6P0601XJ6P0301TI6@0K6a/06ATI
00806ATI0P0J6QX0100K6a/06ATI01XJ6P0J6QX401TI6@<06QXJ100I6AT201PH600501TI6@0J6QX0
6ATI01XJ6P0I6AT01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0P0J6QX2
01TI6@0B01/K6`0J6QX06a/K01/K6`0L71`06a/K01lO7`0R8R80;2`/0410@01ADE40IfMW06IVIP17
AdL0:BTY02<S8`0N7Qh071`L1@0K6a/01`0J6QX06a/K01XJ6P0I6AT06QXJ01`L700K6a/00P0J6QX2
01/K6`0301`L700K6a/06QXJ00@06a/K0P0L71`00`0K6a/071`L01/K6`0201`L700301/K6`0L71`0
71`L008071`L00D07AdM01`L700M7Ad071`L01dM7@0301`L700601/K6`0L71`071`L01dM7@0L71`0
7QhN0P0M7Ad00`0L71`07AdM01hN7P0301dM7@0401`L700N7Qh071`L01hN7P807alO1@0M7Ad00`0N
7Qh07alO01lO7`0601lO7`05024Q8@0P8200820P020P800O7al00P0P820301lO7`80820P00<08B4Q
020P800P82000`0Q8B400`0O7al0820P024Q8@02024Q8@06028R8P0P82008R8R024Q8@0R8R808B4Q
0`0R8R801@0Q8B408b<S028R8P0R8R8092@T00808R8R00T08B4Q028R8P0S8b<08B4Q02<S8`0R8R80
92@T02<S8`0R8R801@0S8b<01P0R8R808b<S02<S8`0S8b<08R8R02@T90808R8R00@08B4Q028R8P0T
92@08B4Q0P0S8b<00`0Q8B408b<S028R8P0202<S8`808R8R0P0S8b<2024Q8@@08R8R00D08B4Q02<S
8`0S8b<08R8R024Q8@02028R8P@08B4Q100P82001P0R8R808B4Q024Q8@0Q8B40820P01lO7`808B4Q
00<0820P01lO7`0P82002@0O7al901hN7P0401lO7`0N7Qh07AdM01`L70807QhN00<07AdM01`L700M
7Ad00P0L71`0100M7Ad06a/K01`L700N7Qh201`L700501/K6`0M7Ad07AdM01`L700K6a/00`0L71`3
01/K6`0301`L700K6a/071`L00806a/K00<071`L01/K6`0J6QX00P0K6a/0100I6AT06QXJ01TI6@0J
6QX201/K6`0501`L700K6a/06QXJ01TI6@0K6a/00P0J6QX01`0K6a/071`L01XJ6P0J6QX06ATI01XJ
6P0I6AT00P0J6QX01`0H61P06QXJ01TI6@0J6QX06a/K01TI6@0L71`00P0J6QX02`0I6AT061PH01XJ
6P0I6AT06QXJ01/K6`0J6QX06ATI01PH600I6AT06QXJ00806ATI0P0H61P01@0I6AT061PH01PH600J
6QX06ATI00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0301XJ6P0I6AT0
6ATI00<06QXJ00l06ATI01XJ6P0J6QX071`L020P800U9BD0>CTi06ATI01nOWh0Vi^K096AT@1GEeL0
;2`/02@T900M7Ad00P0K6a/00`0J6QX06a/K01/K6`0401/K6`806QXJ0`0K6a/301XJ6PL06a/K00@0
71`L01/K6`0K6a/06a/K0P0L71`02`0K6a/071`L01dM7@0K6a/07AdM01`L700M7Ad06a/K01`L700M
7Ad071`L00806a/K00<071`L01hN7P0K6a/00P0M7Ad501`L70807AdM00L07QhN01dM7@0M7Ad07QhN
01dM7@0N7Qh07AdM00<07QhN00@07alO01dM7@0N7Qh07QhN0P0O7al0100M7Ad07QhN01lO7`0N7Qh4
01lO7`0301hN7P0O7al0820P0080820P00<07alO020P800O7al00P0O7al5024Q8@03020P800O7al0
820P00<08B4Q00H08R8R020P800Q8B40820P024Q8@0R8R84024Q8@0902<S8`0R8R808b<S024Q8@0S
8b<08R8R02<S8`0R8R808b<S00808R8R00H08b<S028R8P0R8R808R8R02<S8`0T92@2028R8P0802<S
8`0R8R808R8R020P800S8b<08R8R024Q8@0T92@2028R8P0402<S8`0R8R808R8R024Q8@@08R8R0P0S
8b<00`0R8R808b<S028R8P0202<S8`05028R8P0S8b<08B4Q020P800Q8B401@0R8R801P0Q8B408b<S
024Q8@0Q8B40820P024Q8@80820P00<07alO020P800Q8B400P0Q8B401P0P82008B4Q020P800Q8B40
7alO020P80L07alO00H07QhN020P800O7al07QhN01lO7`0N7Qh201lO7`0501dM7@0N7Qh07QhN01hN
7P0M7Ad00`0N7Qh501dM7@0401`L700O7al07QhN01dM7@@071`L00<07AdM01`L700L71`01P0L71`2
01/K6`0301XJ6P0L71`06a/K00806a/K0`0L71`0100K6a/06QXJ01XJ6P0J6QX401/K6`@06QXJ00<0
71`L01/K6`0J6QX01@0J6QX01P0K6a/06QXJ01XJ6P0J6QX06ATI01XJ6P806ATI00<061PH01TI6@0J
6QX00P0J6QX01@0K6a/06ATI01XJ6P0H61P06QXJ00806ATI00D06QXJ01TI6@0J6QX06QXJ01TI6@02
01XJ6P806ATI00H061PH01TI6@0J6QX06ATI01PH600J6QX60=WIf@4000000@3IfMT001H0fMWI00<0
00000=WIf@3IfMT00`3IfMT00`0J6QX06ATI01TI6@0201TI6@806QXJ00d06a/K01dM7@0L71`08R8R
02HV9P10@400MGEe09FEU@2SXj<0RHV904A4A00V9RH08R8R008071`L00<06a/K01XJ6P0K6a/00`0K
6a/301XJ6PD06a/K00H06QXJ01/K6`0K6a/06QXJ01/K6`0J6QX201/K6`0301XJ6P0K6a/06a/K0080
6a/K00D06QXJ01`L700K6a/06a/K01`L700501/K6`0301dM7@0K6a/071`L00<071`L00L07AdM01`L
700K6a/071`L01dM7@0L71`06a/K00807AdM00<07QhN01dM7@0M7Ad00P0M7Ad401hN7P0301dM7@0K
6a/07QhN00<07QhN0`0O7al0100N7Qh07AdM01hN7P0N7Qh301lO7`04020P800O7al07alO01hN7P80
7alO00D0820P01lO7`0O7al07QhN01lO7`02024Q8@0302LW9`0P8200820P00<0820P00<08B4Q020P
800P82000P0Q8B401P0O7al08R8R024Q8@0R8R808B4Q020P80808R8R0P0S8b<00`0T92@08R8R02<S
8`02028R8P05024Q8@0R8R808B4Q028R8P0S8b<00P0R8R800`0S8b<08B4Q028R8P02024Q8@03028R
8P0S8b<08R8R00808R8R00@08B4Q02<S8`0S8b<08b<S0P0R8R801@0Q8B408R8R028R8P0Q8B408b<S
00808R8R0P0Q8B42028R8P03024Q8@0R8R808b<S00<08R8R0`0Q8B400`0R8R807alO024Q8@06024Q
8@07020P800R8R808B4Q024Q8@0O7al0820P01lO7`02020P800601lO7`0P8200820P020P800O7al0
820P0P0O7al0100P82007alO01lO7`0M7Ad201hN7P04020P800N7Qh07alO01hN7P807AdM0P0N7Qh0
0`0M7Ad071`L01hN7P0201dM7@<07QhN0`0M7Ad00`0N7Qh07AdM01dM7@0201`L700301/K6`0M7Ad0
7AdM00<071`L00@07AdM01/K6`0L71`06a/K0P0L71`01P0K6a/06QXJ01/K6`0L71`06a/K01XJ6P<0
6a/K0P0J6QX01@0I6AT06a/K01/K6`0J6QX06ATI00@06QXJ0`0K6a/401XJ6P<06ATI1@0J6QX00`0I
6AT06QXJ01TI6@0501XJ6P0501/K6`0I6AT06ATI01XJ6P0I6AT0100J6QX00`0K6a/06ATI01PH6003
01TI6@0701PH600J6QX06QXJ01XJ6P0I6AT06QXJ01PH60060=WIf@4000000@3IfMT001H0fMWI00<0
00000=WIf@3IfMT00`3IfMT201XJ6P0A01TI6@0J6QX06a/K01/K6`0J6QX06a/K01`L700N7Qh08b<S
02LW9`0o?cl0KFe]08^;R`2:RXX0Kfm_03Ti>@0T92@00P0N7Qh01@0K6a/06QXJ01`L700K6a/06QXJ
00806a/K0`0J6QX201/K6`0<01XJ6P0K6a/06QXJ01/K6`0J6QX06ATI01/K6`0L71`06QXJ01/K6`0L
71`06QXJ0`0K6a/201`L70806a/K00@071`L01/K6`0L71`06a/K0P0L71`00`0K6a/071`L01`L7002
01dM7@0301`L700M7Ad071`L008071`L00D06a/K01`L700L71`07AdM01`L700201dM7@0301/K6`0M
7Ad07AdM00807AdM00D07QhN01dM7@0M7Ad07QhN01dM7@0401hN7P<07alO00X07QhN01lO7`0O7al0
7alO01hN7P0Q8B407alO01hN7P0O7al07QhN0`0O7al0100P82007alO01lO7`0M7Ad2020P8008024Q
8@0R8R808B4Q020P800O7al0820P028R8P0P8202024Q8@0?020P800Q8B408R8R028R8P0P82008B4Q
020P800Q8B408R8R024Q8@0P82008B4Q028R8P0Q8B408R8R00808B4Q00H0820P028R8P0R8R808R8R
024Q8@0S8b<5024Q8@<08b<S00<08R8R020P800Q8B400P0R8R82024Q8@05028R8P0Q8B408R8R028R
8P0S8b<00P0R8R800`0S8b<08R8R024Q8@02028R8P<08B4Q0`0R8R87024Q8@80820P00P08R8R024Q
8@0P8200820P024Q8@0R8R80820P024Q8@80820P00<08B4Q01hN7P0P82000P0Q8B400`0O7al0820P
01lO7`0201lO7`807QhN00D0820P01hN7P0N7Qh0820P01lO7`0201hN7P0401lO7`0M7Ad07alO01hN
7P807AdM00H07QhN01dM7@0N7Qh07QhN01dM7@0N7Qh301dM7@0401`L700N7Qh07AdM01dM7@L071`L
00<07AdM01hN7P0L71`0100L71`201/K6`0801XJ6P0K6a/071`L01XJ6P0K6a/06QXJ01/K6`0L71`2
01/K6`0301`L700J6QX06a/K00<06QXJ00D06a/K01TI6@0J6QX06a/K01`L700301/K6`0301XJ6P0K
6a/06QXJ00<06QXJ100K6a/201XJ6P806ATI00D061PH01XJ6P0J6QX06QXJ01TI6@0301XJ6P0401TI
6@0J6QX06QXJ01TI6@@06QXJ00D06ATI01PH600J6QX06QXJ01TI6@0201XJ6P0301PH600I6AT06ATI
00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@@06ATI01406QXJ01/K6`0K
6a/06QXJ01/K6`0L71`0820P02@T900f=SH0C4a<05EEE@1<C4`0?Shn02PX:00P82007QhN01`L7002
01XJ6P806a/K00<06QXJ01/K6`0K6a/0100J6QX00`0K6a/06QXJ01`L700201XJ6P0401/K6`0J6QX0
71`L01TI6@806a/K00L071`L01/K6`0K6a/06a/K01XJ6P0K6a/06QXJ00@06a/K00<071`L01/K6`0M
7Ad00`0K6a/201`L700301dM7@0L71`07QhN00@071`L00P06a/K01`L700M7Ad071`L01/K6`0M7Ad0
71`L01dM7@<07QhN00@07alO01dM7@0M7Ad07QhN1@0M7Ad00`0N7Qh07AdM01hN7P0201hN7P0701dM
7@0O7al07alO01dM7@0N7Qh07alO01hN7P0201lO7`0301hN7P0P82007QhN00807QhN00D0820P01lO
7`0P8200820P01hN7P0601lO7`80820P0`0Q8B401P0P82008R8R028R8P0Q8B408R8R020P80808R8R
00@08b<S024Q8@0R8R808R8R0P0Q8B400`0P82008B4Q024Q8@06028R8P03024Q8@0R8R808R8R0080
8R8R00D08B4Q028R8P0S8b<0820P024Q8@03028R8P0302<S8`0R8R808R8R00D08R8R00H08B4Q028R
8P0R8R808B4Q028R8P0Q8B43028R8P05024Q8@0P82008B4Q024Q8@0R8R800P0Q8B400`0P82008B4Q
01lO7`03024Q8@<0820P00<08B4Q020P800Q8B400P0P82000`0O7al07QhN020P800201lO7`0901hN
7P0P8200820P020P800M7Ad07alO020P800N7Qh07AdM00807QhN00@07alO01dM7@0M7Ad07QhN0`0O
7al01P0M7Ad07QhN01dM7@0N7Qh07AdM01`L70807QhN0P0M7Ad01P0L71`07AdM01dM7@0L71`07AdM
01`L70D07AdM00H06a/K01`L700L71`071`L01dM7@0L71`201/K6`0501`L700K6a/06QXJ01/K6`0L
71`0100K6a/00`0J6QX06a/K01XJ6P0201/K6`0401TI6@0K6a/06QXJ01/K6`806QXJ00D06ATI01XJ
6P0I6AT06QXJ01/K6`0401XJ6P0401TI6@0J6QX06QXJ01XJ6P<06ATI00X061PH01TI6@0I6AT06ATI
01XJ6P0I6AT06QXJ01TI6@0J6QX061PH100J6QX01P0K6a/06ATI01XJ6P0I6AT061PH01TI6@806QXJ
0P0I6AT0100K6a/06QXJ01TI6@0H61P60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT0
0`3IfMT301XJ6P0401/K6`0I6AT06QXJ01XJ6P806a/K00X071`L01hN7P0Q8B40:BTY02l_;`0`<300
:b/[02PX:00Q8B407AdM0P0L71`01@0K6a/06QXJ01XJ6P0J6QX06a/K00L06QXJ00L06a/K01XJ6P0J
6QX06a/K01XJ6P0K6a/06QXJ00@06a/K00/071`L01/K6`0K6a/06a/K01XJ6P0L71`06a/K01`L700K
6a/06QXJ01dM7@0201`L700301/K6`0L71`06a/K008071`L00T07AdM01`L700L71`071`L01dM7@0L
71`07AdM01`L700K6a/00`0L71`00`0K6a/07AdM01dM7@0201dM7@0301hN7P0M7Ad071`L00<07AdM
0`0N7Qh01@0M7Ad07QhN01hN7P0O7al07QhN00<07alO00@07AdM01hN7P0O7al07alO0`0N7Qh0100O
7al07QhN01lO7`0N7Qh201lO7`05024Q8@0P82007alO020P800O7al00`0P82001P0O7al0820P020P
800Q8B40820P024Q8@<0820P00H08B4Q020P800R8R808R8R024Q8@0R8R82020P80@08B4Q0P0R8R80
0`0P82008B4Q028R8P02024Q8@03028R8P0Q8B408b<S00<08B4Q00D08R8R024Q8@0Q8B40820P024Q
8@02028R8P09024Q8@0S8b<08B4Q024Q8@0S8b<0820P02<S8`0P82008b<S00<08B4Q00@0820P024Q
8@0Q8B408B4Q0`0R8R801`0S8b<08B4Q020P800P82008b<S028R8P0Q8B400P0P82002@0Q8B40820P
020P800P82008R8R01lO7`0P82007alO020P800301lO7`0:020P800O7al0820P024Q8@0P82007alO
020P800N7Qh07alO01hN7P807alO00H07QhN01dM7@0M7Ad07AdM01hN7P0M7Ad301lO7`0301dM7@0N
7Qh07AdM00807AdM0P0N7Qh01`0L71`07AdM01dM7@0M7Ad07QhN01`L700M7Ad00P0L71`01P0M7Ad0
71`L01`L700M7Ad071`L01/K6`8071`L00<06a/K01`L700L71`00P0K6a/00`0L71`06a/K01/K6`03
01/K6`<06QXJ0P0K6a/00`0J6QX06a/K01XJ6P0301XJ6P0601/K6`0J6QX06QXJ01XJ6P0K6a/06QXJ
0P0K6a/00`0I6AT06QXJ01XJ6P0201TI6@806QXJ0P0I6AT01@0K6a/06QXJ01TI6@0J6QX06a/K0080
6QXJ00<06ATI01XJ6P0J6QX00P0I6AT0100H61P06QXJ01TI6@0J6QX301TI6@0801XJ6P0I6AT06QXJ
01XJ6P0I6AT06QXJ01TI6@0J6QX201TI6@0301PH600J6QX06ATI00H0fMWI0@0000010=WIf@005P3I
fMT00`000000fMWI0=WIf@030=WIf@0401XJ6P0I6AT06QXJ01/K6`<06QXJ00d06a/K01XJ6P0K6a/0
7QhN01lO7`0S8b<09RHV02LW9`0S8b<08R8R020P800L71`07AdM00806a/K00@06QXJ01/K6`0J6QX0
6a/K0P0J6QX00`0I6AT06QXJ01XJ6P0301XJ6P@06a/K00D06QXJ01`L700J6QX06a/K01XJ6P0301/K
6`0301XJ6P0K6a/06QXJ00<06a/K00L071`L01dM7@0L71`06a/K01dM7@0L71`06a/K00<071`L00<0
7AdM01hN7P0L71`00P0M7Ad01@0L71`07AdM01/K6`0K6a/07QhN00<071`L0P0M7Ad00`0N7Qh07AdM
01dM7@0301dM7@<07QhN0P0M7Ad0100N7Qh07alO01hN7P0O7al401hN7P0401lO7`0N7Qh07alO01lO
7`<07QhN0P0O7al01@0N7Qh07alO01lO7`0O7al07QhN0080820P00H07QhN01lO7`0P82007QhN01lO
7`0Q8B4201lO7`07024Q8@0N7Qh0820P024Q8@0O7al08B4Q01lO7`04024Q8@04020P800Q8B408b<S
028R8P808B4Q00P08R8R024Q8@0R8R808B4Q020P800R8R808B4Q020P80H08B4Q00<08R8R024Q8@0Q
8B401P0Q8B400`0R8R80820P024Q8@02024Q8@05028R8P0S8b<08B4Q024Q8@0S8b<01@0Q8B40100P
82008B4Q024Q8@0P8206024Q8@@0820P0P0Q8B40100N7Qh08B4Q01lO7`0P820301lO7`04020P800Q
8B40820P01hN7P<07alO00L07QhN01lO7`0N7Qh07QhN01lO7`0N7Qh07AdM00D07QhN00T07AdM01hN
7P0M7Ad07QhN01dM7@0N7Qh06a/K01dM7@0L71`01P0M7Ad00`0L71`07QhN01`L700401`L700301XJ
6P0K6a/071`L008071`L0`0K6a/00`0L71`06a/K01`L700201dM7@<06a/K00<06ATI01XJ6P0K6a/0
0`0K6a/03@0J6QX06a/K01`L700I6AT06QXJ01`L700J6QX06a/K01XJ6P0K6a/06ATI01XJ6P0K6a/0
0`0J6QX00`0K6a/06ATI01/K6`0201TI6@0301XJ6P0I6AT06QXJ00806QXJ0`0I6AT01P0J6QX06ATI
01XJ6P0J6QX06ATI01XJ6P806ATI00@06a/K01XJ6P0J6QX06QXJ0P0I6AT0100J6QX06ATI01PH600H
61P201TI6@0401XJ6P0I6AT06ATI01XJ6PH0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WI
f@030=WIf@0501PH600I6AT06a/K01TI6@0K6a/0100J6QX00`0K6a/06QXJ01dM7@0301dM7@0401`L
700N7Qh071`L01`L70806QXJ00H071`L01/K6`0J6QX06a/K01XJ6P0K6a/201XJ6P0301`L700J6QX0
6QXJ00<06QXJ00@06a/K01XJ6P0K6a/06a/K0P0J6QX03@0I6AT06a/K01/K6`0K6a/06QXJ01/K6`0L
71`06QXJ01dM7@0K6a/06QXJ01`L700K6a/00P0L71`201/K6`0701`L700M7Ad071`L01/K6`0J6QX0
71`L01/K6`0301`L700701/K6`0M7Ad071`L01/K6`0L71`07AdM01/K6`0301dM7@0301`L700M7Ad0
7AdM00L07AdM0P0N7Qh01@0M7Ad071`L01hN7P0M7Ad07alO00807AdM00L07QhN01lO7`0O7al07alO
01dM7@0N7Qh0820P00807alO00H07QhN01lO7`0O7al07alO01hN7P0O7al2020P800501lO7`0N7Qh0
820P024Q8@0O7al00P0P8200100Q8B407alO01lO7`0Q8B42020P8006024Q8@0P8200820P024Q8@0R
8R80820P100Q8B43020P800:024Q8@0P82008R8R028R8P0Q8B40820P024Q8@0P82008B4Q020P80<0
8B4Q00@0820P024Q8@0P82008R8R0`0Q8B400`0P82008B4Q020P8003024Q8@0:02<S8`0R8R808B4Q
028R8P0P82008B4Q020P800S8b<07alO028R8P808B4Q0`0P82000`0Q8B40820P024Q8@07020P8003
01lO7`0P8200820P0080820P00@07alO020P800O7al0820P0`0O7al00`0N7Qh07alO01lO7`0201lO
7`0301hN7P0M7Ad07alO00D07QhN00H07AdM01hN7P0N7Qh07AdM01hN7P0M7Ad201hN7P807AdM00D0
7QhN01dM7@0L71`07AdM01`L700201dM7@0401/K6`0L71`07QhN01/K6`D071`L00@06a/K01`L700K
6a/071`L0P0K6a/01P0J6QX071`L01/K6`0L71`06a/K01dM7@D06a/K00<06ATI01/K6`0L71`00P0K
6a/201XJ6P806a/K00<071`L01TI6@0L71`00`0J6QX01@0I6AT06QXJ01XJ6P0J6QX06ATI00806QXJ
00D06ATI01/K6`0I6AT06ATI01/K6`0201TI6@0601XJ6P0I6AT06QXJ01XJ6P0I6AT06a/K0`0J6QX0
100K6a/06ATI01/K6`0J6QX201TI6@0301XJ6P0H61P061PH008061PH0`0I6AT00`0J6QX06ATI01TI
6@060=WIf@4000000@3IfMT001H0fMWI0P0000040=WIf@0301TI6@0J6QX06ATI00<06QXJ00<06ATI
01XJ6P0J6QX00P0J6QX201/K6`807AdM00D071`L01dM7@0K6a/06QXJ01/K6`0201XJ6P0301/K6`0J
6QX06QXJ00<06a/K0P0J6QX00`0I6AT06QXJ01XJ6P0201XJ6P0301/K6`0J6QX06QXJ00@06a/K00@0
6QXJ01/K6`0K6a/06QXJ100K6a/01`0J6QX06a/K01`L700L71`06a/K01`L700K6a/01@0L71`00`0M
7Ad06a/K01`L700201`L700401dM7@0N7Qh071`L01dM7@<071`L00H07AdM01hN7P0M7Ad071`L01dM
7@0N7Qh401dM7@8071`L0P0M7Ad01@0O7al07QhN01hN7P0O7al07AdM00807alO00H07AdM01hN7P0M
7Ad07alO01dM7@0O7al301hN7PD07alO00D07QhN01lO7`0O7al07QhN01lO7`02020P800501hN7P0O
7al0820P020P800Q8B400P0P8200200Q8B40820P020P800R8R808B4Q020P800R8R808B4Q1@0P8202
024Q8@08028R8P0Q8B408b<S024Q8@0R8R807alO024Q8@0P8202024Q8@06020P800Q8B40820P024Q
8@0P82008B4Q0P0R8R84020P8003028R8P0Q8B408B4Q00808B4Q00<0820P028R8P0R8R800P0Q8B40
0`0P82008B4Q028R8P02024Q8@06028R8P0P82008B4Q020P800Q8B407alO0`0Q8B402@0O7al08R8R
01lO7`0O7al0820P024Q8@0N7Qh07alO020P800301lO7`0401hN7P0O7al07alO020P80<07alO00<0
7QhN01lO7`0N7Qh00`0N7Qh00`0O7al07QhN01dM7@0401hN7P807AdM0`0N7Qh601dM7@0601hN7P0M
7Ad07AdM01`L700M7Ad06a/K0P0M7Ad401`L700701/K6`0M7Ad06a/K01/K6`0L71`06a/K01`L7005
01/K6`0501`L700M7Ad06QXJ01/K6`0L71`00P0J6QX201/K6`D06QXJ00@06a/K01XJ6P0K6a/06a/K
0P0J6QX00`0K6a/06QXJ01XJ6P0201XJ6P806a/K00@06QXJ01/K6`0J6QX06a/K0`0I6AT601XJ6P04
01TI6@0J6QX06QXJ01XJ6P806ATI0P0J6QX301TI6@0601XJ6P0I6AT06QXJ01XJ6P0H61P06QXJ0P0I
6AT0100H61P06ATI01TI6@0I6AT50=WIf@8000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3I
fMT01`0J6QX06ATI01XJ6P0I6AT06a/K01TI6@0J6QX00P0K6a/02P0J6QX06a/K01/K6`0K6a/071`L
01/K6`0J6QX06a/K01XJ6P0K6a/201XJ6P0701TI6@0K6a/06ATI01/K6`0J6QX06ATI01/K6`0201XJ
6P<06ATI00T06QXJ01/K6`0I6AT06QXJ01`L700K6a/06ATI01/K6`0J6QX00P0K6a/401XJ6P806a/K
00<071`L01XJ6P0K6a/00P0L71`01`0K6a/06QXJ01/K6`0L71`07AdM01/K6`0L71`00P0K6a/0100M
7Ad071`L01/K6`0M7Ad201/K6`8071`L00<07AdM01`L700M7Ad00P0M7Ad03P0L71`07AdM01`L700M
7Ad071`L01dM7@0N7Qh07AdM01`L700M7Ad071`L01hN7P0M7Ad071`L1@0M7Ad401hN7P0301lO7`0N
7Qh07QhN00D07alO00d0820P01lO7`0N7Qh08B4Q01lO7`0N7Qh07alO020P800O7al07QhN020P800N
7Qh0820P00807alO0P0P82000`0Q8B40820P020P8005020P80<08B4Q00<0820P028R8P0R8R800P0P
8204024Q8@03020P800Q8B408B4Q0080820P00L08B4Q020P800R8R808B4Q020P800Q8B408R8R00D0
8B4Q00<08R8R024Q8@0Q8B40100Q8B40100R8R80820P020P800Q8B42020P8003024Q8@0R8R80820P
00807alO0P0P8200100Q8B40820P020P800O7al2024Q8@04020P800Q8B407alO020P80<07alO00<0
7QhN01lO7`0M7Ad00P0O7al00`0P82007alO01lO7`0201hN7P0401lO7`0N7Qh07alO01lO7`807QhN
00<07AdM01hN7P0M7Ad00P0N7Qh401dM7@0401hN7P0L71`07QhN01dM7@8071`L00<07AdM01`L700M
7Ad00P0M7Ad201`L700501/K6`0L71`071`L01`L700M7Ad00`0L71`401/K6`0301`L700J6QX06a/K
00<071`L00@06ATI01XJ6P0K6a/06a/K100J6QX201/K6`0301XJ6P0K6a/06QXJ00L06a/K0`0J6QX0
100K6a/06ATI01TI6@0K6a/201TI6@D06QXJ00<06ATI01/K6`0I6AT00P0J6QX301TI6@0401XJ6P0I
6AT06QXJ01TI6@<06QXJ00@06a/K01PH600J6QX06QXJ0P0I6AT01@0J6QX06ATI01XJ6P0I6AT061PH
00<06ATI1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0P0I6AT01`0J6QX0
6a/K01/K6`0J6QX06a/K01XJ6P0K6a/00P0J6QX0100I6AT06QXJ01`L700J6QX201/K6`0401XJ6P0K
6a/06QXJ01/K6`806QXJ00<06a/K01XJ6P0K6a/00`0J6QX201/K6`0501TI6@0J6QX06QXJ01XJ6P0K
6a/00P0J6QX00`0K6a/06QXJ01/K6`0301XJ6P@06a/K00@071`L01XJ6P0K6a/06a/K0P0L71`00`0J
6QX071`L01`L700201/K6`0301`L700K6a/071`L00806a/K00/071`L01/K6`0L71`071`L01/K6`0M
7Ad06a/K01`L700K6a/07AdM01`L700301dM7@0301`L700M7Ad071`L008071`L0P0M7Ad01`0N7Qh0
7AdM01hN7P0M7Ad071`L01dM7@0L71`00P0N7Qh00`0M7Ad07QhN01dM7@0501hN7P@07alO00L07QhN
01lO7`0O7al07alO01hN7P0O7al07AdM00807QhN0P0P82001@0O7al0820P01lO7`0Q8B407alO0080
8B4Q0P0O7al3020P8003024Q8@0P8200820P0080820P00@08B4Q020P800Q8B40820P1@0Q8B43020P
8005028R8P0Q8B40820P024Q8@0P82000P0Q8B400`0P82008B4Q028R8P02024Q8@0;020P800R8R80
8B4Q024Q8@0R8R808B4Q020P800O7al08B4Q02<S8`0Q8B400`0P82001`0O7al08B4Q020P800O7al0
820P01lO7`0P82000P0O7al2020P8003024Q8@0P82007alO0080820P0P0O7al01P0N7Qh07alO01lO
7`0O7al07QhN020P80807alO00@07QhN020P800N7Qh07AdM0P0O7al401hN7P0401lO7`0N7Qh07alO
01hN7P807AdM00<07QhN01dM7@0M7Ad00P0L71`0100M7Ad07QhN01dM7@0M7Ad201`L70807QhN00D0
7AdM01/K6`0L71`07AdM01/K6`0401`L700601dM7@0K6a/071`L01`L700K6a/06QXJ0P0L71`01@0K
6a/071`L01`L700K6a/06QXJ00806a/K0P0L71`201/K6`0501XJ6P0K6a/06QXJ01/K6`0L71`00P0K
6a/201XJ6P0801/K6`0J6QX06a/K01XJ6P0K6a/06QXJ01`L700I6AT201XJ6P0301TI6@0K6a/06QXJ
00<06QXJ00D06ATI01XJ6P0K6a/06QXJ01`L700301XJ6P0301TI6@0J6QX06QXJ00@06QXJ00H06ATI
01XJ6P0J6QX061PH01`L700J6QX201TI6@0301PH600J6QX06ATI00<06ATI00D06QXJ01TI6@0I6AT0
61PH01TI6@060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT301TI6@0501XJ
6P0I6AT06a/K01XJ6P0I6AT00`0J6QX01@0K6a/06QXJ01XJ6P0J6QX06a/K00806QXJ00@06ATI01/K
6`0I6AT06ATI100J6QX00`0K6a/06QXJ01XJ6P0201/K6`0601TI6@0K6a/06QXJ01/K6`0J6QX06a/K
0P0J6QX0300I6AT071`L01/K6`0K6a/06QXJ01/K6`0J6QX07AdM01/K6`0L71`06QXJ01`L70D06a/K
0P0L71`0200K6a/07AdM01/K6`0L71`06QXJ01`L700K6a/07AdM0P0L71`00`0K6a/071`L01`L7004
01`L700301hN7P0L71`071`L00<071`L00<07AdM01hN7P0N7Qh00`0M7Ad01@0N7Qh071`L01hN7P0M
7Ad07QhN00D07AdM0`0N7Qh00`0O7al07QhN01lO7`0201lO7`H07QhN0`0O7al0100N7Qh07alO01hN
7P0O7al201hN7P807alO00<07QhN020P800O7al0100P8202024Q8@0301lO7`0P82008B4Q00<0820P
00/08B4Q020P800O7al07alO020P800Q8B40820P024Q8@0O7al0820P01lO7`03020P8004024Q8@0R
8R807alO01hN7P807alO100P82000`0Q8B40820P024Q8@02020P80<08B4Q00@0820P024Q8@0Q8B40
8B4Q0`0P8200100Q8B407alO01lO7`0O7al3024Q8@0=01lO7`0P8200820P020P800Q8B40820P01lO
7`0N7Qh07alO01hN7P0O7al07QhN024Q8@0301hN7P0301dM7@0N7Qh0820P00H07QhN0P0M7Ad00`0O
7al07QhN01hN7P0201hN7P0801dM7@0N7Qh07QhN01hN7P0M7Ad07QhN01dM7@0N7Qh201dM7@0401hN
7P0M7Ad071`L01dM7@D071`L00H06a/K01`L700K6a/071`L01/K6`0L71`201/K6`0701`L700I6AT0
6a/K01/K6`0L71`06a/K01`L700301/K6`0301XJ6P0K6a/07AdM00806a/K00<06QXJ01/K6`0J6QX0
0P0K6a/00`0L71`06QXJ01/K6`0201XJ6P806a/K00L06QXJ01/K6`0K6a/06QXJ01/K6`0J6QX06ATI
00<06QXJ0P0I6AT401XJ6P<06ATI00<06a/K01XJ6P0J6QX01@0J6QX0100K6a/06ATI01TI6@0J6QX3
01TI6@806QXJ0P0I6AT201XJ6P0501TI6@0J6QX06ATI01TI6@0H61P01P3IfMT100000040fMWI000F
0=WIf@030000003IfMT0fMWI00<0fMWI0`0I6AT201XJ6P0301TI6@0J6QX06ATI00806ATI00<06a/K
01XJ6P0J6QX00`0J6QX401/K6`806QXJ00<06ATI01/K6`0J6QX00`0J6QX0100K6a/06QXJ01XJ6P0H
61P201XJ6P806a/K00<06QXJ01`L700J6QX00`0J6QX01`0K6a/071`L01XJ6P0L71`06QXJ01`L700K
6a/00`0J6QX401/K6`0701`L700K6a/06a/K01`L700K6a/071`L01/K6`0201`L70<06a/K0`0L71`0
200K6a/071`L01/K6`0L71`07QhN01dM7@0J6QX071`L1@0M7Ad201`L70<07QhN100M7Ad0100N7Qh0
7AdM01dM7@0O7al201hN7P0501dM7@0O7al07QhN01dM7@0N7Qh00`0O7al301hN7P0401dM7@0N7Qh0
7QhN020P80807QhN0P0O7al01P0N7Qh0820P01lO7`0N7Qh0820P01lO7`<0820P00L08B4Q020P800O
7al07alO020P800Q8B407alO0080820P00X07alO020P800O7al08B4Q020P800O7al08B4Q020P800O
7al08B4Q0P0P82001`0O7al0820P020P800O7al08B4Q020P800O7al00P0P8202024Q8@0:01lO7`0Q
8B40820P024Q8@0R8R80820P01lO7`0P82007QhN020P80808B4Q00<0820P01lO7`0O7al00`0O7al0
200P82007alO020P800P82007alO024Q8@0P82007alO100P820201lO7`0501hN7P0O7al07alO01lO
7`0N7Qh00P0O7al201hN7P0701lO7`0N7Qh07alO01lO7`0N7Qh07AdM01hN7P0201lO7`807QhN00D0
7AdM01`L700M7Ad07AdM01hN7P0201dM7@0301`L700M7Ad07AdM00807QhN1P0M7Ad01@0L71`07AdM
01`L700L71`07AdM00@071`L00<06a/K01`L700K6a/01@0L71`0100K6a/071`L01`L700K6a/301`L
700301/K6`0J6QX06a/K008071`L0P0K6a/201XJ6P0301/K6`0J6QX06QXJ00806a/K0P0J6QX00`0I
6AT06a/K01XJ6P0301XJ6P806a/K00D06QXJ01/K6`0J6QX06QXJ01TI6@0201XJ6P0501/K6`0I6AT0
6a/K01XJ6P0I6AT0200J6QX01@0K6a/06QXJ01TI6@0K6a/06QXJ00<06ATI00<06QXJ01TI6@0I6AT0
0`0I6AT00`0J6QX06ATI01TI6@060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3I
fMT301TI6@0401/K6`0J6QX06QXJ01PH60806QXJ00<06ATI01XJ6P0K6a/00P0J6QX00`0K6a/06ATI
01XJ6P0201XJ6P0501/K6`0J6QX06QXJ01XJ6P0K6a/00`0J6QX201/K6`806QXJ00<06ATI01XJ6P0K
6a/00P0K6a/00`0J6QX06a/K01/K6`0301/K6`0401XJ6P0K6a/06QXJ01`L70806a/K00@06QXJ01/K
6`0K6a/06QXJ0P0K6a/201`L700301/K6`0L71`06QXJ00<06a/K0P0L71`0100M7Ad071`L01`L700L
71`401/K6`0601`L700M7Ad071`L01hN7P0L71`07AdM0`0L71`401dM7@0401hN7P0M7Ad07AdM01lO
7`L07AdM100N7Qh0100M7Ad07QhN01dM7@0O7al801hN7P0601lO7`0N7Qh07QhN024Q8@0O7al07QhN
0`0O7al00`0N7Qh07alO01lO7`0201lO7`06020P800N7Qh0820P024Q8@0P82007QhN0P0O7al3020P
80807QhN0P0O7al3020P800301lO7`0P8200820P00<07alO0P0P82001`0N7Qh07alO01lO7`0O7al0
7AdM020P800O7al00`0P82000`0Q8B407alO01lO7`0401lO7`<0820P100O7al00`0N7Qh07alO024Q
8@02020P800501lO7`0P82007alO020P800O7al00P0P8200100N7Qh0820P020P800O7al201hN7P80
7alO00<07QhN01lO7`0N7Qh00`0N7Qh201lO7`0401hN7P0O7al07QhN01dM7@807QhN0P0M7Ad0100L
71`07AdM01lO7`0N7Qh201dM7@0301hN7P0L71`07QhN00807AdM00@07QhN01dM7@0K6a/071`L0`0M
7Ad0100N7Qh07AdM01dM7@0M7Ad201`L700301dM7@0K6a/071`L00H06a/K0P0J6QX00`0K6a/07AdM
01`L700201/K6`0301XJ6P0L71`06QXJ008071`L0P0K6a/01`0J6QX06a/K01/K6`0J6QX06ATI01/K
6`0J6QX00P0K6a/01@0J6QX06a/K01XJ6P0J6QX06ATI00@06QXJ100K6a/01@0I6AT06QXJ01/K6`0I
6AT06QXJ00806ATI100J6QX00`0I6AT06QXJ01/K6`0301XJ6PL06ATI0P0J6QX00`0I6AT06QXJ01PH
600201XJ6P806ATI1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00D06QXJ
01PH600I6AT06QXJ01TI6@0201XJ6P0401TI6@0J6QX06ATI01/K6`806QXJ00D06ATI01XJ6P0J6QX0
6QXJ01/K6`0201XJ6P0301/K6`0J6QX06QXJ00L06QXJ00D06a/K01XJ6P0J6QX06QXJ01/K6`0501XJ
6P0601/K6`0J6QX06a/K01/K6`0J6QX06a/K0P0J6QX0100K6a/06QXJ01/K6`0I6AT201/K6`0701`L
700K6a/06a/K01/K6`0L71`07AdM01`L700201/K6`8071`L00<06a/K01`L700L71`00`0K6a/201`L
70807AdM00L071`L01dM7@0K6a/071`L01/K6`0M7Ad06a/K00807AdM0P0L71`00`0M7Ad071`L01hN
7P0601dM7@807QhN00@07AdM01hN7P0N7Qh07QhN0P0M7Ad0100N7Qh07AdM01hN7P0M7Ad201lO7`05
01hN7P0O7al07alO01lO7`0N7Qh00`0O7al201hN7P80820P00T07QhN01lO7`0O7al07alO01dM7@0O
7al0820P01lO7`0N7Qh00P0P82000`0N7Qh07alO020P800401lO7`80820P00@08B4Q020P800O7al0
7alO0P0Q8B4201lO7`0401hN7P0O7al0820P01hN7P@0820P00<07alO020P800P82000P0Q8B400`0P
82007alO020P8003020P80<07alO00`07QhN020P800O7al0820P01lO7`0N7Qh08B4Q020P800O7al0
7AdM024Q8@0P820301lO7`03020P800N7Qh07alO00@07alO00H07QhN01lO7`0M7Ad07alO01hN7P0O
7al301hN7P<07alO00<07AdM01`L700N7Qh00`0N7Qh02@0M7Ad07alO01hN7P0L71`07AdM01lO7`0M
7Ad071`L01dM7@0201`L70807AdM00D071`L01dM7@0L71`071`L01dM7@0301`L700301hN7P0M7Ad0
71`L00<07AdM00@071`L01/K6`0J6QX06a/K2P0L71`00`0K6a/06QXJ01/K6`0201/K6`0401XJ6P0L
71`06a/K01/K6`806QXJ00<06ATI01/K6`0J6QX01@0K6a/00`0J6QX06ATI01XJ6P0201XJ6P0301TI
6@0J6QX06QXJ00806a/K00<06QXJ01TI6@0J6QX00P0J6QX401TI6@0901XJ6P0K6a/06QXJ01XJ6P0I
6AT06a/K01TI6@0J6QX06a/K00D06QXJ0P0I6AT00`0H61P06QXJ01PH600501TI6@H0fMWI0@000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@<06QXJ00L06ATI01XJ6P0J6QX06QXJ01TI6@0J
6QX06ATI00806QXJ00<06ATI01XJ6P0J6QX0100J6QX201/K6`806QXJ00X06ATI01XJ6P0J6QX06a/K
01XJ6P0K6a/06QXJ01/K6`0J6QX06a/K100J6QX01`0K6a/06QXJ01/K6`0K6a/06QXJ01/K6`0J6QX0
0P0K6a/01`0I6AT071`L01/K6`0K6a/071`L01/K6`0L71`00P0J6QX201`L700401/K6`0L71`071`L
01`L70<06a/K00<071`L01/K6`0L71`00P0L71`00`0M7Ad071`L01dM7@0601`L700401dM7@0L71`0
71`L01dM7@8071`L0P0K6a/00`0M7Ad071`L01dM7@0301dM7@0401`L700M7Ad07QhN01hN7P<07AdM
00H07QhN01dM7@0N7Qh07QhN01dM7@0L71`201hN7P0401lO7`0N7Qh07QhN01hN7P807alO00<07AdM
01lO7`0N7Qh00P0O7al201hN7P0401lO7`0P82007alO01hN7P<07alO0P0P820201lO7`0301hN7P0P
82007alO0080820P00@07QhN020P800O7al0820P0P0O7al2020P800301lO7`0P82007QhN00807alO
0P0N7Qh0100O7al0820P020P800N7Qh2020P800301lO7`0Q8B40820P0080820P0P0Q8B400`0O7al0
8B4Q01hN7P0301lO7`09024Q8@0O7al0820P020P800N7Qh0820P01lO7`0N7Qh0820P00@07alO00D0
7QhN01lO7`0P82007QhN020P800301lO7`0301hN7P0O7al07QhN00D07QhN00<07alO01hN7P0M7Ad0
100N7Qh01`0O7al07QhN01hN7P0N7Qh07alO01dM7@0N7Qh01P0M7Ad00`0N7Qh071`L01dM7@0201dM
7@0301`L700N7Qh07AdM00807AdM0P0L71`201hN7P0501`L700M7Ad071`L01dM7@0K6a/00P0L71`0
0`0J6QX071`L01/K6`0401/K6`0301XJ6P0K6a/06a/K00806a/K00<071`L01XJ6P0K6a/01@0J6QX0
0`0I6AT06QXJ01XJ6P0201/K6`P06QXJ0P0I6AT00`0K6a/06QXJ01/K6`0201/K6`<06ATI0`0J6QX2
01TI6@0401/K6`0J6QX06QXJ01XJ6P806ATI00H06a/K01TI6@0J6QX06QXJ01TI6@0J6QX301TI6@04
01XJ6P0I6AT06ATI01TI6@@06QXJ0`0I6AT60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`0J6QX06ATI01`L700201XJ6P0:01TI6@0K6a/06QXJ01XJ6P0I6AT06a/K01XJ6P0I
6AT06QXJ01TI6@806QXJ00<06ATI01XJ6P0J6QX0100J6QX01@0I6AT06QXJ01/K6`0J6QX06a/K00<0
6QXJ00@06ATI01/K6`0J6QX06a/K0P0J6QX01@0K6a/06QXJ01XJ6P0K6a/06QXJ00806a/K00@06QXJ
01/K6`0J6QX06a/K0P0J6QX00`0K6a/071`L01/K6`0601/K6`0701XJ6P0K6a/06a/K01dM7@0J6QX0
6a/K01`L700201/K6`<071`L00<06a/K01`L700L71`00P0L71`01P0M7Ad06a/K01`L700M7Ad071`L
01hN7P<071`L00P07QhN01`L700L71`07QhN01`L700N7Qh07AdM01`L70807AdM00<07QhN01dM7@0M
7Ad00P0N7Qh201lO7`0301`L700N7Qh07AdM00H07QhN00D07AdM01hN7P0N7Qh07alO01hN7P0201lO
7`80820P00@07alO01hN7P0P82007alO0`0N7Qh0100O7al07QhN020P800O7al2020P80@07alO00<0
8B4Q020P800Q8B400P0P8200100Q8B407alO01lO7`0O7al201hN7P807alO00@0820P01lO7`0N7Qh0
7QhN0P0O7al2020P80<07alO0`0P82000`0Q8B40820P01lO7`02020P800601lO7`0N7Qh07QhN01lO
7`0N7Qh07alO0P0N7Qh201lO7`0301hN7P0O7al07alO00H07alO00L0820P01lO7`0M7Ad07QhN01dM
7@0O7al07QhN00<07alO00<07AdM01hN7P0N7Qh0100N7Qh01`0M7Ad07alO01dM7@0L71`07QhN01dM
7@0N7Qh0100M7Ad00`0L71`07AdM01dM7@0201dM7@8071`L00<07AdM01hN7P0N7Qh0100L71`201hN
7P<07AdM00<06a/K01XJ6P0K6a/00P0K6a/301`L700301/K6`0L71`06a/K00<06a/K00X071`L01/K
6`0L71`071`L01/K6`0L71`06a/K01TI6@0J6QX06a/K0P0J6QX01`0L71`06a/K01XJ6P0J6QX06ATI
01XJ6P0K6a/00P0J6QX0100K6a/06ATI01XJ6P0I6AT201/K6`0601XJ6P0I6AT06QXJ01XJ6P0K6a/0
6QXJ0`0I6AT501XJ6P0401TI6@0K6a/06a/K01TI6@<06QXJ0`0I6AT01`0J6QX06ATI01TI6@0K6a/0
61PH01TI6@0H61P0100I6AT00`0H61P06ATI0=WIf@050=WIf@4000000@3IfMT001H0fMWI00<00000
0=WIf@3IfMT00`3IfMT01P0I6AT06QXJ01XJ6P0J6QX06ATI01/K6`806ATI1`0J6QX01@0K6a/06ATI
01XJ6P0J6QX06ATI00H06QXJ00D06a/K01XJ6P0K6a/06QXJ01/K6`0201XJ6P<06a/K00D06QXJ01/K
6`0K6a/06QXJ01`L700201XJ6P<06a/K00<06QXJ01/K6`0K6a/00P0K6a/201XJ6P@06a/K00@07AdM
01XJ6P0K6a/06a/K0`0L71`301/K6`0301`L700K6a/071`L008071`L00@06a/K01`L700K6a/071`L
0`0K6a/201`L700601/K6`0L71`071`L01`L700M7Ad071`L0P0M7Ad201`L70807AdM00D06a/K01dM
7@0M7Ad071`L01dM7@0201hN7P0301dM7@0N7Qh07AdM00@07AdM0`0N7Qh01@0M7Ad07QhN01lO7`0O
7al07AdM00<07alO00D0820P01hN7P0N7Qh07alO020P800201hN7P<07alO0P0N7Qh0100O7al07QhN
01lO7`0O7al201hN7P06020P800O7al0820P020P800O7al0820P0P0O7al00`0P82008B4Q01lO7`02
01lO7`04020P800O7al07alO020P80807alO00@0820P01hN7P0O7al0820P0P0O7al3020P8009024Q
8@0P8200820P020P800N7Qh07alO020P800M7Ad0820P00807alO00@08B4Q020P800O7al0820P0`0N
7Qh00`0P82007QhN01hN7P0201lO7`0301hN7P0P82007QhN00807QhN00<07alO01dM7@0O7al00P0N
7Qh01P0M7Ad07QhN01lO7`0O7al07QhN01lO7`<07AdM00<07QhN01dM7@0N7Qh0100M7Ad01@0L71`0
7QhN01`L700M7Ad07QhN008071`L0P0M7Ad01P0L71`07AdM01hN7P0L71`07AdM01`L70807AdM00L0
71`L01dM7@0M7Ad07alO01dM7@0L71`07AdM00806a/K0P0L71`01P0K6a/071`L01XJ6P0K6a/071`L
01XJ6P806a/K00<071`L01/K6`0L71`0100K6a/301XJ6P<06a/K00D071`L01/K6`0J6QX06ATI01/K
6`0201XJ6P0301/K6`0J6QX06a/K00@06QXJ0P0K6a/201XJ6P806ATI0P0J6QX0200I6AT06QXJ01TI
6@0J6QX061PH01XJ6P0K6a/06QXJ0P0K6a/00`0I6AT06QXJ01XJ6P0201XJ6P0401TI6@0H61P06QXJ
01TI6@806QXJ0P0I6AT0100J6QX061PH01TI6@0I6AT201PH600301TI6@3IfMT0fMWI00@0fMWI0@00
00010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@806ATI1@0J6QX0100K6a/06QXJ01XJ6P0K
6a/201XJ6P0501TI6@0J6QX06ATI01/K6`0I6AT00`0J6QX00`0K6a/06QXJ01XJ6P0201XJ6P0301/K
6`0J6QX06ATI00806QXJ00P06a/K01XJ6P0L71`06a/K01XJ6P0K6a/06QXJ01TI6@<06a/K00<06QXJ
01/K6`0K6a/00P0J6QX00`0K6a/06QXJ01XJ6P0301XJ6PD06a/K00<071`L01/K6`0L71`00`0K6a/0
1@0M7Ad06a/K01/K6`0K6a/06QXJ00<06a/K00<06QXJ01`L700M7Ad00`0K6a/501`L700301dM7@0K
6a/06a/K00<071`L0`0M7Ad0200N7Qh07AdM01dM7@0L71`07AdM01hN7P0M7Ad07QhN100M7Ad201hN
7P807AdM0P0N7Qh201dM7@0601hN7P0O7al07alO01hN7P0O7al07QhN0P0O7al01P0N7Qh07alO01hN
7P0N7Qh07alO020P80<07alO00X07QhN020P800P82007alO01hN7P0O7al08B4Q01lO7`0N7Qh07alO
0P0P820501lO7`0501hN7P0O7al07alO01lO7`0Q8B400P0O7al00`0N7Qh07alO01lO7`0201hN7P06
020P800N7Qh0820P01lO7`0N7Qh0820P0P0O7al01P0P82007alO01hN7P0N7Qh0820P01lO7`807QhN
00<07alO01hN7P0N7Qh00`0O7al201hN7P807AdM00P07QhN01lO7`0N7Qh07QhN01dM7@0N7Qh07alO
01dM7@807QhN00<07AdM01lO7`0M7Ad00P0N7Qh00`0M7Ad07alO01hN7P0301hN7P<07AdM00@07alO
01hN7P0M7Ad07QhN100M7Ad01P0N7Qh071`L01dM7@0K6a/071`L01dM7@8071`L00<07AdM01`L700L
71`00`0L71`01@0M7Ad071`L01dM7@0M7Ad071`L00807AdM00<06a/K01dM7@0L71`00P0L71`00`0K
6a/071`L01`L700201/K6`0601`L700K6a/071`L01/K6`0L71`06a/K0P0L71`201/K6`806QXJ00<0
6a/K01`L700J6QX01P0J6QX00`0K6a/06QXJ01XJ6P0201/K6`806QXJ00<06a/K01XJ6P0J6QX0100J
6QX201TI6@806QXJ00@06ATI01XJ6P0I6AT061PH0P0I6AT01@0H61P071`L01XJ6P0J6QX06ATI0080
6QXJ00D061PH01XJ6P0I6AT06ATI01XJ6P0201TI6@0401PH600I6AT06ATI01TI6@806QXJ00<06ATI
01XJ6P3IfMT01@3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0P0J6QX201TI
6@0301XJ6P0I6AT06QXJ00D06QXJ00D06a/K01TI6@0I6AT06ATI01/K6`0401XJ6P806ATI100J6QX2
01TI6@<06QXJ00@06a/K01XJ6P0I6AT06a/K100J6QX01@0K6a/071`L01TI6@0K6a/06QXJ00@06a/K
0P0J6QX701/K6`0501XJ6P0M7Ad06a/K01dM7@0J6QX00`0L71`0100K6a/071`L01`L700K6a/301`L
700501/K6`0L71`071`L01`L700M7Ad00P0K6a/00`0M7Ad071`L01`L700201`L700301/K6`0L71`0
6a/K008071`L0P0M7Ad0100L71`07AdM01hN7P0L71`301dM7@807QhN00<071`L01dM7@0M7Ad01@0N
7Qh201dM7@807QhN0`0O7al0200N7Qh07alO01lO7`0O7al07QhN01lO7`0P82007QhN0P0O7al0200N
7Qh07alO01hN7P0O7al07AdM01hN7P0O7al0820P200O7al01@0P82007QhN01lO7`0P82007QhN0080
7alO0P0N7Qh0100O7al07QhN01hN7P0N7Qh201lO7`03020P800N7Qh07alO0080820P1@0O7al2020P
800401hN7P0O7al07alO01dM7@807QhN00<07alO020P800O7al0100O7al01@0P82007alO01hN7P0N
7Qh07alO00<07QhN00<07AdM01lO7`0N7Qh0100N7Qh00`0O7al07QhN01hN7P0201hN7P807AdM0`0N
7Qh401dM7@0301hN7P0M7Ad07AdM00807AdM0P0L71`301dM7@0501`L700M7Ad07AdM01`L700M7Ad0
100L71`201dM7@@071`L00D07QhN01dM7@0L71`071`L01/K6`0201`L700301dM7@0L71`071`L0080
71`L0P0K6a/00`0M7Ad071`L01/K6`0201/K6`0:01XJ6P0K6a/071`L01XJ6P0I6AT06a/K01XJ6P0K
6a/06QXJ01TI6@<06a/K00<06QXJ01/K6`0J6QX01`0J6QX0100K6a/06ATI01XJ6P0I6AT201XJ6P08
01TI6@0J6QX06QXJ01XJ6P0I6AT06a/K01TI6@0K6a/301XJ6P<06ATI00<06QXJ01/K6`0J6QX00P0I
6AT201XJ6P0501TI6@0H61P06ATI01TI6@0J6QX00`0I6AT00`0J6QX0fMWI0=WIf@040=WIf@400000
0@3IfMT001H0fMWI0P0000040=WIf@D06ATI00D06QXJ01TI6@0J6QX06QXJ01/K6`0201TI6@<06QXJ
00<06ATI01XJ6P0I6AT00`0J6QX0200H61P06ATI01XJ6P0I6AT06a/K01TI6@0J6QX06a/K1@0J6QX0
2P0K6a/06QXJ01XJ6P0I6AT06QXJ01/K6`0J6QX06a/K01XJ6P0K6a/301XJ6P0601/K6`0J6QX06QXJ
01/K6`0J6QX071`L1@0K6a/01P0J6QX06a/K01`L700L71`06a/K01`L70<06a/K0`0L71`201/K6`04
01`L700K6a/071`L01/K6`<071`L00L07AdM01/K6`0K6a/07AdM01/K6`0L71`06a/K00X071`L00<0
7AdM01`L700L71`01`0M7Ad00`0N7Qh07AdM01hN7P0301hN7P@07AdM00<07QhN01`L700O7al00P0N
7Qh201lO7`0301dM7@0N7Qh07QhN00<07QhN00H07alO020P800O7al0820P01hN7P0P820201hN7P<0
7alO00<07QhN01lO7`0N7Qh00`0O7al0100N7Qh07alO01lO7`0P820301lO7`05020P800O7al0820P
01lO7`0P82000P0O7al00`0P82007alO01hN7P0201lO7`04020P800Q8B407alO020P80807alO1@0N
7Qh0100O7al07QhN01lO7`0O7al201hN7P807alO0`0N7Qh00`0M7Ad07QhN01hN7P0501hN7P0501dM
7@0N7Qh07QhN01dM7@0N7Qh00`0M7Ad01P0N7Qh07AdM01dM7@0M7Ad071`L01dM7@807QhN00<07AdM
01hN7P0M7Ad00`0M7Ad00`0N7Qh07AdM01dM7@0201`L700301dM7@0K6a/071`L00806a/K00<07AdM
01`L700L71`0100M7Ad01@0L71`07QhN01`L700L71`06a/K00/071`L00H06a/K01`L700L71`06a/K
01XJ6P0L71`601XJ6P0801/K6`0J6QX06a/K01TI6@0J6QX071`L01XJ6P0K6a/201XJ6P0301TI6@0K
6a/06QXJ00806QXJ0`0I6AT00`0J6QX06ATI01TI6@0201TI6@806QXJ0P0I6AT201XJ6P0301TI6@0J
6QX06QXJ00<06ATI00<06QXJ01TI6@0J6QX00P0J6QX201TI6@0701XJ6P0I6AT06QXJ01TI6@0J6QX0
6ATI01PH600301TI6@D0fMWI0P0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0401XJ
6P0I6AT06QXJ01/K6`<06QXJ00H06ATI01/K6`0J6QX06a/K01TI6@0J6QX201TI6@0801XJ6P0K6a/0
6QXJ01/K6`0I6AT06QXJ01TI6@0J6QX201TI6@0501XJ6P0K6a/06QXJ01/K6`0J6QX00P0I6AT0100J
6QX06a/K01XJ6P0J6QX201/K6`0301XJ6P0K6a/06a/K00<06QXJ00/06a/K01XJ6P0K6a/06QXJ01/K
6`0J6QX06a/K01`L700K6a/071`L01XJ6P0201/K6`0301`L700J6QX06QXJ00806a/K0P0J6QX0100L
71`06a/K01/K6`0J6QX201`L70L06a/K00@071`L01/K6`0L71`06QXJ0`0L71`03`0K6a/071`L01/K
6`0M7Ad06a/K01`L700M7Ad071`L01dM7@0K6a/07QhN01`L700N7Qh071`L01hN7P0401dM7@807QhN
00D071`L01dM7@0N7Qh07AdM01`L700501hN7P807AdM1@0N7Qh0100O7al07QhN01hN7P0O7al201dM
7@04020P800O7al07alO01dM7@@07alO00D07QhN01lO7`0P82007alO01hN7P0201lO7`807QhN00L0
7alO01hN7P0O7al0820P01hN7P0O7al07QhN00D07alO00X07QhN01lO7`0M7Ad07QhN01lO7`0N7Qh0
7alO01hN7P0P82007QhN1@0O7al0100N7Qh0820P01lO7`0O7al201hN7P06020P800O7al07QhN01lO
7`0N7Qh071`L1@0N7Qh02@0O7al07QhN01lO7`0N7Qh07alO01dM7@0N7Qh071`L01dM7@0301hN7P07
01dM7@0N7Qh07AdM01dM7@0L71`07AdM01`L700201dM7@0301`L700M7Ad07AdM00807AdM00H06a/K
01`L700K6a/07AdM01/K6`0L71`301dM7@<071`L00<06ATI01`L700L71`00P0K6a/0100L71`07AdM
01`L700M7Ad301`L700301dM7@0L71`06a/K008071`L0P0M7Ad03@0L71`06a/K01/K6`0L71`06a/K
01`L700K6a/06QXJ01/K6`0L71`06a/K01XJ6P0L71`00P0K6a/01@0J6QX06a/K01XJ6P0I6AT06a/K
00806QXJ00P06a/K01XJ6P0K6a/06QXJ01PH600K6a/06ATI01XJ6P806a/K00L061PH01XJ6P0I6AT0
6ATI01XJ6P0K6a/06ATI00806QXJ00P06ATI01/K6`0I6AT06ATI01XJ6P0I6AT061PH01XJ6PD06ATI
00<06QXJ01TI6@0J6QX00P0I6AT01P0M7Ad06ATI01TI6@0I6AT06QXJ01PH60<06QXJ1P3IfMT10000
0040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00<06ATI01XJ6P0J6QX00P0I6AT301XJ6P@0
6ATI00<06QXJ01PH600I6AT00P0J6QX01P0H61P06QXJ01TI6@0I6AT06QXJ01TI6@806QXJ00D06ATI
01XJ6P0K6a/06ATI01XJ6P0201/K6`0301XJ6P0K6a/06a/K00D06QXJ00D06ATI01/K6`0K6a/06QXJ
01TI6@0201/K6`<06QXJ00<06a/K01XJ6P0J6QX01P0J6QX00`0K6a/071`L01/K6`0201/K6`0501XJ
6P0L71`06a/K01`L700K6a/00P0L71`201/K6`806QXJ100L71`01P0K6a/06QXJ01`L700K6a/071`L
01dM7@8071`L00D06a/K01dM7@0M7Ad07AdM01/K6`0201dM7@0701`L700M7Ad07AdM01dM7@0L71`0
7AdM01`L700201dM7@0301`L700M7Ad07AdM00807AdM00L07QhN01dM7@0M7Ad07alO01hN7P0O7al0
7AdM00807QhN00@07alO01hN7P0P82007AdM0P0N7Qh00`0O7al07AdM01lO7`0601hN7P<07alO0`0N
7Qh00`0O7al07QhN01lO7`0201lO7`0301hN7P0O7al07alO00<07alO00D0820P01hN7P0N7Qh07QhN
01lO7`0201hN7P0401lO7`0M7Ad07AdM01lO7`@07QhN100O7al0100P82007alO01hN7P0N7Qh201lO
7`807QhN0P0O7al00`0P82007alO01lO7`0401hN7P0401lO7`0N7Qh07QhN01lO7`807AdM00D07QhN
01dM7@0L71`07AdM01hN7P0201dM7@807QhN00D07AdM01hN7P0M7Ad071`L01dM7@0201`L70807AdM
00`07QhN01`L700M7Ad07AdM01`L700K6a/07QhN01dM7@0K6a/071`L01hN7P0K6a/201dM7@0301/K
6`0L71`071`L00<071`L00D07AdM01/K6`0M7Ad06a/K01`L700201dM7@@071`L00@07AdM01hN7P0L
71`07AdM0P0L71`00`0M7Ad071`L01/K6`0201`L700301dM7@0L71`071`L00806a/K00/06QXJ01/K
6`0L71`071`L01XJ6P0K6a/06QXJ01/K6`0L71`06a/K01`L700401XJ6P0301TI6@0J6QX06QXJ0080
6ATI100J6QX401TI6@D06QXJ00@06ATI01PH600J6QX06ATI1@0J6QX0100H61P06ATI01XJ6P0I6AT2
01XJ6P0301TI6@0J6QX06QXJ00806QXJ00<06ATI01XJ6P0I6AT00P0I6AT60=WIf@4000000@3IfMT0
01H0fMWI00<000000=WIf@3IfMT00`3IfMT01@0I6AT06QXJ01TI6@0I6AT06QXJ00806ATI00@06QXJ
01/K6`0I6AT06QXJ0`0I6AT201XJ6P0401TI6@0K6a/06QXJ01XJ6P806ATI0P0J6QX01P0I6AT06QXJ
01XJ6P0H61P06QXJ01TI6@<06QXJ0P0K6a/301XJ6P0501/K6`0J6QX06a/K01/K6`0I6AT00P0K6a/2
01XJ6P0601/K6`0L71`06a/K01XJ6P0K6a/06QXJ0P0K6a/02`0J6QX06ATI01XJ6P0K6a/071`L01XJ
6P0K6a/071`L01/K6`0J6QX06a/K00806QXJ00X06a/K01`L700K6a/06ATI01/K6`0M7Ad06a/K01`L
700M7Ad06a/K0`0L71`01@0M7Ad06a/K01`L700L71`07AdM00<071`L00@07AdM01`L700L71`07AdM
0`0L71`301dM7@8071`L00<07AdM01hN7P0M7Ad00P0M7Ad00`0L71`07AdM01dM7@0301dM7@0501hN
7P0M7Ad07alO01dM7@0N7Qh00P0M7Ad401lO7`<07QhN00<07AdM01lO7`0O7al00`0N7Qh201lO7`<0
7QhN00H07alO01dM7@0N7Qh07alO01hN7P0P820301hN7P807alO00<07QhN01lO7`0O7al00P0O7al0
1P0M7Ad07QhN01lO7`0O7al07AdM01lO7`807QhN00<07alO020P800O7al00P0O7al0100M7Ad07alO
01lO7`0N7Qh201lO7`0501hN7P0O7al07QhN01lO7`0P82000P0O7al00`0N7Qh07alO01hN7P0201hN
7P0401dM7@0N7Qh07alO01dM7@@07QhN0P0M7Ad01@0L71`07alO01dM7@0M7Ad06a/K00807QhN00L0
7AdM01hN7P0N7Qh071`L01/K6`0M7Ad07QhN00H07AdM00H071`L01dM7@0L71`07AdM01`L700M7Ad3
01`L700601/K6`0L71`071`L01`L700M7Ad06a/K0P0L71`00`0K6a/07AdM01`L700301`L700601dM
7@0L71`071`L01hN7P0L71`07AdM0P0L71`201dM7@P071`L00@06a/K01`L700J6QX071`L1P0J6QX0
0`0I6AT06QXJ01XJ6P0201/K6`806QXJ0`0I6AT201XJ6PD06ATI00H061PH01XJ6P0J6QX06a/K01XJ
6P0I6AT201XJ6P0601PH600I6AT06QXJ01TI6@0H61P06ATI0P0K6a/00`0I6AT06QXJ01XJ6P0201TI
6@806QXJ100I6AT201XJ6P0301TI6@0H61P06QXJ00H0fMWI0@0000010=WIf@005P3IfMT00`000000
fMWI0=WIf@030=WIf@<06ATI00<06QXJ01TI6@0J6QX00P0J6QX01P0I6AT06QXJ01XJ6P0J6QX06ATI
01/K6`<06ATI0P0J6QX0100I6AT06QXJ01TI6@0J6QX201TI6@0901/K6`0I6AT06QXJ01XJ6P0I6AT0
6a/K01XJ6P0I6AT06a/K00806QXJ0P0K6a/0100J6QX06a/K01XJ6P0K6a/601XJ6P806a/K00<06QXJ
01/K6`0J6QX01@0J6QX201/K6`0401XJ6P0M7Ad071`L01XJ6P<06a/K00<06QXJ01/K6`0K6a/00P0K
6a/00`0J6QX06a/K01/K6`0201`L700401/K6`0L71`071`L01dM7@8071`L00<06a/K01`L700L71`0
1@0L71`01P0M7Ad06a/K01`L700L71`07AdM01`L70<07AdM00<071`L01hN7P0L71`00P0N7Qh601dM
7@0601hN7P0M7Ad07QhN01hN7P0M7Ad07alO0P0N7Qh01P0O7al07QhN01hN7P0M7Ad07QhN01`L7080
7alO00/0820P01lO7`0M7Ad07alO01dM7@0P82007alO01hN7P0O7al07QhN01dM7@0201hN7P05020P
800N7Qh07QhN01lO7`0N7Qh00P0M7Ad00`0P82007alO01hN7P0301lO7`0301hN7P0M7Ad07alO0080
7alO100N7Qh0100M7Ad07QhN01hN7P0O7al401hN7P0501dM7@0N7Qh07alO01hN7P0O7al00`0N7Qh0
1@0M7Ad07QhN01hN7P0M7Ad07QhN00807AdM00<071`L01hN7P0M7Ad00`0N7Qh0100M7Ad07QhN01lO
7`0N7Qh501dM7@0601`L700N7Qh07QhN01/K6`0L71`07AdM0P0L71`201dM7@@071`L0P0M7Ad01`0L
71`06a/K01dM7@0M7Ad071`L01/K6`0L71`00`0M7Ad201/K6`0601`L700K6a/071`L01/K6`0L71`0
7AdM0`0L71`301dM7@0301hN7P0L71`071`L00@07AdM00H071`L01/K6`0M7Ad071`L01dM7@0L71`2
01/K6`0501XJ6P0L71`06QXJ01/K6`0J6QX0100K6a/00`0J6QX06a/K01XJ6P0201XJ6P806ATI00L0
6QXJ01TI6@0J6QX06QXJ01TI6@0J6QX06ATI00<06QXJ00H06ATI01XJ6P0I6AT06QXJ01`L700J6QX5
01TI6@<06QXJ00D06ATI01LG5`0I6AT06QXJ01TI6@0201PH60<06ATI00T061PH01TI6@0I6AT06QXJ
01PH600J6QX06ATI01XJ6P0I6AT01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0
fMWI0`0J6QX00`0I6AT06QXJ01TI6@0201TI6@0301XJ6P0H61P06QXJ00<06QXJ0P0I6AT0100K6a/0
6QXJ01XJ6P0J6QX301TI6@0301XJ6P0I6AT06QXJ00<06QXJ00/06ATI01XJ6P0J6QX06ATI01XJ6P0I
6AT06QXJ01/K6`0I6AT06QXJ01/K6`0201XJ6P0301/K6`0J6QX06a/K00@06QXJ00D06a/K01XJ6P0K
6a/06ATI01/K6`0301XJ6P0701TI6@0J6QX071`L01/K6`0L71`06a/K01`L700201/K6`0301XJ6P0K
6a/06QXJ00806QXJ00<071`L01/K6`0K6a/00P0L71`201/K6`0401XJ6P0K6a/06a/K01/K6`8071`L
00<06QXJ01`L700M7Ad00P0K6a/401`L700301/K6`0L71`071`L00<071`L00<07QhN01`L700M7Ad0
0P0M7Ad00`0L71`07QhN01hN7P0201dM7@@07QhN0`0M7Ad01@0N7Qh07AdM01hN7P0N7Qh07alO0080
7QhN00P071`L01hN7P0N7Qh07QhN01lO7`0N7Qh07alO01dM7@@07alO00@0820P01hN7P0O7al07QhN
0P0O7al00`0N7Qh07AdM01dM7@0301hN7P0301lO7`0M7Ad07QhN00807alO00L07QhN01dM7@0O7al0
7alO01dM7@0O7al071`L00807alO1P0N7Qh201dM7@0401lO7`0M7Ad07QhN01hN7P807AdM0P0N7Qh3
01lO7`0401hN7P0O7al07QhN01hN7PD07AdM00D07QhN01dM7@0M7Ad07AdM01`L700201dM7@807QhN
00/07AdM01`L700L71`07QhN01`L700M7Ad071`L01hN7P0M7Ad071`L01dM7@0201`L700301dM7@0L
71`071`L008071`L00<07AdM01/K6`0K6a/00`0M7Ad401`L700301dM7@0L71`07AdM00@071`L00<0
6QXJ01dM7@0L71`00`0M7Ad201hN7P0701lO7`0N7Qh07QhN01hN7P0M7Ad07QhN01lO7`0201hN7P04
01dM7@0L71`071`L01`L70806a/K0P0L71`0100K6a/071`L01XJ6P0J6QX201/K6`806QXJ0P0K6a/0
0`0I6AT06QXJ01XJ6P0301XJ6P0:01TI6@0J6QX06QXJ01XJ6P0K6a/06ATI01PH600I6AT06QXJ01/K
6`806ATI00@061PH01/K6`0I6AT061PH0`0I6AT01P0K6a/06ATI01TI6@0I6AT061PH01XJ6P806ATI
0P0J6QX0100I6AT061PH01TI6@0J6QX301PH60<06ATI00<061PH0=WIf@3IfMT0103IfMT100000040
fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00@06QXJ01TI6@0J6QX06ATI0`0J6QX301TI6@D0
6QXJ00<06ATI01XJ6P0J6QX00P0K6a/301XJ6P0501TI6@0J6QX06ATI01XJ6P0I6AT0100J6QX0100K
6a/06QXJ01TI6@0J6QX501/K6`0401XJ6P0I6AT06a/K01XJ6P806ATI0P0J6QX00`0I6AT06a/K01XJ
6P0201XJ6P0301/K6`0J6QX06a/K00806a/K00P071`L01/K6`0K6a/06a/K01XJ6P0K6a/06QXJ01/K
6`8071`L00D06a/K01XJ6P0K6a/071`L01XJ6P0201/K6`8071`L0P0K6a/0100M7Ad06a/K01/K6`0M
7Ad201/K6`0601dM7@0K6a/07AdM01dM7@0K6a/071`L0P0K6a/201dM7@<071`L00<07AdM01`L700M
7Ad00`0L71`00`0N7Qh071`L01dM7@0:01dM7@<07QhN00D07alO01hN7P0M7Ad07AdM01hN7P0201dM
7@@07QhN0P0O7al201hN7P807alO00H07QhN01dM7@0N7Qh07QhN01lO7`0N7Qh301dM7@<07QhN0P0M
7Ad0100L71`07AdM01dM7@0M7Ad401hN7P0401lO7`0N7Qh07AdM01hN7PD07AdM00@07alO01hN7P0M
7Ad07AdM0P0N7Qh01P0O7al07QhN01dM7@0O7al07AdM01`L70<07AdM0P0N7Qh01@0M7Ad07QhN01dM
7@0M7Ad07alO00807AdM00T071`L01dM7@0N7Qh07AdM01`L700M7Ad07QhN01dM7@0L71`00P0M7Ad2
01`L700301dM7@0L71`07AdM00807AdM0P0L71`201dM7@8071`L00D07AdM01`L700M7Ad071`L01dM
7@0201`L700501/K6`0L71`071`L01/K6`0N7Qh00`0L71`0100M7Ad06a/K01`L700L71`201dM7@07
01lO7`0N7Qh07QhN01lO7`0Q8B407alO024Q8@03020P800301hN7P0O7al07alO00807AdM00<07QhN
01dM7@0N7Qh00`0K6a/01`0J6QX06a/K01/K6`0K6a/071`L01XJ6P0K6a/0100J6QX00`0K6a/06ATI
01XJ6P0201TI6@0501XJ6P0H61P06ATI01XJ6P0I6AT0100J6QX201TI6@0301XJ6P0I6AT06QXJ0080
6ATI00<06QXJ01/K6`0I6AT00`0I6AT501XJ6P0501TI6@0K6a/06QXJ01TI6@0J6QX01`0I6AT60=WI
f@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0100J6QX061PH01PH600I6AT201XJ
6P0401TI6@0J6QX06ATI01TI6@<06QXJ00<06a/K01XJ6P0J6QX00P0I6AT02@0J6QX06ATI01TI6@0I
6AT06QXJ01TI6@0J6QX06ATI01XJ6P0201TI6@806QXJ00<06a/K01XJ6P0J6QX00`0J6QX00`0K6a/0
6QXJ01/K6`0301XJ6P0501/K6`0J6QX06QXJ01XJ6P0L71`00P0J6QX201/K6`0801XJ6P0L71`06QXJ
01/K6`0J6QX06a/K01XJ6P0M7Ad401/K6`806QXJ00<06a/K01XJ6P0I6AT02P0K6a/201`L700301/K
6`0M7Ad06a/K00806a/K0P0L71`00`0K6a/071`L01/K6`0201`L700401dM7@0L71`07AdM01/K6`80
71`L00<07AdM01`L700L71`00`0L71`00`0M7Ad07QhN01`L700201dM7@0401`L700M7Ad07AdM01dM
7@807QhN0P0M7Ad00`0L71`07QhN01hN7P0201hN7P0301dM7@0N7Qh07AdM00<07AdM00@07QhN01lO
7`0M7Ad07AdM0P0N7Qh02@0M7Ad07QhN01hN7P0N7Qh07alO01hN7P0M7Ad07alO01hN7P0201dM7@80
7QhN0`0M7Ad201hN7P807AdM0P0N7Qh201dM7@0501hN7P0M7Ad07QhN01hN7P0O7al00`0M7Ad02`0N
7Qh07AdM01hN7P0O7al071`L01dM7@0N7Qh071`L01hN7P0M7Ad071`L00807QhN00L07AdM01hN7P0N
7Qh07AdM01hN7P0M7Ad07QhN00807AdM0P0L71`0100N7Qh07AdM01hN7P0N7Qh201`L700301hN7P0L
71`071`L00<07AdM00P071`L01dM7@0K6a/071`L01dM7@0L71`06a/K01`L70806a/K0P0L71`0100J
6QX06a/K01`L700L71`201/K6``071`L00L07AdM01`L700N7Qh07AdM01lO7`0N7Qh07alO00807QhN
0P0Q8B400`0R8R80820P028R8P02024Q8@03020P800N7Qh07QhN00807AdM00L06a/K01dM7@0L71`0
6a/K01`L700K6a/071`L00806QXJ00H06a/K01XJ6P0K6a/06QXJ01/K6`0L71`201XJ6P806ATI0P0J
6QX00`0H61P06a/K01TI6@0201TI6@<06QXJ00/06ATI01XJ6P0I6AT06QXJ01TI6@0J6QX06ATI01XJ
6P0I6AT06QXJ01PH600301TI6@0301XJ6P0H61P06ATI00806ATI00@061PH01XJ6P0I6AT061PH0P0I
6AT01P0H61P06ATI01PH600I6AT05aLG01TI6@H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI
0=WIf@030=WIf@0>01TI6@0J6QX06ATI01TI6@0J6QX06ATI01XJ6P0I6AT06a/K01TI6@0J6QX06ATI
01/K6`0J6QX201TI6@0301XJ6P0I6AT06QXJ00@06QXJ0P0I6AT00`0J6QX06ATI01TI6@0301TI6@80
6QXJ00<06a/K01TI6@0K6a/00P0J6QX00`0K6a/06QXJ01/K6`0501XJ6P0801/K6`0J6QX06QXJ01XJ
6P0K6a/06QXJ01/K6`0L71`201XJ6P806a/K0P0J6QX301/K6`806QXJ00@06a/K01TI6@0L71`071`L
100K6a/00`0M7Ad06a/K01/K6`0301/K6`0301`L700K6a/06a/K00806a/K00@071`L01/K6`0L71`0
7AdM0P0K6a/301`L700501dM7@0L71`071`L01`L700M7Ad00P0L71`301dM7@0401hN7P0L71`071`L
01hN7PD07AdM00L071`L01hN7P0M7Ad07AdM01lO7`0N7Qh071`L00807AdM00D07alO01dM7@0N7Qh0
71`L01dM7@0401hN7P0301`L700M7Ad07QhN00807AdM00<07alO01hN7P0O7al00P0M7Ad01P0N7Qh0
71`L01hN7P0O7al07QhN01lO7`D07QhN00@07AdM01hN7P0M7Ad07AdM0P0O7al01@0N7Qh07alO01`L
700O7al07AdM00807QhN00@07AdM01hN7P0N7Qh07AdM0`0N7Qh01P0O7al07AdM01dM7@0M7Ad07QhN
01`L70<07AdM00/071`L01dM7@0N7Qh07AdM01hN7P0L71`07AdM01`L700M7Ad071`L01hN7P0201dM
7@0:01hN7P0M7Ad07AdM01dM7@0L71`07AdM01`L700M7Ad071`L01/K6`H071`L0`0M7Ad201XJ6P06
01dM7@0L71`071`L01/K6`0L71`07AdM0P0L71`201/K6`0701dM7@0K6a/071`L01/K6`0L71`07AdM
01`L700301dM7@0301`L700N7Qh07QhN00<07alO0P0P82001@0Q8B409BDU02DU9@0V9RH09bLW0080
9RHV0P0S8b<2020P800801hN7P0M7Ad071`L01`L700K6a/07AdM01`L700J6QX401/K6`@06QXJ00@0
61PH01XJ6P0I6AT06ATI100J6QX301TI6@0401XJ6P0I6AT06QXJ01TI6@806QXJ0P0H61P00`0J6QX0
6ATI01TI6@0501XJ6P0601TI6@0J6QX06ATI01TI6@0H61P06a/K0`0I6AT201XJ6P806ATI00<061PH
01TI6@0J6QX00P0I6AT60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT201TI
6@0301XJ6P0I6AT06QXJ00806ATI0P0J6QX201TI6@0301XJ6P0I6AT061PH00D06ATI00<06QXJ01TI
6@0J6QX00P0J6QX201TI6@0401/K6`0J6QX061PH01TI6@806QXJ00<06ATI01XJ6P0J6QX0100J6QX0
100K6a/06QXJ01TI6@0I6AT401XJ6P806a/K00<06QXJ01/K6`0J6QX01@0J6QX02@0K6a/06QXJ01/K
6`0J6QX06a/K01XJ6P0K6a/06QXJ01/K6`0301XJ6P806a/K00P06QXJ01/K6`0K6a/071`L01/K6`0L
71`06QXJ01/K6`<071`L00<06a/K01`L700L71`00P0L71`0100J6QX071`L01/K6`0L71`201dM7@@0
71`L00<06a/K01dM7@0M7Ad00P0L71`00`0M7Ad06a/K01`L700201dM7@8071`L0P0M7Ad201`L7009
01hN7P0L71`07AdM01hN7P0M7Ad07alO01/K6`0N7Qh07alO00@07AdM00T07QhN01`L700N7Qh0820P
01hN7P0O7al07AdM01hN7P0L71`00P0N7Qh201dM7@0301hN7P0M7Ad07AdM00807QhN00<07alO01hN
7P0N7Qh00`0N7Qh00`0M7Ad071`L01dM7@0301dM7@0301`L700N7Qh07AdM00807AdM00D07QhN01dM
7@0M7Ad07AdM01hN7P0201dM7@<07QhN00<07AdM01lO7`0M7Ad00P0N7Qh01@0M7Ad071`L01dM7@0O
7al07AdM00807QhN100M7Ad01@0N7Qh071`L01dM7@0M7Ad071`L00807QhN00D071`L01dM7@0K6a/0
71`L01hN7P0201dM7@0701/K6`0L71`06a/K01`L700M7Ad071`L01dM7@0201`L700501/K6`0M7Ad0
71`L01`L700K6a/00P0L71`01@0K6a/07AdM01`L700K6a/07AdM00<071`L0P0K6a/201`L70806a/K
00<071`L01/K6`0N7Qh00P0M7Ad00`0O7al07AdM01hN7P02020P800@02<S8`0U9BD09RHV02XZ:P0_
;bl0<30`02l_;`0^;Rh0:RXZ02DU9@0S8b<08B4Q020P800O7al07QhN01`L70H06a/K1P0J6QX00`0I
6AT06a/K01TI6@0301XJ6P0301/K6`0I6AT06a/K00806QXJ0P0I6AT02@0K6a/06QXJ01XJ6P0I6AT0
6a/K01XJ6P0I6AT06QXJ01`L700201TI6@806QXJ1@0I6AT0100J6QX06ATI01XJ6P0H61P501TI6@80
61PH00<06ATI01PH600I6AT01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI
0P0J6QX0100H61P06ATI01XJ6P0H61P201TI6@0>01XJ6P0K6a/06ATI01XJ6P0I6AT06QXJ01TI6@0K
6a/06ATI01XJ6P0H61P06ATI01/K6`0J6QX401TI6@0501XJ6P0I6AT06QXJ01XJ6P0K6a/00P0J6QX0
0`0K6a/06QXJ01XJ6P0201TI6@@06QXJ00<06a/K01XJ6P0J6QX00P0J6QX01P0K6a/06QXJ01XJ6P0J
6QX06ATI01/K6`@06QXJ0P0I6AT201/K6`0301XJ6P0K6a/06QXJ00<06a/K0`0J6QX0100K6a/06QXJ
01/K6`0L71`401/K6`0701dM7@0K6a/071`L01/K6`0L71`06a/K01`L700301/K6`0401`L700J6QX0
71`L01dM7@8071`L00H06a/K01`L700L71`071`L01/K6`0N7Qh301dM7@0301`L700K6a/071`L0080
7AdM0`0L71`02P0M7Ad07QhN01hN7P0N7Qh07AdM01`L700M7Ad071`L01hN7P0L71`501hN7P807AdM
00<071`L01hN7P0M7Ad00P0M7Ad201lO7`0301dM7@0N7Qh07AdM00807QhN00H07AdM01hN7P0M7Ad0
7QhN01dM7@0N7Qh201dM7@@07QhN00@07alO01hN7P0N7Qh07AdM0P0N7Qh0100M7Ad07QhN01lO7`0M
7Ad201hN7P0301dM7@0N7Qh07QhN00807AdM00@071`L01hN7P0N7Qh07AdM0P0N7Qh0100M7Ad07QhN
01dM7@0M7Ad201hN7P<07AdM00P06a/K01dM7@0L71`071`L01dM7@0L71`07AdM01hN7P<07AdM00H0
7QhN01dM7@0M7Ad071`L01dM7@0L71`201dM7@0401/K6`0L71`071`L01dM7@L071`L00<06a/K01`L
700L71`0100L71`0100M7Ad071`L01`L700K6a/301`L700301dM7@0K6a/071`L00<071`L00<07AdM
01lO7`0N7Qh00P0N7Qh0100P82008R8R02<S8`0T92@202`/;0<0=3@d00D0<30`02h^;P0X:2P08R8R
020P800201hN7P0701dM7@0L71`071`L01`L700K6a/071`L01TI6@0201/K6`806QXJ00L06a/K01XJ
6P0J6QX06QXJ01TI6@0J6QX06ATI00806QXJ0P0I6AT0100J6QX06ATI01PH600I6AT301XJ6P0501TI
6@0H61P06ATI01XJ6P0I6AT00P0J6QX0100I6AT06QXJ01XJ6P0J6QX201TI6@0301XJ6P0I6AT06ATI
00<06ATI00H06QXJ01TI6@0J6QX06QXJ01TI6@0J6QX201TI6@0301PH600I6AT06QXJ00H0fMWI0@00
00010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@806ATI0P0J6QX201TI6@0401XJ6P0I6AT0
6a/K01XJ6P806ATI0P0J6QX601TI6@806QXJ00L06a/K01TI6@0J6QX06QXJ01/K6`0J6QX06ATI00D0
6QXJ00<06ATI01XJ6P0J6QX00`0J6QX00`0H61P06QXJ01`L700201/K6`T06QXJ00`06a/K01XJ6P0I
6AT06QXJ01/K6`0J6QX06ATI01XJ6P0K6a/06QXJ01/K6`0L71`201XJ6PD06a/K00<06QXJ01/K6`0K
6a/01P0K6a/0100L71`06QXJ01/K6`0L71`201/K6`0501`L700K6a/06a/K01`L700M7Ad03@0L71`0
1@0N7Qh071`L01`L700M7Ad06a/K008071`L0P0M7Ad01P0N7Qh06a/K01dM7@0L71`07AdM01`L7080
7AdM00@071`L01dM7@0M7Ad07QhN1P0M7Ad00`0N7Qh071`L01dM7@0301dM7@0801hN7P0M7Ad07QhN
01lO7`0M7Ad07QhN01dM7@0L71`301dM7@<07QhN0P0O7al301hN7P807AdM00T07QhN01dM7@0M7Ad0
7QhN01`L700M7Ad07QhN01dM7@0N7Qh00P0M7Ad03`0L71`07QhN01hN7P0N7Qh07AdM01`L700M7Ad0
7QhN01`L700N7Qh07AdM01`L700M7Ad07QhN01/K6`0201dM7@0401`L700M7Ad07AdM01hN7P807AdM
0P0L71`00`0N7Qh071`L01dM7@0401`L700501dM7@0L71`071`L01`L700M7Ad02@0L71`401/K6`80
71`L100K6a/02@0L71`06QXJ01/K6`0M7Ad071`L01dM7@0L71`07QhN01dM7@0201hN7P0801lO7`0Q
8B408R8R02<S8`0W9bL0;Bd]030`<00i>CT203`l?00303@d=00^;Rh09bLW00808R8R00@0820P01lO
7`0N7Qh07AdM0P0L71`00`0J6QX06a/K01/K6`0301/K6`806QXJ00@06ATI01XJ6P0J6QX06ATI0P0J
6QX301TI6@0301XJ6P0I6AT06ATI00<06ATI0`0J6QX01@0K6a/06QXJ01XJ6P0I6AT06QXJ00806ATI
00D06a/K01XJ6P0I6AT06ATI01XJ6P0201TI6@@06QXJ0P0I6AT01@0J6QX06ATI01TI6@0I6AT06QXJ
008061PH0P0I6AT60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT01@0I6AT0
6QXJ01TI6@0I6AT06QXJ00D06ATI00D06QXJ01TI6@0I6AT06QXJ01TI6@0501XJ6P<06ATI1P0J6QX0
0`0I6AT06QXJ01XJ6P0201TI6@0301XJ6P0I6AT06ATI00<06QXJ00<061PH01XJ6P0J6QX00P0J6QX0
0`0I6AT06QXJ01XJ6P0601XJ6P806a/K100J6QX01P0K6a/06QXJ01/K6`0K6a/06QXJ01/K6`806QXJ
00@06a/K01XJ6P0K6a/071`L0P0K6a/0100L71`06a/K01`L700L71`201/K6`0401XJ6P0K6a/071`L
01`L70P06a/K0P0L71`00`0K6a/071`L01/K6`0301`L700501/K6`0L71`071`L01/K6`0M7Ad00P0L
71`03P0K6a/071`L01hN7P0M7Ad071`L01dM7@0N7Qh07AdM01`L700M7Ad07QhN01`L700N7Qh07AdM
0P0L71`0100N7Qh07AdM01dM7@0N7Qh301dM7@0301hN7P0M7Ad07AdM00807QhN0`0M7Ad0100N7Qh0
7AdM01hN7P0O7al401dM7@0901hN7P0M7Ad07AdM01dM7@0N7Qh07AdM01hN7P0O7al071`L00<07QhN
0P0M7Ad00`0N7Qh07AdM01dM7@0201dM7@807QhN0`0M7Ad01`0N7Qh07AdM01`L700M7Ad071`L01dM
7@0N7Qh00P0L71`01`0N7Qh07AdM01`L700M7Ad071`L01dM7@0N7Qh00P0M7Ad201`L700401hN7P0L
71`07AdM01dM7@8071`L00T07AdM01`L700L71`07AdM01`L700M7Ad071`L01dM7@0L71`01@0K6a/0
0`0M7Ad071`L01/K6`0301/K6`0501`L700M7Ad071`L01`L700M7Ad0100K6a/0100M7Ad06QXJ01`L
700L71`201/K6`0401dM7@0L71`07AdM01`L70@07QhN01408B4Q02<S8`0S8b<09bLW02d];@0b<S80
>CTi03lo?`0l?3`0=3@d02l_;`0X:2P08b<S028R8P0O7al0820P01hN7P0601`L700301/K6`0J6QX0
6ATI00H06QXJ00<06ATI01XJ6P0I6AT00P0J6QX00`0I6AT061PH01XJ6P0201XJ6P806ATI0P0J6QX3
01TI6@0301XJ6P0I6AT06ATI00806QXJ00<06ATI01XJ6P0I6AT00P0I6AT0100J6QX061PH01XJ6P0I
6AT401XJ6P<06ATI00D06QXJ01PH600I6AT061PH01TI6@060=WIf@4000000@3IfMT001H0fMWI0P00
00040=WIf@0301TI6@0H61P06ATI00<06ATI00<06QXJ01TI6@0J6QX0100I6AT00`0J6QX06ATI01XJ
6P0201XJ6P0301PH600I6AT06a/K00D06QXJ00<061PH01XJ6P0J6QX00P0J6QX0100I6AT06QXJ01XJ
6P0I6AT301XJ6P0301TI6@0J6QX06QXJ00@06QXJ0P0I6AT00`0K6a/06QXJ01XJ6P0201XJ6P806a/K
0P0J6QX0100I6AT06a/K01XJ6P0J6QX301/K6`806QXJ00H071`L01/K6`0K6a/06a/K01XJ6P0L71`2
01/K6`8071`L0`0J6QX01@0I6AT06a/K01XJ6P0K6a/071`L00<06a/K00L071`L01/K6`0K6a/071`L
01/K6`0M7Ad06a/K00<071`L00<06a/K01`L700L71`00P0L71`01`0K6a/071`L01`L700M7Ad06a/K
01`L700M7Ad01@0L71`501dM7@0401`L700N7Qh07AdM01dM7@8071`L1@0M7Ad00`0N7Qh07AdM01hN
7P0201`L70<07AdM00<07alO01`L700N7Qh00P0N7Qh201dM7@0301hN7P0M7Ad07QhN00807QhN0`0M
7Ad301hN7P<07AdM0P0N7Qh201dM7@0301/K6`0M7Ad07AdM00807AdM0P0N7Qh201dM7@0301`L700N
7Qh071`L008071`L1P0M7Ad00`0L71`07AdM01hN7P0201`L700301dM7@0N7Qh07AdM00807AdM00T0
6a/K01dM7@0L71`071`L01dM7@0L71`07AdM01`L700M7Ad00`0L71`01P0M7Ad071`L01dM7@0N7Qh0
71`L01dM7@<071`L00L06a/K01`L700K6a/071`L01/K6`0L71`06a/K008071`L00@06QXJ01/K6`0L
71`071`L0P0K6a/301`L700601dM7@0L71`07AdM01dM7@0N7Qh07AdM0P0N7Qh2020P800@02<S8`0U
9BD0:b/[02l_;`0f=SH0>3Ph03Hf=P0_;bl0:b/[02HV9P0S8b<08B4Q01lO7`0P82007QhN01dM7@<0
71`L0`0K6a/201XJ6P0:01/K6`0J6QX06QXJ01XJ6P0K6a/06QXJ01TI6@0K6a/06QXJ01TI6@@06QXJ
00<06ATI01PH600I6AT00`0J6QX201TI6@0401XJ6P0L71`06ATI01XJ6P<06ATI00@06QXJ01TI6@0I
6AT061PH100I6AT0100H61P06QXJ01XJ6P0I6AT201XJ6P@06ATI00<06QXJ01TI6@3IfMT0103IfMT2
00000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00@06ATI01PH600I6AT06ATI100J6QX2
01TI6@0301XJ6P0I6AT06ATI00806QXJ00H06ATI01XJ6P0I6AT06ATI01XJ6P0K6a/201XJ6P0301/K
6`0I6AT06QXJ00<06ATI0`0J6QX00`0I6AT06QXJ01XJ6P0201TI6@0701/K6`0J6QX06QXJ01TI6@0H
61P06QXJ01/K6`0401XJ6P0501TI6@0J6QX06QXJ01/K6`0I6AT00P0K6a/0100I6AT06QXJ01/K6`0L
71`301/K6`0501XJ6P0K6a/06a/K01XJ6P0K6a/00P0J6QX01`0L71`06QXJ01/K6`0K6a/06QXJ01TI
6@0L71`00`0K6a/00`0J6QX071`L01`L700201/K6`8071`L00@06a/K01`L700L71`06a/K0P0L71`0
200K6a/071`L01`L700L71`06a/K01dM7@0L71`07AdM0P0L71`01@0M7Ad06a/K01`L700L71`06a/K
00<071`L0P0M7Ad00`0L71`07AdM01dM7@0201`L700501hN7P0M7Ad07AdM01hN7P0L71`01@0M7Ad0
1@0L71`07AdM01dM7@0L71`07QhN00807AdM00@07QhN01`L700M7Ad07QhN0`0M7Ad201hN7P0401`L
700N7Qh07AdM01hN7PD07AdM00<07QhN01dM7@0N7Qh00P0N7Qh01@0L71`07AdM01hN7P0N7Qh071`L
00807AdM00D07QhN01`L700M7Ad07AdM01`L700201dM7@0401`L700M7Ad07AdM01hN7P8071`L00D0
7AdM01`L700L71`071`L01/K6`0201`L700601dM7@0L71`07AdM01`L700N7Qh07AdM0P0L71`0100N
7Qh071`L01`L700K6a/201dM7@0301`L700M7Ad071`L008071`L00@06a/K01dM7@0K6a/06a/K0P0M
7Ad201`L700501dM7@0K6a/071`L01/K6`0J6QX0100L71`01@0M7Ad06QXJ01dM7@0L71`06QXJ00<0
71`L00<06a/K01`L700K6a/00P0L71`201dM7@8071`L0`0N7Qh02`0Q8B408R8R02<S8`0X:2P0:RXZ
02`/;00];Bd0;2`/02TY:@0W9bL092@T0080820P0P0O7al01`0N7Qh07AdM01`L700L71`06a/K01`L
700I6AT00P0K6a/201TI6@0401/K6`0J6QX06ATI01TI6@<06QXJ00D06ATI01PH600J6QX06ATI01PH
600201TI6@806QXJ0P0I6AT01@0J6QX061PH01/K6`0K6a/06ATI00806QXJ0P0I6AT201XJ6P0301TI
6@0J6QX06QXJ00806ATI0`0J6QX01@0I6AT06QXJ01TI6@0J6QX061PH00806ATI0`0H61P00`0I6AT0
fMWI0=WIf@040=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0100J6QX06ATI
01PH600I6AT201XJ6P0301TI6@0J6QX061PH00806ATI00`06QXJ01PH600J6QX06ATI01/K6`0I6AT0
6QXJ01TI6@0K6a/06QXJ01/K6`0I6AT301XJ6P806ATI00D06a/K01TI6@0J6QX06QXJ01TI6@0301XJ
6P<06ATI0`0J6QX0100I6AT06QXJ01TI6@0I6AT301XJ6P0301PH600J6QX05aLG00806QXJ00<06a/K
01XJ6P0I6AT01`0J6QX201/K6`0301XJ6P0K6a/071`L00806QXJ00H071`L01/K6`0K6a/06a/K01`L
700J6QX201/K6`0301`L700K6a/071`L008071`L00<06a/K01`L700K6a/00P0L71`401/K6`<071`L
00H06a/K01XJ6P0M7Ad07QhN01XJ6P0K6a/301`L700401dM7@0L71`071`L01dM7@8071`L00H07AdM
01/K6`0N7Qh071`L01dM7@0L71`301dM7@807QhN0P0M7Ad201`L700301hN7P0M7Ad071`L00807AdM
00<071`L01dM7@0L71`00P0M7Ad00`0P820071`L01hN7P0201hN7P@07AdM00<07alO01hN7P0M7Ad0
0P0M7Ad00`0L71`07AdM01`L700201`L70807AdM00<07QhN01`L700M7Ad0100M7Ad00`0N7Qh071`L
01hN7P0301dM7@0501`L700M7Ad07QhN01lO7`0L71`00P0M7Ad01`0N7Qh071`L01`L700M7Ad071`L
01hN7P0L71`00P0M7Ad00`0L71`07QhN01hN7P0201`L700601dM7@0K6a/07QhN01/K6`0L71`07AdM
0P0L71`01@0N7Qh07AdM01dM7@0L71`07AdM00806a/K00H071`L01dM7@0L71`06a/K01`L700K6a/2
01dM7@0401`L700M7Ad06a/K01/K6`D071`L1@0K6a/501`L700301dM7@0L71`06a/K00807AdM0P0N
7Qh02`0P82008B4Q028R8P0R8R80:BTY02PX:00Y:BT0:2PX02DU9@0V9RH08b<S0080820P00T07QhN
01`L700N7Qh071`L01dM7@0K6a/071`L01/K6`0J6QX00P0K6a/301XJ6P0301TI6@0J6QX06ATI0080
6QXJ00<06ATI01XJ6P0I6AT00P0K6a/301XJ6P<06ATI0P0J6QX00`0I6AT06a/K01XJ6P0201TI6@03
01XJ6P0H61P06ATI00<06QXJ0P0I6AT0100J6QX06ATI01XJ6P0H61P201TI6@0301XJ6P0I6AT06ATI
00806ATI0P0H61P00`0J6QX061PH01XJ6P060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`0I6AT06QXJ01TI6@0201TI6@806QXJ1@0I6AT501XJ6P0=01/K6`0I6AT06QXJ01TI
6@0J6QX061PH01XJ6P0K6a/061PH01XJ6P0I6AT06QXJ01TI6@0401XJ6P0401/K6`0I6AT06ATI01PH
60806QXJ100I6AT00`0K6a/06ATI01XJ6P0301/K6`0701TI6@0J6QX06QXJ01XJ6P0K6a/06QXJ01/K
6`0301XJ6P806a/K0`0J6QX201/K6`0301XJ6P0I6AT06a/K00<06a/K00<06QXJ01`L700K6a/00`0K
6a/02P0J6QX06a/K01/K6`0J6QX071`L01TI6@0K6a/071`L01XJ6P0K6a/501`L700=01/K6`0L71`0
71`L01`L700K6a/071`L01XJ6P0K6a/071`L01dM7@0K6a/071`L01/K6`0201`L700701dM7@0L71`0
7AdM01hN7P0K6a/071`L01dM7@0201`L70<07AdM00<06a/K01hN7P0L71`00`0M7Ad201hN7P<07AdM
0P0N7Qh0200M7Ad071`L01dM7@0M7Ad07QhN01`L700M7Ad071`L0`0N7Qh0100M7Ad07QhN01hN7P0L
71`201dM7@0401hN7P0M7Ad071`L01`L70807AdM00<071`L01hN7P0L71`00P0M7Ad01@0L71`07AdM
01hN7P0M7Ad071`L00<07AdM00<07QhN01lO7`0M7Ad03@0M7Ad00`0L71`07QhN01dM7@0301dM7@0B
01`L700M7Ad07AdM01dM7@0K6a/071`L01XJ6P0L71`06a/K01`L700M7Ad071`L01/K6`0L71`06a/K
01`L700M7Ad071`L0`0K6a/0200L71`06a/K01/K6`0L71`06a/K01dM7@0K6a/06QXJ0P0K6a/01@0L
71`06a/K01/K6`0L71`06QXJ00<06a/K00L071`L01/K6`0K6a/071`L01dM7@0K6a/07AdM008071`L
00D07alO01hN7P0O7al0820P024Q8@03028R8P0301lO7`0R8R808R8R00@07QhN00H071`L01dM7@0K
6a/06a/K01`L700J6QX301/K6`806QXJ00<06a/K01XJ6P0J6QX02@0J6QX02@0I6AT06QXJ01/K6`0J
6QX06ATI01/K6`0I6AT061PH01/K6`0301TI6@806QXJ00<06a/K01TI6@0J6QX00`0I6AT01P0J6QX0
61PH01TI6@0J6QX06ATI01XJ6P806ATI0P0H61P0100K6a/06QXJ01PH600H61P201TI6@H0fMWI0@00
00010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@H06ATI0P0J6QX0100I6AT06QXJ01TI6@0J
6QX201TI6@@06QXJ0P0I6AT401XJ6P806ATI00<06QXJ01/K6`0I6AT00P0I6AT201XJ6P0401TI6@0J
6QX06ATI01PH60806ATI00<06QXJ01TI6@0I6AT00P0J6QX0100H61P06QXJ01/K6`0J6QX301TI6@<0
6QXJ00@06a/K01XJ6P0K6a/06QXJ0P0K6a/00`0J6QX071`L01TI6@0201/K6`806QXJ0P0K6a/501XJ
6P@06a/K00D06QXJ01/K6`0J6QX06a/K01dM7@0201XJ6P806a/K00L06QXJ01`L700K6a/06a/K01`L
700K6a/071`L00@06a/K100L71`00`0N7Qh06a/K01`L700601`L700301dM7@0L71`071`L00D071`L
00P06a/K01dM7@0L71`071`L01dM7@0N7Qh07AdM01`L70<07AdM00<071`L01dM7@0M7Ad00P0L71`0
200M7Ad071`L01dM7@0N7Qh07AdM01hN7P0M7Ad07QhN0P0L71`401dM7@0301`L700M7Ad07QhN00@0
7AdM00@071`L01dM7@0M7Ad07AdM0`0L71`01@0M7Ad071`L01dM7@0M7Ad071`L00807AdM00<07QhN
01dM7@0L71`00`0M7Ad02@0L71`07AdM01/K6`0M7Ad071`L01/K6`0M7Ad06a/K01dM7@0201`L7004
01dM7@0L71`07AdM01dM7@8071`L00<07AdM01`L700L71`00`0L71`00`0M7Ad06a/K01`L700201`L
700301/K6`0J6QX06a/K008071`L0P0J6QX201/K6`0301`L700K6a/06a/K00@06a/K00<06QXJ01`L
700J6QX00`0L71`301/K6`0801`L700M7Ad06QXJ01dM7@0K6a/07AdM01`L700K6a/301`L700301dM
7@0L71`07alO00<07alO00<07QhN01dM7@0O7al00P0O7al0200M7Ad07QhN01`L700M7Ad071`L01/K
6`0M7Ad071`L0P0K6a/01P0J6QX06a/K01/K6`0K6a/06QXJ01/K6`806QXJ00<06a/K01TI6@0K6a/0
1P0J6QX301TI6@0401/K6`0H61P06ATI01XJ6P<06ATI00D06QXJ01TI6@0I6AT06ATI01/K6`0201TI
6@806QXJ00/06ATI01PH600H61P06QXJ01TI6@0J6QX06ATI01PH600J6QX061PH01TI6@0301PH6003
01TI6@0H61P061PH00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@@06ATI
00@06QXJ01TI6@0H61P06a/K0`0J6QX301TI6@0901XJ6P0I6AT06QXJ01XJ6P0K6a/06QXJ01TI6@0J
6QX06ATI00@06QXJ0P0I6AT00`0J6QX06ATI01TI6@0201XJ6P0401TI6@0J6QX06QXJ01TI6@806QXJ
0P0I6AT201XJ6P0401TI6@0J6QX06QXJ01TI6@D06QXJ00@06a/K01TI6@0I6AT06ATI0`0J6QX00`0K
6a/06QXJ01/K6`0201/K6`0401XJ6P0K6a/06a/K01/K6`806QXJ00@06a/K01XJ6P0K6a/06QXJ1P0K
6a/00`0L71`06QXJ01/K6`0501/K6`8071`L00D06QXJ01`L700K6a/06a/K01dM7@0301/K6`L071`L
0`0K6a/00`0L71`07AdM01`L700201/K6`8071`L00D07AdM01/K6`0M7Ad06a/K01`L700201dM7@06
01`L700M7Ad07AdM01dM7@0L71`07QhN0`0L71`01`0K6a/07AdM01hN7P0M7Ad06a/K01`L700N7Qh0
0`0M7Ad00`0L71`07AdM01dM7@0401dM7@0401`L700M7Ad07QhN01dM7@806a/K00<07AdM01`L700M
7Ad00P0M7Ad501`L700601/K6`0M7Ad07AdM01hN7P0L71`07QhN100M7Ad0100L71`06a/K01`L700K
6a/201`L700601dM7@0L71`071`L01dM7@0L71`06a/K0`0L71`201dM7@0<01`L700M7Ad071`L01`L
700M7Ad071`L01dM7@0L71`07AdM01/K6`0L71`07AdM0P0K6a/0200L71`06a/K01`L700L71`07AdM
01/K6`0L71`06a/K0`0L71`00`0J6QX06a/K01/K6`0801/K6`0401`L700K6a/06a/K01/K6`L071`L
0`0M7Ad00`0L71`07alO01hN7P0301hN7P0401dM7@0N7Qh07AdM01`L70807QhN0`0L71`01@0K6a/0
6ATI01`L700K6a/071`L00806QXJ00@071`L01XJ6P0J6QX06a/K100J6QX0100I6AT06QXJ01XJ6P0I
6AT201XJ6P0301TI6@0J6QX06ATI00806QXJ00<06ATI01XJ6P0I6AT00P0J6QX301TI6@0<01XJ6P0I
6AT06QXJ01XJ6P0I6AT061PH01TI6@0H61P06ATI01XJ6P0I6AT061PH1@0I6AT01P0J6QX06ATI01TI
6@0H61P06QXJ01PH60H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0501TI
6@0H61P06ATI01XJ6P0I6AT00P0J6QX0100I6AT06a/K01TI6@0J6QX401TI6@D06QXJ0P0K6a/01`0J
6QX06ATI01XJ6P0H61P06QXJ01/K6`0J6QX00P0I6AT00`0J6QX06ATI01XJ6P0201TI6@@06QXJ0P0I
6AT601XJ6P0401TI6@0J6QX06a/K01TI6@806QXJ0P0K6a/401XJ6P806a/K00<06ATI01/K6`0I6AT0
0P0L71`00`0J6QX06a/K01/K6`0201XJ6P0301/K6`0J6QX06a/K00806a/K0P0J6QX00`0L71`06QXJ
01/K6`0201/K6`0501XJ6P0L71`06a/K01`L700J6QX01@0K6a/0200L71`06a/K01/K6`0K6a/071`L
01/K6`0L71`06a/K0`0L71`201/K6`0401`L700M7Ad071`L01dM7@8071`L00<07AdM01hN7P0L71`0
0P0L71`01@0M7Ad071`L01`L700L71`06a/K00P07AdM00<07QhN01dM7@0M7Ad00`0L71`02@0M7Ad0
71`L01`L700L71`07QhN01dM7@0L71`07AdM01`L700201dM7@<071`L00@07QhN01`L700N7Qh07AdM
0P0L71`0100M7Ad071`L01`L700L71`301dM7@0401`L700M7Ad07AdM01dM7@8071`L00D07QhN01`L
700M7Ad07QhN01dM7@0201`L700401dM7@0L71`071`L01hN7P<07AdM00L06a/K01`L700K6a/071`L
01hN7P0L71`06a/K00<071`L00L07QhN01`L700L71`06a/K01dM7@0K6a/07AdM00@071`L0`0K6a/2
01`L700301/K6`0L71`06QXJ00806a/K00D07AdM01/K6`0K6a/06ATI01`L700201/K6`0401`L700J
6QX06QXJ01`L70H06a/K00<06QXJ01`L700K6a/00P0K6a/201`L700301/K6`0L71`06a/K008071`L
00@07AdM01hN7P0M7Ad071`L0P0M7Ad01@0L71`06a/K01`L700L71`06a/K008071`L00@06QXJ01/K
6`0J6QX071`L0P0K6a/201XJ6P@06a/K0`0J6QX01@0I6AT06QXJ01XJ6P0J6QX06ATI00806QXJ00@0
6ATI01/K6`0I6AT06QXJ0`0I6AT201XJ6PD06ATI00<06QXJ01PH600H61P0100H61P01@0I6AT061PH
01TI6@0I6AT061PH00806ATI00L06QXJ01PH600I6AT06ATI01XJ6P0H61P06QXJ00H0fMWI0@000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0401XJ6P0I6AT06ATI01TI6@806QXJ0`0I6AT2
01XJ6P806ATI00<06QXJ01TI6@0K6a/01@0J6QX01@0I6AT06a/K01XJ6P0I6AT061PH00D06ATI00D0
6QXJ01PH600J6QX061PH01XJ6P0201TI6@@06QXJ00<06ATI01XJ6P0I6AT00`0I6AT00`0J6QX06ATI
01/K6`0201XJ6P<06ATI0`0J6QX201/K6`0301`L700I6AT06ATI00806a/K00@06QXJ01/K6`0I6AT0
6a/K0P0I6AT201XJ6P806a/K00<071`L01XJ6P0J6QX00P0K6a/0100J6QX06a/K01XJ6P0L71`301/K
6`8071`L0P0K6a/01`0J6QX071`L01/K6`0K6a/071`L01dM7@0L71`00`0K6a/01@0L71`07AdM01dM
7@0M7Ad071`L00806a/K00H07AdM01`L700L71`071`L01dM7@0K6a/301`L70807AdM0P0L71`301dM
7@0:01hN7P0M7Ad071`L01`L700N7Qh07AdM01/K6`0M7Ad071`L01/K6`807AdM0P0L71`00`0M7Ad0
6a/K01dM7@0201`L700301dM7@0L71`07AdM008071`L00<07AdM01`L700M7Ad0100L71`02P0M7Ad0
71`L01`L700L71`07AdM01`L700K6a/07QhN01dM7@0L71`201dM7@8071`L00@07AdM01`L700M7Ad0
7AdM1@0L71`00`0M7Ad071`L01/K6`0301dM7@8071`L00<07AdM01`L700L71`0200L71`301dM7@D0
71`L00H06a/K01dM7@0K6a/06a/K01XJ6P0K6a/201XJ6P0301`L700J6QX071`L00H06a/K00H06QXJ
01`L700K6a/06QXJ01/K6`0L71`201XJ6P<06a/K00/07AdM01XJ6P0L71`06a/K01`L700K6a/071`L
01/K6`0M7Ad06a/K01`L700201dM7@0601`L700M7Ad071`L01`L700M7Ad071`L0`0K6a/0100L71`0
6QXJ01/K6`0J6QX301/K6`0401`L700K6a/06a/K01XJ6P@06a/K1@0J6QX201TI6@0401XJ6P0K6a/0
6QXJ01TI6@D06QXJ0P0I6AT301XJ6P<06ATI00<06QXJ01TI6@0I6AT00P0I6AT301PH600901TI6@0H
61P061PH01XJ6P0H61P06ATI01PH600I6AT06QXJ008061PH1P3IfMT100000040fMWI000F0=WIf@03
0000003IfMT0fMWI00<0fMWI0P0I6AT00`0J6QX061PH01/K6`0201TI6@0301XJ6P0I6AT061PH00<0
6QXJ00D06ATI01PH600J6QX06ATI01XJ6P0301TI6@0501XJ6P0I6AT061PH01PH600J6QX00`0I6AT2
01XJ6P0501TI6@0G5aL06QXJ01TI6@0K6a/00P0I6AT701XJ6P0301TI6@0J6QX06QXJ00806QXJ0P0K
6a/0100I6AT06QXJ01/K6`0K6a/601XJ6P806ATI00<06QXJ01/K6`0J6QX0100J6QX00`0L71`06a/K
01TI6@0301XJ6P0301/K6`0J6QX06a/K00<06QXJ00H06ATI01XJ6P0L71`06a/K01`L700J6QX401/K
6`0401XJ6P0K6a/06a/K01dM7@806a/K00@071`L01XJ6P0K6a/06a/K1@0L71`01@0K6a/071`L01`L
700L71`07AdM008071`L00<07AdM01/K6`0L71`01@0L71`00`0K6a/071`L01/K6`0201dM7@0301`L
700M7Ad07AdM00@071`L00<07AdM01`L700M7Ad00P0M7Ad0100L71`07QhN01hN7P0L71`401dM7@80
71`L00/06a/K01`L700L71`07AdM01`L700M7Ad071`L01dM7@0N7Qh071`L01dM7@0601`L700301/K
6`0L71`071`L00807AdM00H071`L01dM7@0L71`07AdM01`L700K6a/301`L70<07AdM00P07QhN01`L
700K6a/07AdM01`L700K6a/071`L01XJ6P807AdM00@071`L01dM7@0M7Ad07AdM100L71`00`0K6a/0
7QhN01XJ6P0301/K6`0301`L700K6a/06a/K008071`L0P0K6a/201`L700301XJ6P0K6a/06a/K00<0
6a/K0P0L71`401/K6`0701XJ6P0L71`071`L01XJ6P0K6a/06QXJ01`L700201/K6`0301XJ6P0K6a/0
71`L008071`L0`0K6a/401`L700301dM7@0L71`06a/K00@06a/K0P0J6QX00`0K6a/06QXJ01XJ6P02
01/K6`0301XJ6P0K6a/06a/K00806a/K0`0J6QX00`0I6AT06QXJ01TI6@0201XJ6P806a/K00D06QXJ
01TI6@0J6QX06a/K01XJ6P0401TI6@0501XJ6P0I6AT06ATI01TI6@0L71`00P0J6QX00`0I6AT06QXJ
01TI6@0201TI6@0301PH600I6AT06ATI00806ATI0P0H61P301TI6@806QXJ0P0I6AT60=WIf@400000
0@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT00`0J6QX06ATI01TI6@0201XJ6P0301TI6@0J
6QX06ATI00806ATI00H06QXJ01TI6@0J6QX06QXJ01TI6@0J6QX201TI6@0401XJ6P0I6AT06ATI01XJ
6P<06ATI00<06QXJ01TI6@0I6AT00P0J6QX00`0I6AT06QXJ01TI6@0201TI6@0301XJ6P0I6AT06QXJ
00806ATI0P0J6QX201TI6@0601XJ6P0I6AT06ATI01/K6`0J6QX06ATI0P0J6QX0100I6AT06QXJ01XJ
6P0J6QX201TI6@0301XJ6P0H61P06QXJ00@06QXJ0P0K6a/00`0J6QX06ATI01XJ6P0201/K6`0401XJ
6P0I6AT06QXJ01XJ6P806ATI0P0K6a/02P0J6QX06a/K01XJ6P0J6QX06a/K01XJ6P0K6a/06QXJ01`L
700K6a/201XJ6P<06a/K00<071`L01/K6`0L71`00`0K6a/00`0J6QX071`L01`L700301`L700501TI
6@0M7Ad06a/K01dM7@0L71`00P0M7Ad201`L70806a/K0P0L71`0100M7Ad06a/K01dM7@0K6a/201`L
700301dM7@0L71`07AdM00<071`L00D06a/K01dM7@0L71`07QhN01dM7@0601`L700701/K6`0L71`0
7AdM01`L700M7Ad071`L01hN7P0201`L700301dM7@0L71`071`L00<071`L00<07AdM01`L700L71`0
1@0L71`201dM7@0301/K6`0M7Ad071`L00<071`L00@07AdM01/K6`0K6a/07AdM0P0L71`401/K6`80
71`L00D07AdM01`L700L71`071`L01/K6`0301`L700401/K6`0L71`071`L01hN7P<07AdM0P0L71`0
4`0M7Ad071`L01/K6`0K6a/07AdM01`L700K6a/071`L01dM7@0J6QX06a/K01`L700J6QX071`L01XJ
6P0K6a/06QXJ01/K6`0J6QX00`0K6a/201XJ6PD06a/K00X06QXJ01/K6`0K6a/06a/K01`L700K6a/0
71`L01dM7@0K6a/06QXJ0`0K6a/201`L700301XJ6P0L71`06a/K00806a/K00<06QXJ01`L700K6a/0
100K6a/201XJ6P0701/K6`0J6QX06a/K01/K6`0I6AT06QXJ01/K6`0201XJ6P0501/K6`0J6QX06QXJ
01TI6@0K6a/00P0J6QX201TI6@0401XJ6P0I6AT06ATI01XJ6P<06ATI0`0J6QX201TI6@806QXJ0P0I
6AT00`0H61P06ATI01TI6@0201TI6@0901PH600I6AT061PH01TI6@0J6QX06ATI01PH600I6AT06QXJ
00<06ATI00<061PH01TI6@3IfMT01@3IfMT100000040fMWI00030=WIf@<000000P3IfMT2000000@0
fMWI0P0000060=WIf@030000003IfMT0fMWI00<0fMWI0P0I6AT00`0K6a/061PH01XJ6P0501TI6@@0
6QXJ00D06ATI01XJ6P0I6AT06QXJ01/K6`0401XJ6P0601/K6`0I6AT06QXJ01XJ6P0K6a/061PH0`0I
6AT01P0J6QX06ATI01XJ6P0J6QX06ATI01XJ6P806ATI00<06a/K01XJ6P0J6QX00`0J6QX201TI6@@0
6QXJ00<06a/K01XJ6P0J6QX00P0J6QX0100K6a/06ATI01TI6@0I6AT301XJ6P806a/K0`0J6QX00`0I
6AT06a/K01/K6`0201/K6`H06QXJ200K6a/00`0J6QX06a/K01/K6`0301XJ6P@06a/K00h071`L01/K
6`0K6a/071`L01/K6`0L71`06QXJ01`L700K6a/071`L01dM7@0K6a/07AdM01/K6`L071`L00d06a/K
01hN7P0L71`07AdM01`L700M7Ad071`L01dM7@0K6a/07AdM01`L700M7Ad06a/K00807AdM00H06a/K
01`L700L71`07AdM01`L700K6a/301`L700601dM7@0L71`06a/K01dM7@0L71`07QhN0P0M7Ad00`0L
71`07AdM01`L700201`L700301/K6`0L71`071`L00L071`L00P06a/K01`L700L71`071`L01/K6`0M
7Ad071`L01dM7@<071`L00<06a/K01`L700L71`00P0L71`0100K6a/071`L01/K6`0K6a/501`L7004
01dM7@0K6a/07AdM01dM7@8071`L00<07AdM01hN7P0M7Ad00`0N7Qh01@0M7Ad071`L01`L700L71`0
6a/K00806QXJ0P0K6a/201`L700701XJ6P0K6a/071`L01XJ6P0L71`06QXJ01/K6`0201XJ6P0301/K
6`0J6QX06QXJ00<06a/K00<06QXJ01/K6`0K6a/00`0K6a/00`0J6QX06ATI01/K6`0301XJ6P0<01`L
700K6a/06a/K01`L700K6a/06QXJ01`L700J6QX06ATI01/K6`0J6QX06a/K0P0J6QX01@0K6a/06QXJ
01XJ6P0L71`06a/K00806QXJ00<061PH01/K6`0I6AT00P0J6QX01`0K6a/06QXJ01XJ6P0J6QX06a/K
01XJ6P0I6AT00P0J6QX401TI6@806QXJ00<06a/K01TI6@0J6QX00P0I6AT0300J6QX06a/K01XJ6P0K
6a/06ATI01PH600K6a/06QXJ01TI6@0J6QX06ATI01PH60806ATI00@061PH01TI6@0I6AT061PH0P0I
6AT01`0K6a/06ATI01TI6@0I6AT061PH01TI6@0H61P01P3IfMT100000040fMWI00040=WIf@040000
003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@030=WI
f@030000003IfMT0fMWI00<0fMWI0`0H61P501TI6@0401PH600J6QX06QXJ01TI6@806QXJ100I6AT0
100K6a/06ATI01TI6@0I6AT201XJ6P<06ATI00@061PH01TI6@0I6AT06QXJ0P0I6AT00`0H61P06ATI
01TI6@0301XJ6P@06ATI0P0J6QX00`0I6AT06QXJ01XJ6P0201XJ6P0501/K6`0I6AT06ATI01XJ6P0I
6AT0200J6QX201/K6`0301XJ6P0I6AT06QXJ00@06QXJ0P0K6a/00`0L71`06a/K01XJ6P0201`L7080
6QXJ0`0K6a/201XJ6P<06a/K00@06QXJ01/K6`0K6a/06QXJ0`0K6a/00`0J6QX06a/K01`L700401/K
6`8071`L00<06a/K01`L700K6a/00P0L71`201/K6`8071`L00<07AdM01`L700K6a/00P0L71`00`0K
6a/071`L01/K6`0201/K6`0401`L700M7Ad071`L01dM7@8071`L00@07AdM01`L700L71`071`L0P0M
7Ad01`0L71`07AdM01`L700K6a/071`L01hN7P0L71`00P0K6a/0100L71`07AdM01dM7@0K6a/301`L
70<07AdM0P0L71`0100M7Ad071`L01/K6`0K6a/201`L700401dM7@0L71`07AdM01dM7@8071`L0140
7AdM01`L700K6a/06a/K01`L700M7Ad071`L01/K6`0L71`06QXJ01/K6`0M7Ad06a/K01`L700K6a/0
6QXJ01dM7@0601`L700=01/K6`0L71`06a/K01/K6`0M7Ad071`L01lO7`0Q8B408R8R02<S8`0Q8B40
7QhN01`L700401/K6`0301`L700K6a/06a/K00<06a/K0P0J6QX201/K6`0901XJ6P0K6a/06a/K01`L
700J6QX06a/K01XJ6P0L71`06QXJ00@06a/K00@06QXJ01`L700J6QX071`L1@0K6a/00`0J6QX071`L
01XJ6P0201/K6`0301`L700I6AT06a/K00806ATI00<06a/K01TI6@0K6a/01@0J6QX201/K6`<06QXJ
00@06ATI01/K6`0J6QX071`L0`0J6QX00`0H61P06QXJ01/K6`0201XJ6P0401/K6`0I6AT06QXJ01TI
6@D06QXJ00@06ATI01XJ6P0H61P06QXJ0P0I6AT00`0J6QX06ATI01/K6`0201XJ6P0601PH600J6QX0
61PH01TI6@0H61P06ATI0P0H61P00`0I6AT06QXJ01TI6@0301TI6@0401PH600I6AT061PH01XJ6PH0
fMWI0@0000010=WIf@0000<0fMWI0000000000000`0000001@3IfMT000000=WIf@3IfMT000000080
fMWI00@000000=WIf@3IfMT000001@3IfMT3000000<0fMWI00X06ATI01PH600I6AT06ATI01XJ6P0H
61P06QXJ01PH600I6AT061PH0P0I6AT0100J6QX06ATI01TI6@0I6AT201XJ6P806ATI0P0J6QX401TI
6@0701PH600I6AT06ATI01XJ6P0I6AT06QXJ01TI6@0401XJ6P0901TI6@0J6QX06QXJ01XJ6P0I6AT0
61PH01TI6@0K6a/06ATI00806QXJ00<06a/K01XJ6P0J6QX00P0J6QX00`0K6a/061PH01TI6@0201/K
6`0601XJ6P0K6a/06QXJ01TI6@0J6QX06ATI0`0J6QX00`0I6AT06a/K01XJ6P0201/K6`0601XJ6P0K
6a/06QXJ01/K6`0J6QX06a/K0`0J6QX201TI6@@06a/K00<06QXJ01/K6`0J6QX00P0K6a/01`0J6QX0
6a/K01/K6`0K6a/071`L01/K6`0J6QX0100K6a/01@0L71`06a/K01/K6`0L71`06a/K008071`L00L0
6a/K01dM7@0K6a/071`L01/K6`0J6QX07AdM008071`L00<07AdM01`L700L71`00P0L71`0200M7Ad0
6a/K01dM7@0M7Ad071`L01dM7@0L71`07AdM100L71`02@0K6a/071`L01`L700M7Ad071`L01dM7@0K
6a/071`L01dM7@0201`L700301dM7@0N7Qh07AdM008071`L00P06a/K01`L700K6a/06a/K01`L700K
6a/071`L01/K6`8071`L00<06a/K01`L700L71`01P0L71`0100K6a/071`L01`L700J6QX401`L7003
01/K6`0L71`06a/K00@071`L00P06a/K01`L700K6a/071`L01/K6`0L71`06a/K01dM7@8071`L0180
7AdM020P800Q8B409bLW02/[:`0_;bl09bLW028R8P0L71`06QXJ01`L700K6a/06QXJ01/K6`0L71`0
6QXJ01`L700K6a/201`L70<06QXJ00H071`L01XJ6P0J6QX06QXJ01/K6`0L71`301/K6`0701XJ6P0K
6a/06a/K01XJ6P0K6a/06QXJ01TI6@0201/K6`0401TI6@0K6a/06QXJ01XJ6P806a/K00P06QXJ01/K
6`0K6a/06QXJ01TI6@0K6a/06QXJ01PH60@06QXJ00<06ATI01/K6`0J6QX00`0K6a/01P0J6QX06a/K
01XJ6P0I6AT06QXJ01/K6`<06QXJ0P0I6AT201XJ6P0801/K6`0I6AT06QXJ01/K6`0J6QX06a/K01TI
6@0J6QX301/K6`0401TI6@0J6QX06ATI01/K6`<06ATI00<06QXJ01PH600J6QX00`0I6AT00`0J6QX0
6ATI01PH600301TI6@0401PH600I6AT06ATI01XJ6P806ATI00@06QXJ01TI6@0I6AT061PH103IfMT3
00000040fMWI00001@3IfMT000000=WIf@3IfMT000000080fMWI00@000000=WIf@3IfMT000000P3I
fMT010000000fMWI0=WIf@0000050=WIf@030000003IfMT0fMWI00<0fMWI100I6AT201XJ6P0601TI
6@0H61P06ATI01PH600I6AT06QXJ0P0I6AT00`0J6QX061PH01TI6@0201XJ6P<06ATI00@06QXJ01TI
6@0J6QX06QXJ0P0I6AT0200H61P06ATI01PH600H61P06ATI01/K6`0J6QX061PH1P0I6AT01`0J6QX0
6a/K01TI6@0J6QX06a/K01TI6@0J6QX00P0I6AT01@0H61P06QXJ01TI6@0J6QX06ATI00806QXJ00`0
6ATI01XJ6P0J6QX06a/K01XJ6P0I6AT06a/K01TI6@0K6a/06QXJ01/K6`0I6AT301XJ6P806a/K0`0L
71`00`0I6AT06a/K01/K6`0201XJ6PH06a/K00D071`L01XJ6P0K6a/06a/K01XJ6P0201/K6`0301`L
700J6QX071`L00L06a/K00@071`L01/K6`0K6a/06a/K1`0L71`0100K6a/071`L01/K6`0K6a/201`L
700401/K6`0M7Ad071`L01/K6`8071`L00<07AdM01`L700M7Ad01@0L71`301dM7@0301`L700M7Ad0
6a/K00<071`L00<06a/K01dM7@0M7Ad00P0L71`01@0M7Ad071`L01`L700L71`06a/K008071`L00@0
6a/K01`L700K6a/07AdM0P0L71`00`0K6a/071`L01`L700201`L700501/K6`0M7Ad07QhN01`L700N
7Qh00P0K6a/00`0L71`06a/K01dM7@0301`L700501dM7@0L71`07AdM01`L700K6a/00P0M7Ad0100L
71`06a/K01`L700L71`201dM7@0:01`L700M7Ad07alO02<S8`0^;Rh0<S8b034a<@0Y:BT08b<S01dM
7@8071`L00D06a/K01`L700L71`06a/K01`L700301/K6`806QXJ00@06a/K01XJ6P0K6a/06a/K0`0J
6QX701/K6`806QXJ0P0K6a/201XJ6P0301/K6`0J6QX06a/K00806a/K00X06ATI01XJ6P0K6a/06QXJ
01/K6`0I6AT06QXJ01/K6`0J6QX06a/K100J6QX201TI6@H06QXJ00<06a/K01XJ6P0K6a/00`0J6QX0
1P0I6AT06QXJ01XJ6P0J6QX06a/K01TI6@806QXJ00<06a/K01TI6@0K6a/00P0K6a/301XJ6PD06ATI
100J6QX401TI6@0301PH600I6AT06ATI00@06ATI0P0J6QX00`0H61P06QXJ01XJ6P0301TI6@H0fMWI
0@0000010=WIf@000P3IfMT00`000000fMWI000000020=WIf@040000003IfMT0fMWI00000080fMWI
00@000000=WIf@3IfMT000001@3IfMT00`000000fMWI0=WIf@030=WIf@0601TI6@0H61P06QXJ01TI
6@0J6QX06ATI0`0J6QX01`0I6AT06QXJ01XJ6P0I6AT06a/K01TI6@0H61P00`0I6AT00`0H61P06QXJ
01PH600201PH600501TI6@0J6QX06ATI01PH600J6QX00`0I6AT01`0J6QX061PH01TI6@0I6AT06QXJ
01TI6@0J6QX00P0I6AT201XJ6P<06ATI00<061PH01XJ6P0J6QX00P0I6AT0100J6QX06ATI01XJ6P0I
6AT401XJ6P0301TI6@0J6QX06QXJ00806QXJ00D06a/K01`L700J6QX06QXJ01/K6`0201XJ6P0501/K
6`0I6AT06a/K01/K6`0J6QX01@0K6a/301XJ6P8071`L00D06QXJ01/K6`0K6a/06a/K01XJ6P0301/K
6`<06QXJ1`0K6a/201`L700501/K6`0L71`071`L01/K6`0M7Ad00`0L71`01@0J6QX071`L01dM7@0N
7Qh07AdM008071`L00@06a/K01`L700K6a/071`L0P0K6a/0100L71`06a/K01`L700K6a/201`L7004
01XJ6P0M7Ad071`L01hN7P@07AdM00D06a/K01dM7@0N7Qh06a/K01`L700201/K6`0801dM7@0K6a/0
7AdM01dM7@0L71`07AdM01XJ6P0K6a/301dM7@D071`L00P07AdM01`L700K6a/07AdM01XJ6P0K6a/0
71`L01/K6`8071`L00H07AdM01/K6`0K6a/071`L01dM7@0K6a/401`L700E01/K6`0L71`06a/K01`L
700K6a/06QXJ01/K6`0M7Ad06a/K01`L700M7Ad071`L01lO7`0S8b<09bLW03Hf=P0i>CT0=CDe02DU
9@0P82007AdM00<06a/K00@071`L01/K6`0L71`071`L1@0K6a/0100I6AT06a/K01XJ6P0K6a/201XJ
6P806a/K00@06QXJ01/K6`0J6QX06QXJ0P0K6a/01@0J6QX06a/K01/K6`0J6QX071`L00806QXJ00@0
6ATI01/K6`0J6QX06QXJ0`0K6a/00`0J6QX06ATI01XJ6P0301TI6@0401/K6`0J6QX06QXJ01/K6`80
6QXJ00D06ATI01XJ6P0J6QX06QXJ01TI6@0301XJ6P0301TI6@0K6a/06ATI00D06QXJ0P0K6a/201TI
6@0401XJ6P0I6AT071`L01/K6`<06QXJ00<06a/K01TI6@0J6QX00P0I6AT0200K6a/061PH01XJ6P0I
6AT06a/K01PH600I6AT06QXJ0`0I6AT01@0H61P06ATI01PH600H61P06ATI008061PH0P0I6AT01@0H
61P06ATI01TI6@0G5aL061PH00H0fMWI0@0000010=WIf@000`3IfMT2000000<0fMWI0P0000040=WI
f@8000001P3IfMT00`000000fMWI0=WIf@030=WIf@@06ATI0P0J6QX00`0H61P06ATI01TI6@0201TI
6@806QXJ100I6AT301XJ6P0301TI6@0H61P06QXJ00806ATI00<061PH01TI6@0I6AT00P0I6AT00`0J
6QX06ATI01/K6`0201XJ6P0401/K6`0I6AT06ATI01XJ6P806ATI00X061PH01XJ6P0I6AT06QXJ01TI
6@0K6a/06QXJ01TI6@0J6QX06ATI0P0J6QX01@0K6a/06QXJ01XJ6P0I6AT06QXJ00<06ATI1@0J6QX3
01/K6`806QXJ00<06a/K01XJ6P0J6QX00`0J6QX301/K6`806QXJ0P0K6a/01@0J6QX06a/K01/K6`0K
6a/06ATI00806a/K00<071`L01/K6`0K6a/00P0K6a/201`L700701XJ6P0L71`06QXJ01`L700K6a/0
71`L01/K6`0201`L70806a/K100L71`01P0K6a/071`L01dM7@0K6a/071`L01/K6`8071`L00<06QXJ
01dM7@0L71`00P0K6a/03P0L71`07AdM01dM7@0L71`06a/K01dM7@0L71`06a/K01`L700M7Ad071`L
01/K6`0L71`06a/K1`0L71`00`0M7Ad071`L01`L700201`L700601dM7@0K6a/071`L01/K6`0L71`0
7AdM1@0K6a/201`L700401/K6`0L71`07AdM01/K6`@071`L00@06a/K01`L700K6a/071`L0P0K6a/3
01`L70807AdM00@071`L01/K6`0K6a/06a/K1`0L71`02@0M7Ad07QhN028R8P0W9bL0=SHf03Ti>@0`
<3008R8R020P800201`L70D06a/K0`0J6QX201/K6`0301XJ6P0L71`06a/K00806a/K100J6QX00`0L
71`06a/K01/K6`0201XJ6PH06a/K00T06QXJ01/K6`0L71`071`L01TI6@0J6QX06ATI01XJ6P0K6a/0
1@0J6QX01@0K6a/06QXJ01TI6@0I6AT06a/K00806ATI0P0J6QX201TI6@806QXJ00D06a/K01XJ6P0J
6QX06QXJ01TI6@0301XJ6P0301/K6`0I6AT06QXJ00<06QXJ0P0K6a/0100L71`06a/K01/K6`0I6AT2
01XJ6P0501TI6@0J6QX06ATI01TI6@0K6a/01@0J6QX00`0I6AT06QXJ01XJ6P0201TI6@0301XJ6P0I
6AT061PH008061PH00<06QXJ01TI6@0I6AT00P0I6AT0100J6QX06ATI01TI6@0G5aL60=WIf@400000
0@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT00`0I6AT061PH01PH600701TI6@0301/K6`0J
6QX06ATI00<06QXJ0`0I6AT201XJ6P@06ATI00<061PH01XJ6P0J6QX00P0I6AT201XJ6P0301TI6@0J
6QX06ATI00806ATI00<06QXJ01TI6@0I6AT00`0J6QX201TI6@0701XJ6P0I6AT061PH01XJ6P0I6AT0
6QXJ01TI6@0401XJ6P806ATI0P0J6QX00`0I6AT06a/K01XJ6P0301XJ6P0701/K6`0J6QX06QXJ01/K
6`0J6QX06a/K01TI6@0301/K6`0601`L700K6a/06a/K01/K6`0J6QX071`L0`0K6a/201XJ6P0401/K
6`0J6QX06a/K01XJ6P<06a/K00@06QXJ01/K6`0L71`061PH0`0K6a/01@0L71`06QXJ01/K6`0K6a/0
71`L00<06a/K00@071`L01/K6`0K6a/06QXJ0P0L71`00`0K6a/071`L01/K6`0301/K6`@071`L00<0
7AdM01`L700K6a/00P0L71`0100K6a/071`L01`L700K6a/301dM7@0301`L700K6a/07AdM00<071`L
00@07QhN01dM7@0L71`06QXJ0`0L71`201/K6`0401`L700K6a/06a/K01`L70806a/K00/071`L01/K
6`0L71`07AdM01`L700K6a/071`L01/K6`0L71`06a/K01`L700201/K6`0401`L700K6a/06a/K01/K
6`8071`L0P0K6a/201`L700301XJ6P0L71`06a/K00806a/K0`0L71`0400J6QX06a/K01`L700L71`0
7AdM01/K6`0L71`07QhN020P800U9BD0:RXZ02/[:`0S8b<07QhN01`L700M7Ad401XJ6P0301`L700K
6a/06a/K00806a/K00<06QXJ01/K6`0K6a/00`0J6QX00`0K6a/06QXJ01TI6@0201/K6`<06QXJ00P0
6a/K01TI6@0J6QX06a/K01TI6@0J6QX071`L01TI6@806QXJ0P0K6a/301XJ6P0:01TI6@0K6a/06ATI
01TI6@0J6QX06ATI01XJ6P0I6AT06QXJ01TI6@806QXJ00<06a/K01TI6@0J6QX00P0I6AT00`0K6a/0
6ATI01XJ6P0301TI6@806QXJ00<06a/K01XJ6P0I6AT0100J6QX0200I6AT06QXJ01/K6`0I6AT06a/K
01TI6@0J6QX06a/K0P0J6QX0100K6a/06QXJ01XJ6P0L71`201XJ6P806ATI00L06QXJ01TI6@0I6AT0
6ATI01XJ6P0H61P06QXJ00@06ATI00@061PH01LG5`0H61P061PH1@0I6AT00`0H61P0fMWI0=WIf@04
0=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT201TI6@0401XJ6P0I6AT061PH
01PH60@06ATI00<06QXJ01PH600I6AT0100I6AT201XJ6P0301PH600J6QX06QXJ00806ATI0P0J6QX0
1`0H61P06QXJ01/K6`0I6AT06QXJ01PH600I6AT00`0J6QX00`0I6AT06QXJ01PH600301TI6@0801/K
6`0H61P06QXJ01XJ6P0I6AT06QXJ01TI6@0J6QX401TI6@0901XJ6P0I6AT06a/K01XJ6P0K6a/06QXJ
01TI6@0K6a/06ATI00<06QXJ00<06a/K01XJ6P0J6QX00P0K6a/401XJ6P806a/K0P0J6QX0200K6a/0
6ATI01/K6`0K6a/06ATI01`L700J6QX06a/K1@0J6QX0200L71`06QXJ01/K6`0J6QX071`L01XJ6P0L
71`06a/K0P0J6QX01@0K6a/06QXJ01/K6`0K6a/07AdM00806a/K00<071`L01/K6`0K6a/00P0L71`0
0`0K6a/07AdM01XJ6P0201/K6`0301`L700K6a/071`L00806a/K0P0L71`01`0M7Ad071`L01`L700M
7Ad071`L01/K6`0L71`00P0K6a/01`0N7Qh07AdM01`L700L71`06a/K01`L700K6a/00P0L71`401dM
7@8071`L00<07AdM01`L700L71`00P0L71`301/K6`0401dM7@0L71`071`L01/K6`8071`L0P0K6a/3
01`L700401dM7@0L71`071`L01dM7@8071`L00D06a/K01`L700L71`06a/K01dM7@0401/K6`0301`L
700K6a/06a/K00806a/K00h071`L01/K6`0L71`07AdM01`L700K6a/071`L01dM7@0P82007alO028R
8P0Q8B407alO01`L70806a/K00D06QXJ01/K6`0J6QX06a/K01XJ6P0201/K6`<06QXJ00D06ATI01/K
6`0J6QX06QXJ01/K6`0201XJ6P0701TI6@0J6QX06ATI01XJ6P0K6a/06QXJ01/K6`0501XJ6P0301TI
6@0J6QX06QXJ00<06QXJ00L06ATI01/K6`0J6QX06ATI01XJ6P0I6AT06a/K00<06QXJ0P0I6AT01@0J
6QX06a/K01/K6`0J6QX071`L00@06QXJ00@06ATI01/K6`0J6QX06ATI0`0J6QX201TI6@0601XJ6P0I
6AT06ATI01/K6`0J6QX06a/K0P0J6QX01P0K6a/06QXJ01`L700L71`06a/K01`L70<06QXJ00<06a/K
01XJ6P0J6QX0100J6QX00`0I6AT061PH01TI6@0201TI6@8061PH1`0I6AT201PH60806ATI00<05aLG
01PH603IfMT01@3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0`0I6AT00`0J
6QX06ATI01TI6@0601TI6@<06QXJ00H061PH01XJ6P0J6QX06QXJ01TI6@0J6QX201TI6@0:01PH600J
6QX06ATI01TI6@0J6QX06ATI01XJ6P0I6AT06QXJ01TI6@8061PH00<06ATI01XJ6P0H61P01@0I6AT0
1P0H61P06ATI01XJ6P0J6QX06a/K01XJ6P806ATI00<06a/K01TI6@0J6QX01@0J6QX01@0I6AT06QXJ
01XJ6P0J6QX06a/K00806QXJ00<06a/K01XJ6P0J6QX00P0K6a/01`0J6QX06a/K01XJ6P0K6a/06QXJ
01/K6`0J6QX00P0K6a/301XJ6P0401/K6`0L71`06a/K01/K6`806QXJ00@06a/K01XJ6P0K6a/06a/K
0P0J6QX00`0L71`06QXJ01XJ6P0301/K6`0401`L700K6a/06a/K01XJ6P<06a/K00@071`L01/K6`0K
6a/06a/K0P0L71`00`0M7Ad071`L01`L700201/K6`8071`L0P0K6a/201`L700501/K6`0M7Ad071`L
01`L700M7Ad00`0K6a/00`0J6QX06a/K01dM7@0301`L70806a/K00@071`L01dM7@0K6a/06a/K1@0L
71`00`0K6a/071`L01`L700201dM7@0601/K6`0L71`06a/K01/K6`0L71`06a/K0`0L71`0100K6a/0
6QXJ01/K6`0L71`301/K6`8071`L0`0K6a/0300M7Ad06QXJ01/K6`0K6a/06QXJ01/K6`0J6QX071`L
01/K6`0L71`06a/K01XJ6P806a/K0P0L71`201/K6`0301`L700K6a/06a/K00807AdM0`0N7Qh00`0L
71`07AdM01/K6`0201/K6`0601XJ6P0L71`06a/K01XJ6P0K6a/06QXJ0`0K6a/00`0J6QX071`L01XJ
6P0301XJ6P0301/K6`0J6QX06QXJ00<06QXJ00D06a/K01XJ6P0K6a/06a/K01TI6@0201XJ6P0401/K
6`0I6AT06QXJ01XJ6P<06a/K0`0J6QX00`0I6AT06QXJ01TI6@0401XJ6P0301/K6`0I6AT06a/K00@0
6QXJ00L06ATI01XJ6P0J6QX06QXJ01TI6@0J6QX06a/K00806QXJ0P0I6AT401XJ6P0601/K6`0I6AT0
6QXJ01XJ6P0K6a/06QXJ0`0K6a/0100L71`06a/K01/K6`0J6QX201TI6@0501XJ6P0I6AT06QXJ01/K
6`0J6QX0100I6AT201XJ6P@06ATI00<061PH01TI6@0J6QX00P0H61P00`0I6AT061PH01TI6@0201PH
60H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@P06ATI00T061PH01XJ6P0I
6AT061PH01XJ6P0K6a/061PH01TI6@0J6QX00P0I6AT201XJ6P0401TI6@0H61P06ATI01PH60<06ATI
0P0J6QX301TI6@0401PH600I6AT06ATI01XJ6P806ATI00<06QXJ01TI6@0J6QX00P0I6AT301XJ6PD0
6ATI00<06QXJ01TI6@0J6QX00P0J6QX00`0K6a/06ATI01TI6@0201XJ6P0901TI6@0J6QX06QXJ01PH
600J6QX06ATI01XJ6P0I6AT06a/K00806QXJ00T06ATI01XJ6P0I6AT06a/K01XJ6P0K6a/06ATI01/K
6`0J6QX00P0K6a/00`0L71`06a/K01TI6@0201XJ6P8071`L00D06QXJ01/K6`0I6AT06ATI01/K6`03
01XJ6P<06a/K00<07AdM01/K6`0K6a/00`0L71`201/K6`0401XJ6P0L71`06a/K01`L70806a/K00L0
71`L01/K6`0M7Ad06a/K01dM7@0J6QX06a/K008071`L0P0K6a/00`0M7Ad06a/K01`L700201`L7003
01/K6`0L71`071`L00<06a/K00D07AdM01`L700J6QX071`L01/K6`0201`L700601/K6`0J6QX07AdM
01/K6`0L71`07AdM0P0K6a/201`L700801XJ6P0L71`071`L01`L700K6a/07AdM01`L700K6a/201`L
70H06a/K100L71`01@0J6QX071`L01`L700J6QX071`L00<06QXJ0`0L71`00`0K6a/071`L01/K6`03
01/K6`D071`L00@07AdM01/K6`0L71`071`L0`0K6a/00`0L71`06QXJ01/K6`0301/K6`0701XJ6P0K
6a/06ATI01XJ6P0K6a/06QXJ01/K6`0401XJ6P0301`L700J6QX06a/K00@06QXJ00<06ATI01XJ6P0J
6QX00`0J6QX201/K6`D06QXJ00<06a/K01TI6@0J6QX0100J6QX00`0I6AT06QXJ01TI6@0201XJ6P<0
6ATI00<06QXJ01/K6`0I6AT00P0J6QX01`0K6a/06ATI01TI6@0J6QX06a/K01TI6@0K6a/00`0J6QX0
100K6a/06ATI01/K6`0K6a/301XJ6P0401/K6`0J6QX07AdM01/K6`8071`L00@07AdM01`L700K6a/0
6a/K0`0J6QX01`0L71`06QXJ01XJ6P0I6AT061PH01TI6@0J6QX01@0I6AT0100J6QX06ATI01TI6@0I
6AT301PH60<06ATI00<06QXJ0=WIf@3IfMT0103IfMT100000040fMWI000F0=WIf@030000003IfMT0
fMWI00<0fMWI00P06QXJ01TI6@0I6AT061PH01TI6@0H61P06ATI01PH60<06ATI00@061PH01TI6@0I
6AT06QXJ0P0I6AT201XJ6P8061PH00H06QXJ01PH600I6AT06ATI01XJ6P0H61P601TI6@0701XJ6P0I
6AT06ATI01XJ6P0H61P06QXJ01TI6@0201PH600301TI6@0J6QX06ATI00806QXJ00<06a/K01XJ6P0I
6AT00P0J6QX201TI6@H06QXJ00<06ATI01XJ6P0J6QX00P0K6a/00`0J6QX06a/K01XJ6P0201XJ6P04
01/K6`0J6QX06QXJ01TI6@806QXJ00<06ATI01/K6`0J6QX0100J6QX401/K6`0301`L700J6QX06QXJ
00@06a/K0P0J6QX301/K6`806QXJ00<071`L01XJ6P0L71`00P0K6a/301`L700301XJ6P0K6a/06a/K
00806a/K00<071`L01/K6`0L71`00P0K6a/00`0L71`06a/K01`L700301/K6`0401`L700J6QX071`L
01dM7@806a/K00<071`L01/K6`0L71`00`0L71`00`0M7Ad071`L01/K6`0501`L70807AdM100L71`0
100M7Ad06a/K01/K6`0K6a/201`L700301/K6`0M7Ad06a/K00<071`L0P0K6a/01@0M7Ad06a/K01`L
700K6a/071`L00<06a/K0P0L71`0100K6a/071`L01/K6`0J6QX201/K6`0301XJ6P0I6AT071`L0080
71`L0P0K6a/00`0J6QX06a/K01`L700201XJ6P0401/K6`0I6AT06QXJ01XJ6P806a/K00@06QXJ01TI
6@0J6QX071`L1@0K6a/00`0J6QX071`L01XJ6P0201XJ6P0301TI6@0K6a/06QXJ00<06QXJ00<071`L
01/K6`0J6QX00P0J6QX0100I6AT06QXJ01XJ6P0I6AT501XJ6P806ATI00<06a/K01XJ6P0K6a/00P0K
6a/00`0I6AT06QXJ01XJ6P0301XJ6P<06ATI0P0J6QX0200K6a/06QXJ01XJ6P0J6QX06a/K01TI6@0J
6QX06a/K0P0I6AT201XJ6P0301TI6@0J6QX06a/K00806QXJ00D06ATI01XJ6P0J6QX06QXJ01TI6@07
01XJ6P0501`L700K6a/071`L01`L700M7Ad00P0L71`201/K6`806QXJ00<06ATI01XJ6P0K6a/00P0I
6AT201XJ6P0501TI6@0J6QX06ATI01TI6@0J6QX00`0I6AT00`0H61P06ATI01TI6@0201TI6@8061PH
00<06ATI0=WIf@3IfMT0103IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0P0I
6AT201PH600301TI6@0H61P06ATI00<06QXJ0P0I6AT00`0J6QX06ATI01XJ6P0801TI6@0301XJ6P0I
6AT06ATI00<06ATI00X06QXJ01TI6@0H61P061PH01TI6@0H61P06ATI01PH600J6QX061PH0P0I6AT0
0`0J6QX06ATI01TI6@0401TI6@806QXJ00<06ATI01XJ6P0J6QX00P0J6QX00`0I6AT06QXJ01TI6@05
01XJ6P0301TI6@0J6QX06QXJ00<06QXJ00<06ATI01XJ6P0J6QX0100J6QX401/K6`806QXJ100K6a/0
1@0L71`06QXJ01/K6`0J6QX071`L00<06a/K00<071`L01/K6`0J6QX00P0L71`00`0J6QX071`L01/K
6`0201XJ6P0601`L700K6a/06a/K01`L700K6a/06QXJ0`0K6a/01@0L71`06a/K01/K6`0K6a/071`L
00D06a/K00<071`L01/K6`0K6a/0100L71`201/K6`0401XJ6P0L71`07AdM01/K6`8071`L00@06a/K
01`L700L71`07AdM0`0L71`201dM7@0401`L700K6a/071`L01/K6`8071`L00@06QXJ01`L700L71`0
71`L0P0K6a/00`0L71`06a/K01/K6`0201`L700301XJ6P0K6a/07AdM00<06a/K00D071`L01XJ6P0K
6a/071`L01XJ6P0301/K6`<071`L00<06ATI01XJ6P0L71`00`0K6a/00`0L71`06a/K01`L700301/K
6`0501`L700M7Ad06QXJ01/K6`0J6QX00P0K6a/201XJ6P0501`L700K6a/06QXJ01`L700K6a/00`0J
6QX301/K6`806QXJ00<06a/K01XJ6P0K6a/00P0J6QX301/K6`806QXJ00<06ATI01XJ6P0J6QX0100J
6QX01@0H61P06QXJ01/K6`0J6QX06a/K00806QXJ00`06ATI01XJ6P0J6QX06a/K01TI6@0J6QX061PH
01XJ6P0I6AT061PH01TI6@0G5aL201XJ6P806ATI00X06QXJ01TI6@0I6AT06QXJ01TI6@0J6QX06a/K
01TI6@0J6QX06a/K0`0I6AT901XJ6P<06a/K00H07AdM01/K6`0L71`07AdM01`L700M7Ad201`L7004
01/K6`0J6QX06a/K01/K6`<06QXJ00<061PH01/K6`0I6AT00`0I6AT00`0H61P06ATI01PH600201XJ
6P0301TI6@0H61P06ATI00D06ATI1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0
fMWI00<06QXJ01PH600H61P01@0I6AT0100G5aL06ATI01PH600I6AT201XJ6P0401TI6@0J6QX061PH
01XJ6P<06ATI0P0H61P601TI6@0301PH600I6AT06ATI00806ATI0P0J6QX201TI6@0801PH600I6AT0
6ATI01TI6@0H61P06ATI01PH600I6AT301XJ6P@06ATI00<06QXJ01/K6`0J6QX00P0J6QX01@0I6AT0
6QXJ01TI6@0L71`06ATI00P06QXJ00@06ATI01XJ6P0J6QX06QXJ0`0K6a/00`0J6QX06a/K01/K6`02
01XJ6P0301/K6`0L71`06QXJ00806a/K00@06ATI01/K6`0J6QX06QXJ0P0K6a/301XJ6P<071`L00@0
6a/K01`L700K6a/071`L0`0K6a/00`0J6QX06a/K01/K6`0201XJ6P0<01`L700K6a/06QXJ01/K6`0I
6AT06a/K01XJ6P0L71`06a/K01`L700K6a/071`L0P0K6a/01P0L71`06a/K01XJ6P0K6a/071`L01/K
6`806QXJ00<06a/K01XJ6P0M7Ad00P0L71`00`0J6QX071`L01/K6`0401`L70@06a/K0P0L71`01`0K
6a/071`L01`L700K6a/06QXJ01/K6`0L71`0100K6a/0100L71`06a/K01`L700L71`201/K6`8071`L
200K6a/0100J6QX071`L01/K6`0J6QX201/K6`8071`L00<06a/K01`L700K6a/0100L71`201/K6`07
01TI6@0K6a/06QXJ01XJ6P0K6a/06QXJ01/K6`0201XJ6P<06a/K0P0J6QX00`0K6a/06QXJ01XJ6P02
01XJ6P0301/K6`0J6QX06ATI00806QXJ00D06ATI01XJ6P0K6a/06a/K01XJ6P0201/K6`@06QXJ0P0I
6AT00`0J6QX06ATI01/K6`0301TI6@@06QXJ0`0I6AT01@0J6QX06ATI01XJ6P0J6QX06ATI00<06QXJ
00<06ATI01XJ6P0I6AT00P0J6QX01@0I6AT06a/K01XJ6P0J6QX061PH00806ATI0P0J6QX401TI6@03
01/K6`0J6QX06QXJ00806a/K00T06QXJ01dM7@0M7Ad06a/K01`L700M7Ad07QhN01dM7@0L71`00P0M
7Ad01P0L71`06a/K01/K6`0K6a/06QXJ01PH60<06ATI0P0J6QX201TI6@0301PH600I6AT061PH0080
6QXJ00@061PH01TI6@0I6AT061PH0`0I6AT00`0H61P0fMWI0=WIf@040=WIf@4000000@3IfMT001H0
fMWI00<000000=WIf@3IfMT00`3IfMT201TI6@0301XJ6P0I6AT06ATI00<06ATI00<061PH01TI6@0J
6QX01@0I6AT201XJ6P<06ATI00<061PH01TI6@0I6AT00P0I6AT201PH600301TI6@0H61P06ATI0080
6ATI0P0H61P201TI6@0401LG5`0H61P06ATI01TI6@806QXJ00<06ATI01XJ6P0H61P00P0J6QX201TI
6@0501/K6`0J6QX06QXJ01XJ6P0K6a/00P0J6QX201TI6@806QXJ0P0I6AT201XJ6P0401/K6`0J6QX0
6ATI01XJ6P806ATI00D06a/K01XJ6P0J6QX06a/K01`L700201/K6`0301XJ6P0K6a/06QXJ00@06QXJ
1@0K6a/00`0J6QX06a/K01`L700501/K6`0;01XJ6P0K6a/071`L01XJ6P0K6a/06QXJ01`L700K6a/0
71`L01/K6`0J6QX00P0L71`301/K6`0401XJ6P0L71`06a/K01XJ6P@06a/K0P0J6QX201`L700301XJ
6P0L71`06a/K00@06a/K00<071`L01/K6`0L71`01P0K6a/0100J6QX06a/K01`L700L71`201/K6`09
01`L700J6QX06QXJ01`L700J6QX071`L01/K6`0L71`06QXJ00806a/K0P0L71`00`0J6QX06a/K01/K
6`0201/K6`0901XJ6P0K6a/06QXJ01/K6`0L71`06QXJ01/K6`0L71`06a/K00806QXJ0`0K6a/01@0J
6QX06a/K01/K6`0K6a/06QXJ00<06a/K00L06QXJ01/K6`0J6QX06QXJ01`L700K6a/06QXJ00806a/K
0`0J6QX201/K6`8071`L00@06QXJ01/K6`0J6QX06a/K0P0J6QX00`0I6AT06a/K01XJ6P0201XJ6P05
01/K6`0J6QX06QXJ01XJ6P0K6a/00P0J6QX00`0K6a/06QXJ01XJ6P0701XJ6P0601/K6`0I6AT06ATI
01PH600J6QX06a/K0P0I6AT02P0J6QX06a/K01XJ6P0I6AT06QXJ01PH600K6a/06QXJ01TI6@0J6QX7
01TI6@0801/K6`0I6AT06QXJ01/K6`0I6AT06QXJ01PH600J6QX601TI6@0301XJ6P0I6AT06QXJ0080
6QXJ00<06a/K01`L700K6a/00P0K6a/00`0L71`07AdM01hN7P0201dM7@807QhN00L07AdM01`L700K
6a/071`L01TI6@0J6QX06a/K00<06QXJ0P0I6AT01@0J6QX06ATI01XJ6P0I6AT06QXJ00H06ATI00<0
61PH01TI6@0G5aL01P3IfMT100000040fMWI000F0=WIf@800000103IfMT201XJ6P806ATI00@06QXJ
01TI6@0H61P061PH0`0I6AT201XJ6P0401PH600I6AT06ATI01TI6@8061PH0P0I6AT01@0H61P06ATI
01TI6@0I6AT061PH00L06ATI0P0J6QX501TI6@0501XJ6P0I6AT06ATI01XJ6P0H61P00`0I6AT0100H
61P06QXJ01TI6@0I6AT201XJ6P0401TI6@0J6QX06QXJ01XJ6P<06ATI00<06a/K01XJ6P0J6QX00P0J
6QX00`0K6a/06ATI01XJ6P0501XJ6P806a/K00@06QXJ01/K6`0J6QX06a/K0P0L71`0100J6QX06a/K
01XJ6P0K6a/201XJ6P0301/K6`0J6QX06a/K00806a/K100J6QX301/K6`0501dM7@0J6QX06a/K01`L
700K6a/00P0J6QX0200L71`06QXJ01/K6`0K6a/071`L01dM7@0J6QX06a/K0P0L71`0100K6a/071`L
01XJ6P0L71`201/K6`0301`L700K6a/071`L00@06a/K00L06QXJ01`L700K6a/06a/K01XJ6P0K6a/0
7AdM00P06a/K00D07AdM01`L700L71`07AdM01/K6`0201`L700301/K6`0L71`06QXJ00@06a/K00@0
6QXJ01`L700J6QX071`L0P0K6a/00`0J6QX06a/K01`L700201/K6`0601`L700J6QX06QXJ01/K6`0J
6QX06a/K0P0J6QX00`0K6a/071`L01/K6`0301`L70806a/K00<06QXJ01`L700K6a/00`0K6a/201XJ
6P0301`L700K6a/071`L00<06QXJ00@06a/K01XJ6P0K6a/06QXJ0P0K6a/301XJ6P0401/K6`0J6QX0
6a/K01TI6@806QXJ00<06ATI01/K6`0J6QX00P0I6AT201XJ6P806ATI0P0J6QX0100I6AT06QXJ01`L
700J6QX201TI6@806QXJ0P0I6AT301XJ6P0301/K6`0J6QX06QXJ00806QXJ100I6AT201XJ6P0501TI
6@0J6QX06ATI01TI6@0J6QX00P0I6AT0100K6a/06QXJ01TI6@0J6QX201TI6@0501PH600I6AT06ATI
01XJ6P0I6AT0100J6QX0100I6AT06QXJ01XJ6P0J6QX201/K6`8071`L0`0M7Ad03@0O7al07AdM01lO
7`0N7Qh0820P01lO7`0M7Ad071`L01/K6`0L71`06a/K01TI6@0K6a/00P0I6AT0100J6QX061PH01TI
6@0I6AT201PH600301TI6@0H61P06ATI00806ATI00<05aLG01XJ6P0J6QX00P0I6AT50=WIf@800000
0@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT201TI6@806QXJ00H061PH01TI6@0I6AT06QXJ
01TI6@0J6QX201PH600401XJ6P0H61P06QXJ01XJ6P@06ATI00<06QXJ01TI6@0I6AT00P0I6AT0100H
61P06ATI01TI6@0H61P301TI6@0601/K6`0J6QX06ATI01TI6@0J6QX061PH1@0I6AT00`0J6QX06ATI
01TI6@0301XJ6P0401TI6@0K6a/061PH01XJ6P<06ATI0P0J6QX201TI6@<06QXJ00D071`L01XJ6P0K
6a/06QXJ01/K6`0401XJ6P0301/K6`0I6AT06ATI00<06QXJ00H06a/K01`L700I6AT06ATI01XJ6P0K
6a/201XJ6P0301/K6`0J6QX06a/K00806a/K0P0J6QX0100K6a/071`L01/K6`0J6QX201/K6`0401`L
700K6a/071`L01`L70@06a/K100J6QX201/K6`0401XJ6P0K6a/06QXJ01XJ6P8071`L00@06a/K01XJ
6P0L71`06a/K0P0L71`0100K6a/06QXJ01XJ6P0L71`601/K6`0@01XJ6P0K6a/06a/K01`L700J6QX0
71`L01/K6`0J6QX06a/K01`L700J6QX06a/K01`L700K6a/071`L01XJ6P<06a/K00<071`L01XJ6P0L
71`00`0K6a/01@0L71`07AdM01`L700N7Qh071`L00806a/K0P0L71`301/K6`0301XJ6P0K6a/06a/K
00806a/K00`06QXJ01/K6`0I6AT071`L01/K6`0J6QX071`L01XJ6P0K6a/06QXJ01`L700J6QX201/K
6`0801`L700K6a/06a/K01XJ6P0L71`06QXJ01TI6@0J6QX501/K6`0401XJ6P0K6a/06QXJ01/K6`80
6QXJ00<06a/K01TI6@0J6QX0200J6QX0300K6a/06QXJ01/K6`0J6QX06a/K01XJ6P0I6AT06a/K01XJ
6P0K6a/06QXJ01/K6`806QXJ00@06ATI01XJ6P0J6QX06QXJ200I6AT00`0J6QX06ATI01XJ6P0401TI
6@0801XJ6P0I6AT06QXJ01XJ6P0K6a/06QXJ01/K6`0J6QX501TI6@0<01XJ6P0I6AT06ATI01TI6@0J
6QX06ATI01PH600I6AT06QXJ01/K6`0J6QX06a/K0`0L71`0100N7Qh0820P024Q8@0Q8B4302<S8`04
024Q8@0O7al07AdM01dM7@8071`L0P0J6QX00`0K6a/06ATI01XJ6P0301XJ6P0501PH600I6AT06QXJ
01XJ6P0I6AT00P0H61P201TI6@0301PH600I6AT0fMWI00D0fMWI0@0000010=WIf@005P3IfMT00`00
0000fMWI0=WIf@030=WIf@8061PH100I6AT201XJ6P@06ATI00<06QXJ01TI6@0I6AT00`0I6AT01`0J
6QX06ATI01PH600I6AT06QXJ01TI6@0J6QX00P0I6AT201PH60@06ATI00<061PH01TI6@0J6QX0100I
6AT00`0K6a/06QXJ01TI6@0601TI6@@06QXJ0P0I6AT301XJ6P806ATI00D06QXJ01/K6`0K6a/06a/K
01TI6@0201XJ6P0301TI6@0J6QX06a/K00806QXJ00<06ATI01XJ6P0J6QX00`0J6QX601/K6`L06QXJ
00P06a/K01XJ6P0K6a/071`L01dM7@0J6QX06a/K01`L70<06a/K00<06QXJ01/K6`0J6QX00P0K6a/0
0`0L71`06a/K01/K6`0401/K6`8071`L0`0K6a/0100J6QX06a/K01TI6@0K6a/301XJ6P0B01`L700J
6QX06a/K01XJ6P0K6a/07AdM01/K6`0L71`06QXJ01/K6`0J6QX06a/K01`L700J6QX06a/K01`L700K
6a/071`L0P0J6QX0100K6a/07AdM01`L700L71`401/K6`0601XJ6P0K6a/06a/K01/K6`0J6QX06a/K
100L71`01@0J6QX06a/K01/K6`0K6a/06QXJ00806a/K00@06QXJ01/K6`0K6a/06QXJ0P0K6a/01@0J
6QX071`L01/K6`0J6QX071`L00806a/K0`0J6QX00`0K6a/071`L01`L700201/K6`0301XJ6P0K6a/0
6QXJ00806QXJ00<06ATI01/K6`0J6QX01`0J6QX00`0I6AT06QXJ01/K6`0701XJ6P0501/K6`0J6QX0
6QXJ01XJ6P0K6a/00P0J6QX00`0K6a/06QXJ01XJ6P0201TI6@0301XJ6P0I6AT06ATI00806QXJ00H0
6ATI01XJ6P0J6QX06ATI01XJ6P0I6AT301XJ6P0501PH600I6AT06ATI01TI6@0J6QX00`0I6AT0100J
6QX061PH01XJ6P0I6AT201XJ6P0:01/K6`0J6QX06QXJ01TI6@0H61P06QXJ01TI6@0J6QX061PH01XJ
6P@06ATI00@06a/K01XJ6P0J6QX06ATI0P0K6a/0100J6QX071`L01/K6`0L71`201dM7@80820P00H0
8R8R02HV9P0V9RH09BDU02<S8`0R8R8201hN7P<06a/K0P0J6QX201TI6@0901PH600J6QX06QXJ01PH
600I6AT06QXJ01TI6@0J6QX06ATI008061PH00<06ATI01PH600I6AT01P3IfMT100000040fMWI000F
0=WIf@030000003IfMT0fMWI00<0fMWI0P0I6AT0100H61P06ATI01PH600G5aL201XJ6P0301TI6@0H
61P06ATI00806ATI00H061PH01XJ6P0I6AT061PH01TI6@0J6QX201TI6@0301XJ6P0K6a/061PH00<0
6ATI00<061PH01XJ6P0I6AT0100I6AT01`0J6QX06ATI01XJ6P0I6AT06QXJ01TI6@0J6QX00P0I6AT0
0`0J6QX06ATI01TI6@0301XJ6P0501/K6`0I6AT06a/K01TI6@0J6QX00P0I6AT00`0J6QX06ATI01XJ
6P0301XJ6P0301TI6@0K6a/06a/K00806a/K00H06QXJ01TI6@0K6a/06QXJ01/K6`0J6QX201/K6`03
01TI6@0J6QX06QXJ00<06QXJ0P0K6a/00`0I6AT06QXJ01TI6@0201XJ6P0401/K6`0J6QX06a/K01XJ
6P806a/K0`0J6QX01`0K6a/06QXJ01XJ6P0J6QX06a/K01XJ6P0K6a/0100J6QX01`0L71`06QXJ01XJ
6P0J6QX06a/K01`L700J6QX00P0K6a/201`L700401/K6`0L71`06QXJ01XJ6P<071`L00H06a/K01XJ
6P0K6a/06QXJ01/K6`0J6QX201/K6`0301`L700K6a/06a/K00@06a/K00L06QXJ01/K6`0L71`071`L
01/K6`0L71`06a/K008071`L00<07AdM01`L700J6QX00`0K6a/201`L700401/K6`0J6QX06a/K01/K
6`8071`L0`0K6a/00`0J6QX06a/K01`L700501/K6`0701XJ6P0K6a/06QXJ01TI6@0J6QX071`L01XJ
6P0301/K6`0301`L700K6a/06QXJ00806a/K00<06ATI01XJ6P0J6QX01P0J6QX01@0K6a/06QXJ01/K
6`0I6AT06a/K00806QXJ00<06a/K01XJ6P0J6QX00P0J6QX01`0I6AT06QXJ01/K6`0K6a/06ATI01XJ
6P0I6AT00P0J6QX04@0K6a/06QXJ01TI6@0I6AT06QXJ01/K6`0I6AT06QXJ01/K6`0H61P06QXJ01TI
6@0J6QX06ATI01XJ6P0I6AT06QXJ00806ATI0P0J6QX01@0I6AT06QXJ01TI6@0I6AT061PH00<06ATI
0P0J6QX401TI6@0401XJ6P0I6AT06ATI01XJ6P<06ATI00<06QXJ01PH600I6AT01@0I6AT00`0J6QX0
6a/K01XJ6P0201XJ6P0301TI6@0J6QX06QXJ00806QXJ00l071`L01/K6`0N7Qh07alO024Q8@0V9RH0
:b/[02l_;`0^;Rh0:BTY02LW9`0P82007QhN01dM7@0K6a/00P0J6QX00`0I6AT06a/K01TI6@0501TI
6@806QXJ00L06ATI01XJ6P0J6QX06QXJ01PH600I6AT061PH00H0fMWI0@0000010=WIf@005P3IfMT0
0`000000fMWI0=WIf@030=WIf@<06ATI00D061PH01TI6@0H61P06ATI01XJ6P0201TI6@0501XJ6P0I
6AT06QXJ01PH600G5aL00P0I6AT01`0K6a/06ATI01TI6@0J6QX061PH01TI6@0H61P00P0I6AT00`0J
6QX061PH01TI6@0301TI6@0401PH600I6AT06ATI01TI6@<06QXJ0P0H61P201TI6@806QXJ00H061PH
01XJ6P0I6AT06a/K01XJ6P0I6AT201XJ6P0501PH600J6QX06QXJ01TI6@0J6QX00P0I6AT00`0K6a/0
6QXJ01TI6@0201XJ6P806a/K0P0J6QX201/K6`0301TI6@0K6a/06ATI00806QXJ00/06ATI01XJ6P0J
6QX06QXJ01/K6`0J6QX06ATI01XJ6P0K6a/06QXJ01TI6@0301XJ6P0401TI6@0J6QX06QXJ01XJ6P80
6a/K0P0J6QX01@0K6a/06QXJ01XJ6P0J6QX06a/K00806QXJ1P0K6a/301`L700701/K6`0J6QX06a/K
01/K6`0L71`06a/K01`L700301/K6`0301XJ6P0K6a/06QXJ00<06a/K00L071`L01XJ6P0M7Ad06a/K
01XJ6P0K6a/071`L00<06a/K0P0L71`00`0M7Ad06QXJ01/K6`0501/K6`0401dM7@0K6a/06a/K01`L
70<06a/K00H071`L01/K6`0J6QX071`L01/K6`0L71`301/K6`0401XJ6P0K6a/071`L01XJ6P806a/K
00@06QXJ01/K6`0K6a/06QXJ100K6a/00`0J6QX06a/K01/K6`0201/K6`0301XJ6P0L71`06QXJ0080
6QXJ00<06a/K01TI6@0J6QX00`0K6a/201XJ6P0401/K6`0I6AT06QXJ01TI6@<06QXJ00H06a/K01XJ
6P0K6a/06a/K01XJ6P0K6a/201XJ6P806ATI0P0J6QX0100K6a/06QXJ01TI6@0J6QX201/K6`<06ATI
0`0J6QX00`0I6AT06QXJ01TI6@0201TI6@0301XJ6P0K6a/06ATI00P06ATI0P0J6QX0100I6AT06QXJ
01XJ6P0I6AT201XJ6P806ATI0P0J6QX00`0H61P06ATI01TI6@0301XJ6P0401PH600I6AT061PH01PH
60<06ATI00H06a/K01PH600H61P061PH01XJ6P0K6a/201TI6@0@01XJ6P0L71`06a/K01/K6`0M7Ad0
820P028R8P0Y:BT0<c<c03Lg=`0i>CT0<C4a02`/;00R8R80820P01hN7P<06a/K00@06QXJ01TI6@0J
6QX06QXJ100I6AT00`0H61P06QXJ01PH600201XJ6P806ATI00<061PH01TI6@3IfMT01@3IfMT10000
0040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00<06ATI01PH600H61P00`0I6AT00`0H61P0
6QXJ01PH600201TI6@0301XJ6P0I6AT06QXJ00806ATI00<06QXJ01TI6@0I6AT0100I6AT0100G5aL0
6ATI01XJ6P0H61P301TI6@0301PH600I6AT061PH008061PH00<06ATI01XJ6P0I6AT00P0I6AT201XJ
6P0301PH600I6AT06QXJ00806QXJ00<06ATI01XJ6P0J6QX00P0I6AT0100H61P06QXJ01XJ6P0I6AT4
01XJ6P806ATI0`0K6a/0100J6QX06ATI01XJ6P0K6a/401XJ6P0301TI6@0J6QX06QXJ00<06ATI0`0K
6a/0100I6AT06QXJ01/K6`0K6a/201XJ6P0301/K6`0I6AT06ATI00D06QXJ0P0K6a/0100J6QX06a/K
01/K6`0J6QX201/K6`806QXJ0P0I6AT00`0J6QX06a/K01/K6`0201XJ6P806a/K00D06QXJ01`L700K
6a/06QXJ01/K6`0201XJ6P0501/K6`0M7Ad06a/K01/K6`0L71`00P0K6a/00`0L71`06a/K01/K6`02
01/K6`0301XJ6P0K6a/06a/K00@071`L100K6a/01@0M7Ad06a/K01`L700K6a/071`L00<06a/K00@0
6ATI01/K6`0K6a/06QXJ1@0K6a/401XJ6P<06a/K0P0J6QX0200K6a/071`L01/K6`0L71`06a/K01`L
700K6a/071`L0P0K6a/201XJ6P@06a/K0P0J6QX00`0I6AT06QXJ01/K6`0201XJ6P0301TI6@0K6a/0
6a/K00806QXJ00@06a/K01XJ6P0I6AT06a/K0`0J6QX301/K6`0301TI6@0J6QX06a/K00<06QXJ00<0
6a/K01TI6@0I6AT00P0I6AT01@0J6QX061PH01XJ6P0I6AT06QXJ00806ATI00@06QXJ01TI6@0K6a/0
6ATI100J6QX01P0I6AT06QXJ01TI6@0I6AT06QXJ01TI6@806QXJ100I6AT01@0J6QX06ATI01TI6@0I
6AT06QXJ008061PH00<06QXJ01TI6@0H61P01@0I6AT01@0H61P06ATI01TI6@0I6AT06QXJ00806ATI
00@061PH01XJ6P0I6AT06QXJ0P0I6AT301XJ6P806a/K010071`L01dM7@0M7Ad08B4Q02<S8`0X:2P0
=3@d03`l?00k>c/0<C4a02l_;`0T92@08R8R01dM7@0K6a/071`L0P0K6a/201TI6@0301PH600J6QX0
6ATI00806ATI00D06QXJ01TI6@0H61P06QXJ01TI6@0201PH60806ATI1P3IfMT100000040fMWI000F
0=WIf@030000003IfMT0fMWI00<0fMWI0P0I6AT01`0H61P06ATI01TI6@0H61P06ATI01PH600J6QX0
0P0I6AT01P0H61P06ATI01TI6@0J6QX06ATI01XJ6P<06ATI00<061PH01TI6@0H61P00P0I6AT01@0J
6QX06ATI01TI6@0J6QX061PH00806ATI00<061PH01TI6@0I6AT00P0I6AT01`0J6QX06ATI01TI6@0I
6AT06QXJ01PH600J6QX00P0I6AT01`0K6a/06QXJ01TI6@0J6QX06ATI01XJ6P0I6AT0100J6QX00`0H
61P06QXJ01TI6@0301TI6@0501XJ6P0I6AT06QXJ01XJ6P0I6AT00P0J6QX301TI6@0301XJ6P0I6AT0
6ATI00806ATI00<06a/K01TI6@0I6AT01@0I6AT701XJ6P806ATI00<06QXJ01TI6@0K6a/00`0K6a/2
01XJ6P0501/K6`0L71`06ATI01XJ6P0K6a/00P0J6QX0100K6a/06QXJ01/K6`0J6QX401/K6`0301`L
700J6QX06a/K00806a/K0P0J6QX00`0K6a/06QXJ01/K6`0301/K6`0301`L700J6QX06a/K00<06a/K
00D06QXJ01/K6`0K6a/06a/K01`L700301XJ6P806a/K00X071`L01/K6`0K6a/06a/K01XJ6P0K6a/0
6QXJ01/K6`0L71`06QXJ0P0K6a/0100J6QX06a/K01XJ6P0K6a/201XJ6P0401/K6`0J6QX06a/K01/K
6`<06QXJ00D06a/K01XJ6P0K6a/06QXJ01`L700201/K6`0301XJ6P0K6a/06a/K00<06a/K00@06QXJ
01/K6`0J6QX06QXJ0`0K6a/01`0J6QX06a/K01/K6`0J6QX06ATI01/K6`0I6AT00`0J6QX02@0K6a/0
6ATI01/K6`0J6QX06ATI01XJ6P0I6AT06QXJ01TI6@0201XJ6P806ATI00<06a/K01TI6@0I6AT00P0I
6AT201XJ6P806ATI00<061PH01XJ6P0J6QX01@0K6a/00`0I6AT06QXJ01TI6@0301XJ6P0801TI6@0J
6QX06ATI01XJ6P0I6AT06QXJ01TI6@0H61P501TI6@0301XJ6P0I6AT06QXJ00<06ATI00<061PH01TI
6@0I6AT00`0I6AT00`0H61P06ATI01TI6@0301TI6@0401LG5`0I6AT06ATI01TI6@806QXJ01006ATI
01XJ6P0I6AT06a/K01XJ6P0L71`07AdM01`L700O7al08B4Q02XZ:P0d=3@0>SXj03/k>`0`<300:RXZ
0P0R8R80100N7Qh07AdM01/K6`0K6a/201XJ6P<06ATI00<06QXJ01TI6@0I6AT00`0H61P01P0I6AT0
61PH01XJ6P0I6AT061PH01TI6@H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WI
f@D06ATI0`0J6QX00`0I6AT061PH01PH600501TI6@0501PH600I6AT06QXJ01TI6@0J6QX00P0I6AT3
01PH60806ATI00@061PH01XJ6P0H61P061PH100I6AT0100H61P06ATI01TI6@0J6QX501TI6@0301XJ
6P0I6AT06ATI00<06ATI00@06QXJ01TI6@0I6AT06QXJ0P0I6AT02`0H61P06ATI01XJ6P0I6AT06QXJ
01TI6@0J6QX06ATI01XJ6P0I6AT06a/K00<06QXJ00<06ATI01XJ6P0I6AT00P0I6AT0100J6QX06a/K
01XJ6P0K6a/201XJ6P0901/K6`0I6AT06QXJ01XJ6P0K6a/06QXJ01/K6`0J6QX06ATI00806a/K00<0
6ATI01/K6`0K6a/00`0J6QX00`0K6a/06QXJ01XJ6P0501XJ6P0601/K6`0J6QX06QXJ01XJ6P0K6a/0
6ATI0`0K6a/00`0J6QX06a/K01XJ6P0301/K6`0301XJ6P0L71`06a/K008071`L00X06a/K01TI6@0K
6a/06a/K01`L700K6a/071`L01/K6`0J6QX06a/K0P0J6QX00`0L71`06QXJ01/K6`0201`L700501/K
6`0J6QX06a/K01`L700J6QX00P0K6a/00`0L71`06QXJ01XJ6P0601/K6`0301XJ6P0K6a/06a/K0080
6QXJ00@071`L01/K6`0K6a/06QXJ0`0K6a/401XJ6P<06a/K00D06ATI01`L700J6QX06ATI01/K6`03
01XJ6PH06a/K100J6QX00`0K6a/06ATI01XJ6P0201XJ6P<06a/K1`0J6QX01@0K6a/06QXJ01XJ6P0I
6AT06QXJ00806ATI00@061PH01TI6@0I6AT06ATI1@0J6QX00`0L71`06a/K01/K6`0201XJ6P0301TI
6@0J6QX06QXJ00<06ATI00@06QXJ01PH600I6AT06QXJ0`0I6AT01`0H61P06QXJ01PH600J6QX06ATI
01XJ6P0H61P00P0I6AT01P0H61P06ATI01TI6@0H61P06ATI01/K6`@06ATI00L061PH01TI6@0I6AT0
6QXJ01/K6`0J6QX061PH00806QXJ0P0I6AT201XJ6P0A01/K6`0L71`06a/K01`L700M7Ad07alO024Q
8@0X:2P0<C4a03Hf=P0e=CD0;Bd]02TY:@0S8b<08B4Q01hN7P0M7Ad00P0L71`02`0K6a/06QXJ01XJ
6P0I6AT06QXJ01TI6@0J6QX06a/K01XJ6P0I6AT06QXJ00@061PH00<06ATI01XJ6P3IfMT01@3IfMT1
00000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0`0I6AT00`0J6QX06ATI01XJ6P0201TI
6@0601PH600I6AT06ATI01XJ6P0I6AT06QXJ0`0I6AT201XJ6P0801TI6@0J6QX06ATI01TI6@0H61P0
6ATI01XJ6P0I6AT201PH60P06ATI00<061PH01TI6@0I6AT0100J6QX401TI6@0401XJ6P0I6AT06ATI
01XJ6P806ATI00`06QXJ01TI6@0I6AT06ATI01PH600J6QX06ATI01XJ6P0I6AT06QXJ01/K6`0I6AT3
01/K6`0701TI6@0J6QX06QXJ01/K6`0J6QX06ATI01XJ6P0201TI6@0401XJ6P0I6AT061PH01TI6@D0
6QXJ00<06a/K01XJ6P0J6QX00`0I6AT201XJ6P0301TI6@0J6QX06ATI00806ATI00H06QXJ01/K6`0K
6a/071`L01/K6`0J6QX701/K6`0301`L700K6a/06a/K00806QXJ0P0K6a/01@0J6QX06a/K01/K6`0K
6a/071`L00806QXJ0P0K6a/01P0J6QX06a/K01XJ6P0J6QX06a/K01`L70806a/K00<06QXJ01/K6`0L
71`00`0K6a/01P0J6QX06a/K01`L700J6QX06a/K01XJ6PD06a/K00<071`L01XJ6P0J6QX00P0K6a/0
100L71`06QXJ01XJ6P0L71`401/K6`0301XJ6P0K6a/06a/K00<06a/K00<071`L01/K6`0K6a/0200J
6QX201/K6`<06QXJ00<06a/K01XJ6P0J6QX00`0J6QX201/K6`0301TI6@0J6QX06QXJ00@06QXJ0P0K
6a/0100I6AT06QXJ01XJ6P0K6a/201XJ6P0401/K6`0I6AT06QXJ01/K6`806QXJ00<06ATI01XJ6P0J
6QX00`0J6QX00`0K6a/06QXJ01XJ6P0601XJ6P<06ATI00T061PH01XJ6P0I6AT06QXJ01TI6@0J6QX0
61PH01TI6@0J6QX01@0I6AT00`0H61P06QXJ01XJ6P0301TI6@0301PH600J6QX06QXJ008061PH00<0
6QXJ01TI6@0H61P0100I6AT0100J6QX06ATI01TI6@0H61P201TI6@0301PH600I6AT061PH00<06QXJ
00<06ATI01/K6`0L71`00P0N7Qh01P0T92@0:2PX02`/;00[:b/09bLW02HV9P808R8R00<07QhN01dM
7@0K6a/00P0J6QX0100K6a/06ATI01XJ6P0J6QX201TI6@0:01XJ6P0I6AT06ATI01TI6@0J6QX06ATI
01PH600J6QX05aLG01PH60H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@P0
6ATI00@06QXJ01TI6@0I6AT061PH0P0I6AT201PH60D06ATI0P0J6QX0100I6AT061PH01PH600H61P2
01XJ6P<06ATI00D06QXJ01PH600H61P061PH01TI6@0201XJ6P0301TI6@0H61P061PH00806QXJ0P0I
6AT201XJ6P806ATI0`0J6QX0100I6AT06QXJ01XJ6P0J6QX301TI6@0501XJ6P0I6AT06ATI01XJ6P0H
61P01@0K6a/01P0I6AT06QXJ01XJ6P0J6QX06a/K01TI6@H06QXJ0P0I6AT201XJ6P0601TI6@0J6QX0
6QXJ01/K6`0J6QX06ATI0`0J6QX0200K6a/06ATI01/K6`0I6AT06QXJ01TI6@0J6QX06ATI0P0J6QX0
0`0K6a/06QXJ01XJ6P0201XJ6P<06a/K00<06ATI01/K6`0J6QX0100K6a/0100L71`06QXJ01XJ6P0K
6a/201XJ6P0301/K6`0L71`06QXJ00806a/K0P0J6QX301/K6`0401XJ6P0K6a/06QXJ01/K6`@06QXJ
0`0K6a/01`0J6QX06a/K01XJ6P0J6QX06a/K01`L700K6a/00P0J6QX201/K6`806QXJ00@06a/K01TI
6@0K6a/06QXJ0P0K6a/01@0J6QX06a/K01/K6`0K6a/06QXJ00@06a/K00<06ATI01XJ6P0K6a/00P0J
6QX03@0K6a/06QXJ01/K6`0K6a/06QXJ01/K6`0J6QX06ATI01XJ6P0I6AT06a/K01XJ6P0K6a/00P0I
6AT01P0J6QX06a/K01XJ6P0K6a/06QXJ01/K6`@06QXJ00L06a/K01XJ6P0J6QX06QXJ01/K6`0J6QX0
6ATI00806QXJ00@06a/K01XJ6P0J6QX06QXJ0P0I6AT0100J6QX06ATI01TI6@0J6QX301TI6@806QXJ
00@06a/K01XJ6P0J6QX06QXJ0P0I6AT301XJ6P806ATI00@061PH01TI6@0K6a/061PH0`0J6QX201TI
6@0701PH600I6AT06ATI01PH600J6QX06ATI01XJ6P0401TI6@0301PH600I6AT061PH00806ATI00<0
61PH01TI6@0I6AT00`0I6AT00`0H61P06ATI01LG5`0201TI6@@06QXJ00<06ATI01/K6`0L71`00P0M
7Ad00`0P82008R8R028R8P0202<S8`04028R8P0Q8B40820P01hN7P<071`L1P0J6QX0100I6AT061PH
01TI6@0H61P301TI6@@061PH1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI
00<061PH01TI6@0J6QX00P0I6AT0100J6QX061PH01TI6@0J6QX401TI6@806QXJ00D061PH01TI6@0I
6AT06ATI01PH600301TI6@<061PH00@06QXJ01TI6@0I6AT06ATI0P0H61P01P0I6AT061PH01PH600J
6QX061PH01LG5`<06ATI00<061PH01XJ6P0I6AT00P0I6AT0100J6QX06ATI01TI6@0H61P201XJ6P03
01PH600I6AT06ATI00@06ATI0P0J6QX0100I6AT06QXJ01XJ6P0K6a/301`L700301/K6`0J6QX06QXJ
00806QXJ00L06ATI01XJ6P0J6QX06ATI01XJ6P0I6AT06a/K00806QXJ00<061PH01/K6`0K6a/01@0J
6QX201TI6@0701XJ6P0I6AT06ATI01/K6`0J6QX06a/K01XJ6P0201TI6@0301/K6`0J6QX06QXJ0080
6QXJ0`0K6a/0100I6AT06a/K01TI6@0J6QX301/K6`8071`L0P0J6QX201/K6`0301`L700K6a/06QXJ
00@06a/K00D071`L01/K6`0K6a/06a/K01`L700301/K6`0901`L700K6a/06QXJ01TI6@0K6a/06QXJ
01/K6`0J6QX06a/K008071`L1`0J6QX00`0I6AT06QXJ01/K6`0201/K6`0501XJ6P0L71`071`L01/K
6`0L71`00P0J6QX0200L71`06a/K01/K6`0K6a/06ATI01XJ6P0K6a/071`L0P0K6a/01@0L71`06a/K
01XJ6P0K6a/06QXJ00806a/K00H06QXJ01/K6`0J6QX06ATI01XJ6P0I6AT201/K6`806QXJ00@06a/K
01XJ6P0I6AT06QXJ0P0I6AT201/K6`806QXJ00@061PH01XJ6P0J6QX06ATI0P0J6QX201TI6@0301XJ
6P0I6AT06ATI00<06QXJ00@06ATI01/K6`0K6a/06QXJ0P0K6a/0100H61P06ATI01XJ6P0I6AT201XJ
6P0301/K6`0J6QX06QXJ00<06ATI00L061PH01XJ6P0H61P06ATI01LG5`0I6AT06QXJ008061PH0`0I
6AT01@0J6QX06ATI01XJ6P0H61P06ATI00806QXJ00H06ATI01PH600I6AT061PH01TI6@0H61P301TI
6@0401PH600J6QX06ATI01PH60H06ATI00<061PH01TI6@0J6QX00P0J6QX01`0K6a/06QXJ01XJ6P0K
6a/07AdM01`L700N7Qh00P0P82002`0Q8B40820P024Q8@0P82007alO01hN7P0M7Ad071`L01/K6`0J
6QX06a/K00806QXJ0`0I6AT01`0J6QX06ATI01TI6@0H61P06ATI01PH600I6AT00`0H61P60=WIf@40
00000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT301TI6@0<01XJ6P0I6AT06ATI01TI6@0J
6QX06ATI01PH600I6AT06QXJ01PH600I6AT061PH0P0I6AT00`0H61P06ATI01PH600501TI6@0401PH
600I6AT061PH01PH60806ATI00D05aLG01TI6@0I6AT06ATI01XJ6P0201TI6@0501XJ6P0H61P06ATI
01PH600J6QX00P0I6AT0100J6QX06ATI01XJ6P0I6AT201PH60@06ATI00<06QXJ01TI6@0J6QX01@0I
6AT0100J6QX06a/K01/K6`0M7Ad201`L700>01XJ6P0K6a/06ATI01TI6@0J6QX05aLG01/K6`0J6QX0
6a/K01XJ6P0I6AT06QXJ01TI6@0K6a/201XJ6P0<01PH600J6QX06ATI01TI6@0J6QX06ATI01XJ6P0I
6AT06QXJ01TI6@0K6a/06ATI0`0J6QX301TI6@0601/K6`0J6QX06QXJ01/K6`0I6AT06a/K0P0J6QX3
01/K6`0401XJ6P0K6a/06a/K01`L70806a/K00<06ATI01/K6`0I6AT00`0K6a/301XJ6P806a/K00@0
6ATI01`L700J6QX071`L0`0K6a/00`0L71`06QXJ01XJ6P0401/K6`0501XJ6P0I6AT06QXJ01XJ6P0K
6a/00`0J6QX01@0K6a/06ATI01XJ6P0J6QX06a/K00806QXJ0`0K6a/0100L71`06QXJ01XJ6P0J6QX2
01/K6`0<01XJ6P0I6AT06QXJ01XJ6P0K6a/06QXJ01/K6`0J6QX06ATI01XJ6P0K6a/071`L1P0J6QX0
3@0I6AT06QXJ01XJ6P0J6QX0820P01hN7P0I6AT06a/K01TI6@0H61P06QXJ01/K6`0I6AT01P0J6QX0
1`0I6AT06QXJ01/K6`0J6QX061PH01/K6`0J6QX01@0I6AT02@0J6QX06ATI01TI6@0J6QX06ATI01PH
600K6a/06QXJ01PH600201XJ6P806ATI0P0J6QX02P0I6AT06a/K01TI6@0I6AT06QXJ01TI6@0J6QX0
6ATI01XJ6P0H61P301TI6@0301XJ6P0I6AT06ATI008061PH00<06QXJ01PH600L71`0200I6AT00`0H
61P06ATI01PH600301TI6@0601PH600I6AT06ATI01XJ6P0I6AT06QXJ0P0I6AT201XJ6P806ATI00H0
6QXJ01/K6`0J6QX06a/K01XJ6P0L71`201dM7@807QhN00<07alO01dM7@0M7Ad00P0L71`00`0K6a/0
71`L01/K6`0201/K6`0301XJ6P0K6a/06QXJ00806ATI0P0J6QX00`0I6AT061PH01TI6@0401TI6@H0
fMWI0@0000010=WIf@005P3IfMT2000000@0fMWI0P0I6AT301PH60<06ATI00<061PH01TI6@0K6a/0
1@0I6AT301PH600301XJ6P0H61P06ATI008061PH0P0I6AT0200G5aL06ATI01TI6@0I6AT061PH01XJ
6P0H61P06a/K1`0I6AT0100J6QX061PH01TI6@0I6AT301XJ6P806ATI00D06QXJ01TI6@0I6AT06QXJ
01PH600801TI6@806QXJ0P0K6a/01@0L71`06a/K01TI6@0J6QX06ATI00806a/K0`0I6AT201XJ6P06
01PH600I6AT06ATI01TI6@0J6QX06ATI0`0J6QX00`0I6AT06QXJ01XJ6P0201TI6@0301/K6`0J6QX0
6a/K00@06QXJ0P0I6AT501XJ6P0601TI6@0J6QX06QXJ01/K6`0J6QX06a/K0P0J6QX0100K6a/06QXJ
01XJ6P0J6QX201/K6`0401XJ6P0K6a/06QXJ01TI6@<06a/K00<06QXJ01/K6`0J6QX00`0J6QX00`0L
71`06a/K01XJ6P0201XJ6P0501/K6`0J6QX06a/K01/K6`0J6QX0100K6a/00`0J6QX06a/K01XJ6P04
01/K6`0301`L700J6QX06a/K00806QXJ0`0K6a/0100J6QX06a/K01/K6`0I6AT201XJ6P0401/K6`0J
6QX06a/K01XJ6P806a/K00<06QXJ01/K6`0J6QX00P0J6QX00`0K6a/06QXJ01XJ6P0201/K6`0701XJ
6P0L71`06ATI01/K6`0I6AT06a/K01`L700301XJ6P<06ATI00L06a/K01TI6@0K6a/06a/K01XJ6P0K
6a/06ATI00806QXJ00T061PH01/K6`0J6QX06a/K01PH600J6QX06ATI01XJ6P0K6a/00P0J6QX01P0I
6AT06QXJ01TI6@0J6QX06ATI01XJ6P806ATI100J6QX0100I6AT06QXJ01TI6@0J6QX201TI6@806QXJ
00@061PH01XJ6P0J6QX06QXJ0P0I6AT00`0J6QX06ATI01PH600501TI6@0301PH600J6QX06ATI00@0
6ATI0P0H61P00`0I6AT06QXJ01TI6@0201PH600301XJ6P0H61P06ATI00806QXJ0P0I6AT0100H61P0
6ATI01TI6@0H61P201XJ6P0301TI6@0J6QX06a/K00<06QXJ00@071`L01dM7@0N7Qh07AdM0P0L71`2
01dM7@0301`L700M7Ad071`L00<06a/K1@0J6QX401TI6@0401PH600I6AT06ATI01PH60806ATI1@3I
fMT200000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00L06ATI01LG5`0H61P06ATI01XJ
6P0H61P06ATI008061PH0P0I6AT01@0J6QX061PH01TI6@0I6AT06QXJ00806ATI00D061PH01XJ6P0I
6AT061PH01LG5`0201TI6@0501PH600I6AT06QXJ01TI6@0H61P00`0I6AT01@0H61P06ATI01XJ6P0H
61P06QXJ00806ATI0`0H61P201TI6@0701PH600J6QX061PH01TI6@0J6QX061PH01XJ6P0201TI6@03
01XJ6P0H61P061PH00<06ATI00<061PH01XJ6P0J6QX00`0J6QX01`0K6a/06QXJ01TI6@0J6QX06ATI
01XJ6P0I6AT0100J6QX701TI6@<06QXJ100I6AT301XJ6P0601/K6`0J6QX06QXJ01XJ6P0H61P06a/K
0`0J6QX201/K6`0501XJ6P0I6AT06QXJ01XJ6P0K6a/00`0J6QX00`0K6a/06QXJ01XJ6P0501/K6`80
6QXJ00<06a/K01XJ6P0K6a/00P0K6a/301XJ6PD06a/K0P0J6QX0200K6a/06QXJ01/K6`0K6a/06QXJ
01/K6`0M7Ad06a/K100J6QX0100L71`06a/K01/K6`0K6a/201XJ6P<06a/K0P0J6QX00`0K6a/06QXJ
01/K6`0201/K6`0301TI6@0K6a/06a/K00806QXJ00H06a/K01TI6@0J6QX06a/K01XJ6P0K6a/201XJ
6P806ATI00<06QXJ01/K6`0J6QX00P0J6QX00`0K6a/06QXJ01XJ6P0301XJ6P0401/K6`0I6AT06QXJ
01TI6@H06QXJ00@06ATI01XJ6P0I6AT06ATI0P0J6QX0100K6a/06ATI01PH600J6QX201TI6@0301/K
6`0J6QX061PH00806ATI1P0J6QX0100I6AT06QXJ01/K6`0H61P401TI6@@06QXJ00L06ATI01XJ6P0J
6QX06ATI01XJ6P0I6AT05aLG00L06ATI0`0J6QX00`0I6AT06QXJ01TI6@0301XJ6P<06ATI0P0J6QX2
01TI6@0301PH600I6AT06ATI00<06ATI00L06QXJ01TI6@0I6AT05QHF01XJ6P0I6AT06QXJ00806ATI
00L06QXJ01TI6@0I6AT06a/K01`L700J6QX06a/K00<071`L00<06a/K01`L700L71`00P0K6a/0100L
71`06a/K01/K6`0J6QX501TI6@0601XJ6P0I6AT06ATI01XJ6P0H61P06QXJ0P0H61P60=WIf@400000
0@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0100I6AT061PH01TI6@0I6AT201PH600401XJ
6P0I6AT06ATI01XJ6P<06ATI00@061PH01XJ6P0I6AT061PH0P0J6QX00`0H61P06ATI01XJ6P0501TI
6@0:01XJ6P0I6AT06ATI01PH600J6QX061PH01LG5`0H61P06QXJ01TI6@806QXJ00L06ATI01PH600I
6AT061PH01TI6@0J6QX061PH00@06ATI00<061PH01TI6@0H61P00P0I6AT01P0H61P06ATI01TI6@0I
6AT06QXJ01TI6@806QXJ100I6AT0100H61P06ATI01XJ6P0I6AT401XJ6P806ATI00<06QXJ01TI6@0J
6QX00P0I6AT301XJ6P0501TI6@0J6QX061PH01XJ6P0I6AT00P0J6QX201TI6@0401XJ6P0I6AT06ATI
01TI6@D06QXJ00@06ATI01XJ6P0K6a/07AdM100J6QX201/K6`0301TI6@0K6a/06QXJ00806QXJ0P0K
6a/401XJ6P806a/K00<06QXJ01/K6`0K6a/00P0J6QX0400K6a/06QXJ01/K6`0K6a/06QXJ01/K6`0I
6AT06a/K01XJ6P0I6AT06a/K01`L700J6QX06a/K01`L700I6AT301XJ6P0301/K6`0J6QX06QXJ00<0
6QXJ00@06a/K01XJ6P0K6a/06QXJ0`0K6a/01@0J6QX071`L01`L700J6QX071`L00<06QXJ00@071`L
01XJ6P0J6QX06ATI1@0K6a/401XJ6P0501/K6`0J6QX06QXJ01/K6`0I6AT01P0J6QX00`0H61P06ATI
01TI6@0201TI6@806QXJ0P0I6AT00`0K6a/06ATI01TI6@0201/K6`0501XJ6P0K6a/06ATI01XJ6P0H
61P00P0I6AT201XJ6P0301TI6@0J6QX06ATI00806QXJ1@0I6AT501XJ6P0401TI6@0J6QX06QXJ01XJ
6P<06ATI00H061PH01TI6@0I6AT06QXJ01TI6@0K6a/201TI6@0301PH600G5aL06ATI00<06ATI00<0
61PH01TI6@0H61P00P0I6AT01`0H61P06ATI01XJ6P0I6AT061PH01TI6@0H61P00P0I6AT201PH6003
01TI6@0J6QX06ATI00<06ATI0P0J6QX201TI6@0301PH600I6AT06QXJ00806QXJ00D061PH01XJ6P0K
6a/071`L01/K6`0201`L700301TI6@0L71`06a/K00<06a/K00<06ATI01`L700J6QX00P0I6AT01`0J
6QX06ATI01TI6@0H61P06ATI01PH600I6AT00P0H61P201TI6@H0fMWI0@0000010=WIf@005P3IfMT0
0`000000fMWI0=WIf@030=WIf@@06ATI00D061PH01TI6@0I6AT05aLG01TI6@0201PH600401TI6@0H
61P06ATI01PH60806ATI0`0H61P201TI6@0901PH600I6AT06QXJ01PH600J6QX061PH01TI6@0J6QX0
61PH00806ATI00<061PH01TI6@0H61P00`0H61P00`0I6AT06QXJ01TI6@0701TI6@0401XJ6P0I6AT0
6QXJ01PH60D06ATI00<06QXJ01TI6@0I6AT00P0J6QX00`0I6AT06QXJ01XJ6P0301XJ6P0301PH600J
6QX06ATI00806QXJ00<06a/K01TI6@0I6AT0100I6AT01`0J6QX06a/K01TI6@0J6QX06ATI01PH600J
6QX00P0I6AT00`0K6a/06ATI01TI6@0201XJ6P0401/K6`0J6QX06QXJ01XJ6P806ATI00<06QXJ01/K
6`0I6AT00`0I6AT0200K6a/06QXJ01/K6`0L71`06a/K01XJ6P0K6a/06QXJ0`0K6a/201XJ6P0601/K
6`0J6QX06QXJ01XJ6P0L71`06a/K0P0J6QX01P0K6a/06ATI01/K6`0I6AT06QXJ01/K6`H06QXJ00L0
6a/K01XJ6P0K6a/06a/K01TI6@0K6a/06QXJ00806a/K00D06ATI01/K6`0K6a/06QXJ01TI6@0301/K
6`@06QXJ0P0K6a/201XJ6P806a/K00T06QXJ01/K6`0J6QX06QXJ01`L700J6QX06a/K01XJ6P0I6AT0
2@0J6QX00`0K6a/06QXJ01/K6`0501XJ6P806a/K0P0J6QX01@0I6AT06QXJ01XJ6P0I6AT06QXJ00<0
6ATI0`0J6QX0100I6AT06QXJ01TI6@0I6AT301XJ6P0301/K6`0H61P06QXJ00H06ATI00H06a/K01XJ
6P0J6QX06QXJ01/K6`0J6QX201TI6@0401XJ6P0I6AT06ATI01XJ6P806ATI100H61P201XJ6P0401PH
600I6AT06QXJ01XJ6P806ATI00<061PH01TI6@0I6AT01@0I6AT201PH600501TI6@0H61P061PH01TI
6@0J6QX00P0H61P01@0I6AT061PH01PH600I6AT061PH00H06ATI00@061PH01TI6@0I6AT061PH0P0J
6QX01P0K6a/06QXJ01XJ6P0J6QX06a/K01XJ6PH06a/K100J6QX0100K6a/06ATI01TI6@0J6QX201TI
6@806QXJ0`0I6AT201PH600301TI6@3IfMT0fMWI00@0fMWI0@0000010=WIf@005P3IfMT00`000000
fMWI0=WIf@030=WIf@0301PH600I6AT061PH00806ATI00D06QXJ01TI6@0I6AT061PH01TI6@0201PH
600601TI6@0H61P06ATI01TI6@0J6QX06ATI0P0H61P01@0I6AT061PH01PH600I6AT061PH00P06ATI
100H61P01`0I6AT061PH01PH600J6QX061PH01TI6@0J6QX00P0I6AT0100J6QX06ATI01PH600I6AT3
01PH600301TI6@0H61P061PH00806ATI00<061PH01TI6@0I6AT00P0I6AT0100J6QX06ATI01TI6@0I
6AT201XJ6P0801PH600I6AT06ATI01XJ6P0I6AT06QXJ01TI6@0J6QX201TI6@D06QXJ00<06ATI01XJ
6P0I6AT00P0I6AT01P0J6QX06a/K01XJ6P0K6a/06ATI01XJ6P806ATI00@061PH01TI6@0H61P06QXJ
0`0I6AT01@0J6QX06ATI01XJ6P0L71`06QXJ00806a/K00H06QXJ01/K6`0K6a/06QXJ01/K6`0J6QX2
01/K6`806QXJ0`0K6a/00`0J6QX06a/K01XJ6P0201/K6`0401XJ6P0K6a/06QXJ01/K6`806QXJ00@0
6a/K01XJ6P0I6AT06ATI0`0J6QX201/K6`0301TI6@0J6QX071`L00806a/K0P0J6QX201/K6`@06QXJ
00H06ATI01XJ6P0I6AT06ATI01XJ6P0K6a/201XJ6P0301/K6`0J6QX06QXJ00806a/K00@06QXJ01/K
6`0K6a/06a/K0`0J6QX01`0I6AT06QXJ01XJ6P0I6AT06a/K01XJ6P0K6a/00P0J6QX201/K6`806QXJ
0`0I6AT401XJ6P0401TI6@0J6QX06QXJ01XJ6P806ATI0P0J6QX201TI6@806QXJ00@061PH01TI6@0J
6QX06QXJ0`0I6AT0100J6QX06ATI01XJ6P0J6QX301TI6@0501XJ6P0I6AT06ATI01XJ6P0I6AT00P0K
6a/00`0J6QX06ATI01PH600401TI6@0501XJ6P0H61P06ATI01TI6@0G5aL00P0H61P00`0J6QX061PH
01XJ6P0301TI6@0401XJ6P0I6AT061PH01TI6@@061PH00<06QXJ01TI6@0I6AT02@0I6AT0100H61P0
6ATI01PH600J6QX301TI6@0301PH600G5aL06QXJ00@06ATI0P0J6QX201TI6@806QXJ00D06a/K01XJ
6P0I6AT06a/K01`L700501XJ6P0301/K6`0J6QX06QXJ00806QXJ1P0I6AT201PH600301TI6@3IfMT0
fMWI00@0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@D06ATI00@06QXJ01TI
6@0I6AT06QXJ1P0I6AT0200J6QX061PH01XJ6P0I6AT06QXJ01PH600J6QX061PH1P0I6AT00`0J6QX0
6ATI01PH600301TI6@0701PH600I6AT061PH01TI6@0H61P06ATI01XJ6P0301TI6@0301PH600I6AT0
61PH00806ATI00@061PH01TI6@0H61P06ATI0P0H61P301TI6@0501PH600K6a/061PH01PH600J6QX0
1@0I6AT301XJ6P<06ATI00D06QXJ01TI6@0H61P06QXJ01TI6@0201XJ6P0401/K6`0I6AT06ATI01TI
6@@06QXJ00D061PH01TI6@0I6AT06ATI01PH600201TI6@806QXJ00L06ATI01XJ6P0I6AT06QXJ01TI
6@0J6QX06a/K00<06QXJ0P0I6AT00`0J6QX06a/K01TI6@0201XJ6P0401/K6`0I6AT06QXJ01TI6@80
6QXJ00<06ATI01/K6`0I6AT00P0J6QX301/K6`0701TI6@0J6QX06QXJ01XJ6P0I6AT06a/K01XJ6P02
01/K6`0801XJ6P0K6a/06QXJ01/K6`0L71`06QXJ01/K6`0I6AT201XJ6P0301/K6`0J6QX06ATI0080
6a/K1P0J6QX201/K6`<06QXJ00@06a/K01TI6@0I6AT06QXJ0P0I6AT201XJ6P806ATI00d06QXJ01`L
700J6QX06a/K01XJ6P0K6a/06QXJ01`L700J6QX06a/K01XJ6P0H61P06QXJ00806a/K00L06QXJ01TI
6@0J6QX06QXJ01TI6@0J6QX06ATI00D06QXJ0P0I6AT00`0J6QX061PH01XJ6P0201XJ6P0501PH600I
6AT06QXJ01XJ6P0K6a/00P0J6QX301TI6@0301PH600I6AT06QXJ00806QXJ00@06ATI01/K6`0J6QX0
6a/K100I6AT00`0J6QX06ATI01TI6@0201XJ6P<06ATI00<061PH01TI6@0H61P00`0I6AT0100H61P0
6ATI01PH600H61P201TI6@8061PH00<06ATI01PH600I6AT01P0I6AT00`0K6a/06ATI01TI6@0301PH
600501XJ6P0I6AT061PH01PH600I6AT00P0H61P01P0I6AT061PH01TI6@0H61P05aLG01PH60806ATI
00<061PH01XJ6P0I6AT00P0J6QX02@0K6a/06ATI01XJ6P0I6AT06QXJ01`L700K6a/06QXJ01TI6@03
01XJ6P0=01PH600I6AT06ATI01TI6@0H61P06QXJ01TI6@0J6QX06ATI01PH600I6AT061PH01TI6@06
0=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT00`0I6AT061PH01TI6@0301TI
6@8061PH0P0I6AT01`0J6QX06ATI01PH600I6AT06a/K01TI6@0H61P00P0I6AT01@0J6QX06ATI01XJ
6P0I6AT061PH00806ATI00<061PH01TI6@0K6a/00`0I6AT01`0H61P06ATI01TI6@0H61P06ATI01PH
600J6QX00P0I6AT01@0H61P06ATI01TI6@0I6AT06QXJ00806ATI0P0H61P301TI6@0401PH600J6QX0
6QXJ01XJ6P806ATI0P0J6QX00`0I6AT06QXJ01TI6@0601TI6@0701XJ6P0I6AT06ATI01XJ6P0H61P0
6ATI01PH600301XJ6P0301TI6@0J6QX06QXJ00806QXJ0P0K6a/00`0I6AT06QXJ01XJ6P0201/K6`80
6ATI00<06QXJ01TI6@0J6QX00P0I6AT601XJ6P0501/K6`0I6AT06QXJ01TI6@0J6QX0100K6a/501XJ
6P0601/K6`0J6QX06QXJ01XJ6P0K6a/06QXJ0`0K6a/201XJ6P0501/K6`0J6QX06ATI01XJ6P0K6a/0
0P0J6QX01@0K6a/06QXJ01XJ6P0J6QX06a/K00<06QXJ00D06ATI01XJ6P0J6QX06ATI01/K6`0201XJ
6P806a/K00<06ATI01/K6`0J6QX0100K6a/00`0I6AT06QXJ01XJ6P0501XJ6P0<01/K6`0I6AT06QXJ
01XJ6P0I6AT06QXJ01/K6`0J6QX06ATI01XJ6P0K6a/06QXJ0P0K6a/301XJ6P0501`L700J6QX06a/K
01/K6`0J6QX00P0I6AT401XJ6P0301TI6@0K6a/06ATI00@06QXJ00<061PH01XJ6P0I6AT00P0J6QX0
1@0I6AT06QXJ01TI6@0J6QX07AdM00<06QXJ00H061PH01TI6@0J6QX06ATI01XJ6P0H61P201TI6@80
6QXJ00@06a/K01TI6@0J6QX061PH0P0I6AT201XJ6P0601TI6@0J6QX06ATI01LG5`0I6AT06QXJ0`0I
6AT01P0H61P06ATI01TI6@0H61P06ATI01PH60<06ATI0P0H61P701TI6@0401XJ6P0I6AT06ATI01XJ
6P@06ATI00@061PH01TI6@0I6AT061PH0P0J6QX01`0I6AT06QXJ01PH600H61P06ATI01XJ6P0H61P0
0P0I6AT301XJ6P0401PH600I6AT06QXJ01XJ6P<06a/K0P0I6AT201XJ6P806ATI00H06QXJ01TI6@0J
6QX06QXJ01PH600J6QX301TI6@0401PH600I6AT06ATI01PH60H0fMWI0@0000010=WIf@005P3IfMT0
0`000000fMWI0=WIf@030=WIf@H06ATI00P06QXJ01TI6@0H61P061PH01TI6@0J6QX061PH01TI6@80
6QXJ0P0I6AT01P0H61P06ATI01PH600H61P06ATI01XJ6PX06ATI00T061PH01TI6@0H61P061PH01XJ
6P0I6AT061PH01TI6@0J6QX00`0H61P00`0I6AT061PH01XJ6P0301TI6@0301PH600J6QX06ATI0080
6ATI0P0H61P01@0J6QX06ATI01XJ6P0I6AT06QXJ00@06ATI00D06QXJ01TI6@0I6AT06QXJ01/K6`04
01TI6@806QXJ00<061PH01XJ6P0I6AT00P0I6AT201XJ6P0301TI6@0K6a/06a/K00D06QXJ0`0I6AT0
0`0H61P06QXJ01TI6@0:01XJ6P0501/K6`0J6QX06a/K01/K6`0I6AT0100J6QX201TI6@806QXJ00@0
6a/K01XJ6P0K6a/06a/K100J6QX201TI6@806QXJ00D06ATI01XJ6P0J6QX06QXJ01/K6`0201XJ6P04
01/K6`0J6QX06QXJ01TI6@<06QXJ0P0K6a/01@0J6QX06ATI01XJ6P0J6QX06a/K00P06QXJ00@06a/K
01XJ6P0K6a/06ATI0P0J6QX00`0I6AT06QXJ01XJ6P0501XJ6P0;01TI6@0J6QX06a/K01/K6`0I6AT0
6QXJ01TI6@0J6QX06a/K01XJ6P0K6a/00P0I6AT01@0K6a/06ATI01TI6@0I6AT06QXJ00@06ATI00<0
6QXJ01/K6`0J6QX00`0I6AT01P0K6a/06ATI01XJ6P0J6QX06ATI01XJ6P<06ATI00@06QXJ01TI6@0J
6QX06ATI0`0J6QX301TI6@0301XJ6P0K6a/06a/K00806QXJ0`0H61P401TI6@0401PH600I6AT06QXJ
01PH60H06ATI00@06QXJ01TI6@0J6QX061PH0P0I6AT201PH60D06ATI00<061PH01XJ6P0H61P00P0J
6QX201TI6@0301LG5`0I6AT061PH00806ATI00L06QXJ01TI6@0I6AT061PH01TI6@0H61P06ATI0080
61PH1@0I6AT0100J6QX06ATI01TI6@0I6AT401XJ6P0301/K6`0J6QX06QXJ00@06QXJ00<06ATI01PH
600H61P00`0H61P00`0I6AT061PH01PH600201PH600301TI6@0H61P0fMWI00D0fMWI0@0000010=WI
f@005P3IfMT00`000000fMWI0=WIf@030=WIf@806ATI00<061PH01TI6@0I6AT00P0J6QX00`0H61P0
6QXJ01XJ6P0201XJ6P0301TI6@0H61P06ATI00806ATI00D06QXJ01TI6@0H61P06ATI01PH600301TI
6@0301PH600I6AT06ATI00<061PH00<06ATI01PH600H61P0100I6AT01@0H61P06ATI01TI6@0J6QX0
6ATI00806QXJ00@061PH01TI6@0I6AT061PH0P0I6AT201PH600501/K6`0H61P061PH01TI6@0H61P0
1@0I6AT0100J6QX06ATI01TI6@0H61P201TI6@0601XJ6P0I6AT06QXJ01/K6`0J6QX06ATI0`0J6QX0
0`0I6AT06a/K01TI6@0201XJ6P@06ATI00@06QXJ01PH600J6QX06ATI0P0J6QX00`0K6a/06QXJ01TI
6@0301TI6@0301/K6`0J6QX06QXJ00806QXJ0P0I6AT02P0J6QX06ATI01XJ6P0K6a/06QXJ01TI6@0J
6QX06a/K01XJ6P0L71`201XJ6P0601TI6@0J6QX06a/K01/K6`0J6QX06a/K300J6QX201TI6@0301/K
6`0J6QX06a/K00806QXJ00T071`L01XJ6P0J6QX06QXJ01/K6`0I6AT06QXJ01/K6`0I6AT00`0J6QX0
200K6a/06QXJ01/K6`0J6QX06ATI01XJ6P0K6a/06ATI0P0J6QX0100I6AT06a/K01/K6`0J6QX301TI
6@0301/K6`0J6QX06QXJ00<06QXJ00<06a/K01TI6@0L71`00P0J6QX01@0K6a/06QXJ01TI6@0J6QX0
6ATI00<06QXJ00<06ATI01XJ6P0I6AT00P0I6AT01@0J6QX06ATI01TI6@0J6QX06ATI00@06QXJ0P0I
6AT0100H61P06QXJ01TI6@0H61P201XJ6P0401TI6@0J6QX06QXJ01XJ6P806ATI00X06QXJ01TI6@0I
6AT06ATI01XJ6P0I6AT06QXJ01TI6@0J6QX06ATI0P0H61P201/K6`0301XJ6P0I6AT06ATI00806ATI
00<06QXJ01TI6@0I6AT00P0H61P00`0I6AT061PH01TI6@0301TI6@0=01PH600I6AT06ATI01TI6@0K
6a/06ATI01PH600I6AT06QXJ01PH600J6QX06ATI01PH600901TI6@8061PH00<06ATI01PH600I6AT0
0P0I6AT201PH600301TI6@0H61P06ATI00@06ATI0`0J6QX201TI6@806QXJ00H06ATI01XJ6P0J6QX0
6QXJ01TI6@0H61P201TI6@0901PH600J6QX06ATI01TI6@0K6a/06ATI01PH600I6AT061PH00<06ATI
1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00<061PH01XJ6P0I6AT00P0I
6AT01P0J6QX06ATI01TI6@0I6AT06a/K01PH60<06ATI0`0H61P201TI6@0401PH600I6AT06ATI01PH
60@06ATI00D06QXJ01TI6@0H61P06ATI01PH600301TI6@806QXJ00@06ATI01PH600J6QX061PH100I
6AT0100H61P06ATI01TI6@0H61P301TI6@0501PH600I6AT06ATI01TI6@0J6QX0100I6AT01@0H61P0
6ATI01PH600H61P06ATI00806QXJ0P0I6AT00`0J6QX06ATI01TI6@0301XJ6P806ATI00T061PH01TI
6@0J6QX06ATI01PH600I6AT06QXJ01TI6@0J6QX00`0I6AT301XJ6P806ATI00D06QXJ01TI6@0J6QX0
61PH01TI6@0301XJ6P0501TI6@0J6QX06QXJ01TI6@0K6a/00P0J6QX00`0I6AT06a/K01XJ6P0501XJ
6P0601`L700J6QX06a/K01/K6`0J6QX06a/K100J6QX01@0K6a/06QXJ01XJ6P0J6QX06ATI00<06QXJ
00P06ATI01XJ6P0J6QX06QXJ01TI6@0J6QX06a/K01TI6@<06QXJ00D06ATI01XJ6P0J6QX06QXJ01/K
6`0201XJ6P0501TI6@0J6QX06QXJ01XJ6P0I6AT00P0J6QX0100K6a/06QXJ01XJ6P0I6AT401XJ6P05
01TI6@0J6QX06QXJ01TI6@0K6a/00P0J6QX0100I6AT06QXJ01XJ6P0I6AT401XJ6P0301/K6`0J6QX0
6QXJ00<06QXJ100I6AT301XJ6P@06ATI00L061PH01TI6@0J6QX06ATI01XJ6P0I6AT06QXJ00806ATI
00<06QXJ01TI6@0H61P00`0H61P0100K6a/061PH01PH600I6AT201XJ6P<06ATI00<06QXJ01TI6@0I
6AT0100I6AT00`0H61P06ATI01TI6@0501TI6@0601XJ6P0G5aL061PH01XJ6P0H61P06QXJ0P0I6AT0
0`0H61P06ATI01PH600201XJ6P0401PH600I6AT061PH01PH60806ATI00H061PH01LG5`0J6QX06ATI
01PH600J6QX201TI6@0301PH600G5aL061PH008061PH00<05aLG01PH600G5aL00P0I6AT201XJ6P03
01PH600I6AT06ATI00806ATI00<06QXJ01TI6@0J6QX00P0I6AT01@0J6QX06ATI01XJ6P0J6QX06ATI
00806QXJ00L06a/K01XJ6P0I6AT06QXJ01PH600J6QX06ATI00806QXJ0`0I6AT0100J6QX061PH01TI
6@0H61P201TI6@H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@D06ATI0P0J
6QX01`0H61P06ATI01TI6@0I6AT06QXJ01TI6@0H61P00P0J6QX0100I6AT061PH01/K6`0H61P401TI
6@0301XJ6P0I6AT06ATI00<06ATI00<061PH01TI6@0J6QX01@0I6AT01@0H61P06ATI01TI6@0I6AT0
61PH00P06ATI00L05aLG01PH600H61P06ATI01PH600I6AT061PH00<06ATI0`0J6QX01`0I6AT061PH
01XJ6P0I6AT061PH01XJ6P0H61P0100I6AT00`0K6a/06QXJ01TI6@0301TI6@806QXJ0`0I6AT00`0J
6QX06ATI01/K6`0201XJ6P0501TI6@0J6QX06ATI01PH600J6QX00P0I6AT01P0J6QX06ATI01TI6@0J
6QX06ATI01/K6`@06QXJ00D06a/K01XJ6P0K6a/06ATI01XJ6P0301/K6`<06QXJ0`0I6AT0100J6QX0
6a/K01XJ6P0K6a/201XJ6P806ATI100J6QX201TI6@806a/K0`0J6QX00`0I6AT06QXJ01TI6@0201TI
6@806QXJ00<06a/K01TI6@0K6a/01@0J6QX00`0K6a/06QXJ01XJ6P0201TI6@0301/K6`0J6QX06ATI
00806QXJ00@06a/K01XJ6P0J6QX06QXJ1@0I6AT01P0J6QX06ATI01/K6`0J6QX06ATI01XJ6P806ATI
100J6QX01@0I6AT06QXJ01XJ6P0J6QX06ATI00H06QXJ0P0I6AT201XJ6P0301TI6@0H61P06ATI00@0
6ATI0`0J6QX201TI6@0:01XJ6P0I6AT06ATI01XJ6P0I6AT06QXJ01PH600J6QX06ATI01XJ6P806ATI
00H06QXJ01PH600I6AT05aLG01TI6@0J6QX201TI6@0301PH600I6AT061PH00<061PH0`0J6QX201PH
600501TI6@0J6QX06ATI01XJ6P0G5aL00P0H61P00`0I6AT06QXJ01TI6@0301TI6@0601PH600I6AT0
6QXJ01PH600I6AT061PH0P0I6AT01P0H61P06ATI01LG5`0I6AT06QXJ01TI6@8061PH00@06ATI01PH
600I6AT061PH0P0I6AT00`0J6QX06ATI01XJ6P0201TI6@0601PH600I6AT06ATI01TI6@0J6QX06ATI
0P0J6QX00`0G5aL06QXJ01TI6@0201TI6@0701XJ6P0I6AT06ATI01XJ6P0H61P06QXJ01PH600301XJ
6P0301TI6@0H61P06ATI008061PH00<06ATI0=WIf@3IfMT0103IfMT100000040fMWI000F0=WIf@03
0000003IfMT0fMWI00<0fMWI00<061PH01TI6@0H61P00P0I6AT00`0J6QX06ATI01XJ6P0201TI6@03
01XJ6P0H61P061PH00806ATI0P0H61P00`0I6AT06QXJ01TI6@0301PH600601TI6@0H61P06ATI01PH
600I6AT061PH0P0I6AT01P0H61P06ATI01XJ6P0J6QX06ATI01PH60@06ATI1@0H61P00`0I6AT06QXJ
01XJ6P0301TI6@0601XJ6P0H61P061PH01TI6@0H61P05aLG0`0I6AT02@0H61P06a/K01TI6@0I6AT0
61PH01TI6@0H61P06QXJ01PH600401TI6@806QXJ2P0I6AT201XJ6P@06ATI0P0K6a/01@0J6QX061PH
01TI6@0J6QX06ATI00806QXJ00<06ATI01XJ6P0I6AT00`0J6QX201/K6`806QXJ0P0K6a/501XJ6P03
01/K6`0J6QX06a/K00<06QXJ00/06ATI01/K6`0K6a/06ATI01XJ6P0L71`06a/K01TI6@0K6a/06QXJ
01TI6@0201XJ6P0301TI6@0J6QX06QXJ00806QXJ0P0I6AT00`0K6a/06QXJ01XJ6P0201XJ6P0301TI
6@0J6QX06QXJ00@06QXJ00@06a/K01XJ6P0J6QX06a/K0P0I6AT401XJ6P0301/K6`0I6AT06QXJ00<0
6QXJ00L06ATI01XJ6P0J6QX06QXJ01TI6@0J6QX06ATI00806QXJ00L06ATI01XJ6P0J6QX06QXJ01TI
6@0J6QX06a/K00@06ATI00<06a/K01XJ6P0J6QX00P0J6QX01`0I6AT06QXJ01XJ6P0I6AT06QXJ01TI
6@0J6QX00P0I6AT00`0J6QX06ATI01/K6`0201TI6@0301XJ6P0K6a/06ATI008061PH200I6AT00`0J
6QX06ATI01TI6@0301PH60<06ATI00@061PH01TI6@0I6AT061PH0P0I6AT201XJ6PH06ATI00@06QXJ
01TI6@0I6AT06ATI0P0H61P201TI6@0301LG5`0H61P06QXJ00806ATI00@061PH01TI6@0I6AT061PH
0P0I6AT201LG5`0501TI6@0H61P061PH01TI6@0H61P00P0I6AT0100H61P06ATI01TI6@0I6AT201PH
600401TI6@0J6QX05aLG01XJ6P806ATI00h061PH01XJ6P0J6QX06QXJ01TI6@0J6QX06ATI01PH600I
6AT06a/K01XJ6P0I6AT06QXJ01PH60806ATI00H06QXJ01TI6@0I6AT05aLG01PH600J6QX201TI6@03
01PH600I6AT06ATI00H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@806ATI
0P0H61P0100I6AT06QXJ01PH600K6a/501TI6@0301XJ6P0I6AT061PH00<06ATI0P0H61P301TI6@05
01XJ6P0I6AT06QXJ01PH600I6AT00P0H61P01`0J6QX06ATI01XJ6P0I6AT061PH01/K6`0H61P00P0I
6AT00`0J6QX061PH01TI6@0301TI6@0301LG5`0I6AT06ATI00806ATI00@061PH01TI6@0I6AT06QXJ
1@0I6AT0100H61P06QXJ01TI6@0J6QX301TI6@0:01/K6`0J6QX06ATI01TI6@0H61P05aLG01PH600I
6AT06QXJ01TI6@806QXJ100I6AT01@0K6a/06ATI01XJ6P0J6QX06ATI00<06QXJ00`06ATI01XJ6P0J
6QX06ATI01XJ6P0I6AT06a/K01XJ6P0I6AT06QXJ01PH600J6QX201TI6@0401/K6`0J6QX061PH01TI
6@806QXJ00<06ATI01XJ6P0I6AT00P0J6QX301TI6@0801/K6`0I6AT06QXJ01TI6@0J6QX06a/K01XJ
6P0I6AT401XJ6P0903De=@0M7Ad06QXJ01XJ6P0H61P06QXJ01/K6`0I6AT06QXJ00806ATI00@06a/K
01XJ6P0J6QX06a/K0`0J6QX01@0I6AT06QXJ01XJ6P0J6QX06a/K00806ATI00<071`L01/K6`0J6QX0
0P0I6AT201XJ6P0301TI6@0K6a/06a/K00<06QXJ00h06ATI01XJ6P0I6AT06QXJ01TI6@0K6a/06QXJ
01TI6@0K6a/06QXJ01PH600J6QX06a/K01TI6@806QXJ00L06ATI01XJ6P0I6AT06ATI01XJ6P0I6AT0
61PH00D06ATI00P06QXJ01TI6@0K6a/06ATI01XJ6P0H61P06a/K01TI6@806QXJ0P0I6AT00`0H61P0
6ATI01TI6@0201XJ6P@06ATI00@06a/K01TI6@0H61P06ATI0`0H61P00`0J6QX06ATI01TI6@0201TI
6@0401XJ6P0I6AT06ATI01PH60<06ATI00<061PH01TI6@0I6AT0100I6AT0100J6QX061PH01TI6@0H
61P201TI6@0301LG5`0I6AT06QXJ00@06ATI100H61P00`0I6AT061PH01XJ6P0301TI6@8061PH00<0
5aLG01TI6@0I6AT00`0J6QX301TI6@0501PH600I6AT061PH01TI6@0H61P00P0J6QX01@0I6AT06QXJ
01TI6@0H61P06ATI00<06QXJ00@06ATI01PH600I6AT06QXJ1@0I6AT201XJ6P<06ATI00<06QXJ01TI
6@0H61P00`0I6AT00`0H61P0fMWI0=WIf@040=WIf@4000000@3IfMT001H0fMWI0P0000040=WIf@06
01TI6@0H61P06ATI01PH600I6AT061PH0P0I6AT01P0K6a/06ATI01TI6@0H61P06ATI01PH60D06ATI
00D061PH01TI6@0J6QX06ATI01XJ6P0401PH600501XJ6P0I6AT061PH01XJ6P0I6AT00P0J6QX201TI
6@0801PH600I6AT06ATI01TI6@0H61P06QXJ01TI6@0J6QX201TI6@0901PH600I6AT061PH01TI6@0H
61P06QXJ01TI6@0H61P06QXJ00H06ATI0P0H61P01P0I6AT06QXJ01TI6@0I6AT061PH01XJ6P<06ATI
00D061PH01TI6@0J6QX06QXJ01PH600301TI6@0301XJ6P0I6AT05aLG00806ATI00<06QXJ01TI6@0K
6a/00P0I6AT401XJ6P0301/K6`0I6AT06QXJ00D06ATI00<06QXJ01TI6@0J6QX00P0J6QX00`0I6AT0
6a/K01TI6@0201TI6@<06QXJ00<06ATI01XJ6P0J6QX00`0J6QX00`0I6AT06QXJ01TI6@0401XJ6P04
01/K6`0J6QX06QXJ01/K6`@06QXJ00D06ATI01XJ6P0I6AT06QXJ01TI6@0301XJ6P0301TI6@0J6QX0
6ATI00<06QXJ0P0I6AT201XJ6P0701TI6@0K6a/06ATI01XJ6P0I6AT061PH01/K6`0301XJ6P0301/K
6`0I6AT06a/K00806ATI1@0J6QX00`0I6AT06QXJ01XJ6P0201TI6@0301XJ6P0I6AT06QXJ00806QXJ
00@06ATI01/K6`0J6QX06ATI0P0J6QX00`0I6AT06QXJ01TI6@0201XJ6P0401/K6`0I6AT06a/K01XJ
6P806ATI00<06QXJ01TI6@0J6QX0100I6AT0100J6QX06ATI01XJ6P0I6AT201PH60806ATI00L061PH
01XJ6P0I6AT06ATI01XJ6P0I6AT06QXJ00D06ATI00P06QXJ01TI6@0I6AT061PH01TI6@0H61P06QXJ
01TI6@@061PH00H06ATI01PH600J6QX06QXJ01TI6@0H61P401TI6@0901PH600J6QX061PH01TI6@0H
61P06ATI01XJ6P0H61P06QXJ00806ATI00@06QXJ01TI6@0I6AT06ATI0`0H61P01P0I6AT06QXJ01TI
6@0J6QX06ATI01LG5`H06ATI00<061PH01TI6@0I6AT00`0I6AT201PH60<06ATI00D06QXJ01PH600I
6AT06QXJ01TI6@0201XJ6P@06ATI0P0J6QX0100I6AT06QXJ01TI6@0J6QX201PH600301TI6@0H61P0
61PH00D0fMWI0P0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0401PH600J6QX06QXJ
01PH60@06ATI00@061PH01XJ6P0I6AT06ATI0P0J6QX00`0H61P06ATI01TI6@0201TI6@0301XJ6P0I
6AT06ATI00<061PH00@06ATI01PH600I6AT06ATI0P0H61P00`0I6AT06QXJ01TI6@0201PH60D06ATI
00D061PH01TI6@0H61P061PH01TI6@0201PH60806ATI00@06QXJ01TI6@0I6AT061PH1P0I6AT00`0H
61P06ATI01TI6@0201TI6@806QXJ00<06ATI01PH600I6AT00P0I6AT00`0H61P06ATI01TI6@0201TI
6@0301XJ6P0I6AT06ATI00806ATI00@061PH01XJ6P0J6QX06QXJ0P0I6AT00`0J6QX061PH01TI6@03
01XJ6P0401TI6@0H61P06ATI01TI6@D06QXJ00/06ATI01XJ6P0J6QX06ATI01XJ6P0K6a/06ATI01XJ
6P0K6a/06ATI01`L700301XJ6P0501/K6`0J6QX06QXJ01TI6@0J6QX00P0I6AT201XJ6P0301/K6`0J
6QX06QXJ00806QXJ00<06ATI01XJ6P0K6a/00`0J6QX00`0I6AT06QXJ01TI6@0401XJ6P0901TI6@0J
6QX06ATI01XJ6P0I6AT06QXJ01TI6@0J6QX06a/K00806QXJ00<06a/K01TI6@0J6QX00P0J6QX03@0I
6AT06QXJ01PH600K6a/06ATI01/K6`0J6QX06a/K01XJ6P0I6AT06QXJ01/K6`0J6QX00P0K6a/01P0J
6QX06ATI01TI6@0J6QX06ATI01XJ6P<06ATI00@06QXJ01/K6`0J6QX06ATI2@0J6QX201TI6@0301PH
600I6AT061PH00806QXJ1@0I6AT0100J6QX06ATI01TI6@0K6a/201PH600501TI6@0J6QX06QXJ01TI
6@0H61P00P0J6QX201PH600401XJ6P0H61P061PH01PH60806QXJ100I6AT01P0J6QX061PH01TI6@0I
6AT06QXJ01PH60D06ATI00@061PH01TI6@0I6AT06QXJ0P0H61P01P0I6AT06QXJ01XJ6P0I6AT061PH
01TI6@8061PH00H06QXJ01PH600I6AT06QXJ01TI6@0H61P301TI6@0601PH600I6AT06ATI01TI6@0J
6QX06ATI0P0H61P0100I6AT061PH01XJ6P0I6AT201PH60H06ATI00<06QXJ01TI6@0I6AT00`0I6AT0
1@0J6QX06ATI01XJ6P0J6QX061PH00<06ATI00@061PH01TI6@0I6AT06ATI0P0H61P0100I6AT06QXJ
01TI6@0H61P201TI6@H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0501TI
6@0H61P06ATI01TI6@0H61P00P0I6AT0100H61P06QXJ01PH600H61P201TI6@0401PH600I6AT06ATI
01XJ6P@06ATI00@061PH01TI6@0H61P06ATI0`0H61P0300I6AT061PH01TI6@0H61P06QXJ01PH600I
6AT06QXJ01TI6@0H61P06ATI01PH60<06ATI00H061PH01TI6@0H61P06QXJ01TI6@0G5aL201PH6005
01XJ6P0H61P061PH01TI6@0H61P00P0J6QX501TI6@0301XJ6P0I6AT06ATI00806QXJ3@0I6AT00`0J
6QX061PH01TI6@0201TI6@0301PH600I6AT06ATI00806QXJ0`0I6AT201XJ6P0401TI6@0J6QX06ATI
01XJ6P<06ATI00@06QXJ01TI6@0J6QX06a/K0`0I6AT301XJ6P806a/K0P0J6QX01@0I6AT06QXJ01XJ
6P0I6AT06QXJ00<06a/K00<06ATI01XJ6P0I6AT00P0J6QX00`0I6AT07AdM01XJ6P0201XJ6P0501`L
700J6QX06QXJ01PH600J6QX00P0I6AT201/K6`<06ATI0P0J6QX201TI6@0301/K6`0J6QX06ATI00H0
6QXJ00<06ATI01XJ6P0I6AT00`0I6AT00`0J6QX06ATI01XJ6P0201XJ6P0301/K6`0J6QX06QXJ0080
6ATI0`0J6QX01@0K6a/06ATI01XJ6P0J6QX06ATI00@06QXJ00<06ATI01/K6`0I6AT00P0I6AT201XJ
6P<06ATI00@06QXJ01TI6@0I6AT06ATI0P0J6QX701TI6@0501XJ6P0I6AT06ATI01TI6@0J6QX01@0I
6AT201XJ6P0501PH600I6AT06ATI01PH600J6QX00`0I6AT00`0H61P06ATI01PH600201TI6@0401PH
600I6AT06ATI01LG5`806ATI00@06QXJ01PH600I6AT061PH0`0I6AT201PH60D06ATI0P0H61P201TI
6@0601PH600I6AT061PH01PH600I6AT06QXJ0`0I6AT00`0H61P05aLG01PH600201TI6@806QXJ00L0
6ATI01PH600H61P061PH01TI6@0J6QX061PH00806ATI0P0H61P0200I6AT061PH01XJ6P0I6AT061PH
01TI6@0J6QX061PH0P0I6AT201PH600801TI6@0J6QX06ATI01XJ6P0I6AT06QXJ01TI6@0J6QX301TI
6@0401LG5`0I6AT061PH01TI6@H0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WI
f@0301PH600I6AT06ATI00806ATI0`0H61P501TI6@8061PH00@06QXJ01TI6@0I6AT06ATI0P0H61P0
0`0J6QX06ATI01TI6@0401TI6@0501PH600I6AT06ATI01XJ6P0H61P00`0I6AT00`0H61P06ATI01PH
600301TI6@0301PH600I6AT061PH00@06ATI00@061PH01TI6@0H61P061PH0`0I6AT01P0J6QX06ATI
01TI6@0K6a/06ATI01PH60@06ATI00<06QXJ01TI6@0J6QX00P0I6AT0100H61P06ATI01LG5`0H61P3
01TI6@0301XJ6P0I6AT06QXJ00<06ATI0P0J6QX00`0H61P06ATI01TI6@0201TI6@0301XJ6P0I6AT0
6a/K00806QXJ00<061PH01XJ6P0I6AT00P0J6QX00`0I6AT06QXJ01XJ6P0201XJ6P0501PH600J6QX0
6QXJ01XJ6P0K6a/00`0J6QX00`0I6AT06QXJ01TI6@0201XJ6P0301PH600J6QX06QXJ00806QXJ00H0
6a/K01XJ6P0J6QX06QXJ01/K6`0I6AT201XJ6P806ATI0P0K6a/201TI6@806QXJ00@06ATI01XJ6P0J
6QX06QXJ0P0I6AT01@0J6QX06a/K01XJ6P0J6QX06ATI00H06QXJ00H06ATI01XJ6P0J6QX061PH01XJ
6P0I6AT501XJ6P0501/K6`0I6AT06ATI01XJ6P0I6AT00P0J6QX0100I6AT06QXJ01TI6@0I6AT401XJ
6P0701TI6@0J6QX06ATI01XJ6P0K6a/06ATI01XJ6P0201TI6@806QXJ00H061PH01TI6@0I6AT06QXJ
01TI6@0J6QX201TI6@0301PH600I6AT06ATI00806ATI0P0J6QX301TI6@0301XJ6P0I6AT06QXJ0080
6ATI00L061PH01TI6@0J6QX06QXJ01TI6@0H61P06ATI008061PH0P0J6QX301TI6@806QXJ100I6AT2
01XJ6P0301PH600G5aL061PH00@06ATI0P0H61P0100J6QX061PH01PH600H61P301TI6@0601XJ6P0I
6AT06ATI01PH600I6AT06QXJ0P0H61P01P0I6AT061PH01TI6@0G5aL061PH01TI6@8061PH0P0I6AT0
0`0H61P06ATI01PH600201TI6@0301XJ6P0I6AT06ATI00806ATI00<061PH01TI6@0I6AT00P0I6AT0
1@0H61P06ATI01TI6@0J6QX061PH00806ATI00H061PH01TI6@0H61P061PH01TI6@0H61P301TI6@80
61PH0`0I6AT01@0J6QX061PH01TI6@0H61P06QXJ00H0fMWI0@0000010=WIf@005P3IfMT00`000000
fMWI0=WIf@030=WIf@0301TI6@0H61P061PH00806ATI00<06QXJ01TI6@0I6AT00P0H61P0100I6AT0
6QXJ01TI6@0J6QX201TI6@0701XJ6P0K6a/06ATI01TI6@0J6QX05aLG01PH600401TI6@0401XJ6P0H
61P061PH01XJ6P<06ATI00<061PH01LG5`0I6AT00`0I6AT01`0H61P06QXJ01/K6`0J6QX061PH01TI
6@0J6QX00P0I6AT0100G5aL06QXJ01TI6@0J6QX201PH600301XJ6P0I6AT06ATI00806ATI00<061PH
01TI6@0J6QX00P0J6QX0100I6AT061PH01TI6@0H61P301TI6@0501PH600I6AT061PH01PH600J6QX0
200I6AT00`0H61P06ATI01TI6@0201TI6@0501XJ6P0I6AT06a/K01XJ6P0I6AT00P0J6QX00`0I6AT0
6QXJ01XJ6P0301TI6@0301XJ6P0I6AT061PH00806ATI00<06QXJ01/K6`0J6QX00`0J6QX00`0K6a/0
6ATI01TI6@0201TI6@806QXJ00<06a/K01XJ6P0J6QX0100J6QX00`0H61P06ATI01XJ6P0301XJ6P05
01TI6@0J6QX06QXJ01XJ6P0I6AT00P0J6QX01@0I6AT06QXJ01XJ6P0J6QX06ATI00@06QXJ00<06a/K
01TI6@0J6QX00`0J6QX02@0K6a/06QXJ01TI6@0J6QX06ATI01/K6`0J6QX06ATI01XJ6P0301TI6@80
6QXJ00<06ATI01XJ6P0J6QX00`0J6QX501TI6@806QXJ00D06ATI01XJ6P0I6AT06ATI01XJ6P0201TI
6@<06QXJ00<06ATI01XJ6P0I6AT0100I6AT01`0J6QX061PH01PH600I6AT06QXJ01TI6@0J6QX00P0I
6AT0200J6QX06ATI01XJ6P0J6QX06ATI01PH600I6AT061PH0`0I6AT00`0H61P06QXJ01TI6@0201TI
6@0301PH600I6AT06ATI00806QXJ0P0I6AT00`0H61P06ATI01LG5`0301TI6@0301XJ6P0H61P06ATI
00806ATI00@061PH01TI6@0H61P06QXJ0`0I6AT00`0G5aL061PH01TI6@0401TI6@0401LG5`0H61P0
6ATI01TI6@805aLG0P0I6AT301PH60806ATI00@061PH01TI6@0H61P06QXJ100H61P01@0I6AT061PH
01PH600I6AT061PH00806ATI00@06QXJ01PH600J6QX06ATI0P0H61P701TI6@0301XJ6P0H61P06QXJ
00806ATI00<06QXJ01TI6@0J6QX00`0I6AT201XJ6P0301TI6@0H61P06ATI00H0fMWI0@0000010=WI
f@005P3IfMT00`000000fMWI0=WIf@030=WIf@806ATI00<061PH01TI6@0I6AT00`0I6AT01P0H61P0
6ATI01XJ6P0H61P06ATI01PH60806QXJ00<06a/K01TI6@0I6AT00P0I6AT02P0H61P06QXJ01PH600H
61P06ATI01XJ6P0I6AT061PH01TI6@0J6QX501TI6@0401XJ6P0I6AT061PH01TI6@8061PH00@06ATI
01PH600I6AT061PH100I6AT00`0H61P06ATI01PH600201TI6@8061PH0P0I6AT00`0G5aL061PH01PH
600701TI6@0501XJ6P0I6AT06QXJ01TI6@0H61P02@0I6AT201XJ6PD06ATI00@06QXJ01TI6@0I6AT0
6ATI0P0J6QX0100I6AT061PH01TI6@0I6AT201PH60806ATI0`0J6QX201TI6@0501XJ6P0K6a/06ATI
01XJ6P0K6a/0100J6QX0100I6AT06QXJ01TI6@0I6AT201XJ6P806ATI00<06QXJ01TI6@0I6AT00P0I
6AT00`0J6QX06ATI01XJ6P0201/K6`0;01XJ6P0I6AT06QXJ01XJ6P0K6a/06ATI01XJ6P0I6AT06QXJ
01/K6`0J6QX00P0I6AT0100J6QX06ATI01TI6@0I6AT:01XJ6P0501PH600J6QX06QXJ01XJ6P0I6AT0
1P0J6QX00`0I6AT06QXJ01TI6@0201XJ6P806ATI00H06QXJ01TI6@0K6a/06QXJ01PH600K6a/201XJ
6P0501TI6@0J6QX06QXJ01TI6@0J6QX00P0I6AT00`0H61P06ATI01PH600201TI6@0301XJ6P0I6AT0
6ATI008061PH0`0I6AT01`0H61P06ATI01TI6@0J6QX06ATI01XJ6P0I6AT00P0J6QX301TI6@0301PH
600I6AT06ATI008061PH00D06QXJ01TI6@0I6AT06ATI01PH600201TI6@0301XJ6P0I6AT06ATI00@0
6ATI0P0H61P00`0I6AT061PH01PH600201PH60806ATI0P0H61P201TI6@0801PH600I6AT061PH01PH
600J6QX061PH01TI6@0H61P301TI6@0401PH600I6AT06ATI01TI6@8061PH00L06ATI01PH600H61P0
6ATI01PH600G5aL061PH00@06ATI0P0H61P201TI6@0301PH600I6AT06ATI008061PH1P0I6AT00`0J
6QX06ATI01PH600201PH60P06ATI00D061PH01TI6@0I6AT06ATI01PH60060=WIf@4000000@3IfMT0
01H0fMWI00<000000=WIf@3IfMT00`3IfMT201PH60806ATI00<06QXJ01TI6@0I6AT00P0I6AT01@0J
6QX06ATI01TI6@0H61P06ATI00D06QXJ00<06ATI01XJ6P0I6AT00`0I6AT0100J6QX061PH01TI6@0J
6QX201TI6@0501XJ6P0I6AT06ATI01PH600I6AT00`0H61P901TI6@0901PH600I6AT06ATI01PH600I
6AT061PH01TI6@0H61P06QXJ00806ATI00L06QXJ01TI6@0H61P06ATI01XJ6P0I6AT061PH00H06ATI
00<061PH01TI6@0J6QX00P0H61P401TI6@0801PH600I6AT06ATI01TI6@0J6QX06ATI01PH600J6QX4
01TI6@<06QXJ00<06ATI01/K6`0J6QX00`0J6QX01@0I6AT06QXJ01XJ6P0I6AT061PH00806QXJ00D0
6ATI01PH600I6AT06a/K01TI6@0;01XJ6P0301TI6@0J6QX06a/K00<06QXJ00D06a/K01`L700J6QX0
6QXJ01PH600701XJ6P0701/K6`0J6QX06QXJ01/K6`0I6AT06QXJ01/K6`0301XJ6P806a/K00D06QXJ
01/K6`0I6AT06a/K01TI6@0201XJ6P0601TI6@0J6QX06a/K01TI6@0J6QX06ATI0P0J6QX201TI6@80
6QXJ00H06a/K01XJ6P0I6AT06ATI01XJ6P0K6a/201TI6@0401XJ6P0H61P06QXJ01PH60D06QXJ0P0I
6AT02`0K6a/06ATI01TI6@0I6AT06QXJ01TI6@0J6QX06ATI01PH600J6QX061PH00806ATI0P0J6QX2
01TI6@0301XJ6P0H61P06ATI00H06ATI00<06QXJ01TI6@0J6QX02@0I6AT301PH60D06ATI00<061PH
01TI6@0I6AT00P0H61P501TI6@0301XJ6P0I6AT061PH00806ATI00@061PH01TI6@0I6AT06ATI0P0H
61P01@0I6AT061PH01TI6@0I6AT061PH00D06ATI0P0G5aL01@0I6AT061PH01PH600H61P06ATI0080
61PH00<06ATI01XJ6P0H61P01@0I6AT201PH600301XJ6P0I6AT061PH00<06ATI0P0H61P0100I6AT0
61PH01PH600H61P301TI6@@061PH00<06QXJ01TI6@0I6AT00`0I6AT60=WIf@4000000@3IfMT001H0
fMWI00<000000=WIf@3IfMT00`3IfMT501TI6@0401PH600I6AT06ATI01PH60806ATI00`061PH01XJ
6P0I6AT06ATI01XJ6P0I6AT06QXJ01TI6@0J6QX06ATI01XJ6P0I6AT201PH600601XJ6P0I6AT06ATI
01XJ6P0I6AT06QXJ0P0H61P401TI6@0301XJ6P0I6AT06ATI00806ATI00<061PH01TI6@0I6AT00`0I
6AT00`0H61P06ATI01PH600301TI6@0301PH600G5aL061PH00H06ATI00h06QXJ01TI6@0H61P06ATI
01XJ6P0I6AT05aLG01TI6@0H61P06QXJ01TI6@0J6QX06ATI01PH60806ATI0P0J6QX00`0I6AT061PH
01TI6@0201PH60<06ATI00<06a/K01TI6@0J6QX01@0I6AT401XJ6P@06ATI00<06QXJ01TI6@0J6QX0
200J6QX0100I6AT061PH01XJ6P0J6QX301TI6@806QXJ00D06ATI01XJ6P0J6QX06QXJ01TI6@0501XJ
6P0401TI6@0J6QX06ATI01XJ6P806ATI00L06QXJ01TI6@0J6QX06QXJ01TI6@0J6QX06ATI00806QXJ
00D06a/K01XJ6P0J6QX06QXJ01TI6@0201XJ6P0601TI6@0J6QX06QXJ01XJ6P0K6a/06QXJ1@0I6AT0
0`0J6QX06a/K01XJ6P0401TI6@806QXJ0P0I6AT01@0J6QX06ATI01TI6@0I6AT06QXJ00<06ATI00D0
6QXJ01TI6@0H61P06ATI01XJ6P0401TI6@0301XJ6P0H61P06QXJ00@06ATI0`0J6QX201TI6@0401PH
600I6AT06QXJ01XJ6P806ATI00@06QXJ01TI6@0I6AT06a/K0P0H61P00`0I6AT061PH01TI6@0201TI
6@0301PH600I6AT06ATI00806QXJ0P0I6AT0100H61P06ATI01PH600I6AT301PH60806ATI0P0H61P0
0`0J6QX061PH01TI6@0301TI6@0301PH600G5aL06ATI008061PH0`0I6AT0100H61P06ATI01PH600I
6AT201PH600801LG5`0H61P061PH01TI6@0H61P06QXJ01PH600I6AT701PH600401TI6@0H61P05aLG
01TI6@<061PH00L06ATI01PH600I6AT06ATI01PH600I6AT06QXJ008061PH00@06QXJ01PH600I6AT0
61PH0P0I6AT00`0J6QX06ATI01TI6@0301PH600501TI6@0J6QX061PH01TI6@0J6QX00P0I6AT00`0H
61P0fMWI0=WIf@040=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT201TI6@04
01XJ6P0I6AT06ATI01TI6@<061PH00<06ATI01PH600J6QX00P0I6AT301XJ6P0301PH600I6AT06ATI
00@06ATI00<061PH01TI6@0I6AT00`0I6AT301PH600301TI6@0J6QX061PH00806ATI00@061PH01TI
6@0H61P06ATI0P0H61P201TI6@0301XJ6P0I6AT06ATI008061PH00@06ATI01PH600I6AT06ATI0P0H
61P00`0I6AT061PH01PH600301PH600301TI6@0H61P06ATI00806ATI00<061PH01XJ6P0H61P00P0I
6AT0100J6QX06ATI01TI6@0K6a/201TI6@0301XJ6P0I6AT06ATI00806ATI00@06QXJ01TI6@0J6QX0
6QXJ1`0I6AT301XJ6P@06ATI00@06QXJ01TI6@0I6AT06QXJ0P0I6AT00`0J6QX06ATI01TI6@0301XJ
6P0401TI6@0K6a/061PH01/K6`H06QXJ0P0I6AT00`0J6QX06a/K01XJ6P0201TI6@806QXJ00<06ATI
01XJ6P0I6AT01@0I6AT201XJ6P0701TI6@0K6a/06ATI01TI6@0J6QX06a/K01TI6@0401XJ6P806ATI
00D06QXJ01TI6@0J6QX06ATI01PH600201TI6@0301/K6`0J6QX06QXJ00806ATI00D06QXJ01TI6@0J
6QX06a/K01TI6@0201XJ6P0701/K6`0I6AT06QXJ01XJ6P0I6AT06QXJ01TI6@0401XJ6P0601TI6@0J
6QX061PH01TI6@0H61P06QXJ0P0I6AT0100J6QX06ATI01TI6@0I6AT201XJ6PH06ATI00@061PH01TI
6@0I6AT061PH0P0I6AT201PH600401TI6@0J6QX06ATI01TI6@806QXJ00<06ATI01XJ6P0J6QX00P0I
6AT01`0J6QX06ATI01XJ6P0I6AT06QXJ01TI6@0J6QX00P0I6AT00`0J6QX05aLG01TI6@0301TI6@04
01XJ6P0I6AT061PH01PH60806ATI00@061PH01LG5`0I6AT061PH0P0J6QX00`0H61P06ATI01TI6@02
01PH60D06ATI1@0H61P0100I6AT061PH01TI6@0I6AT201PH600:01TI6@0H61P05aLG01PH600I6AT0
61PH01TI6@0H61P05aLG01PH60806ATI0P0H61P0100I6AT061PH01TI6@0H61P201TI6@0301PH600I
6AT06ATI00<06ATI00<05aLG01TI6@0G5aL00P0H61P02P0J6QX061PH01PH600I6AT061PH01TI6@0H
61P06QXJ01PH600I6AT60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT00`0I
6AT06QXJ01TI6@0201TI6@0401PH600G5aL06a/K01XJ6P<06ATI0P0J6QX201TI6@0401PH600I6AT0
6ATI01XJ6P806ATI00@061PH01XJ6P0H61P06ATI0P0H61P00`0G5aL06ATI01TI6@0401TI6@0301PH
600I6AT06ATI00806ATI0P0H61P601TI6@<061PH1@0I6AT201PH60D06ATI0P0J6QX01@0I6AT06QXJ
01TI6@0J6QX061PH00806ATI00L061PH01XJ6P0J6QX06ATI01XJ6P0H61P06ATI00806QXJ0`0I6AT0
100J6QX06ATI01TI6@0H61P201TI6@0601XJ6P0I6AT06QXJ01TI6@0H61P06ATI0P0J6QX201TI6@@0
6QXJ0`0I6AT01@0K6a/06ATI01TI6@0J6QX06ATI00806QXJ00<06a/K01XJ6P0H61P00P0I6AT00`0H
61P06QXJ01XJ6P0501XJ6P0901TI6@0K6a/06ATI01TI6@0J6QX071`L01XJ6P0I6AT06QXJ00806ATI
1P0J6QX01@0I6AT061PH01TI6@0J6QX061PH00806a/K0P0J6QX00`0I6AT06QXJ01TI6@0201TI6@80
6a/K0`0I6AT401XJ6P806ATI0P0J6QX00`0I6AT06QXJ01TI6@0201TI6@0301/K6`0J6QX06QXJ00H0
6QXJ0`0I6AT0100J6QX06ATI01TI6@0J6QX301TI6@0701PH600J6QX06ATI01PH600J6QX06ATI01PH
600301TI6@0301/K6`0I6AT06ATI008061PH00P06QXJ01TI6@0I6AT06ATI01PH600I6AT06QXJ01PH
60<06ATI00<061PH01XJ6P0I6AT0100I6AT02`0J6QX06ATI01PH600I6AT061PH01XJ6P0H61P06QXJ
01PH600J6QX061PH00806ATI00<06QXJ01PH600H61P00P0I6AT0100J6QX061PH01PH600H61P301TI
6@0401PH600I6AT061PH01PH60<06ATI0P0H61P00`0G5aL06ATI01TI6@0401PH60D06ATI00<061PH
01TI6@0H61P00P0H61P02`0I6AT061PH01TI6@0I6AT05aLG01PH600I6AT061PH01XJ6P0I6AT06QXJ
00<06ATI00<061PH01TI6@0I6AT00P0H61P501TI6@0301PH600I6AT061PH00<061PH0P0I6AT201PH
600301TI6@3IfMT0fMWI00@0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@05
01PH600I6AT061PH01PH600I6AT00P0H61P301TI6@0501PH600I6AT061PH01/K6`0H61P0100I6AT0
100H61P06QXJ01TI6@0H61P201TI6@0601PH600I6AT06ATI01/K6`0J6QX06ATI0P0H61P01@0J6QX0
6ATI01TI6@0I6AT06QXJ00L06ATI00L06QXJ01LG5`0H61P061PH01LG5`0H61P06QXJ00<061PH00<0
6ATI01XJ6P0G5aL01@0I6AT01@0H61P06ATI01TI6@0I6AT061PH00806ATI00<061PH01TI6@0I6AT0
0`0I6AT301XJ6P0301TI6@0H61P06ATI00806QXJ00<061PH01TI6@0H61P00P0I6AT00`0J6QX06ATI
01XJ6P0201XJ6P0@01TI6@0J6QX06ATI01TI6@0G5aL06ATI01XJ6P0H61P06QXJ01/K6`0H61P06QXJ
01TI6@0J6QX06ATI01XJ6P806ATI00D06QXJ01/K6`0K6a/061PH01/K6`0301XJ6P806ATI0P0J6QX0
100H61P06QXJ01TI6@0I6AT201XJ6P0601TI6@0J6QX06ATI01TI6@0J6QX06a/K0P0J6QX01@0K6a/0
6ATI01XJ6P0J6QX06ATI00H06QXJ00<06ATI01PH600I6AT01`0J6QX201/K6`0801TI6@0J6QX06QXJ
01/K6`0I6AT06a/K01TI6@0J6QX501TI6@0401XJ6P0I6AT06ATI01XJ6P@06ATI00<06a/K01TI6@0I
6AT00P0J6QX00`0I6AT06QXJ01XJ6P0201XJ6P0301/K6`0I6AT06ATI00806ATI00<061PH01TI6@0I
6AT00P0I6AT00`0J6QX05aLG01PH600401TI6@0301PH600I6AT061PH00<06ATI00@061PH01TI6@0I
6AT06QXJ2@0I6AT00`0J6QX06ATI01TI6@0201TI6@<06QXJ0`0I6AT01@0H61P06ATI01PH600I6AT0
61PH00D06ATI00@061PH01XJ6P0I6AT06ATI0`0H61P00`0I6AT06QXJ01TI6@0301PH600401TI6@0H
61P06ATI01TI6@8061PH00<06ATI01XJ6P0I6AT00P0H61P0100I6AT061PH01PH600I6AT201PH6003
01XJ6P0I6AT06ATI008061PH00<06QXJ01TI6@0G5aL00`0I6AT401PH60806ATI0`0H61P201TI6@80
6QXJ00<061PH01TI6@0G5aL00P0H61P01P0I6AT061PH01TI6@0I6AT061PH01TI6@H0fMWI0@000001
0=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0>01PH600I6AT06ATI01TI6@0J6QX06ATI01LG
5`0J6QX06ATI01PH600G5aL061PH01TI6@0J6QX401PH600701TI6@0H61P06ATI01TI6@0J6QX06ATI
01PH600301TI6@8061PH00D06ATI01PH600J6QX05aLG01PH600401TI6@8061PH00<06ATI01XJ6P0H
61P01@0I6AT00`0H61P06QXJ01PH600201PH600<01TI6@0H61P06ATI01LG5`0J6QX06ATI01PH600I
6AT05aLG01TI6@0H61P06QXJ0`0I6AT0100H61P06ATI01TI6@0I6AT201XJ6P0401TI6@0J6QX06ATI
01XJ6PD06ATI00<06QXJ01TI6@0I6AT00P0I6AT301XJ6P806ATI0`0J6QX01@0I6AT06QXJ01TI6@0H
61P06ATI00806QXJ00@06a/K01XJ6P0J6QX06a/K0P0I6AT201XJ6P0301/K6`0I6AT06QXJ00@06ATI
00@06a/K01XJ6P0J6QX06a/K100J6QX0100I6AT06QXJ01PH600I6AT201XJ6P806ATI00X06QXJ01/K
6`0J6QX06QXJ01/K6`0J6QX061PH01XJ6P0K6a/06QXJ0P0I6AT01@0H61P06QXJ01XJ6P0J6QX06ATI
00<06QXJ00<06ATI01/K6`0J6QX0200J6QX00`0H61P06ATI01XJ6P0301XJ6P0401TI6@0J6QX06QXJ
01TI6@<06QXJ00/06ATI01XJ6P0I6AT06QXJ01TI6@0J6QX061PH01TI6@0H61P06ATI01XJ6P0201TI
6@0401PH600I6AT06QXJ01XJ6P806ATI00D06QXJ01TI6@0J6QX061PH01XJ6P0301TI6@0;01PH600I
6AT06ATI01PH600J6QX06a/K01TI6@0H61P06ATI01XJ6P0H61P0100I6AT201PH600301TI6@0H61P0
6ATI00806ATI00<061PH01TI6@0I6AT00P0I6AT00`0H61P06ATI01PH600301TI6@0401PH600I6AT0
6ATI01PH60D06ATI00<06QXJ01TI6@0I6AT00P0H61P00`0I6AT061PH01PH600301PH600301XJ6P0H
61P06ATI00H061PH00l05aLG01TI6@0I6AT05aLG01TI6@0G5aL06ATI01PH600I6AT06QXJ01TI6@0H
61P06ATI01PH600J6QX00P0H61P01@0I6AT061PH01TI6@0I6AT06QXJ00806ATI00D05aLG01PH600I
6AT061PH01LG5`0201TI6@0301PH600I6AT061PH00806ATI100H61P00`0I6AT05aLG01PH600301PH
60H0fMWI0@0000010=WIf@005P3IfMT2000000@0fMWI00@06ATI01PH600H61P061PH0P0I6AT00`0H
61P06ATI01TI6@0201TI6@8061PH0P0I6AT01`0J6QX061PH01TI6@0I6AT061PH01TI6@0H61P00P0I
6AT02@0J6QX06ATI01PH600I6AT06QXJ01PH600I6AT061PH01XJ6P0301TI6@0401XJ6P0I6AT06ATI
01PH60806QXJ00D06ATI01XJ6P0I6AT061PH01XJ6P0301PH60H06ATI00<06QXJ01PH600I6AT00P0H
61P00`0I6AT061PH01PH600301TI6@8061PH00H06ATI01PH600I6AT061PH01XJ6P0I6AT201PH6003
01TI6@0H61P06ATI00806QXJ00<06ATI01PH600J6QX00`0I6AT201XJ6P0501PH600J6QX06ATI01TI
6@0J6QX00P0I6AT201XJ6P806ATI00@06QXJ01/K6`0H61P06ATI0P0J6QX201TI6@0901XJ6P0I6AT0
6QXJ01XJ6P0H61P06a/K01XJ6P0K6a/06QXJ00806a/K1P0J6QX01@0I6AT06QXJ01XJ6P0I6AT06QXJ
00806ATI1`0J6QX01P0K6a/06QXJ01XJ6P0I6AT06QXJ01TI6@806QXJ00D061PH01TI6@0I6AT06ATI
01XJ6P0301TI6@0401PH600K6a/06ATI01TI6@806QXJ0`0I6AT201XJ6P0601TI6@0J6QX06ATI01XJ
6P0I6AT06a/K1@0J6QX00`0I6AT06a/K01TI6@0201XJ6P0501TI6@0J6QX06ATI01TI6@0J6QX00P0I
6AT00`0J6QX06ATI01XJ6P0201TI6@0501PH600I6AT06QXJ01TI6@0J6QX00`0I6AT01@0H61P06ATI
01TI6@0H61P06ATI008061PH0`0J6QX0100I6AT06QXJ01XJ6P0H61P201XJ6P0301TI6@0H61P061PH
00806QXJ00T06ATI01XJ6P0H61P06ATI01PH600I6AT061PH01TI6@0H61P00P0I6AT01@0H61P06ATI
01TI6@0H61P06ATI008061PH0P0I6AT02P0K6a/06ATI01XJ6P0I6AT061PH01TI6@0H61P06ATI01PH
600I6AT201PH600<01TI6@0H61P061PH01XJ6P0I6AT061PH01TI6@0G5aL06ATI01LG5`0J6QX061PH
0P0I6AT201PH600401TI6@0J6QX061PH01LG5`8061PH00D05aLG01PH600G5aL061PH01TI6@0401PH
600301TI6@0J6QX061PH008061PH0P0I6AT501PH60806ATI0P0J6QX0100H61P06ATI01TI6@0I6AT4
01PH600301TI6@0H61P06ATI00D0fMWI0P0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WI
f@806ATI00D06a/K01TI6@0I6AT06ATI01PH600301TI6@8061PH00D06QXJ01TI6@0I6AT06ATI01XJ
6P0201TI6@8061PH0P0I6AT00`0G5aL061PH01TI6@0501TI6@0301PH600I6AT06ATI00<06ATI00`0
61PH01XJ6P0H61P06ATI01PH600J6QX06ATI01PH600I6AT05aLG01PH600I6AT201PH600501TI6@0H
61P061PH01PH600I6AT00`0H61P01P0I6AT061PH01TI6@0I6AT06QXJ01PH60@06ATI0P0J6QX201PH
600401XJ6P0H61P06ATI01XJ6P806ATI00@06QXJ01TI6@0J6QX061PH0P0I6AT201XJ6P<06ATI0P0J
6QX00`0I6AT06QXJ01PH600301XJ6P0301TI6@0J6QX06QXJ00806ATI0`0J6QX00`0K6a/06QXJ01XJ
6P0601XJ6P0501/K6`0I6AT06QXJ01/K6`0I6AT00P0J6QX00`0K6a/06QXJ01TI6@0501XJ6P<06ATI
00@06QXJ01TI6@0J6QX06ATI100J6QX301TI6@0301XJ6P0H61P06QXJ00<06ATI00<06QXJ01TI6@0J
6QX00P0I6AT00`0J6QX06ATI01PH600201XJ6P<06ATI100J6QX401TI6@D06QXJ00P06ATI01XJ6P0H
61P06ATI01XJ6P0I6AT06QXJ01PH60D06ATI00<06QXJ01TI6@0I6AT0100I6AT0200J6QX06ATI01TI
6@0H61P06ATI01PH600I6AT06QXJ0`0I6AT00`0H61P06ATI01TI6@0701TI6@0301PH600J6QX06ATI
00@06ATI00@061PH01TI6@0I6AT06QXJ0P0I6AT00`0G5aL06ATI01LG5`0201PH60806ATI00D061PH
01TI6@0H61P061PH01TI6@0201PH60806ATI00D061PH01TI6@0J6QX06ATI01PH600201TI6@8061PH
0P0I6AT301PH60806ATI00D06QXJ01PH600H61P06ATI01XJ6P0301TI6@0301PH600G5aL061PH0080
6ATI00H06QXJ01LG5`0I6AT06ATI01PH600I6AT201LG5`0401TI6@0H61P061PH01PH60D06ATI100H
61P00`0I6AT061PH01PH600201TI6@0301PH600I6AT06ATI00806ATI00<061PH01XJ6P0I6AT00P0I
6AT00`0H61P06ATI01TI6@060=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT0
1@0I6AT061PH01PH600I6AT06QXJ00@06ATI00H06QXJ01PH600I6AT06ATI01PH600I6AT201PH6003
01XJ6P0H61P06ATI00806ATI00<061PH01TI6@0J6QX00P0J6QX0100I6AT06QXJ01PH600J6QX201TI
6@0601/K6`0H61P061PH01XJ6P0H61P05QHF0P0I6AT201PH600501TI6@0H61P06ATI01TI6@0J6QX0
0`0I6AT0100H61P06ATI01PH600H61P201TI6@0301LG5`0H61P06ATI00D06ATI0P0H61P0100I6AT0
61PH01TI6@0H61P201XJ6P0301TI6@0H61P06QXJ00P06ATI00<06a/K01XJ6P0I6AT01`0I6AT301XJ
6P0301/K6`0I6AT06QXJ00806ATI0P0J6QX00`0I6AT06QXJ01TI6@0201XJ6P806ATI0`0J6QX0100I
6AT06QXJ01XJ6P0I6AT601XJ6P0901TI6@0J6QX06QXJ01XJ6P0K6a/06ATI01XJ6P0I6AT06QXJ0080
6ATI00<06QXJ01TI6@0J6QX00P0I6AT01P0J6QX06ATI01XJ6P0J6QX06ATI01/K6`806ATI0P0J6QX0
0`0I6AT06QXJ01XJ6P0201TI6@@06QXJ00H06ATI01XJ6P0I6AT06QXJ01TI6@0J6QX401TI6@0601XJ
6P0I6AT06ATI01PH600J6QX06ATI0P0J6QX0200I6AT061PH01TI6@0J6QX061PH01XJ6P0K6a/06QXJ
0P0I6AT01@0J6QX06ATI01XJ6P0J6QX06a/K00<06ATI00<061PH01TI6@0J6QX00`0I6AT01@0J6QX0
61PH01TI6@0J6QX061PH00806ATI00L061PH01XJ6P0H61P06ATI01PH600J6QX061PH00<06ATI00X0
61PH01TI6@0I6AT061PH01XJ6P0I6AT06QXJ01TI6@0J6QX061PH0`0I6AT0100H61P06QXJ01TI6@0H
61P301TI6@0301PH600I6AT061PH00<06ATI00P06QXJ01PH600G5aL06ATI01PH600I6AT06QXJ01PH
60<06ATI00P06QXJ01LG5`0I6AT06ATI01PH600I6AT061PH01TI6@8061PH00D06ATI01PH600H61P0
61PH01HF5P0201PH600301LG5`0H61P06QXJ00806ATI1@0H61P02@0G5aL06ATI01PH600H61P06ATI
01PH600G5aL06ATI01PH600301TI6@H061PH0`0I6AT301PH600301XJ6P0I6AT06ATI00<06ATI00<0
61PH01TI6@3IfMT01@3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00D06ATI
01PH600I6AT06QXJ01PH600201TI6@0301PH600I6AT061PH00806ATI00D061PH01TI6@0H61P061PH
01TI6@0301PH600401XJ6P0I6AT06ATI01TI6@806QXJ0P0I6AT01P0J6QX06ATI01TI6@0I6AT061PH
01TI6@<061PH00X06QXJ01LG5`0H61P06ATI01/K6`0J6QX06ATI01XJ6P0H61P06QXJ0P0H61P0100I
6AT061PH01PH600I6AT401PH600301XJ6P0I6AT06QXJ008061PH00@06QXJ01TI6@0I6AT06ATI100H
61P201TI6@0301PH600I6AT06ATI008061PH1P0I6AT00`0J6QX06ATI01TI6@0201TI6@0501XJ6P0I
6AT06QXJ01TI6@0J6QX00P0I6AT301XJ6P0301PH600K6a/06ATI00806QXJ00T06ATI01XJ6P0K6a/0
6a/K01TI6@0J6QX06a/K01TI6@0J6QX00P0I6AT0100J6QX06a/K01TI6@0K6a/701XJ6P0401/K6`0I
6AT06a/K01/K6`806QXJ0P0I6AT00`0J6QX06ATI01XJ6P0201TI6@0401XJ6P0I6AT06a/K01TI6@L0
6QXJ0`0I6AT00`0K6a/06ATI01TI6@0201TI6@0301XJ6P0I6AT06ATI00D06QXJ00P06ATI01XJ6P0I
6AT06QXJ01PH600I6AT06QXJ01TI6@806QXJ00@061PH01TI6@0J6QX06ATI0`0J6QX0100I6AT06QXJ
01XJ6P0H61P301XJ6P0401TI6@0J6QX06ATI01TI6@8061PH1P0I6AT00`0H61P06ATI01PH600201TI
6@806QXJ00<06ATI01PH600I6AT0100I6AT0100J6QX061PH01TI6@0H61P601TI6@0501PH600J6QX0
6ATI01TI6@0H61P01P0I6AT0100H61P06ATI01XJ6P0H61P201TI6@0801PH600I6AT06QXJ01LG5`0J
6QX06ATI01PH600G5aL201TI6@D061PH0`0I6AT01@0H61P06ATI01PH600H61P06ATI008061PH00L0
5aLG01PH600H61P061PH01TI6@0H61P05aLG00806ATI00@05aLG01TI6@0H61P06ATI0P0H61P01P0I
6AT061PH01PH600G5aL06QXJ01PH60@06ATI100H61P301TI6@8061PH0`0I6AT0100J6QX06ATI01TI
6@0H61P201TI6@8061PH00<05aLG01TI6@3IfMT01@3IfMT100000040fMWI000F0=WIf@030000003I
fMT0fMWI00<0fMWI00H06ATI01PH600H61P061PH01TI6@0H61P201TI6@0801XJ6P0H61P06ATI01TI
6@0J6QX061PH01XJ6P0H61P201TI6@0;01XJ6P0I6AT06ATI01XJ6P0I6AT06QXJ01TI6@0J6QX061PH
01TI6@0J6QX01P0I6AT00`0J6QX06ATI01TI6@0201TI6@0301LG5`0I6AT06ATI00806QXJ00<06ATI
01PH600H61P01@0I6AT201PH60D06ATI00<061PH01TI6@0I6AT00P0H61P201TI6@0601PH600I6AT0
6ATI01PH600I6AT06QXJ0`0I6AT01@0J6QX06ATI01TI6@0J6QX061PH00@06ATI0P0J6QX201TI6@03
01PH600J6QX06QXJ00806QXJ0P0I6AT301XJ6P806ATI00L061PH01XJ6P0J6QX06ATI01XJ6P0K6a/0
6ATI00D06QXJ00<06ATI01PH600I6AT00P0I6AT601XJ6P0601TI6@0J6QX06QXJ01TI6@0J6QX06ATI
0P0J6QX201PH60<06ATI00@06a/K01TI6@0J6QX06ATI0P0J6QX01@0I6AT06QXJ01TI6@0J6QX06a/K
00806ATI100J6QX0200I6AT061PH01XJ6P0I6AT06QXJ01TI6@0K6a/06ATI100J6QX201PH60806QXJ
00D06ATI01XJ6P0I6AT06ATI01/K6`0301TI6@0301PH600J6QX06ATI00<06QXJ00D061PH01XJ6P0J
6QX06QXJ01TI6@0201XJ6P806ATI0P0J6QX00`0I6AT06QXJ01PH600401TI6@0;01PH600J6QX06ATI
01TI6@0H61P06QXJ01PH600I6AT061PH01TI6@0H61P00P0J6QX0100I6AT06QXJ01TI6@0I6AT201PH
60806ATI0P0J6QX0100I6AT061PH01TI6@0J6QX501TI6@0701PH600I6AT06ATI01TI6@0H61P06ATI
01PH600301TI6@0301PH600I6AT061PH008061PH0P0I6AT201PH60<05aLG00@06ATI01PH600H61P0
6ATI0`0H61P00`0I6AT061PH01TI6@0401PH60806ATI1P0H61P02P0I6AT061PH01PH600H61P06ATI
01LG5`0H61P06QXJ01PH600J6QX301TI6@0301PH600I6AT061PH00<061PH00@06ATI01PH600H61P0
61PH0`0I6AT00`0H61P06QXJ01TI6@0301PH60806ATI00<061PH01TI6@3IfMT01@3IfMT100000040
fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI0P0I6AT02@0H61P06ATI01PH600I6AT061PH01TI
6@0H61P06ATI01LG5`0401PH600301TI6@0H61P06ATI00806ATI00P06QXJ01TI6@0J6QX06QXJ01TI
6@0J6QX06a/K01PH60<06ATI00<061PH01LG5`0H61P00`0H61P301XJ6P0401TI6@0H61P06ATI01TI
6@805aLG00D06ATI01PH600H61P06ATI01XJ6P0401TI6@0401PH600I6AT06ATI01TI6@8061PH0P0I
6AT201PH600401TI6@0H61P05aLG01XJ6P<061PH0P0I6AT0100J6QX06ATI01TI6@0J6QX201TI6@0:
01XJ6P0I6AT06QXJ01XJ6P0I6AT06QXJ01PH600I6AT061PH01XJ6P806ATI00<06QXJ01TI6@0I6AT0
0P0I6AT201PH60X06ATI0`0J6QX01@0I6AT06QXJ01PH600J6QX061PH00@06QXJ00D06ATI01/K6`0J
6QX06ATI01XJ6P0201TI6@0501XJ6P0K6a/061PH01XJ6P0I6AT00`0J6QX00`0I6AT06QXJ01XJ6P03
01XJ6P0801TI6@0H61P06ATI01XJ6P0K6a/06ATI01XJ6P0K6a/401TI6@0301/K6`0I6AT06ATI0080
6QXJ00@06ATI01XJ6P0J6QX06QXJ0P0I6AT201XJ6P8061PH00T06QXJ01/K6`0J6QX06ATI01XJ6P0H
61P06QXJ01TI6@0H61P00P0I6AT02@0J6QX06ATI01XJ6P0H61P06QXJ01TI6@0H61P06QXJ01PH6003
01TI6@0301PH600J6QX06ATI00806QXJ00<06ATI01PH600I6AT00P0H61P201TI6@0901XJ6P0H61P0
6QXJ01XJ6P0K6a/061PH01TI6@0H61P06QXJ00806ATI00<061PH01TI6@0I6AT00`0I6AT01`0J6QX0
6ATI01TI6@0I6AT061PH01TI6@0H61P0100I6AT0100H61P06ATI01PH600G5aL201TI6@0301PH600I
6AT061PH00806ATI0P0J6QX401TI6@0601PH600I6AT06ATI01PH600I6AT061PH0P0I6AT201PH6080
5aLG00<06ATI01PH600H61P01P0H61P201TI6@<061PH00<06QXJ01TI6@0H61P00P0H61P01P0I6AT0
61PH01TI6@0I6AT061PH01TI6@8061PH00<06ATI01PH600J6QX00`0I6AT00`0H61P06ATI01PH6002
01TI6@0301PH600I6AT061PH00806ATI00<06QXJ01PH600I6AT00`0H61P0100G5aL06ATI01TI6@0I
6AT60=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT01@0I6AT061PH01PH600H
61P06QXJ00806ATI0P0H61P00`0J6QX06ATI01PH600201TI6@0301PH600J6QX06ATI00D06ATI00<0
61PH01XJ6P0J6QX00P0J6QX0100I6AT061PH01XJ6P0H61P301TI6@0<01XJ6P0H61P06ATI01TI6@0H
61P06ATI01XJ6P0H61P06QXJ01TI6@0J6QX06ATI0`0H61P301TI6@0401PH600G5aL06QXJ01PH6080
6ATI00H061PH01TI6@0I6AT06QXJ01TI6@0J6QX301TI6@0301PH600J6QX06ATI00806ATI00P061PH
01TI6@0I6AT06QXJ01TI6@0G5aL06ATI01PH60@06ATI00<061PH01XJ6P0J6QX00P0J6QX01@0I6AT0
61PH01XJ6P0I6AT06QXJ00806ATI00D06a/K01XJ6P0I6AT06ATI01XJ6P0201TI6@0501XJ6P0I6AT0
6ATI01XJ6P0H61P00`0J6QX201TI6@0601/K6`0I6AT06ATI01TI6@0K6a/06QXJ0P0I6AT301XJ6P05
01/K6`0I6AT06a/K01TI6@0H61P00P0J6QX00`0K6a/06QXJ01TI6@0201XJ6P806a/K00@06ATI01XJ
6P0I6AT06ATI0P0J6QX201TI6@0301PH600I6AT06QXJ00806QXJ00<061PH01TI6@0I6AT00P0I6AT2
01XJ6P0701TI6@0J6QX06QXJ01TI6@0H61P06QXJ01TI6@0201XJ6P0401TI6@0J6QX06QXJ01/K6`80
6ATI00P061PH01XJ6P0J6QX06QXJ01TI6@0J6QX06ATI01XJ6P@06ATI00L06QXJ01TI6@0H61P06ATI
01XJ6P0I6AT06QXJ008061PH0P0J6QX301PH600501TI6@0J6QX05aLG01TI6@0J6QX00`0I6AT201/K
6`L06ATI00<06QXJ01TI6@0I6AT0100I6AT00`0H61P06QXJ01XJ6P0201PH60806ATI00<06QXJ01PH
600I6AT00P0H61P01@0J6QX06ATI01PH600I6AT05aLG008061PH00P06ATI01XJ6P0I6AT06QXJ01TI
6@0H61P06ATI01PH60<06ATI00<061PH01TI6@0H61P0100H61P01@0I6AT061PH01TI6@0J6QX06ATI
008061PH00<06ATI01PH600H61P00P0I6AT301PH60806ATI0P0H61P0100I6AT061PH01PH600I6AT3
01LG5`0301PH600I6AT061PH00<061PH0P0I6AT00`0G5aL06ATI01PH600201PH600401TI6@0H61P0
6ATI01PH60806ATI00D061PH01TI6@0I6AT061PH01LG5`0201TI6@0301PH600I6AT0fMWI00D0fMWI
0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0401TI6@0H61P06ATI01PH60806ATI
00@061PH01TI6@0J6QX061PH100I6AT00`0H61P06ATI01TI6@0501TI6@0301XJ6P0I6AT06ATI0080
6QXJ00<06ATI01PH600H61P00`0I6AT00`0H61P06ATI01TI6@0401TI6@0401PH600I6AT06ATI01PH
60806ATI0`0J6QX01@0I6AT06QXJ01TI6@0I6AT05aLG008061PH0P0I6AT201PH60806ATI00D061PH
01TI6@0H61P06QXJ01TI6@0201PH600901TI6@0J6QX06ATI01XJ6P0I6AT06QXJ01TI6@0J6QX06ATI
00806QXJ0P0I6AT601PH60806ATI0P0J6QX201TI6@806QXJ00@06a/K01PH600J6QX061PH100I6AT0
0`0K6a/06QXJ01XJ6P0201TI6@806QXJ0P0I6AT301XJ6P0701PH600J6QX06QXJ01XJ6P0K6a/06ATI
01XJ6P0801TI6@0401PH600J6QX06ATI01XJ6P@06ATI00<061PH01XJ6P0I6AT0100I6AT0200J6QX0
6ATI01TI6@0I6AT06QXJ01TI6@0J6QX06ATI0P0J6QX401TI6@0401/K6`0I6AT06ATI01XJ6P<06ATI
00@06QXJ01TI6@0K6a/06ATI0P0J6QX00`0H61P06ATI01TI6@0201TI6@8061PH0P0I6AT00`0J6QX0
6ATI01TI6@0201XJ6P0301TI6@0H61P06ATI00<06ATI00D06a/K01TI6@0I6AT06ATI01XJ6P0301TI
6@0401XJ6P0I6AT06ATI01XJ6P806ATI0P0J6QX401TI6@8061PH00<06ATI01PH600I6AT00`0I6AT0
0`0K6a/06QXJ01TI6@0301TI6@0301XJ6P0I6AT06QXJ00806ATI0`0H61P201TI6@0501XJ6P0I6AT0
61PH01TI6@0H61P00P0I6AT0100J6QX061PH01TI6@0J6QX401TI6@0401LG5`0H61P06ATI01TI6@80
61PH0P0I6AT02P0H61P06ATI01PH600J6QX061PH01TI6@0H61P06ATI01PH600I6AT201PH600401TI
6@0H61P061PH01TI6@805aLG00H06ATI01PH600I6AT06ATI01PH600I6AT201PH60806ATI00<05aLG
01PH600I6AT00`0H61P00`0G5aL061PH01XJ6P0201TI6@0301PH600I6AT061PH00@061PH100I6AT2
01PH600301LG5`0I6AT0fMWI00D0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WI
f@0501TI6@0H61P061PH01XJ6P0H61P00P0I6AT0100H61P06ATI01TI6@0H61P701TI6@0301XJ6P0I
6AT06QXJ00806ATI100J6QX01@0I6AT061PH01TI6@0I6AT06QXJ00806ATI00<061PH01TI6@0H61P0
0`0J6QX0100I6AT06QXJ01TI6@0H61P201TI6@0401XJ6P0H61P061PH01XJ6PD06ATI0`0H61P01P0I
6AT061PH01XJ6P0I6AT06QXJ01TI6@8061PH00<06QXJ01TI6@0I6AT01`0I6AT301XJ6P0301TI6@0J
6QX061PH00806ATI00D06QXJ01TI6@0I6AT06ATI01XJ6P0201TI6@0401XJ6P0I6AT06QXJ01TI6@@0
6QXJ00<06ATI01XJ6P0I6AT00`0J6QX0200I6AT061PH01TI6@0J6QX06a/K01TI6@0J6QX06ATI0P0J
6QX201TI6@0601XJ6P0I6AT06ATI01XJ6P0I6AT06a/K0P0J6QX01@0L71`06QXJ01TI6@0I6AT06QXJ
00806ATI00<061PH01XJ6P0I6AT00`0J6QX501TI6@0401XJ6P0I6AT06ATI01XJ6P806ATI0`0J6QX0
0`0I6AT06a/K01TI6@0301TI6@0501XJ6P0I6AT06ATI01PH600I6AT00P0J6QX01@0I6AT06QXJ01XJ
6P0J6QX06ATI00806QXJ0P0I6AT00`0H61P06ATI01TI6@0201TI6@0301XJ6P0I6AT06ATI00D06ATI
00H06QXJ01PH600J6QX06a/K01TI6@0J6QX401TI6@0301XJ6P0I6AT06ATI00806QXJ0`0I6AT201XJ
6P0401TI6@0H61P06ATI01XJ6P<06ATI00X061PH01XJ6P0I6AT061PH01XJ6P0I6AT06a/K024Q8@0L
71`06QXJ1P0I6AT201PH60806ATI00@061PH01TI6@0I6AT06ATI0`0H61P00`0I6AT061PH01TI6@02
01PH60806ATI00D061PH01TI6@0J6QX061PH01TI6@0201XJ6P0301TI6@0H61P06QXJ008061PH0P0I
6AT201LG5`8061PH0P0I6AT501PH600401TI6@0H61P06ATI01PH60<06ATI0`0H61P301TI6@D061PH
00@06ATI01PH600H61P061PH0P0I6AT301PH60@06ATI0P0H61P201XJ6P0401LG5`0I6AT061PH01LG
5`8061PH1P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00T06ATI01PH600H
61P06ATI01PH600I6AT06QXJ01TI6@0H61P01@0I6AT0100H61P06ATI01TI6@0J6QX201TI6@0301XJ
6P0I6AT06ATI00<06ATI00H06QXJ01PH600H61P06QXJ01PH600I6AT201XJ6PD06ATI0P0H61P0100K
6a/06ATI01TI6@0H61P301TI6@0901PH600I6AT061PH01TI6@0G5aL06ATI01PH600I6AT061PH0080
6ATI00@06QXJ01PH600J6QX06QXJ0P0I6AT01@0H61P06ATI01TI6@0I6AT06QXJ00<06ATI00@06QXJ
01TI6@0I6AT06QXJ1@0I6AT01P0J6QX061PH01TI6@0J6QX06ATI01XJ6P806ATI00D06a/K01TI6@0I
6AT06ATI01PH600201TI6@0301XJ6P0H61P06ATI00806ATI00D06QXJ01TI6@0I6AT06ATI01XJ6P03
01TI6@0601XJ6P0I6AT06QXJ01TI6@0J6QX06ATI0P0J6QX01`0I6AT06QXJ01XJ6P0K6a/06QXJ01TI
6@0J6QX00P0I6AT401XJ6P0301/K6`0I6AT06QXJ00<06QXJ0P0I6AT01@0J6QX06ATI01PH600I6AT0
61PH00D06ATI0P0J6QX02P0I6AT06QXJ01XJ6P0J6QX06ATI01XJ6P0K6a/06QXJ01/K6`0J6QX301TI
6@0901XJ6P0I6AT06QXJ01PH600I6AT06QXJ01PH600I6AT06QXJ00D06ATI00H061PH01TI6@0I6AT0
61PH01TI6@0H61P201TI6@0401PH600I6AT06ATI01TI6@806QXJ00H061PH01TI6@0H61P06QXJ01TI
6@0H61P201TI6@806QXJ00<06ATI01XJ6P0I6AT00P0I6AT01`0J6QX06ATI01TI6@0I6AT06QXJ01TI
6@0J6QX00P0H61P201TI6@0601XJ6P0H61P08B4Q0?ooo`2`/;004A4A100I6AT02P0G5aL06ATI01PH
600I6AT061PH01TI6@0J6QX06ATI01PH600I6AT801PH60806ATI00@061PH01TI6@0H61P06QXJ100I
6AT701PH600301TI6@0H61P06ATI00806ATI00<05aLG01PH600I6AT00P0H61P00`0G5aL06ATI01TI
6@0201PH600301LG5`0I6AT061PH00805aLG00<061PH01TI6@0H61P00P0H61P201TI6@0501PH600I
6AT061PH01PH600I6AT00`0H61P301TI6@0301/K6`0I6AT06ATI00<06ATI00D061PH01TI6@0G5aL0
6ATI01PH600201TI6@H0fMWI0@0000010=WIf@000P3IfMT2000000@0fMWI0P0000040=WIf@800000
1P3IfMT00`000000fMWI0=WIf@030=WIf@0501TI6@0H61P061PH01TI6@0H61P00P0I6AT00`0J6QX0
6ATI01PH600201XJ6P0501TI6@0K6a/06ATI01TI6@0J6QX00P0I6AT201XJ6P0501TI6@0J6QX06ATI
01TI6@0J6QX00`0I6AT0100J6QX06ATI01TI6@0H61P201TI6@0401PH600I6AT06QXJ01PH60D06ATI
00@061PH01TI6@0I6AT06QXJ0P0I6AT01P0H61P06QXJ01LG5`0H61P06ATI01LG5`806ATI00<06QXJ
01TI6@0I6AT00P0I6AT0100J6QX061PH01TI6@0H61P201TI6@0801XJ6P0I6AT06ATI01XJ6P0I6AT0
61PH01TI6@0H61P201TI6@06020P800I6AT06QXJ01PH600I6AT06a/K0P0I6AT00`0H61P06QXJ01XJ
6P0401TI6@0301PH600J6QX06QXJ00806ATI00D06QXJ01TI6@0I6AT06QXJ01TI6@0201XJ6P0701TI
6@0J6QX06QXJ01PH600I6AT06QXJ01PH600201XJ6P806a/K0P0J6QX01@0I6AT06QXJ01XJ6P0I6AT0
6QXJ00806ATI0P0J6QX0100I6AT06QXJ01TI6@0I6AT201XJ6P<06ATI00@06a/K01TI6@0I6AT06QXJ
0`0I6AT0100H61P06ATI01TI6@0J6QX201TI6@0601XJ6P0I6AT06QXJ01XJ6P0I6AT06QXJ0`0I6AT0
100J6QX061PH01XJ6P0H61P201TI6@@06QXJ00@06ATI01PH600I6AT06QXJ0P0I6AT0200J6QX06ATI
01TI6@0H61P06ATI01XJ6P0I6AT06QXJ0P0I6AT00`0J6QX061PH01XJ6P0301TI6@0301PH600I6AT0
6ATI00806ATI00<06QXJ01TI6@0I6AT00P0J6QX00`0I6AT06QXJ01TI6@0201XJ6P0301/K6`0J6QX0
61PH00L06ATI00P061PH01TI6@0I6AT06ATI01PH600000001PH600`<308061PH00H06ATI01XJ6P0I
6AT061PH01TI6@0J6QX201TI6@0601PH600I6AT061PH01PH600I6AT061PH100I6AT401PH600301TI
6@0H61P061PH008061PH00<06ATI01PH600H61P00P0I6AT00`0H61P06ATI01TI6@0201PH600301TI
6@0G5aL06ATI00<061PH00@06ATI01PH600I6AT06ATI0P0G5aL02@0I6AT061PH01PH600H61P06ATI
01XJ6P0H61P06ATI01PH600201TI6@0401LG5`0H61P06ATI01TI6@<061PH00@06ATI01PH600I6AT0
61PH100I6AT00`0H61P06ATI01TI6@0201TI6@806QXJ00@06ATI01PH600H61P06ATI0P0H61P60=WI
f@4000000@3IfMT000050=WIf@000000fMWI0=WIf@0000000P3IfMT010000000fMWI0=WIf@000002
0=WIf@040000003IfMT0fMWI000000D0fMWI00<000000=WIf@3IfMT00`3IfMT00`0J6QX061PH01TI
6@0301TI6@0401XJ6P0H61P06ATI01TI6@8061PH00@06ATI01PH600J6QX06QXJ1@0I6AT201XJ6P80
6ATI00X061PH01TI6@0I6AT061PH01TI6@0H61P06ATI01XJ6P0I6AT061PH0P0I6AT301XJ6P806ATI
0P0J6QX0100I6AT06QXJ01TI6@0J6QX201PH60<06ATI00H061PH01TI6@0H61P06ATI01XJ6P0H61P4
01TI6@0501XJ6P0H61P061PH01TI6@0J6QX00`0I6AT02@0J6QX06ATI01TI6@0H61P06QXJ01TI6@0H
61P06QXJ01PH600301TI6@806QXJ00<06ATI01XJ6P0I6AT00P0I6AT00`0K6a/06ATI01PH600201TI
6@0401XJ6P0I6AT06ATI01XJ6P806ATI00<06QXJ01TI6@0J6QX0100I6AT01@0J6QX06ATI01XJ6P0J
6QX06ATI00<06QXJ0`0I6AT01@0K6a/06QXJ01TI6@0H61P06ATI00806QXJ00<06ATI01XJ6P0I6AT0
0`0I6AT00`0J6QX06a/K01XJ6P0201TI6@806QXJ00@06ATI01XJ6P0H61P061PH100J6QX0100I6AT0
61PH01TI6@0I6AT201XJ6P@06ATI00<06QXJ01TI6@0J6QX00P0I6AT01@0J6QX06ATI01TI6@0H61P0
6QXJ00806ATI0P0J6QX01P0I6AT061PH01TI6@0I6AT061PH01TI6@806QXJ0P0I6AT00`0J6QX06ATI
01TI6@0401TI6@0301XJ6P0I6AT06QXJ00@06ATI00<061PH01TI6@0I6AT0100I6AT0100J6QX06ATI
01XJ6P0J6QX301TI6@0601XJ6P0K6a/06ATI01TI6@0H61P06QXJ100I6AT01`0H61P06QXJ01DE5@0J
6QX061PH01TI6@0J6QX00`0I6AT01P0J6QX061PH01PH600H61P06ATI01LG5`806ATI00<06QXJ01PH
600I6AT00`0I6AT01P0H61P06ATI01XJ6P0H61P06ATI01XJ6P<06ATI00D06QXJ01PH600I6AT061PH
01TI6@0201PH60806ATI00<061PH01TI6@0I6AT00`0H61P201LG5`0301TI6@0H61P06ATI00<061PH
00H06ATI01PH600H61P061PH01TI6@0G5aL201PH600301LG5`0H61P061PH008061PH00<05aLG01PH
600H61P00P0H61P0100I6AT061PH01TI6@0J6QX201PH60806ATI00D06QXJ01PH600I6AT061PH01TI
6@0201PH600601TI6@0J6QX06ATI01PH600I6AT061PH1P3IfMT100000040fMWI00040=WIf@040000
003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@030=WI
f@<000000`3IfMT0100I6AT061PH01TI6@0J6QX601TI6@0701XJ6P0I6AT05aLG01TI6@0J6QX06ATI
01PH600201TI6@0301/K6`0I6AT06ATI00<06ATI00<06QXJ01PH600I6AT00P0I6AT01P0J6QX06ATI
01XJ6P0I6AT06QXJ01PH60@06ATI00<061PH01TI6@0H61P00P0H61P00`0J6QX06ATI01PH600501TI
6@0501PH600J6QX061PH01PH600I6AT00P0H61P02P0I6AT061PH01TI6@0J6QX061PH01TI6@0H61P0
6ATI01XJ6P0H61P201TI6@0301PH600I6AT06ATI00806ATI00<06a/K01TI6@0H61P00`0I6AT201XJ
6P806ATI0P0J6QX201TI6@0301XJ6P0I6AT061PH00<06ATI00D061PH01TI6@0J6QX06QXJ01TI6@02
01XJ6P806ATI0P0J6QX00`0I6AT06QXJ01/K6`0901TI6@@06QXJ00d06ATI01XJ6P0J6QX061PH01XJ
6P0I6AT061PH01XJ6P0I6AT06QXJ01TI6@0K6a/06ATI00806QXJ0P0I6AT00`0H61P06QXJ01TI6@03
01TI6@0501PH600J6QX06QXJ01XJ6P0K6a/00P0J6QX0100K6a/06ATI01XJ6P0K6a/401XJ6PD06ATI
00@061PH01XJ6P0J6QX061PH1@0J6QX201TI6@0301XJ6P0I6AT06ATI00806ATI00L061PH01TI6@0H
61P06ATI01PH600I6AT061PH00806ATI00<06QXJ01TI6@0I6AT00`0J6QX201/K6`0601PH600I6AT0
6ATI01XJ6P0I6AT061PH100I6AT0100J6QX06ATI01XJ6P0K6a/201PH60L06ATI00@061PH01TI6@0I
6AT06QXJ1@0I6AT0100J6QX061PH01TI6@0H61P301TI6@8061PH00@06ATI01PH600H61P061PH0`0I
6AT00`0J6QX06ATI01PH600201PH600301LG5`0I6AT06ATI00806ATI100H61P01@0I6AT061PH01PH
600G5aL06ATI00D061PH00D06ATI01PH600H61P061PH01TI6@0501PH600401LG5`0H61P06ATI01TI
6@@061PH0P0I6AT201PH600301TI6@0J6QX06a/K00H06ATI00<061PH01TI6@0H61P00P0I6AT201PH
600401TI6@0H61P06ATI01TI6@@0fMWI0`0000010=WIf@000P3IfMT2000000<0fMWI00@000000=WI
f@3IfMT000000P3IfMT010000000fMWI0=WIf@0000050=WIf@030000003IfMT0fMWI00<0fMWI0P0I
6AT00`0J6QX06ATI01TI6@0301TI6@806QXJ00@061PH01TI6@0I6AT06ATI0P0J6QX301TI6@0301PH
600I6AT06ATI00806ATI00<06QXJ01PH600J6QX00`0I6AT301XJ6P0401TI6@0J6QX06QXJ01PH6080
6ATI00L061PH01TI6@0I6AT06ATI01PH600J6QX061PH00@06ATI00<061PH01TI6@0H61P00P0I6AT0
100H61P06QXJ01XJ6P0I6AT201XJ6P806ATI00@061PH01XJ6P0J6QX061PH0`0I6AT01@0H61P06ATI
01TI6@0I6AT06QXJ00806ATI00@061PH01TI6@0J6QX06QXJ0P0I6AT02@0J6QX061PH01TI6@0I6AT0
6QXJ01TI6@0J6QX06ATI01XJ6P0201TI6@0401PH600J6QX06ATI01XJ6P@06ATI00@061PH01TI6@0J
6QX06QXJ0`0I6AT00`0H61P06QXJ01XJ6P0201XJ6P806ATI0P0J6QX01@0H61P06ATI01XJ6P0H61P0
6ATI00806QXJ00@06ATI01XJ6P0J6QX06QXJ0`0I6AT201XJ6P<06ATI0`0J6QX301TI6@806QXJ00<0
61PH01XJ6P0I6AT01@0J6QX201TI6@@06QXJ0P0I6AT00`0J6QX06ATI01XJ6P0201XJ6P8061PH00D0
6QXJ01TI6@0I6AT06ATI01XJ6P0:01TI6@0401XJ6P0I6AT061PH01PH60806ATI00D06QXJ01TI6@0H
61P06ATI01XJ6P0401TI6@0301XJ6P0K6a/06QXJ00806ATI00@061PH01TI6@0H61P06QXJ0P0I6AT2
01XJ6P<06ATI00<06QXJ01TI6@0I6AT00P0I6AT301PH60H06ATI00H061PH01XJ6P0I6AT06QXJ01PH
600J6QX201TI6@0401PH600J6QX06ATI01TI6@@061PH00<06ATI01PH600H61P00`0H61P401TI6@06
01PH600I6AT05aLG01TI6@0H61P06ATI100H61P01`0I6AT061PH01PH600I6AT05aLG01PH600I6AT0
0P0H61P201TI6@8061PH00@05aLG01TI6@0H61P05aLG0P0I6AT0100G5aL061PH01PH600H61P201TI
6@<061PH0P0I6AT00`0H61P06ATI01/K6`0401TI6@0401PH600I6AT061PH01XJ6P@06ATI00D05aLG
01PH600H61P05aLG01TI6@060=WIf@4000000@3IfMT00080fMWI00<000000=WIf@3IfMT00P3IfMT0
10000000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI000000D0fMWI00<000000=WIf@3IfMT0
0`3IfMT201PH60@06ATI00D06QXJ01PH600J6QX06QXJ01/K6`0201TI6@0801XJ6P0H61P06ATI01TI
6@0H61P06ATI01PH600I6AT201XJ6P806ATI0P0J6QX0100I6AT061PH01TI6@0H61P301XJ6PH06ATI
00@06QXJ01TI6@0I6AT06QXJ0`0I6AT00`0J6QX06ATI01TI6@0201TI6@0401PH600I6AT06ATI01PH
60D06QXJ0P0I6AT301XJ6PL06ATI00T06QXJ01TI6@0I6AT06ATI01XJ6P0I6AT06QXJ01PH600J6QX0
1@0I6AT0100J6QX06ATI01TI6@0I6AT301XJ6P0601TI6@0H61P06ATI01/K6`0I6AT061PH0`0J6QX0
4P0K6a/06ATI01TI6@0J6QX06ATI01XJ6P0G5aL06QXJ01TI6@0J6QX06a/K01XJ6P0I6AT06QXJ01/K
6`0J6QX06ATI01XJ6P<06a/K0`0I6AT201XJ6P0401TI6@0H61P06ATI01PH60<06ATI00H061PH01`L
700J6QX06QXJ01PH600J6QX501PH60806ATI00<06QXJ01TI6@0I6AT00P0J6QX201TI6@<06QXJ0`0I
6AT0100J6QX06ATI01TI6@0I6AT201XJ6P@06ATI00<06QXJ01TI6@0J6QX01P0I6AT01@0J6QX06ATI
01TI6@0I6AT061PH00806QXJ0P0I6AT01P0J6QX06ATI01TI6@0H61P06QXJ01PH60806ATI00@061PH
01XJ6P0I6AT06ATI0P0J6QX00`0I6AT06QXJ01TI6@0201TI6@806QXJ0P0I6AT01P0J6QX06ATI01PH
600I6AT06QXJ01TI6@<061PH1@0I6AT0100H61P06ATI01XJ6P0I6AT201PH600301TI6@0H61P06QXJ
008061PH0`0I6AT301PH600501LG5`0I6AT061PH01TI6@0G5aL00`0I6AT01P0H61P06ATI01TI6@0H
61P06QXJ01TI6@<061PH00<05aLG01PH600H61P00`0H61P02@0J6QX061PH01PH600G5aL061PH01XJ
6P0H61P06ATI01PH600201LG5`806ATI00D05aLG01PH600G5aL061PH01TI6@0201PH60<06ATI0P0H
61P01@0J6QX06ATI01TI6@0I6AT06a/K00806ATI0P0H61P01@0J6QX06ATI01XJ6P0I6AT061PH0080
6QXJ00@05aLG01PH600H61P061PH0P0G5aL60=WIf@4000000@3IfMT00080fMWI0`0000030=WIf@80
0000103IfMT2000000H0fMWI00<000000=WIf@3IfMT00`3IfMT00`0J6QX06ATI01TI6@0601TI6@05
01PH600I6AT061PH01XJ6P0I6AT00P0J6QX01@0I6AT061PH01TI6@0I6AT061PH00@06ATI00D06QXJ
01TI6@0I6AT061PH01TI6@0301XJ6P0501LG5`0I6AT06ATI01TI6@0J6QX01@0I6AT201XJ6P0501TI
6@0J6QX06QXJ01TI6@0J6QX00P0I6AT00`0H61P06QXJ01TI6@0301TI6@806QXJ00<061PH01XJ6P0J
6QX01@0I6AT00`0J6QX06a/K01TI6@0501TI6@0401XJ6P0I6AT06QXJ01TI6@806QXJ0`0I6AT0200H
61P06ATI01PH600I6AT06a/K01XJ6P0I6AT06QXJ100I6AT0200J6QX06ATI01XJ6P0J6QX06ATI01PH
600J6QX061PH0P0J6QX201PH600301XJ6P0H61P06QXJ00806QXJ00@06ATI01XJ6P0I6AT06QXJ0`0I
6AT201XJ6P0401TI6@0J6QX06ATI01TI6@<06QXJ00@06ATI01PH600J6QX06ATI0P0J6QX00`0H61P0
6QXJ01TI6@0701TI6@0301XJ6P0I6AT06QXJ00<06ATI00<06QXJ01TI6@0J6QX00P0I6AT00`0K6a/0
6ATI01/K6`0201TI6@0301XJ6P0H61P06ATI00806ATI00@06a/K01TI6@0J6QX06ATI0P0J6QX0100I
6AT06QXJ01TI6@0J6QX201TI6@0901XJ6P0I6AT06ATI01TI6@0K6a/06ATI01HF5P0H61P06QXJ00<0
6ATI00@06QXJ01TI6@0H61P06QXJ0`0I6AT03@0J6QX06ATI01TI6@0J6QX06ATI01XJ6P0H61P06QXJ
01PH600I6AT061PH01XJ6P0K6a/00`0J6QX00`0I6AT06QXJ01XJ6P0201PH600301XJ6P0I6AT06ATI
00806ATI0P0J6QX00`0I6AT061PH01XJ6P0301PH60<06ATI00@05aLG01TI6@0I6AT06ATI100H61P2
01TI6@0401PH600I6AT061PH01TI6@8061PH00<06ATI01PH600I6AT00P0I6AT0100J6QX06ATI01PH
600G5aL401PH600301TI6@0H61P05aLG00H061PH00<06ATI01PH600H61P00`0H61P01@0G5aL061PH
01PH600H61P06ATI008061PH00<05aLG01PH600I6AT0100H61P00`0I6AT061PH01PH600201TI6@80
61PH00D06QXJ01TI6@0H61P061PH01TI6@0301PH600301LG5`0H61P06ATI00<061PH1P3IfMT10000
0040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00<06QXJ01TI6@0H61P00P0I6AT201XJ6P80
6ATI00<06QXJ01TI6@0I6AT00P0I6AT0100H61P06ATI01XJ6P0H61P601TI6@0301XJ6P0I6AT061PH
00<06ATI00@061PH01XJ6P0J6QX06ATI0P0J6QX01`0I6AT06QXJ01XJ6P0I6AT06QXJ01TI6@0J6QX0
100I6AT02@0H61P06QXJ01TI6@0I6AT06a/K01TI6@0J6QX061PH01TI6@0201XJ6P<06ATI00/06QXJ
01TI6@0K6a/06QXJ01TI6@0J6QX06ATI01PH600J6QX06ATI01XJ6P0301TI6@0401XJ6P0H61P061PH
01XJ6P<06ATI00H061PH01XJ6P0I6AT06ATI01XJ6P0I6AT301XJ6P<06ATI0P0H61P201TI6@0301XJ
6P0I6AT06QXJ00806ATI0P0J6QX00`0I6AT06QXJ01TI6@0401TI6@0301XJ6P0K6a/06QXJ00<06QXJ
00D06a/K01XJ6P0J6QX06ATI01XJ6P0401TI6@0501XJ6P0I6AT06QXJ01PH600I6AT00P0J6QX201TI
6@0>01XJ6P0I6AT06ATI01TI6@0J6QX06a/K01XJ6P0K6a/06QXJ01PH600J6QX06ATI01PH600J6QX2
01TI6@0501/K6`0J6QX06ATI01XJ6P0I6AT00`0J6QX00`0K6a/06ATI01XJ6P0601TI6@806QXJ100I
6AT0100J6QX061PH01PH600J6QX601TI6@0401LG5`0J6QX06QXJ01XJ6P<06ATI00@05aLG01TI6@0I
6AT06QXJ0`0I6AT0100H61P06ATI01TI6@0I6AT201XJ6P0301PH600I6AT06ATI00<06ATI0P0J6QX4
01TI6@0301PH600I6AT06ATI00<061PH00P06ATI01PH600H61P06ATI01PH600J6QX06ATI01PH6080
6ATI00<061PH01XJ6P0I6AT01P0I6AT0100H61P06ATI01TI6@0I6AT201PH600301TI6@0H61P06ATI
00806ATI100H61P201TI6@H061PH0`0I6AT01@0H61P05aLG01PH600H61P06ATI00@061PH00@06ATI
01PH600H61P06ATI0P0H61P01P0G5aL061PH01PH600I6AT061PH01TI6@8061PH0`0I6AT01P0J6QX0
61PH01TI6@0H61P06ATI01PH60806ATI00<061PH01TI6@0H61P00P0H61P01`0I6AT061PH01PH600I
6AT061PH01TI6@0H61P01P3IfMT100000040fMWI000F0=WIf@030000003IfMT0fMWI00<0fMWI00<0
6QXJ01TI6@0I6AT0100I6AT00`0J6QX06ATI01XJ6P0201XJ6P0301TI6@0J6QX06ATI00806ATI00L0
61PH01TI6@0I6AT06ATI01XJ6P0I6AT06QXJ00806ATI00D061PH01TI6@0I6AT06ATI01XJ6P0201TI
6@0301XJ6P0I6AT061PH00@06ATI0P0J6QX0100H61P06ATI01TI6@0K6a/201PH60806ATI0P0H61P0
1@0I6AT06QXJ01TI6@0I6AT061PH00D06ATI00@06a/K01TI6@0I6AT06ATI0`0J6QX0100K6a/06ATI
01XJ6P0J6QX201TI6@806QXJ00D061PH01XJ6P0I6AT06QXJ01PH600301TI6@@06QXJ0`0I6AT0100K
6a/06QXJ01XJ6P0J6QX301TI6@0301XJ6P0I6AT06QXJ00806ATI0P0J6QX0100I6AT06QXJ01XJ6P0I
6AT401XJ6P0301/K6`0J6QX06QXJ00806ATI0P0J6QX00`0H61P06QXJ01XJ6P0201TI6@0401XJ6P0I
6AT06a/K01XJ6PD06ATI00D06QXJ01TI6@0I6AT06ATI01PH600201XJ6P806ATI00H06a/K01XJ6P0I
6AT06ATI01/K6`0J6QX201TI6@0301XJ6P0I6AT06ATI00806ATI00D06QXJ01TI6@0I6AT06ATI01PH
600201TI6@0501XJ6P0I6AT06ATI01TI6@0J6QX00P0I6AT01@0J6QX06ATI01PH600I6AT061PH00/0
6ATI0`0J6QX01`0H61P06ATI01TI6@0J6QX06ATI01XJ6P0H61P00P0J6QX01@0H61P06ATI01TI6@0I
6AT061PH00806ATI00<06QXJ01PH600I6AT00P0J6QX601TI6@806QXJ00L06ATI01XJ6P0I6AT06ATI
01PH600I6AT061PH00806ATI00<06QXJ01LG5`0H61P00`0H61P201TI6@0401LG5`0H61P06QXJ01XJ
6P8061PH100I6AT01`0G5aL06ATI01TI6@0I6AT061PH01TI6@0H61P00`0I6AT201PH60806ATI0P0H
61P301TI6@X061PH00<05aLG01PH600G5aL00P0H61P201LG5`0601PH600G5aL061PH01TI6@0H61P0
6ATI0`0H61P00`0I6AT061PH01PH600301PH600501TI6@0H61P061PH01TI6@0H61P00`0I6AT201PH
60806ATI00D05aLG01PH600I6AT06ATI01XJ6P060=WIf@4000000@3IfMT001H0fMWI00<000000=WI
f@3IfMT00`3IfMT00`0I6AT061PH01TI6@0401TI6@0401/K6`0I6AT06QXJ01XJ6P<06ATI00@06QXJ
01TI6@0I6AT06ATI0P0H61P00`0J6QX06ATI01TI6@0501XJ6P0501TI6@0J6QX061PH01XJ6P0G5aL0
0P0I6AT201XJ6P0301TI6@0J6QX06ATI00@06ATI00D06QXJ01PH600J6QX06ATI01XJ6P0201TI6@03
01PH600I6AT06ATI008061PH0P0I6AT02P0H61P06ATI01TI6@0J6QX061PH01TI6@0J6QX05aLG01TI
6@0J6QX301TI6@0301XJ6P0I6AT06ATI00H06ATI00H06a/K01XJ6P0I6AT06ATI01XJ6P0I6AT401XJ
6P806ATI0P0J6QX301TI6@806QXJ1@0I6AT201XJ6P@06ATI1@0J6QX00`0I6AT06a/K01TI6@0201TI
6@806QXJ100I6AT00`0J6QX06ATI01PH600301XJ6P0601TI6@0J6QX06ATI01PH600J6QX06ATI100J
6QX201TI6@806QXJ0P0I6AT00`0K6a/06QXJ01TI6@0301XJ6P<06ATI00@06QXJ01PH600H61P06ATI
0P0H61P201XJ6P0301TI6@0J6QX06ATI00@06ATI0`0H61P201XJ6P<06ATI00@06QXJ01TI6@0I6AT0
61PH0P0I6AT01@0H61P06QXJ01TI6@0J6QX061PH00@06ATI00<061PH01TI6@0I6AT01P0I6AT01`0H
61P06ATI01TI6@0I6AT061PH01TI6@0J6QX0100I6AT02P0H61P06ATI01PH600H61P06ATI01XJ6P0I
6AT06QXJ01TI6@0H61P201TI6@806QXJ0`0I6AT00`0G5aL06ATI01PH600501TI6@8061PH0P0I6AT2
01PH600601TI6@0H61P05aLG01TI6@0H61P06ATI0`0H61P0100I6AT061PH01LG5`0I6AT501PH6006
01LG5`0I6AT061PH01TI6@0H61P06ATI100H61P01`0F5QH061PH01LG5`0H61P05aLG01PH600I6AT0
0P0H61P0100I6AT05aLG01PH600I6AT201PH60806ATI00@061PH01TI6@0H61P06ATI0P0H61P00`0G
5aL06ATI01PH600201PH600401TI6@0H61P061PH01TI6@<061PH00<06ATI01PH600H61P00P0I6AT6
0=WIf@4000000@3IfMT001H0fMWI00<000000=WIf@3IfMT00`3IfMT501TI6@@06QXJ00D06ATI01XJ
6P0J6QX06ATI01PH600301TI6@0301XJ6P0I6AT06QXJ00806ATI00<061PH01XJ6P0I6AT0100I6AT0
200H61P06ATI01TI6@0J6QX061PH01XJ6P0I6AT061PH1@0I6AT201XJ6P0401PH600I6AT06QXJ01PH
60<06ATI00@061PH01XJ6P0I6AT061PH0P0I6AT0200H61P06a/K01TI6@0H61P06ATI01PH600I6AT0
61PH0`0I6AT01@0J6QX061PH01XJ6P0J6QX06ATI00806QXJ0P0I6AT0100H61P06ATI01TI6@0K6a/4
01TI6@0401/K6`0I6AT061PH01XJ6P<06ATI00@06QXJ01PH600H61P06ATI0P0J6QX301TI6@806QXJ
00<06ATI01XJ6P0I6AT00`0I6AT0100K6a/06ATI01TI6@0I6AT201XJ6P806ATI0`0J6QX301TI6@06
01PH600I6AT06ATI01/K6`0I6AT061PH0`0I6AT01P0J6QX06ATI01XJ6P0J6QX06ATI01PH60806QXJ
1@0I6AT01P0H61P06ATI01TI6@0H61P06QXJ01TI6@806QXJ0`0I6AT00`0H61P06QXJ01XJ6P0301TI
6@806QXJ1@0I6AT401XJ6P0401TI6@0H61P06QXJ01TI6@806QXJ0P0I6AT01@0J6QX06ATI01TI6@0J
6QX061PH00806ATI00<06a/K01XJ6P0H61P01@0I6AT01`0J6QX061PH01TI6@0I6AT061PH01LG5`0J
6QX00P0I6AT301XJ6P0801PH600I6AT06ATI01/K6`0J6QX061PH01TI6@0H61P301TI6@0301XJ6P0I
6AT06ATI00806ATI00<061PH01XJ6P0J6QX00P0I6AT01P0K6a/06ATI01XJ6P0I6AT06QXJ01PH60T0
6ATI00D061PH01LG5`0I6AT06ATI01PH600201TI6@0401PH600I6AT06ATI01TI6@H061PH00<06ATI
01PH600I6AT00P0I6AT0100H61P05aLG01PH600H61P201TI6@<061PH00<06ATI01PH600H61P00P0H
61P201LG5`0601PH600I6AT06QXJ01PH600G5aL06ATI1P0H61P0100I6AT061PH01PH600H61P301TI
6@0601LG5`0I6AT06ATI01PH600G5aL06QXJ100I6AT201PH600301LG5`3IfMT0fMWI00@0fMWI0@00
00010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@0301PH600G5aL06QXJ00@061PH00<06QXJ
01TI6@0I6AT00P0G5aL00`0H61P06ATI01TI6@0201PH600301TI6@0H61P06ATI008061PH00<05aLG
01PH600I6AT00P0H61P00`0G5aL061PH01PH600301LG5`8061PH00L06ATI01PH600H61P06ATI01PH
600G5aL061PH00805aLG00<061PH01LG5`0G5aL00P0H61P01P0G5aL061PH01LG5`0G5aL061PH01LG
5`806ATI00X05aLG01HF5P0H61P05QHF01TI6@0H61P06ATI01PH600F5QH05aLG1P0H61P401TI6@06
01LG5`0H61P061PH01LG5`0H61P06ATI0P0H61P301TI6@0501PH600I6AT061PH01TI6@0G5aL00`0H
61P00`0I6AT05aLG01PH600501PH60805aLG0P0H61P00`0I6AT061PH01PH600201PH60806ATI0P0H
61P0100I6AT06QXJ01TI6@0J6QX201PH600301TI6@0H61P061PH00<061PH0P0I6AT00`0H61P06ATI
01TI6@0201PH600301LG5`0H61P05aLG00H061PH00D05aLG01PH600H61P061PH01TI6@0201PH60@0
6ATI0`0H61P0100G5aL061PH01PH600H61P201LG5`0?01PH600K6a/061PH01PH600G5aL061PH01LG
5`0H61P05aLG01PH600G5aL061PH01LG5`0H61P06ATI008061PH00@06ATI01PH600I6AT05QHF0`0H
61P01`0G5aL06ATI01PH600J6QX061PH01HF5P0H61P00P0G5aL00`0H61P06ATI01PH600301LG5`08
01PH600G5aL061PH01PH600F5QH05aLG01TI6@0G5aL401PH600301LG5`0H61P061PH00<05aLG0`0H
61P01`0G5aL06ATI01PH600G5aL061PH01LG5`0I6AT00`0G5aL201PH60805aLG00D061PH01HF5P0H
61P05aLG01HF5P0201LG5`0301PH600G5aL05aLG00<05aLG00<05QHF01LG5`0F5QH00`0H61P301LG
5`0301HF5P0H61P05QHF00805aLG0P0H61P03`0G5aL05QHF01LG5`0G5aL05ADE01HF5P0G5aL05QHF
01LG5`0F5QH05aLG01HF5P0H61P05QHF01PH600201HF5PL05aLG00<05QHF01DE5@0F5QH00`0G5aL0
1@0F5QH05aLG01LG5`0F5QH061PH00805aLG0P0H61P0100G5aL05QHF01HF5P0G5aL201PH600301LG
5`3IfMT0fMWI00@0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WIfD@0fMWI0@00
00010=WIf@005P3IfMT00`000000fMWI0=WIf@3o0=WIfD@0fMWI0@0000010=WIf@005P3IfMT00`00
0000fMWI0=WIf@3o0=WIfD@0fMWI0@0000010=WIf@005P3IfMT00`000000fMWI0=WIf@030=WIf@03
0000003IfMT0fMWI03X0fMWI00<000000=WIf@3IfMT0>`3IfMT00`000000fMWI0=WIf@0j0=WIf@03
0000003IfMT0fMWI03X0fMWI00<000000=WIf@3IfMT0>`3IfMT00`000000fMWI0=WIf@0:0=WIf@40
00000@3IfMT001H0fMWI0P0000040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0
2@3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0
2@3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0
2@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
2@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0
2P3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0
2P3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0
2@3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0
2@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
2@3IfMT200000040fMWI000F0=WIfOl00000B00000010=WIf@00o`3IfMUO0=WIf@00o`3IfMUO0=WI
f@00o`3IfMUO0=WIf@00o`3IfMUO0=WIf@00\
\>"],
  ImageRangeCache->{{{0, 349}, {349, 0}} -> {-46.2288, -38.9981, 1.62945, \
1.62945}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowSize->{816, 651},
WindowMargins->{{78, Automatic}, {Automatic, -3}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions (based on Report.nb)", "Subtitle"],
  
  Cell["Created by Andy Hunt for use with \"newin42.nb\"", "Text",
    FontWeight->"Bold"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.
Make modifications to any definition using commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Color"->RGBColor[0.744411, 0.47155, 0.371542]},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowCellLabel->False,
    ImageSize->{200, 200},
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"New in ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], " 4.2"}], 
            "Header"]}, {Cell[ 
            TextData[ {"New in ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], " 4.2"}], 
            "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"FirstPageHeader"->False,
    "FirstPageFooter"->False},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellFrame->{{0, 0}, {0, 0.25}},
    CellMargins->{{18, 10}, {0, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CellFrameColor->GrayLevel[0],
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    LineSpacing->{0.95, 13},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->RGBColor[0.4, 0, 0.239994]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{20, 10}, {2, 20}},
    CellFrameMargins->5,
    FontColor->RGBColor[0.744411, 0.47155, 0.371542]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 30}, {0, 0}},
    CellFrameMargins->4,
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{20, 30}, {2, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CellFrameMargins->{{0, 4}, {8, 4}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    LineSpacing->{1, 0},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{20, 10}, {2, 10}}],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 30}, {0, 10}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section 1"],
    CellFrame->{{0, 0}, {0, 3}},
    CellMargins->{{18, 10}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->{{0, 4}, {8, 4}},
    CellFrameColor->RGBColor[0.4, 0, 0.239994],
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section 1", "Presentation"],
    CellMargins->{{20, 10}, {6, 30}},
    CellFrameMargins->5],
  
  Cell[StyleData["Section 1", "Printout"],
    CellMargins->{{18, 30}, {4, 30}},
    CellFrameMargins->4,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 0.25}},
    CellMargins->{{18, 10}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0.4, 0, 0.239994],
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{20, 10}, {0, 30}}],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 30}, {0, 30}},
    CellFrameMargins->5,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{35, 30}, {2, 20}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{35, 30}, {0, 20}}],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{2, 30}, {0, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{55, 30}, {4, 10}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{31, 30}, {0, 12}}],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 30}, {0, 12}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{55, 10}, {6, 6}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 2},
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{20, 10}, {6, 6}},
    TextAlignment->Left,
    TextJustification->0,
    LineSpacing->{1.3, 0},
    FontSize->14],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{28, 4}, {4, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellMargins->{{55, 10}, {2, 6}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 2},
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["Commentary", "Presentation"],
    CellMargins->{{60, 30}, {2, 6}},
    TextJustification->1,
    LineSpacing->{1.3, 0},
    FontSize->12],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{18, 30}, {3, 0}},
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->{{1, 1}, {0, 1}},
    CellMargins->{{55, 10}, {0, 0}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelPositioning->Automatic,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    FontSize->12,
    FontWeight->"Bold",
    Background->GrayLevel[0.966674]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{60, 10}, {0, 10}},
    Background->GrayLevel[0.850004]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{55, 12}, {-1, 10}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10,
    Background->GrayLevel[0.850004]]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->{{1, 1}, {1, 0}},
    CellMargins->{{55, 10}, {15, 0}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    FontSize->12,
    Background->GrayLevel[0.850004]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{60, Inherited}, {10, 0}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{55, 12}, {10, 0}},
    PageBreakWithin->Automatic,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InputOnly"],
    CellFrame->1,
    CellMargins->{{55, 10}, {15, 0}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelPositioning->Automatic,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    FontSize->12,
    FontWeight->"Bold",
    Background->GrayLevel[0.966674]],
  
  Cell[StyleData["InputOnly", "Presentation"],
    CellMargins->{{60, Inherited}, {10, 10}}],
  
  Cell[StyleData["InputOnly", "Printout"],
    CellMargins->{{55, 12}, {10, 10}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellFrame->{{1, 1}, {0, 0}},
    CellDingbat->"\[LongDash]",
    CellMargins->{{55, 10}, {0, 0}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{60, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{55, 12}, {0, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{55, 26}, {1, 6}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    Background->GrayLevel[0.700008]],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{60, Inherited}, {10, 2}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {2, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellFrame->{{1, 1}, {1, 0}},
    CellMargins->{{55, 10}, {12, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    Background->GrayLevel[0.850004]],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{60, Inherited}, {0, 0}},
    ImageMargins->{{10, 10}, {10, 10}}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{55, 12}, {0, 0}},
    ImageSize->{0.0625, 0.0625}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontSlant->"Oblique",
    FontColor->RGBColor[0.6, 0, 0.6]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    CellMargins->{{18, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["CellLabel", "Printout"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Additional Styles for NewIn42", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ScreenShots"],
    CellMargins->{{18, 10}, {20, 20}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    ImageMargins->{{35, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["ScreenShots", "Printout"],
    CellMargins->{{45, 4}, {12, 12}},
    Magnification->0.45]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ScreenShots2"],
    CellMargins->{{18, 10}, {20, 20}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    ImageMargins->{{35, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["ScreenShots2", "Printout"],
    CellMargins->{{45, 4}, {12, 12}},
    Magnification->0.75]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BilateralCell"],
    CellMargins->{{55, 10}, {6, 6}},
    StyleMenuListing->None,
    FontSize->12,
    GridBoxOptions->{ColumnWidths->{0.33, 0.6},
    RowAlignments->Top,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BilateralCell", "Printout"],
    CellMargins->{{28, 2}, {6, 6}},
    TextJustification->1,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellFrame->False,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10],
  
  Cell[StyleData["InlineFormula", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10],
  
  Cell[StyleData["InlineFormula", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5],
  
  Cell[StyleData["InlineOutput", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5],
  
  Cell[StyleData["InlineOutput", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{20, 30}, {45, 5}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CellFrameMargins->{{0, 4}, {8, 4}},
    LineSpacing->{1, 0},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{20, 30}, {45, 10}}],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{18, 30}, {45, 5}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellFrame->False,
    CellMargins->{{18, 140}, {4, 30}},
    Hyphenation->True,
    LineSpacing->{0.9, 0},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Abstract", "Presentation"],
    CellFrame->True,
    CellMargins->{{20, 10}, {Inherited, 30}}],
  
  Cell[StyleData["Abstract", "Printout"],
    LineSpacing->{1, 2},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{55, 10}, {5, 3}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Presentation"],
    CellMargins->{{60, 65}, {6, 4}},
    FontSize->10],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{55, 55}, {5, 4}},
    LineSpacing->{1, 2},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{24, 40}, {6, 6}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 0},
    FontFamily->"Times"],
  
  Cell[StyleData["Reference", "Presentation"],
    CellMargins->{{20, 40}, {Inherited, 6}},
    TextJustification->0,
    LineSpacing->{1, 4},
    FontSize->12],
  
  Cell[StyleData["Reference", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellFrame->{{1, 1}, {0, 0}},
    CellMargins->{{55, Inherited}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    ShowCellLabel->False,
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    Background->GrayLevel[0.850004]],
  
  Cell[StyleData["PictureGroup", "Presentation"],
    CellMargins->{{60, Inherited}, {0, 0}},
    ImageMargins->{{10, 10}, {10, 10}}],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{55, Inherited}, {0, 0}},
    ImageSize->{0.0625, 0.0625}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{60, 10}, {Inherited, 6}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{18, 4}, {4, 4}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{55, 10}, {Inherited, 0}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    TextJustification->1,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{60, 10}, {Inherited, 6}}],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{55, 10}, {Inherited, 0}},
    CellHorizontalScrolling->True,
    Hyphenation->False,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{60, 10}, {Inherited, 6}}],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    LineSpacing->{1, 3},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{55, 85}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontFamily->"Times"],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{60, 10}, {Inherited, 6}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{55, 95}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}], FontWeight -> "Bold"], None}},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False,
    FontFamily->"Times"],
  
  Cell[StyleData["NumberedFigure", "Presentation"],
    CellMargins->{{60, 80}, {Inherited, 6}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    CellMargins->{{18, 80}, {4, 4}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{55, 95}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}], FontWeight -> "Bold"], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False,
    FontFamily->"Times"],
  
  Cell[StyleData["NumberedTable", "Presentation"],
    CellMargins->{{60, 80}, {Inherited, 6}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["NumberedTable", "Printout"],
    CellMargins->{{18, 80}, {4, 4}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["PageNumber"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"],
  
  Cell[StyleData["Footer"],
    TextAlignment->Center,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Slide Show Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowNavigationBar"],
    Editable->False,
    CellFrame->True,
    CellMargins->{{0, 0}, {3, 3}},
    CellGroupingRules->{"SectionGrouping", 30},
    CellFrameMargins->False,
    CellFrameColor->GrayLevel[1],
    CellFrameLabelMargins->False,
    TextAlignment->Center,
    CounterIncrements->"SlideShowNavigationBar",
    StyleMenuListing->None,
    FontSize->10,
    Background->GrayLevel[0.8],
    GridBoxOptions->{RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->{3.5, 3.5, 3.5, 3.5, 13, 5, 4},
    ColumnAlignments->{
      Center, Center, Center, Center, Center, Center, Right, Center}}],
  
  Cell[StyleData["SlideShowNavigationBar", "SlideShow"],
    Deletable->False,
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {-1, 0}},
    PageBreakAbove->True],
  
  Cell[StyleData["SlideShowNavigationBar", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{0, 0}, {10, 0}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->{{12, 4}, {6, 12}},
    CellFrameColor->RGBColor[0.4, 0, 0.239994],
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->RGBColor[0.6, 0.749996, 0.899992]],
  
  Cell[StyleData["SlideShowSection", "SlideShow"],
    ShowCellBracket->False,
    PageBreakAbove->True],
  
  Cell[StyleData["SlideShowSection", "Printout"],
    CellMargins->{{18, 30}, {0, 30}},
    CellFrameMargins->5,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideHyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->16,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMargins->1.5,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["SlideHyperlink", "SlideShow"],
    FontSize->16],
  
  Cell[StyleData["SlideHyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOCLink"],
    CellMargins->{{24, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Helvetica",
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMargins->1.5,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["SlideTOCLink", "SlideShow"]],
  
  Cell[StyleData["SlideTOCLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOC"],
    CellDingbat->"\[Bullet]",
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["SlideTOC", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["SlideTOC", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["1ColumnBox", "SlideShow"],
    CellMargins->{{36, 36}, {3, 6}},
    Background->RGBColor[0.700008, 0.849989, 0.949996]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.31, 0.67}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnBox", "SlideShow"],
    CellMargins->{{36, 36}, {6, 6}},
    Background->RGBColor[0.700008, 0.849989, 0.949996]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox", "SlideShow"],
    CellMargins->{{36, 36}, {6, 6}},
    Background->RGBColor[0.700008, 0.849989, 0.949996]]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 313, 10, 41, "Subtitle"],
Cell[2092, 65, 915, 15, 139, "Abstract"],

Cell[CellGroupData[{
Cell[3032, 84, 33, 0, 67, "Section"],
Cell[3068, 86, 129, 3, 55, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[3234, 94, 43, 0, 67, "Section"],
Cell[3280, 96, 1402, 23, 165, "Text"],
Cell[4685, 121, 166, 4, 35, "Input"],
Cell[4854, 127, 822, 12, 114, "Text"],
Cell[5679, 141, 168, 4, 35, "Input"],

Cell[CellGroupData[{
Cell[5872, 149, 127, 2, 35, "Input"],
Cell[6002, 153, 1092775, 14981, 379, 537128, 8118, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1098792, 15137, 260, 5, 46, "Text"],
Cell[1099055, 15144, 276, 5, 46, "Text"],
Cell[1099334, 15151, 167, 4, 35, "Input"],
Cell[1099504, 15157, 143, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[1099672, 15164, 142, 2, 35, "Input"],
Cell[1099817, 15168, 780, 18, 109, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1100646, 15192, 37, 0, 67, "Section"],
Cell[1100686, 15194, 289, 5, 46, "Text"],
Cell[1100978, 15201, 175, 3, 29, "Text"],
Cell[1101156, 15206, 67, 1, 35, "Input"],
Cell[1101226, 15209, 152, 3, 29, "Text"],
Cell[1101381, 15214, 190, 3, 35, "Input"],
Cell[1101574, 15219, 134, 3, 29, "Text"],
Cell[1101711, 15224, 149, 3, 35, "Input"],
Cell[1101863, 15229, 99, 2, 29, "Text"],
Cell[1101965, 15233, 107, 2, 35, "Input"],
Cell[1102075, 15237, 137, 3, 29, "Text"],
Cell[1102215, 15242, 159, 3, 35, "Input"],
Cell[1102377, 15247, 169, 3, 29, "Text"],
Cell[1102549, 15252, 114, 2, 35, "Input"],
Cell[1102666, 15256, 179, 4, 46, "Text"],
Cell[1102848, 15262, 75, 1, 35, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1102960, 15268, 39, 0, 67, "Section"],
Cell[1103002, 15270, 445, 7, 63, "Text"],

Cell[CellGroupData[{
Cell[1103472, 15281, 155, 2, 35, "Input"],
Cell[1103630, 15285, 1029756, 14212, 354, 578874, 8642, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2133401, 29500, 171, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[2133597, 29507, 131, 2, 35, "Input"],
Cell[2133731, 29511, 1057642, 14548, 379, 537128, 8118, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[3191388, 44062, 301, 7, 46, "Text"],

Cell[CellGroupData[{
Cell[3191714, 44073, 170, 3, 35, "Input"],
Cell[3191887, 44078, 1003967, 13885, 379, 537128, 8118, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

